Method: Stripe::PaymentIntent#amount

Defined in:
lib/stripe/resources/payment_intent.rb

#amountObject (readonly)

Amount intended to be collected by this PaymentIntent. A positive integer representing how much to charge in the [smallest currency unit](docs.stripe.com/currencies#zero-decimal) (e.g., 100 cents to charge $1.00 or 100 to charge ¥100, a zero-decimal currency). The minimum amount is $0.50 US or [equivalent in charge currency](docs.stripe.com/currencies#minimum-and-maximum-charge-amounts). The amount value supports up to eight digits (e.g., a value of 99999999 for a USD charge of $999,999.99).



2822
2823
2824
# File 'lib/stripe/resources/payment_intent.rb', line 2822

def amount
  @amount
end