Class: Stripe::Account::BusinessProfile

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: AnnualRevenue, MonthlyEstimatedRevenue, SupportAddress

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#annual_revenueObject (readonly)

The applicant’s gross annual revenue for its preceding fiscal year.



69
70
71
# File 'lib/stripe/resources/account.rb', line 69

def annual_revenue
  @annual_revenue
end

#estimated_worker_countObject (readonly)

An estimated upper bound of employees, contractors, vendors, etc. currently working for the business.



71
72
73
# File 'lib/stripe/resources/account.rb', line 71

def estimated_worker_count
  @estimated_worker_count
end

#mccObject (readonly)

[The merchant category code for the account](/connect/setting-mcc). MCCs are used to classify businesses based on the goods or services they provide.



73
74
75
# File 'lib/stripe/resources/account.rb', line 73

def mcc
  @mcc
end

#minority_owned_business_designationObject (readonly)

Whether the business is a minority-owned, women-owned, and/or LGBTQI+-owned business.



75
76
77
# File 'lib/stripe/resources/account.rb', line 75

def minority_owned_business_designation
  @minority_owned_business_designation
end

#monthly_estimated_revenueObject (readonly)

Attribute for field monthly_estimated_revenue



77
78
79
# File 'lib/stripe/resources/account.rb', line 77

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#nameObject (readonly)

The customer-facing business name.



79
80
81
# File 'lib/stripe/resources/account.rb', line 79

def name
  @name
end

#product_descriptionObject (readonly)

Internal-only description of the product sold or service provided by the business. It’s used by Stripe for risk and underwriting purposes.



81
82
83
# File 'lib/stripe/resources/account.rb', line 81

def product_description
  @product_description
end

#support_addressObject (readonly)

A publicly available mailing address for sending support issues to.



83
84
85
# File 'lib/stripe/resources/account.rb', line 83

def support_address
  @support_address
end

#support_emailObject (readonly)

A publicly available email address for sending support issues to.



85
86
87
# File 'lib/stripe/resources/account.rb', line 85

def support_email
  @support_email
end

#support_phoneObject (readonly)

A publicly available phone number to call with support issues.



87
88
89
# File 'lib/stripe/resources/account.rb', line 87

def support_phone
  @support_phone
end

#support_urlObject (readonly)

A publicly available website for handling support issues.



89
90
91
# File 'lib/stripe/resources/account.rb', line 89

def support_url
  @support_url
end

#urlObject (readonly)

The business’s publicly available website.



91
92
93
# File 'lib/stripe/resources/account.rb', line 91

def url
  @url
end