Class: Stripe::Account::BusinessProfile::MonthlyEstimatedRevenue
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Account::BusinessProfile::MonthlyEstimatedRevenue
- Defined in:
- lib/stripe/resources/account.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
A non-negative integer representing how much to charge in the [smallest currency unit](/currencies#zero-decimal).
-
#currency ⇒ Object
readonly
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
A non-negative integer representing how much to charge in the [smallest currency unit](/currencies#zero-decimal).
51 52 53 |
# File 'lib/stripe/resources/account.rb', line 51 def amount @amount end |
#currency ⇒ Object (readonly)
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
54 55 56 |
# File 'lib/stripe/resources/account.rb', line 54 def currency @currency end |