Class: Stripe::Account::Company::OwnershipDeclaration

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#dateObject (readonly)

The Unix timestamp marking when the beneficial owner attestation was made.



382
383
384
# File 'lib/stripe/resources/account.rb', line 382

def date
  @date
end

#ipObject (readonly)

The IP address from which the beneficial owner attestation was made.



384
385
386
# File 'lib/stripe/resources/account.rb', line 384

def ip
  @ip
end

#user_agentObject (readonly)

The user-agent string from the browser where the beneficial owner attestation was made.



386
387
388
# File 'lib/stripe/resources/account.rb', line 386

def user_agent
  @user_agent
end

Class Method Details

.field_remappingsObject



392
393
394
# File 'lib/stripe/resources/account.rb', line 392

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



388
389
390
# File 'lib/stripe/resources/account.rb', line 388

def self.inner_class_types
  @inner_class_types = {}
end