Class: Stripe::Account::Company::RepresentativeDeclaration

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#dateObject (readonly)

The Unix timestamp marking when the representative declaration attestation was made.



426
427
428
# File 'lib/stripe/resources/account.rb', line 426

def date
  @date
end

#ipObject (readonly)

The IP address from which the representative declaration attestation was made.



428
429
430
# File 'lib/stripe/resources/account.rb', line 428

def ip
  @ip
end

#user_agentObject (readonly)

The user-agent string from the browser where the representative declaration attestation was made.



430
431
432
# File 'lib/stripe/resources/account.rb', line 430

def user_agent
  @user_agent
end

Class Method Details

.field_remappingsObject



436
437
438
# File 'lib/stripe/resources/account.rb', line 436

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



432
433
434
# File 'lib/stripe/resources/account.rb', line 432

def self.inner_class_types
  @inner_class_types = {}
end