Class: Stripe::Account::Controller

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: Application, Dashboard, Fees, Losses, StripeDashboard

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#applicationObject (readonly)

Attribute for field application



660
661
662
# File 'lib/stripe/resources/account.rb', line 660

def application
  @application
end

#dashboardObject (readonly)

Attribute for field dashboard



662
663
664
# File 'lib/stripe/resources/account.rb', line 662

def dashboard
  @dashboard
end

#feesObject (readonly)

Attribute for field fees



664
665
666
# File 'lib/stripe/resources/account.rb', line 664

def fees
  @fees
end

#is_controllerObject (readonly)

true if the Connect application retrieving the resource controls the account and can therefore exercise platform controls. Otherwise, this field is null.



666
667
668
# File 'lib/stripe/resources/account.rb', line 666

def is_controller
  @is_controller
end

#lossesObject (readonly)

Attribute for field losses



668
669
670
# File 'lib/stripe/resources/account.rb', line 668

def losses
  @losses
end

#requirement_collectionObject (readonly)

A value indicating responsibility for collecting requirements on this account. Only returned when the Connect application retrieving the resource controls the account.



670
671
672
# File 'lib/stripe/resources/account.rb', line 670

def requirement_collection
  @requirement_collection
end

#stripe_dashboardObject (readonly)

Attribute for field stripe_dashboard



672
673
674
# File 'lib/stripe/resources/account.rb', line 672

def stripe_dashboard
  @stripe_dashboard
end

#typeObject (readonly)

The controller type. Can be application, if a Connect application controls the account, or account, if the account controls itself.



674
675
676
# File 'lib/stripe/resources/account.rb', line 674

def type
  @type
end

Class Method Details

.field_remappingsObject



686
687
688
# File 'lib/stripe/resources/account.rb', line 686

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



676
677
678
679
680
681
682
683
684
# File 'lib/stripe/resources/account.rb', line 676

def self.inner_class_types
  @inner_class_types = {
    application: Application,
    dashboard: Dashboard,
    fees: Fees,
    losses: Losses,
    stripe_dashboard: StripeDashboard,
  }
end