Class: Stripe::Account::CreateParams::BankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(object: nil, account_holder_name: nil, account_holder_type: nil, account_number: nil, country: nil, currency: nil, routing_number: nil) ⇒ BankAccount

Returns a new instance of BankAccount.



3446
3447
3448
3449
3450
3451
3452
3453
3454
3455
3456
3457
3458
3459
3460
3461
3462
# File 'lib/stripe/resources/account.rb', line 3446

def initialize(
  object: nil,
  account_holder_name: nil,
  account_holder_type: nil,
  account_number: nil,
  country: nil,
  currency: nil,
  routing_number: nil
)
  @object = object
  @account_holder_name = 
  @account_holder_type = 
  @account_number = 
  @country = country
  @currency = currency
  @routing_number = routing_number
end

Instance Attribute Details

#account_holder_nameObject

The name of the person or business that owns the bank account.This field is required when attaching the bank account to a ‘Customer` object.



3434
3435
3436
# File 'lib/stripe/resources/account.rb', line 3434

def 
  @account_holder_name
end

#account_holder_typeObject

The type of entity that holds the account. It can be ‘company` or `individual`. This field is required when attaching the bank account to a `Customer` object.



3436
3437
3438
# File 'lib/stripe/resources/account.rb', line 3436

def 
  @account_holder_type
end

#account_numberObject

The account number for the bank account, in string form. Must be a checking account.



3438
3439
3440
# File 'lib/stripe/resources/account.rb', line 3438

def 
  @account_number
end

#countryObject

The country in which the bank account is located.



3440
3441
3442
# File 'lib/stripe/resources/account.rb', line 3440

def country
  @country
end

#currencyObject

The currency the bank account is in. This must be a country/currency pairing that [Stripe supports.](docs/payouts)



3442
3443
3444
# File 'lib/stripe/resources/account.rb', line 3442

def currency
  @currency
end

#objectObject

Attribute for param field object



3432
3433
3434
# File 'lib/stripe/resources/account.rb', line 3432

def object
  @object
end

#routing_numberObject

The routing number, sort code, or other country-appropriate institution number for the bank account. For US bank accounts, this is required and should be the ACH routing number, not the wire routing number. If you are providing an IBAN for ‘account_number`, this field is not required.



3444
3445
3446
# File 'lib/stripe/resources/account.rb', line 3444

def routing_number
  @routing_number
end