Class: Stripe::Account::CreateParams::BusinessProfile

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: AnnualRevenue, MonthlyEstimatedRevenue, SupportAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(annual_revenue: nil, estimated_worker_count: nil, mcc: nil, minority_owned_business_designation: nil, monthly_estimated_revenue: nil, name: nil, product_description: nil, support_address: nil, support_email: nil, support_phone: nil, support_url: nil, url: nil) ⇒ BusinessProfile

Returns a new instance of BusinessProfile.



3548
3549
3550
3551
3552
3553
3554
3555
3556
3557
3558
3559
3560
3561
3562
3563
3564
3565
3566
3567
3568
3569
3570
3571
3572
3573
3574
# File 'lib/stripe/resources/account.rb', line 3548

def initialize(
  annual_revenue: nil,
  estimated_worker_count: nil,
  mcc: nil,
  minority_owned_business_designation: nil,
  monthly_estimated_revenue: nil,
  name: nil,
  product_description: nil,
  support_address: nil,
  support_email: nil,
  support_phone: nil,
  support_url: nil,
  url: nil
)
  @annual_revenue = annual_revenue
  @estimated_worker_count = estimated_worker_count
  @mcc = mcc
  @minority_owned_business_designation = minority_owned_business_designation
  @monthly_estimated_revenue = monthly_estimated_revenue
  @name = name
  @product_description = product_description
  @support_address = support_address
  @support_email = support_email
  @support_phone = support_phone
  @support_url = support_url
  @url = url
end

Instance Attribute Details

#annual_revenueObject

The applicant’s gross annual revenue for its preceding fiscal year.



3524
3525
3526
# File 'lib/stripe/resources/account.rb', line 3524

def annual_revenue
  @annual_revenue
end

#estimated_worker_countObject

An estimated upper bound of employees, contractors, vendors, etc. currently working for the business.



3526
3527
3528
# File 'lib/stripe/resources/account.rb', line 3526

def estimated_worker_count
  @estimated_worker_count
end

#mccObject

[The merchant category code for the account](/connect/setting-mcc). MCCs are used to classify businesses based on the goods or services they provide.



3528
3529
3530
# File 'lib/stripe/resources/account.rb', line 3528

def mcc
  @mcc
end

#minority_owned_business_designationObject

Whether the business is a minority-owned, women-owned, and/or LGBTQI+ -owned business.



3530
3531
3532
# File 'lib/stripe/resources/account.rb', line 3530

def minority_owned_business_designation
  @minority_owned_business_designation
end

#monthly_estimated_revenueObject

An estimate of the monthly revenue of the business. Only accepted for accounts in Brazil and India.



3532
3533
3534
# File 'lib/stripe/resources/account.rb', line 3532

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#nameObject

The customer-facing business name.



3534
3535
3536
# File 'lib/stripe/resources/account.rb', line 3534

def name
  @name
end

#product_descriptionObject

Internal-only description of the product sold by, or service provided by, the business. Used by Stripe for risk and underwriting purposes.



3536
3537
3538
# File 'lib/stripe/resources/account.rb', line 3536

def product_description
  @product_description
end

#support_addressObject

A publicly available mailing address for sending support issues to.



3538
3539
3540
# File 'lib/stripe/resources/account.rb', line 3538

def support_address
  @support_address
end

#support_emailObject

A publicly available email address for sending support issues to.



3540
3541
3542
# File 'lib/stripe/resources/account.rb', line 3540

def support_email
  @support_email
end

#support_phoneObject

A publicly available phone number to call with support issues.



3542
3543
3544
# File 'lib/stripe/resources/account.rb', line 3542

def support_phone
  @support_phone
end

#support_urlObject

A publicly available website for handling support issues.



3544
3545
3546
# File 'lib/stripe/resources/account.rb', line 3544

def support_url
  @support_url
end

#urlObject

The business’s publicly available website.



3546
3547
3548
# File 'lib/stripe/resources/account.rb', line 3546

def url
  @url
end