Class: Stripe::Account::CreateParams::BusinessProfile::AnnualRevenue
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::CreateParams::BusinessProfile::AnnualRevenue
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
A non-negative integer representing the amount in the [smallest currency unit](/currencies#zero-decimal).
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#fiscal_year_end ⇒ Object
The close-out date of the preceding fiscal year in ISO 8601 format.
Instance Method Summary collapse
-
#initialize(amount: nil, currency: nil, fiscal_year_end: nil) ⇒ AnnualRevenue
constructor
A new instance of AnnualRevenue.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, currency: nil, fiscal_year_end: nil) ⇒ AnnualRevenue
Returns a new instance of AnnualRevenue.
3290 3291 3292 3293 3294 |
# File 'lib/stripe/resources/account.rb', line 3290 def initialize(amount: nil, currency: nil, fiscal_year_end: nil) @amount = amount @currency = currency @fiscal_year_end = fiscal_year_end end |
Instance Attribute Details
#amount ⇒ Object
A non-negative integer representing the amount in the [smallest currency unit](/currencies#zero-decimal).
3282 3283 3284 |
# File 'lib/stripe/resources/account.rb', line 3282 def amount @amount end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
3285 3286 3287 |
# File 'lib/stripe/resources/account.rb', line 3285 def currency @currency end |
#fiscal_year_end ⇒ Object
The close-out date of the preceding fiscal year in ISO 8601 format. E.g. 2023-12-31 for the 31st of December, 2023.
3288 3289 3290 |
# File 'lib/stripe/resources/account.rb', line 3288 def fiscal_year_end @fiscal_year_end end |