Class: Stripe::Account::CreateParams::BusinessProfile::MonthlyEstimatedRevenue
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::CreateParams::BusinessProfile::MonthlyEstimatedRevenue
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
A non-negative integer representing how much to charge in the [smallest currency unit](/currencies#zero-decimal).
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
Instance Method Summary collapse
-
#initialize(amount: nil, currency: nil) ⇒ MonthlyEstimatedRevenue
constructor
A new instance of MonthlyEstimatedRevenue.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, currency: nil) ⇒ MonthlyEstimatedRevenue
Returns a new instance of MonthlyEstimatedRevenue.
2653 2654 2655 2656 |
# File 'lib/stripe/resources/account.rb', line 2653 def initialize(amount: nil, currency: nil) @amount = amount @currency = currency end |
Instance Attribute Details
#amount ⇒ Object
A non-negative integer representing how much to charge in the [smallest currency unit](/currencies#zero-decimal).
2649 2650 2651 |
# File 'lib/stripe/resources/account.rb', line 2649 def amount @amount end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
2651 2652 2653 |
# File 'lib/stripe/resources/account.rb', line 2651 def currency @currency end |