Class: Stripe::Account::CreateParams::Capabilities::BankTransferPayments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(requested: nil) ⇒ BankTransferPayments

Returns a new instance of BankTransferPayments.



3239
3240
3241
# File 'lib/stripe/resources/account.rb', line 3239

def initialize(requested: nil)
  @requested = requested
end

Instance Attribute Details

#requestedObject

Passing true requests the capability for the account, if it is not already requested. A requested capability may not immediately become active. Any requirements to activate the capability are returned in the ‘requirements` arrays.



3237
3238
3239
# File 'lib/stripe/resources/account.rb', line 3237

def requested
  @requested
end