Class: Stripe::Account::CreateParams::Capabilities::CardPayments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(requested: nil) ⇒ CardPayments

Returns a new instance of CardPayments.



2865
2866
2867
# File 'lib/stripe/resources/account.rb', line 2865

def initialize(requested: nil)
  @requested = requested
end

Instance Attribute Details

#requestedObject

Passing true requests the capability for the account, if it is not already requested. A requested capability may not immediately become active. Any requirements to activate the capability are returned in the ‘requirements` arrays.



2863
2864
2865
# File 'lib/stripe/resources/account.rb', line 2863

def requested
  @requested
end