Class: Stripe::Account::CreateParams::Capabilities::CashappPayments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(requested: nil) ⇒ CashappPayments

Returns a new instance of CashappPayments.



3213
3214
3215
# File 'lib/stripe/resources/account.rb', line 3213

def initialize(requested: nil)
  @requested = requested
end

Instance Attribute Details

#requestedObject

Passing true requests the capability for the account, if it is not already requested. A requested capability may not immediately become active. Any requirements to activate the capability are returned in the ‘requirements` arrays.



3211
3212
3213
# File 'lib/stripe/resources/account.rb', line 3211

def requested
  @requested
end