Class: Stripe::Account::CreateParams::Capabilities::FpxPayments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::CreateParams::Capabilities::FpxPayments
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#requested ⇒ Object
Passing true requests the capability for the account, if it is not already requested.
Instance Method Summary collapse
-
#initialize(requested: nil) ⇒ FpxPayments
constructor
A new instance of FpxPayments.
Methods inherited from RequestParams
Constructor Details
#initialize(requested: nil) ⇒ FpxPayments
Returns a new instance of FpxPayments.
3154 3155 3156 |
# File 'lib/stripe/resources/account.rb', line 3154 def initialize(requested: nil) @requested = requested end |
Instance Attribute Details
#requested ⇒ Object
Passing true requests the capability for the account, if it is not already requested. A requested capability may not immediately become active. Any requirements to activate the capability are returned in the ‘requirements` arrays.
3152 3153 3154 |
# File 'lib/stripe/resources/account.rb', line 3152 def requested @requested end |