Class: Stripe::Account::CreateParams::Capabilities::GiropayPayments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(requested: nil) ⇒ GiropayPayments

Returns a new instance of GiropayPayments.



3279
3280
3281
# File 'lib/stripe/resources/account.rb', line 3279

def initialize(requested: nil)
  @requested = requested
end

Instance Attribute Details

#requestedObject

Passing true requests the capability for the account, if it is not already requested. A requested capability may not immediately become active. Any requirements to activate the capability are returned in the ‘requirements` arrays.



3277
3278
3279
# File 'lib/stripe/resources/account.rb', line 3277

def requested
  @requested
end