Class: Stripe::Account::CreateParams::Capabilities::GopayPayments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::CreateParams::Capabilities::GopayPayments
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#requested ⇒ Object
Passing true requests the capability for the account, if it is not already requested.
Instance Method Summary collapse
-
#initialize(requested: nil) ⇒ GopayPayments
constructor
A new instance of GopayPayments.
Methods inherited from RequestParams
Constructor Details
#initialize(requested: nil) ⇒ GopayPayments
Returns a new instance of GopayPayments.
3183 3184 3185 |
# File 'lib/stripe/resources/account.rb', line 3183 def initialize(requested: nil) @requested = requested end |
Instance Attribute Details
#requested ⇒ Object
Passing true requests the capability for the account, if it is not already requested. A requested capability may not immediately become active. Any requirements to activate the capability are returned in the ‘requirements` arrays.
3181 3182 3183 |
# File 'lib/stripe/resources/account.rb', line 3181 def requested @requested end |