Class: Stripe::Account::CreateParams::Capabilities::IdBankTransferPaymentsBca

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(requested: nil) ⇒ IdBankTransferPaymentsBca

Returns a new instance of IdBankTransferPaymentsBca.



3208
3209
3210
# File 'lib/stripe/resources/account.rb', line 3208

def initialize(requested: nil)
  @requested = requested
end

Instance Attribute Details

#requestedObject

Passing true requests the capability for the account, if it is not already requested. A requested capability may not immediately become active. Any requirements to activate the capability are returned in the ‘requirements` arrays.



3206
3207
3208
# File 'lib/stripe/resources/account.rb', line 3206

def requested
  @requested
end