Class: Stripe::Account::CreateParams::Capabilities::IndiaInternationalPayments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::CreateParams::Capabilities::IndiaInternationalPayments
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#requested ⇒ Object
Passing true requests the capability for the account, if it is not already requested.
Instance Method Summary collapse
-
#initialize(requested: nil) ⇒ IndiaInternationalPayments
constructor
A new instance of IndiaInternationalPayments.
Methods inherited from RequestParams
Constructor Details
#initialize(requested: nil) ⇒ IndiaInternationalPayments
Returns a new instance of IndiaInternationalPayments.
3825 3826 3827 |
# File 'lib/stripe/resources/account.rb', line 3825 def initialize(requested: nil) @requested = requested end |
Instance Attribute Details
#requested ⇒ Object
Passing true requests the capability for the account, if it is not already requested. A requested capability may not immediately become active. Any requirements to activate the capability are returned in the ‘requirements` arrays.
3823 3824 3825 |
# File 'lib/stripe/resources/account.rb', line 3823 def requested @requested end |