Class: Stripe::Account::CreateParams::Capabilities::KlarnaPayments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(requested: nil) ⇒ KlarnaPayments

Returns a new instance of KlarnaPayments.



3050
3051
3052
# File 'lib/stripe/resources/account.rb', line 3050

def initialize(requested: nil)
  @requested = requested
end

Instance Attribute Details

#requestedObject

Passing true requests the capability for the account, if it is not already requested. A requested capability may not immediately become active. Any requirements to activate the capability are returned in the ‘requirements` arrays.



3048
3049
3050
# File 'lib/stripe/resources/account.rb', line 3048

def requested
  @requested
end