Class: Stripe::Account::CreateParams::Capabilities::KrCardPayments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(requested: nil) ⇒ KrCardPayments

Returns a new instance of KrCardPayments.



3068
3069
3070
# File 'lib/stripe/resources/account.rb', line 3068

def initialize(requested: nil)
  @requested = requested
end

Instance Attribute Details

#requestedObject

Passing true requests the capability for the account, if it is not already requested. A requested capability may not immediately become active. Any requirements to activate the capability are returned in the ‘requirements` arrays.



3066
3067
3068
# File 'lib/stripe/resources/account.rb', line 3066

def requested
  @requested
end