Class: Stripe::Account::CreateParams::Capabilities::LinkPayments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(requested: nil) ⇒ LinkPayments

Returns a new instance of LinkPayments.



3897
3898
3899
# File 'lib/stripe/resources/account.rb', line 3897

def initialize(requested: nil)
  @requested = requested
end

Instance Attribute Details

#requestedObject

Passing true requests the capability for the account, if it is not already requested. A requested capability may not immediately become active. Any requirements to activate the capability are returned in the ‘requirements` arrays.



3895
3896
3897
# File 'lib/stripe/resources/account.rb', line 3895

def requested
  @requested
end