Class: Stripe::Account::CreateParams::Capabilities::QrisPayments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(requested: nil) ⇒ QrisPayments

Returns a new instance of QrisPayments.



3563
3564
3565
# File 'lib/stripe/resources/account.rb', line 3563

def initialize(requested: nil)
  @requested = requested
end

Instance Attribute Details

#requestedObject

Passing true requests the capability for the account, if it is not already requested. A requested capability may not immediately become active. Any requirements to activate the capability are returned in the ‘requirements` arrays.



3561
3562
3563
# File 'lib/stripe/resources/account.rb', line 3561

def requested
  @requested
end