Class: Stripe::Account::CreateParams::Capabilities::RevolutPayPayments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::CreateParams::Capabilities::RevolutPayPayments
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#requested ⇒ Object
Passing true requests the capability for the account, if it is not already requested.
Instance Method Summary collapse
-
#initialize(requested: nil) ⇒ RevolutPayPayments
constructor
A new instance of RevolutPayPayments.
Methods inherited from RequestParams
Constructor Details
#initialize(requested: nil) ⇒ RevolutPayPayments
Returns a new instance of RevolutPayPayments.
3386 3387 3388 |
# File 'lib/stripe/resources/account.rb', line 3386 def initialize(requested: nil) @requested = requested end |
Instance Attribute Details
#requested ⇒ Object
Passing true requests the capability for the account, if it is not already requested. A requested capability may not immediately become active. Any requirements to activate the capability are returned in the ‘requirements` arrays.
3384 3385 3386 |
# File 'lib/stripe/resources/account.rb', line 3384 def requested @requested end |