Class: Stripe::Account::CreateParams::Capabilities::SamsungPayPayments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::CreateParams::Capabilities::SamsungPayPayments
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#requested ⇒ Object
Passing true requests the capability for the account, if it is not already requested.
Instance Method Summary collapse
-
#initialize(requested: nil) ⇒ SamsungPayPayments
constructor
A new instance of SamsungPayPayments.
Methods inherited from RequestParams
Constructor Details
#initialize(requested: nil) ⇒ SamsungPayPayments
Returns a new instance of SamsungPayPayments.
4068 4069 4070 |
# File 'lib/stripe/resources/account.rb', line 4068 def initialize(requested: nil) @requested = requested end |
Instance Attribute Details
#requested ⇒ Object
Passing true requests the capability for the account, if it is not already requested. A requested capability may not immediately become active. Any requirements to activate the capability are returned in the ‘requirements` arrays.
4066 4067 4068 |
# File 'lib/stripe/resources/account.rb', line 4066 def requested @requested end |