Class: Stripe::Account::CreateParams::Capabilities::UsBankTransferPayments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::CreateParams::Capabilities::UsBankTransferPayments
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#requested ⇒ Object
Passing true requests the capability for the account, if it is not already requested.
Instance Method Summary collapse
-
#initialize(requested: nil) ⇒ UsBankTransferPayments
constructor
A new instance of UsBankTransferPayments.
Methods inherited from RequestParams
Constructor Details
#initialize(requested: nil) ⇒ UsBankTransferPayments
Returns a new instance of UsBankTransferPayments.
3530 3531 3532 |
# File 'lib/stripe/resources/account.rb', line 3530 def initialize(requested: nil) @requested = requested end |
Instance Attribute Details
#requested ⇒ Object
Passing true requests the capability for the account, if it is not already requested. A requested capability may not immediately become active. Any requirements to activate the capability are returned in the ‘requirements` arrays.
3528 3529 3530 |
# File 'lib/stripe/resources/account.rb', line 3528 def requested @requested end |