Class: Stripe::Account::CreateParams::Company

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: Address, AddressKana, AddressKanji, DirectorshipDeclaration, OwnershipDeclaration, RegistrationDate, Verification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, address_kana: nil, address_kanji: nil, directors_provided: nil, directorship_declaration: nil, executives_provided: nil, export_license_id: nil, export_purpose_code: nil, name: nil, name_kana: nil, name_kanji: nil, owners_provided: nil, ownership_declaration: nil, ownership_exemption_reason: nil, phone: nil, registration_date: nil, registration_number: nil, structure: nil, tax_id: nil, tax_id_registrar: nil, vat_id: nil, verification: nil) ⇒ Company

Returns a new instance of Company.



4825
4826
4827
4828
4829
4830
4831
4832
4833
4834
4835
4836
4837
4838
4839
4840
4841
4842
4843
4844
4845
4846
4847
4848
4849
4850
4851
4852
4853
4854
4855
4856
4857
4858
4859
4860
4861
4862
4863
4864
4865
4866
4867
4868
4869
4870
4871
# File 'lib/stripe/resources/account.rb', line 4825

def initialize(
  address: nil,
  address_kana: nil,
  address_kanji: nil,
  directors_provided: nil,
  directorship_declaration: nil,
  executives_provided: nil,
  export_license_id: nil,
  export_purpose_code: nil,
  name: nil,
  name_kana: nil,
  name_kanji: nil,
  owners_provided: nil,
  ownership_declaration: nil,
  ownership_exemption_reason: nil,
  phone: nil,
  registration_date: nil,
  registration_number: nil,
  structure: nil,
  tax_id: nil,
  tax_id_registrar: nil,
  vat_id: nil,
  verification: nil
)
  @address = address
  @address_kana = address_kana
  @address_kanji = address_kanji
  @directors_provided = directors_provided
  @directorship_declaration = directorship_declaration
  @executives_provided = executives_provided
  @export_license_id = export_license_id
  @export_purpose_code = export_purpose_code
  @name = name
  @name_kana = name_kana
  @name_kanji = name_kanji
  @owners_provided = owners_provided
  @ownership_declaration = ownership_declaration
  @ownership_exemption_reason = ownership_exemption_reason
  @phone = phone
  @registration_date = registration_date
  @registration_number = registration_number
  @structure = structure
  @tax_id = tax_id
  @tax_id_registrar = tax_id_registrar
  @vat_id = vat_id
  @verification = verification
end

Instance Attribute Details

#addressObject

The company’s primary address.



4781
4782
4783
# File 'lib/stripe/resources/account.rb', line 4781

def address
  @address
end

#address_kanaObject

The Kana variation of the company’s primary address (Japan only).



4783
4784
4785
# File 'lib/stripe/resources/account.rb', line 4783

def address_kana
  @address_kana
end

#address_kanjiObject

The Kanji variation of the company’s primary address (Japan only).



4785
4786
4787
# File 'lib/stripe/resources/account.rb', line 4785

def address_kanji
  @address_kanji
end

#directors_providedObject

Whether the company’s directors have been provided. Set this Boolean to ‘true` after creating all the company’s directors with [the Persons API](/api/persons) for accounts with a ‘relationship.director` requirement. This value is not automatically set to `true` after creating directors, so it needs to be updated to indicate all directors have been provided.



4787
4788
4789
# File 'lib/stripe/resources/account.rb', line 4787

def directors_provided
  @directors_provided
end

#directorship_declarationObject

This hash is used to attest that the directors information provided to Stripe is both current and correct.



4789
4790
4791
# File 'lib/stripe/resources/account.rb', line 4789

def directorship_declaration
  @directorship_declaration
end

#executives_providedObject

Whether the company’s executives have been provided. Set this Boolean to ‘true` after creating all the company’s executives with [the Persons API](/api/persons) for accounts with a ‘relationship.executive` requirement.



4791
4792
4793
# File 'lib/stripe/resources/account.rb', line 4791

def executives_provided
  @executives_provided
end

#export_license_idObject

The export license ID number of the company, also referred as Import Export Code (India only).



4793
4794
4795
# File 'lib/stripe/resources/account.rb', line 4793

def export_license_id
  @export_license_id
end

#export_purpose_codeObject

The purpose code to use for export transactions (India only).



4795
4796
4797
# File 'lib/stripe/resources/account.rb', line 4795

def export_purpose_code
  @export_purpose_code
end

#nameObject

The company’s legal name.



4797
4798
4799
# File 'lib/stripe/resources/account.rb', line 4797

def name
  @name
end

#name_kanaObject

The Kana variation of the company’s legal name (Japan only).



4799
4800
4801
# File 'lib/stripe/resources/account.rb', line 4799

def name_kana
  @name_kana
end

#name_kanjiObject

The Kanji variation of the company’s legal name (Japan only).



4801
4802
4803
# File 'lib/stripe/resources/account.rb', line 4801

def name_kanji
  @name_kanji
end

#owners_providedObject

Whether the company’s owners have been provided. Set this Boolean to ‘true` after creating all the company’s owners with [the Persons API](/api/persons) for accounts with a ‘relationship.owner` requirement.



4803
4804
4805
# File 'lib/stripe/resources/account.rb', line 4803

def owners_provided
  @owners_provided
end

#ownership_declarationObject

This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.



4805
4806
4807
# File 'lib/stripe/resources/account.rb', line 4805

def ownership_declaration
  @ownership_declaration
end

#ownership_exemption_reasonObject

This value is used to determine if a business is exempt from providing ultimate beneficial owners. See [this support article](support.stripe.com/questions/exemption-from-providing-ownership-details) and [changelog](docs.stripe.com/changelog/acacia/2025-01-27/ownership-exemption-reason-accounts-api) for more details.



4807
4808
4809
# File 'lib/stripe/resources/account.rb', line 4807

def ownership_exemption_reason
  @ownership_exemption_reason
end

#phoneObject

The company’s phone number (used for verification).



4809
4810
4811
# File 'lib/stripe/resources/account.rb', line 4809

def phone
  @phone
end

#registration_dateObject

When the business was incorporated or registered.



4811
4812
4813
# File 'lib/stripe/resources/account.rb', line 4811

def registration_date
  @registration_date
end

#registration_numberObject

The identification number given to a company when it is registered or incorporated, if distinct from the identification number used for filing taxes. (Examples are the CIN for companies and LLP IN for partnerships in India, and the Company Registration Number in Hong Kong).



4813
4814
4815
# File 'lib/stripe/resources/account.rb', line 4813

def registration_number
  @registration_number
end

#structureObject

The category identifying the legal structure of the company or legal entity. See [Business structure](/connect/identity-verification#business-structure) for more details. Pass an empty string to unset this value.



4815
4816
4817
# File 'lib/stripe/resources/account.rb', line 4815

def structure
  @structure
end

#tax_idObject

The business ID number of the company, as appropriate for the company’s country. (Examples are an Employer ID Number in the U.S., a Business Number in Canada, or a Company Number in the UK.)



4817
4818
4819
# File 'lib/stripe/resources/account.rb', line 4817

def tax_id
  @tax_id
end

#tax_id_registrarObject

The jurisdiction in which the ‘tax_id` is registered (Germany-based companies only).



4819
4820
4821
# File 'lib/stripe/resources/account.rb', line 4819

def tax_id_registrar
  @tax_id_registrar
end

#vat_idObject

The VAT number of the company.



4821
4822
4823
# File 'lib/stripe/resources/account.rb', line 4821

def vat_id
  @vat_id
end

#verificationObject

Information on the verification state of the company.



4823
4824
4825
# File 'lib/stripe/resources/account.rb', line 4823

def verification
  @verification
end