Class: Stripe::Account::CreateParams::Company::DirectorshipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ DirectorshipDeclaration

Returns a new instance of DirectorshipDeclaration.



4724
4725
4726
4727
4728
# File 'lib/stripe/resources/account.rb', line 4724

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the directorship declaration attestation was made.



4718
4719
4720
# File 'lib/stripe/resources/account.rb', line 4718

def date
  @date
end

#ipObject

The IP address from which the directorship declaration attestation was made.



4720
4721
4722
# File 'lib/stripe/resources/account.rb', line 4720

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the directorship declaration attestation was made.



4722
4723
4724
# File 'lib/stripe/resources/account.rb', line 4722

def user_agent
  @user_agent
end