Class: Stripe::Account::CreateParams::Company::OwnershipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ OwnershipDeclaration

Returns a new instance of OwnershipDeclaration.



4739
4740
4741
4742
4743
# File 'lib/stripe/resources/account.rb', line 4739

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the beneficial owner attestation was made.



4733
4734
4735
# File 'lib/stripe/resources/account.rb', line 4733

def date
  @date
end

#ipObject

The IP address from which the beneficial owner attestation was made.



4735
4736
4737
# File 'lib/stripe/resources/account.rb', line 4735

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the beneficial owner attestation was made.



4737
4738
4739
# File 'lib/stripe/resources/account.rb', line 4737

def user_agent
  @user_agent
end