Class: Stripe::Account::CreateParams::Company::Verification::Document
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::CreateParams::Company::Verification::Document
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#back ⇒ Object
The back of a document returned by a [file upload](stripe.com/docs/api#create_file) with a ‘purpose` value of `additional_verification`.
-
#front ⇒ Object
The front of a document returned by a [file upload](stripe.com/docs/api#create_file) with a ‘purpose` value of `additional_verification`.
Instance Method Summary collapse
-
#initialize(back: nil, front: nil) ⇒ Document
constructor
A new instance of Document.
Methods inherited from RequestParams
Constructor Details
#initialize(back: nil, front: nil) ⇒ Document
Returns a new instance of Document.
4259 4260 4261 4262 |
# File 'lib/stripe/resources/account.rb', line 4259 def initialize(back: nil, front: nil) @back = back @front = front end |
Instance Attribute Details
#back ⇒ Object
The back of a document returned by a [file upload](stripe.com/docs/api#create_file) with a ‘purpose` value of `additional_verification`. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.
4255 4256 4257 |
# File 'lib/stripe/resources/account.rb', line 4255 def back @back end |
#front ⇒ Object
The front of a document returned by a [file upload](stripe.com/docs/api#create_file) with a ‘purpose` value of `additional_verification`. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.
4257 4258 4259 |
# File 'lib/stripe/resources/account.rb', line 4257 def front @front end |