Class: Stripe::Account::CreateParams::Controller

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: Application, Dashboard, Fees, Losses, StripeDashboard

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(application: nil, dashboard: nil, fees: nil, losses: nil, requirement_collection: nil, stripe_dashboard: nil) ⇒ Controller

Returns a new instance of Controller.



4938
4939
4940
4941
4942
4943
4944
4945
4946
4947
4948
4949
4950
4951
4952
# File 'lib/stripe/resources/account.rb', line 4938

def initialize(
  application: nil,
  dashboard: nil,
  fees: nil,
  losses: nil,
  requirement_collection: nil,
  stripe_dashboard: nil
)
  @application = application
  @dashboard = dashboard
  @fees = fees
  @losses = losses
  @requirement_collection = requirement_collection
  @stripe_dashboard = stripe_dashboard
end

Instance Attribute Details

#applicationObject

A hash of configuration describing the Connect application that controls the account.



4926
4927
4928
# File 'lib/stripe/resources/account.rb', line 4926

def application
  @application
end

#dashboardObject

Properties of the account’s dashboard.



4928
4929
4930
# File 'lib/stripe/resources/account.rb', line 4928

def dashboard
  @dashboard
end

#feesObject

A hash of configuration for who pays Stripe fees for product usage on this account.



4930
4931
4932
# File 'lib/stripe/resources/account.rb', line 4930

def fees
  @fees
end

#lossesObject

A hash of configuration for products that have negative balance liability, and whether Stripe or a Connect application is responsible for them.



4932
4933
4934
# File 'lib/stripe/resources/account.rb', line 4932

def losses
  @losses
end

#requirement_collectionObject

A value indicating responsibility for collecting updated information when requirements on the account are due or change. Defaults to ‘stripe`.



4934
4935
4936
# File 'lib/stripe/resources/account.rb', line 4934

def requirement_collection
  @requirement_collection
end

#stripe_dashboardObject

A hash of configuration for Stripe-hosted dashboards.



4936
4937
4938
# File 'lib/stripe/resources/account.rb', line 4936

def stripe_dashboard
  @stripe_dashboard
end