Class: Stripe::Account::CreateParams::Controller::Dashboard
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::CreateParams::Controller::Dashboard
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#type ⇒ Object
Whether this account should have access to the full Stripe Dashboard (‘full`), to the Express Dashboard (`express`), or to no Stripe-hosted dashboard (`none`).
Instance Method Summary collapse
-
#initialize(type: nil) ⇒ Dashboard
constructor
A new instance of Dashboard.
Methods inherited from RequestParams
Constructor Details
#initialize(type: nil) ⇒ Dashboard
Returns a new instance of Dashboard.
4218 4219 4220 |
# File 'lib/stripe/resources/account.rb', line 4218 def initialize(type: nil) @type = type end |
Instance Attribute Details
#type ⇒ Object
Whether this account should have access to the full Stripe Dashboard (‘full`), to the Express Dashboard (`express`), or to no Stripe-hosted dashboard (`none`). Defaults to `full`.
4216 4217 4218 |
# File 'lib/stripe/resources/account.rb', line 4216 def type @type end |