Class: Stripe::Account::CreateParams::Controller::StripeDashboard
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::CreateParams::Controller::StripeDashboard
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#type ⇒ Object
Whether this account should have access to the full Stripe Dashboard (‘full`), to the Express Dashboard (`express`), or to no Stripe-hosted dashboard (`none`).
Instance Method Summary collapse
-
#initialize(type: nil) ⇒ StripeDashboard
constructor
A new instance of StripeDashboard.
Methods inherited from RequestParams
Constructor Details
#initialize(type: nil) ⇒ StripeDashboard
Returns a new instance of StripeDashboard.
3855 3856 3857 |
# File 'lib/stripe/resources/account.rb', line 3855 def initialize(type: nil) @type = type end |
Instance Attribute Details
#type ⇒ Object
Whether this account should have access to the full Stripe Dashboard (‘full`), to the Express Dashboard (`express`), or to no Stripe-hosted dashboard (`none`). Defaults to `full`.
3853 3854 3855 |
# File 'lib/stripe/resources/account.rb', line 3853 def type @type end |