Class: Stripe::Account::CreateParams::Documents::ProofOfUltimateBeneficialOwnership
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::CreateParams::Documents::ProofOfUltimateBeneficialOwnership
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#files ⇒ Object
One or more document ids returned by a [file upload](stripe.com/docs/api#create_file) with a ‘purpose` value of `account_requirement`.
Instance Method Summary collapse
-
#initialize(files: nil) ⇒ ProofOfUltimateBeneficialOwnership
constructor
A new instance of ProofOfUltimateBeneficialOwnership.
Methods inherited from RequestParams
Constructor Details
#initialize(files: nil) ⇒ ProofOfUltimateBeneficialOwnership
Returns a new instance of ProofOfUltimateBeneficialOwnership.
4608 4609 4610 |
# File 'lib/stripe/resources/account.rb', line 4608 def initialize(files: nil) @files = files end |
Instance Attribute Details
#files ⇒ Object
One or more document ids returned by a [file upload](stripe.com/docs/api#create_file) with a ‘purpose` value of `account_requirement`.
4606 4607 4608 |
# File 'lib/stripe/resources/account.rb', line 4606 def files @files end |