Class: Stripe::Account::CreateParams::Groups

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(payments_pricing: nil) ⇒ Groups

Returns a new instance of Groups.



4088
4089
4090
# File 'lib/stripe/resources/account.rb', line 4088

def initialize(payments_pricing: nil)
  @payments_pricing = payments_pricing
end

Instance Attribute Details

#payments_pricingObject

The group the account is in to determine their payments pricing, and null if the account is on customized pricing. [See the Platform pricing tool documentation](stripe.com/docs/connect/platform-pricing-tools) for details.



4086
4087
4088
# File 'lib/stripe/resources/account.rb', line 4086

def payments_pricing
  @payments_pricing
end