Class: Stripe::Account::CreateParams::Individual::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship

Returns a new instance of Relationship.



5247
5248
5249
5250
5251
5252
5253
5254
5255
5256
5257
5258
5259
# File 'lib/stripe/resources/account.rb', line 5247

def initialize(
  director: nil,
  executive: nil,
  owner: nil,
  percent_ownership: nil,
  title: nil
)
  @director = director
  @executive = executive
  @owner = owner
  @percent_ownership = percent_ownership
  @title = title
end

Instance Attribute Details

#directorObject

Whether the person is a director of the account’s legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



5237
5238
5239
# File 'lib/stripe/resources/account.rb', line 5237

def director
  @director
end

#executiveObject

Whether the person has significant responsibility to control, manage, or direct the organization.



5239
5240
5241
# File 'lib/stripe/resources/account.rb', line 5239

def executive
  @executive
end

#ownerObject

Whether the person is an owner of the account’s legal entity.



5241
5242
5243
# File 'lib/stripe/resources/account.rb', line 5241

def owner
  @owner
end

#percent_ownershipObject

The percent owned by the person of the account’s legal entity.



5243
5244
5245
# File 'lib/stripe/resources/account.rb', line 5243

def percent_ownership
  @percent_ownership
end

#titleObject

The person’s title (e.g., CEO, Support Engineer).



5245
5246
5247
# File 'lib/stripe/resources/account.rb', line 5245

def title
  @title
end