Class: Stripe::Account::CreateParams::Individual::Verification::AdditionalDocument

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(back: nil, front: nil) ⇒ AdditionalDocument

Returns a new instance of AdditionalDocument.



5269
5270
5271
5272
# File 'lib/stripe/resources/account.rb', line 5269

def initialize(back: nil, front: nil)
  @back = back
  @front = front
end

Instance Attribute Details

#backObject

The back of an ID returned by a [file upload](stripe.com/docs/api#create_file) with a ‘purpose` value of `identity_document`. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.



5265
5266
5267
# File 'lib/stripe/resources/account.rb', line 5265

def back
  @back
end

#frontObject

The front of an ID returned by a [file upload](stripe.com/docs/api#create_file) with a ‘purpose` value of `identity_document`. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.



5267
5268
5269
# File 'lib/stripe/resources/account.rb', line 5267

def front
  @front
end