Class: Stripe::Account::CreateParams::Settings::CardIssuing::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



5486
5487
5488
5489
5490
# File 'lib/stripe/resources/account.rb', line 5486

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



5480
5481
5482
# File 'lib/stripe/resources/account.rb', line 5480

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



5482
5483
5484
# File 'lib/stripe/resources/account.rb', line 5482

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



5484
5485
5486
# File 'lib/stripe/resources/account.rb', line 5484

def user_agent
  @user_agent
end