Class: Stripe::Account::CreateParams::Settings::Invoices
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::CreateParams::Settings::Invoices
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#hosted_payment_method_save ⇒ Object
Whether payment methods should be saved when a payment is completed for a one-time invoices on a hosted invoice page.
Instance Method Summary collapse
-
#initialize(hosted_payment_method_save: nil) ⇒ Invoices
constructor
A new instance of Invoices.
Methods inherited from RequestParams
Constructor Details
#initialize(hosted_payment_method_save: nil) ⇒ Invoices
Returns a new instance of Invoices.
5016 5017 5018 |
# File 'lib/stripe/resources/account.rb', line 5016 def initialize(hosted_payment_method_save: nil) @hosted_payment_method_save = hosted_payment_method_save end |
Instance Attribute Details
#hosted_payment_method_save ⇒ Object
Whether payment methods should be saved when a payment is completed for a one-time invoices on a hosted invoice page.
5014 5015 5016 |
# File 'lib/stripe/resources/account.rb', line 5014 def hosted_payment_method_save @hosted_payment_method_save end |