Class: Stripe::Account::CreateParams::Settings::Payouts

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: Schedule

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(debit_negative_balances: nil, schedule: nil, statement_descriptor: nil) ⇒ Payouts

Returns a new instance of Payouts.



5176
5177
5178
5179
5180
# File 'lib/stripe/resources/account.rb', line 5176

def initialize(debit_negative_balances: nil, schedule: nil, statement_descriptor: nil)
  @debit_negative_balances = debit_negative_balances
  @schedule = schedule
  @statement_descriptor = statement_descriptor
end

Instance Attribute Details

#debit_negative_balancesObject

A Boolean indicating whether Stripe should try to reclaim negative balances from an attached bank account. For details, see [Understanding Connect Account Balances](/connect/account-balances).



5170
5171
5172
# File 'lib/stripe/resources/account.rb', line 5170

def debit_negative_balances
  @debit_negative_balances
end

#scheduleObject

Details on when funds from charges are available, and when they are paid out to an external account. For details, see our [Setting Bank and Debit Card Payouts](/connect/bank-transfers#payout-information) documentation.



5172
5173
5174
# File 'lib/stripe/resources/account.rb', line 5172

def schedule
  @schedule
end

#statement_descriptorObject

The text that appears on the bank account statement for payouts. If not set, this defaults to the platform’s bank descriptor as set in the Dashboard.



5174
5175
5176
# File 'lib/stripe/resources/account.rb', line 5174

def statement_descriptor
  @statement_descriptor
end