Class: Stripe::Account::CreateParams::TosAcceptance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::CreateParams::TosAcceptance
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the account representative accepted their service agreement.
-
#ip ⇒ Object
The IP address from which the account representative accepted their service agreement.
-
#service_agreement ⇒ Object
The user’s service agreement type.
-
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted their service agreement.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance
constructor
A new instance of TosAcceptance.
Methods inherited from RequestParams
Constructor Details
#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance
Returns a new instance of TosAcceptance.
4628 4629 4630 4631 4632 4633 |
# File 'lib/stripe/resources/account.rb', line 4628 def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) @date = date @ip = ip @service_agreement = service_agreement @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the account representative accepted their service agreement.
4620 4621 4622 |
# File 'lib/stripe/resources/account.rb', line 4620 def date @date end |
#ip ⇒ Object
The IP address from which the account representative accepted their service agreement.
4622 4623 4624 |
# File 'lib/stripe/resources/account.rb', line 4622 def ip @ip end |
#service_agreement ⇒ Object
The user’s service agreement type.
4624 4625 4626 |
# File 'lib/stripe/resources/account.rb', line 4624 def service_agreement @service_agreement end |
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted their service agreement.
4626 4627 4628 |
# File 'lib/stripe/resources/account.rb', line 4626 def user_agent @user_agent end |