Class: Stripe::Account::FutureRequirements
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Account::FutureRequirements
- Defined in:
- lib/stripe/resources/account.rb
Defined Under Namespace
Classes: Alternative, Error
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#alternatives ⇒ Object
readonly
Fields that are due and can be resolved by providing the corresponding alternative fields instead.
-
#current_deadline ⇒ Object
readonly
Date on which
future_requirementsbecomes the mainrequirementshash andfuture_requirementsbecomes empty. -
#currently_due ⇒ Object
readonly
Fields that need to be resolved to keep the account enabled.
-
#disabled_reason ⇒ Object
readonly
This is typed as an enum for consistency with
requirements.disabled_reason. -
#errors ⇒ Object
readonly
Fields that are
currently_dueand need to be collected again because validation or verification failed. -
#eventually_due ⇒ Object
readonly
Fields you must collect when all thresholds are reached.
-
#past_due ⇒ Object
readonly
Fields that haven't been resolved by
requirements.current_deadline. -
#pending_verification ⇒ Object
readonly
Fields that are being reviewed, or might become required depending on the results of a review.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#alternatives ⇒ Object (readonly)
Fields that are due and can be resolved by providing the corresponding alternative fields instead. Many alternatives can list the same original_fields_due, and any of these alternatives can serve as a pathway for attempting to resolve the fields again. Re-providing original_fields_due also serves as a pathway for attempting to resolve the fields again.
656 657 658 |
# File 'lib/stripe/resources/account.rb', line 656 def alternatives @alternatives end |
#current_deadline ⇒ Object (readonly)
Date on which future_requirements becomes the main requirements hash and future_requirements becomes empty. After the transition, currently_due requirements may immediately become past_due, but the account may also be given a grace period depending on its enablement state prior to transitioning.
658 659 660 |
# File 'lib/stripe/resources/account.rb', line 658 def current_deadline @current_deadline end |
#currently_due ⇒ Object (readonly)
Fields that need to be resolved to keep the account enabled. If not resolved by future_requirements[current_deadline], these fields will transition to the main requirements hash.
660 661 662 |
# File 'lib/stripe/resources/account.rb', line 660 def currently_due @currently_due end |
#disabled_reason ⇒ Object (readonly)
This is typed as an enum for consistency with requirements.disabled_reason.
662 663 664 |
# File 'lib/stripe/resources/account.rb', line 662 def disabled_reason @disabled_reason end |
#errors ⇒ Object (readonly)
Fields that are currently_due and need to be collected again because validation or verification failed.
664 665 666 |
# File 'lib/stripe/resources/account.rb', line 664 def errors @errors end |
#eventually_due ⇒ Object (readonly)
Fields you must collect when all thresholds are reached. As they become required, they appear in currently_due as well.
666 667 668 |
# File 'lib/stripe/resources/account.rb', line 666 def eventually_due @eventually_due end |
#past_due ⇒ Object (readonly)
Fields that haven't been resolved by requirements.current_deadline. These fields need to be resolved to enable the capability on the account. future_requirements.past_due is a subset of requirements.past_due.
668 669 670 |
# File 'lib/stripe/resources/account.rb', line 668 def past_due @past_due end |
#pending_verification ⇒ Object (readonly)
Fields that are being reviewed, or might become required depending on the results of a review. If the review fails, these fields can move to eventually_due, currently_due, past_due or alternatives. Fields might appear in eventually_due, currently_due, past_due or alternatives and in pending_verification if one verification fails but another is still pending.
670 671 672 |
# File 'lib/stripe/resources/account.rb', line 670 def pending_verification @pending_verification end |
Class Method Details
.field_remappings ⇒ Object
676 677 678 |
# File 'lib/stripe/resources/account.rb', line 676 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
672 673 674 |
# File 'lib/stripe/resources/account.rb', line 672 def self.inner_class_types @inner_class_types = { alternatives: Alternative, errors: Error } end |