Class: Stripe::Account::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



2586
2587
2588
2589
2590
2591
2592
# File 'lib/stripe/resources/account.rb', line 2586

def initialize(created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil)
  @created = created
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
end

Instance Attribute Details

#createdObject

Only return connected accounts that were created during the given date interval.



2576
2577
2578
# File 'lib/stripe/resources/account.rb', line 2576

def created
  @created
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



2578
2579
2580
# File 'lib/stripe/resources/account.rb', line 2578

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



2580
2581
2582
# File 'lib/stripe/resources/account.rb', line 2580

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



2582
2583
2584
# File 'lib/stripe/resources/account.rb', line 2582

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



2584
2585
2586
# File 'lib/stripe/resources/account.rb', line 2584

def starting_after
  @starting_after
end