Class: Stripe::Account::PersonsParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: Relationship

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(ending_before: nil, expand: nil, limit: nil, relationship: nil, starting_after: nil) ⇒ PersonsParams

Returns a new instance of PersonsParams.



5836
5837
5838
5839
5840
5841
5842
5843
5844
5845
5846
5847
5848
# File 'lib/stripe/resources/account.rb', line 5836

def initialize(
  ending_before: nil,
  expand: nil,
  limit: nil,
  relationship: nil,
  starting_after: nil
)
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @relationship = relationship
  @starting_after = starting_after
end

Instance Attribute Details

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



5826
5827
5828
# File 'lib/stripe/resources/account.rb', line 5826

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



5828
5829
5830
# File 'lib/stripe/resources/account.rb', line 5828

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



5830
5831
5832
# File 'lib/stripe/resources/account.rb', line 5830

def limit
  @limit
end

#relationshipObject

Filters on the list of people returned based on the person’s relationship to the account’s company.



5832
5833
5834
# File 'lib/stripe/resources/account.rb', line 5832

def relationship
  @relationship
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



5834
5835
5836
# File 'lib/stripe/resources/account.rb', line 5834

def starting_after
  @starting_after
end