Class: Stripe::Account::PersonsParams::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(authorizer: nil, director: nil, executive: nil, legal_guardian: nil, owner: nil, representative: nil) ⇒ Relationship

Returns a new instance of Relationship.



5809
5810
5811
5812
5813
5814
5815
5816
5817
5818
5819
5820
5821
5822
5823
# File 'lib/stripe/resources/account.rb', line 5809

def initialize(
  authorizer: nil,
  director: nil,
  executive: nil,
  legal_guardian: nil,
  owner: nil,
  representative: nil
)
  @authorizer = authorizer
  @director = director
  @executive = executive
  @legal_guardian = legal_guardian
  @owner = owner
  @representative = representative
end

Instance Attribute Details

#authorizerObject

A filter on the list of people returned based on whether these people are authorizers of the account’s representative.



5797
5798
5799
# File 'lib/stripe/resources/account.rb', line 5797

def authorizer
  @authorizer
end

#directorObject

A filter on the list of people returned based on whether these people are directors of the account’s company.



5799
5800
5801
# File 'lib/stripe/resources/account.rb', line 5799

def director
  @director
end

#executiveObject

A filter on the list of people returned based on whether these people are executives of the account’s company.



5801
5802
5803
# File 'lib/stripe/resources/account.rb', line 5801

def executive
  @executive
end

A filter on the list of people returned based on whether these people are legal guardians of the account’s representative.



5803
5804
5805
# File 'lib/stripe/resources/account.rb', line 5803

def legal_guardian
  @legal_guardian
end

#ownerObject

A filter on the list of people returned based on whether these people are owners of the account’s company.



5805
5806
5807
# File 'lib/stripe/resources/account.rb', line 5805

def owner
  @owner
end

#representativeObject

A filter on the list of people returned based on whether these people are the representative of the account’s company.



5807
5808
5809
# File 'lib/stripe/resources/account.rb', line 5807

def representative
  @representative
end