Class: Stripe::Account::RejectParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::RejectParams
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#reason ⇒ Object
The reason for rejecting the account.
Instance Method Summary collapse
-
#initialize(expand: nil, reason: nil) ⇒ RejectParams
constructor
A new instance of RejectParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, reason: nil) ⇒ RejectParams
Returns a new instance of RejectParams.
5048 5049 5050 5051 |
# File 'lib/stripe/resources/account.rb', line 5048 def initialize(expand: nil, reason: nil) @expand = @reason = reason end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
5044 5045 5046 |
# File 'lib/stripe/resources/account.rb', line 5044 def @expand end |
#reason ⇒ Object
The reason for rejecting the account. Can be ‘fraud`, `terms_of_service`, or `other`.
5046 5047 5048 |
# File 'lib/stripe/resources/account.rb', line 5046 def reason @reason end |