Class: Stripe::Account::Requirements

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: Alternative, Error

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#alternatives ⇒ Object (readonly)

Fields that are due and can be resolved by providing the corresponding alternative fields instead. Many alternatives can list the same original_fields_due, and any of these alternatives can serve as a pathway for attempting to resolve the fields again. Re-providing original_fields_due also serves as a pathway for attempting to resolve the fields again.



735
736
737
# File 'lib/stripe/resources/account.rb', line 735

def alternatives
  @alternatives
end

#current_deadline ⇒ Object (readonly)

Date by which the fields in currently_due must be collected to keep the account enabled. These fields may disable the account sooner if the next threshold is reached before they are collected.



737
738
739
# File 'lib/stripe/resources/account.rb', line 737

def current_deadline
  @current_deadline
end

#currently_due ⇒ Object (readonly)

Fields that need to be resolved to keep the account enabled. If not resolved by current_deadline, these fields will appear in past_due as well, and the account will be disabled.



739
740
741
# File 'lib/stripe/resources/account.rb', line 739

def currently_due
  @currently_due
end

#disabled_reason ⇒ Object (readonly)

If the account is disabled, this enum describes why. Learn more about handling verification issues.



741
742
743
# File 'lib/stripe/resources/account.rb', line 741

def disabled_reason
  @disabled_reason
end

#errors ⇒ Object (readonly)

Fields that are currently_due and need to be collected again because validation or verification failed.



743
744
745
# File 'lib/stripe/resources/account.rb', line 743

def errors
  @errors
end

#eventually_due ⇒ Object (readonly)

Fields you must collect when all thresholds are reached. As they become required, they appear in currently_due as well, and current_deadline becomes set.



745
746
747
# File 'lib/stripe/resources/account.rb', line 745

def eventually_due
  @eventually_due
end

#past_due ⇒ Object (readonly)

Fields that haven't been resolved by current_deadline. These fields need to be resolved to enable the account.



747
748
749
# File 'lib/stripe/resources/account.rb', line 747

def past_due
  @past_due
end

#pending_verification ⇒ Object (readonly)

Fields that are being reviewed, or might become required depending on the results of a review. If the review fails, these fields can move to eventually_due, currently_due, past_due or alternatives. Fields might appear in eventually_due, currently_due, past_due or alternatives and in pending_verification if one verification fails but another is still pending.



749
750
751
# File 'lib/stripe/resources/account.rb', line 749

def pending_verification
  @pending_verification
end

Class Method Details

.field_remappings ⇒ Object



755
756
757
# File 'lib/stripe/resources/account.rb', line 755

def self.field_remappings
  @field_remappings = {}
end

.inner_class_types ⇒ Object



751
752
753
# File 'lib/stripe/resources/account.rb', line 751

def self.inner_class_types
  @inner_class_types = { alternatives: Alternative, errors: Error }
end