Class: Stripe::Account::RiskControls::Charges
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Account::RiskControls::Charges
- Defined in:
- lib/stripe/resources/account.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#pause_requested ⇒ Object
readonly
Whether a pause of the risk control has been requested.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#pause_requested ⇒ Object (readonly)
Whether a pause of the risk control has been requested.
476 477 478 |
# File 'lib/stripe/resources/account.rb', line 476 def pause_requested @pause_requested end |