Class: Stripe::Account::Settings::Branding
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Account::Settings::Branding
- Defined in:
- lib/stripe/resources/account.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#icon ⇒ Object
readonly
(ID of a [file upload](stripe.com/docs/guides/file-upload)) An icon for the account.
-
#logo ⇒ Object
readonly
(ID of a [file upload](stripe.com/docs/guides/file-upload)) A logo for the account that will be used in Checkout instead of the icon and without the account’s name next to it if provided.
-
#primary_color ⇒ Object
readonly
A CSS hex color value representing the primary branding color for this account.
-
#secondary_color ⇒ Object
readonly
A CSS hex color value representing the secondary branding color for this account.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#icon ⇒ Object (readonly)
(ID of a [file upload](stripe.com/docs/guides/file-upload)) An icon for the account. Must be square and at least 128px x 128px.
839 840 841 |
# File 'lib/stripe/resources/account.rb', line 839 def icon @icon end |
#logo ⇒ Object (readonly)
(ID of a [file upload](stripe.com/docs/guides/file-upload)) A logo for the account that will be used in Checkout instead of the icon and without the account’s name next to it if provided. Must be at least 128px x 128px.
841 842 843 |
# File 'lib/stripe/resources/account.rb', line 841 def logo @logo end |
#primary_color ⇒ Object (readonly)
A CSS hex color value representing the primary branding color for this account
843 844 845 |
# File 'lib/stripe/resources/account.rb', line 843 def primary_color @primary_color end |
#secondary_color ⇒ Object (readonly)
A CSS hex color value representing the secondary branding color for this account
845 846 847 |
# File 'lib/stripe/resources/account.rb', line 845 def secondary_color @secondary_color end |
Class Method Details
.field_remappings ⇒ Object
851 852 853 |
# File 'lib/stripe/resources/account.rb', line 851 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
847 848 849 |
# File 'lib/stripe/resources/account.rb', line 847 def self.inner_class_types @inner_class_types = {} end |