Class: Stripe::Account::Settings::Capital
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Account::Settings::Capital
- Defined in:
- lib/stripe/resources/account.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#payout_destination ⇒ Object
readonly
Per-currency mapping of user-selected destination accounts used to pay out loans.
-
#payout_destination_selector ⇒ Object
readonly
Per-currency mapping of all destination accounts eligible to receive loan payouts.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#payout_destination ⇒ Object (readonly)
Per-currency mapping of user-selected destination accounts used to pay out loans.
544 545 546 |
# File 'lib/stripe/resources/account.rb', line 544 def payout_destination @payout_destination end |
#payout_destination_selector ⇒ Object (readonly)
Per-currency mapping of all destination accounts eligible to receive loan payouts.
546 547 548 |
# File 'lib/stripe/resources/account.rb', line 546 def payout_destination_selector @payout_destination_selector end |