Class: Stripe::Account::Settings::CardPayments

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: DeclineOn

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#decline_onObject (readonly)

Attribute for field decline_on



832
833
834
# File 'lib/stripe/resources/account.rb', line 832

def decline_on
  @decline_on
end

#statement_descriptor_prefixObject (readonly)

The default text that appears on credit card statements when a charge is made. This field prefixes any dynamic statement_descriptor specified on the charge. statement_descriptor_prefix is useful for maximizing descriptor space for the dynamic portion.



834
835
836
# File 'lib/stripe/resources/account.rb', line 834

def statement_descriptor_prefix
  @statement_descriptor_prefix
end

#statement_descriptor_prefix_kanaObject (readonly)

The Kana variation of the default text that appears on credit card statements when a charge is made (Japan only). This field prefixes any dynamic statement_descriptor_suffix_kana specified on the charge. statement_descriptor_prefix_kana is useful for maximizing descriptor space for the dynamic portion.



836
837
838
# File 'lib/stripe/resources/account.rb', line 836

def statement_descriptor_prefix_kana
  @statement_descriptor_prefix_kana
end

#statement_descriptor_prefix_kanjiObject (readonly)

The Kanji variation of the default text that appears on credit card statements when a charge is made (Japan only). This field prefixes any dynamic statement_descriptor_suffix_kanji specified on the charge. statement_descriptor_prefix_kanji is useful for maximizing descriptor space for the dynamic portion.



838
839
840
# File 'lib/stripe/resources/account.rb', line 838

def statement_descriptor_prefix_kanji
  @statement_descriptor_prefix_kanji
end

Class Method Details

.field_remappingsObject



844
845
846
# File 'lib/stripe/resources/account.rb', line 844

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



840
841
842
# File 'lib/stripe/resources/account.rb', line 840

def self.inner_class_types
  @inner_class_types = { decline_on: DeclineOn }
end