Class: Stripe::Account::Settings::Dashboard

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/account.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#display_nameObject (readonly)

The display name for this account. This is used on the Stripe Dashboard to differentiate between accounts.



924
925
926
# File 'lib/stripe/resources/account.rb', line 924

def display_name
  @display_name
end

#timezoneObject (readonly)

The timezone used in the Stripe Dashboard for this account. A list of possible time zone values is maintained at the [IANA Time Zone Database](www.iana.org/time-zones).



926
927
928
# File 'lib/stripe/resources/account.rb', line 926

def timezone
  @timezone
end

Class Method Details

.field_remappingsObject



932
933
934
# File 'lib/stripe/resources/account.rb', line 932

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



928
929
930
# File 'lib/stripe/resources/account.rb', line 928

def self.inner_class_types
  @inner_class_types = {}
end