Class: Stripe::Account::Settings::PaypayPayments
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Account::Settings::PaypayPayments
- Defined in:
- lib/stripe/resources/account.rb
Defined Under Namespace
Classes: Site
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#additional_files ⇒ Object
readonly
Additional files that are required to support the onboarding process of your business.
-
#goods_type ⇒ Object
readonly
The type of goods your business sells.
-
#site ⇒ Object
readonly
Attribute for field site.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#additional_files ⇒ Object (readonly)
Additional files that are required to support the onboarding process of your business.
1008 1009 1010 |
# File 'lib/stripe/resources/account.rb', line 1008 def additional_files @additional_files end |
#goods_type ⇒ Object (readonly)
The type of goods your business sells. Use digital_content if you sell digital content. Use other for all other types of goods or services.
1010 1011 1012 |
# File 'lib/stripe/resources/account.rb', line 1010 def goods_type @goods_type end |
#site ⇒ Object (readonly)
Attribute for field site
1012 1013 1014 |
# File 'lib/stripe/resources/account.rb', line 1012 def site @site end |
Class Method Details
.field_remappings ⇒ Object
1018 1019 1020 |
# File 'lib/stripe/resources/account.rb', line 1018 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1014 1015 1016 |
# File 'lib/stripe/resources/account.rb', line 1014 def self.inner_class_types @inner_class_types = { site: Site } end |