Class: Stripe::Account::Settings::PaypayPayments::Site::InDevelopment
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Account::Settings::PaypayPayments::Site::InDevelopment
- Defined in:
- lib/stripe/resources/account.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#password_provided ⇒ Object
readonly
Field to indicate that the website password has been provided.
-
#username ⇒ Object
readonly
The username needed to access your business’s website.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#password_provided ⇒ Object (readonly)
Field to indicate that the website password has been provided.
1024 1025 1026 |
# File 'lib/stripe/resources/account.rb', line 1024 def password_provided @password_provided end |
#username ⇒ Object (readonly)
The username needed to access your business’s website.
1026 1027 1028 |
# File 'lib/stripe/resources/account.rb', line 1026 def username @username end |
Class Method Details
.field_remappings ⇒ Object
1032 1033 1034 |
# File 'lib/stripe/resources/account.rb', line 1032 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1028 1029 1030 |
# File 'lib/stripe/resources/account.rb', line 1028 def self.inner_class_types @inner_class_types = {} end |