Class: Stripe::Account::Settings::Treasury::TosAcceptance
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Account::Settings::Treasury::TosAcceptance
- Defined in:
- lib/stripe/resources/account.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#date ⇒ Object
readonly
The Unix timestamp marking when the account representative accepted the service agreement.
-
#ip ⇒ Object
readonly
The IP address from which the account representative accepted the service agreement.
-
#user_agent ⇒ Object
readonly
The user agent of the browser from which the account representative accepted the service agreement.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#date ⇒ Object (readonly)
The Unix timestamp marking when the account representative accepted the service agreement.
1022 1023 1024 |
# File 'lib/stripe/resources/account.rb', line 1022 def date @date end |
#ip ⇒ Object (readonly)
The IP address from which the account representative accepted the service agreement.
1024 1025 1026 |
# File 'lib/stripe/resources/account.rb', line 1024 def ip @ip end |
#user_agent ⇒ Object (readonly)
The user agent of the browser from which the account representative accepted the service agreement.
1026 1027 1028 |
# File 'lib/stripe/resources/account.rb', line 1026 def user_agent @user_agent end |
Class Method Details
.field_remappings ⇒ Object
1032 1033 1034 |
# File 'lib/stripe/resources/account.rb', line 1032 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1028 1029 1030 |
# File 'lib/stripe/resources/account.rb', line 1028 def self.inner_class_types @inner_class_types = {} end |