Class: Stripe::Account::TosAcceptance
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Account::TosAcceptance
- Defined in:
- lib/stripe/resources/account.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#date ⇒ Object
readonly
The Unix timestamp marking when the account representative accepted their service agreement.
-
#ip ⇒ Object
readonly
The IP address from which the account representative accepted their service agreement.
-
#service_agreement ⇒ Object
readonly
The user's service agreement type.
-
#user_agent ⇒ Object
readonly
The user agent of the browser from which the account representative accepted their service agreement.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#date ⇒ Object (readonly)
The Unix timestamp marking when the account representative accepted their service agreement
1296 1297 1298 |
# File 'lib/stripe/resources/account.rb', line 1296 def date @date end |
#ip ⇒ Object (readonly)
The IP address from which the account representative accepted their service agreement
1298 1299 1300 |
# File 'lib/stripe/resources/account.rb', line 1298 def ip @ip end |
#service_agreement ⇒ Object (readonly)
The user's service agreement type
1300 1301 1302 |
# File 'lib/stripe/resources/account.rb', line 1300 def service_agreement @service_agreement end |
#user_agent ⇒ Object (readonly)
The user agent of the browser from which the account representative accepted their service agreement
1302 1303 1304 |
# File 'lib/stripe/resources/account.rb', line 1302 def user_agent @user_agent end |
Class Method Details
.field_remappings ⇒ Object
1308 1309 1310 |
# File 'lib/stripe/resources/account.rb', line 1308 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1304 1305 1306 |
# File 'lib/stripe/resources/account.rb', line 1304 def self.inner_class_types @inner_class_types = {} end |