Class: Stripe::Account::UpdateParams::BankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(object: nil, account_holder_name: nil, account_holder_type: nil, account_number: nil, country: nil, currency: nil, routing_number: nil) ⇒ BankAccount

Returns a new instance of BankAccount.



1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
# File 'lib/stripe/resources/account.rb', line 1133

def initialize(
  object: nil,
  account_holder_name: nil,
  account_holder_type: nil,
  account_number: nil,
  country: nil,
  currency: nil,
  routing_number: nil
)
  @object = object
  @account_holder_name = 
  @account_holder_type = 
  @account_number = 
  @country = country
  @currency = currency
  @routing_number = routing_number
end

Instance Attribute Details

#account_holder_nameObject

The name of the person or business that owns the bank account.This field is required when attaching the bank account to a ‘Customer` object.



1121
1122
1123
# File 'lib/stripe/resources/account.rb', line 1121

def 
  @account_holder_name
end

#account_holder_typeObject

The type of entity that holds the account. It can be ‘company` or `individual`. This field is required when attaching the bank account to a `Customer` object.



1123
1124
1125
# File 'lib/stripe/resources/account.rb', line 1123

def 
  @account_holder_type
end

#account_numberObject

The account number for the bank account, in string form. Must be a checking account.



1125
1126
1127
# File 'lib/stripe/resources/account.rb', line 1125

def 
  @account_number
end

#countryObject

The country in which the bank account is located.



1127
1128
1129
# File 'lib/stripe/resources/account.rb', line 1127

def country
  @country
end

#currencyObject

The currency the bank account is in. This must be a country/currency pairing that [Stripe supports.](docs/payouts)



1129
1130
1131
# File 'lib/stripe/resources/account.rb', line 1129

def currency
  @currency
end

#objectObject

Attribute for param field object



1119
1120
1121
# File 'lib/stripe/resources/account.rb', line 1119

def object
  @object
end

#routing_numberObject

The routing number, sort code, or other country-appropriate institution number for the bank account. For US bank accounts, this is required and should be the ACH routing number, not the wire routing number. If you are providing an IBAN for ‘account_number`, this field is not required.



1131
1132
1133
# File 'lib/stripe/resources/account.rb', line 1131

def routing_number
  @routing_number
end