Class: Stripe::Account::UpdateParams::BusinessProfile

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: AnnualRevenue, MonthlyEstimatedRevenue, SupportAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(annual_revenue: nil, estimated_worker_count: nil, mcc: nil, minority_owned_business_designation: nil, monthly_estimated_revenue: nil, name: nil, product_description: nil, support_address: nil, support_email: nil, support_phone: nil, support_url: nil, url: nil) ⇒ BusinessProfile

Returns a new instance of BusinessProfile.



1235
1236
1237
1238
1239
1240
1241
1242
1243
1244
1245
1246
1247
1248
1249
1250
1251
1252
1253
1254
1255
1256
1257
1258
1259
1260
1261
# File 'lib/stripe/resources/account.rb', line 1235

def initialize(
  annual_revenue: nil,
  estimated_worker_count: nil,
  mcc: nil,
  minority_owned_business_designation: nil,
  monthly_estimated_revenue: nil,
  name: nil,
  product_description: nil,
  support_address: nil,
  support_email: nil,
  support_phone: nil,
  support_url: nil,
  url: nil
)
  @annual_revenue = annual_revenue
  @estimated_worker_count = estimated_worker_count
  @mcc = mcc
  @minority_owned_business_designation = minority_owned_business_designation
  @monthly_estimated_revenue = monthly_estimated_revenue
  @name = name
  @product_description = product_description
  @support_address = support_address
  @support_email = support_email
  @support_phone = support_phone
  @support_url = support_url
  @url = url
end

Instance Attribute Details

#annual_revenueObject

The applicant’s gross annual revenue for its preceding fiscal year.



1211
1212
1213
# File 'lib/stripe/resources/account.rb', line 1211

def annual_revenue
  @annual_revenue
end

#estimated_worker_countObject

An estimated upper bound of employees, contractors, vendors, etc. currently working for the business.



1213
1214
1215
# File 'lib/stripe/resources/account.rb', line 1213

def estimated_worker_count
  @estimated_worker_count
end

#mccObject

[The merchant category code for the account](/connect/setting-mcc). MCCs are used to classify businesses based on the goods or services they provide.



1215
1216
1217
# File 'lib/stripe/resources/account.rb', line 1215

def mcc
  @mcc
end

#minority_owned_business_designationObject

Whether the business is a minority-owned, women-owned, and/or LGBTQI+ -owned business.



1217
1218
1219
# File 'lib/stripe/resources/account.rb', line 1217

def minority_owned_business_designation
  @minority_owned_business_designation
end

#monthly_estimated_revenueObject

An estimate of the monthly revenue of the business. Only accepted for accounts in Brazil and India.



1219
1220
1221
# File 'lib/stripe/resources/account.rb', line 1219

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#nameObject

The customer-facing business name.



1221
1222
1223
# File 'lib/stripe/resources/account.rb', line 1221

def name
  @name
end

#product_descriptionObject

Internal-only description of the product sold by, or service provided by, the business. Used by Stripe for risk and underwriting purposes.



1223
1224
1225
# File 'lib/stripe/resources/account.rb', line 1223

def product_description
  @product_description
end

#support_addressObject

A publicly available mailing address for sending support issues to.



1225
1226
1227
# File 'lib/stripe/resources/account.rb', line 1225

def support_address
  @support_address
end

#support_emailObject

A publicly available email address for sending support issues to.



1227
1228
1229
# File 'lib/stripe/resources/account.rb', line 1227

def support_email
  @support_email
end

#support_phoneObject

A publicly available phone number to call with support issues.



1229
1230
1231
# File 'lib/stripe/resources/account.rb', line 1229

def support_phone
  @support_phone
end

#support_urlObject

A publicly available website for handling support issues.



1231
1232
1233
# File 'lib/stripe/resources/account.rb', line 1231

def support_url
  @support_url
end

#urlObject

The business’s publicly available website.



1233
1234
1235
# File 'lib/stripe/resources/account.rb', line 1233

def url
  @url
end