Class: Stripe::Account::UpdateParams::Capabilities::PaypalPayments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::UpdateParams::Capabilities::PaypalPayments
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#requested ⇒ Object
Passing true requests the capability for the account, if it is not already requested.
Instance Method Summary collapse
-
#initialize(requested: nil) ⇒ PaypalPayments
constructor
A new instance of PaypalPayments.
Methods inherited from RequestParams
Constructor Details
#initialize(requested: nil) ⇒ PaypalPayments
Returns a new instance of PaypalPayments.
1203 1204 1205 |
# File 'lib/stripe/resources/account.rb', line 1203 def initialize(requested: nil) @requested = requested end |
Instance Attribute Details
#requested ⇒ Object
Passing true requests the capability for the account, if it is not already requested. A requested capability may not immediately become active. Any requirements to activate the capability are returned in the ‘requirements` arrays.
1201 1202 1203 |
# File 'lib/stripe/resources/account.rb', line 1201 def requested @requested end |