Class: Stripe::Account::UpdateParams::Capabilities::SwishPayments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::UpdateParams::Capabilities::SwishPayments
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#requested ⇒ Object
Passing true requests the capability for the account, if it is not already requested.
Instance Method Summary collapse
-
#initialize(requested: nil) ⇒ SwishPayments
constructor
A new instance of SwishPayments.
Methods inherited from RequestParams
Constructor Details
#initialize(requested: nil) ⇒ SwishPayments
Returns a new instance of SwishPayments.
1302 1303 1304 |
# File 'lib/stripe/resources/account.rb', line 1302 def initialize(requested: nil) @requested = requested end |
Instance Attribute Details
#requested ⇒ Object
Passing true requests the capability for the account, if it is not already requested. A requested capability may not immediately become active. Any requirements to activate the capability are returned in the ‘requirements` arrays.
1300 1301 1302 |
# File 'lib/stripe/resources/account.rb', line 1300 def requested @requested end |