Class: Stripe::Account::UpdateParams::Capabilities::TaxReportingUs1099K
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::UpdateParams::Capabilities::TaxReportingUs1099K
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#requested ⇒ Object
Passing true requests the capability for the account, if it is not already requested.
Instance Method Summary collapse
-
#initialize(requested: nil) ⇒ TaxReportingUs1099K
constructor
A new instance of TaxReportingUs1099K.
Methods inherited from RequestParams
Constructor Details
#initialize(requested: nil) ⇒ TaxReportingUs1099K
Returns a new instance of TaxReportingUs1099K.
1215 1216 1217 |
# File 'lib/stripe/resources/account.rb', line 1215 def initialize(requested: nil) @requested = requested end |
Instance Attribute Details
#requested ⇒ Object
Passing true requests the capability for the account, if it is not already requested. A requested capability may not immediately become active. Any requirements to activate the capability are returned in the ‘requirements` arrays.
1213 1214 1215 |
# File 'lib/stripe/resources/account.rb', line 1213 def requested @requested end |