Class: Stripe::Account::UpdateParams::Capabilities::TwintPayments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::UpdateParams::Capabilities::TwintPayments
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#requested ⇒ Object
Passing true requests the capability for the account, if it is not already requested.
Instance Method Summary collapse
-
#initialize(requested: nil) ⇒ TwintPayments
constructor
A new instance of TwintPayments.
Methods inherited from RequestParams
Constructor Details
#initialize(requested: nil) ⇒ TwintPayments
Returns a new instance of TwintPayments.
1890 1891 1892 |
# File 'lib/stripe/resources/account.rb', line 1890 def initialize(requested: nil) @requested = requested end |
Instance Attribute Details
#requested ⇒ Object
Passing true requests the capability for the account, if it is not already requested. A requested capability may not immediately become active. Any requirements to activate the capability are returned in the ‘requirements` arrays.
1888 1889 1890 |
# File 'lib/stripe/resources/account.rb', line 1888 def requested @requested end |