Class: Stripe::Account::UpdateParams::Company

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: Address, AddressKana, AddressKanji, DirectorshipDeclaration, OwnershipDeclaration, RegistrationDate, Verification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, address_kana: nil, address_kanji: nil, directors_provided: nil, directorship_declaration: nil, executives_provided: nil, export_license_id: nil, export_purpose_code: nil, name: nil, name_kana: nil, name_kanji: nil, owners_provided: nil, ownership_declaration: nil, ownership_exemption_reason: nil, phone: nil, registration_date: nil, registration_number: nil, structure: nil, tax_id: nil, tax_id_registrar: nil, vat_id: nil, verification: nil) ⇒ Company

Returns a new instance of Company.



2512
2513
2514
2515
2516
2517
2518
2519
2520
2521
2522
2523
2524
2525
2526
2527
2528
2529
2530
2531
2532
2533
2534
2535
2536
2537
2538
2539
2540
2541
2542
2543
2544
2545
2546
2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
# File 'lib/stripe/resources/account.rb', line 2512

def initialize(
  address: nil,
  address_kana: nil,
  address_kanji: nil,
  directors_provided: nil,
  directorship_declaration: nil,
  executives_provided: nil,
  export_license_id: nil,
  export_purpose_code: nil,
  name: nil,
  name_kana: nil,
  name_kanji: nil,
  owners_provided: nil,
  ownership_declaration: nil,
  ownership_exemption_reason: nil,
  phone: nil,
  registration_date: nil,
  registration_number: nil,
  structure: nil,
  tax_id: nil,
  tax_id_registrar: nil,
  vat_id: nil,
  verification: nil
)
  @address = address
  @address_kana = address_kana
  @address_kanji = address_kanji
  @directors_provided = directors_provided
  @directorship_declaration = directorship_declaration
  @executives_provided = executives_provided
  @export_license_id = export_license_id
  @export_purpose_code = export_purpose_code
  @name = name
  @name_kana = name_kana
  @name_kanji = name_kanji
  @owners_provided = owners_provided
  @ownership_declaration = ownership_declaration
  @ownership_exemption_reason = ownership_exemption_reason
  @phone = phone
  @registration_date = registration_date
  @registration_number = registration_number
  @structure = structure
  @tax_id = tax_id
  @tax_id_registrar = tax_id_registrar
  @vat_id = vat_id
  @verification = verification
end

Instance Attribute Details

#addressObject

The company’s primary address.



2468
2469
2470
# File 'lib/stripe/resources/account.rb', line 2468

def address
  @address
end

#address_kanaObject

The Kana variation of the company’s primary address (Japan only).



2470
2471
2472
# File 'lib/stripe/resources/account.rb', line 2470

def address_kana
  @address_kana
end

#address_kanjiObject

The Kanji variation of the company’s primary address (Japan only).



2472
2473
2474
# File 'lib/stripe/resources/account.rb', line 2472

def address_kanji
  @address_kanji
end

#directors_providedObject

Whether the company’s directors have been provided. Set this Boolean to ‘true` after creating all the company’s directors with [the Persons API](/api/persons) for accounts with a ‘relationship.director` requirement. This value is not automatically set to `true` after creating directors, so it needs to be updated to indicate all directors have been provided.



2474
2475
2476
# File 'lib/stripe/resources/account.rb', line 2474

def directors_provided
  @directors_provided
end

#directorship_declarationObject

This hash is used to attest that the directors information provided to Stripe is both current and correct.



2476
2477
2478
# File 'lib/stripe/resources/account.rb', line 2476

def directorship_declaration
  @directorship_declaration
end

#executives_providedObject

Whether the company’s executives have been provided. Set this Boolean to ‘true` after creating all the company’s executives with [the Persons API](/api/persons) for accounts with a ‘relationship.executive` requirement.



2478
2479
2480
# File 'lib/stripe/resources/account.rb', line 2478

def executives_provided
  @executives_provided
end

#export_license_idObject

The export license ID number of the company, also referred as Import Export Code (India only).



2480
2481
2482
# File 'lib/stripe/resources/account.rb', line 2480

def export_license_id
  @export_license_id
end

#export_purpose_codeObject

The purpose code to use for export transactions (India only).



2482
2483
2484
# File 'lib/stripe/resources/account.rb', line 2482

def export_purpose_code
  @export_purpose_code
end

#nameObject

The company’s legal name.



2484
2485
2486
# File 'lib/stripe/resources/account.rb', line 2484

def name
  @name
end

#name_kanaObject

The Kana variation of the company’s legal name (Japan only).



2486
2487
2488
# File 'lib/stripe/resources/account.rb', line 2486

def name_kana
  @name_kana
end

#name_kanjiObject

The Kanji variation of the company’s legal name (Japan only).



2488
2489
2490
# File 'lib/stripe/resources/account.rb', line 2488

def name_kanji
  @name_kanji
end

#owners_providedObject

Whether the company’s owners have been provided. Set this Boolean to ‘true` after creating all the company’s owners with [the Persons API](/api/persons) for accounts with a ‘relationship.owner` requirement.



2490
2491
2492
# File 'lib/stripe/resources/account.rb', line 2490

def owners_provided
  @owners_provided
end

#ownership_declarationObject

This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.



2492
2493
2494
# File 'lib/stripe/resources/account.rb', line 2492

def ownership_declaration
  @ownership_declaration
end

#ownership_exemption_reasonObject

This value is used to determine if a business is exempt from providing ultimate beneficial owners. See [this support article](support.stripe.com/questions/exemption-from-providing-ownership-details) and [changelog](docs.stripe.com/changelog/acacia/2025-01-27/ownership-exemption-reason-accounts-api) for more details.



2494
2495
2496
# File 'lib/stripe/resources/account.rb', line 2494

def ownership_exemption_reason
  @ownership_exemption_reason
end

#phoneObject

The company’s phone number (used for verification).



2496
2497
2498
# File 'lib/stripe/resources/account.rb', line 2496

def phone
  @phone
end

#registration_dateObject

Attribute for param field registration_date



2498
2499
2500
# File 'lib/stripe/resources/account.rb', line 2498

def registration_date
  @registration_date
end

#registration_numberObject

The identification number given to a company when it is registered or incorporated, if distinct from the identification number used for filing taxes. (Examples are the CIN for companies and LLP IN for partnerships in India, and the Company Registration Number in Hong Kong).



2500
2501
2502
# File 'lib/stripe/resources/account.rb', line 2500

def registration_number
  @registration_number
end

#structureObject

The category identifying the legal structure of the company or legal entity. See [Business structure](/connect/identity-verification#business-structure) for more details. Pass an empty string to unset this value.



2502
2503
2504
# File 'lib/stripe/resources/account.rb', line 2502

def structure
  @structure
end

#tax_idObject

The business ID number of the company, as appropriate for the company’s country. (Examples are an Employer ID Number in the U.S., a Business Number in Canada, or a Company Number in the UK.)



2504
2505
2506
# File 'lib/stripe/resources/account.rb', line 2504

def tax_id
  @tax_id
end

#tax_id_registrarObject

The jurisdiction in which the ‘tax_id` is registered (Germany-based companies only).



2506
2507
2508
# File 'lib/stripe/resources/account.rb', line 2506

def tax_id_registrar
  @tax_id_registrar
end

#vat_idObject

The VAT number of the company.



2508
2509
2510
# File 'lib/stripe/resources/account.rb', line 2508

def vat_id
  @vat_id
end

#verificationObject

Information on the verification state of the company.



2510
2511
2512
# File 'lib/stripe/resources/account.rb', line 2510

def verification
  @verification
end