Class: Stripe::Account::UpdateParams::Company::DirectorshipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ DirectorshipDeclaration

Returns a new instance of DirectorshipDeclaration.



2411
2412
2413
2414
2415
# File 'lib/stripe/resources/account.rb', line 2411

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the directorship declaration attestation was made.



2405
2406
2407
# File 'lib/stripe/resources/account.rb', line 2405

def date
  @date
end

#ipObject

The IP address from which the directorship declaration attestation was made.



2407
2408
2409
# File 'lib/stripe/resources/account.rb', line 2407

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the directorship declaration attestation was made.



2409
2410
2411
# File 'lib/stripe/resources/account.rb', line 2409

def user_agent
  @user_agent
end