Class: Stripe::Account::UpdateParams::Company::OwnershipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ OwnershipDeclaration

Returns a new instance of OwnershipDeclaration.



2426
2427
2428
2429
2430
# File 'lib/stripe/resources/account.rb', line 2426

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the beneficial owner attestation was made.



2420
2421
2422
# File 'lib/stripe/resources/account.rb', line 2420

def date
  @date
end

#ipObject

The IP address from which the beneficial owner attestation was made.



2422
2423
2424
# File 'lib/stripe/resources/account.rb', line 2422

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the beneficial owner attestation was made.



2424
2425
2426
# File 'lib/stripe/resources/account.rb', line 2424

def user_agent
  @user_agent
end