Class: Stripe::Account::UpdateParams::Documents

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: BankAccountOwnershipVerification, CompanyLicense, CompanyMemorandumOfAssociation, CompanyMinisterialDecree, CompanyRegistrationVerification, CompanyTaxIdVerification, ProofOfAddress, ProofOfRegistration, ProofOfUltimateBeneficialOwnership

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bank_account_ownership_verification: nil, company_license: nil, company_memorandum_of_association: nil, company_ministerial_decree: nil, company_registration_verification: nil, company_tax_id_verification: nil, proof_of_address: nil, proof_of_registration: nil, proof_of_ultimate_beneficial_ownership: nil) ⇒ Documents

Returns a new instance of Documents.



2661
2662
2663
2664
2665
2666
2667
2668
2669
2670
2671
2672
2673
2674
2675
2676
2677
2678
2679
2680
2681
# File 'lib/stripe/resources/account.rb', line 2661

def initialize(
  bank_account_ownership_verification: nil,
  company_license: nil,
  company_memorandum_of_association: nil,
  company_ministerial_decree: nil,
  company_registration_verification: nil,
  company_tax_id_verification: nil,
  proof_of_address: nil,
  proof_of_registration: nil,
  proof_of_ultimate_beneficial_ownership: nil
)
  @bank_account_ownership_verification = 
  @company_license = company_license
  @company_memorandum_of_association = company_memorandum_of_association
  @company_ministerial_decree = company_ministerial_decree
  @company_registration_verification = company_registration_verification
  @company_tax_id_verification = company_tax_id_verification
  @proof_of_address = proof_of_address
  @proof_of_registration = proof_of_registration
  @proof_of_ultimate_beneficial_ownership = proof_of_ultimate_beneficial_ownership
end

Instance Attribute Details

#bank_account_ownership_verificationObject

One or more documents that support the [Bank account ownership verification](support.stripe.com/questions/bank-account-ownership-verification) requirement. Must be a document associated with the account’s primary active bank account that displays the last 4 digits of the account number, either a statement or a check.



2643
2644
2645
# File 'lib/stripe/resources/account.rb', line 2643

def 
  @bank_account_ownership_verification
end

#company_licenseObject

One or more documents that demonstrate proof of a company’s license to operate.



2645
2646
2647
# File 'lib/stripe/resources/account.rb', line 2645

def company_license
  @company_license
end

#company_memorandum_of_associationObject

One or more documents showing the company’s Memorandum of Association.



2647
2648
2649
# File 'lib/stripe/resources/account.rb', line 2647

def company_memorandum_of_association
  @company_memorandum_of_association
end

#company_ministerial_decreeObject

(Certain countries only) One or more documents showing the ministerial decree legalizing the company’s establishment.



2649
2650
2651
# File 'lib/stripe/resources/account.rb', line 2649

def company_ministerial_decree
  @company_ministerial_decree
end

#company_registration_verificationObject

One or more documents that demonstrate proof of a company’s registration with the appropriate local authorities.



2651
2652
2653
# File 'lib/stripe/resources/account.rb', line 2651

def company_registration_verification
  @company_registration_verification
end

#company_tax_id_verificationObject

One or more documents that demonstrate proof of a company’s tax ID.



2653
2654
2655
# File 'lib/stripe/resources/account.rb', line 2653

def company_tax_id_verification
  @company_tax_id_verification
end

#proof_of_addressObject

One or more documents that demonstrate proof of address.



2655
2656
2657
# File 'lib/stripe/resources/account.rb', line 2655

def proof_of_address
  @proof_of_address
end

#proof_of_registrationObject

One or more documents showing the company’s proof of registration with the national business registry.



2657
2658
2659
# File 'lib/stripe/resources/account.rb', line 2657

def proof_of_registration
  @proof_of_registration
end

#proof_of_ultimate_beneficial_ownershipObject

One or more documents that demonstrate proof of ultimate beneficial ownership.



2659
2660
2661
# File 'lib/stripe/resources/account.rb', line 2659

def proof_of_ultimate_beneficial_ownership
  @proof_of_ultimate_beneficial_ownership
end