Class: Stripe::Account::UpdateParams::Documents::CompanyLicense
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::UpdateParams::Documents::CompanyLicense
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#files ⇒ Object
One or more document ids returned by a [file upload](stripe.com/docs/api#create_file) with a ‘purpose` value of `account_requirement`.
Instance Method Summary collapse
-
#initialize(files: nil) ⇒ CompanyLicense
constructor
A new instance of CompanyLicense.
Methods inherited from RequestParams
Constructor Details
#initialize(files: nil) ⇒ CompanyLicense
Returns a new instance of CompanyLicense.
1811 1812 1813 |
# File 'lib/stripe/resources/account.rb', line 1811 def initialize(files: nil) @files = files end |
Instance Attribute Details
#files ⇒ Object
One or more document ids returned by a [file upload](stripe.com/docs/api#create_file) with a ‘purpose` value of `account_requirement`.
1809 1810 1811 |
# File 'lib/stripe/resources/account.rb', line 1809 def files @files end |