Class: Stripe::Account::UpdateParams::Groups
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::UpdateParams::Groups
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#payments_pricing ⇒ Object
The group the account is in to determine their payments pricing, and null if the account is on customized pricing.
Instance Method Summary collapse
-
#initialize(payments_pricing: nil) ⇒ Groups
constructor
A new instance of Groups.
Methods inherited from RequestParams
Constructor Details
#initialize(payments_pricing: nil) ⇒ Groups
Returns a new instance of Groups.
1961 1962 1963 |
# File 'lib/stripe/resources/account.rb', line 1961 def initialize(payments_pricing: nil) @payments_pricing = payments_pricing end |
Instance Attribute Details
#payments_pricing ⇒ Object
The group the account is in to determine their payments pricing, and null if the account is on customized pricing. [See the Platform pricing tool documentation](stripe.com/docs/connect/platform-pricing-tools) for details.
1959 1960 1961 |
# File 'lib/stripe/resources/account.rb', line 1959 def payments_pricing @payments_pricing end |