Class: Stripe::Account::UpdateParams::Individual

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: Address, AddressKana, AddressKanji, Dob, RegisteredAddress, Relationship, Verification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, address_kana: nil, address_kanji: nil, dob: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil) ⇒ Individual

Returns a new instance of Individual.



2949
2950
2951
2952
2953
2954
2955
2956
2957
2958
2959
2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
2970
2971
2972
2973
2974
2975
2976
2977
2978
2979
2980
2981
2982
2983
2984
2985
2986
2987
2988
2989
2990
2991
2992
2993
2994
2995
2996
2997
# File 'lib/stripe/resources/account.rb', line 2949

def initialize(
  address: nil,
  address_kana: nil,
  address_kanji: nil,
  dob: nil,
  email: nil,
  first_name: nil,
  first_name_kana: nil,
  first_name_kanji: nil,
  full_name_aliases: nil,
  gender: nil,
  id_number: nil,
  id_number_secondary: nil,
  last_name: nil,
  last_name_kana: nil,
  last_name_kanji: nil,
  maiden_name: nil,
  metadata: nil,
  phone: nil,
  political_exposure: nil,
  registered_address: nil,
  relationship: nil,
  ssn_last_4: nil,
  verification: nil
)
  @address = address
  @address_kana = address_kana
  @address_kanji = address_kanji
  @dob = dob
  @email = email
  @first_name = first_name
  @first_name_kana = first_name_kana
  @first_name_kanji = first_name_kanji
  @full_name_aliases = full_name_aliases
  @gender = gender
  @id_number = id_number
  @id_number_secondary = id_number_secondary
  @last_name = last_name
  @last_name_kana = last_name_kana
  @last_name_kanji = last_name_kanji
  @maiden_name = maiden_name
  @metadata = 
  @phone = phone
  @political_exposure = political_exposure
  @registered_address = registered_address
  @relationship = relationship
  @ssn_last_4 = ssn_last_4
  @verification = verification
end

Instance Attribute Details

#addressObject

The individual’s primary address.



2903
2904
2905
# File 'lib/stripe/resources/account.rb', line 2903

def address
  @address
end

#address_kanaObject

The Kana variation of the individual’s primary address (Japan only).



2905
2906
2907
# File 'lib/stripe/resources/account.rb', line 2905

def address_kana
  @address_kana
end

#address_kanjiObject

The Kanji variation of the individual’s primary address (Japan only).



2907
2908
2909
# File 'lib/stripe/resources/account.rb', line 2907

def address_kanji
  @address_kanji
end

#dobObject

The individual’s date of birth.



2909
2910
2911
# File 'lib/stripe/resources/account.rb', line 2909

def dob
  @dob
end

#emailObject

The individual’s email address.



2911
2912
2913
# File 'lib/stripe/resources/account.rb', line 2911

def email
  @email
end

#first_nameObject

The individual’s first name.



2913
2914
2915
# File 'lib/stripe/resources/account.rb', line 2913

def first_name
  @first_name
end

#first_name_kanaObject

The Kana variation of the individual’s first name (Japan only).



2915
2916
2917
# File 'lib/stripe/resources/account.rb', line 2915

def first_name_kana
  @first_name_kana
end

#first_name_kanjiObject

The Kanji variation of the individual’s first name (Japan only).



2917
2918
2919
# File 'lib/stripe/resources/account.rb', line 2917

def first_name_kanji
  @first_name_kanji
end

#full_name_aliasesObject

A list of alternate names or aliases that the individual is known by.



2919
2920
2921
# File 'lib/stripe/resources/account.rb', line 2919

def full_name_aliases
  @full_name_aliases
end

#genderObject

The individual’s gender



2921
2922
2923
# File 'lib/stripe/resources/account.rb', line 2921

def gender
  @gender
end

#id_numberObject

The government-issued ID number of the individual, as appropriate for the representative’s country. (Examples are a Social Security Number in the U.S., or a Social Insurance Number in Canada). Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).



2923
2924
2925
# File 'lib/stripe/resources/account.rb', line 2923

def id_number
  @id_number
end

#id_number_secondaryObject

The government-issued secondary ID number of the individual, as appropriate for the representative’s country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).



2925
2926
2927
# File 'lib/stripe/resources/account.rb', line 2925

def id_number_secondary
  @id_number_secondary
end

#last_nameObject

The individual’s last name.



2927
2928
2929
# File 'lib/stripe/resources/account.rb', line 2927

def last_name
  @last_name
end

#last_name_kanaObject

The Kana variation of the individual’s last name (Japan only).



2929
2930
2931
# File 'lib/stripe/resources/account.rb', line 2929

def last_name_kana
  @last_name_kana
end

#last_name_kanjiObject

The Kanji variation of the individual’s last name (Japan only).



2931
2932
2933
# File 'lib/stripe/resources/account.rb', line 2931

def last_name_kanji
  @last_name_kanji
end

#maiden_nameObject

The individual’s maiden name.



2933
2934
2935
# File 'lib/stripe/resources/account.rb', line 2933

def maiden_name
  @maiden_name
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2935
2936
2937
# File 'lib/stripe/resources/account.rb', line 2935

def 
  @metadata
end

#phoneObject

The individual’s phone number.



2937
2938
2939
# File 'lib/stripe/resources/account.rb', line 2937

def phone
  @phone
end

#political_exposureObject

Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.



2939
2940
2941
# File 'lib/stripe/resources/account.rb', line 2939

def political_exposure
  @political_exposure
end

#registered_addressObject

The individual’s registered address.



2941
2942
2943
# File 'lib/stripe/resources/account.rb', line 2941

def registered_address
  @registered_address
end

#relationshipObject

Describes the person’s relationship to the account.



2943
2944
2945
# File 'lib/stripe/resources/account.rb', line 2943

def relationship
  @relationship
end

#ssn_last_4Object

The last four digits of the individual’s Social Security Number (U.S. only).



2945
2946
2947
# File 'lib/stripe/resources/account.rb', line 2945

def ssn_last_4
  @ssn_last_4
end

#verificationObject

The individual’s verification document information.



2947
2948
2949
# File 'lib/stripe/resources/account.rb', line 2947

def verification
  @verification
end