Class: Stripe::Account::UpdateParams::Individual::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship

Returns a new instance of Relationship.



2429
2430
2431
2432
2433
2434
2435
2436
2437
2438
2439
2440
2441
# File 'lib/stripe/resources/account.rb', line 2429

def initialize(
  director: nil,
  executive: nil,
  owner: nil,
  percent_ownership: nil,
  title: nil
)
  @director = director
  @executive = executive
  @owner = owner
  @percent_ownership = percent_ownership
  @title = title
end

Instance Attribute Details

#directorObject

Whether the person is a director of the account’s legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



2419
2420
2421
# File 'lib/stripe/resources/account.rb', line 2419

def director
  @director
end

#executiveObject

Whether the person has significant responsibility to control, manage, or direct the organization.



2421
2422
2423
# File 'lib/stripe/resources/account.rb', line 2421

def executive
  @executive
end

#ownerObject

Whether the person is an owner of the account’s legal entity.



2423
2424
2425
# File 'lib/stripe/resources/account.rb', line 2423

def owner
  @owner
end

#percent_ownershipObject

The percent owned by the person of the account’s legal entity.



2425
2426
2427
# File 'lib/stripe/resources/account.rb', line 2425

def percent_ownership
  @percent_ownership
end

#titleObject

The person’s title (e.g., CEO, Support Engineer).



2427
2428
2429
# File 'lib/stripe/resources/account.rb', line 2427

def title
  @title
end