Class: Stripe::Account::UpdateParams::Settings::Branding

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil) ⇒ Branding

Returns a new instance of Branding.



3063
3064
3065
3066
3067
3068
# File 'lib/stripe/resources/account.rb', line 3063

def initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil)
  @icon = icon
  @logo = 
  @primary_color = primary_color
  @secondary_color = secondary_color
end

Instance Attribute Details

#iconObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) An icon for the account. Must be square and at least 128px x 128px.



3055
3056
3057
# File 'lib/stripe/resources/account.rb', line 3055

def icon
  @icon
end

#logoObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) A logo for the account that will be used in Checkout instead of the icon and without the account’s name next to it if provided. Must be at least 128px x 128px.



3057
3058
3059
# File 'lib/stripe/resources/account.rb', line 3057

def 
  @logo
end

#primary_colorObject

A CSS hex color value representing the primary branding color for this account.



3059
3060
3061
# File 'lib/stripe/resources/account.rb', line 3059

def primary_color
  @primary_color
end

#secondary_colorObject

A CSS hex color value representing the secondary branding color for this account.



3061
3062
3063
# File 'lib/stripe/resources/account.rb', line 3061

def secondary_color
  @secondary_color
end