Class: Stripe::Account::UpdateParams::Settings::CardIssuing::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



2668
2669
2670
2671
2672
# File 'lib/stripe/resources/account.rb', line 2668

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



2662
2663
2664
# File 'lib/stripe/resources/account.rb', line 2662

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



2664
2665
2666
# File 'lib/stripe/resources/account.rb', line 2664

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



2666
2667
2668
# File 'lib/stripe/resources/account.rb', line 2666

def user_agent
  @user_agent
end