Class: Stripe::Account::UpdateParams::Settings::CardPayments::DeclineOn

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(avs_failure: nil, cvc_failure: nil) ⇒ DeclineOn

Returns a new instance of DeclineOn.



2613
2614
2615
2616
# File 'lib/stripe/resources/account.rb', line 2613

def initialize(avs_failure: nil, cvc_failure: nil)
  @avs_failure = avs_failure
  @cvc_failure = cvc_failure
end

Instance Attribute Details

#avs_failureObject

Whether Stripe automatically declines charges with an incorrect ZIP or postal code. This setting only applies when a ZIP or postal code is provided and they fail bank verification.



2609
2610
2611
# File 'lib/stripe/resources/account.rb', line 2609

def avs_failure
  @avs_failure
end

#cvc_failureObject

Whether Stripe automatically declines charges with an incorrect CVC. This setting only applies when a CVC is provided and it fails bank verification.



2611
2612
2613
# File 'lib/stripe/resources/account.rb', line 2611

def cvc_failure
  @cvc_failure
end