Class: Stripe::Account::UpdateParams::Settings::Treasury::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



3234
3235
3236
3237
3238
# File 'lib/stripe/resources/account.rb', line 3234

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



3228
3229
3230
# File 'lib/stripe/resources/account.rb', line 3228

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



3230
3231
3232
# File 'lib/stripe/resources/account.rb', line 3230

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



3232
3233
3234
# File 'lib/stripe/resources/account.rb', line 3232

def user_agent
  @user_agent
end