Class: Stripe::Account::UpdateParams::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



3307
3308
3309
3310
3311
3312
# File 'lib/stripe/resources/account.rb', line 3307

def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil)
  @date = date
  @ip = ip
  @service_agreement = service_agreement
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted their service agreement.



3299
3300
3301
# File 'lib/stripe/resources/account.rb', line 3299

def date
  @date
end

#ipObject

The IP address from which the account representative accepted their service agreement.



3301
3302
3303
# File 'lib/stripe/resources/account.rb', line 3301

def ip
  @ip
end

#service_agreementObject

The user’s service agreement type.



3303
3304
3305
# File 'lib/stripe/resources/account.rb', line 3303

def service_agreement
  @service_agreement
end

#user_agentObject

The user agent of the browser from which the account representative accepted their service agreement.



3305
3306
3307
# File 'lib/stripe/resources/account.rb', line 3305

def user_agent
  @user_agent
end