Class: Stripe::AccountCreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/account_create_params.rb

Defined Under Namespace

Classes: BankAccount, BusinessProfile, Capabilities, Card, CardToken, Company, Controller, Documents, Groups, Individual, Settings, TosAcceptance

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(account_token: nil, business_profile: nil, business_type: nil, capabilities: nil, company: nil, controller: nil, country: nil, default_currency: nil, documents: nil, email: nil, expand: nil, external_account: nil, groups: nil, individual: nil, metadata: nil, settings: nil, tos_acceptance: nil, type: nil) ⇒ AccountCreateParams



2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
2124
2125
2126
2127
2128
2129
2130
2131
2132
2133
2134
2135
2136
2137
2138
2139
2140
2141
2142
2143
2144
2145
2146
2147
2148
# File 'lib/stripe/params/account_create_params.rb', line 2110

def initialize(
  account_token: nil,
  business_profile: nil,
  business_type: nil,
  capabilities: nil,
  company: nil,
  controller: nil,
  country: nil,
  default_currency: nil,
  documents: nil,
  email: nil,
  expand: nil,
  external_account: nil,
  groups: nil,
  individual: nil,
  metadata: nil,
  settings: nil,
  tos_acceptance: nil,
  type: nil
)
  @account_token = 
  @business_profile = business_profile
  @business_type = business_type
  @capabilities = capabilities
  @company = company
  @controller = controller
  @country = country
  @default_currency = default_currency
  @documents = documents
  @email = email
  @expand = expand
   = 
  @groups = groups
  @individual = individual
   = 
  @settings = settings
  @tos_acceptance = tos_acceptance
  @type = type
end

Instance Attribute Details

#account_tokenObject

An [account token](api.stripe.com#create_account_token), used to securely provide details to the account.



2067
2068
2069
# File 'lib/stripe/params/account_create_params.rb', line 2067

def 
  @account_token
end

#business_profileObject

Business information about the account.



2069
2070
2071
# File 'lib/stripe/params/account_create_params.rb', line 2069

def business_profile
  @business_profile
end

#business_typeObject

The business type. Once you create an [Account Link](/api/account_links) or [Account Session](/api/account_sessions), this property can only be updated for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is application, which includes Custom accounts.



2071
2072
2073
# File 'lib/stripe/params/account_create_params.rb', line 2071

def business_type
  @business_type
end

#capabilitiesObject

Each key of the dictionary represents a capability, and each capability maps to its settings (for example, whether it has been requested or not). Each capability is inactive until you have provided its specific requirements and Stripe has verified them. An account might have some of its requested capabilities be active and some be inactive.

Required when [account.controller.stripe_dashboard.type](/api/accounts/create#create_account-controller-dashboard-type) is none, which includes Custom accounts.



2080
2081
2082
# File 'lib/stripe/params/account_create_params.rb', line 2080

def capabilities
  @capabilities
end

#companyObject

Information about the company or business. This field is available for any business_type. Once you create an [Account Link](/api/account_links) or [Account Session](/api/account_sessions), this property can only be updated for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is application, which includes Custom accounts.



2082
2083
2084
# File 'lib/stripe/params/account_create_params.rb', line 2082

def company
  @company
end

#controllerObject

A hash of configuration describing the account controller’s attributes.



2084
2085
2086
# File 'lib/stripe/params/account_create_params.rb', line 2084

def controller
  @controller
end

#countryObject

The country in which the account holder resides, or in which the business is legally established. This should be an ISO 3166-1 alpha-2 country code. For example, if you are in the United States and the business for which you’re creating an account is legally represented in Canada, you would use CA as the country for the account being created. Available countries include [Stripe’s global markets](stripe.com/global) as well as countries where [cross-border payouts](stripe.com/docs/connect/cross-border-payouts) are supported.



2086
2087
2088
# File 'lib/stripe/params/account_create_params.rb', line 2086

def country
  @country
end

#default_currencyObject

Three-letter ISO currency code representing the default currency for the account. This must be a currency that [Stripe supports in the account’s country](docs.stripe.com/payouts).



2088
2089
2090
# File 'lib/stripe/params/account_create_params.rb', line 2088

def default_currency
  @default_currency
end

#documentsObject

Documents that may be submitted to satisfy various informational requests.



2090
2091
2092
# File 'lib/stripe/params/account_create_params.rb', line 2090

def documents
  @documents
end

#emailObject

The email address of the account holder. This is only to make the account easier to identify to you. If [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is application, which includes Custom accounts, Stripe doesn’t email the account without your consent.



2092
2093
2094
# File 'lib/stripe/params/account_create_params.rb', line 2092

def email
  @email
end

#expandObject

Specifies which fields in the response should be expanded.



2094
2095
2096
# File 'lib/stripe/params/account_create_params.rb', line 2094

def expand
  @expand
end

#external_accountObject

A card or bank account to attach to the account for receiving [payouts](/connect/bank-debit-card-payouts) (you won’t be able to use it for top-ups). You can provide either a token, like the ones returned by [Stripe.js](/js), or a dictionary, as documented in the external_account parameter for [bank account](/api#account_create_bank_account) creation.

By default, providing an external account sets it as the new default external account for its currency, and deletes the old default if one exists. To add additional external accounts without replacing the existing default for the currency, use the [bank account](/api#account_create_bank_account) or [card creation](/api#account_create_card) APIs. After you create an [Account Link](/api/account_links) or [Account Session](/api/account_sessions), this property can only be updated for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is application, which includes Custom accounts.



2096
2097
2098
# File 'lib/stripe/params/account_create_params.rb', line 2096

def 
  
end

#groupsObject

A hash of account group type to tokens. These are account groups this account should be added to.



2098
2099
2100
# File 'lib/stripe/params/account_create_params.rb', line 2098

def groups
  @groups
end

#individualObject

Information about the person represented by the account. This field is null unless business_type is set to individual. Once you create an [Account Link](/api/account_links) or [Account Session](/api/account_sessions), this property can only be updated for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is application, which includes Custom accounts.



2100
2101
2102
# File 'lib/stripe/params/account_create_params.rb', line 2100

def individual
  @individual
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.



2102
2103
2104
# File 'lib/stripe/params/account_create_params.rb', line 2102

def 
  
end

#settingsObject

Options for customizing how the account functions within Stripe.



2104
2105
2106
# File 'lib/stripe/params/account_create_params.rb', line 2104

def settings
  @settings
end

#tos_acceptanceObject

Details on the account’s acceptance of the [Stripe Services Agreement](/connect/updating-accounts#tos-acceptance). This property can only be updated for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is application, which includes Custom accounts. This property defaults to a full service agreement when empty.



2106
2107
2108
# File 'lib/stripe/params/account_create_params.rb', line 2106

def tos_acceptance
  @tos_acceptance
end

#typeObject

The type of Stripe account to create. May be one of custom, express or standard.



2108
2109
2110
# File 'lib/stripe/params/account_create_params.rb', line 2108

def type
  @type
end