Class: Stripe::AccountCreateParams::Capabilities::AlmaPayments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(requested: nil) ⇒ AlmaPayments

Returns a new instance of AlmaPayments.



189
190
191
# File 'lib/stripe/params/account_create_params.rb', line 189

def initialize(requested: nil)
  @requested = requested
end

Instance Attribute Details

#requestedObject

Passing true requests the capability for the account, if it is not already requested. A requested capability may not immediately become active. Any requirements to activate the capability are returned in the ‘requirements` arrays.



187
188
189
# File 'lib/stripe/params/account_create_params.rb', line 187

def requested
  @requested
end