Class: Stripe::AccountCreateParams::Capabilities::EpsPayments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(requested: nil) ⇒ EpsPayments

Returns a new instance of EpsPayments.



333
334
335
# File 'lib/stripe/params/account_create_params.rb', line 333

def initialize(requested: nil)
  @requested = requested
end

Instance Attribute Details

#requestedObject

Passing true requests the capability for the account, if it is not already requested. A requested capability may not immediately become active. Any requirements to activate the capability are returned in the ‘requirements` arrays.



331
332
333
# File 'lib/stripe/params/account_create_params.rb', line 331

def requested
  @requested
end