Class: Stripe::AccountCreateParams::Capabilities::IndiaInternationalPayments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(requested: nil) ⇒ IndiaInternationalPayments

Returns a new instance of IndiaInternationalPayments.



414
415
416
# File 'lib/stripe/params/account_create_params.rb', line 414

def initialize(requested: nil)
  @requested = requested
end

Instance Attribute Details

#requestedObject

Passing true requests the capability for the account, if it is not already requested. A requested capability may not immediately become active. Any requirements to activate the capability are returned in the ‘requirements` arrays.



412
413
414
# File 'lib/stripe/params/account_create_params.rb', line 412

def requested
  @requested
end