Class: Stripe::AccountCreateParams::Capabilities::KrCardPayments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(requested: nil) ⇒ KrCardPayments

Returns a new instance of KrCardPayments.



459
460
461
# File 'lib/stripe/params/account_create_params.rb', line 459

def initialize(requested: nil)
  @requested = requested
end

Instance Attribute Details

#requestedObject

Passing true requests the capability for the account, if it is not already requested. A requested capability may not immediately become active. Any requirements to activate the capability are returned in the ‘requirements` arrays.



457
458
459
# File 'lib/stripe/params/account_create_params.rb', line 457

def requested
  @requested
end