Class: Stripe::AccountCreateParams::Capabilities::MobilepayPayments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountCreateParams::Capabilities::MobilepayPayments
- Defined in:
- lib/stripe/params/account_create_params.rb
Instance Attribute Summary collapse
-
#requested ⇒ Object
Passing true requests the capability for the account, if it is not already requested.
Instance Method Summary collapse
-
#initialize(requested: nil) ⇒ MobilepayPayments
constructor
A new instance of MobilepayPayments.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(requested: nil) ⇒ MobilepayPayments
Returns a new instance of MobilepayPayments.
504 505 506 |
# File 'lib/stripe/params/account_create_params.rb', line 504 def initialize(requested: nil) @requested = requested end |
Instance Attribute Details
#requested ⇒ Object
Passing true requests the capability for the account, if it is not already requested. A requested capability may not immediately become active. Any requirements to activate the capability are returned in the ‘requirements` arrays.
502 503 504 |
# File 'lib/stripe/params/account_create_params.rb', line 502 def requested @requested end |