Class: Stripe::AccountCreateParams::Capabilities::P24Payments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(requested: nil) ⇒ P24Payments

Returns a new instance of P24Payments.



558
559
560
# File 'lib/stripe/params/account_create_params.rb', line 558

def initialize(requested: nil)
  @requested = requested
end

Instance Attribute Details

#requestedObject

Passing true requests the capability for the account, if it is not already requested. A requested capability may not immediately become active. Any requirements to activate the capability are returned in the ‘requirements` arrays.



556
557
558
# File 'lib/stripe/params/account_create_params.rb', line 556

def requested
  @requested
end