Class: Stripe::AccountCreateParams::Capabilities::RechnungPayments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(requested: nil) ⇒ RechnungPayments

Returns a new instance of RechnungPayments.



648
649
650
# File 'lib/stripe/params/account_create_params.rb', line 648

def initialize(requested: nil)
  @requested = requested
end

Instance Attribute Details

#requestedObject

Passing true requests the capability for the account, if it is not already requested. A requested capability may not immediately become active. Any requirements to activate the capability are returned in the ‘requirements` arrays.



646
647
648
# File 'lib/stripe/params/account_create_params.rb', line 646

def requested
  @requested
end