Class: Stripe::AccountCreateParams::Capabilities::SepaBankTransferPayments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountCreateParams::Capabilities::SepaBankTransferPayments
- Defined in:
- lib/stripe/params/account_create_params.rb
Instance Attribute Summary collapse
-
#requested ⇒ Object
Passing true requests the capability for the account, if it is not already requested.
Instance Method Summary collapse
-
#initialize(requested: nil) ⇒ SepaBankTransferPayments
constructor
A new instance of SepaBankTransferPayments.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(requested: nil) ⇒ SepaBankTransferPayments
Returns a new instance of SepaBankTransferPayments.
684 685 686 |
# File 'lib/stripe/params/account_create_params.rb', line 684 def initialize(requested: nil) @requested = requested end |
Instance Attribute Details
#requested ⇒ Object
Passing true requests the capability for the account, if it is not already requested. A requested capability may not immediately become active. Any requirements to activate the capability are returned in the ‘requirements` arrays.
682 683 684 |
# File 'lib/stripe/params/account_create_params.rb', line 682 def requested @requested end |