Class: Stripe::AccountCreateParams::Capabilities::UpiPayments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountCreateParams::Capabilities::UpiPayments
- Defined in:
- lib/stripe/params/account_create_params.rb
Instance Attribute Summary collapse
-
#requested ⇒ Object
Passing true requests the capability for the account, if it is not already requested.
Instance Method Summary collapse
-
#initialize(requested: nil) ⇒ UpiPayments
constructor
A new instance of UpiPayments.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(requested: nil) ⇒ UpiPayments
Returns a new instance of UpiPayments.
819 820 821 |
# File 'lib/stripe/params/account_create_params.rb', line 819 def initialize(requested: nil) @requested = requested end |
Instance Attribute Details
#requested ⇒ Object
Passing true requests the capability for the account, if it is not already requested. A requested capability may not immediately become active. Any requirements to activate the capability are returned in the ‘requirements` arrays.
817 818 819 |
# File 'lib/stripe/params/account_create_params.rb', line 817 def requested @requested end |