Class: Stripe::AccountCreateParams::Capabilities::ZipPayments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountCreateParams::Capabilities::ZipPayments
- Defined in:
- lib/stripe/params/account_create_params.rb
Instance Attribute Summary collapse
-
#requested ⇒ Object
Passing true requests the capability for the account, if it is not already requested.
Instance Method Summary collapse
-
#initialize(requested: nil) ⇒ ZipPayments
constructor
A new instance of ZipPayments.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(requested: nil) ⇒ ZipPayments
Returns a new instance of ZipPayments.
707 708 709 |
# File 'lib/stripe/params/account_create_params.rb', line 707 def initialize(requested: nil) @requested = requested end |
Instance Attribute Details
#requested ⇒ Object
Passing true requests the capability for the account, if it is not already requested. A requested capability may not immediately become active. Any requirements to activate the capability are returned in the requirements arrays.
705 706 707 |
# File 'lib/stripe/params/account_create_params.rb', line 705 def requested @requested end |