Class: Stripe::AccountCreateParams::Company

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/account_create_params.rb

Defined Under Namespace

Classes: Address, AddressKana, AddressKanji, AdministrativeAddress, DirectorshipDeclaration, OwnershipDeclaration, PrincipalPlaceOfBusiness, RegistrationDate, RepresentativeDeclaration, Verification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h

Constructor Details

#initialize(address: nil, address_kana: nil, address_kanji: nil, administrative_address: nil, directors_provided: nil, directorship_declaration: nil, executives_provided: nil, export_license_id: nil, export_purpose_code: nil, name: nil, name_kana: nil, name_kanji: nil, owners_provided: nil, ownership_declaration: nil, ownership_exemption_reason: nil, phone: nil, principal_place_of_business: nil, registration_date: nil, registration_number: nil, representative_declaration: nil, structure: nil, tax_id: nil, tax_id_registrar: nil, vat_id: nil, verification: nil) ⇒ Company

Returns a new instance of Company.



1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
1458
1459
1460
1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
1481
1482
1483
1484
1485
1486
1487
1488
1489
1490
# File 'lib/stripe/params/account_create_params.rb', line 1438

def initialize(
  address: nil,
  address_kana: nil,
  address_kanji: nil,
  administrative_address: nil,
  directors_provided: nil,
  directorship_declaration: nil,
  executives_provided: nil,
  export_license_id: nil,
  export_purpose_code: nil,
  name: nil,
  name_kana: nil,
  name_kanji: nil,
  owners_provided: nil,
  ownership_declaration: nil,
  ownership_exemption_reason: nil,
  phone: nil,
  principal_place_of_business: nil,
  registration_date: nil,
  registration_number: nil,
  representative_declaration: nil,
  structure: nil,
  tax_id: nil,
  tax_id_registrar: nil,
  vat_id: nil,
  verification: nil
)
  @address = address
  @address_kana = address_kana
  @address_kanji = address_kanji
  @administrative_address = administrative_address
  @directors_provided = directors_provided
  @directorship_declaration = directorship_declaration
  @executives_provided = executives_provided
  @export_license_id = export_license_id
  @export_purpose_code = export_purpose_code
  @name = name
  @name_kana = name_kana
  @name_kanji = name_kanji
  @owners_provided = owners_provided
  @ownership_declaration = ownership_declaration
  @ownership_exemption_reason = ownership_exemption_reason
  @phone = phone
  @principal_place_of_business = principal_place_of_business
  @registration_date = registration_date
  @registration_number = registration_number
  @representative_declaration = representative_declaration
  @structure = structure
  @tax_id = tax_id
  @tax_id_registrar = tax_id_registrar
  @vat_id = vat_id
  @verification = verification
end

Instance Attribute Details

#address ⇒ Object

The company's primary address.



1386
1387
1388
# File 'lib/stripe/params/account_create_params.rb', line 1386

def address
  @address
end

#address_kana ⇒ Object

The Kana variation of the company's primary address (Japan only).



1388
1389
1390
# File 'lib/stripe/params/account_create_params.rb', line 1388

def address_kana
  @address_kana
end

#address_kanji ⇒ Object

The Kanji variation of the company's primary address (Japan only).



1390
1391
1392
# File 'lib/stripe/params/account_create_params.rb', line 1390

def address_kanji
  @address_kanji
end

#administrative_address ⇒ Object

The location where the business is administered.



1392
1393
1394
# File 'lib/stripe/params/account_create_params.rb', line 1392

def administrative_address
  @administrative_address
end

#directors_provided ⇒ Object

Whether the company's directors have been provided. Set this Boolean to true after creating all the company's directors with the Persons API for accounts with a relationship.director requirement. This value is not automatically set to true after creating directors, so it needs to be updated to indicate all directors have been provided.



1394
1395
1396
# File 'lib/stripe/params/account_create_params.rb', line 1394

def directors_provided
  @directors_provided
end

#directorship_declaration ⇒ Object

This hash is used to attest that the directors information provided to Stripe is both current and correct.



1396
1397
1398
# File 'lib/stripe/params/account_create_params.rb', line 1396

def directorship_declaration
  @directorship_declaration
end

#executives_provided ⇒ Object

Whether the company's executives have been provided. Set this Boolean to true after creating all the company's executives with the Persons API for accounts with a relationship.executive requirement.



1398
1399
1400
# File 'lib/stripe/params/account_create_params.rb', line 1398

def executives_provided
  @executives_provided
end

#export_license_id ⇒ Object

The export license ID number of the company, also referred as Import Export Code (India only).



1400
1401
1402
# File 'lib/stripe/params/account_create_params.rb', line 1400

def export_license_id
  @export_license_id
end

#export_purpose_code ⇒ Object

The purpose code to use for export transactions (India only).



1402
1403
1404
# File 'lib/stripe/params/account_create_params.rb', line 1402

def export_purpose_code
  @export_purpose_code
end

#name ⇒ Object

The company's legal name.



1404
1405
1406
# File 'lib/stripe/params/account_create_params.rb', line 1404

def name
  @name
end

#name_kana ⇒ Object

The Kana variation of the company's legal name (Japan only).



1406
1407
1408
# File 'lib/stripe/params/account_create_params.rb', line 1406

def name_kana
  @name_kana
end

#name_kanji ⇒ Object

The Kanji variation of the company's legal name (Japan only).



1408
1409
1410
# File 'lib/stripe/params/account_create_params.rb', line 1408

def name_kanji
  @name_kanji
end

#owners_provided ⇒ Object

Whether the company's owners have been provided. Set this Boolean to true after creating all the company's owners with the Persons API for accounts with a relationship.owner requirement.



1410
1411
1412
# File 'lib/stripe/params/account_create_params.rb', line 1410

def owners_provided
  @owners_provided
end

#ownership_declaration ⇒ Object

This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.



1412
1413
1414
# File 'lib/stripe/params/account_create_params.rb', line 1412

def ownership_declaration
  @ownership_declaration
end

#ownership_exemption_reason ⇒ Object

This value is used to determine if a business is exempt from providing ultimate beneficial owners. See this support article and changelog for more details.



1414
1415
1416
# File 'lib/stripe/params/account_create_params.rb', line 1414

def ownership_exemption_reason
  @ownership_exemption_reason
end

#phone ⇒ Object

The company's phone number (used for verification).



1416
1417
1418
# File 'lib/stripe/params/account_create_params.rb', line 1416

def phone
  @phone
end

#principal_place_of_business ⇒ Object

The primary location where the business conducts operations.



1418
1419
1420
# File 'lib/stripe/params/account_create_params.rb', line 1418

def principal_place_of_business
  @principal_place_of_business
end

#registration_date ⇒ Object

When the business was incorporated or registered.



1420
1421
1422
# File 'lib/stripe/params/account_create_params.rb', line 1420

def registration_date
  @registration_date
end

#registration_number ⇒ Object

The identification number given to a company when it is registered or incorporated, if distinct from the identification number used for filing taxes. (Examples are the CIN for companies and LLP IN for partnerships in India, and the Company Registration Number in Hong Kong).



1422
1423
1424
# File 'lib/stripe/params/account_create_params.rb', line 1422

def registration_number
  @registration_number
end

#representative_declaration ⇒ Object

This hash is used to attest that the representative is authorized to act as the representative of their legal entity.



1424
1425
1426
# File 'lib/stripe/params/account_create_params.rb', line 1424

def representative_declaration
  @representative_declaration
end

#structure ⇒ Object

The category identifying the legal structure of the company or legal entity. See Business structure for more details. Pass an empty string to unset this value.



1426
1427
1428
# File 'lib/stripe/params/account_create_params.rb', line 1426

def structure
  @structure
end

#tax_id ⇒ Object

The business ID number of the company, as appropriate for the company’s country. (Examples are an Employer ID Number in the U.S., a Business Number in Canada, or a Company Number in the UK.)

Changing this value requires that the account re-accept the terms of service.



1430
1431
1432
# File 'lib/stripe/params/account_create_params.rb', line 1430

def tax_id
  @tax_id
end

#tax_id_registrar ⇒ Object

The jurisdiction in which the tax_id is registered (Germany-based companies only).



1432
1433
1434
# File 'lib/stripe/params/account_create_params.rb', line 1432

def tax_id_registrar
  @tax_id_registrar
end

#vat_id ⇒ Object

The VAT number of the company.



1434
1435
1436
# File 'lib/stripe/params/account_create_params.rb', line 1434

def vat_id
  @vat_id
end

#verification ⇒ Object

Information on the verification state of the company.



1436
1437
1438
# File 'lib/stripe/params/account_create_params.rb', line 1436

def verification
  @verification
end