Class: Stripe::AccountCreateParams::Company::DirectorshipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ DirectorshipDeclaration

Returns a new instance of DirectorshipDeclaration.



1240
1241
1242
1243
1244
# File 'lib/stripe/params/account_create_params.rb', line 1240

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the directorship declaration attestation was made.



1234
1235
1236
# File 'lib/stripe/params/account_create_params.rb', line 1234

def date
  @date
end

#ipObject

The IP address from which the directorship declaration attestation was made.



1236
1237
1238
# File 'lib/stripe/params/account_create_params.rb', line 1236

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the directorship declaration attestation was made.



1238
1239
1240
# File 'lib/stripe/params/account_create_params.rb', line 1238

def user_agent
  @user_agent
end