Class: Stripe::AccountCreateParams::Company::Verification::Document

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(back: nil, front: nil) ⇒ Document

Returns a new instance of Document.



1434
1435
1436
1437
# File 'lib/stripe/params/account_create_params.rb', line 1434

def initialize(back: nil, front: nil)
  @back = back
  @front = front
end

Instance Attribute Details

#backObject

The back of a document returned by a [file upload](api.stripe.com#create_file) with a ‘purpose` value of `additional_verification`. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.



1430
1431
1432
# File 'lib/stripe/params/account_create_params.rb', line 1430

def back
  @back
end

#frontObject

The front of a document returned by a [file upload](api.stripe.com#create_file) with a ‘purpose` value of `additional_verification`. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.



1432
1433
1434
# File 'lib/stripe/params/account_create_params.rb', line 1432

def front
  @front
end