Class: Stripe::AccountCreateParams::Controller::Dashboard
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountCreateParams::Controller::Dashboard
- Defined in:
- lib/stripe/params/account_create_params.rb
Instance Attribute Summary collapse
-
#type ⇒ Object
Whether this account should have access to the full Stripe Dashboard (‘full`), to the Express Dashboard (`express`), or to no Stripe-hosted dashboard (`none`).
Instance Method Summary collapse
-
#initialize(type: nil) ⇒ Dashboard
constructor
A new instance of Dashboard.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(type: nil) ⇒ Dashboard
Returns a new instance of Dashboard.
1545 1546 1547 |
# File 'lib/stripe/params/account_create_params.rb', line 1545 def initialize(type: nil) @type = type end |
Instance Attribute Details
#type ⇒ Object
Whether this account should have access to the full Stripe Dashboard (‘full`), to the Express Dashboard (`express`), or to no Stripe-hosted dashboard (`none`). Defaults to `full`.
1543 1544 1545 |
# File 'lib/stripe/params/account_create_params.rb', line 1543 def type @type end |