Class: Stripe::AccountCreateParams::Controller::StripeDashboard
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountCreateParams::Controller::StripeDashboard
- Defined in:
- lib/stripe/params/account_create_params.rb
Instance Attribute Summary collapse
-
#type ⇒ Object
Whether this account should have access to the full Stripe Dashboard (‘full`), to the Express Dashboard (`express`), or to no Stripe-hosted dashboard (`none`).
Instance Method Summary collapse
-
#initialize(type: nil) ⇒ StripeDashboard
constructor
A new instance of StripeDashboard.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(type: nil) ⇒ StripeDashboard
Returns a new instance of StripeDashboard.
1572 1573 1574 |
# File 'lib/stripe/params/account_create_params.rb', line 1572 def initialize(type: nil) @type = type end |
Instance Attribute Details
#type ⇒ Object
Whether this account should have access to the full Stripe Dashboard (‘full`), to the Express Dashboard (`express`), or to no Stripe-hosted dashboard (`none`). Defaults to `full`.
1570 1571 1572 |
# File 'lib/stripe/params/account_create_params.rb', line 1570 def type @type end |