Class: Stripe::AccountCreateParams::Documents::ProofOfRegistration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Defined Under Namespace

Classes: Signer

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(files: nil, signer: nil) ⇒ ProofOfRegistration

Returns a new instance of ProofOfRegistration.



1703
1704
1705
1706
# File 'lib/stripe/params/account_create_params.rb', line 1703

def initialize(files: nil, signer: nil)
  @files = files
  @signer = signer
end

Instance Attribute Details

#filesObject

One or more document ids returned by a [file upload](api.stripe.com#create_file) with a ‘purpose` value of `account_requirement`.



1699
1700
1701
# File 'lib/stripe/params/account_create_params.rb', line 1699

def files
  @files
end

#signerObject

Information regarding the person signing the document if applicable.



1701
1702
1703
# File 'lib/stripe/params/account_create_params.rb', line 1701

def signer
  @signer
end