Class: Stripe::AccountCreateParams::Documents::ProofOfRegistration::Signer
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountCreateParams::Documents::ProofOfRegistration::Signer
- Defined in:
- lib/stripe/params/account_create_params.rb
Instance Attribute Summary collapse
-
#person ⇒ Object
The token of the person signing the document, if applicable.
Instance Method Summary collapse
-
#initialize(person: nil) ⇒ Signer
constructor
A new instance of Signer.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(person: nil) ⇒ Signer
1439 1440 1441 |
# File 'lib/stripe/params/account_create_params.rb', line 1439 def initialize(person: nil) @person = person end |
Instance Attribute Details
#person ⇒ Object
The token of the person signing the document, if applicable.
1437 1438 1439 |
# File 'lib/stripe/params/account_create_params.rb', line 1437 def person @person end |