Class: Stripe::AccountCreateParams::Documents::ProofOfUltimateBeneficialOwnership

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Defined Under Namespace

Classes: Signer

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(files: nil, signer: nil) ⇒ ProofOfUltimateBeneficialOwnership

Returns a new instance of ProofOfUltimateBeneficialOwnership.



1801
1802
1803
1804
# File 'lib/stripe/params/account_create_params.rb', line 1801

def initialize(files: nil, signer: nil)
  @files = files
  @signer = signer
end

Instance Attribute Details

#filesObject

One or more document ids returned by a file upload with a purpose value of account_requirement.



1797
1798
1799
# File 'lib/stripe/params/account_create_params.rb', line 1797

def files
  @files
end

#signerObject

Information regarding the person signing the document if applicable.



1799
1800
1801
# File 'lib/stripe/params/account_create_params.rb', line 1799

def signer
  @signer
end