Class: Stripe::AccountCreateParams::Individual::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship

Returns a new instance of Relationship.



2044
2045
2046
2047
2048
2049
2050
2051
2052
2053
2054
2055
2056
# File 'lib/stripe/params/account_create_params.rb', line 2044

def initialize(
  director: nil,
  executive: nil,
  owner: nil,
  percent_ownership: nil,
  title: nil
)
  @director = director
  @executive = executive
  @owner = owner
  @percent_ownership = percent_ownership
  @title = title
end

Instance Attribute Details

#directorObject

Whether the person is a director of the account's legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



2034
2035
2036
# File 'lib/stripe/params/account_create_params.rb', line 2034

def director
  @director
end

#executiveObject

Whether the person has significant responsibility to control, manage, or direct the organization.



2036
2037
2038
# File 'lib/stripe/params/account_create_params.rb', line 2036

def executive
  @executive
end

#ownerObject

Whether the person is an owner of the account’s legal entity.



2038
2039
2040
# File 'lib/stripe/params/account_create_params.rb', line 2038

def owner
  @owner
end

#percent_ownershipObject

The percent owned by the person of the account's legal entity.



2040
2041
2042
# File 'lib/stripe/params/account_create_params.rb', line 2040

def percent_ownership
  @percent_ownership
end

#titleObject

The person's title (e.g., CEO, Support Engineer).



2042
2043
2044
# File 'lib/stripe/params/account_create_params.rb', line 2042

def title
  @title
end