Class: Stripe::AccountCreateParams::Individual::Verification::Document
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountCreateParams::Individual::Verification::Document
- Defined in:
- lib/stripe/params/account_create_params.rb
Instance Attribute Summary collapse
-
#back ⇒ Object
The back of an ID returned by a file upload with a
purposevalue ofidentity_document. -
#front ⇒ Object
The front of an ID returned by a file upload with a
purposevalue ofidentity_document.
Instance Method Summary collapse
-
#initialize(back: nil, front: nil) ⇒ Document
constructor
A new instance of Document.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(back: nil, front: nil) ⇒ Document
Returns a new instance of Document.
1818 1819 1820 1821 |
# File 'lib/stripe/params/account_create_params.rb', line 1818 def initialize(back: nil, front: nil) @back = back @front = front end |
Instance Attribute Details
#back ⇒ Object
The back of an ID returned by a file upload with a purpose value of identity_document. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.
1814 1815 1816 |
# File 'lib/stripe/params/account_create_params.rb', line 1814 def back @back end |
#front ⇒ Object
The front of an ID returned by a file upload with a purpose value of identity_document. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.
1816 1817 1818 |
# File 'lib/stripe/params/account_create_params.rb', line 1816 def front @front end |