Class: Stripe::AccountCreateParams::Settings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountCreateParams::Settings
- Defined in:
- lib/stripe/params/account_create_params.rb
Defined Under Namespace
Classes: BacsDebitPayments, BankBcaOnboarding, Branding, Capital, CardIssuing, CardPayments, Invoices, Payments, Payouts, PaypayPayments, SmartDisputes, TaxForms, Treasury, WechatPayPayments
Instance Attribute Summary collapse
-
#bacs_debit_payments ⇒ Object
Settings specific to Bacs Direct Debit.
-
#bank_bca_onboarding ⇒ Object
Settings specific to bank BCA onboarding for Indonesia bank transfers payments method.
-
#branding ⇒ Object
Settings used to apply the account's branding to email receipts, invoices, Checkout, and other products.
-
#capital ⇒ Object
Settings specific to the account's use of the Capital product.
-
#card_issuing ⇒ Object
Settings specific to the account's use of the Card Issuing product.
-
#card_payments ⇒ Object
Settings specific to card charging on the account.
-
#invoices ⇒ Object
Settings specific to the account’s use of Invoices.
-
#payments ⇒ Object
Settings that apply across payment methods for charging on the account.
-
#payouts ⇒ Object
Settings specific to the account's payouts.
-
#paypay_payments ⇒ Object
Settings specific to the PayPay payments method.
-
#smart_disputes ⇒ Object
Settings specific to the account's use of Smart Disputes.
-
#tax_forms ⇒ Object
Settings specific to the account's tax forms.
-
#treasury ⇒ Object
Settings specific to the account's Treasury FinancialAccounts.
-
#wechat_pay_payments ⇒ Object
Settings specific to the WeChat Pay payments method.
Instance Method Summary collapse
-
#initialize(bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, paypay_payments: nil, smart_disputes: nil, tax_forms: nil, treasury: nil, wechat_pay_payments: nil) ⇒ Settings
constructor
A new instance of Settings.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, paypay_payments: nil, smart_disputes: nil, tax_forms: nil, treasury: nil, wechat_pay_payments: nil) ⇒ Settings
Returns a new instance of Settings.
2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 2604 2605 2606 2607 2608 2609 2610 2611 2612 2613 2614 |
# File 'lib/stripe/params/account_create_params.rb', line 2584 def initialize( bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, paypay_payments: nil, smart_disputes: nil, tax_forms: nil, treasury: nil, wechat_pay_payments: nil ) @bacs_debit_payments = bacs_debit_payments @bank_bca_onboarding = bank_bca_onboarding @branding = branding @capital = capital @card_issuing = card_issuing @card_payments = card_payments @invoices = invoices @payments = payments @payouts = payouts @paypay_payments = paypay_payments @smart_disputes = smart_disputes @tax_forms = tax_forms @treasury = treasury @wechat_pay_payments = wechat_pay_payments end |
Instance Attribute Details
#bacs_debit_payments ⇒ Object
Settings specific to Bacs Direct Debit.
2556 2557 2558 |
# File 'lib/stripe/params/account_create_params.rb', line 2556 def bacs_debit_payments @bacs_debit_payments end |
#bank_bca_onboarding ⇒ Object
Settings specific to bank BCA onboarding for Indonesia bank transfers payments method.
2558 2559 2560 |
# File 'lib/stripe/params/account_create_params.rb', line 2558 def bank_bca_onboarding @bank_bca_onboarding end |
#branding ⇒ Object
Settings used to apply the account's branding to email receipts, invoices, Checkout, and other products.
2560 2561 2562 |
# File 'lib/stripe/params/account_create_params.rb', line 2560 def branding @branding end |
#capital ⇒ Object
Settings specific to the account's use of the Capital product.
2562 2563 2564 |
# File 'lib/stripe/params/account_create_params.rb', line 2562 def capital @capital end |
#card_issuing ⇒ Object
Settings specific to the account's use of the Card Issuing product.
2564 2565 2566 |
# File 'lib/stripe/params/account_create_params.rb', line 2564 def card_issuing @card_issuing end |
#card_payments ⇒ Object
Settings specific to card charging on the account.
2566 2567 2568 |
# File 'lib/stripe/params/account_create_params.rb', line 2566 def card_payments @card_payments end |
#invoices ⇒ Object
Settings specific to the account’s use of Invoices.
2568 2569 2570 |
# File 'lib/stripe/params/account_create_params.rb', line 2568 def invoices @invoices end |
#payments ⇒ Object
Settings that apply across payment methods for charging on the account.
2570 2571 2572 |
# File 'lib/stripe/params/account_create_params.rb', line 2570 def payments @payments end |
#payouts ⇒ Object
Settings specific to the account's payouts.
2572 2573 2574 |
# File 'lib/stripe/params/account_create_params.rb', line 2572 def payouts @payouts end |
#paypay_payments ⇒ Object
Settings specific to the PayPay payments method.
2574 2575 2576 |
# File 'lib/stripe/params/account_create_params.rb', line 2574 def paypay_payments @paypay_payments end |
#smart_disputes ⇒ Object
Settings specific to the account's use of Smart Disputes.
2576 2577 2578 |
# File 'lib/stripe/params/account_create_params.rb', line 2576 def smart_disputes @smart_disputes end |
#tax_forms ⇒ Object
Settings specific to the account's tax forms.
2578 2579 2580 |
# File 'lib/stripe/params/account_create_params.rb', line 2578 def tax_forms @tax_forms end |
#treasury ⇒ Object
Settings specific to the account's Treasury FinancialAccounts.
2580 2581 2582 |
# File 'lib/stripe/params/account_create_params.rb', line 2580 def treasury @treasury end |
#wechat_pay_payments ⇒ Object
Settings specific to the WeChat Pay payments method.
2582 2583 2584 |
# File 'lib/stripe/params/account_create_params.rb', line 2582 def wechat_pay_payments @wechat_pay_payments end |