Class: Stripe::AccountCreateParams::Settings::Branding

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil) ⇒ Branding

Returns a new instance of Branding.



2242
2243
2244
2245
2246
2247
# File 'lib/stripe/params/account_create_params.rb', line 2242

def initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil)
  @icon = icon
  @logo = 
  @primary_color = primary_color
  @secondary_color = secondary_color
end

Instance Attribute Details

#iconObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) An icon for the account. Must be square and at least 128px x 128px.



2234
2235
2236
# File 'lib/stripe/params/account_create_params.rb', line 2234

def icon
  @icon
end

#logoObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) A logo for the account that will be used in Checkout instead of the icon and without the account’s name next to it if provided. Must be at least 128px x 128px.



2236
2237
2238
# File 'lib/stripe/params/account_create_params.rb', line 2236

def 
  @logo
end

#primary_colorObject

A CSS hex color value representing the primary branding color for this account.



2238
2239
2240
# File 'lib/stripe/params/account_create_params.rb', line 2238

def primary_color
  @primary_color
end

#secondary_colorObject

A CSS hex color value representing the secondary branding color for this account.



2240
2241
2242
# File 'lib/stripe/params/account_create_params.rb', line 2240

def secondary_color
  @secondary_color
end