Class: Stripe::AccountCreateParams::Settings::CardIssuing::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



1868
1869
1870
1871
1872
# File 'lib/stripe/params/account_create_params.rb', line 1868

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



1862
1863
1864
# File 'lib/stripe/params/account_create_params.rb', line 1862

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



1864
1865
1866
# File 'lib/stripe/params/account_create_params.rb', line 1864

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



1866
1867
1868
# File 'lib/stripe/params/account_create_params.rb', line 1866

def user_agent
  @user_agent
end