Class: Stripe::AccountCreateParams::Settings::CardPayments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Defined Under Namespace

Classes: DeclineOn

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h

Constructor Details

#initialize(decline_on: nil, statement_descriptor_prefix: nil, statement_descriptor_prefix_kana: nil, statement_descriptor_prefix_kanji: nil) ⇒ CardPayments

Returns a new instance of CardPayments.



2046
2047
2048
2049
2050
2051
2052
2053
2054
2055
2056
# File 'lib/stripe/params/account_create_params.rb', line 2046

def initialize(
  decline_on: nil,
  statement_descriptor_prefix: nil,
  statement_descriptor_prefix_kana: nil,
  statement_descriptor_prefix_kanji: nil
)
  @decline_on = decline_on
  @statement_descriptor_prefix = statement_descriptor_prefix
  @statement_descriptor_prefix_kana = statement_descriptor_prefix_kana
  @statement_descriptor_prefix_kanji = statement_descriptor_prefix_kanji
end

Instance Attribute Details

#decline_on ⇒ Object

Automatically declines certain charge types regardless of whether the card issuer accepted or declined the charge.



2038
2039
2040
# File 'lib/stripe/params/account_create_params.rb', line 2038

def decline_on
  @decline_on
end

#statement_descriptor_prefix ⇒ Object

The default text that appears on credit card statements when a charge is made. This field prefixes any dynamic statement_descriptor specified on the charge. statement_descriptor_prefix is useful for maximizing descriptor space for the dynamic portion.



2040
2041
2042
# File 'lib/stripe/params/account_create_params.rb', line 2040

def statement_descriptor_prefix
  @statement_descriptor_prefix
end

#statement_descriptor_prefix_kana ⇒ Object

The Kana variation of the default text that appears on credit card statements when a charge is made (Japan only). This field prefixes any dynamic statement_descriptor_suffix_kana specified on the charge. statement_descriptor_prefix_kana is useful for maximizing descriptor space for the dynamic portion.



2042
2043
2044
# File 'lib/stripe/params/account_create_params.rb', line 2042

def statement_descriptor_prefix_kana
  @statement_descriptor_prefix_kana
end

#statement_descriptor_prefix_kanji ⇒ Object

The Kanji variation of the default text that appears on credit card statements when a charge is made (Japan only). This field prefixes any dynamic statement_descriptor_suffix_kanji specified on the charge. statement_descriptor_prefix_kanji is useful for maximizing descriptor space for the dynamic portion.



2044
2045
2046
# File 'lib/stripe/params/account_create_params.rb', line 2044

def statement_descriptor_prefix_kanji
  @statement_descriptor_prefix_kanji
end