Class: Stripe::AccountCreateParams::Settings::Invoices

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(hosted_payment_method_save: nil) ⇒ Invoices

Returns a new instance of Invoices.



2211
2212
2213
# File 'lib/stripe/params/account_create_params.rb', line 2211

def initialize(hosted_payment_method_save: nil)
  @hosted_payment_method_save = hosted_payment_method_save
end

Instance Attribute Details

#hosted_payment_method_saveObject

Whether to save the payment method after a payment is completed for a one-time invoice or a subscription invoice when the customer already has a default payment method on the hosted invoice page.



2209
2210
2211
# File 'lib/stripe/params/account_create_params.rb', line 2209

def hosted_payment_method_save
  @hosted_payment_method_save
end