Class: Stripe::AccountCreateParams::Settings::Payments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h

Constructor Details

#initialize(statement_descriptor: nil, statement_descriptor_kana: nil, statement_descriptor_kanji: nil) ⇒ Payments

Returns a new instance of Payments.



2076
2077
2078
2079
2080
2081
2082
2083
2084
# File 'lib/stripe/params/account_create_params.rb', line 2076

def initialize(
  statement_descriptor: nil,
  statement_descriptor_kana: nil,
  statement_descriptor_kanji: nil
)
  @statement_descriptor = statement_descriptor
  @statement_descriptor_kana = statement_descriptor_kana
  @statement_descriptor_kanji = statement_descriptor_kanji
end

Instance Attribute Details

#statement_descriptor ⇒ Object

The default text that appears on statements for non-card charges outside of Japan. For card charges, if you don't set a statement_descriptor_prefix, this text is also used as the statement descriptor prefix. In that case, if concatenating the statement descriptor suffix causes the combined statement descriptor to exceed 22 characters, we truncate the statement_descriptor text to limit the full descriptor to 22 characters. For more information about statement descriptors and their requirements, see the account settings documentation.



2070
2071
2072
# File 'lib/stripe/params/account_create_params.rb', line 2070

def statement_descriptor
  @statement_descriptor
end

#statement_descriptor_kana ⇒ Object

The Kana variation of statement_descriptor used for charges in Japan. Japanese statement descriptors have special requirements.



2072
2073
2074
# File 'lib/stripe/params/account_create_params.rb', line 2072

def statement_descriptor_kana
  @statement_descriptor_kana
end

#statement_descriptor_kanji ⇒ Object

The Kanji variation of statement_descriptor used for charges in Japan. Japanese statement descriptors have special requirements.



2074
2075
2076
# File 'lib/stripe/params/account_create_params.rb', line 2074

def statement_descriptor_kanji
  @statement_descriptor_kanji
end