Class: Stripe::AccountCreateParams::Settings::PaypayPayments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Defined Under Namespace

Classes: Site

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(additional_files: nil, goods_type: nil, site: nil) ⇒ PaypayPayments

Returns a new instance of PaypayPayments.



2491
2492
2493
2494
2495
# File 'lib/stripe/params/account_create_params.rb', line 2491

def initialize(additional_files: nil, goods_type: nil, site: nil)
  @additional_files = additional_files
  @goods_type = goods_type
  @site = site
end

Instance Attribute Details

#additional_filesObject

Additional files that are required to support the onboarding process of your business.



2485
2486
2487
# File 'lib/stripe/params/account_create_params.rb', line 2485

def additional_files
  @additional_files
end

#goods_typeObject

The type of goods your business sells. Use digital_content if you sell digital content. Use other for all other types of goods or services.



2487
2488
2489
# File 'lib/stripe/params/account_create_params.rb', line 2487

def goods_type
  @goods_type
end

#siteObject

Details regarding your business's website.



2489
2490
2491
# File 'lib/stripe/params/account_create_params.rb', line 2489

def site
  @site
end