Class: Stripe::AccountCreateParams::Settings::PaypayPayments::Site::Restricted
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountCreateParams::Settings::PaypayPayments::Site::Restricted
- Defined in:
- lib/stripe/params/account_create_params.rb
Instance Attribute Summary collapse
-
#payment_flow_file ⇒ Object
The file explaining the payment flow for your business.
Instance Method Summary collapse
-
#initialize(payment_flow_file: nil) ⇒ Restricted
constructor
A new instance of Restricted.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(payment_flow_file: nil) ⇒ Restricted
Returns a new instance of Restricted.
2304 2305 2306 |
# File 'lib/stripe/params/account_create_params.rb', line 2304 def initialize(payment_flow_file: nil) @payment_flow_file = payment_flow_file end |
Instance Attribute Details
#payment_flow_file ⇒ Object
The file explaining the payment flow for your business.
2302 2303 2304 |
# File 'lib/stripe/params/account_create_params.rb', line 2302 def payment_flow_file @payment_flow_file end |