Class: Stripe::AccountCreateParams::Settings::Treasury::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



2450
2451
2452
2453
2454
# File 'lib/stripe/params/account_create_params.rb', line 2450

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



2444
2445
2446
# File 'lib/stripe/params/account_create_params.rb', line 2444

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



2446
2447
2448
# File 'lib/stripe/params/account_create_params.rb', line 2446

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



2448
2449
2450
# File 'lib/stripe/params/account_create_params.rb', line 2448

def user_agent
  @user_agent
end