Class: Stripe::AccountExternalAccountService::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_external_account_service.rb

Defined Under Namespace

Classes: BankAccount, Card, CardToken

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(default_for_currency: nil, expand: nil, external_account: nil, metadata: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



291
292
293
294
295
296
# File 'lib/stripe/services/account_external_account_service.rb', line 291

def initialize(default_for_currency: nil, expand: nil, external_account: nil, metadata: nil)
  @default_for_currency = default_for_currency
  @expand = expand
  @external_account = 
  @metadata = 
end

Instance Attribute Details

#default_for_currencyObject

When set to true, or if this is the first external account added in this currency, this account becomes the default external account for its currency.



280
281
282
# File 'lib/stripe/services/account_external_account_service.rb', line 280

def default_for_currency
  @default_for_currency
end

#expandObject

Specifies which fields in the response should be expanded.



283
284
285
# File 'lib/stripe/services/account_external_account_service.rb', line 283

def expand
  @expand
end

#external_accountObject

Please refer to full [documentation](stripe.com/docs/api) instead.



286
287
288
# File 'lib/stripe/services/account_external_account_service.rb', line 286

def 
  @external_account
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



289
290
291
# File 'lib/stripe/services/account_external_account_service.rb', line 289

def 
  @metadata
end