Class: Stripe::AccountLink

Inherits:
APIResource show all
Extended by:
Stripe::APIOperations::Create
Defined in:
lib/stripe/resources/account_link.rb

Overview

Account Links are the means by which a Connect platform grants a connected account permission to access Stripe-hosted applications, such as Connect Onboarding.

Related guide: [Connect Onboarding](stripe.com/docs/connect/custom/hosted-onboarding)

Defined Under Namespace

Classes: CreateParams

Constant Summary collapse

OBJECT_NAME =
"account_link"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods included from Stripe::APIOperations::Create

create

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from Stripe::APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



70
71
72
# File 'lib/stripe/resources/account_link.rb', line 70

def created
  @created
end

#expires_atObject (readonly)

The timestamp at which this account link will expire.



73
74
75
# File 'lib/stripe/resources/account_link.rb', line 73

def expires_at
  @expires_at
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



76
77
78
# File 'lib/stripe/resources/account_link.rb', line 76

def object
  @object
end

#urlObject (readonly)

The URL for the account link.



79
80
81
# File 'lib/stripe/resources/account_link.rb', line 79

def url
  @url
end

Class Method Details

.create(params = {}, opts = {}) ⇒ Object

Creates an AccountLink object that includes a single-use Stripe URL that the platform can redirect their user to in order to take them through the Connect Onboarding flow.



82
83
84
# File 'lib/stripe/resources/account_link.rb', line 82

def self.create(params = {}, opts = {})
  request_stripe_object(method: :post, path: "/v1/account_links", params: params, opts: opts)
end

.object_nameObject



13
14
15
# File 'lib/stripe/resources/account_link.rb', line 13

def self.object_name
  "account_link"
end