Class: Stripe::AccountLinkService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountLinkService::CreateParams
- Defined in:
- lib/stripe/services/account_link_service.rb
Defined Under Namespace
Classes: CollectionOptions
Instance Attribute Summary collapse
-
#account ⇒ Object
The identifier of the account to create an account link for.
-
#collect ⇒ Object
The collect parameter is deprecated.
-
#collection_options ⇒ Object
Specifies the requirements that Stripe collects from connected accounts in the Connect Onboarding flow.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#refresh_url ⇒ Object
The URL the user will be redirected to if the account link is expired, has been previously-visited, or is otherwise invalid.
-
#return_url ⇒ Object
The URL that the user will be redirected to upon leaving or completing the linked flow.
-
#type ⇒ Object
The type of account link the user is requesting.
Instance Method Summary collapse
-
#initialize(account: nil, collect: nil, collection_options: nil, expand: nil, refresh_url: nil, return_url: nil, type: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(account: nil, collect: nil, collection_options: nil, expand: nil, refresh_url: nil, return_url: nil, type: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 |
# File 'lib/stripe/services/account_link_service.rb', line 33 def initialize( account: nil, collect: nil, collection_options: nil, expand: nil, refresh_url: nil, return_url: nil, type: nil ) @account = account @collect = collect @collection_options = @expand = @refresh_url = refresh_url @return_url = return_url @type = type end |
Instance Attribute Details
#account ⇒ Object
The identifier of the account to create an account link for.
19 20 21 |
# File 'lib/stripe/services/account_link_service.rb', line 19 def account @account end |
#collect ⇒ Object
The collect parameter is deprecated. Use ‘collection_options` instead.
21 22 23 |
# File 'lib/stripe/services/account_link_service.rb', line 21 def collect @collect end |
#collection_options ⇒ Object
Specifies the requirements that Stripe collects from connected accounts in the Connect Onboarding flow.
23 24 25 |
# File 'lib/stripe/services/account_link_service.rb', line 23 def @collection_options end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
25 26 27 |
# File 'lib/stripe/services/account_link_service.rb', line 25 def @expand end |
#refresh_url ⇒ Object
The URL the user will be redirected to if the account link is expired, has been previously-visited, or is otherwise invalid. The URL you specify should attempt to generate a new account link with the same parameters used to create the original account link, then redirect the user to the new account link’s URL so they can continue with Connect Onboarding. If a new account link cannot be generated or the redirect fails you should display a useful error to the user.
27 28 29 |
# File 'lib/stripe/services/account_link_service.rb', line 27 def refresh_url @refresh_url end |
#return_url ⇒ Object
The URL that the user will be redirected to upon leaving or completing the linked flow.
29 30 31 |
# File 'lib/stripe/services/account_link_service.rb', line 29 def return_url @return_url end |
#type ⇒ Object
The type of account link the user is requesting. Possible values are ‘account_onboarding` or `account_update`.
31 32 33 |
# File 'lib/stripe/services/account_link_service.rb', line 31 def type @type end |