Class: Stripe::AccountNotice::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/account_notice.rb

Defined Under Namespace

Classes: Email

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, expand: nil, metadata: nil, sent_at: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



96
97
98
99
100
101
# File 'lib/stripe/resources/account_notice.rb', line 96

def initialize(email: nil, expand: nil, metadata: nil, sent_at: nil)
  @email = email
  @expand = expand
  @metadata = 
  @sent_at = sent_at
end

Instance Attribute Details

#emailObject

Information about the email you sent.



88
89
90
# File 'lib/stripe/resources/account_notice.rb', line 88

def email
  @email
end

#expandObject

Specifies which fields in the response should be expanded.



90
91
92
# File 'lib/stripe/resources/account_notice.rb', line 90

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



92
93
94
# File 'lib/stripe/resources/account_notice.rb', line 92

def 
  @metadata
end

#sent_atObject

Date when you sent the notice.



94
95
96
# File 'lib/stripe/resources/account_notice.rb', line 94

def sent_at
  @sent_at
end