Class: Stripe::AccountNoticeUpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/account_notice_update_params.rb

Defined Under Namespace

Classes: Email

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(email: nil, expand: nil, metadata: nil, sent_at: nil) ⇒ AccountNoticeUpdateParams

Returns a new instance of AccountNoticeUpdateParams.



29
30
31
32
33
34
# File 'lib/stripe/params/account_notice_update_params.rb', line 29

def initialize(email: nil, expand: nil, metadata: nil, sent_at: nil)
  @email = email
  @expand = expand
  @metadata = 
  @sent_at = sent_at
end

Instance Attribute Details

#emailObject

Information about the email you sent.



21
22
23
# File 'lib/stripe/params/account_notice_update_params.rb', line 21

def email
  @email
end

#expandObject

Specifies which fields in the response should be expanded.



23
24
25
# File 'lib/stripe/params/account_notice_update_params.rb', line 23

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



25
26
27
# File 'lib/stripe/params/account_notice_update_params.rb', line 25

def 
  @metadata
end

#sent_atObject

Date when you sent the notice.



27
28
29
# File 'lib/stripe/params/account_notice_update_params.rb', line 27

def sent_at
  @sent_at
end