Class: Stripe::AccountPersonCreateParams::Documents::Passport
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountPersonCreateParams::Documents::Passport
- Defined in:
- lib/stripe/params/account_person_create_params.rb
Instance Attribute Summary collapse
-
#files ⇒ Object
One or more document ids returned by a file upload with a
purposevalue ofaccount_requirement.
Instance Method Summary collapse
-
#initialize(files: nil) ⇒ Passport
constructor
A new instance of Passport.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(files: nil) ⇒ Passport
Returns a new instance of Passport.
176 177 178 |
# File 'lib/stripe/params/account_person_create_params.rb', line 176 def initialize(files: nil) @files = files end |
Instance Attribute Details
#files ⇒ Object
One or more document ids returned by a file upload with a purpose value of account_requirement.
174 175 176 |
# File 'lib/stripe/params/account_person_create_params.rb', line 174 def files @files end |