Class: Stripe::AccountPersonService::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_person_service.rb

Defined Under Namespace

Classes: AdditionalTosAcceptances, Address, AddressKana, AddressKanji, Dob, Documents, RegisteredAddress, Relationship, UsCfpbData, Verification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(additional_tos_acceptances: nil, address: nil, address_kana: nil, address_kanji: nil, dob: nil, documents: nil, email: nil, expand: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, nationality: nil, person_token: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, us_cfpb_data: nil, verification: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



901
902
903
904
905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
933
934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
951
952
953
954
955
956
957
958
959
960
961
# File 'lib/stripe/services/account_person_service.rb', line 901

def initialize(
  additional_tos_acceptances: nil,
  address: nil,
  address_kana: nil,
  address_kanji: nil,
  dob: nil,
  documents: nil,
  email: nil,
  expand: nil,
  first_name: nil,
  first_name_kana: nil,
  first_name_kanji: nil,
  full_name_aliases: nil,
  gender: nil,
  id_number: nil,
  id_number_secondary: nil,
  last_name: nil,
  last_name_kana: nil,
  last_name_kanji: nil,
  maiden_name: nil,
  metadata: nil,
  nationality: nil,
  person_token: nil,
  phone: nil,
  political_exposure: nil,
  registered_address: nil,
  relationship: nil,
  ssn_last_4: nil,
  us_cfpb_data: nil,
  verification: nil
)
  @additional_tos_acceptances = additional_tos_acceptances
  @address = address
  @address_kana = address_kana
  @address_kanji = address_kanji
  @dob = dob
  @documents = documents
  @email = email
  @expand = expand
  @first_name = first_name
  @first_name_kana = first_name_kana
  @first_name_kanji = first_name_kanji
  @full_name_aliases = full_name_aliases
  @gender = gender
  @id_number = id_number
  @id_number_secondary = id_number_secondary
  @last_name = last_name
  @last_name_kana = last_name_kana
  @last_name_kanji = last_name_kanji
  @maiden_name = maiden_name
  @metadata = 
  @nationality = nationality
  @person_token = person_token
  @phone = phone
  @political_exposure = political_exposure
  @registered_address = registered_address
  @relationship = relationship
  @ssn_last_4 = ssn_last_4
  @us_cfpb_data = us_cfpb_data
  @verification = verification
end

Instance Attribute Details

#additional_tos_acceptancesObject

Details on the legal guardian’s or authorizer’s acceptance of the required Stripe agreements.



843
844
845
# File 'lib/stripe/services/account_person_service.rb', line 843

def additional_tos_acceptances
  @additional_tos_acceptances
end

#addressObject

The person’s address.



845
846
847
# File 'lib/stripe/services/account_person_service.rb', line 845

def address
  @address
end

#address_kanaObject

The Kana variation of the person’s address (Japan only).



847
848
849
# File 'lib/stripe/services/account_person_service.rb', line 847

def address_kana
  @address_kana
end

#address_kanjiObject

The Kanji variation of the person’s address (Japan only).



849
850
851
# File 'lib/stripe/services/account_person_service.rb', line 849

def address_kanji
  @address_kanji
end

#dobObject

The person’s date of birth.



851
852
853
# File 'lib/stripe/services/account_person_service.rb', line 851

def dob
  @dob
end

#documentsObject

Documents that may be submitted to satisfy various informational requests.



853
854
855
# File 'lib/stripe/services/account_person_service.rb', line 853

def documents
  @documents
end

#emailObject

The person’s email address.



855
856
857
# File 'lib/stripe/services/account_person_service.rb', line 855

def email
  @email
end

#expandObject

Specifies which fields in the response should be expanded.



857
858
859
# File 'lib/stripe/services/account_person_service.rb', line 857

def expand
  @expand
end

#first_nameObject

The person’s first name.



859
860
861
# File 'lib/stripe/services/account_person_service.rb', line 859

def first_name
  @first_name
end

#first_name_kanaObject

The Kana variation of the person’s first name (Japan only).



861
862
863
# File 'lib/stripe/services/account_person_service.rb', line 861

def first_name_kana
  @first_name_kana
end

#first_name_kanjiObject

The Kanji variation of the person’s first name (Japan only).



863
864
865
# File 'lib/stripe/services/account_person_service.rb', line 863

def first_name_kanji
  @first_name_kanji
end

#full_name_aliasesObject

A list of alternate names or aliases that the person is known by.



865
866
867
# File 'lib/stripe/services/account_person_service.rb', line 865

def full_name_aliases
  @full_name_aliases
end

#genderObject

The person’s gender (International regulations require either “male” or “female”).



867
868
869
# File 'lib/stripe/services/account_person_service.rb', line 867

def gender
  @gender
end

#id_numberObject

The person’s ID number, as appropriate for their country. For example, a social security number in the U.S., social insurance number in Canada, etc. Instead of the number itself, you can also provide a [PII token provided by Stripe.js](docs.stripe.com/js/tokens/create_token?type=pii).



869
870
871
# File 'lib/stripe/services/account_person_service.rb', line 869

def id_number
  @id_number
end

#id_number_secondaryObject

The person’s secondary ID number, as appropriate for their country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a [PII token provided by Stripe.js](docs.stripe.com/js/tokens/create_token?type=pii).



871
872
873
# File 'lib/stripe/services/account_person_service.rb', line 871

def id_number_secondary
  @id_number_secondary
end

#last_nameObject

The person’s last name.



873
874
875
# File 'lib/stripe/services/account_person_service.rb', line 873

def last_name
  @last_name
end

#last_name_kanaObject

The Kana variation of the person’s last name (Japan only).



875
876
877
# File 'lib/stripe/services/account_person_service.rb', line 875

def last_name_kana
  @last_name_kana
end

#last_name_kanjiObject

The Kanji variation of the person’s last name (Japan only).



877
878
879
# File 'lib/stripe/services/account_person_service.rb', line 877

def last_name_kanji
  @last_name_kanji
end

#maiden_nameObject

The person’s maiden name.



879
880
881
# File 'lib/stripe/services/account_person_service.rb', line 879

def maiden_name
  @maiden_name
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



881
882
883
# File 'lib/stripe/services/account_person_service.rb', line 881

def 
  @metadata
end

#nationalityObject

The country where the person is a national. Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)), or “XX” if unavailable.



883
884
885
# File 'lib/stripe/services/account_person_service.rb', line 883

def nationality
  @nationality
end

#person_tokenObject

A [person token](docs.stripe.com/connect/account-tokens), used to securely provide details to the person.



885
886
887
# File 'lib/stripe/services/account_person_service.rb', line 885

def person_token
  @person_token
end

#phoneObject

The person’s phone number.



887
888
889
# File 'lib/stripe/services/account_person_service.rb', line 887

def phone
  @phone
end

#political_exposureObject

Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.



889
890
891
# File 'lib/stripe/services/account_person_service.rb', line 889

def political_exposure
  @political_exposure
end

#registered_addressObject

The person’s registered address.



891
892
893
# File 'lib/stripe/services/account_person_service.rb', line 891

def registered_address
  @registered_address
end

#relationshipObject

The relationship that this person has with the account’s legal entity.



893
894
895
# File 'lib/stripe/services/account_person_service.rb', line 893

def relationship
  @relationship
end

#ssn_last_4Object

The last four digits of the person’s Social Security number (U.S. only).



895
896
897
# File 'lib/stripe/services/account_person_service.rb', line 895

def ssn_last_4
  @ssn_last_4
end

#us_cfpb_dataObject

Demographic data related to the person.



897
898
899
# File 'lib/stripe/services/account_person_service.rb', line 897

def us_cfpb_data
  @us_cfpb_data
end

#verificationObject

The person’s verification status.



899
900
901
# File 'lib/stripe/services/account_person_service.rb', line 899

def verification
  @verification
end