Class: Stripe::AccountPersonService::CreateParams::Documents

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_person_service.rb

Defined Under Namespace

Classes: CompanyAuthorization, Passport, Visa

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(company_authorization: nil, passport: nil, visa: nil) ⇒ Documents

Returns a new instance of Documents.



694
695
696
697
698
# File 'lib/stripe/services/account_person_service.rb', line 694

def initialize(company_authorization: nil, passport: nil, visa: nil)
  @company_authorization = company_authorization
  @passport = passport
  @visa = visa
end

Instance Attribute Details

#company_authorizationObject

One or more documents that demonstrate proof that this person is authorized to represent the company.



688
689
690
# File 'lib/stripe/services/account_person_service.rb', line 688

def company_authorization
  @company_authorization
end

#passportObject

One or more documents showing the person’s passport page with photo and personal data.



690
691
692
# File 'lib/stripe/services/account_person_service.rb', line 690

def passport
  @passport
end

#visaObject

One or more documents showing the person’s visa required for living in the country where they are residing.



692
693
694
# File 'lib/stripe/services/account_person_service.rb', line 692

def visa
  @visa
end