Class: Stripe::AccountPersonService::CreateParams::Relationship
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountPersonService::CreateParams::Relationship
- Defined in:
- lib/stripe/services/account_person_service.rb
Instance Attribute Summary collapse
-
#authorizer ⇒ Object
Whether the person is the authorizer of the account’s representative.
-
#director ⇒ Object
Whether the person is a director of the account’s legal entity.
-
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
-
#legal_guardian ⇒ Object
Whether the person is the legal guardian of the account’s representative.
-
#owner ⇒ Object
Whether the person is an owner of the account’s legal entity.
-
#percent_ownership ⇒ Object
The percent owned by the person of the account’s legal entity.
-
#representative ⇒ Object
Whether the person is authorized as the primary representative of the account.
-
#title ⇒ Object
The person’s title (e.g., CEO, Support Engineer).
Instance Method Summary collapse
-
#initialize(authorizer: nil, director: nil, executive: nil, legal_guardian: nil, owner: nil, percent_ownership: nil, representative: nil, title: nil) ⇒ Relationship
constructor
A new instance of Relationship.
Methods inherited from RequestParams
Constructor Details
#initialize(authorizer: nil, director: nil, executive: nil, legal_guardian: nil, owner: nil, percent_ownership: nil, representative: nil, title: nil) ⇒ Relationship
Returns a new instance of Relationship.
749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 |
# File 'lib/stripe/services/account_person_service.rb', line 749 def initialize( authorizer: nil, director: nil, executive: nil, legal_guardian: nil, owner: nil, percent_ownership: nil, representative: nil, title: nil ) @authorizer = @director = director @executive = executive @legal_guardian = legal_guardian @owner = owner @percent_ownership = percent_ownership @representative = representative @title = title end |
Instance Attribute Details
#authorizer ⇒ Object
Whether the person is the authorizer of the account’s representative.
733 734 735 |
# File 'lib/stripe/services/account_person_service.rb', line 733 def @authorizer end |
#director ⇒ Object
Whether the person is a director of the account’s legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.
735 736 737 |
# File 'lib/stripe/services/account_person_service.rb', line 735 def director @director end |
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
737 738 739 |
# File 'lib/stripe/services/account_person_service.rb', line 737 def executive @executive end |
#legal_guardian ⇒ Object
Whether the person is the legal guardian of the account’s representative.
739 740 741 |
# File 'lib/stripe/services/account_person_service.rb', line 739 def legal_guardian @legal_guardian end |
#owner ⇒ Object
Whether the person is an owner of the account’s legal entity.
741 742 743 |
# File 'lib/stripe/services/account_person_service.rb', line 741 def owner @owner end |
#percent_ownership ⇒ Object
The percent owned by the person of the account’s legal entity.
743 744 745 |
# File 'lib/stripe/services/account_person_service.rb', line 743 def percent_ownership @percent_ownership end |
#representative ⇒ Object
Whether the person is authorized as the primary representative of the account. This is the person nominated by the business to provide information about themselves, and general information about the account. There can only be one representative at any given time. At the time the account is created, this person should be set to the person responsible for opening the account.
745 746 747 |
# File 'lib/stripe/services/account_person_service.rb', line 745 def representative @representative end |
#title ⇒ Object
The person’s title (e.g., CEO, Support Engineer).
747 748 749 |
# File 'lib/stripe/services/account_person_service.rb', line 747 def title @title end |