Class: Stripe::AccountPersonService::ListParams::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_person_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(authorizer: nil, director: nil, executive: nil, legal_guardian: nil, owner: nil, representative: nil) ⇒ Relationship

Returns a new instance of Relationship.



477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
# File 'lib/stripe/services/account_person_service.rb', line 477

def initialize(
  authorizer: nil,
  director: nil,
  executive: nil,
  legal_guardian: nil,
  owner: nil,
  representative: nil
)
  @authorizer = authorizer
  @director = director
  @executive = executive
  @legal_guardian = legal_guardian
  @owner = owner
  @representative = representative
end

Instance Attribute Details

#authorizerObject

A filter on the list of people returned based on whether these people are authorizers of the account’s representative.



465
466
467
# File 'lib/stripe/services/account_person_service.rb', line 465

def authorizer
  @authorizer
end

#directorObject

A filter on the list of people returned based on whether these people are directors of the account’s company.



467
468
469
# File 'lib/stripe/services/account_person_service.rb', line 467

def director
  @director
end

#executiveObject

A filter on the list of people returned based on whether these people are executives of the account’s company.



469
470
471
# File 'lib/stripe/services/account_person_service.rb', line 469

def executive
  @executive
end

A filter on the list of people returned based on whether these people are legal guardians of the account’s representative.



471
472
473
# File 'lib/stripe/services/account_person_service.rb', line 471

def legal_guardian
  @legal_guardian
end

#ownerObject

A filter on the list of people returned based on whether these people are owners of the account’s company.



473
474
475
# File 'lib/stripe/services/account_person_service.rb', line 473

def owner
  @owner
end

#representativeObject

A filter on the list of people returned based on whether these people are the representative of the account’s company.



475
476
477
# File 'lib/stripe/services/account_person_service.rb', line 475

def representative
  @representative
end