Class: Stripe::AccountPersonService::UpdateParams::AdditionalTosAcceptances::Account

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_person_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ Account

Returns a new instance of Account.



27
28
29
30
31
# File 'lib/stripe/services/account_person_service.rb', line 27

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



21
22
23
# File 'lib/stripe/services/account_person_service.rb', line 21

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



23
24
25
# File 'lib/stripe/services/account_person_service.rb', line 23

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



25
26
27
# File 'lib/stripe/services/account_person_service.rb', line 25

def user_agent
  @user_agent
end