Class: Stripe::AccountPersonService::UpdateParams::Documents

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_person_service.rb

Defined Under Namespace

Classes: CompanyAuthorization, Passport, Visa

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(company_authorization: nil, passport: nil, visa: nil) ⇒ Documents

Returns a new instance of Documents.



191
192
193
194
195
# File 'lib/stripe/services/account_person_service.rb', line 191

def initialize(company_authorization: nil, passport: nil, visa: nil)
  @company_authorization = company_authorization
  @passport = passport
  @visa = visa
end

Instance Attribute Details

#company_authorizationObject

One or more documents that demonstrate proof that this person is authorized to represent the company.



185
186
187
# File 'lib/stripe/services/account_person_service.rb', line 185

def company_authorization
  @company_authorization
end

#passportObject

One or more documents showing the person’s passport page with photo and personal data.



187
188
189
# File 'lib/stripe/services/account_person_service.rb', line 187

def passport
  @passport
end

#visaObject

One or more documents showing the person’s visa required for living in the country where they are residing.



189
190
191
# File 'lib/stripe/services/account_person_service.rb', line 189

def visa
  @visa
end