Class: Stripe::AccountPersonService::UpdateParams::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_person_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(authorizer: nil, director: nil, executive: nil, legal_guardian: nil, owner: nil, percent_ownership: nil, representative: nil, title: nil) ⇒ Relationship

Returns a new instance of Relationship.



247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/stripe/services/account_person_service.rb', line 247

def initialize(
  authorizer: nil,
  director: nil,
  executive: nil,
  legal_guardian: nil,
  owner: nil,
  percent_ownership: nil,
  representative: nil,
  title: nil
)
  @authorizer = authorizer
  @director = director
  @executive = executive
  @legal_guardian = legal_guardian
  @owner = owner
  @percent_ownership = percent_ownership
  @representative = representative
  @title = title
end

Instance Attribute Details

#authorizerObject

Whether the person is the authorizer of the account’s representative.



231
232
233
# File 'lib/stripe/services/account_person_service.rb', line 231

def authorizer
  @authorizer
end

#directorObject

Whether the person is a director of the account’s legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



233
234
235
# File 'lib/stripe/services/account_person_service.rb', line 233

def director
  @director
end

#executiveObject

Whether the person has significant responsibility to control, manage, or direct the organization.



235
236
237
# File 'lib/stripe/services/account_person_service.rb', line 235

def executive
  @executive
end

Whether the person is the legal guardian of the account’s representative.



237
238
239
# File 'lib/stripe/services/account_person_service.rb', line 237

def legal_guardian
  @legal_guardian
end

#ownerObject

Whether the person is an owner of the account’s legal entity.



239
240
241
# File 'lib/stripe/services/account_person_service.rb', line 239

def owner
  @owner
end

#percent_ownershipObject

The percent owned by the person of the account’s legal entity.



241
242
243
# File 'lib/stripe/services/account_person_service.rb', line 241

def percent_ownership
  @percent_ownership
end

#representativeObject

Whether the person is authorized as the primary representative of the account. This is the person nominated by the business to provide information about themselves, and general information about the account. There can only be one representative at any given time. At the time the account is created, this person should be set to the person responsible for opening the account.



243
244
245
# File 'lib/stripe/services/account_person_service.rb', line 243

def representative
  @representative
end

#titleObject

The person’s title (e.g., CEO, Support Engineer).



245
246
247
# File 'lib/stripe/services/account_person_service.rb', line 245

def title
  @title
end