Class: Stripe::AccountPersonUpdateParams::Documents

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_person_update_params.rb

Defined Under Namespace

Classes: CompanyAuthorization, Passport, Visa

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(company_authorization: nil, passport: nil, visa: nil) ⇒ Documents

Returns a new instance of Documents.



196
197
198
199
200
# File 'lib/stripe/params/account_person_update_params.rb', line 196

def initialize(company_authorization: nil, passport: nil, visa: nil)
  @company_authorization = company_authorization
  @passport = passport
  @visa = visa
end

Instance Attribute Details

#company_authorizationObject

One or more documents that demonstrate proof that this person is authorized to represent the company.



190
191
192
# File 'lib/stripe/params/account_person_update_params.rb', line 190

def company_authorization
  @company_authorization
end

#passportObject

One or more documents showing the person’s passport page with photo and personal data.



192
193
194
# File 'lib/stripe/params/account_person_update_params.rb', line 192

def passport
  @passport
end

#visaObject

One or more documents showing the person’s visa required for living in the country where they are residing.



194
195
196
# File 'lib/stripe/params/account_person_update_params.rb', line 194

def visa
  @visa
end