Class: Stripe::AccountRejectParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountRejectParams
- Defined in:
- lib/stripe/params/account_reject_params.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#payouts_action ⇒ Object
Whether to pause payouts on the account as part of the rejection.
-
#reason ⇒ Object
The reason for rejecting the account.
Instance Method Summary collapse
-
#initialize(expand: nil, payouts_action: nil, reason: nil) ⇒ AccountRejectParams
constructor
A new instance of AccountRejectParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(expand: nil, payouts_action: nil, reason: nil) ⇒ AccountRejectParams
Returns a new instance of AccountRejectParams.
13 14 15 16 17 |
# File 'lib/stripe/params/account_reject_params.rb', line 13 def initialize(expand: nil, payouts_action: nil, reason: nil) @expand = @payouts_action = payouts_action @reason = reason end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
7 8 9 |
# File 'lib/stripe/params/account_reject_params.rb', line 7 def @expand end |
#payouts_action ⇒ Object
Whether to pause payouts on the account as part of the rejection. Defaults to pause. Use none to leave payouts enabled.
9 10 11 |
# File 'lib/stripe/params/account_reject_params.rb', line 9 def payouts_action @payouts_action end |
#reason ⇒ Object
The reason for rejecting the account. Can be fraud, terms_of_service, or other.
11 12 13 |
# File 'lib/stripe/params/account_reject_params.rb', line 11 def reason @reason end |