Class: Stripe::AccountService::CreateParams::BankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(object: nil, account_holder_name: nil, account_holder_type: nil, account_number: nil, country: nil, currency: nil, routing_number: nil) ⇒ BankAccount

Returns a new instance of BankAccount.



2366
2367
2368
2369
2370
2371
2372
2373
2374
2375
2376
2377
2378
2379
2380
2381
2382
# File 'lib/stripe/services/account_service.rb', line 2366

def initialize(
  object: nil,
  account_holder_name: nil,
  account_holder_type: nil,
  account_number: nil,
  country: nil,
  currency: nil,
  routing_number: nil
)
  @object = object
  @account_holder_name = 
  @account_holder_type = 
  @account_number = 
  @country = country
  @currency = currency
  @routing_number = routing_number
end

Instance Attribute Details

#account_holder_nameObject

The name of the person or business that owns the bank account.This field is required when attaching the bank account to a ‘Customer` object.



2354
2355
2356
# File 'lib/stripe/services/account_service.rb', line 2354

def 
  @account_holder_name
end

#account_holder_typeObject

The type of entity that holds the account. It can be ‘company` or `individual`. This field is required when attaching the bank account to a `Customer` object.



2356
2357
2358
# File 'lib/stripe/services/account_service.rb', line 2356

def 
  @account_holder_type
end

#account_numberObject

The account number for the bank account, in string form. Must be a checking account.



2358
2359
2360
# File 'lib/stripe/services/account_service.rb', line 2358

def 
  @account_number
end

#countryObject

The country in which the bank account is located.



2360
2361
2362
# File 'lib/stripe/services/account_service.rb', line 2360

def country
  @country
end

#currencyObject

The currency the bank account is in. This must be a country/currency pairing that [Stripe supports.](docs/payouts)



2362
2363
2364
# File 'lib/stripe/services/account_service.rb', line 2362

def currency
  @currency
end

#objectObject

Attribute for param field object



2352
2353
2354
# File 'lib/stripe/services/account_service.rb', line 2352

def object
  @object
end

#routing_numberObject

The routing number, sort code, or other country-appropriate institution number for the bank account. For US bank accounts, this is required and should be the ACH routing number, not the wire routing number. If you are providing an IBAN for ‘account_number`, this field is not required.



2364
2365
2366
# File 'lib/stripe/services/account_service.rb', line 2364

def routing_number
  @routing_number
end