Class: Stripe::AccountService::CreateParams::BusinessProfile

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Defined Under Namespace

Classes: AnnualRevenue, MonthlyEstimatedRevenue, SupportAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(annual_revenue: nil, estimated_worker_count: nil, mcc: nil, minority_owned_business_designation: nil, monthly_estimated_revenue: nil, name: nil, product_description: nil, support_address: nil, support_email: nil, support_phone: nil, support_url: nil, url: nil) ⇒ BusinessProfile

Returns a new instance of BusinessProfile.



2468
2469
2470
2471
2472
2473
2474
2475
2476
2477
2478
2479
2480
2481
2482
2483
2484
2485
2486
2487
2488
2489
2490
2491
2492
2493
2494
# File 'lib/stripe/services/account_service.rb', line 2468

def initialize(
  annual_revenue: nil,
  estimated_worker_count: nil,
  mcc: nil,
  minority_owned_business_designation: nil,
  monthly_estimated_revenue: nil,
  name: nil,
  product_description: nil,
  support_address: nil,
  support_email: nil,
  support_phone: nil,
  support_url: nil,
  url: nil
)
  @annual_revenue = annual_revenue
  @estimated_worker_count = estimated_worker_count
  @mcc = mcc
  @minority_owned_business_designation = minority_owned_business_designation
  @monthly_estimated_revenue = monthly_estimated_revenue
  @name = name
  @product_description = product_description
  @support_address = support_address
  @support_email = support_email
  @support_phone = support_phone
  @support_url = support_url
  @url = url
end

Instance Attribute Details

#annual_revenueObject

The applicant’s gross annual revenue for its preceding fiscal year.



2444
2445
2446
# File 'lib/stripe/services/account_service.rb', line 2444

def annual_revenue
  @annual_revenue
end

#estimated_worker_countObject

An estimated upper bound of employees, contractors, vendors, etc. currently working for the business.



2446
2447
2448
# File 'lib/stripe/services/account_service.rb', line 2446

def estimated_worker_count
  @estimated_worker_count
end

#mccObject

[The merchant category code for the account](/connect/setting-mcc). MCCs are used to classify businesses based on the goods or services they provide.



2448
2449
2450
# File 'lib/stripe/services/account_service.rb', line 2448

def mcc
  @mcc
end

#minority_owned_business_designationObject

Whether the business is a minority-owned, women-owned, and/or LGBTQI+ -owned business.



2450
2451
2452
# File 'lib/stripe/services/account_service.rb', line 2450

def minority_owned_business_designation
  @minority_owned_business_designation
end

#monthly_estimated_revenueObject

An estimate of the monthly revenue of the business. Only accepted for accounts in Brazil and India.



2452
2453
2454
# File 'lib/stripe/services/account_service.rb', line 2452

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#nameObject

The customer-facing business name.



2454
2455
2456
# File 'lib/stripe/services/account_service.rb', line 2454

def name
  @name
end

#product_descriptionObject

Internal-only description of the product sold by, or service provided by, the business. Used by Stripe for risk and underwriting purposes.



2456
2457
2458
# File 'lib/stripe/services/account_service.rb', line 2456

def product_description
  @product_description
end

#support_addressObject

A publicly available mailing address for sending support issues to.



2458
2459
2460
# File 'lib/stripe/services/account_service.rb', line 2458

def support_address
  @support_address
end

#support_emailObject

A publicly available email address for sending support issues to.



2460
2461
2462
# File 'lib/stripe/services/account_service.rb', line 2460

def support_email
  @support_email
end

#support_phoneObject

A publicly available phone number to call with support issues.



2462
2463
2464
# File 'lib/stripe/services/account_service.rb', line 2462

def support_phone
  @support_phone
end

#support_urlObject

A publicly available website for handling support issues.



2464
2465
2466
# File 'lib/stripe/services/account_service.rb', line 2464

def support_url
  @support_url
end

#urlObject

The business’s publicly available website.



2466
2467
2468
# File 'lib/stripe/services/account_service.rb', line 2466

def url
  @url
end