Class: Stripe::AccountService::CreateParams::BusinessProfile::MonthlyEstimatedRevenue
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountService::CreateParams::BusinessProfile::MonthlyEstimatedRevenue
- Defined in:
- lib/stripe/services/account_service.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
A non-negative integer representing how much to charge in the [smallest currency unit](/currencies#zero-decimal).
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
Instance Method Summary collapse
-
#initialize(amount: nil, currency: nil) ⇒ MonthlyEstimatedRevenue
constructor
A new instance of MonthlyEstimatedRevenue.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, currency: nil) ⇒ MonthlyEstimatedRevenue
Returns a new instance of MonthlyEstimatedRevenue.
2106 2107 2108 2109 |
# File 'lib/stripe/services/account_service.rb', line 2106 def initialize(amount: nil, currency: nil) @amount = amount @currency = currency end |
Instance Attribute Details
#amount ⇒ Object
A non-negative integer representing how much to charge in the [smallest currency unit](/currencies#zero-decimal).
2102 2103 2104 |
# File 'lib/stripe/services/account_service.rb', line 2102 def amount @amount end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
2104 2105 2106 |
# File 'lib/stripe/services/account_service.rb', line 2104 def currency @currency end |