Class: Stripe::AccountService::CreateParams::Capabilities::AuBecsDebitPayments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountService::CreateParams::Capabilities::AuBecsDebitPayments
- Defined in:
- lib/stripe/services/account_service.rb
Instance Attribute Summary collapse
-
#requested ⇒ Object
Passing true requests the capability for the account, if it is not already requested.
Instance Method Summary collapse
-
#initialize(requested: nil) ⇒ AuBecsDebitPayments
constructor
A new instance of AuBecsDebitPayments.
Methods inherited from RequestParams
Constructor Details
#initialize(requested: nil) ⇒ AuBecsDebitPayments
Returns a new instance of AuBecsDebitPayments.
2246 2247 2248 |
# File 'lib/stripe/services/account_service.rb', line 2246 def initialize(requested: nil) @requested = requested end |
Instance Attribute Details
#requested ⇒ Object
Passing true requests the capability for the account, if it is not already requested. A requested capability may not immediately become active. Any requirements to activate the capability are returned in the ‘requirements` arrays.
2244 2245 2246 |
# File 'lib/stripe/services/account_service.rb', line 2244 def requested @requested end |