Class: Stripe::AccountService::CreateParams::Capabilities::BacsDebitPayments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(requested: nil) ⇒ BacsDebitPayments

Returns a new instance of BacsDebitPayments.



2294
2295
2296
# File 'lib/stripe/services/account_service.rb', line 2294

def initialize(requested: nil)
  @requested = requested
end

Instance Attribute Details

#requestedObject

Passing true requests the capability for the account, if it is not already requested. A requested capability may not immediately become active. Any requirements to activate the capability are returned in the ‘requirements` arrays.



2292
2293
2294
# File 'lib/stripe/services/account_service.rb', line 2292

def requested
  @requested
end