Class: Stripe::AccountService::CreateParams::Capabilities::CartesBancairesPayments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountService::CreateParams::Capabilities::CartesBancairesPayments
- Defined in:
- lib/stripe/services/account_service.rb
Instance Attribute Summary collapse
-
#requested ⇒ Object
Passing true requests the capability for the account, if it is not already requested.
Instance Method Summary collapse
-
#initialize(requested: nil) ⇒ CartesBancairesPayments
constructor
A new instance of CartesBancairesPayments.
Methods inherited from RequestParams
Constructor Details
#initialize(requested: nil) ⇒ CartesBancairesPayments
Returns a new instance of CartesBancairesPayments.
2366 2367 2368 |
# File 'lib/stripe/services/account_service.rb', line 2366 def initialize(requested: nil) @requested = requested end |
Instance Attribute Details
#requested ⇒ Object
Passing true requests the capability for the account, if it is not already requested. A requested capability may not immediately become active. Any requirements to activate the capability are returned in the ‘requirements` arrays.
2364 2365 2366 |
# File 'lib/stripe/services/account_service.rb', line 2364 def requested @requested end |