Class: Stripe::AccountService::CreateParams::Capabilities::CryptoPayments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountService::CreateParams::Capabilities::CryptoPayments
- Defined in:
- lib/stripe/services/account_service.rb
Instance Attribute Summary collapse
-
#requested ⇒ Object
Passing true requests the capability for the account, if it is not already requested.
Instance Method Summary collapse
-
#initialize(requested: nil) ⇒ CryptoPayments
constructor
A new instance of CryptoPayments.
Methods inherited from RequestParams
Constructor Details
#initialize(requested: nil) ⇒ CryptoPayments
Returns a new instance of CryptoPayments.
2655 2656 2657 |
# File 'lib/stripe/services/account_service.rb', line 2655 def initialize(requested: nil) @requested = requested end |
Instance Attribute Details
#requested ⇒ Object
Passing true requests the capability for the account, if it is not already requested. A requested capability may not immediately become active. Any requirements to activate the capability are returned in the ‘requirements` arrays.
2653 2654 2655 |
# File 'lib/stripe/services/account_service.rb', line 2653 def requested @requested end |