Class: Stripe::AccountService::CreateParams::Capabilities::GiropayPayments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(requested: nil) ⇒ GiropayPayments

Returns a new instance of GiropayPayments.



2420
2421
2422
# File 'lib/stripe/services/account_service.rb', line 2420

def initialize(requested: nil)
  @requested = requested
end

Instance Attribute Details

#requestedObject

Passing true requests the capability for the account, if it is not already requested. A requested capability may not immediately become active. Any requirements to activate the capability are returned in the ‘requirements` arrays.



2418
2419
2420
# File 'lib/stripe/services/account_service.rb', line 2418

def requested
  @requested
end