Class: Stripe::AccountService::CreateParams::Capabilities::GrabpayPayments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(requested: nil) ⇒ GrabpayPayments

Returns a new instance of GrabpayPayments.



2622
2623
2624
# File 'lib/stripe/services/account_service.rb', line 2622

def initialize(requested: nil)
  @requested = requested
end

Instance Attribute Details

#requestedObject

Passing true requests the capability for the account, if it is not already requested. A requested capability may not immediately become active. Any requirements to activate the capability are returned in the ‘requirements` arrays.



2620
2621
2622
# File 'lib/stripe/services/account_service.rb', line 2620

def requested
  @requested
end