Class: Stripe::AccountService::CreateParams::Capabilities::IdBankTransferPaymentsBca

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(requested: nil) ⇒ IdBankTransferPaymentsBca

Returns a new instance of IdBankTransferPaymentsBca.



2679
2680
2681
# File 'lib/stripe/services/account_service.rb', line 2679

def initialize(requested: nil)
  @requested = requested
end

Instance Attribute Details

#requestedObject

Passing true requests the capability for the account, if it is not already requested. A requested capability may not immediately become active. Any requirements to activate the capability are returned in the ‘requirements` arrays.



2677
2678
2679
# File 'lib/stripe/services/account_service.rb', line 2677

def requested
  @requested
end