Class: Stripe::AccountService::CreateParams::Capabilities::JcbPayments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(requested: nil) ⇒ JcbPayments

Returns a new instance of JcbPayments.



2456
2457
2458
# File 'lib/stripe/services/account_service.rb', line 2456

def initialize(requested: nil)
  @requested = requested
end

Instance Attribute Details

#requestedObject

Passing true requests the capability for the account, if it is not already requested. A requested capability may not immediately become active. Any requirements to activate the capability are returned in the ‘requirements` arrays.



2454
2455
2456
# File 'lib/stripe/services/account_service.rb', line 2454

def requested
  @requested
end