Class: Stripe::AccountService::CreateParams::Capabilities::NaverPayPayments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountService::CreateParams::Capabilities::NaverPayPayments
- Defined in:
- lib/stripe/services/account_service.rb
Instance Attribute Summary collapse
-
#requested ⇒ Object
Passing true requests the capability for the account, if it is not already requested.
Instance Method Summary collapse
-
#initialize(requested: nil) ⇒ NaverPayPayments
constructor
A new instance of NaverPayPayments.
Methods inherited from RequestParams
Constructor Details
#initialize(requested: nil) ⇒ NaverPayPayments
Returns a new instance of NaverPayPayments.
2507 2508 2509 |
# File 'lib/stripe/services/account_service.rb', line 2507 def initialize(requested: nil) @requested = requested end |
Instance Attribute Details
#requested ⇒ Object
Passing true requests the capability for the account, if it is not already requested. A requested capability may not immediately become active. Any requirements to activate the capability are returned in the ‘requirements` arrays.
2505 2506 2507 |
# File 'lib/stripe/services/account_service.rb', line 2505 def requested @requested end |