Class: Stripe::AccountService::CreateParams::Capabilities::P24Payments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountService::CreateParams::Capabilities::P24Payments
- Defined in:
- lib/stripe/services/account_service.rb
Instance Attribute Summary collapse
-
#requested ⇒ Object
Passing true requests the capability for the account, if it is not already requested.
Instance Method Summary collapse
-
#initialize(requested: nil) ⇒ P24Payments
constructor
A new instance of P24Payments.
Methods inherited from RequestParams
Constructor Details
#initialize(requested: nil) ⇒ P24Payments
Returns a new instance of P24Payments.
2582 2583 2584 |
# File 'lib/stripe/services/account_service.rb', line 2582 def initialize(requested: nil) @requested = requested end |
Instance Attribute Details
#requested ⇒ Object
Passing true requests the capability for the account, if it is not already requested. A requested capability may not immediately become active. Any requirements to activate the capability are returned in the ‘requirements` arrays.
2580 2581 2582 |
# File 'lib/stripe/services/account_service.rb', line 2580 def requested @requested end |