Class: Stripe::AccountService::CreateParams::Capabilities::PaypalPayments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(requested: nil) ⇒ PaypalPayments

Returns a new instance of PaypalPayments.



2765
2766
2767
# File 'lib/stripe/services/account_service.rb', line 2765

def initialize(requested: nil)
  @requested = requested
end

Instance Attribute Details

#requestedObject

Passing true requests the capability for the account, if it is not already requested. A requested capability may not immediately become active. Any requirements to activate the capability are returned in the ‘requirements` arrays.



2763
2764
2765
# File 'lib/stripe/services/account_service.rb', line 2763

def requested
  @requested
end