Class: Stripe::AccountService::CreateParams::Capabilities::RevolutPayPayments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(requested: nil) ⇒ RevolutPayPayments

Returns a new instance of RevolutPayPayments.



2979
2980
2981
# File 'lib/stripe/services/account_service.rb', line 2979

def initialize(requested: nil)
  @requested = requested
end

Instance Attribute Details

#requestedObject

Passing true requests the capability for the account, if it is not already requested. A requested capability may not immediately become active. Any requirements to activate the capability are returned in the ‘requirements` arrays.



2977
2978
2979
# File 'lib/stripe/services/account_service.rb', line 2977

def requested
  @requested
end