Class: Stripe::AccountService::CreateParams::Capabilities::SepaDebitPayments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountService::CreateParams::Capabilities::SepaDebitPayments
- Defined in:
- lib/stripe/services/account_service.rb
Instance Attribute Summary collapse
-
#requested ⇒ Object
Passing true requests the capability for the account, if it is not already requested.
Instance Method Summary collapse
-
#initialize(requested: nil) ⇒ SepaDebitPayments
constructor
A new instance of SepaDebitPayments.
Methods inherited from RequestParams
Constructor Details
#initialize(requested: nil) ⇒ SepaDebitPayments
Returns a new instance of SepaDebitPayments.
2783 2784 2785 |
# File 'lib/stripe/services/account_service.rb', line 2783 def initialize(requested: nil) @requested = requested end |
Instance Attribute Details
#requested ⇒ Object
Passing true requests the capability for the account, if it is not already requested. A requested capability may not immediately become active. Any requirements to activate the capability are returned in the ‘requirements` arrays.
2781 2782 2783 |
# File 'lib/stripe/services/account_service.rb', line 2781 def requested @requested end |