Class: Stripe::AccountService::CreateParams::Capabilities::ShopeepayPayments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(requested: nil) ⇒ ShopeepayPayments

Returns a new instance of ShopeepayPayments.



3070
3071
3072
# File 'lib/stripe/services/account_service.rb', line 3070

def initialize(requested: nil)
  @requested = requested
end

Instance Attribute Details

#requestedObject

Passing true requests the capability for the account, if it is not already requested. A requested capability may not immediately become active. Any requirements to activate the capability are returned in the ‘requirements` arrays.



3068
3069
3070
# File 'lib/stripe/services/account_service.rb', line 3068

def requested
  @requested
end