Class: Stripe::AccountService::CreateParams::Capabilities::UsBankAccountAchPayments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountService::CreateParams::Capabilities::UsBankAccountAchPayments
- Defined in:
- lib/stripe/services/account_service.rb
Instance Attribute Summary collapse
-
#requested ⇒ Object
Passing true requests the capability for the account, if it is not already requested.
Instance Method Summary collapse
-
#initialize(requested: nil) ⇒ UsBankAccountAchPayments
constructor
A new instance of UsBankAccountAchPayments.
Methods inherited from RequestParams
Constructor Details
#initialize(requested: nil) ⇒ UsBankAccountAchPayments
Returns a new instance of UsBankAccountAchPayments.
3132 3133 3134 |
# File 'lib/stripe/services/account_service.rb', line 3132 def initialize(requested: nil) @requested = requested end |
Instance Attribute Details
#requested ⇒ Object
Passing true requests the capability for the account, if it is not already requested. A requested capability may not immediately become active. Any requirements to activate the capability are returned in the ‘requirements` arrays.
3130 3131 3132 |
# File 'lib/stripe/services/account_service.rb', line 3130 def requested @requested end |