Class: Stripe::AccountService::CreateParams::Company

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Defined Under Namespace

Classes: Address, AddressKana, AddressKanji, DirectorshipDeclaration, OwnershipDeclaration, RegistrationDate, Verification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, address_kana: nil, address_kanji: nil, directors_provided: nil, directorship_declaration: nil, executives_provided: nil, export_license_id: nil, export_purpose_code: nil, name: nil, name_kana: nil, name_kanji: nil, owners_provided: nil, ownership_declaration: nil, ownership_exemption_reason: nil, phone: nil, registration_date: nil, registration_number: nil, structure: nil, tax_id: nil, tax_id_registrar: nil, vat_id: nil, verification: nil) ⇒ Company

Returns a new instance of Company.



3745
3746
3747
3748
3749
3750
3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
3783
3784
3785
3786
3787
3788
3789
3790
3791
# File 'lib/stripe/services/account_service.rb', line 3745

def initialize(
  address: nil,
  address_kana: nil,
  address_kanji: nil,
  directors_provided: nil,
  directorship_declaration: nil,
  executives_provided: nil,
  export_license_id: nil,
  export_purpose_code: nil,
  name: nil,
  name_kana: nil,
  name_kanji: nil,
  owners_provided: nil,
  ownership_declaration: nil,
  ownership_exemption_reason: nil,
  phone: nil,
  registration_date: nil,
  registration_number: nil,
  structure: nil,
  tax_id: nil,
  tax_id_registrar: nil,
  vat_id: nil,
  verification: nil
)
  @address = address
  @address_kana = address_kana
  @address_kanji = address_kanji
  @directors_provided = directors_provided
  @directorship_declaration = directorship_declaration
  @executives_provided = executives_provided
  @export_license_id = export_license_id
  @export_purpose_code = export_purpose_code
  @name = name
  @name_kana = name_kana
  @name_kanji = name_kanji
  @owners_provided = owners_provided
  @ownership_declaration = ownership_declaration
  @ownership_exemption_reason = ownership_exemption_reason
  @phone = phone
  @registration_date = registration_date
  @registration_number = registration_number
  @structure = structure
  @tax_id = tax_id
  @tax_id_registrar = tax_id_registrar
  @vat_id = vat_id
  @verification = verification
end

Instance Attribute Details

#addressObject

The company’s primary address.



3701
3702
3703
# File 'lib/stripe/services/account_service.rb', line 3701

def address
  @address
end

#address_kanaObject

The Kana variation of the company’s primary address (Japan only).



3703
3704
3705
# File 'lib/stripe/services/account_service.rb', line 3703

def address_kana
  @address_kana
end

#address_kanjiObject

The Kanji variation of the company’s primary address (Japan only).



3705
3706
3707
# File 'lib/stripe/services/account_service.rb', line 3705

def address_kanji
  @address_kanji
end

#directors_providedObject

Whether the company’s directors have been provided. Set this Boolean to ‘true` after creating all the company’s directors with [the Persons API](/api/persons) for accounts with a ‘relationship.director` requirement. This value is not automatically set to `true` after creating directors, so it needs to be updated to indicate all directors have been provided.



3707
3708
3709
# File 'lib/stripe/services/account_service.rb', line 3707

def directors_provided
  @directors_provided
end

#directorship_declarationObject

This hash is used to attest that the directors information provided to Stripe is both current and correct.



3709
3710
3711
# File 'lib/stripe/services/account_service.rb', line 3709

def directorship_declaration
  @directorship_declaration
end

#executives_providedObject

Whether the company’s executives have been provided. Set this Boolean to ‘true` after creating all the company’s executives with [the Persons API](/api/persons) for accounts with a ‘relationship.executive` requirement.



3711
3712
3713
# File 'lib/stripe/services/account_service.rb', line 3711

def executives_provided
  @executives_provided
end

#export_license_idObject

The export license ID number of the company, also referred as Import Export Code (India only).



3713
3714
3715
# File 'lib/stripe/services/account_service.rb', line 3713

def export_license_id
  @export_license_id
end

#export_purpose_codeObject

The purpose code to use for export transactions (India only).



3715
3716
3717
# File 'lib/stripe/services/account_service.rb', line 3715

def export_purpose_code
  @export_purpose_code
end

#nameObject

The company’s legal name.



3717
3718
3719
# File 'lib/stripe/services/account_service.rb', line 3717

def name
  @name
end

#name_kanaObject

The Kana variation of the company’s legal name (Japan only).



3719
3720
3721
# File 'lib/stripe/services/account_service.rb', line 3719

def name_kana
  @name_kana
end

#name_kanjiObject

The Kanji variation of the company’s legal name (Japan only).



3721
3722
3723
# File 'lib/stripe/services/account_service.rb', line 3721

def name_kanji
  @name_kanji
end

#owners_providedObject

Whether the company’s owners have been provided. Set this Boolean to ‘true` after creating all the company’s owners with [the Persons API](/api/persons) for accounts with a ‘relationship.owner` requirement.



3723
3724
3725
# File 'lib/stripe/services/account_service.rb', line 3723

def owners_provided
  @owners_provided
end

#ownership_declarationObject

This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.



3725
3726
3727
# File 'lib/stripe/services/account_service.rb', line 3725

def ownership_declaration
  @ownership_declaration
end

#ownership_exemption_reasonObject

This value is used to determine if a business is exempt from providing ultimate beneficial owners. See [this support article](support.stripe.com/questions/exemption-from-providing-ownership-details) and [changelog](docs.stripe.com/changelog/acacia/2025-01-27/ownership-exemption-reason-accounts-api) for more details.



3727
3728
3729
# File 'lib/stripe/services/account_service.rb', line 3727

def ownership_exemption_reason
  @ownership_exemption_reason
end

#phoneObject

The company’s phone number (used for verification).



3729
3730
3731
# File 'lib/stripe/services/account_service.rb', line 3729

def phone
  @phone
end

#registration_dateObject

When the business was incorporated or registered.



3731
3732
3733
# File 'lib/stripe/services/account_service.rb', line 3731

def registration_date
  @registration_date
end

#registration_numberObject

The identification number given to a company when it is registered or incorporated, if distinct from the identification number used for filing taxes. (Examples are the CIN for companies and LLP IN for partnerships in India, and the Company Registration Number in Hong Kong).



3733
3734
3735
# File 'lib/stripe/services/account_service.rb', line 3733

def registration_number
  @registration_number
end

#structureObject

The category identifying the legal structure of the company or legal entity. See [Business structure](/connect/identity-verification#business-structure) for more details. Pass an empty string to unset this value.



3735
3736
3737
# File 'lib/stripe/services/account_service.rb', line 3735

def structure
  @structure
end

#tax_idObject

The business ID number of the company, as appropriate for the company’s country. (Examples are an Employer ID Number in the U.S., a Business Number in Canada, or a Company Number in the UK.)



3737
3738
3739
# File 'lib/stripe/services/account_service.rb', line 3737

def tax_id
  @tax_id
end

#tax_id_registrarObject

The jurisdiction in which the ‘tax_id` is registered (Germany-based companies only).



3739
3740
3741
# File 'lib/stripe/services/account_service.rb', line 3739

def tax_id_registrar
  @tax_id_registrar
end

#vat_idObject

The VAT number of the company.



3741
3742
3743
# File 'lib/stripe/services/account_service.rb', line 3741

def vat_id
  @vat_id
end

#verificationObject

Information on the verification state of the company.



3743
3744
3745
# File 'lib/stripe/services/account_service.rb', line 3743

def verification
  @verification
end