Class: Stripe::AccountService::CreateParams::Company::DirectorshipDeclaration
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountService::CreateParams::Company::DirectorshipDeclaration
- Defined in:
- lib/stripe/services/account_service.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the directorship declaration attestation was made.
-
#ip ⇒ Object
The IP address from which the directorship declaration attestation was made.
-
#user_agent ⇒ Object
The user agent of the browser from which the directorship declaration attestation was made.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ DirectorshipDeclaration
constructor
A new instance of DirectorshipDeclaration.
Methods inherited from RequestParams
Constructor Details
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ DirectorshipDeclaration
Returns a new instance of DirectorshipDeclaration.
3644 3645 3646 3647 3648 |
# File 'lib/stripe/services/account_service.rb', line 3644 def initialize(date: nil, ip: nil, user_agent: nil) @date = date @ip = ip @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the directorship declaration attestation was made.
3638 3639 3640 |
# File 'lib/stripe/services/account_service.rb', line 3638 def date @date end |
#ip ⇒ Object
The IP address from which the directorship declaration attestation was made.
3640 3641 3642 |
# File 'lib/stripe/services/account_service.rb', line 3640 def ip @ip end |
#user_agent ⇒ Object
The user agent of the browser from which the directorship declaration attestation was made.
3642 3643 3644 |
# File 'lib/stripe/services/account_service.rb', line 3642 def user_agent @user_agent end |