Class: Stripe::AccountService::CreateParams::Company::OwnershipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ OwnershipDeclaration

Returns a new instance of OwnershipDeclaration.



3215
3216
3217
3218
3219
# File 'lib/stripe/services/account_service.rb', line 3215

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the beneficial owner attestation was made.



3209
3210
3211
# File 'lib/stripe/services/account_service.rb', line 3209

def date
  @date
end

#ipObject

The IP address from which the beneficial owner attestation was made.



3211
3212
3213
# File 'lib/stripe/services/account_service.rb', line 3211

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the beneficial owner attestation was made.



3213
3214
3215
# File 'lib/stripe/services/account_service.rb', line 3213

def user_agent
  @user_agent
end