Class: Stripe::AccountService::CreateParams::Company::Verification::Document

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(back: nil, front: nil) ⇒ Document

Returns a new instance of Document.



3688
3689
3690
3691
# File 'lib/stripe/services/account_service.rb', line 3688

def initialize(back: nil, front: nil)
  @back = back
  @front = front
end

Instance Attribute Details

#backObject

The back of a document returned by a [file upload](stripe.com/docs/api#create_file) with a ‘purpose` value of `additional_verification`. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.



3684
3685
3686
# File 'lib/stripe/services/account_service.rb', line 3684

def back
  @back
end

#frontObject

The front of a document returned by a [file upload](stripe.com/docs/api#create_file) with a ‘purpose` value of `additional_verification`. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.



3686
3687
3688
# File 'lib/stripe/services/account_service.rb', line 3686

def front
  @front
end