Class: Stripe::AccountService::CreateParams::Individual::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship

Returns a new instance of Relationship.



3686
3687
3688
3689
3690
3691
3692
3693
3694
3695
3696
3697
3698
# File 'lib/stripe/services/account_service.rb', line 3686

def initialize(
  director: nil,
  executive: nil,
  owner: nil,
  percent_ownership: nil,
  title: nil
)
  @director = director
  @executive = executive
  @owner = owner
  @percent_ownership = percent_ownership
  @title = title
end

Instance Attribute Details

#directorObject

Whether the person is a director of the account’s legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



3676
3677
3678
# File 'lib/stripe/services/account_service.rb', line 3676

def director
  @director
end

#executiveObject

Whether the person has significant responsibility to control, manage, or direct the organization.



3678
3679
3680
# File 'lib/stripe/services/account_service.rb', line 3678

def executive
  @executive
end

#ownerObject

Whether the person is an owner of the account’s legal entity.



3680
3681
3682
# File 'lib/stripe/services/account_service.rb', line 3680

def owner
  @owner
end

#percent_ownershipObject

The percent owned by the person of the account’s legal entity.



3682
3683
3684
# File 'lib/stripe/services/account_service.rb', line 3682

def percent_ownership
  @percent_ownership
end

#titleObject

The person’s title (e.g., CEO, Support Engineer).



3684
3685
3686
# File 'lib/stripe/services/account_service.rb', line 3684

def title
  @title
end