Class: Stripe::AccountService::CreateParams::Settings::Branding

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil) ⇒ Branding

Returns a new instance of Branding.



4241
4242
4243
4244
4245
4246
# File 'lib/stripe/services/account_service.rb', line 4241

def initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil)
  @icon = icon
  @logo = 
  @primary_color = primary_color
  @secondary_color = secondary_color
end

Instance Attribute Details

#iconObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) An icon for the account. Must be square and at least 128px x 128px.



4233
4234
4235
# File 'lib/stripe/services/account_service.rb', line 4233

def icon
  @icon
end

#logoObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) A logo for the account that will be used in Checkout instead of the icon and without the account’s name next to it if provided. Must be at least 128px x 128px.



4235
4236
4237
# File 'lib/stripe/services/account_service.rb', line 4235

def 
  @logo
end

#primary_colorObject

A CSS hex color value representing the primary branding color for this account.



4237
4238
4239
# File 'lib/stripe/services/account_service.rb', line 4237

def primary_color
  @primary_color
end

#secondary_colorObject

A CSS hex color value representing the secondary branding color for this account.



4239
4240
4241
# File 'lib/stripe/services/account_service.rb', line 4239

def secondary_color
  @secondary_color
end