Class: Stripe::AccountService::CreateParams::Settings::CardIssuing::TosAcceptance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountService::CreateParams::Settings::CardIssuing::TosAcceptance
- Defined in:
- lib/stripe/services/account_service.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the account representative accepted the service agreement.
-
#ip ⇒ Object
The IP address from which the account representative accepted the service agreement.
-
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted the service agreement.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance
constructor
A new instance of TosAcceptance.
Methods inherited from RequestParams
Constructor Details
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance
Returns a new instance of TosAcceptance.
3870 3871 3872 3873 3874 |
# File 'lib/stripe/services/account_service.rb', line 3870 def initialize(date: nil, ip: nil, user_agent: nil) @date = date @ip = ip @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the account representative accepted the service agreement.
3864 3865 3866 |
# File 'lib/stripe/services/account_service.rb', line 3864 def date @date end |
#ip ⇒ Object
The IP address from which the account representative accepted the service agreement.
3866 3867 3868 |
# File 'lib/stripe/services/account_service.rb', line 3866 def ip @ip end |
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted the service agreement.
3868 3869 3870 |
# File 'lib/stripe/services/account_service.rb', line 3868 def user_agent @user_agent end |