Class: Stripe::AccountService::CreateParams::Settings::Invoices
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountService::CreateParams::Settings::Invoices
- Defined in:
- lib/stripe/services/account_service.rb
Instance Attribute Summary collapse
-
#hosted_payment_method_save ⇒ Object
Whether payment methods should be saved when a payment is completed for a one-time invoices on a hosted invoice page.
Instance Method Summary collapse
-
#initialize(hosted_payment_method_save: nil) ⇒ Invoices
constructor
A new instance of Invoices.
Methods inherited from RequestParams
Constructor Details
#initialize(hosted_payment_method_save: nil) ⇒ Invoices
Returns a new instance of Invoices.
4458 4459 4460 |
# File 'lib/stripe/services/account_service.rb', line 4458 def initialize(hosted_payment_method_save: nil) @hosted_payment_method_save = hosted_payment_method_save end |
Instance Attribute Details
#hosted_payment_method_save ⇒ Object
Whether payment methods should be saved when a payment is completed for a one-time invoices on a hosted invoice page.
4456 4457 4458 |
# File 'lib/stripe/services/account_service.rb', line 4456 def hosted_payment_method_save @hosted_payment_method_save end |