Class: Stripe::AccountService::CreateParams::Settings::TaxForms
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountService::CreateParams::Settings::TaxForms
- Defined in:
- lib/stripe/services/account_service.rb
Instance Attribute Summary collapse
-
#consented_to_paperless_delivery ⇒ Object
Whether the account opted out of receiving their tax forms by postal delivery.
Instance Method Summary collapse
-
#initialize(consented_to_paperless_delivery: nil) ⇒ TaxForms
constructor
A new instance of TaxForms.
Methods inherited from RequestParams
Constructor Details
#initialize(consented_to_paperless_delivery: nil) ⇒ TaxForms
Returns a new instance of TaxForms.
4428 4429 4430 |
# File 'lib/stripe/services/account_service.rb', line 4428 def initialize(consented_to_paperless_delivery: nil) @consented_to_paperless_delivery = end |
Instance Attribute Details
#consented_to_paperless_delivery ⇒ Object
Whether the account opted out of receiving their tax forms by postal delivery.
4426 4427 4428 |
# File 'lib/stripe/services/account_service.rb', line 4426 def @consented_to_paperless_delivery end |