Class: Stripe::AccountService::CreateParams::Settings::Treasury::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



4000
4001
4002
4003
4004
# File 'lib/stripe/services/account_service.rb', line 4000

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



3994
3995
3996
# File 'lib/stripe/services/account_service.rb', line 3994

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



3996
3997
3998
# File 'lib/stripe/services/account_service.rb', line 3996

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



3998
3999
4000
# File 'lib/stripe/services/account_service.rb', line 3998

def user_agent
  @user_agent
end