Class: Stripe::AccountService::CreateParams::TosAcceptance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountService::CreateParams::TosAcceptance
- Defined in:
- lib/stripe/services/account_service.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the account representative accepted their service agreement.
-
#ip ⇒ Object
The IP address from which the account representative accepted their service agreement.
-
#service_agreement ⇒ Object
The user’s service agreement type.
-
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted their service agreement.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance
constructor
A new instance of TosAcceptance.
Methods inherited from RequestParams
Constructor Details
#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance
Returns a new instance of TosAcceptance.
4618 4619 4620 4621 4622 4623 |
# File 'lib/stripe/services/account_service.rb', line 4618 def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) @date = date @ip = ip @service_agreement = service_agreement @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the account representative accepted their service agreement.
4610 4611 4612 |
# File 'lib/stripe/services/account_service.rb', line 4610 def date @date end |
#ip ⇒ Object
The IP address from which the account representative accepted their service agreement.
4612 4613 4614 |
# File 'lib/stripe/services/account_service.rb', line 4612 def ip @ip end |
#service_agreement ⇒ Object
The user’s service agreement type.
4614 4615 4616 |
# File 'lib/stripe/services/account_service.rb', line 4614 def service_agreement @service_agreement end |
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted their service agreement.
4616 4617 4618 |
# File 'lib/stripe/services/account_service.rb', line 4616 def user_agent @user_agent end |