Class: Stripe::AccountService::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountService::ListParams
- Defined in:
- lib/stripe/services/account_service.rb
Defined Under Namespace
Classes: Created
Instance Attribute Summary collapse
-
#created ⇒ Object
Only return connected accounts that were created during the given date interval.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#starting_after ⇒ Object
A cursor for use in pagination.
Instance Method Summary collapse
-
#initialize(created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams
Returns a new instance of ListParams.
2078 2079 2080 2081 2082 2083 2084 |
# File 'lib/stripe/services/account_service.rb', line 2078 def initialize(created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) @created = created @ending_before = ending_before @expand = @limit = limit @starting_after = starting_after end |
Instance Attribute Details
#created ⇒ Object
Only return connected accounts that were created during the given date interval.
2068 2069 2070 |
# File 'lib/stripe/services/account_service.rb', line 2068 def created @created end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
2070 2071 2072 |
# File 'lib/stripe/services/account_service.rb', line 2070 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2072 2073 2074 |
# File 'lib/stripe/services/account_service.rb', line 2072 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
2074 2075 2076 |
# File 'lib/stripe/services/account_service.rb', line 2074 def limit @limit end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
2076 2077 2078 |
# File 'lib/stripe/services/account_service.rb', line 2076 def starting_after @starting_after end |