Class: Stripe::AccountService::RejectParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountService::RejectParams
- Defined in:
- lib/stripe/services/account_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#reason ⇒ Object
The reason for rejecting the account.
Instance Method Summary collapse
-
#initialize(expand: nil, reason: nil) ⇒ RejectParams
constructor
A new instance of RejectParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, reason: nil) ⇒ RejectParams
Returns a new instance of RejectParams.
4571 4572 4573 4574 |
# File 'lib/stripe/services/account_service.rb', line 4571 def initialize(expand: nil, reason: nil) @expand = @reason = reason end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
4567 4568 4569 |
# File 'lib/stripe/services/account_service.rb', line 4567 def @expand end |
#reason ⇒ Object
The reason for rejecting the account. Can be ‘fraud`, `terms_of_service`, or `other`.
4569 4570 4571 |
# File 'lib/stripe/services/account_service.rb', line 4569 def reason @reason end |