Class: Stripe::AccountService::RetrieveCurrentParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountService::RetrieveCurrentParams
- Defined in:
- lib/stripe/services/account_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ RetrieveCurrentParams
constructor
A new instance of RetrieveCurrentParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ RetrieveCurrentParams
Returns a new instance of RetrieveCurrentParams.
2132 2133 2134 |
# File 'lib/stripe/services/account_service.rb', line 2132 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2130 2131 2132 |
# File 'lib/stripe/services/account_service.rb', line 2130 def @expand end |