Class: Stripe::AccountService::UpdateParams::BusinessProfile

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Defined Under Namespace

Classes: AnnualRevenue, MonthlyEstimatedRevenue, SupportAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(annual_revenue: nil, estimated_worker_count: nil, mcc: nil, minority_owned_business_designation: nil, monthly_estimated_revenue: nil, name: nil, product_description: nil, support_address: nil, support_email: nil, support_phone: nil, support_url: nil, url: nil) ⇒ BusinessProfile

Returns a new instance of BusinessProfile.



146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
# File 'lib/stripe/services/account_service.rb', line 146

def initialize(
  annual_revenue: nil,
  estimated_worker_count: nil,
  mcc: nil,
  minority_owned_business_designation: nil,
  monthly_estimated_revenue: nil,
  name: nil,
  product_description: nil,
  support_address: nil,
  support_email: nil,
  support_phone: nil,
  support_url: nil,
  url: nil
)
  @annual_revenue = annual_revenue
  @estimated_worker_count = estimated_worker_count
  @mcc = mcc
  @minority_owned_business_designation = minority_owned_business_designation
  @monthly_estimated_revenue = monthly_estimated_revenue
  @name = name
  @product_description = product_description
  @support_address = support_address
  @support_email = support_email
  @support_phone = support_phone
  @support_url = support_url
  @url = url
end

Instance Attribute Details

#annual_revenueObject

The applicant’s gross annual revenue for its preceding fiscal year.



122
123
124
# File 'lib/stripe/services/account_service.rb', line 122

def annual_revenue
  @annual_revenue
end

#estimated_worker_countObject

An estimated upper bound of employees, contractors, vendors, etc. currently working for the business.



124
125
126
# File 'lib/stripe/services/account_service.rb', line 124

def estimated_worker_count
  @estimated_worker_count
end

#mccObject

[The merchant category code for the account](/connect/setting-mcc). MCCs are used to classify businesses based on the goods or services they provide.



126
127
128
# File 'lib/stripe/services/account_service.rb', line 126

def mcc
  @mcc
end

#minority_owned_business_designationObject

Whether the business is a minority-owned, women-owned, and/or LGBTQI+ -owned business.



128
129
130
# File 'lib/stripe/services/account_service.rb', line 128

def minority_owned_business_designation
  @minority_owned_business_designation
end

#monthly_estimated_revenueObject

An estimate of the monthly revenue of the business. Only accepted for accounts in Brazil and India.



130
131
132
# File 'lib/stripe/services/account_service.rb', line 130

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#nameObject

The customer-facing business name.



132
133
134
# File 'lib/stripe/services/account_service.rb', line 132

def name
  @name
end

#product_descriptionObject

Internal-only description of the product sold by, or service provided by, the business. Used by Stripe for risk and underwriting purposes.



134
135
136
# File 'lib/stripe/services/account_service.rb', line 134

def product_description
  @product_description
end

#support_addressObject

A publicly available mailing address for sending support issues to.



136
137
138
# File 'lib/stripe/services/account_service.rb', line 136

def support_address
  @support_address
end

#support_emailObject

A publicly available email address for sending support issues to.



138
139
140
# File 'lib/stripe/services/account_service.rb', line 138

def support_email
  @support_email
end

#support_phoneObject

A publicly available phone number to call with support issues.



140
141
142
# File 'lib/stripe/services/account_service.rb', line 140

def support_phone
  @support_phone
end

#support_urlObject

A publicly available website for handling support issues.



142
143
144
# File 'lib/stripe/services/account_service.rb', line 142

def support_url
  @support_url
end

#urlObject

The business’s publicly available website.



144
145
146
# File 'lib/stripe/services/account_service.rb', line 144

def url
  @url
end