Class: Stripe::AccountService::UpdateParams::BusinessProfile::AnnualRevenue
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountService::UpdateParams::BusinessProfile::AnnualRevenue
- Defined in:
- lib/stripe/services/account_service.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
A non-negative integer representing the amount in the [smallest currency unit](/currencies#zero-decimal).
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#fiscal_year_end ⇒ Object
The close-out date of the preceding fiscal year in ISO 8601 format.
Instance Method Summary collapse
-
#initialize(amount: nil, currency: nil, fiscal_year_end: nil) ⇒ AnnualRevenue
constructor
A new instance of AnnualRevenue.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, currency: nil, fiscal_year_end: nil) ⇒ AnnualRevenue
Returns a new instance of AnnualRevenue.
72 73 74 75 76 |
# File 'lib/stripe/services/account_service.rb', line 72 def initialize(amount: nil, currency: nil, fiscal_year_end: nil) @amount = amount @currency = currency @fiscal_year_end = fiscal_year_end end |
Instance Attribute Details
#amount ⇒ Object
A non-negative integer representing the amount in the [smallest currency unit](/currencies#zero-decimal).
66 67 68 |
# File 'lib/stripe/services/account_service.rb', line 66 def amount @amount end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
68 69 70 |
# File 'lib/stripe/services/account_service.rb', line 68 def currency @currency end |
#fiscal_year_end ⇒ Object
The close-out date of the preceding fiscal year in ISO 8601 format. E.g. 2023-12-31 for the 31st of December, 2023.
70 71 72 |
# File 'lib/stripe/services/account_service.rb', line 70 def fiscal_year_end @fiscal_year_end end |