Class: Stripe::AccountService::UpdateParams::Capabilities::EpsPayments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountService::UpdateParams::Capabilities::EpsPayments
- Defined in:
- lib/stripe/services/account_service.rb
Instance Attribute Summary collapse
-
#requested ⇒ Object
Passing true requests the capability for the account, if it is not already requested.
Instance Method Summary collapse
-
#initialize(requested: nil) ⇒ EpsPayments
constructor
A new instance of EpsPayments.
Methods inherited from RequestParams
Constructor Details
#initialize(requested: nil) ⇒ EpsPayments
Returns a new instance of EpsPayments.
324 325 326 |
# File 'lib/stripe/services/account_service.rb', line 324 def initialize(requested: nil) @requested = requested end |
Instance Attribute Details
#requested ⇒ Object
Passing true requests the capability for the account, if it is not already requested. A requested capability may not immediately become active. Any requirements to activate the capability are returned in the ‘requirements` arrays.
322 323 324 |
# File 'lib/stripe/services/account_service.rb', line 322 def requested @requested end |