Class: Stripe::AccountService::UpdateParams::Capabilities::SepaBankTransferPayments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountService::UpdateParams::Capabilities::SepaBankTransferPayments
- Defined in:
- lib/stripe/services/account_service.rb
Instance Attribute Summary collapse
-
#requested ⇒ Object
Passing true requests the capability for the account, if it is not already requested.
Instance Method Summary collapse
-
#initialize(requested: nil) ⇒ SepaBankTransferPayments
constructor
A new instance of SepaBankTransferPayments.
Methods inherited from RequestParams
Constructor Details
#initialize(requested: nil) ⇒ SepaBankTransferPayments
Returns a new instance of SepaBankTransferPayments.
582 583 584 |
# File 'lib/stripe/services/account_service.rb', line 582 def initialize(requested: nil) @requested = requested end |
Instance Attribute Details
#requested ⇒ Object
Passing true requests the capability for the account, if it is not already requested. A requested capability may not immediately become active. Any requirements to activate the capability are returned in the ‘requirements` arrays.
580 581 582 |
# File 'lib/stripe/services/account_service.rb', line 580 def requested @requested end |