Class: Stripe::AccountService::UpdateParams::Capabilities::SofortPayments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(requested: nil) ⇒ SofortPayments

Returns a new instance of SofortPayments.



690
691
692
# File 'lib/stripe/services/account_service.rb', line 690

def initialize(requested: nil)
  @requested = requested
end

Instance Attribute Details

#requestedObject

Passing true requests the capability for the account, if it is not already requested. A requested capability may not immediately become active. Any requirements to activate the capability are returned in the ‘requirements` arrays.



688
689
690
# File 'lib/stripe/services/account_service.rb', line 688

def requested
  @requested
end