Class: Stripe::AccountService::UpdateParams::Company::DirectorshipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ DirectorshipDeclaration

Returns a new instance of DirectorshipDeclaration.



1309
1310
1311
1312
1313
# File 'lib/stripe/services/account_service.rb', line 1309

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the directorship declaration attestation was made.



1303
1304
1305
# File 'lib/stripe/services/account_service.rb', line 1303

def date
  @date
end

#ipObject

The IP address from which the directorship declaration attestation was made.



1305
1306
1307
# File 'lib/stripe/services/account_service.rb', line 1305

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the directorship declaration attestation was made.



1307
1308
1309
# File 'lib/stripe/services/account_service.rb', line 1307

def user_agent
  @user_agent
end