Class: Stripe::AccountService::UpdateParams::Company::OwnershipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ OwnershipDeclaration

Returns a new instance of OwnershipDeclaration.



1324
1325
1326
1327
1328
# File 'lib/stripe/services/account_service.rb', line 1324

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the beneficial owner attestation was made.



1318
1319
1320
# File 'lib/stripe/services/account_service.rb', line 1318

def date
  @date
end

#ipObject

The IP address from which the beneficial owner attestation was made.



1320
1321
1322
# File 'lib/stripe/services/account_service.rb', line 1320

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the beneficial owner attestation was made.



1322
1323
1324
# File 'lib/stripe/services/account_service.rb', line 1322

def user_agent
  @user_agent
end