Class: Stripe::AccountService::UpdateParams::Groups

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(payments_pricing: nil) ⇒ Groups

Returns a new instance of Groups.



1417
1418
1419
# File 'lib/stripe/services/account_service.rb', line 1417

def initialize(payments_pricing: nil)
  @payments_pricing = payments_pricing
end

Instance Attribute Details

#payments_pricingObject

The group the account is in to determine their payments pricing, and null if the account is on customized pricing. [See the Platform pricing tool documentation](stripe.com/docs/connect/platform-pricing-tools) for details.



1415
1416
1417
# File 'lib/stripe/services/account_service.rb', line 1415

def payments_pricing
  @payments_pricing
end