Class: Stripe::AccountService::UpdateParams::Individual::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship

Returns a new instance of Relationship.



1582
1583
1584
1585
1586
1587
1588
1589
1590
1591
1592
1593
1594
# File 'lib/stripe/services/account_service.rb', line 1582

def initialize(
  director: nil,
  executive: nil,
  owner: nil,
  percent_ownership: nil,
  title: nil
)
  @director = director
  @executive = executive
  @owner = owner
  @percent_ownership = percent_ownership
  @title = title
end

Instance Attribute Details

#directorObject

Whether the person is a director of the account’s legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



1572
1573
1574
# File 'lib/stripe/services/account_service.rb', line 1572

def director
  @director
end

#executiveObject

Whether the person has significant responsibility to control, manage, or direct the organization.



1574
1575
1576
# File 'lib/stripe/services/account_service.rb', line 1574

def executive
  @executive
end

#ownerObject

Whether the person is an owner of the account’s legal entity.



1576
1577
1578
# File 'lib/stripe/services/account_service.rb', line 1576

def owner
  @owner
end

#percent_ownershipObject

The percent owned by the person of the account’s legal entity.



1578
1579
1580
# File 'lib/stripe/services/account_service.rb', line 1578

def percent_ownership
  @percent_ownership
end

#titleObject

The person’s title (e.g., CEO, Support Engineer).



1580
1581
1582
# File 'lib/stripe/services/account_service.rb', line 1580

def title
  @title
end