Class: Stripe::AccountService::UpdateParams::Individual::Verification::AdditionalDocument
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountService::UpdateParams::Individual::Verification::AdditionalDocument
- Defined in:
- lib/stripe/services/account_service.rb
Instance Attribute Summary collapse
-
#back ⇒ Object
The back of an ID returned by a [file upload](stripe.com/docs/api#create_file) with a ‘purpose` value of `identity_document`.
-
#front ⇒ Object
The front of an ID returned by a [file upload](stripe.com/docs/api#create_file) with a ‘purpose` value of `identity_document`.
Instance Method Summary collapse
-
#initialize(back: nil, front: nil) ⇒ AdditionalDocument
constructor
A new instance of AdditionalDocument.
Methods inherited from RequestParams
Constructor Details
#initialize(back: nil, front: nil) ⇒ AdditionalDocument
Returns a new instance of AdditionalDocument.
1543 1544 1545 1546 |
# File 'lib/stripe/services/account_service.rb', line 1543 def initialize(back: nil, front: nil) @back = back @front = front end |
Instance Attribute Details
#back ⇒ Object
The back of an ID returned by a [file upload](stripe.com/docs/api#create_file) with a ‘purpose` value of `identity_document`. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.
1539 1540 1541 |
# File 'lib/stripe/services/account_service.rb', line 1539 def back @back end |
#front ⇒ Object
The front of an ID returned by a [file upload](stripe.com/docs/api#create_file) with a ‘purpose` value of `identity_document`. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.
1541 1542 1543 |
# File 'lib/stripe/services/account_service.rb', line 1541 def front @front end |