Class: Stripe::AccountService::UpdateParams::Settings::Branding
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountService::UpdateParams::Settings::Branding
- Defined in:
- lib/stripe/services/account_service.rb
Instance Attribute Summary collapse
-
#icon ⇒ Object
(ID of a [file upload](stripe.com/docs/guides/file-upload)) An icon for the account.
-
#logo ⇒ Object
(ID of a [file upload](stripe.com/docs/guides/file-upload)) A logo for the account that will be used in Checkout instead of the icon and without the account’s name next to it if provided.
-
#primary_color ⇒ Object
A CSS hex color value representing the primary branding color for this account.
-
#secondary_color ⇒ Object
A CSS hex color value representing the secondary branding color for this account.
Instance Method Summary collapse
-
#initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil) ⇒ Branding
constructor
A new instance of Branding.
Methods inherited from RequestParams
Constructor Details
#initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil) ⇒ Branding
Returns a new instance of Branding.
1749 1750 1751 1752 1753 1754 |
# File 'lib/stripe/services/account_service.rb', line 1749 def initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil) @icon = icon @logo = logo @primary_color = primary_color @secondary_color = secondary_color end |
Instance Attribute Details
#icon ⇒ Object
(ID of a [file upload](stripe.com/docs/guides/file-upload)) An icon for the account. Must be square and at least 128px x 128px.
1741 1742 1743 |
# File 'lib/stripe/services/account_service.rb', line 1741 def icon @icon end |
#logo ⇒ Object
(ID of a [file upload](stripe.com/docs/guides/file-upload)) A logo for the account that will be used in Checkout instead of the icon and without the account’s name next to it if provided. Must be at least 128px x 128px.
1743 1744 1745 |
# File 'lib/stripe/services/account_service.rb', line 1743 def logo @logo end |
#primary_color ⇒ Object
A CSS hex color value representing the primary branding color for this account.
1745 1746 1747 |
# File 'lib/stripe/services/account_service.rb', line 1745 def primary_color @primary_color end |
#secondary_color ⇒ Object
A CSS hex color value representing the secondary branding color for this account.
1747 1748 1749 |
# File 'lib/stripe/services/account_service.rb', line 1747 def secondary_color @secondary_color end |