Class: Stripe::AccountService::UpdateParams::Settings::CardIssuing::TosAcceptance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountService::UpdateParams::Settings::CardIssuing::TosAcceptance
- Defined in:
- lib/stripe/services/account_service.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the account representative accepted the service agreement.
-
#ip ⇒ Object
The IP address from which the account representative accepted the service agreement.
-
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted the service agreement.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance
constructor
A new instance of TosAcceptance.
Methods inherited from RequestParams
Constructor Details
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance
Returns a new instance of TosAcceptance.
1766 1767 1768 1769 1770 |
# File 'lib/stripe/services/account_service.rb', line 1766 def initialize(date: nil, ip: nil, user_agent: nil) @date = date @ip = ip @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the account representative accepted the service agreement.
1760 1761 1762 |
# File 'lib/stripe/services/account_service.rb', line 1760 def date @date end |
#ip ⇒ Object
The IP address from which the account representative accepted the service agreement.
1762 1763 1764 |
# File 'lib/stripe/services/account_service.rb', line 1762 def ip @ip end |
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted the service agreement.
1764 1765 1766 |
# File 'lib/stripe/services/account_service.rb', line 1764 def user_agent @user_agent end |