Class: Stripe::AccountService::UpdateParams::Settings::TaxForms
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountService::UpdateParams::Settings::TaxForms
- Defined in:
- lib/stripe/services/account_service.rb
Instance Attribute Summary collapse
-
#consented_to_paperless_delivery ⇒ Object
Whether the account opted out of receiving their tax forms by postal delivery.
Instance Method Summary collapse
-
#initialize(consented_to_paperless_delivery: nil) ⇒ TaxForms
constructor
A new instance of TaxForms.
Methods inherited from RequestParams
Constructor Details
#initialize(consented_to_paperless_delivery: nil) ⇒ TaxForms
Returns a new instance of TaxForms.
2057 2058 2059 |
# File 'lib/stripe/services/account_service.rb', line 2057 def initialize(consented_to_paperless_delivery: nil) @consented_to_paperless_delivery = end |
Instance Attribute Details
#consented_to_paperless_delivery ⇒ Object
Whether the account opted out of receiving their tax forms by postal delivery.
2055 2056 2057 |
# File 'lib/stripe/services/account_service.rb', line 2055 def @consented_to_paperless_delivery end |