Class: Stripe::AccountService::UpdateParams::TosAcceptance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountService::UpdateParams::TosAcceptance
- Defined in:
- lib/stripe/services/account_service.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the account representative accepted their service agreement.
-
#ip ⇒ Object
The IP address from which the account representative accepted their service agreement.
-
#service_agreement ⇒ Object
The user’s service agreement type.
-
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted their service agreement.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance
constructor
A new instance of TosAcceptance.
Methods inherited from RequestParams
Constructor Details
#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance
Returns a new instance of TosAcceptance.
2179 2180 2181 2182 2183 2184 |
# File 'lib/stripe/services/account_service.rb', line 2179 def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) @date = date @ip = ip @service_agreement = service_agreement @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the account representative accepted their service agreement.
2171 2172 2173 |
# File 'lib/stripe/services/account_service.rb', line 2171 def date @date end |
#ip ⇒ Object
The IP address from which the account representative accepted their service agreement.
2173 2174 2175 |
# File 'lib/stripe/services/account_service.rb', line 2173 def ip @ip end |
#service_agreement ⇒ Object
The user’s service agreement type.
2175 2176 2177 |
# File 'lib/stripe/services/account_service.rb', line 2175 def service_agreement @service_agreement end |
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted their service agreement.
2177 2178 2179 |
# File 'lib/stripe/services/account_service.rb', line 2177 def user_agent @user_agent end |