Class: Stripe::AccountSession::Components::Bills::Features
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::AccountSession::Components::Bills::Features
- Defined in:
- lib/stripe/resources/account_session.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bill_management ⇒ Object
readonly
Whether to enable the bill management feature that grants access to bill creation and payment.
-
#disable_stripe_user_authentication ⇒ Object
readonly
Whether Stripe user authentication is disabled.
-
#send_money ⇒ Object
readonly
Whether to enable the send money feature that grants access to bill creation and payment.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bill_management ⇒ Object (readonly)
Whether to enable the bill management feature that grants access to bill creation and payment.
165 166 167 |
# File 'lib/stripe/resources/account_session.rb', line 165 def bill_management @bill_management end |
#disable_stripe_user_authentication ⇒ Object (readonly)
Whether Stripe user authentication is disabled. This value can only be true for accounts where controller.requirement_collection is application for the account. This is false by default.
167 168 169 |
# File 'lib/stripe/resources/account_session.rb', line 167 def disable_stripe_user_authentication @disable_stripe_user_authentication end |
#send_money ⇒ Object (readonly)
Whether to enable the send money feature that grants access to bill creation and payment.
169 170 171 |
# File 'lib/stripe/resources/account_session.rb', line 169 def send_money @send_money end |
Class Method Details
.field_remappings ⇒ Object
175 176 177 |
# File 'lib/stripe/resources/account_session.rb', line 175 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
171 172 173 |
# File 'lib/stripe/resources/account_session.rb', line 171 def self.inner_class_types @inner_class_types = {} end |