Class: Stripe::AccountSession::Components::IssuingCardsList::Features

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/account_session.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#card_managementObject (readonly)

Whether to allow card management features.



163
164
165
# File 'lib/stripe/resources/account_session.rb', line 163

def card_management
  @card_management
end

#card_spend_dispute_managementObject (readonly)

Whether to allow card spend dispute management features.



165
166
167
# File 'lib/stripe/resources/account_session.rb', line 165

def card_spend_dispute_management
  @card_spend_dispute_management
end

#cardholder_managementObject (readonly)

Whether to allow cardholder management features.



167
168
169
# File 'lib/stripe/resources/account_session.rb', line 167

def cardholder_management
  @cardholder_management
end

#disable_stripe_user_authenticationObject (readonly)

Disables Stripe user authentication for this embedded component. This feature can only be false for accounts where you’re responsible for collecting updated information when requirements are due or change, like custom accounts.



169
170
171
# File 'lib/stripe/resources/account_session.rb', line 169

def disable_stripe_user_authentication
  @disable_stripe_user_authentication
end

#spend_control_managementObject (readonly)

Whether to allow spend control management features.



171
172
173
# File 'lib/stripe/resources/account_session.rb', line 171

def spend_control_management
  @spend_control_management
end