Class: Stripe::AccountSession::Components::Payments::Features
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::AccountSession::Components::Payments::Features
- Defined in:
- lib/stripe/resources/account_session.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#capture_payments ⇒ Object
readonly
Whether to allow capturing and cancelling payment intents.
-
#destination_on_behalf_of_charge_management ⇒ Object
readonly
Whether connected accounts can manage destination charges that are created on behalf of them.
-
#dispute_management ⇒ Object
readonly
Whether responding to disputes is enabled, including submitting evidence and accepting disputes.
-
#refund_management ⇒ Object
readonly
Whether sending refunds is enabled.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#capture_payments ⇒ Object (readonly)
Whether to allow capturing and cancelling payment intents. This is ‘true` by default.
618 619 620 |
# File 'lib/stripe/resources/account_session.rb', line 618 def capture_payments @capture_payments end |
#destination_on_behalf_of_charge_management ⇒ Object (readonly)
Whether connected accounts can manage destination charges that are created on behalf of them. This is ‘false` by default.
620 621 622 |
# File 'lib/stripe/resources/account_session.rb', line 620 def destination_on_behalf_of_charge_management @destination_on_behalf_of_charge_management end |
#dispute_management ⇒ Object (readonly)
Whether responding to disputes is enabled, including submitting evidence and accepting disputes. This is ‘true` by default.
622 623 624 |
# File 'lib/stripe/resources/account_session.rb', line 622 def dispute_management @dispute_management end |
#refund_management ⇒ Object (readonly)
Whether sending refunds is enabled. This is ‘true` by default.
624 625 626 |
# File 'lib/stripe/resources/account_session.rb', line 624 def refund_management @refund_management end |
Class Method Details
.field_remappings ⇒ Object
630 631 632 |
# File 'lib/stripe/resources/account_session.rb', line 630 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
626 627 628 |
# File 'lib/stripe/resources/account_session.rb', line 626 def self.inner_class_types @inner_class_types = {} end |