Class: Stripe::AccountSession::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSession::CreateParams
- Defined in:
- lib/stripe/resources/account_session.rb
Defined Under Namespace
Classes: Components
Instance Attribute Summary collapse
-
#account ⇒ Object
The identifier of the account to create an Account Session for.
-
#components ⇒ Object
Each key of the dictionary represents an embedded component, and each embedded component maps to its configuration (e.g. whether it has been enabled or not).
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(account: nil, components: nil, expand: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(account: nil, components: nil, expand: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
1644 1645 1646 1647 1648 |
# File 'lib/stripe/resources/account_session.rb', line 1644 def initialize(account: nil, components: nil, expand: nil) @account = account @components = components @expand = end |
Instance Attribute Details
#account ⇒ Object
The identifier of the account to create an Account Session for.
1638 1639 1640 |
# File 'lib/stripe/resources/account_session.rb', line 1638 def account @account end |
#components ⇒ Object
Each key of the dictionary represents an embedded component, and each embedded component maps to its configuration (e.g. whether it has been enabled or not).
1640 1641 1642 |
# File 'lib/stripe/resources/account_session.rb', line 1640 def components @components end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1642 1643 1644 |
# File 'lib/stripe/resources/account_session.rb', line 1642 def @expand end |