Class: Stripe::AccountSession::CreateParams::Components
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSession::CreateParams::Components
- Defined in:
- lib/stripe/resources/account_session.rb
Defined Under Namespace
Classes: AccountManagement, AccountOnboarding, AppInstall, AppViewport, Balances, CapitalFinancing, CapitalFinancingApplication, CapitalFinancingPromotion, CapitalOverview, Documents, ExportTaxTransactions, FinancialAccount, FinancialAccountTransactions, IssuingCard, IssuingCardsList, NotificationBanner, PaymentDetails, PaymentDisputes, PaymentMethodSettings, Payments, Payouts, PayoutsList, ProductTaxCodeSelector, Recipients, ReportingChart, TaxRegistrations, TaxSettings, TaxThresholdMonitoring
Instance Attribute Summary collapse
-
#account_management ⇒ Object
Configuration for the account management embedded component.
-
#account_onboarding ⇒ Object
Configuration for the account onboarding embedded component.
-
#app_install ⇒ Object
Configuration for the app install component.
-
#app_viewport ⇒ Object
Configuration for the app viewport component.
-
#balances ⇒ Object
Configuration for the balances embedded component.
-
#capital_financing ⇒ Object
Configuration for the capital financing embedded component.
-
#capital_financing_application ⇒ Object
Configuration for the capital financing application embedded component.
-
#capital_financing_promotion ⇒ Object
Configuration for the capital financing promotion embedded component.
-
#capital_overview ⇒ Object
Configuration for the capital overview embedded component.
-
#documents ⇒ Object
Configuration for the documents embedded component.
-
#export_tax_transactions ⇒ Object
Configuration for the export tax transactions embedded component.
-
#financial_account ⇒ Object
Configuration for the financial account embedded component.
-
#financial_account_transactions ⇒ Object
Configuration for the financial account transactions embedded component.
-
#issuing_card ⇒ Object
Configuration for the issuing card embedded component.
-
#issuing_cards_list ⇒ Object
Configuration for the issuing cards list embedded component.
-
#notification_banner ⇒ Object
Configuration for the notification banner embedded component.
-
#payment_details ⇒ Object
Configuration for the payment details embedded component.
-
#payment_disputes ⇒ Object
Configuration for the payment disputes embedded component.
-
#payment_method_settings ⇒ Object
Configuration for the payment method settings embedded component.
-
#payments ⇒ Object
Configuration for the payments embedded component.
-
#payouts ⇒ Object
Configuration for the payouts embedded component.
-
#payouts_list ⇒ Object
Configuration for the payouts list embedded component.
-
#product_tax_code_selector ⇒ Object
Configuration for the product tax code selector embedded component.
-
#recipients ⇒ Object
Configuration for the recipients component.
-
#reporting_chart ⇒ Object
Configuration for the reporting chart embedded component.
-
#tax_registrations ⇒ Object
Configuration for the tax registrations embedded component.
-
#tax_settings ⇒ Object
Configuration for the tax settings embedded component.
-
#tax_threshold_monitoring ⇒ Object
Configuration for the tax threshold monitoring embedded component.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(account_management: nil, account_onboarding: nil, app_install: nil, app_viewport: nil, balances: nil, capital_financing: nil, capital_financing_application: nil, capital_financing_promotion: nil, capital_overview: nil, documents: nil, export_tax_transactions: nil, financial_account: nil, financial_account_transactions: nil, issuing_card: nil, issuing_cards_list: nil, notification_banner: nil, payment_details: nil, payment_disputes: nil, payment_method_settings: nil, payments: nil, payouts: nil, payouts_list: nil, product_tax_code_selector: nil, recipients: nil, reporting_chart: nil, tax_registrations: nil, tax_settings: nil, tax_threshold_monitoring: nil) ⇒ Components
Returns a new instance of Components.
967 968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 |
# File 'lib/stripe/resources/account_session.rb', line 967 def initialize( account_management: nil, account_onboarding: nil, app_install: nil, app_viewport: nil, balances: nil, capital_financing: nil, capital_financing_application: nil, capital_financing_promotion: nil, capital_overview: nil, documents: nil, export_tax_transactions: nil, financial_account: nil, financial_account_transactions: nil, issuing_card: nil, issuing_cards_list: nil, notification_banner: nil, payment_details: nil, payment_disputes: nil, payment_method_settings: nil, payments: nil, payouts: nil, payouts_list: nil, product_tax_code_selector: nil, recipients: nil, reporting_chart: nil, tax_registrations: nil, tax_settings: nil, tax_threshold_monitoring: nil ) @account_management = account_management @account_onboarding = account_onboarding @app_install = app_install @app_viewport = @balances = balances @capital_financing = capital_financing @capital_financing_application = capital_financing_application @capital_financing_promotion = capital_financing_promotion @capital_overview = capital_overview @documents = documents @export_tax_transactions = export_tax_transactions @financial_account = financial_account @financial_account_transactions = financial_account_transactions @issuing_card = issuing_card @issuing_cards_list = issuing_cards_list @notification_banner = @payment_details = payment_details @payment_disputes = payment_disputes @payment_method_settings = payment_method_settings @payments = payments @payouts = payouts @payouts_list = payouts_list @product_tax_code_selector = product_tax_code_selector @recipients = recipients @reporting_chart = reporting_chart @tax_registrations = tax_registrations @tax_settings = tax_settings @tax_threshold_monitoring = tax_threshold_monitoring end |
Instance Attribute Details
#account_management ⇒ Object
Configuration for the account management embedded component.
911 912 913 |
# File 'lib/stripe/resources/account_session.rb', line 911 def account_management @account_management end |
#account_onboarding ⇒ Object
Configuration for the account onboarding embedded component.
913 914 915 |
# File 'lib/stripe/resources/account_session.rb', line 913 def account_onboarding @account_onboarding end |
#app_install ⇒ Object
Configuration for the app install component.
915 916 917 |
# File 'lib/stripe/resources/account_session.rb', line 915 def app_install @app_install end |
#app_viewport ⇒ Object
Configuration for the app viewport component.
917 918 919 |
# File 'lib/stripe/resources/account_session.rb', line 917 def @app_viewport end |
#balances ⇒ Object
Configuration for the balances embedded component.
919 920 921 |
# File 'lib/stripe/resources/account_session.rb', line 919 def balances @balances end |
#capital_financing ⇒ Object
Configuration for the capital financing embedded component.
921 922 923 |
# File 'lib/stripe/resources/account_session.rb', line 921 def capital_financing @capital_financing end |
#capital_financing_application ⇒ Object
Configuration for the capital financing application embedded component.
923 924 925 |
# File 'lib/stripe/resources/account_session.rb', line 923 def capital_financing_application @capital_financing_application end |
#capital_financing_promotion ⇒ Object
Configuration for the capital financing promotion embedded component.
925 926 927 |
# File 'lib/stripe/resources/account_session.rb', line 925 def capital_financing_promotion @capital_financing_promotion end |
#capital_overview ⇒ Object
Configuration for the capital overview embedded component.
927 928 929 |
# File 'lib/stripe/resources/account_session.rb', line 927 def capital_overview @capital_overview end |
#documents ⇒ Object
Configuration for the documents embedded component.
929 930 931 |
# File 'lib/stripe/resources/account_session.rb', line 929 def documents @documents end |
#export_tax_transactions ⇒ Object
Configuration for the export tax transactions embedded component.
931 932 933 |
# File 'lib/stripe/resources/account_session.rb', line 931 def export_tax_transactions @export_tax_transactions end |
#financial_account ⇒ Object
Configuration for the financial account embedded component.
933 934 935 |
# File 'lib/stripe/resources/account_session.rb', line 933 def financial_account @financial_account end |
#financial_account_transactions ⇒ Object
Configuration for the financial account transactions embedded component.
935 936 937 |
# File 'lib/stripe/resources/account_session.rb', line 935 def financial_account_transactions @financial_account_transactions end |
#issuing_card ⇒ Object
Configuration for the issuing card embedded component.
937 938 939 |
# File 'lib/stripe/resources/account_session.rb', line 937 def issuing_card @issuing_card end |
#issuing_cards_list ⇒ Object
Configuration for the issuing cards list embedded component.
939 940 941 |
# File 'lib/stripe/resources/account_session.rb', line 939 def issuing_cards_list @issuing_cards_list end |
#notification_banner ⇒ Object
Configuration for the notification banner embedded component.
941 942 943 |
# File 'lib/stripe/resources/account_session.rb', line 941 def @notification_banner end |
#payment_details ⇒ Object
Configuration for the payment details embedded component.
943 944 945 |
# File 'lib/stripe/resources/account_session.rb', line 943 def payment_details @payment_details end |
#payment_disputes ⇒ Object
Configuration for the payment disputes embedded component.
945 946 947 |
# File 'lib/stripe/resources/account_session.rb', line 945 def payment_disputes @payment_disputes end |
#payment_method_settings ⇒ Object
Configuration for the payment method settings embedded component.
947 948 949 |
# File 'lib/stripe/resources/account_session.rb', line 947 def payment_method_settings @payment_method_settings end |
#payments ⇒ Object
Configuration for the payments embedded component.
949 950 951 |
# File 'lib/stripe/resources/account_session.rb', line 949 def payments @payments end |
#payouts ⇒ Object
Configuration for the payouts embedded component.
951 952 953 |
# File 'lib/stripe/resources/account_session.rb', line 951 def payouts @payouts end |
#payouts_list ⇒ Object
Configuration for the payouts list embedded component.
953 954 955 |
# File 'lib/stripe/resources/account_session.rb', line 953 def payouts_list @payouts_list end |
#product_tax_code_selector ⇒ Object
Configuration for the product tax code selector embedded component.
955 956 957 |
# File 'lib/stripe/resources/account_session.rb', line 955 def product_tax_code_selector @product_tax_code_selector end |
#recipients ⇒ Object
Configuration for the recipients component.
957 958 959 |
# File 'lib/stripe/resources/account_session.rb', line 957 def recipients @recipients end |
#reporting_chart ⇒ Object
Configuration for the reporting chart embedded component.
959 960 961 |
# File 'lib/stripe/resources/account_session.rb', line 959 def reporting_chart @reporting_chart end |
#tax_registrations ⇒ Object
Configuration for the tax registrations embedded component.
961 962 963 |
# File 'lib/stripe/resources/account_session.rb', line 961 def tax_registrations @tax_registrations end |
#tax_settings ⇒ Object
Configuration for the tax settings embedded component.
963 964 965 |
# File 'lib/stripe/resources/account_session.rb', line 963 def tax_settings @tax_settings end |
#tax_threshold_monitoring ⇒ Object
Configuration for the tax threshold monitoring embedded component.
965 966 967 |
# File 'lib/stripe/resources/account_session.rb', line 965 def tax_threshold_monitoring @tax_threshold_monitoring end |