Class: Stripe::AccountSession::CreateParams::Components::AccountManagement::Features
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSession::CreateParams::Components::AccountManagement::Features
- Defined in:
- lib/stripe/resources/account_session.rb
Instance Attribute Summary collapse
-
#disable_stripe_user_authentication ⇒ Object
Disables Stripe user authentication for this embedded component.
-
#external_account_collection ⇒ Object
Whether to allow platforms to control bank account collection for their connected accounts.
Instance Method Summary collapse
-
#initialize(disable_stripe_user_authentication: nil, external_account_collection: nil) ⇒ Features
constructor
A new instance of Features.
Methods inherited from RequestParams
Constructor Details
#initialize(disable_stripe_user_authentication: nil, external_account_collection: nil) ⇒ Features
Returns a new instance of Features.
334 335 336 337 338 339 340 |
# File 'lib/stripe/resources/account_session.rb', line 334 def initialize( disable_stripe_user_authentication: nil, external_account_collection: nil ) @disable_stripe_user_authentication = disable_stripe_user_authentication @external_account_collection = external_account_collection end |
Instance Attribute Details
#disable_stripe_user_authentication ⇒ Object
Disables Stripe user authentication for this embedded component. This value can only be true for accounts where ‘controller.requirement_collection` is `application`. The default value is the opposite of the `external_account_collection` value. For example, if you don’t set `external_account_collection`, it defaults to true and `disable_stripe_user_authentication` defaults to false.
330 331 332 |
# File 'lib/stripe/resources/account_session.rb', line 330 def disable_stripe_user_authentication @disable_stripe_user_authentication end |
#external_account_collection ⇒ Object
Whether to allow platforms to control bank account collection for their connected accounts. This feature can only be false for accounts where you’re responsible for collecting updated information when requirements are due or change, like custom accounts. Otherwise, bank account collection is determined by compliance requirements. The default value for this feature is ‘true`.
332 333 334 |
# File 'lib/stripe/resources/account_session.rb', line 332 def external_account_collection @external_account_collection end |