Class: Stripe::AccountSession::CreateParams::Components::AppInstall
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSession::CreateParams::Components::AppInstall
- Defined in:
- lib/stripe/resources/account_session.rb
Defined Under Namespace
Classes: Features
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Whether the embedded component is enabled.
-
#features ⇒ Object
The list of features enabled in the embedded component.
Instance Method Summary collapse
-
#initialize(enabled: nil, features: nil) ⇒ AppInstall
constructor
A new instance of AppInstall.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, features: nil) ⇒ AppInstall
Returns a new instance of AppInstall.
857 858 859 860 |
# File 'lib/stripe/resources/account_session.rb', line 857 def initialize(enabled: nil, features: nil) @enabled = enabled @features = features end |
Instance Attribute Details
#enabled ⇒ Object
Whether the embedded component is enabled.
853 854 855 |
# File 'lib/stripe/resources/account_session.rb', line 853 def enabled @enabled end |
#features ⇒ Object
The list of features enabled in the embedded component.
855 856 857 |
# File 'lib/stripe/resources/account_session.rb', line 855 def features @features end |