Class: Stripe::AccountSession::CreateParams::Components::AppViewport::Features
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSession::CreateParams::Components::AppViewport::Features
- Defined in:
- lib/stripe/resources/account_session.rb
Instance Attribute Summary collapse
-
#allowed_apps ⇒ Object
List of apps allowed to be enabled for this account session.
Instance Method Summary collapse
-
#initialize(allowed_apps: nil) ⇒ Features
constructor
A new instance of Features.
Methods inherited from RequestParams
Constructor Details
#initialize(allowed_apps: nil) ⇒ Features
Returns a new instance of Features.
345 346 347 |
# File 'lib/stripe/resources/account_session.rb', line 345 def initialize(allowed_apps: nil) @allowed_apps = allowed_apps end |
Instance Attribute Details
#allowed_apps ⇒ Object
List of apps allowed to be enabled for this account session.
343 344 345 |
# File 'lib/stripe/resources/account_session.rb', line 343 def allowed_apps @allowed_apps end |