Class: Stripe::AccountSession::CreateParams::Components::Balances
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSession::CreateParams::Components::Balances
- Defined in:
- lib/stripe/resources/account_session.rb
Defined Under Namespace
Classes: Features
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Whether the embedded component is enabled.
-
#features ⇒ Object
The list of features enabled in the embedded component.
Instance Method Summary collapse
-
#initialize(enabled: nil, features: nil) ⇒ Balances
constructor
A new instance of Balances.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, features: nil) ⇒ Balances
Returns a new instance of Balances.
441 442 443 444 |
# File 'lib/stripe/resources/account_session.rb', line 441 def initialize(enabled: nil, features: nil) @enabled = enabled @features = features end |
Instance Attribute Details
#enabled ⇒ Object
Whether the embedded component is enabled.
437 438 439 |
# File 'lib/stripe/resources/account_session.rb', line 437 def enabled @enabled end |
#features ⇒ Object
The list of features enabled in the embedded component.
439 440 441 |
# File 'lib/stripe/resources/account_session.rb', line 439 def features @features end |