Class: Stripe::AccountSession::CreateParams::Components::CapitalFinancingApplication
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSession::CreateParams::Components::CapitalFinancingApplication
- Defined in:
- lib/stripe/resources/account_session.rb
Defined Under Namespace
Classes: Features
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Whether the embedded component is enabled.
-
#features ⇒ Object
The list of features enabled in the embedded component.
Instance Method Summary collapse
-
#initialize(enabled: nil, features: nil) ⇒ CapitalFinancingApplication
constructor
A new instance of CapitalFinancingApplication.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, features: nil) ⇒ CapitalFinancingApplication
Returns a new instance of CapitalFinancingApplication.
477 478 479 480 |
# File 'lib/stripe/resources/account_session.rb', line 477 def initialize(enabled: nil, features: nil) @enabled = enabled @features = features end |
Instance Attribute Details
#enabled ⇒ Object
Whether the embedded component is enabled.
473 474 475 |
# File 'lib/stripe/resources/account_session.rb', line 473 def enabled @enabled end |
#features ⇒ Object
The list of features enabled in the embedded component.
475 476 477 |
# File 'lib/stripe/resources/account_session.rb', line 475 def features @features end |