Class: Stripe::AccountSession::CreateParams::Components::CapitalFinancingPromotion
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSession::CreateParams::Components::CapitalFinancingPromotion
- Defined in:
- lib/stripe/resources/account_session.rb
Defined Under Namespace
Classes: Features
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Whether the embedded component is enabled.
-
#features ⇒ Object
An empty list, because this embedded component has no features.
Instance Method Summary collapse
-
#initialize(enabled: nil, features: nil) ⇒ CapitalFinancingPromotion
constructor
A new instance of CapitalFinancingPromotion.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, features: nil) ⇒ CapitalFinancingPromotion
Returns a new instance of CapitalFinancingPromotion.
550 551 552 553 |
# File 'lib/stripe/resources/account_session.rb', line 550 def initialize(enabled: nil, features: nil) @enabled = enabled @features = features end |
Instance Attribute Details
#enabled ⇒ Object
Whether the embedded component is enabled.
546 547 548 |
# File 'lib/stripe/resources/account_session.rb', line 546 def enabled @enabled end |
#features ⇒ Object
An empty list, because this embedded component has no features.
548 549 550 |
# File 'lib/stripe/resources/account_session.rb', line 548 def features @features end |