Class: Stripe::AccountSession::CreateParams::Components::DisputesList::Features
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSession::CreateParams::Components::DisputesList::Features
- Defined in:
- lib/stripe/resources/account_session.rb
Instance Attribute Summary collapse
-
#capture_payments ⇒ Object
Whether to allow capturing and cancelling payment intents.
-
#destination_on_behalf_of_charge_management ⇒ Object
Whether connected accounts can manage destination charges that are created on behalf of them.
-
#dispute_management ⇒ Object
Whether responding to disputes is enabled, including submitting evidence and accepting disputes.
-
#refund_management ⇒ Object
Whether sending refunds is enabled.
Instance Method Summary collapse
-
#initialize(capture_payments: nil, destination_on_behalf_of_charge_management: nil, dispute_management: nil, refund_management: nil) ⇒ Features
constructor
A new instance of Features.
Methods inherited from RequestParams
Constructor Details
#initialize(capture_payments: nil, destination_on_behalf_of_charge_management: nil, dispute_management: nil, refund_management: nil) ⇒ Features
Returns a new instance of Features.
580 581 582 583 584 585 586 587 588 589 590 |
# File 'lib/stripe/resources/account_session.rb', line 580 def initialize( capture_payments: nil, destination_on_behalf_of_charge_management: nil, dispute_management: nil, refund_management: nil ) @capture_payments = capture_payments @destination_on_behalf_of_charge_management = destination_on_behalf_of_charge_management @dispute_management = dispute_management @refund_management = refund_management end |
Instance Attribute Details
#capture_payments ⇒ Object
Whether to allow capturing and cancelling payment intents. This is ‘true` by default.
572 573 574 |
# File 'lib/stripe/resources/account_session.rb', line 572 def capture_payments @capture_payments end |
#destination_on_behalf_of_charge_management ⇒ Object
Whether connected accounts can manage destination charges that are created on behalf of them. This is ‘false` by default.
574 575 576 |
# File 'lib/stripe/resources/account_session.rb', line 574 def destination_on_behalf_of_charge_management @destination_on_behalf_of_charge_management end |
#dispute_management ⇒ Object
Whether responding to disputes is enabled, including submitting evidence and accepting disputes. This is ‘true` by default.
576 577 578 |
# File 'lib/stripe/resources/account_session.rb', line 576 def dispute_management @dispute_management end |
#refund_management ⇒ Object
Whether sending refunds is enabled. This is ‘true` by default.
578 579 580 |
# File 'lib/stripe/resources/account_session.rb', line 578 def refund_management @refund_management end |