Class: Stripe::AccountSession::CreateParams::Components::IssuingCard
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSession::CreateParams::Components::IssuingCard
- Defined in:
- lib/stripe/resources/account_session.rb
Defined Under Namespace
Classes: Features
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Whether the embedded component is enabled.
-
#features ⇒ Object
The list of features enabled in the embedded component.
Instance Method Summary collapse
-
#initialize(enabled: nil, features: nil) ⇒ IssuingCard
constructor
A new instance of IssuingCard.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, features: nil) ⇒ IssuingCard
Returns a new instance of IssuingCard.
1158 1159 1160 1161 |
# File 'lib/stripe/resources/account_session.rb', line 1158 def initialize(enabled: nil, features: nil) @enabled = enabled @features = features end |
Instance Attribute Details
#enabled ⇒ Object
Whether the embedded component is enabled.
1154 1155 1156 |
# File 'lib/stripe/resources/account_session.rb', line 1154 def enabled @enabled end |
#features ⇒ Object
The list of features enabled in the embedded component.
1156 1157 1158 |
# File 'lib/stripe/resources/account_session.rb', line 1156 def features @features end |