Class: Stripe::AccountSession::CreateParams::Components::NotificationBanner::Features
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSession::CreateParams::Components::NotificationBanner::Features
- Defined in:
- lib/stripe/resources/account_session.rb
Instance Attribute Summary collapse
-
#disable_stripe_user_authentication ⇒ Object
Disables Stripe user authentication for this embedded component.
-
#external_account_collection ⇒ Object
Whether to allow platforms to control bank account collection for their connected accounts.
Instance Method Summary collapse
-
#initialize(disable_stripe_user_authentication: nil, external_account_collection: nil) ⇒ Features
constructor
A new instance of Features.
Methods inherited from RequestParams
Constructor Details
#initialize(disable_stripe_user_authentication: nil, external_account_collection: nil) ⇒ Features
Returns a new instance of Features.
567 568 569 570 571 572 573 |
# File 'lib/stripe/resources/account_session.rb', line 567 def initialize( disable_stripe_user_authentication: nil, external_account_collection: nil ) @disable_stripe_user_authentication = disable_stripe_user_authentication @external_account_collection = external_account_collection end |
Instance Attribute Details
#disable_stripe_user_authentication ⇒ Object
Disables Stripe user authentication for this embedded component. This value can only be true for accounts where ‘controller.requirement_collection` is `application`. The default value is the opposite of the `external_account_collection` value. For example, if you don’t set `external_account_collection`, it defaults to true and `disable_stripe_user_authentication` defaults to false.
563 564 565 |
# File 'lib/stripe/resources/account_session.rb', line 563 def disable_stripe_user_authentication @disable_stripe_user_authentication end |
#external_account_collection ⇒ Object
Whether to allow platforms to control bank account collection for their connected accounts. This feature can only be false for accounts where you’re responsible for collecting updated information when requirements are due or change, like custom accounts. Otherwise, bank account collection is determined by compliance requirements. The default value for this feature is ‘true`.
565 566 567 |
# File 'lib/stripe/resources/account_session.rb', line 565 def external_account_collection @external_account_collection end |