Class: Stripe::AccountSession::CreateParams::Components::PaymentDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSession::CreateParams::Components::PaymentDetails
- Defined in:
- lib/stripe/resources/account_session.rb
Defined Under Namespace
Classes: Features
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Whether the embedded component is enabled.
-
#features ⇒ Object
The list of features enabled in the embedded component.
Instance Method Summary collapse
-
#initialize(enabled: nil, features: nil) ⇒ PaymentDetails
constructor
A new instance of PaymentDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, features: nil) ⇒ PaymentDetails
Returns a new instance of PaymentDetails.
671 672 673 674 |
# File 'lib/stripe/resources/account_session.rb', line 671 def initialize(enabled: nil, features: nil) @enabled = enabled @features = features end |
Instance Attribute Details
#enabled ⇒ Object
Whether the embedded component is enabled.
667 668 669 |
# File 'lib/stripe/resources/account_session.rb', line 667 def enabled @enabled end |
#features ⇒ Object
The list of features enabled in the embedded component.
669 670 671 |
# File 'lib/stripe/resources/account_session.rb', line 669 def features @features end |