Class: Stripe::AccountSession::CreateParams::Components::PaymentDisputes::Features
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSession::CreateParams::Components::PaymentDisputes::Features
- Defined in:
- lib/stripe/resources/account_session.rb
Instance Attribute Summary collapse
-
#destination_on_behalf_of_charge_management ⇒ Object
Whether connected accounts can manage destination charges that are created on behalf of them.
-
#dispute_management ⇒ Object
Whether responding to disputes is enabled, including submitting evidence and accepting disputes.
-
#refund_management ⇒ Object
Whether sending refunds is enabled.
Instance Method Summary collapse
-
#initialize(destination_on_behalf_of_charge_management: nil, dispute_management: nil, refund_management: nil) ⇒ Features
constructor
A new instance of Features.
Methods inherited from RequestParams
Constructor Details
#initialize(destination_on_behalf_of_charge_management: nil, dispute_management: nil, refund_management: nil) ⇒ Features
Returns a new instance of Features.
811 812 813 814 815 816 817 818 819 |
# File 'lib/stripe/resources/account_session.rb', line 811 def initialize( destination_on_behalf_of_charge_management: nil, dispute_management: nil, refund_management: nil ) @destination_on_behalf_of_charge_management = destination_on_behalf_of_charge_management @dispute_management = dispute_management @refund_management = refund_management end |
Instance Attribute Details
#destination_on_behalf_of_charge_management ⇒ Object
Whether connected accounts can manage destination charges that are created on behalf of them. This is ‘false` by default.
805 806 807 |
# File 'lib/stripe/resources/account_session.rb', line 805 def destination_on_behalf_of_charge_management @destination_on_behalf_of_charge_management end |
#dispute_management ⇒ Object
Whether responding to disputes is enabled, including submitting evidence and accepting disputes. This is ‘true` by default.
807 808 809 |
# File 'lib/stripe/resources/account_session.rb', line 807 def dispute_management @dispute_management end |
#refund_management ⇒ Object
Whether sending refunds is enabled. This is ‘true` by default.
809 810 811 |
# File 'lib/stripe/resources/account_session.rb', line 809 def refund_management @refund_management end |