Class: Stripe::AccountSession::CreateParams::Components::Payments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSession::CreateParams::Components::Payments
- Defined in:
- lib/stripe/resources/account_session.rb
Defined Under Namespace
Classes: Features
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Whether the embedded component is enabled.
-
#features ⇒ Object
The list of features enabled in the embedded component.
Instance Method Summary collapse
-
#initialize(enabled: nil, features: nil) ⇒ Payments
constructor
A new instance of Payments.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, features: nil) ⇒ Payments
Returns a new instance of Payments.
725 726 727 728 |
# File 'lib/stripe/resources/account_session.rb', line 725 def initialize(enabled: nil, features: nil) @enabled = enabled @features = features end |
Instance Attribute Details
#enabled ⇒ Object
Whether the embedded component is enabled.
721 722 723 |
# File 'lib/stripe/resources/account_session.rb', line 721 def enabled @enabled end |
#features ⇒ Object
The list of features enabled in the embedded component.
723 724 725 |
# File 'lib/stripe/resources/account_session.rb', line 723 def features @features end |