Class: Stripe::AccountSession::CreateParams::Components::Payments::Features
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSession::CreateParams::Components::Payments::Features
- Defined in:
- lib/stripe/resources/account_session.rb
Instance Attribute Summary collapse
-
#capture_payments ⇒ Object
Whether to allow capturing and cancelling payment intents.
-
#destination_on_behalf_of_charge_management ⇒ Object
Whether to allow connected accounts to manage destination charges that are created on behalf of them.
-
#dispute_management ⇒ Object
Whether to allow responding to disputes, including submitting evidence and accepting disputes.
-
#refund_management ⇒ Object
Whether to allow sending refunds.
Instance Method Summary collapse
-
#initialize(capture_payments: nil, destination_on_behalf_of_charge_management: nil, dispute_management: nil, refund_management: nil) ⇒ Features
constructor
A new instance of Features.
Methods inherited from RequestParams
Constructor Details
#initialize(capture_payments: nil, destination_on_behalf_of_charge_management: nil, dispute_management: nil, refund_management: nil) ⇒ Features
Returns a new instance of Features.
809 810 811 812 813 814 815 816 817 818 819 |
# File 'lib/stripe/resources/account_session.rb', line 809 def initialize( capture_payments: nil, destination_on_behalf_of_charge_management: nil, dispute_management: nil, refund_management: nil ) @capture_payments = capture_payments @destination_on_behalf_of_charge_management = destination_on_behalf_of_charge_management @dispute_management = dispute_management @refund_management = refund_management end |
Instance Attribute Details
#capture_payments ⇒ Object
Whether to allow capturing and cancelling payment intents. This is ‘true` by default.
801 802 803 |
# File 'lib/stripe/resources/account_session.rb', line 801 def capture_payments @capture_payments end |
#destination_on_behalf_of_charge_management ⇒ Object
Whether to allow connected accounts to manage destination charges that are created on behalf of them. This is ‘false` by default.
803 804 805 |
# File 'lib/stripe/resources/account_session.rb', line 803 def destination_on_behalf_of_charge_management @destination_on_behalf_of_charge_management end |
#dispute_management ⇒ Object
Whether to allow responding to disputes, including submitting evidence and accepting disputes. This is ‘true` by default.
805 806 807 |
# File 'lib/stripe/resources/account_session.rb', line 805 def dispute_management @dispute_management end |
#refund_management ⇒ Object
Whether to allow sending refunds. This is ‘true` by default.
807 808 809 |
# File 'lib/stripe/resources/account_session.rb', line 807 def refund_management @refund_management end |