Class: Stripe::AccountSession::CreateParams::Components::PayoutsList
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSession::CreateParams::Components::PayoutsList
- Defined in:
- lib/stripe/resources/account_session.rb
Defined Under Namespace
Classes: Features
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Whether the embedded component is enabled.
-
#features ⇒ Object
The list of features enabled in the embedded component.
Instance Method Summary collapse
-
#initialize(enabled: nil, features: nil) ⇒ PayoutsList
constructor
A new instance of PayoutsList.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, features: nil) ⇒ PayoutsList
Returns a new instance of PayoutsList.
631 632 633 634 |
# File 'lib/stripe/resources/account_session.rb', line 631 def initialize(enabled: nil, features: nil) @enabled = enabled @features = features end |
Instance Attribute Details
#enabled ⇒ Object
Whether the embedded component is enabled.
627 628 629 |
# File 'lib/stripe/resources/account_session.rb', line 627 def enabled @enabled end |
#features ⇒ Object
The list of features enabled in the embedded component.
629 630 631 |
# File 'lib/stripe/resources/account_session.rb', line 629 def features @features end |