Class: Stripe::AccountSession::CreateParams::Components::ProductTaxCodeSelector
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSession::CreateParams::Components::ProductTaxCodeSelector
- Defined in:
- lib/stripe/resources/account_session.rb
Defined Under Namespace
Classes: Features
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Whether the embedded component is enabled.
-
#features ⇒ Object
The list of features enabled in the embedded component.
Instance Method Summary collapse
-
#initialize(enabled: nil, features: nil) ⇒ ProductTaxCodeSelector
constructor
A new instance of ProductTaxCodeSelector.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, features: nil) ⇒ ProductTaxCodeSelector
Returns a new instance of ProductTaxCodeSelector.
937 938 939 940 |
# File 'lib/stripe/resources/account_session.rb', line 937 def initialize(enabled: nil, features: nil) @enabled = enabled @features = features end |
Instance Attribute Details
#enabled ⇒ Object
Whether the embedded component is enabled.
933 934 935 |
# File 'lib/stripe/resources/account_session.rb', line 933 def enabled @enabled end |
#features ⇒ Object
The list of features enabled in the embedded component.
935 936 937 |
# File 'lib/stripe/resources/account_session.rb', line 935 def features @features end |