Class: Stripe::AccountSession::CreateParams::Components::TaxRegistrations
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSession::CreateParams::Components::TaxRegistrations
- Defined in:
- lib/stripe/resources/account_session.rb
Defined Under Namespace
Classes: Features
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Whether the embedded component is enabled.
-
#features ⇒ Object
The list of features enabled in the embedded component.
Instance Method Summary collapse
-
#initialize(enabled: nil, features: nil) ⇒ TaxRegistrations
constructor
A new instance of TaxRegistrations.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, features: nil) ⇒ TaxRegistrations
Returns a new instance of TaxRegistrations.
983 984 985 986 |
# File 'lib/stripe/resources/account_session.rb', line 983 def initialize(enabled: nil, features: nil) @enabled = enabled @features = features end |
Instance Attribute Details
#enabled ⇒ Object
Whether the embedded component is enabled.
979 980 981 |
# File 'lib/stripe/resources/account_session.rb', line 979 def enabled @enabled end |
#features ⇒ Object
The list of features enabled in the embedded component.
981 982 983 |
# File 'lib/stripe/resources/account_session.rb', line 981 def features @features end |