Class: Stripe::AccountSessionCreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/account_session_create_params.rb

Defined Under Namespace

Classes: Components

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(account: nil, components: nil, expand: nil) ⇒ AccountSessionCreateParams

Returns a new instance of AccountSessionCreateParams.



942
943
944
945
946
# File 'lib/stripe/params/account_session_create_params.rb', line 942

def initialize(account: nil, components: nil, expand: nil)
  @account = 
  @components = components
  @expand = expand
end

Instance Attribute Details

#accountObject

The identifier of the account to create an Account Session for.



936
937
938
# File 'lib/stripe/params/account_session_create_params.rb', line 936

def 
  @account
end

#componentsObject

Each key of the dictionary represents an embedded component, and each embedded component maps to its configuration (e.g. whether it has been enabled or not).



938
939
940
# File 'lib/stripe/params/account_session_create_params.rb', line 938

def components
  @components
end

#expandObject

Specifies which fields in the response should be expanded.



940
941
942
# File 'lib/stripe/params/account_session_create_params.rb', line 940

def expand
  @expand
end