Class: Stripe::AccountSessionCreateParams::Components
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSessionCreateParams::Components
- Defined in:
- lib/stripe/params/account_session_create_params.rb
Defined Under Namespace
Classes: AccountManagement, AccountOnboarding, AppInstall, AppViewport, BalanceReport, Balances, CapitalFinancing, CapitalFinancingApplication, CapitalFinancingPromotion, CapitalOverview, DisputesList, Documents, ExportTaxTransactions, FinancialAccount, FinancialAccountTransactions, InstantPayoutsPromotion, IssuingCard, IssuingCardsList, NotificationBanner, PaymentDetails, PaymentDisputes, PaymentMethodSettings, Payments, PayoutDetails, PayoutReconciliationReport, Payouts, PayoutsList, ProductTaxCodeSelector, Recipients, ReportingChart, TaxRegistrations, TaxSettings, TaxThresholdMonitoring
Instance Attribute Summary collapse
-
#account_management ⇒ Object
Configuration for the account management embedded component.
-
#account_onboarding ⇒ Object
Configuration for the account onboarding embedded component.
-
#app_install ⇒ Object
Configuration for the app install embedded component.
-
#app_viewport ⇒ Object
Configuration for the app viewport embedded component.
-
#balance_report ⇒ Object
Configuration for the balance report embedded component.
-
#balances ⇒ Object
Configuration for the balances embedded component.
-
#capital_financing ⇒ Object
Configuration for the Capital financing embedded component.
-
#capital_financing_application ⇒ Object
Configuration for the Capital financing application embedded component.
-
#capital_financing_promotion ⇒ Object
Configuration for the Capital financing promotion embedded component.
-
#capital_overview ⇒ Object
Configuration for the Capital overview embedded component.
-
#disputes_list ⇒ Object
Configuration for the disputes list embedded component.
-
#documents ⇒ Object
Configuration for the documents embedded component.
-
#export_tax_transactions ⇒ Object
Configuration for the export tax transactions embedded component.
-
#financial_account ⇒ Object
Configuration for the financial account embedded component.
-
#financial_account_transactions ⇒ Object
Configuration for the financial account transactions embedded component.
-
#instant_payouts_promotion ⇒ Object
Configuration for the instant payouts promotion embedded component.
-
#issuing_card ⇒ Object
Configuration for the issuing card embedded component.
-
#issuing_cards_list ⇒ Object
Configuration for the issuing cards list embedded component.
-
#notification_banner ⇒ Object
Configuration for the notification banner embedded component.
-
#payment_details ⇒ Object
Configuration for the payment details embedded component.
-
#payment_disputes ⇒ Object
Configuration for the payment disputes embedded component.
-
#payment_method_settings ⇒ Object
Configuration for the payment method settings embedded component.
-
#payments ⇒ Object
Configuration for the payments embedded component.
-
#payout_details ⇒ Object
Configuration for the payout details embedded component.
-
#payout_reconciliation_report ⇒ Object
Configuration for the payout reconciliation report embedded component.
-
#payouts ⇒ Object
Configuration for the payouts embedded component.
-
#payouts_list ⇒ Object
Configuration for the payouts list embedded component.
-
#product_tax_code_selector ⇒ Object
Configuration for the product tax code selector embedded component.
-
#recipients ⇒ Object
Configuration for the recipients embedded component.
-
#reporting_chart ⇒ Object
Configuration for the reporting chart embedded component.
-
#tax_registrations ⇒ Object
Configuration for the tax registrations embedded component.
-
#tax_settings ⇒ Object
Configuration for the tax settings embedded component.
-
#tax_threshold_monitoring ⇒ Object
Configuration for the tax threshold monitoring embedded component.
Instance Method Summary collapse
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(account_management: nil, account_onboarding: nil, app_install: nil, app_viewport: nil, balance_report: nil, balances: nil, capital_financing: nil, capital_financing_application: nil, capital_financing_promotion: nil, capital_overview: nil, disputes_list: nil, documents: nil, export_tax_transactions: nil, financial_account: nil, financial_account_transactions: nil, instant_payouts_promotion: nil, issuing_card: nil, issuing_cards_list: nil, notification_banner: nil, payment_details: nil, payment_disputes: nil, payment_method_settings: nil, payments: nil, payout_details: nil, payout_reconciliation_report: nil, payouts: nil, payouts_list: nil, product_tax_code_selector: nil, recipients: nil, reporting_chart: nil, tax_registrations: nil, tax_settings: nil, tax_threshold_monitoring: nil) ⇒ Components
Returns a new instance of Components.
797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 |
# File 'lib/stripe/params/account_session_create_params.rb', line 797 def initialize( account_management: nil, account_onboarding: nil, app_install: nil, app_viewport: nil, balance_report: nil, balances: nil, capital_financing: nil, capital_financing_application: nil, capital_financing_promotion: nil, capital_overview: nil, disputes_list: nil, documents: nil, export_tax_transactions: nil, financial_account: nil, financial_account_transactions: nil, instant_payouts_promotion: nil, issuing_card: nil, issuing_cards_list: nil, notification_banner: nil, payment_details: nil, payment_disputes: nil, payment_method_settings: nil, payments: nil, payout_details: nil, payout_reconciliation_report: nil, payouts: nil, payouts_list: nil, product_tax_code_selector: nil, recipients: nil, reporting_chart: nil, tax_registrations: nil, tax_settings: nil, tax_threshold_monitoring: nil ) @account_management = account_management @account_onboarding = account_onboarding @app_install = app_install @app_viewport = @balance_report = balance_report @balances = balances @capital_financing = capital_financing @capital_financing_application = capital_financing_application @capital_financing_promotion = capital_financing_promotion @capital_overview = capital_overview @disputes_list = disputes_list @documents = documents @export_tax_transactions = export_tax_transactions @financial_account = financial_account @financial_account_transactions = financial_account_transactions @instant_payouts_promotion = instant_payouts_promotion @issuing_card = issuing_card @issuing_cards_list = issuing_cards_list @notification_banner = @payment_details = payment_details @payment_disputes = payment_disputes @payment_method_settings = payment_method_settings @payments = payments @payout_details = payout_details @payout_reconciliation_report = payout_reconciliation_report @payouts = payouts @payouts_list = payouts_list @product_tax_code_selector = product_tax_code_selector @recipients = recipients @reporting_chart = reporting_chart @tax_registrations = tax_registrations @tax_settings = tax_settings @tax_threshold_monitoring = tax_threshold_monitoring end |
Instance Attribute Details
#account_management ⇒ Object
Configuration for the account management embedded component.
731 732 733 |
# File 'lib/stripe/params/account_session_create_params.rb', line 731 def account_management @account_management end |
#account_onboarding ⇒ Object
Configuration for the account onboarding embedded component.
733 734 735 |
# File 'lib/stripe/params/account_session_create_params.rb', line 733 def account_onboarding @account_onboarding end |
#app_install ⇒ Object
Configuration for the app install embedded component.
735 736 737 |
# File 'lib/stripe/params/account_session_create_params.rb', line 735 def app_install @app_install end |
#app_viewport ⇒ Object
Configuration for the app viewport embedded component.
737 738 739 |
# File 'lib/stripe/params/account_session_create_params.rb', line 737 def @app_viewport end |
#balance_report ⇒ Object
Configuration for the balance report embedded component.
739 740 741 |
# File 'lib/stripe/params/account_session_create_params.rb', line 739 def balance_report @balance_report end |
#balances ⇒ Object
Configuration for the balances embedded component.
741 742 743 |
# File 'lib/stripe/params/account_session_create_params.rb', line 741 def balances @balances end |
#capital_financing ⇒ Object
Configuration for the Capital financing embedded component.
743 744 745 |
# File 'lib/stripe/params/account_session_create_params.rb', line 743 def capital_financing @capital_financing end |
#capital_financing_application ⇒ Object
Configuration for the Capital financing application embedded component.
745 746 747 |
# File 'lib/stripe/params/account_session_create_params.rb', line 745 def capital_financing_application @capital_financing_application end |
#capital_financing_promotion ⇒ Object
Configuration for the Capital financing promotion embedded component.
747 748 749 |
# File 'lib/stripe/params/account_session_create_params.rb', line 747 def capital_financing_promotion @capital_financing_promotion end |
#capital_overview ⇒ Object
Configuration for the Capital overview embedded component.
749 750 751 |
# File 'lib/stripe/params/account_session_create_params.rb', line 749 def capital_overview @capital_overview end |
#disputes_list ⇒ Object
Configuration for the disputes list embedded component.
751 752 753 |
# File 'lib/stripe/params/account_session_create_params.rb', line 751 def disputes_list @disputes_list end |
#documents ⇒ Object
Configuration for the documents embedded component.
753 754 755 |
# File 'lib/stripe/params/account_session_create_params.rb', line 753 def documents @documents end |
#export_tax_transactions ⇒ Object
Configuration for the export tax transactions embedded component.
755 756 757 |
# File 'lib/stripe/params/account_session_create_params.rb', line 755 def export_tax_transactions @export_tax_transactions end |
#financial_account ⇒ Object
Configuration for the financial account embedded component.
757 758 759 |
# File 'lib/stripe/params/account_session_create_params.rb', line 757 def financial_account @financial_account end |
#financial_account_transactions ⇒ Object
Configuration for the financial account transactions embedded component.
759 760 761 |
# File 'lib/stripe/params/account_session_create_params.rb', line 759 def financial_account_transactions @financial_account_transactions end |
#instant_payouts_promotion ⇒ Object
Configuration for the instant payouts promotion embedded component.
761 762 763 |
# File 'lib/stripe/params/account_session_create_params.rb', line 761 def instant_payouts_promotion @instant_payouts_promotion end |
#issuing_card ⇒ Object
Configuration for the issuing card embedded component.
763 764 765 |
# File 'lib/stripe/params/account_session_create_params.rb', line 763 def issuing_card @issuing_card end |
#issuing_cards_list ⇒ Object
Configuration for the issuing cards list embedded component.
765 766 767 |
# File 'lib/stripe/params/account_session_create_params.rb', line 765 def issuing_cards_list @issuing_cards_list end |
#notification_banner ⇒ Object
Configuration for the notification banner embedded component.
767 768 769 |
# File 'lib/stripe/params/account_session_create_params.rb', line 767 def @notification_banner end |
#payment_details ⇒ Object
Configuration for the payment details embedded component.
769 770 771 |
# File 'lib/stripe/params/account_session_create_params.rb', line 769 def payment_details @payment_details end |
#payment_disputes ⇒ Object
Configuration for the payment disputes embedded component.
771 772 773 |
# File 'lib/stripe/params/account_session_create_params.rb', line 771 def payment_disputes @payment_disputes end |
#payment_method_settings ⇒ Object
Configuration for the payment method settings embedded component.
773 774 775 |
# File 'lib/stripe/params/account_session_create_params.rb', line 773 def payment_method_settings @payment_method_settings end |
#payments ⇒ Object
Configuration for the payments embedded component.
775 776 777 |
# File 'lib/stripe/params/account_session_create_params.rb', line 775 def payments @payments end |
#payout_details ⇒ Object
Configuration for the payout details embedded component.
777 778 779 |
# File 'lib/stripe/params/account_session_create_params.rb', line 777 def payout_details @payout_details end |
#payout_reconciliation_report ⇒ Object
Configuration for the payout reconciliation report embedded component.
779 780 781 |
# File 'lib/stripe/params/account_session_create_params.rb', line 779 def payout_reconciliation_report @payout_reconciliation_report end |
#payouts ⇒ Object
Configuration for the payouts embedded component.
781 782 783 |
# File 'lib/stripe/params/account_session_create_params.rb', line 781 def payouts @payouts end |
#payouts_list ⇒ Object
Configuration for the payouts list embedded component.
783 784 785 |
# File 'lib/stripe/params/account_session_create_params.rb', line 783 def payouts_list @payouts_list end |
#product_tax_code_selector ⇒ Object
Configuration for the product tax code selector embedded component.
785 786 787 |
# File 'lib/stripe/params/account_session_create_params.rb', line 785 def product_tax_code_selector @product_tax_code_selector end |
#recipients ⇒ Object
Configuration for the recipients embedded component.
787 788 789 |
# File 'lib/stripe/params/account_session_create_params.rb', line 787 def recipients @recipients end |
#reporting_chart ⇒ Object
Configuration for the reporting chart embedded component.
789 790 791 |
# File 'lib/stripe/params/account_session_create_params.rb', line 789 def reporting_chart @reporting_chart end |
#tax_registrations ⇒ Object
Configuration for the tax registrations embedded component.
791 792 793 |
# File 'lib/stripe/params/account_session_create_params.rb', line 791 def tax_registrations @tax_registrations end |
#tax_settings ⇒ Object
Configuration for the tax settings embedded component.
793 794 795 |
# File 'lib/stripe/params/account_session_create_params.rb', line 793 def tax_settings @tax_settings end |
#tax_threshold_monitoring ⇒ Object
Configuration for the tax threshold monitoring embedded component.
795 796 797 |
# File 'lib/stripe/params/account_session_create_params.rb', line 795 def tax_threshold_monitoring @tax_threshold_monitoring end |