Class: Stripe::AccountSessionCreateParams::Components::AppInstall
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSessionCreateParams::Components::AppInstall
- Defined in:
- lib/stripe/params/account_session_create_params.rb
Defined Under Namespace
Classes: Features
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Whether the embedded component is enabled.
-
#features ⇒ Object
The list of features enabled in the embedded component.
Instance Method Summary collapse
-
#initialize(enabled: nil, features: nil) ⇒ AppInstall
constructor
A new instance of AppInstall.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(enabled: nil, features: nil) ⇒ AppInstall
Returns a new instance of AppInstall.
67 68 69 70 |
# File 'lib/stripe/params/account_session_create_params.rb', line 67 def initialize(enabled: nil, features: nil) @enabled = enabled @features = features end |
Instance Attribute Details
#enabled ⇒ Object
Whether the embedded component is enabled.
63 64 65 |
# File 'lib/stripe/params/account_session_create_params.rb', line 63 def enabled @enabled end |
#features ⇒ Object
The list of features enabled in the embedded component.
65 66 67 |
# File 'lib/stripe/params/account_session_create_params.rb', line 65 def features @features end |