Class: Stripe::AccountSessionCreateParams::Components::AppViewport
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSessionCreateParams::Components::AppViewport
- Defined in:
- lib/stripe/params/account_session_create_params.rb
Defined Under Namespace
Classes: Features
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Whether the embedded component is enabled.
-
#features ⇒ Object
The list of features enabled in the embedded component.
Instance Method Summary collapse
-
#initialize(enabled: nil, features: nil) ⇒ AppViewport
constructor
A new instance of AppViewport.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(enabled: nil, features: nil) ⇒ AppViewport
Returns a new instance of AppViewport.
87 88 89 90 |
# File 'lib/stripe/params/account_session_create_params.rb', line 87 def initialize(enabled: nil, features: nil) @enabled = enabled @features = features end |
Instance Attribute Details
#enabled ⇒ Object
Whether the embedded component is enabled.
83 84 85 |
# File 'lib/stripe/params/account_session_create_params.rb', line 83 def enabled @enabled end |
#features ⇒ Object
The list of features enabled in the embedded component.
85 86 87 |
# File 'lib/stripe/params/account_session_create_params.rb', line 85 def features @features end |