Class: Stripe::AccountSessionCreateParams::Components::AppViewport::Features
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSessionCreateParams::Components::AppViewport::Features
- Defined in:
- lib/stripe/params/account_session_create_params.rb
Instance Attribute Summary collapse
-
#allowed_apps ⇒ Object
The list of apps allowed to be enabled in the embedded component.
Instance Method Summary collapse
-
#initialize(allowed_apps: nil) ⇒ Features
constructor
A new instance of Features.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(allowed_apps: nil) ⇒ Features
Returns a new instance of Features.
78 79 80 |
# File 'lib/stripe/params/account_session_create_params.rb', line 78 def initialize(allowed_apps: nil) @allowed_apps = allowed_apps end |
Instance Attribute Details
#allowed_apps ⇒ Object
The list of apps allowed to be enabled in the embedded component.
76 77 78 |
# File 'lib/stripe/params/account_session_create_params.rb', line 76 def allowed_apps @allowed_apps end |