Class: Stripe::AccountSessionCreateParams::Components::CapitalFinancing
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSessionCreateParams::Components::CapitalFinancing
- Defined in:
- lib/stripe/params/account_session_create_params.rb
Defined Under Namespace
Classes: Features
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Whether the embedded component is enabled.
-
#features ⇒ Object
An empty list, because this embedded component has no features.
Instance Method Summary collapse
-
#initialize(enabled: nil, features: nil) ⇒ CapitalFinancing
constructor
A new instance of CapitalFinancing.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(enabled: nil, features: nil) ⇒ CapitalFinancing
Returns a new instance of CapitalFinancing.
151 152 153 154 |
# File 'lib/stripe/params/account_session_create_params.rb', line 151 def initialize(enabled: nil, features: nil) @enabled = enabled @features = features end |
Instance Attribute Details
#enabled ⇒ Object
Whether the embedded component is enabled.
147 148 149 |
# File 'lib/stripe/params/account_session_create_params.rb', line 147 def enabled @enabled end |
#features ⇒ Object
An empty list, because this embedded component has no features.
149 150 151 |
# File 'lib/stripe/params/account_session_create_params.rb', line 149 def features @features end |