Class: Stripe::AccountSessionCreateParams::Components::CapitalFinancingApplication
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSessionCreateParams::Components::CapitalFinancingApplication
- Defined in:
- lib/stripe/params/account_session_create_params.rb
Defined Under Namespace
Classes: Features
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Whether the embedded component is enabled.
-
#features ⇒ Object
An empty list, because this embedded component has no features.
Instance Method Summary collapse
-
#initialize(enabled: nil, features: nil) ⇒ CapitalFinancingApplication
constructor
A new instance of CapitalFinancingApplication.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(enabled: nil, features: nil) ⇒ CapitalFinancingApplication
Returns a new instance of CapitalFinancingApplication.
164 165 166 167 |
# File 'lib/stripe/params/account_session_create_params.rb', line 164 def initialize(enabled: nil, features: nil) @enabled = enabled @features = features end |
Instance Attribute Details
#enabled ⇒ Object
Whether the embedded component is enabled.
160 161 162 |
# File 'lib/stripe/params/account_session_create_params.rb', line 160 def enabled @enabled end |
#features ⇒ Object
An empty list, because this embedded component has no features.
162 163 164 |
# File 'lib/stripe/params/account_session_create_params.rb', line 162 def features @features end |