Class: Stripe::AccountSessionCreateParams::Components::FinancialAccountTransactions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSessionCreateParams::Components::FinancialAccountTransactions
- Defined in:
- lib/stripe/params/account_session_create_params.rb
Defined Under Namespace
Classes: Features
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Whether the embedded component is enabled.
-
#features ⇒ Object
The list of features enabled in the embedded component.
Instance Method Summary collapse
-
#initialize(enabled: nil, features: nil) ⇒ FinancialAccountTransactions
constructor
A new instance of FinancialAccountTransactions.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(enabled: nil, features: nil) ⇒ FinancialAccountTransactions
Returns a new instance of FinancialAccountTransactions.
304 305 306 307 |
# File 'lib/stripe/params/account_session_create_params.rb', line 304 def initialize(enabled: nil, features: nil) @enabled = enabled @features = features end |
Instance Attribute Details
#enabled ⇒ Object
Whether the embedded component is enabled.
300 301 302 |
# File 'lib/stripe/params/account_session_create_params.rb', line 300 def enabled @enabled end |
#features ⇒ Object
The list of features enabled in the embedded component.
302 303 304 |
# File 'lib/stripe/params/account_session_create_params.rb', line 302 def features @features end |