Class: Stripe::AccountSessionCreateParams::Components::InstantPayoutsPromotion
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSessionCreateParams::Components::InstantPayoutsPromotion
- Defined in:
- lib/stripe/params/account_session_create_params.rb
Defined Under Namespace
Classes: Features
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Whether the embedded component is enabled.
-
#features ⇒ Object
The list of features enabled in the embedded component.
Instance Method Summary collapse
-
#initialize(enabled: nil, features: nil) ⇒ InstantPayoutsPromotion
constructor
A new instance of InstantPayoutsPromotion.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(enabled: nil, features: nil) ⇒ InstantPayoutsPromotion
Returns a new instance of InstantPayoutsPromotion.
334 335 336 337 |
# File 'lib/stripe/params/account_session_create_params.rb', line 334 def initialize(enabled: nil, features: nil) @enabled = enabled @features = features end |
Instance Attribute Details
#enabled ⇒ Object
Whether the embedded component is enabled.
330 331 332 |
# File 'lib/stripe/params/account_session_create_params.rb', line 330 def enabled @enabled end |
#features ⇒ Object
The list of features enabled in the embedded component.
332 333 334 |
# File 'lib/stripe/params/account_session_create_params.rb', line 332 def features @features end |