Class: Stripe::AccountSessionCreateParams::Components::InstantPayoutsPromotion::Features

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_session_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(disable_stripe_user_authentication: nil, external_account_collection: nil, instant_payouts: nil) ⇒ Features

Returns a new instance of Features.



201
202
203
204
205
206
207
208
209
# File 'lib/stripe/params/account_session_create_params.rb', line 201

def initialize(
  disable_stripe_user_authentication: nil,
  external_account_collection: nil,
  instant_payouts: nil
)
  @disable_stripe_user_authentication = disable_stripe_user_authentication
   = 
  @instant_payouts = instant_payouts
end

Instance Attribute Details

#disable_stripe_user_authenticationObject

Whether Stripe user authentication is disabled. This value can only be true for accounts where controller.requirement_collection is application for the account. The default value is the opposite of the external_account_collection value. For example, if you don’t set external_account_collection, it defaults to true and disable_stripe_user_authentication defaults to false.



195
196
197
# File 'lib/stripe/params/account_session_create_params.rb', line 195

def disable_stripe_user_authentication
  @disable_stripe_user_authentication
end

#external_account_collectionObject

Whether external account collection is enabled. This feature can only be false for accounts where you’re responsible for collecting updated information when requirements are due or change, like Custom accounts. The default value for this feature is true.



197
198
199
# File 'lib/stripe/params/account_session_create_params.rb', line 197

def 
  
end

#instant_payoutsObject

Whether instant payouts are enabled for this component.



199
200
201
# File 'lib/stripe/params/account_session_create_params.rb', line 199

def instant_payouts
  @instant_payouts
end