Class: Stripe::AccountSessionCreateParams::Components::IssuingCardsList
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSessionCreateParams::Components::IssuingCardsList
- Defined in:
- lib/stripe/params/account_session_create_params.rb
Defined Under Namespace
Classes: Features
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Whether the embedded component is enabled.
-
#features ⇒ Object
The list of features enabled in the embedded component.
Instance Method Summary collapse
-
#initialize(enabled: nil, features: nil) ⇒ IssuingCardsList
constructor
A new instance of IssuingCardsList.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(enabled: nil, features: nil) ⇒ IssuingCardsList
Returns a new instance of IssuingCardsList.
439 440 441 442 |
# File 'lib/stripe/params/account_session_create_params.rb', line 439 def initialize(enabled: nil, features: nil) @enabled = enabled @features = features end |
Instance Attribute Details
#enabled ⇒ Object
Whether the embedded component is enabled.
435 436 437 |
# File 'lib/stripe/params/account_session_create_params.rb', line 435 def enabled @enabled end |
#features ⇒ Object
The list of features enabled in the embedded component.
437 438 439 |
# File 'lib/stripe/params/account_session_create_params.rb', line 437 def features @features end |