Class: Stripe::AccountSessionCreateParams::Components::PaymentMethodSettings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSessionCreateParams::Components::PaymentMethodSettings
- Defined in:
- lib/stripe/params/account_session_create_params.rb
Defined Under Namespace
Classes: Features
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Whether the embedded component is enabled.
-
#features ⇒ Object
An empty list, because this embedded component has no features.
Instance Method Summary collapse
-
#initialize(enabled: nil, features: nil) ⇒ PaymentMethodSettings
constructor
A new instance of PaymentMethodSettings.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, features: nil) ⇒ PaymentMethodSettings
Returns a new instance of PaymentMethodSettings.
519 520 521 522 |
# File 'lib/stripe/params/account_session_create_params.rb', line 519 def initialize(enabled: nil, features: nil) @enabled = enabled @features = features end |
Instance Attribute Details
#enabled ⇒ Object
Whether the embedded component is enabled.
515 516 517 |
# File 'lib/stripe/params/account_session_create_params.rb', line 515 def enabled @enabled end |
#features ⇒ Object
An empty list, because this embedded component has no features.
517 518 519 |
# File 'lib/stripe/params/account_session_create_params.rb', line 517 def features @features end |