Class: Stripe::AccountSessionCreateParams::Components::Payments::Features
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSessionCreateParams::Components::Payments::Features
- Defined in:
- lib/stripe/params/account_session_create_params.rb
Instance Attribute Summary collapse
-
#capture_payments ⇒ Object
Whether to allow capturing and cancelling payment intents.
-
#destination_on_behalf_of_charge_management ⇒ Object
Whether connected accounts can manage destination charges that are created on behalf of them.
-
#dispute_management ⇒ Object
Whether responding to disputes is enabled, including submitting evidence and accepting disputes.
-
#refund_management ⇒ Object
Whether sending refunds is enabled.
-
#smart_disputes_management ⇒ Object
Whether to allow connected accounts to submit disputes using Smart Disputes.
Instance Method Summary collapse
-
#initialize(capture_payments: nil, destination_on_behalf_of_charge_management: nil, dispute_management: nil, refund_management: nil, smart_disputes_management: nil) ⇒ Features
constructor
A new instance of Features.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(capture_payments: nil, destination_on_behalf_of_charge_management: nil, dispute_management: nil, refund_management: nil, smart_disputes_management: nil) ⇒ Features
Returns a new instance of Features.
544 545 546 547 548 549 550 551 552 553 554 555 556 |
# File 'lib/stripe/params/account_session_create_params.rb', line 544 def initialize( capture_payments: nil, destination_on_behalf_of_charge_management: nil, dispute_management: nil, refund_management: nil, smart_disputes_management: nil ) @capture_payments = capture_payments @destination_on_behalf_of_charge_management = destination_on_behalf_of_charge_management @dispute_management = dispute_management @refund_management = refund_management @smart_disputes_management = smart_disputes_management end |
Instance Attribute Details
#capture_payments ⇒ Object
Whether to allow capturing and cancelling payment intents. This is true by default.
534 535 536 |
# File 'lib/stripe/params/account_session_create_params.rb', line 534 def capture_payments @capture_payments end |
#destination_on_behalf_of_charge_management ⇒ Object
Whether connected accounts can manage destination charges that are created on behalf of them. This is false by default.
536 537 538 |
# File 'lib/stripe/params/account_session_create_params.rb', line 536 def destination_on_behalf_of_charge_management @destination_on_behalf_of_charge_management end |
#dispute_management ⇒ Object
Whether responding to disputes is enabled, including submitting evidence and accepting disputes. This is true by default.
538 539 540 |
# File 'lib/stripe/params/account_session_create_params.rb', line 538 def dispute_management @dispute_management end |
#refund_management ⇒ Object
Whether sending refunds is enabled. This is true by default.
540 541 542 |
# File 'lib/stripe/params/account_session_create_params.rb', line 540 def refund_management @refund_management end |
#smart_disputes_management ⇒ Object
Whether to allow connected accounts to submit disputes using Smart Disputes. Defaults to the value of dispute_management.
542 543 544 |
# File 'lib/stripe/params/account_session_create_params.rb', line 542 def smart_disputes_management @smart_disputes_management end |