Class: Stripe::AccountSessionCreateParams::Components::PayoutDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSessionCreateParams::Components::PayoutDetails
- Defined in:
- lib/stripe/params/account_session_create_params.rb
Defined Under Namespace
Classes: Features
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Whether the embedded component is enabled.
-
#features ⇒ Object
An empty list, because this embedded component has no features.
Instance Method Summary collapse
-
#initialize(enabled: nil, features: nil) ⇒ PayoutDetails
constructor
A new instance of PayoutDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(enabled: nil, features: nil) ⇒ PayoutDetails
Returns a new instance of PayoutDetails.
553 554 555 556 |
# File 'lib/stripe/params/account_session_create_params.rb', line 553 def initialize(enabled: nil, features: nil) @enabled = enabled @features = features end |
Instance Attribute Details
#enabled ⇒ Object
Whether the embedded component is enabled.
549 550 551 |
# File 'lib/stripe/params/account_session_create_params.rb', line 549 def enabled @enabled end |
#features ⇒ Object
An empty list, because this embedded component has no features.
551 552 553 |
# File 'lib/stripe/params/account_session_create_params.rb', line 551 def features @features end |