Class: Stripe::AccountSessionCreateParams::Components::Payouts
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSessionCreateParams::Components::Payouts
- Defined in:
- lib/stripe/params/account_session_create_params.rb
Defined Under Namespace
Classes: Features
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Whether the embedded component is enabled.
-
#features ⇒ Object
The list of features enabled in the embedded component.
Instance Method Summary collapse
-
#initialize(enabled: nil, features: nil) ⇒ Payouts
constructor
A new instance of Payouts.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(enabled: nil, features: nil) ⇒ Payouts
Returns a new instance of Payouts.
604 605 606 607 |
# File 'lib/stripe/params/account_session_create_params.rb', line 604 def initialize(enabled: nil, features: nil) @enabled = enabled @features = features end |
Instance Attribute Details
#enabled ⇒ Object
Whether the embedded component is enabled.
600 601 602 |
# File 'lib/stripe/params/account_session_create_params.rb', line 600 def enabled @enabled end |
#features ⇒ Object
The list of features enabled in the embedded component.
602 603 604 |
# File 'lib/stripe/params/account_session_create_params.rb', line 602 def features @features end |