Class: Stripe::AccountSessionCreateParams::Components::ProductTaxCodeSelector
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSessionCreateParams::Components::ProductTaxCodeSelector
- Defined in:
- lib/stripe/params/account_session_create_params.rb
Defined Under Namespace
Classes: Features
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Whether the embedded component is enabled.
-
#features ⇒ Object
An empty list, because this embedded component has no features.
Instance Method Summary collapse
-
#initialize(enabled: nil, features: nil) ⇒ ProductTaxCodeSelector
constructor
A new instance of ProductTaxCodeSelector.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(enabled: nil, features: nil) ⇒ ProductTaxCodeSelector
Returns a new instance of ProductTaxCodeSelector.
646 647 648 649 |
# File 'lib/stripe/params/account_session_create_params.rb', line 646 def initialize(enabled: nil, features: nil) @enabled = enabled @features = features end |
Instance Attribute Details
#enabled ⇒ Object
Whether the embedded component is enabled.
642 643 644 |
# File 'lib/stripe/params/account_session_create_params.rb', line 642 def enabled @enabled end |
#features ⇒ Object
An empty list, because this embedded component has no features.
644 645 646 |
# File 'lib/stripe/params/account_session_create_params.rb', line 644 def features @features end |