Class: Stripe::AccountSessionCreateParams::Components::ReportingChart
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSessionCreateParams::Components::ReportingChart
- Defined in:
- lib/stripe/params/account_session_create_params.rb
Defined Under Namespace
Classes: Features
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Whether the embedded component is enabled.
-
#features ⇒ Object
An empty list, because this embedded component has no features.
Instance Method Summary collapse
-
#initialize(enabled: nil, features: nil) ⇒ ReportingChart
constructor
A new instance of ReportingChart.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(enabled: nil, features: nil) ⇒ ReportingChart
Returns a new instance of ReportingChart.
663 664 665 666 |
# File 'lib/stripe/params/account_session_create_params.rb', line 663 def initialize(enabled: nil, features: nil) @enabled = enabled @features = features end |
Instance Attribute Details
#enabled ⇒ Object
Whether the embedded component is enabled.
659 660 661 |
# File 'lib/stripe/params/account_session_create_params.rb', line 659 def enabled @enabled end |
#features ⇒ Object
An empty list, because this embedded component has no features.
661 662 663 |
# File 'lib/stripe/params/account_session_create_params.rb', line 661 def features @features end |