Class: Stripe::AccountSessionCreateParams::Components::TaxRegistrations
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSessionCreateParams::Components::TaxRegistrations
- Defined in:
- lib/stripe/params/account_session_create_params.rb
Defined Under Namespace
Classes: Features
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Whether the embedded component is enabled.
-
#features ⇒ Object
An empty list, because this embedded component has no features.
Instance Method Summary collapse
-
#initialize(enabled: nil, features: nil) ⇒ TaxRegistrations
constructor
A new instance of TaxRegistrations.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(enabled: nil, features: nil) ⇒ TaxRegistrations
Returns a new instance of TaxRegistrations.
676 677 678 679 |
# File 'lib/stripe/params/account_session_create_params.rb', line 676 def initialize(enabled: nil, features: nil) @enabled = enabled @features = features end |
Instance Attribute Details
#enabled ⇒ Object
Whether the embedded component is enabled.
672 673 674 |
# File 'lib/stripe/params/account_session_create_params.rb', line 672 def enabled @enabled end |
#features ⇒ Object
An empty list, because this embedded component has no features.
674 675 676 |
# File 'lib/stripe/params/account_session_create_params.rb', line 674 def features @features end |