Class: Stripe::AccountSessionCreateParams::Components::TaxThresholdMonitoring
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSessionCreateParams::Components::TaxThresholdMonitoring
- Defined in:
- lib/stripe/params/account_session_create_params.rb
Defined Under Namespace
Classes: Features
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Whether the embedded component is enabled.
-
#features ⇒ Object
An empty list, because this embedded component has no features.
Instance Method Summary collapse
-
#initialize(enabled: nil, features: nil) ⇒ TaxThresholdMonitoring
constructor
A new instance of TaxThresholdMonitoring.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(enabled: nil, features: nil) ⇒ TaxThresholdMonitoring
Returns a new instance of TaxThresholdMonitoring.
735 736 737 738 |
# File 'lib/stripe/params/account_session_create_params.rb', line 735 def initialize(enabled: nil, features: nil) @enabled = enabled @features = features end |
Instance Attribute Details
#enabled ⇒ Object
Whether the embedded component is enabled.
731 732 733 |
# File 'lib/stripe/params/account_session_create_params.rb', line 731 def enabled @enabled end |
#features ⇒ Object
An empty list, because this embedded component has no features.
733 734 735 |
# File 'lib/stripe/params/account_session_create_params.rb', line 733 def features @features end |