Class: Stripe::AccountSessionService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::AccountSessionService
- Defined in:
- lib/stripe/services/account_session_service.rb
Defined Under Namespace
Classes: CreateParams
Instance Method Summary collapse
-
#create(params = {}, opts = {}) ⇒ Object
Creates a AccountSession object that includes a single-use token that the platform can use on their front-end to grant client-side API access.
Methods inherited from StripeService
#initialize, #request, #request_stream
Constructor Details
This class inherits a constructor from Stripe::StripeService
Instance Method Details
#create(params = {}, opts = {}) ⇒ Object
Creates a AccountSession object that includes a single-use token that the platform can use on their front-end to grant client-side API access.
671 672 673 674 675 676 677 678 679 |
# File 'lib/stripe/services/account_session_service.rb', line 671 def create(params = {}, opts = {}) request( method: :post, path: "/v1/account_sessions", params: params, opts: opts, base_address: :api ) end |