Class: Stripe::AccountSessionService::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_session_service.rb

Defined Under Namespace

Classes: Components

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account: nil, components: nil, expand: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



861
862
863
864
865
# File 'lib/stripe/services/account_session_service.rb', line 861

def initialize(account: nil, components: nil, expand: nil)
  @account = 
  @components = components
  @expand = expand
end

Instance Attribute Details

#accountObject

The identifier of the account to create an Account Session for.



855
856
857
# File 'lib/stripe/services/account_session_service.rb', line 855

def 
  @account
end

#componentsObject

Each key of the dictionary represents an embedded component, and each embedded component maps to its configuration (e.g. whether it has been enabled or not).



857
858
859
# File 'lib/stripe/services/account_session_service.rb', line 857

def components
  @components
end

#expandObject

Specifies which fields in the response should be expanded.



859
860
861
# File 'lib/stripe/services/account_session_service.rb', line 859

def expand
  @expand
end