Class: Stripe::AccountSessionService::CreateParams::Components::AccountOnboarding
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSessionService::CreateParams::Components::AccountOnboarding
- Defined in:
- lib/stripe/services/account_session_service.rb
Defined Under Namespace
Classes: Features
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Whether the embedded component is enabled.
-
#features ⇒ Object
The list of features enabled in the embedded component.
Instance Method Summary collapse
-
#initialize(enabled: nil, features: nil) ⇒ AccountOnboarding
constructor
A new instance of AccountOnboarding.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, features: nil) ⇒ AccountOnboarding
Returns a new instance of AccountOnboarding.
58 59 60 61 |
# File 'lib/stripe/services/account_session_service.rb', line 58 def initialize(enabled: nil, features: nil) @enabled = enabled @features = features end |
Instance Attribute Details
#enabled ⇒ Object
Whether the embedded component is enabled.
53 54 55 |
# File 'lib/stripe/services/account_session_service.rb', line 53 def enabled @enabled end |
#features ⇒ Object
The list of features enabled in the embedded component.
56 57 58 |
# File 'lib/stripe/services/account_session_service.rb', line 56 def features @features end |