Class: Stripe::AccountSessionService::CreateParams::Components::AppInstall
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSessionService::CreateParams::Components::AppInstall
- Defined in:
- lib/stripe/services/account_session_service.rb
Defined Under Namespace
Classes: Features
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Whether the embedded component is enabled.
-
#features ⇒ Object
The list of features enabled in the embedded component.
Instance Method Summary collapse
-
#initialize(enabled: nil, features: nil) ⇒ AppInstall
constructor
A new instance of AppInstall.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, features: nil) ⇒ AppInstall
Returns a new instance of AppInstall.
74 75 76 77 |
# File 'lib/stripe/services/account_session_service.rb', line 74 def initialize(enabled: nil, features: nil) @enabled = enabled @features = features end |
Instance Attribute Details
#enabled ⇒ Object
Whether the embedded component is enabled.
70 71 72 |
# File 'lib/stripe/services/account_session_service.rb', line 70 def enabled @enabled end |
#features ⇒ Object
The list of features enabled in the embedded component.
72 73 74 |
# File 'lib/stripe/services/account_session_service.rb', line 72 def features @features end |