Class: Stripe::AccountSessionService::CreateParams::Components::AppViewport::Features
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSessionService::CreateParams::Components::AppViewport::Features
- Defined in:
- lib/stripe/services/account_session_service.rb
Instance Attribute Summary collapse
-
#allowed_apps ⇒ Object
The list of apps allowed to be enabled in the embedded component.
Instance Method Summary collapse
-
#initialize(allowed_apps: nil) ⇒ Features
constructor
A new instance of Features.
Methods inherited from RequestParams
Constructor Details
#initialize(allowed_apps: nil) ⇒ Features
Returns a new instance of Features.
85 86 87 |
# File 'lib/stripe/services/account_session_service.rb', line 85 def initialize(allowed_apps: nil) @allowed_apps = allowed_apps end |
Instance Attribute Details
#allowed_apps ⇒ Object
The list of apps allowed to be enabled in the embedded component.
83 84 85 |
# File 'lib/stripe/services/account_session_service.rb', line 83 def allowed_apps @allowed_apps end |