Class: Stripe::AccountSessionService::CreateParams::Components::BalanceReport
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSessionService::CreateParams::Components::BalanceReport
- Defined in:
- lib/stripe/services/account_session_service.rb
Defined Under Namespace
Classes: Features
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Whether the embedded component is enabled.
-
#features ⇒ Object
An empty list, because this embedded component has no features.
Instance Method Summary collapse
-
#initialize(enabled: nil, features: nil) ⇒ BalanceReport
constructor
A new instance of BalanceReport.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, features: nil) ⇒ BalanceReport
Returns a new instance of BalanceReport.
107 108 109 110 |
# File 'lib/stripe/services/account_session_service.rb', line 107 def initialize(enabled: nil, features: nil) @enabled = enabled @features = features end |
Instance Attribute Details
#enabled ⇒ Object
Whether the embedded component is enabled.
103 104 105 |
# File 'lib/stripe/services/account_session_service.rb', line 103 def enabled @enabled end |
#features ⇒ Object
An empty list, because this embedded component has no features.
105 106 107 |
# File 'lib/stripe/services/account_session_service.rb', line 105 def features @features end |