Class: Stripe::AccountSessionService::CreateParams::Components::Balances
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSessionService::CreateParams::Components::Balances
- Defined in:
- lib/stripe/services/account_session_service.rb
Defined Under Namespace
Classes: Features
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Whether the embedded component is enabled.
-
#features ⇒ Object
The list of features enabled in the embedded component.
Instance Method Summary collapse
-
#initialize(enabled: nil, features: nil) ⇒ Balances
constructor
A new instance of Balances.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, features: nil) ⇒ Balances
Returns a new instance of Balances.
105 106 107 108 |
# File 'lib/stripe/services/account_session_service.rb', line 105 def initialize(enabled: nil, features: nil) @enabled = enabled @features = features end |
Instance Attribute Details
#enabled ⇒ Object
Whether the embedded component is enabled.
101 102 103 |
# File 'lib/stripe/services/account_session_service.rb', line 101 def enabled @enabled end |
#features ⇒ Object
The list of features enabled in the embedded component.
103 104 105 |
# File 'lib/stripe/services/account_session_service.rb', line 103 def features @features end |