Class: Stripe::AccountSessionService::CreateParams::Components::Balances::Features
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSessionService::CreateParams::Components::Balances::Features
- Defined in:
- lib/stripe/services/account_session_service.rb
Instance Attribute Summary collapse
-
#disable_stripe_user_authentication ⇒ Object
Disables Stripe user authentication for this embedded component.
-
#edit_payout_schedule ⇒ Object
Whether to allow payout schedule to be changed.
-
#external_account_collection ⇒ Object
Whether to allow platforms to control bank account collection for their connected accounts.
-
#instant_payouts ⇒ Object
Whether to allow creation of instant payouts.
-
#standard_payouts ⇒ Object
Whether to allow creation of standard payouts.
Instance Method Summary collapse
-
#initialize(disable_stripe_user_authentication: nil, edit_payout_schedule: nil, external_account_collection: nil, instant_payouts: nil, standard_payouts: nil) ⇒ Features
constructor
A new instance of Features.
Methods inherited from RequestParams
Constructor Details
#initialize(disable_stripe_user_authentication: nil, edit_payout_schedule: nil, external_account_collection: nil, instant_payouts: nil, standard_payouts: nil) ⇒ Features
Returns a new instance of Features.
113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/stripe/services/account_session_service.rb', line 113 def initialize( disable_stripe_user_authentication: nil, edit_payout_schedule: nil, external_account_collection: nil, instant_payouts: nil, standard_payouts: nil ) @disable_stripe_user_authentication = disable_stripe_user_authentication @edit_payout_schedule = edit_payout_schedule @external_account_collection = external_account_collection @instant_payouts = instant_payouts @standard_payouts = standard_payouts end |
Instance Attribute Details
#disable_stripe_user_authentication ⇒ Object
Disables Stripe user authentication for this embedded component. This value can only be true for accounts where ‘controller.requirement_collection` is `application`. The default value is the opposite of the `external_account_collection` value. For example, if you don’t set `external_account_collection`, it defaults to true and `disable_stripe_user_authentication` defaults to false.
103 104 105 |
# File 'lib/stripe/services/account_session_service.rb', line 103 def disable_stripe_user_authentication @disable_stripe_user_authentication end |
#edit_payout_schedule ⇒ Object
Whether to allow payout schedule to be changed. Default ‘true` when Stripe owns Loss Liability, default `false` otherwise.
105 106 107 |
# File 'lib/stripe/services/account_session_service.rb', line 105 def edit_payout_schedule @edit_payout_schedule end |
#external_account_collection ⇒ Object
Whether to allow platforms to control bank account collection for their connected accounts. This feature can only be false for accounts where you’re responsible for collecting updated information when requirements are due or change, like custom accounts. Otherwise, bank account collection is determined by compliance requirements. The default value for this feature is ‘true`.
107 108 109 |
# File 'lib/stripe/services/account_session_service.rb', line 107 def external_account_collection @external_account_collection end |
#instant_payouts ⇒ Object
Whether to allow creation of instant payouts. Default ‘true` when Stripe owns Loss Liability, default `false` otherwise.
109 110 111 |
# File 'lib/stripe/services/account_session_service.rb', line 109 def instant_payouts @instant_payouts end |
#standard_payouts ⇒ Object
Whether to allow creation of standard payouts. Default ‘true` when Stripe owns Loss Liability, default `false` otherwise.
111 112 113 |
# File 'lib/stripe/services/account_session_service.rb', line 111 def standard_payouts @standard_payouts end |