Class: Stripe::AccountSessionService::CreateParams::Components::DisputesList::Features

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_session_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(capture_payments: nil, destination_on_behalf_of_charge_management: nil, dispute_management: nil, refund_management: nil) ⇒ Features

Returns a new instance of Features.



201
202
203
204
205
206
207
208
209
210
211
# File 'lib/stripe/services/account_session_service.rb', line 201

def initialize(
  capture_payments: nil,
  destination_on_behalf_of_charge_management: nil,
  dispute_management: nil,
  refund_management: nil
)
  @capture_payments = capture_payments
  @destination_on_behalf_of_charge_management = destination_on_behalf_of_charge_management
  @dispute_management = dispute_management
  @refund_management = refund_management
end

Instance Attribute Details

#capture_paymentsObject

Whether to allow capturing and cancelling payment intents. This is ‘true` by default.



193
194
195
# File 'lib/stripe/services/account_session_service.rb', line 193

def capture_payments
  @capture_payments
end

#destination_on_behalf_of_charge_managementObject

Whether to allow connected accounts to manage destination charges that are created on behalf of them. This is ‘false` by default.



195
196
197
# File 'lib/stripe/services/account_session_service.rb', line 195

def destination_on_behalf_of_charge_management
  @destination_on_behalf_of_charge_management
end

#dispute_managementObject

Whether to allow responding to disputes, including submitting evidence and accepting disputes. This is ‘true` by default.



197
198
199
# File 'lib/stripe/services/account_session_service.rb', line 197

def dispute_management
  @dispute_management
end

#refund_managementObject

Whether to allow sending refunds. This is ‘true` by default.



199
200
201
# File 'lib/stripe/services/account_session_service.rb', line 199

def refund_management
  @refund_management
end