Class: Stripe::AccountSessionService::CreateParams::Components::Documents
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSessionService::CreateParams::Components::Documents
- Defined in:
- lib/stripe/services/account_session_service.rb
Defined Under Namespace
Classes: Features
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Whether the embedded component is enabled.
-
#features ⇒ Object
The list of features enabled in the embedded component.
Instance Method Summary collapse
-
#initialize(enabled: nil, features: nil) ⇒ Documents
constructor
A new instance of Documents.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, features: nil) ⇒ Documents
Returns a new instance of Documents.
202 203 204 205 |
# File 'lib/stripe/services/account_session_service.rb', line 202 def initialize(enabled: nil, features: nil) @enabled = enabled @features = features end |
Instance Attribute Details
#enabled ⇒ Object
Whether the embedded component is enabled.
198 199 200 |
# File 'lib/stripe/services/account_session_service.rb', line 198 def enabled @enabled end |
#features ⇒ Object
The list of features enabled in the embedded component.
200 201 202 |
# File 'lib/stripe/services/account_session_service.rb', line 200 def features @features end |