Class: Stripe::AccountSessionService::CreateParams::Components::FinancialAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSessionService::CreateParams::Components::FinancialAccount
- Defined in:
- lib/stripe/services/account_session_service.rb
Defined Under Namespace
Classes: Features
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Whether the embedded component is enabled.
-
#features ⇒ Object
The list of features enabled in the embedded component.
Instance Method Summary collapse
-
#initialize(enabled: nil, features: nil) ⇒ FinancialAccount
constructor
A new instance of FinancialAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, features: nil) ⇒ FinancialAccount
Returns a new instance of FinancialAccount.
278 279 280 281 |
# File 'lib/stripe/services/account_session_service.rb', line 278 def initialize(enabled: nil, features: nil) @enabled = enabled @features = features end |
Instance Attribute Details
#enabled ⇒ Object
Whether the embedded component is enabled.
274 275 276 |
# File 'lib/stripe/services/account_session_service.rb', line 274 def enabled @enabled end |
#features ⇒ Object
The list of features enabled in the embedded component.
276 277 278 |
# File 'lib/stripe/services/account_session_service.rb', line 276 def features @features end |