Class: Stripe::AccountSessionService::CreateParams::Components::FinancialAccount::Features
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSessionService::CreateParams::Components::FinancialAccount::Features
- Defined in:
- lib/stripe/services/account_session_service.rb
Instance Attribute Summary collapse
-
#disable_stripe_user_authentication ⇒ Object
Whether Stripe user authentication is disabled.
-
#external_account_collection ⇒ Object
Whether external account collection is enabled.
-
#send_money ⇒ Object
Whether to allow sending money.
-
#transfer_balance ⇒ Object
Whether to allow transferring balance.
Instance Method Summary collapse
-
#initialize(disable_stripe_user_authentication: nil, external_account_collection: nil, send_money: nil, transfer_balance: nil) ⇒ Features
constructor
A new instance of Features.
Methods inherited from RequestParams
Constructor Details
#initialize(disable_stripe_user_authentication: nil, external_account_collection: nil, send_money: nil, transfer_balance: nil) ⇒ Features
Returns a new instance of Features.
274 275 276 277 278 279 280 281 282 283 284 |
# File 'lib/stripe/services/account_session_service.rb', line 274 def initialize( disable_stripe_user_authentication: nil, external_account_collection: nil, send_money: nil, transfer_balance: nil ) @disable_stripe_user_authentication = disable_stripe_user_authentication @external_account_collection = external_account_collection @send_money = send_money @transfer_balance = transfer_balance end |
Instance Attribute Details
#disable_stripe_user_authentication ⇒ Object
Whether Stripe user authentication is disabled. This value can only be ‘true` for accounts where `controller.requirement_collection` is `application` for the account. The default value is the opposite of the `external_account_collection` value. For example, if you don’t set ‘external_account_collection`, it defaults to `true` and `disable_stripe_user_authentication` defaults to `false`.
266 267 268 |
# File 'lib/stripe/services/account_session_service.rb', line 266 def disable_stripe_user_authentication @disable_stripe_user_authentication end |
#external_account_collection ⇒ Object
Whether external account collection is enabled. This feature can only be ‘false` for accounts where you’re responsible for collecting updated information when requirements are due or change, like Custom accounts. The default value for this feature is `true`.
268 269 270 |
# File 'lib/stripe/services/account_session_service.rb', line 268 def external_account_collection @external_account_collection end |
#send_money ⇒ Object
Whether to allow sending money.
270 271 272 |
# File 'lib/stripe/services/account_session_service.rb', line 270 def send_money @send_money end |
#transfer_balance ⇒ Object
Whether to allow transferring balance.
272 273 274 |
# File 'lib/stripe/services/account_session_service.rb', line 272 def transfer_balance @transfer_balance end |