Class: Stripe::AccountSessionService::CreateParams::Components::FinancialAccountTransactions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSessionService::CreateParams::Components::FinancialAccountTransactions
- Defined in:
- lib/stripe/services/account_session_service.rb
Defined Under Namespace
Classes: Features
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Whether the embedded component is enabled.
-
#features ⇒ Object
The list of features enabled in the embedded component.
Instance Method Summary collapse
-
#initialize(enabled: nil, features: nil) ⇒ FinancialAccountTransactions
constructor
A new instance of FinancialAccountTransactions.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, features: nil) ⇒ FinancialAccountTransactions
Returns a new instance of FinancialAccountTransactions.
298 299 300 301 |
# File 'lib/stripe/services/account_session_service.rb', line 298 def initialize(enabled: nil, features: nil) @enabled = enabled @features = features end |
Instance Attribute Details
#enabled ⇒ Object
Whether the embedded component is enabled.
294 295 296 |
# File 'lib/stripe/services/account_session_service.rb', line 294 def enabled @enabled end |
#features ⇒ Object
The list of features enabled in the embedded component.
296 297 298 |
# File 'lib/stripe/services/account_session_service.rb', line 296 def features @features end |