Class: Stripe::AccountSessionService::CreateParams::Components::InstantPayoutsPromotion::Features
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSessionService::CreateParams::Components::InstantPayoutsPromotion::Features
- Defined in:
- lib/stripe/services/account_session_service.rb
Instance Attribute Summary collapse
-
#disable_stripe_user_authentication ⇒ Object
Whether Stripe user authentication is disabled.
-
#external_account_collection ⇒ Object
Whether external account collection is enabled.
-
#instant_payouts ⇒ Object
Whether to allow creation of instant payouts.
Instance Method Summary collapse
-
#initialize(disable_stripe_user_authentication: nil, external_account_collection: nil, instant_payouts: nil) ⇒ Features
constructor
A new instance of Features.
Methods inherited from RequestParams
Constructor Details
#initialize(disable_stripe_user_authentication: nil, external_account_collection: nil, instant_payouts: nil) ⇒ Features
Returns a new instance of Features.
313 314 315 316 317 318 319 320 321 |
# File 'lib/stripe/services/account_session_service.rb', line 313 def initialize( disable_stripe_user_authentication: nil, external_account_collection: nil, instant_payouts: nil ) @disable_stripe_user_authentication = disable_stripe_user_authentication @external_account_collection = external_account_collection @instant_payouts = instant_payouts end |
Instance Attribute Details
#disable_stripe_user_authentication ⇒ Object
Whether Stripe user authentication is disabled. This value can only be ‘true` for accounts where `controller.requirement_collection` is `application` for the account. The default value is the opposite of the `external_account_collection` value. For example, if you don’t set ‘external_account_collection`, it defaults to `true` and `disable_stripe_user_authentication` defaults to `false`.
307 308 309 |
# File 'lib/stripe/services/account_session_service.rb', line 307 def disable_stripe_user_authentication @disable_stripe_user_authentication end |
#external_account_collection ⇒ Object
Whether external account collection is enabled. This feature can only be ‘false` for accounts where you’re responsible for collecting updated information when requirements are due or change, like Custom accounts. The default value for this feature is `true`.
309 310 311 |
# File 'lib/stripe/services/account_session_service.rb', line 309 def external_account_collection @external_account_collection end |
#instant_payouts ⇒ Object
Whether to allow creation of instant payouts. Defaults to ‘true` when `controller.losses.payments` is set to `stripe` for the account, otherwise `false`.
311 312 313 |
# File 'lib/stripe/services/account_session_service.rb', line 311 def instant_payouts @instant_payouts end |