Class: Stripe::AccountSessionService::CreateParams::Components::IssuingCard
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSessionService::CreateParams::Components::IssuingCard
- Defined in:
- lib/stripe/services/account_session_service.rb
Defined Under Namespace
Classes: Features
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Whether the embedded component is enabled.
-
#features ⇒ Object
The list of features enabled in the embedded component.
Instance Method Summary collapse
-
#initialize(enabled: nil, features: nil) ⇒ IssuingCard
constructor
A new instance of IssuingCard.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, features: nil) ⇒ IssuingCard
Returns a new instance of IssuingCard.
375 376 377 378 |
# File 'lib/stripe/services/account_session_service.rb', line 375 def initialize(enabled: nil, features: nil) @enabled = enabled @features = features end |
Instance Attribute Details
#enabled ⇒ Object
Whether the embedded component is enabled.
371 372 373 |
# File 'lib/stripe/services/account_session_service.rb', line 371 def enabled @enabled end |
#features ⇒ Object
The list of features enabled in the embedded component.
373 374 375 |
# File 'lib/stripe/services/account_session_service.rb', line 373 def features @features end |