Class: Stripe::AccountSessionService::CreateParams::Components::PaymentDetails::Features
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSessionService::CreateParams::Components::PaymentDetails::Features
- Defined in:
- lib/stripe/services/account_session_service.rb
Instance Attribute Summary collapse
-
#capture_payments ⇒ Object
Whether to allow capturing and cancelling payment intents.
-
#destination_on_behalf_of_charge_management ⇒ Object
Whether connected accounts can manage destination charges that are created on behalf of them.
-
#dispute_management ⇒ Object
Whether responding to disputes is enabled, including submitting evidence and accepting disputes.
-
#refund_management ⇒ Object
Whether sending refunds is enabled.
Instance Method Summary collapse
-
#initialize(capture_payments: nil, destination_on_behalf_of_charge_management: nil, dispute_management: nil, refund_management: nil) ⇒ Features
constructor
A new instance of Features.
Methods inherited from RequestParams
Constructor Details
#initialize(capture_payments: nil, destination_on_behalf_of_charge_management: nil, dispute_management: nil, refund_management: nil) ⇒ Features
Returns a new instance of Features.
443 444 445 446 447 448 449 450 451 452 453 |
# File 'lib/stripe/services/account_session_service.rb', line 443 def initialize( capture_payments: nil, destination_on_behalf_of_charge_management: nil, dispute_management: nil, refund_management: nil ) @capture_payments = capture_payments @destination_on_behalf_of_charge_management = destination_on_behalf_of_charge_management @dispute_management = dispute_management @refund_management = refund_management end |
Instance Attribute Details
#capture_payments ⇒ Object
Whether to allow capturing and cancelling payment intents. This is ‘true` by default.
435 436 437 |
# File 'lib/stripe/services/account_session_service.rb', line 435 def capture_payments @capture_payments end |
#destination_on_behalf_of_charge_management ⇒ Object
Whether connected accounts can manage destination charges that are created on behalf of them. This is ‘false` by default.
437 438 439 |
# File 'lib/stripe/services/account_session_service.rb', line 437 def destination_on_behalf_of_charge_management @destination_on_behalf_of_charge_management end |
#dispute_management ⇒ Object
Whether responding to disputes is enabled, including submitting evidence and accepting disputes. This is ‘true` by default.
439 440 441 |
# File 'lib/stripe/services/account_session_service.rb', line 439 def dispute_management @dispute_management end |
#refund_management ⇒ Object
Whether sending refunds is enabled. This is ‘true` by default.
441 442 443 |
# File 'lib/stripe/services/account_session_service.rb', line 441 def refund_management @refund_management end |