Class: Stripe::AccountSessionService::CreateParams::Components::PaymentDisputes
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSessionService::CreateParams::Components::PaymentDisputes
- Defined in:
- lib/stripe/services/account_session_service.rb
Defined Under Namespace
Classes: Features
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Whether the embedded component is enabled.
-
#features ⇒ Object
The list of features enabled in the embedded component.
Instance Method Summary collapse
-
#initialize(enabled: nil, features: nil) ⇒ PaymentDisputes
constructor
A new instance of PaymentDisputes.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, features: nil) ⇒ PaymentDisputes
Returns a new instance of PaymentDisputes.
398 399 400 401 |
# File 'lib/stripe/services/account_session_service.rb', line 398 def initialize(enabled: nil, features: nil) @enabled = enabled @features = features end |
Instance Attribute Details
#enabled ⇒ Object
Whether the embedded component is enabled.
394 395 396 |
# File 'lib/stripe/services/account_session_service.rb', line 394 def enabled @enabled end |
#features ⇒ Object
The list of features enabled in the embedded component.
396 397 398 |
# File 'lib/stripe/services/account_session_service.rb', line 396 def features @features end |