Class: Stripe::AccountSessionService::CreateParams::Components::PaymentDisputes::Features
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSessionService::CreateParams::Components::PaymentDisputes::Features
- Defined in:
- lib/stripe/services/account_session_service.rb
Instance Attribute Summary collapse
-
#destination_on_behalf_of_charge_management ⇒ Object
Whether connected accounts can manage destination charges that are created on behalf of them.
-
#dispute_management ⇒ Object
Whether responding to disputes is enabled, including submitting evidence and accepting disputes.
-
#refund_management ⇒ Object
Whether sending refunds is enabled.
Instance Method Summary collapse
-
#initialize(destination_on_behalf_of_charge_management: nil, dispute_management: nil, refund_management: nil) ⇒ Features
constructor
A new instance of Features.
Methods inherited from RequestParams
Constructor Details
#initialize(destination_on_behalf_of_charge_management: nil, dispute_management: nil, refund_management: nil) ⇒ Features
Returns a new instance of Features.
488 489 490 491 492 493 494 495 496 |
# File 'lib/stripe/services/account_session_service.rb', line 488 def initialize( destination_on_behalf_of_charge_management: nil, dispute_management: nil, refund_management: nil ) @destination_on_behalf_of_charge_management = destination_on_behalf_of_charge_management @dispute_management = dispute_management @refund_management = refund_management end |
Instance Attribute Details
#destination_on_behalf_of_charge_management ⇒ Object
Whether connected accounts can manage destination charges that are created on behalf of them. This is ‘false` by default.
482 483 484 |
# File 'lib/stripe/services/account_session_service.rb', line 482 def destination_on_behalf_of_charge_management @destination_on_behalf_of_charge_management end |
#dispute_management ⇒ Object
Whether responding to disputes is enabled, including submitting evidence and accepting disputes. This is ‘true` by default.
484 485 486 |
# File 'lib/stripe/services/account_session_service.rb', line 484 def dispute_management @dispute_management end |
#refund_management ⇒ Object
Whether sending refunds is enabled. This is ‘true` by default.
486 487 488 |
# File 'lib/stripe/services/account_session_service.rb', line 486 def refund_management @refund_management end |