Class: Stripe::AccountSessionService::CreateParams::Components::PaymentMethodSettings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSessionService::CreateParams::Components::PaymentMethodSettings
- Defined in:
- lib/stripe/services/account_session_service.rb
Defined Under Namespace
Classes: Features
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Whether the embedded component is enabled.
-
#features ⇒ Object
The list of features enabled in the embedded component.
Instance Method Summary collapse
-
#initialize(enabled: nil, features: nil) ⇒ PaymentMethodSettings
constructor
A new instance of PaymentMethodSettings.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, features: nil) ⇒ PaymentMethodSettings
Returns a new instance of PaymentMethodSettings.
446 447 448 449 |
# File 'lib/stripe/services/account_session_service.rb', line 446 def initialize(enabled: nil, features: nil) @enabled = enabled @features = features end |
Instance Attribute Details
#enabled ⇒ Object
Whether the embedded component is enabled.
442 443 444 |
# File 'lib/stripe/services/account_session_service.rb', line 442 def enabled @enabled end |
#features ⇒ Object
The list of features enabled in the embedded component.
444 445 446 |
# File 'lib/stripe/services/account_session_service.rb', line 444 def features @features end |