Class: Stripe::AccountSessionService::CreateParams::Components::PayoutsList
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSessionService::CreateParams::Components::PayoutsList
- Defined in:
- lib/stripe/services/account_session_service.rb
Defined Under Namespace
Classes: Features
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Whether the embedded component is enabled.
-
#features ⇒ Object
The list of features enabled in the embedded component.
Instance Method Summary collapse
-
#initialize(enabled: nil, features: nil) ⇒ PayoutsList
constructor
A new instance of PayoutsList.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, features: nil) ⇒ PayoutsList
Returns a new instance of PayoutsList.
378 379 380 381 |
# File 'lib/stripe/services/account_session_service.rb', line 378 def initialize(enabled: nil, features: nil) @enabled = enabled @features = features end |
Instance Attribute Details
#enabled ⇒ Object
Whether the embedded component is enabled.
374 375 376 |
# File 'lib/stripe/services/account_session_service.rb', line 374 def enabled @enabled end |
#features ⇒ Object
The list of features enabled in the embedded component.
376 377 378 |
# File 'lib/stripe/services/account_session_service.rb', line 376 def features @features end |