Class: Stripe::AccountSessionService::CreateParams::Components::ReportingChart
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSessionService::CreateParams::Components::ReportingChart
- Defined in:
- lib/stripe/services/account_session_service.rb
Defined Under Namespace
Classes: Features
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Whether the embedded component is enabled.
-
#features ⇒ Object
The list of features enabled in the embedded component.
Instance Method Summary collapse
-
#initialize(enabled: nil, features: nil) ⇒ ReportingChart
constructor
A new instance of ReportingChart.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, features: nil) ⇒ ReportingChart
Returns a new instance of ReportingChart.
522 523 524 525 |
# File 'lib/stripe/services/account_session_service.rb', line 522 def initialize(enabled: nil, features: nil) @enabled = enabled @features = features end |
Instance Attribute Details
#enabled ⇒ Object
Whether the embedded component is enabled.
518 519 520 |
# File 'lib/stripe/services/account_session_service.rb', line 518 def enabled @enabled end |
#features ⇒ Object
The list of features enabled in the embedded component.
520 521 522 |
# File 'lib/stripe/services/account_session_service.rb', line 520 def features @features end |