Class: Stripe::AccountSessionService::CreateParams::Components::TaxRegistrations
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSessionService::CreateParams::Components::TaxRegistrations
- Defined in:
- lib/stripe/services/account_session_service.rb
Defined Under Namespace
Classes: Features
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Whether the embedded component is enabled.
-
#features ⇒ Object
An empty list, because this embedded component has no features.
Instance Method Summary collapse
-
#initialize(enabled: nil, features: nil) ⇒ TaxRegistrations
constructor
A new instance of TaxRegistrations.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, features: nil) ⇒ TaxRegistrations
Returns a new instance of TaxRegistrations.
686 687 688 689 |
# File 'lib/stripe/services/account_session_service.rb', line 686 def initialize(enabled: nil, features: nil) @enabled = enabled @features = features end |
Instance Attribute Details
#enabled ⇒ Object
Whether the embedded component is enabled.
682 683 684 |
# File 'lib/stripe/services/account_session_service.rb', line 682 def enabled @enabled end |
#features ⇒ Object
An empty list, because this embedded component has no features.
684 685 686 |
# File 'lib/stripe/services/account_session_service.rb', line 684 def features @features end |