Class: Stripe::AccountSessionService::CreateParams::Components::TaxSettings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSessionService::CreateParams::Components::TaxSettings
- Defined in:
- lib/stripe/services/account_session_service.rb
Defined Under Namespace
Classes: Features
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Whether the embedded component is enabled.
-
#features ⇒ Object
The list of features enabled in the embedded component.
Instance Method Summary collapse
-
#initialize(enabled: nil, features: nil) ⇒ TaxSettings
constructor
A new instance of TaxSettings.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, features: nil) ⇒ TaxSettings
Returns a new instance of TaxSettings.
660 661 662 663 |
# File 'lib/stripe/services/account_session_service.rb', line 660 def initialize(enabled: nil, features: nil) @enabled = enabled @features = features end |
Instance Attribute Details
#enabled ⇒ Object
Whether the embedded component is enabled.
656 657 658 |
# File 'lib/stripe/services/account_session_service.rb', line 656 def enabled @enabled end |
#features ⇒ Object
The list of features enabled in the embedded component.
658 659 660 |
# File 'lib/stripe/services/account_session_service.rb', line 658 def features @features end |