Class: Stripe::AccountSessionService::CreateParams::Components::TaxThresholdMonitoring
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSessionService::CreateParams::Components::TaxThresholdMonitoring
- Defined in:
- lib/stripe/services/account_session_service.rb
Defined Under Namespace
Classes: Features
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Whether the embedded component is enabled.
-
#features ⇒ Object
An empty list, because this embedded component has no features.
Instance Method Summary collapse
-
#initialize(enabled: nil, features: nil) ⇒ TaxThresholdMonitoring
constructor
A new instance of TaxThresholdMonitoring.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, features: nil) ⇒ TaxThresholdMonitoring
Returns a new instance of TaxThresholdMonitoring.
712 713 714 715 |
# File 'lib/stripe/services/account_session_service.rb', line 712 def initialize(enabled: nil, features: nil) @enabled = enabled @features = features end |
Instance Attribute Details
#enabled ⇒ Object
Whether the embedded component is enabled.
708 709 710 |
# File 'lib/stripe/services/account_session_service.rb', line 708 def enabled @enabled end |
#features ⇒ Object
An empty list, because this embedded component has no features.
710 711 712 |
# File 'lib/stripe/services/account_session_service.rb', line 710 def features @features end |