Class: Stripe::AccountSignals

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/account_signals.rb

Overview

The Account Signals API provides risk related signals that can be used to better manage risks.

Defined Under Namespace

Classes: Delinquency, FraudIntent

Constant Summary collapse

OBJECT_NAME =
"account_signals"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from Stripe::APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#accountObject (readonly)

The account for which the signals belong to.



86
87
88
# File 'lib/stripe/resources/account_signals.rb', line 86

def 
  @account
end

#delinquencyObject (readonly)

The delinquency signal of the account.



88
89
90
# File 'lib/stripe/resources/account_signals.rb', line 88

def delinquency
  @delinquency
end

#fraud_intentObject (readonly)

The fraud intent signal of the account.



90
91
92
# File 'lib/stripe/resources/account_signals.rb', line 90

def fraud_intent
  @fraud_intent
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



92
93
94
# File 'lib/stripe/resources/account_signals.rb', line 92

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



94
95
96
# File 'lib/stripe/resources/account_signals.rb', line 94

def object
  @object
end

Class Method Details

.field_remappingsObject



100
101
102
# File 'lib/stripe/resources/account_signals.rb', line 100

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



96
97
98
# File 'lib/stripe/resources/account_signals.rb', line 96

def self.inner_class_types
  @inner_class_types = { delinquency: Delinquency, fraud_intent: FraudIntent }
end

.object_nameObject



8
9
10
# File 'lib/stripe/resources/account_signals.rb', line 8

def self.object_name
  "account_signals"
end