Class: Stripe::AccountSignals::Delinquency

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/account_signals.rb

Defined Under Namespace

Classes: Indicator

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#evaluated_atObject (readonly)

Time at which the signal was evaluated, measured in seconds since the Unix epoch.



30
31
32
# File 'lib/stripe/resources/account_signals.rb', line 30

def evaluated_at
  @evaluated_at
end

#indicatorsObject (readonly)

Array of objects representing individual factors that contributed to the calculated probability of delinquency.



32
33
34
# File 'lib/stripe/resources/account_signals.rb', line 32

def indicators
  @indicators
end

#probabilityObject (readonly)

The probability of delinquency. Can be between 0.00 and 100.00



34
35
36
# File 'lib/stripe/resources/account_signals.rb', line 34

def probability
  @probability
end

#risk_levelObject (readonly)

Categorical assessment of the delinquency risk based on probability.



36
37
38
# File 'lib/stripe/resources/account_signals.rb', line 36

def risk_level
  @risk_level
end

#signal_idObject (readonly)

Unique identifier for the delinquency signal.



38
39
40
# File 'lib/stripe/resources/account_signals.rb', line 38

def signal_id
  @signal_id
end

Class Method Details

.field_remappingsObject



44
45
46
# File 'lib/stripe/resources/account_signals.rb', line 44

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



40
41
42
# File 'lib/stripe/resources/account_signals.rb', line 40

def self.inner_class_types
  @inner_class_types = { indicators: Indicator }
end