Class: Stripe::AccountSignals::FraudIntent
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::AccountSignals::FraudIntent
- Defined in:
- lib/stripe/resources/account_signals.rb
Defined Under Namespace
Classes: Indicator
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#evaluated_at ⇒ Object
readonly
Time at which the signal was evaluated, measured in seconds since the Unix epoch.
-
#indicators ⇒ Object
readonly
Array of objects representing individual factors that contributed to the calculated probability of fraud intent.
-
#probability ⇒ Object
readonly
The probability of fraud intent.
-
#risk_level ⇒ Object
readonly
Categorical assessment of the fraud intent risk based on probability.
-
#signal_id ⇒ Object
readonly
Unique identifier for the fraud intent signal.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#evaluated_at ⇒ Object (readonly)
Time at which the signal was evaluated, measured in seconds since the Unix epoch.
67 68 69 |
# File 'lib/stripe/resources/account_signals.rb', line 67 def evaluated_at @evaluated_at end |
#indicators ⇒ Object (readonly)
Array of objects representing individual factors that contributed to the calculated probability of fraud intent.
69 70 71 |
# File 'lib/stripe/resources/account_signals.rb', line 69 def indicators @indicators end |
#probability ⇒ Object (readonly)
The probability of fraud intent. Can be between 0.00 and 100.00
71 72 73 |
# File 'lib/stripe/resources/account_signals.rb', line 71 def probability @probability end |
#risk_level ⇒ Object (readonly)
Categorical assessment of the fraud intent risk based on probability.
73 74 75 |
# File 'lib/stripe/resources/account_signals.rb', line 73 def risk_level @risk_level end |
#signal_id ⇒ Object (readonly)
Unique identifier for the fraud intent signal.
75 76 77 |
# File 'lib/stripe/resources/account_signals.rb', line 75 def signal_id @signal_id end |
Class Method Details
.field_remappings ⇒ Object
81 82 83 |
# File 'lib/stripe/resources/account_signals.rb', line 81 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
77 78 79 |
# File 'lib/stripe/resources/account_signals.rb', line 77 def self.inner_class_types @inner_class_types = { indicators: Indicator } end |