Class: Stripe::AccountUpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/account_update_params.rb

Defined Under Namespace

Classes: BankAccount, BusinessProfile, Capabilities, Card, CardToken, Company, Documents, Groups, Individual, Settings, TosAcceptance

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(account_token: nil, business_profile: nil, business_type: nil, capabilities: nil, company: nil, default_currency: nil, documents: nil, email: nil, expand: nil, external_account: nil, groups: nil, individual: nil, metadata: nil, settings: nil, tos_acceptance: nil) ⇒ AccountUpdateParams

Returns a new instance of AccountUpdateParams.



2063
2064
2065
2066
2067
2068
2069
2070
2071
2072
2073
2074
2075
2076
2077
2078
2079
2080
2081
2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
2092
2093
2094
2095
# File 'lib/stripe/params/account_update_params.rb', line 2063

def initialize(
  account_token: nil,
  business_profile: nil,
  business_type: nil,
  capabilities: nil,
  company: nil,
  default_currency: nil,
  documents: nil,
  email: nil,
  expand: nil,
  external_account: nil,
  groups: nil,
  individual: nil,
  metadata: nil,
  settings: nil,
  tos_acceptance: nil
)
  @account_token = 
  @business_profile = business_profile
  @business_type = business_type
  @capabilities = capabilities
  @company = company
  @default_currency = default_currency
  @documents = documents
  @email = email
  @expand = expand
   = 
  @groups = groups
  @individual = individual
   = 
  @settings = settings
  @tos_acceptance = tos_acceptance
end

Instance Attribute Details

#account_tokenObject

An [account token](api.stripe.com#create_account_token), used to securely provide details to the account.



2026
2027
2028
# File 'lib/stripe/params/account_update_params.rb', line 2026

def 
  @account_token
end

#business_profileObject

Business information about the account.



2028
2029
2030
# File 'lib/stripe/params/account_update_params.rb', line 2028

def business_profile
  @business_profile
end

#business_typeObject

The business type. Once you create an [Account Link](/api/account_links) or [Account Session](/api/account_sessions), this property can only be updated for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is application, which includes Custom accounts.



2030
2031
2032
# File 'lib/stripe/params/account_update_params.rb', line 2030

def business_type
  @business_type
end

#capabilitiesObject

Each key of the dictionary represents a capability, and each capability maps to its settings (for example, whether it has been requested or not). Each capability is inactive until you have provided its specific requirements and Stripe has verified them. An account might have some of its requested capabilities be active and some be inactive.

Required when [account.controller.stripe_dashboard.type](/api/accounts/create#create_account-controller-dashboard-type) is none, which includes Custom accounts.



2039
2040
2041
# File 'lib/stripe/params/account_update_params.rb', line 2039

def capabilities
  @capabilities
end

#companyObject

Information about the company or business. This field is available for any business_type. Once you create an [Account Link](/api/account_links) or [Account Session](/api/account_sessions), this property can only be updated for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is application, which includes Custom accounts.



2041
2042
2043
# File 'lib/stripe/params/account_update_params.rb', line 2041

def company
  @company
end

#default_currencyObject

Three-letter ISO currency code representing the default currency for the account. This must be a currency that [Stripe supports in the account’s country](docs.stripe.com/payouts).



2043
2044
2045
# File 'lib/stripe/params/account_update_params.rb', line 2043

def default_currency
  @default_currency
end

#documentsObject

Documents that may be submitted to satisfy various informational requests.



2045
2046
2047
# File 'lib/stripe/params/account_update_params.rb', line 2045

def documents
  @documents
end

#emailObject

The email address of the account holder. This is only to make the account easier to identify to you. If [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is application, which includes Custom accounts, Stripe doesn’t email the account without your consent.



2047
2048
2049
# File 'lib/stripe/params/account_update_params.rb', line 2047

def email
  @email
end

#expandObject

Specifies which fields in the response should be expanded.



2049
2050
2051
# File 'lib/stripe/params/account_update_params.rb', line 2049

def expand
  @expand
end

#external_accountObject

A card or bank account to attach to the account for receiving [payouts](/connect/bank-debit-card-payouts) (you won’t be able to use it for top-ups). You can provide either a token, like the ones returned by [Stripe.js](/js), or a dictionary, as documented in the external_account parameter for [bank account](/api#account_create_bank_account) creation.

By default, providing an external account sets it as the new default external account for its currency, and deletes the old default if one exists. To add additional external accounts without replacing the existing default for the currency, use the [bank account](/api#account_create_bank_account) or [card creation](/api#account_create_card) APIs. After you create an [Account Link](/api/account_links) or [Account Session](/api/account_sessions), this property can only be updated for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is application, which includes Custom accounts.



2051
2052
2053
# File 'lib/stripe/params/account_update_params.rb', line 2051

def 
  
end

#groupsObject

A hash of account group type to tokens. These are account groups this account should be added to.



2053
2054
2055
# File 'lib/stripe/params/account_update_params.rb', line 2053

def groups
  @groups
end

#individualObject

Information about the person represented by the account. This field is null unless business_type is set to individual. Once you create an [Account Link](/api/account_links) or [Account Session](/api/account_sessions), this property can only be updated for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is application, which includes Custom accounts.



2055
2056
2057
# File 'lib/stripe/params/account_update_params.rb', line 2055

def individual
  @individual
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.



2057
2058
2059
# File 'lib/stripe/params/account_update_params.rb', line 2057

def 
  
end

#settingsObject

Options for customizing how the account functions within Stripe.



2059
2060
2061
# File 'lib/stripe/params/account_update_params.rb', line 2059

def settings
  @settings
end

#tos_acceptanceObject

Details on the account’s acceptance of the [Stripe Services Agreement](/connect/updating-accounts#tos-acceptance). This property can only be updated for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is application, which includes Custom accounts. This property defaults to a full service agreement when empty.



2061
2062
2063
# File 'lib/stripe/params/account_update_params.rb', line 2061

def tos_acceptance
  @tos_acceptance
end