Class: Stripe::AccountUpdateParams::Capabilities::AffirmPayments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountUpdateParams::Capabilities::AffirmPayments
- Defined in:
- lib/stripe/params/account_update_params.rb
Instance Attribute Summary collapse
-
#requested ⇒ Object
Passing true requests the capability for the account, if it is not already requested.
Instance Method Summary collapse
-
#initialize(requested: nil) ⇒ AffirmPayments
constructor
A new instance of AffirmPayments.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(requested: nil) ⇒ AffirmPayments
Returns a new instance of AffirmPayments.
171 172 173 |
# File 'lib/stripe/params/account_update_params.rb', line 171 def initialize(requested: nil) @requested = requested end |
Instance Attribute Details
#requested ⇒ Object
Passing true requests the capability for the account, if it is not already requested. A requested capability may not immediately become active. Any requirements to activate the capability are returned in the ‘requirements` arrays.
169 170 171 |
# File 'lib/stripe/params/account_update_params.rb', line 169 def requested @requested end |