Class: Stripe::AccountUpdateParams::Capabilities::CardIssuing

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(requested: nil) ⇒ CardIssuing

Returns a new instance of CardIssuing.



288
289
290
# File 'lib/stripe/params/account_update_params.rb', line 288

def initialize(requested: nil)
  @requested = requested
end

Instance Attribute Details

#requestedObject

Passing true requests the capability for the account, if it is not already requested. A requested capability may not immediately become active. Any requirements to activate the capability are returned in the ‘requirements` arrays.



286
287
288
# File 'lib/stripe/params/account_update_params.rb', line 286

def requested
  @requested
end