Class: Stripe::AccountUpdateParams::Capabilities::CardPayments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountUpdateParams::Capabilities::CardPayments
- Defined in:
- lib/stripe/params/account_update_params.rb
Defined Under Namespace
Classes: Protections
Instance Attribute Summary collapse
-
#protections ⇒ Object
Protections to apply to this capability.
-
#requested ⇒ Object
Passing true requests the capability for the account, if it is not already requested.
Instance Method Summary collapse
-
#initialize(protections: nil, requested: nil) ⇒ CardPayments
constructor
A new instance of CardPayments.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(protections: nil, requested: nil) ⇒ CardPayments
Returns a new instance of CardPayments.
315 316 317 318 |
# File 'lib/stripe/params/account_update_params.rb', line 315 def initialize(protections: nil, requested: nil) @protections = protections @requested = requested end |
Instance Attribute Details
#protections ⇒ Object
Protections to apply to this capability.
311 312 313 |
# File 'lib/stripe/params/account_update_params.rb', line 311 def protections @protections end |
#requested ⇒ Object
Passing true requests the capability for the account, if it is not already requested. A requested capability may not immediately become active. Any requirements to activate the capability are returned in the ‘requirements` arrays.
313 314 315 |
# File 'lib/stripe/params/account_update_params.rb', line 313 def requested @requested end |