Class: Stripe::AccountUpdateParams::Capabilities::CartesBancairesPayments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountUpdateParams::Capabilities::CartesBancairesPayments
- Defined in:
- lib/stripe/params/account_update_params.rb
Instance Attribute Summary collapse
-
#requested ⇒ Object
Passing true requests the capability for the account, if it is not already requested.
Instance Method Summary collapse
-
#initialize(requested: nil) ⇒ CartesBancairesPayments
constructor
A new instance of CartesBancairesPayments.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(requested: nil) ⇒ CartesBancairesPayments
Returns a new instance of CartesBancairesPayments.
306 307 308 |
# File 'lib/stripe/params/account_update_params.rb', line 306 def initialize(requested: nil) @requested = requested end |
Instance Attribute Details
#requested ⇒ Object
Passing true requests the capability for the account, if it is not already requested. A requested capability may not immediately become active. Any requirements to activate the capability are returned in the ‘requirements` arrays.
304 305 306 |
# File 'lib/stripe/params/account_update_params.rb', line 304 def requested @requested end |