Class: Stripe::AccountUpdateParams::Capabilities::NzBankAccountBecsDebitPayments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(requested: nil) ⇒ NzBankAccountBecsDebitPayments

Returns a new instance of NzBankAccountBecsDebitPayments.



540
541
542
# File 'lib/stripe/params/account_update_params.rb', line 540

def initialize(requested: nil)
  @requested = requested
end

Instance Attribute Details

#requestedObject

Passing true requests the capability for the account, if it is not already requested. A requested capability may not immediately become active. Any requirements to activate the capability are returned in the ‘requirements` arrays.



538
539
540
# File 'lib/stripe/params/account_update_params.rb', line 538

def requested
  @requested
end