Class: Stripe::AccountUpdateParams::Capabilities::PaypayPayments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountUpdateParams::Capabilities::PaypayPayments
- Defined in:
- lib/stripe/params/account_update_params.rb
Instance Attribute Summary collapse
-
#requested ⇒ Object
Passing true requests the capability for the account, if it is not already requested.
Instance Method Summary collapse
-
#initialize(requested: nil) ⇒ PaypayPayments
constructor
A new instance of PaypayPayments.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(requested: nil) ⇒ PaypayPayments
Returns a new instance of PaypayPayments.
603 604 605 |
# File 'lib/stripe/params/account_update_params.rb', line 603 def initialize(requested: nil) @requested = requested end |
Instance Attribute Details
#requested ⇒ Object
Passing true requests the capability for the account, if it is not already requested. A requested capability may not immediately become active. Any requirements to activate the capability are returned in the ‘requirements` arrays.
601 602 603 |
# File 'lib/stripe/params/account_update_params.rb', line 601 def requested @requested end |