Class: Stripe::AccountUpdateParams::Company::DirectorshipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ DirectorshipDeclaration

Returns a new instance of DirectorshipDeclaration.



1432
1433
1434
1435
1436
# File 'lib/stripe/params/account_update_params.rb', line 1432

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the directorship declaration attestation was made.



1426
1427
1428
# File 'lib/stripe/params/account_update_params.rb', line 1426

def date
  @date
end

#ipObject

The IP address from which the directorship declaration attestation was made.



1428
1429
1430
# File 'lib/stripe/params/account_update_params.rb', line 1428

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the directorship declaration attestation was made.



1430
1431
1432
# File 'lib/stripe/params/account_update_params.rb', line 1430

def user_agent
  @user_agent
end