Class: Stripe::AccountUpdateParams::Company::OwnershipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ OwnershipDeclaration

Returns a new instance of OwnershipDeclaration.



1172
1173
1174
1175
1176
# File 'lib/stripe/params/account_update_params.rb', line 1172

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the beneficial owner attestation was made.



1166
1167
1168
# File 'lib/stripe/params/account_update_params.rb', line 1166

def date
  @date
end

#ipObject

The IP address from which the beneficial owner attestation was made.



1168
1169
1170
# File 'lib/stripe/params/account_update_params.rb', line 1168

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the beneficial owner attestation was made.



1170
1171
1172
# File 'lib/stripe/params/account_update_params.rb', line 1170

def user_agent
  @user_agent
end