Class: Stripe::AccountUpdateParams::Company::RepresentativeDeclaration
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountUpdateParams::Company::RepresentativeDeclaration
- Defined in:
- lib/stripe/params/account_update_params.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the representative declaration attestation was made.
-
#ip ⇒ Object
The IP address from which the representative declaration attestation was made.
-
#user_agent ⇒ Object
The user agent of the browser from which the representative declaration attestation was made.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ RepresentativeDeclaration
constructor
A new instance of RepresentativeDeclaration.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ RepresentativeDeclaration
Returns a new instance of RepresentativeDeclaration.
1202 1203 1204 1205 1206 |
# File 'lib/stripe/params/account_update_params.rb', line 1202 def initialize(date: nil, ip: nil, user_agent: nil) @date = date @ip = ip @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the representative declaration attestation was made.
1196 1197 1198 |
# File 'lib/stripe/params/account_update_params.rb', line 1196 def date @date end |
#ip ⇒ Object
The IP address from which the representative declaration attestation was made.
1198 1199 1200 |
# File 'lib/stripe/params/account_update_params.rb', line 1198 def ip @ip end |
#user_agent ⇒ Object
The user agent of the browser from which the representative declaration attestation was made.
1200 1201 1202 |
# File 'lib/stripe/params/account_update_params.rb', line 1200 def user_agent @user_agent end |