Class: Stripe::AccountUpdateParams::Documents::BankAccountOwnershipVerification
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountUpdateParams::Documents::BankAccountOwnershipVerification
- Defined in:
- lib/stripe/params/account_update_params.rb
Instance Attribute Summary collapse
-
#files ⇒ Object
One or more document ids returned by a [file upload](api.stripe.com#create_file) with a ‘purpose` value of `account_requirement`.
Instance Method Summary collapse
-
#initialize(files: nil) ⇒ BankAccountOwnershipVerification
constructor
A new instance of BankAccountOwnershipVerification.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(files: nil) ⇒ BankAccountOwnershipVerification
Returns a new instance of BankAccountOwnershipVerification.
1530 1531 1532 |
# File 'lib/stripe/params/account_update_params.rb', line 1530 def initialize(files: nil) @files = files end |
Instance Attribute Details
#files ⇒ Object
One or more document ids returned by a [file upload](api.stripe.com#create_file) with a ‘purpose` value of `account_requirement`.
1528 1529 1530 |
# File 'lib/stripe/params/account_update_params.rb', line 1528 def files @files end |