Class: Stripe::AccountUpdateParams::Documents::ProofOfAddress
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountUpdateParams::Documents::ProofOfAddress
- Defined in:
- lib/stripe/params/account_update_params.rb
Instance Attribute Summary collapse
-
#files ⇒ Object
One or more document ids returned by a file upload with a
purposevalue ofaccount_requirement.
Instance Method Summary collapse
-
#initialize(files: nil) ⇒ ProofOfAddress
constructor
A new instance of ProofOfAddress.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(files: nil) ⇒ ProofOfAddress
Returns a new instance of ProofOfAddress.
1701 1702 1703 |
# File 'lib/stripe/params/account_update_params.rb', line 1701 def initialize(files: nil) @files = files end |
Instance Attribute Details
#files ⇒ Object
One or more document ids returned by a file upload with a purpose value of account_requirement.
1699 1700 1701 |
# File 'lib/stripe/params/account_update_params.rb', line 1699 def files @files end |