Class: Stripe::AccountUpdateParams::Documents::ProofOfRegistration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_update_params.rb

Defined Under Namespace

Classes: Signer

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(files: nil, signer: nil) ⇒ ProofOfRegistration

Returns a new instance of ProofOfRegistration.



1629
1630
1631
1632
# File 'lib/stripe/params/account_update_params.rb', line 1629

def initialize(files: nil, signer: nil)
  @files = files
  @signer = signer
end

Instance Attribute Details

#filesObject

One or more document ids returned by a [file upload](api.stripe.com#create_file) with a ‘purpose` value of `account_requirement`.



1625
1626
1627
# File 'lib/stripe/params/account_update_params.rb', line 1625

def files
  @files
end

#signerObject

Information regarding the person signing the document if applicable.



1627
1628
1629
# File 'lib/stripe/params/account_update_params.rb', line 1627

def signer
  @signer
end