Class: Stripe::AccountUpdateParams::Documents::ProofOfUltimateBeneficialOwnership::Signer
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountUpdateParams::Documents::ProofOfUltimateBeneficialOwnership::Signer
- Defined in:
- lib/stripe/params/account_update_params.rb
Instance Attribute Summary collapse
-
#person ⇒ Object
The token of the person signing the document, if applicable.
Instance Method Summary collapse
-
#initialize(person: nil) ⇒ Signer
constructor
A new instance of Signer.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(person: nil) ⇒ Signer
Returns a new instance of Signer.
1640 1641 1642 |
# File 'lib/stripe/params/account_update_params.rb', line 1640 def initialize(person: nil) @person = person end |
Instance Attribute Details
#person ⇒ Object
The token of the person signing the document, if applicable.
1638 1639 1640 |
# File 'lib/stripe/params/account_update_params.rb', line 1638 def person @person end |