Class: Stripe::AccountUpdateParams::Individual::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship

Returns a new instance of Relationship.



1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
1896
# File 'lib/stripe/params/account_update_params.rb', line 1884

def initialize(
  director: nil,
  executive: nil,
  owner: nil,
  percent_ownership: nil,
  title: nil
)
  @director = director
  @executive = executive
  @owner = owner
  @percent_ownership = percent_ownership
  @title = title
end

Instance Attribute Details

#directorObject

Whether the person is a director of the account’s legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



1874
1875
1876
# File 'lib/stripe/params/account_update_params.rb', line 1874

def director
  @director
end

#executiveObject

Whether the person has significant responsibility to control, manage, or direct the organization.



1876
1877
1878
# File 'lib/stripe/params/account_update_params.rb', line 1876

def executive
  @executive
end

#ownerObject

Whether the person is an owner of the account’s legal entity.



1878
1879
1880
# File 'lib/stripe/params/account_update_params.rb', line 1878

def owner
  @owner
end

#percent_ownershipObject

The percent owned by the person of the account’s legal entity.



1880
1881
1882
# File 'lib/stripe/params/account_update_params.rb', line 1880

def percent_ownership
  @percent_ownership
end

#titleObject

The person’s title (e.g., CEO, Support Engineer).



1882
1883
1884
# File 'lib/stripe/params/account_update_params.rb', line 1882

def title
  @title
end