Class: Stripe::AccountUpdateParams::Individual::Verification::AdditionalDocument

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(back: nil, front: nil) ⇒ AdditionalDocument

Returns a new instance of AdditionalDocument.



1846
1847
1848
1849
# File 'lib/stripe/params/account_update_params.rb', line 1846

def initialize(back: nil, front: nil)
  @back = back
  @front = front
end

Instance Attribute Details

#backObject

The back of an ID returned by a [file upload](api.stripe.com#create_file) with a ‘purpose` value of `identity_document`. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.



1842
1843
1844
# File 'lib/stripe/params/account_update_params.rb', line 1842

def back
  @back
end

#frontObject

The front of an ID returned by a [file upload](api.stripe.com#create_file) with a ‘purpose` value of `identity_document`. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.



1844
1845
1846
# File 'lib/stripe/params/account_update_params.rb', line 1844

def front
  @front
end