Class: Stripe::AccountUpdateParams::Individual::Verification::Document

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(back: nil, front: nil) ⇒ Document

Returns a new instance of Document.



1674
1675
1676
1677
# File 'lib/stripe/params/account_update_params.rb', line 1674

def initialize(back: nil, front: nil)
  @back = back
  @front = front
end

Instance Attribute Details

#backObject

The back of an ID returned by a [file upload](api.stripe.com#create_file) with a purpose value of identity_document. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.



1670
1671
1672
# File 'lib/stripe/params/account_update_params.rb', line 1670

def back
  @back
end

#frontObject

The front of an ID returned by a [file upload](api.stripe.com#create_file) with a purpose value of identity_document. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.



1672
1673
1674
# File 'lib/stripe/params/account_update_params.rb', line 1672

def front
  @front
end