Class: Stripe::AccountUpdateParams::Settings

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/account_update_params.rb

Defined Under Namespace

Classes: BacsDebitPayments, BankBcaOnboarding, Branding, Capital, CardIssuing, CardPayments, Invoices, Payments, Payouts, PaypayPayments, SepaDebitPayments, SmartDisputes, TaxForms, Treasury, WechatPayPayments

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, paypay_payments: nil, sepa_debit_payments: nil, smart_disputes: nil, tax_forms: nil, treasury: nil, wechat_pay_payments: nil) ⇒ Settings

Returns a new instance of Settings.



2541
2542
2543
2544
2545
2546
2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
2569
2570
2571
2572
2573
# File 'lib/stripe/params/account_update_params.rb', line 2541

def initialize(
  bacs_debit_payments: nil,
  bank_bca_onboarding: nil,
  branding: nil,
  capital: nil,
  card_issuing: nil,
  card_payments: nil,
  invoices: nil,
  payments: nil,
  payouts: nil,
  paypay_payments: nil,
  sepa_debit_payments: nil,
  smart_disputes: nil,
  tax_forms: nil,
  treasury: nil,
  wechat_pay_payments: nil
)
  @bacs_debit_payments = bacs_debit_payments
  @bank_bca_onboarding = bank_bca_onboarding
  @branding = branding
  @capital = capital
  @card_issuing = card_issuing
  @card_payments = card_payments
  @invoices = invoices
  @payments = payments
  @payouts = payouts
  @paypay_payments = paypay_payments
  @sepa_debit_payments = sepa_debit_payments
  @smart_disputes = smart_disputes
  @tax_forms = tax_forms
  @treasury = treasury
  @wechat_pay_payments = wechat_pay_payments
end

Instance Attribute Details

#bacs_debit_paymentsObject

Settings specific to Bacs Direct Debit payments.



2511
2512
2513
# File 'lib/stripe/params/account_update_params.rb', line 2511

def bacs_debit_payments
  @bacs_debit_payments
end

#bank_bca_onboardingObject

Settings specific to bank BCA onboarding for Indonesia bank transfers payments method.



2513
2514
2515
# File 'lib/stripe/params/account_update_params.rb', line 2513

def bank_bca_onboarding
  @bank_bca_onboarding
end

#brandingObject

Settings used to apply the account's branding to email receipts, invoices, Checkout, and other products.



2515
2516
2517
# File 'lib/stripe/params/account_update_params.rb', line 2515

def branding
  @branding
end

#capitalObject

Settings specific to the account's use of the Capital product.



2517
2518
2519
# File 'lib/stripe/params/account_update_params.rb', line 2517

def capital
  @capital
end

#card_issuingObject

Settings specific to the account's use of the Card Issuing product.



2519
2520
2521
# File 'lib/stripe/params/account_update_params.rb', line 2519

def card_issuing
  @card_issuing
end

#card_paymentsObject

Settings specific to card charging on the account.



2521
2522
2523
# File 'lib/stripe/params/account_update_params.rb', line 2521

def card_payments
  @card_payments
end

#invoicesObject

Settings specific to the account's use of Invoices.



2523
2524
2525
# File 'lib/stripe/params/account_update_params.rb', line 2523

def invoices
  @invoices
end

#paymentsObject

Settings that apply across payment methods for charging on the account.



2525
2526
2527
# File 'lib/stripe/params/account_update_params.rb', line 2525

def payments
  @payments
end

#payoutsObject

Settings specific to the account's payouts.



2527
2528
2529
# File 'lib/stripe/params/account_update_params.rb', line 2527

def payouts
  @payouts
end

#paypay_paymentsObject

Settings specific to the PayPay payments method.



2529
2530
2531
# File 'lib/stripe/params/account_update_params.rb', line 2529

def paypay_payments
  @paypay_payments
end

#sepa_debit_paymentsObject

Settings specific to SEPA Direct Debit payments.



2531
2532
2533
# File 'lib/stripe/params/account_update_params.rb', line 2531

def sepa_debit_payments
  @sepa_debit_payments
end

#smart_disputesObject

Settings specific to the account's use of Smart Disputes.



2533
2534
2535
# File 'lib/stripe/params/account_update_params.rb', line 2533

def smart_disputes
  @smart_disputes
end

#tax_formsObject

Settings specific to the account's tax forms.



2535
2536
2537
# File 'lib/stripe/params/account_update_params.rb', line 2535

def tax_forms
  @tax_forms
end

#treasuryObject

Settings specific to the account's Treasury FinancialAccounts.



2537
2538
2539
# File 'lib/stripe/params/account_update_params.rb', line 2537

def treasury
  @treasury
end

#wechat_pay_paymentsObject

Settings specific to the WeChat Pay payments method.



2539
2540
2541
# File 'lib/stripe/params/account_update_params.rb', line 2539

def wechat_pay_payments
  @wechat_pay_payments
end