Class: Stripe::AccountUpdateParams::Settings::Branding

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil) ⇒ Branding

Returns a new instance of Branding.



1931
1932
1933
1934
1935
1936
# File 'lib/stripe/params/account_update_params.rb', line 1931

def initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil)
  @icon = icon
  @logo = 
  @primary_color = primary_color
  @secondary_color = secondary_color
end

Instance Attribute Details

#iconObject

(ID of a file upload) An icon for the account. Must be square and at least 128px x 128px.



1923
1924
1925
# File 'lib/stripe/params/account_update_params.rb', line 1923

def icon
  @icon
end

#logoObject

(ID of a file upload) A logo for the account that will be used in Checkout instead of the icon and without the account's name next to it if provided. Must be at least 128px x 128px.



1925
1926
1927
# File 'lib/stripe/params/account_update_params.rb', line 1925

def 
  @logo
end

#primary_colorObject

A CSS hex color value representing the primary branding color for this account.



1927
1928
1929
# File 'lib/stripe/params/account_update_params.rb', line 1927

def primary_color
  @primary_color
end

#secondary_colorObject

A CSS hex color value representing the secondary branding color for this account.



1929
1930
1931
# File 'lib/stripe/params/account_update_params.rb', line 1929

def secondary_color
  @secondary_color
end