Class: Stripe::AccountUpdateParams::Settings::CardIssuing::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



1991
1992
1993
1994
1995
# File 'lib/stripe/params/account_update_params.rb', line 1991

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#date ⇒ Object

The Unix timestamp marking when the account representative accepted the service agreement.



1985
1986
1987
# File 'lib/stripe/params/account_update_params.rb', line 1985

def date
  @date
end

#ip ⇒ Object

The IP address from which the account representative accepted the service agreement.



1987
1988
1989
# File 'lib/stripe/params/account_update_params.rb', line 1987

def ip
  @ip
end

#user_agent ⇒ Object

The user agent of the browser from which the account representative accepted the service agreement.



1989
1990
1991
# File 'lib/stripe/params/account_update_params.rb', line 1989

def user_agent
  @user_agent
end