Class: Stripe::AccountUpdateParams::Settings::CardPayments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_update_params.rb

Defined Under Namespace

Classes: DeclineOn

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(decline_on: nil, statement_descriptor_prefix: nil, statement_descriptor_prefix_kana: nil, statement_descriptor_prefix_kanji: nil) ⇒ CardPayments

Returns a new instance of CardPayments.



2297
2298
2299
2300
2301
2302
2303
2304
2305
2306
2307
# File 'lib/stripe/params/account_update_params.rb', line 2297

def initialize(
  decline_on: nil,
  statement_descriptor_prefix: nil,
  statement_descriptor_prefix_kana: nil,
  statement_descriptor_prefix_kanji: nil
)
  @decline_on = decline_on
  @statement_descriptor_prefix = statement_descriptor_prefix
  @statement_descriptor_prefix_kana = statement_descriptor_prefix_kana
  @statement_descriptor_prefix_kanji = statement_descriptor_prefix_kanji
end

Instance Attribute Details

#decline_onObject

Automatically declines certain charge types regardless of whether the card issuer accepted or declined the charge.



2289
2290
2291
# File 'lib/stripe/params/account_update_params.rb', line 2289

def decline_on
  @decline_on
end

#statement_descriptor_prefixObject

The default text that appears on credit card statements when a charge is made. This field prefixes any dynamic statement_descriptor specified on the charge. statement_descriptor_prefix is useful for maximizing descriptor space for the dynamic portion.



2291
2292
2293
# File 'lib/stripe/params/account_update_params.rb', line 2291

def statement_descriptor_prefix
  @statement_descriptor_prefix
end

#statement_descriptor_prefix_kanaObject

The Kana variation of the default text that appears on credit card statements when a charge is made (Japan only). This field prefixes any dynamic statement_descriptor_suffix_kana specified on the charge. statement_descriptor_prefix_kana is useful for maximizing descriptor space for the dynamic portion.



2293
2294
2295
# File 'lib/stripe/params/account_update_params.rb', line 2293

def statement_descriptor_prefix_kana
  @statement_descriptor_prefix_kana
end

#statement_descriptor_prefix_kanjiObject

The Kanji variation of the default text that appears on credit card statements when a charge is made (Japan only). This field prefixes any dynamic statement_descriptor_suffix_kanji specified on the charge. statement_descriptor_prefix_kanji is useful for maximizing descriptor space for the dynamic portion.



2295
2296
2297
# File 'lib/stripe/params/account_update_params.rb', line 2295

def statement_descriptor_prefix_kanji
  @statement_descriptor_prefix_kanji
end