Class: Stripe::AccountUpdateParams::Settings::Invoices

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(default_account_tax_ids: nil, hosted_payment_method_save: nil) ⇒ Invoices

Returns a new instance of Invoices.



2002
2003
2004
2005
# File 'lib/stripe/params/account_update_params.rb', line 2002

def initialize(default_account_tax_ids: nil, hosted_payment_method_save: nil)
  @default_account_tax_ids = 
  @hosted_payment_method_save = hosted_payment_method_save
end

Instance Attribute Details

#default_account_tax_idsObject

The list of default Account Tax IDs to automatically include on invoices. Account Tax IDs get added when an invoice is finalized.



1998
1999
2000
# File 'lib/stripe/params/account_update_params.rb', line 1998

def 
  @default_account_tax_ids
end

#hosted_payment_method_saveObject

Whether to save the payment method after a payment is completed for a one-time invoice or a subscription invoice when the customer already has a default payment method on the hosted invoice page.



2000
2001
2002
# File 'lib/stripe/params/account_update_params.rb', line 2000

def hosted_payment_method_save
  @hosted_payment_method_save
end