Class: Stripe::AccountUpdateParams::Settings::PaypayPayments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountUpdateParams::Settings::PaypayPayments
- Defined in:
- lib/stripe/params/account_update_params.rb
Defined Under Namespace
Classes: Site
Instance Attribute Summary collapse
-
#additional_files ⇒ Object
Additional files that are required to support the onboarding process of your business.
-
#goods_type ⇒ Object
The type of goods your business sells.
-
#site ⇒ Object
Details regarding your business's website.
Instance Method Summary collapse
-
#initialize(additional_files: nil, goods_type: nil, site: nil) ⇒ PaypayPayments
constructor
A new instance of PaypayPayments.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(additional_files: nil, goods_type: nil, site: nil) ⇒ PaypayPayments
Returns a new instance of PaypayPayments.
2437 2438 2439 2440 2441 |
# File 'lib/stripe/params/account_update_params.rb', line 2437 def initialize(additional_files: nil, goods_type: nil, site: nil) @additional_files = additional_files @goods_type = goods_type @site = site end |
Instance Attribute Details
#additional_files ⇒ Object
Additional files that are required to support the onboarding process of your business.
2431 2432 2433 |
# File 'lib/stripe/params/account_update_params.rb', line 2431 def additional_files @additional_files end |
#goods_type ⇒ Object
The type of goods your business sells. Use digital_content if you sell digital content. Use other for all other types of goods or services.
2433 2434 2435 |
# File 'lib/stripe/params/account_update_params.rb', line 2433 def goods_type @goods_type end |
#site ⇒ Object
Details regarding your business's website.
2435 2436 2437 |
# File 'lib/stripe/params/account_update_params.rb', line 2435 def site @site end |