Class: Stripe::AccountUpdateParams::Settings::PaypayPayments::Site::Restricted
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountUpdateParams::Settings::PaypayPayments::Site::Restricted
- Defined in:
- lib/stripe/params/account_update_params.rb
Instance Attribute Summary collapse
-
#payment_flow_file ⇒ Object
The file explaining the payment flow for your business.
Instance Method Summary collapse
-
#initialize(payment_flow_file: nil) ⇒ Restricted
constructor
A new instance of Restricted.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(payment_flow_file: nil) ⇒ Restricted
Returns a new instance of Restricted.
2226 2227 2228 |
# File 'lib/stripe/params/account_update_params.rb', line 2226 def initialize(payment_flow_file: nil) @payment_flow_file = payment_flow_file end |
Instance Attribute Details
#payment_flow_file ⇒ Object
The file explaining the payment flow for your business.
2224 2225 2226 |
# File 'lib/stripe/params/account_update_params.rb', line 2224 def payment_flow_file @payment_flow_file end |