Class: Stripe::AccountUpdateParams::Settings::Treasury::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



2090
2091
2092
2093
2094
# File 'lib/stripe/params/account_update_params.rb', line 2090

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



2084
2085
2086
# File 'lib/stripe/params/account_update_params.rb', line 2084

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



2086
2087
2088
# File 'lib/stripe/params/account_update_params.rb', line 2086

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



2088
2089
2090
# File 'lib/stripe/params/account_update_params.rb', line 2088

def user_agent
  @user_agent
end