Class: Stripe::ApplePayDomain::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ApplePayDomain::CreateParams
- Defined in:
- lib/stripe/resources/apple_pay_domain.rb
Instance Attribute Summary collapse
-
#domain_name ⇒ Object
Attribute for param field domain_name.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(domain_name: nil, expand: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(domain_name: nil, expand: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
51 52 53 54 |
# File 'lib/stripe/resources/apple_pay_domain.rb', line 51 def initialize(domain_name: nil, expand: nil) @domain_name = domain_name @expand = end |
Instance Attribute Details
#domain_name ⇒ Object
Attribute for param field domain_name
47 48 49 |
# File 'lib/stripe/resources/apple_pay_domain.rb', line 47 def domain_name @domain_name end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
49 50 51 |
# File 'lib/stripe/resources/apple_pay_domain.rb', line 49 def @expand end |