Class: Stripe::ApplePayDomainService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ApplePayDomainService::CreateParams
- Defined in:
- lib/stripe/services/apple_pay_domain_service.rb
Instance Attribute Summary collapse
-
#domain_name ⇒ Object
Attribute for param field domain_name.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(domain_name: nil, expand: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(domain_name: nil, expand: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
56 57 58 59 |
# File 'lib/stripe/services/apple_pay_domain_service.rb', line 56 def initialize(domain_name: nil, expand: nil) @domain_name = domain_name @expand = end |
Instance Attribute Details
#domain_name ⇒ Object
Attribute for param field domain_name
51 52 53 |
# File 'lib/stripe/services/apple_pay_domain_service.rb', line 51 def domain_name @domain_name end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
54 55 56 |
# File 'lib/stripe/services/apple_pay_domain_service.rb', line 54 def @expand end |