Class: Stripe::ApplicationFeeRefund

Inherits:
APIResource show all
Includes:
Stripe::APIOperations::Save
Defined in:
lib/stripe/resources/application_fee_refund.rb

Overview

‘Application Fee Refund` objects allow you to refund an application fee that has previously been created but not yet refunded. Funds will be refunded to the Stripe account from which the fee was originally collected.

Related guide: [Refunding application fees](stripe.com/docs/connect/destination-charges#refunding-app-fee)

Constant Summary collapse

OBJECT_NAME =
"fee_refund"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Stripe::APIOperations::Save

included, #save

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, save_nested_resource

Methods included from Stripe::APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Amount, in cents (or local equivalent).



19
20
21
# File 'lib/stripe/resources/application_fee_refund.rb', line 19

def amount
  @amount
end

#balance_transactionObject (readonly)

Balance transaction that describes the impact on your account balance.



22
23
24
# File 'lib/stripe/resources/application_fee_refund.rb', line 22

def balance_transaction
  @balance_transaction
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



25
26
27
# File 'lib/stripe/resources/application_fee_refund.rb', line 25

def created
  @created
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



28
29
30
# File 'lib/stripe/resources/application_fee_refund.rb', line 28

def currency
  @currency
end

#feeObject (readonly)

ID of the application fee that was refunded.



31
32
33
# File 'lib/stripe/resources/application_fee_refund.rb', line 31

def fee
  @fee
end

#idObject (readonly)

Unique identifier for the object.



34
35
36
# File 'lib/stripe/resources/application_fee_refund.rb', line 34

def id
  @id
end

#metadataObject (readonly)

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



37
38
39
# File 'lib/stripe/resources/application_fee_refund.rb', line 37

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



40
41
42
# File 'lib/stripe/resources/application_fee_refund.rb', line 40

def object
  @object
end

Class Method Details

.object_nameObject



14
15
16
# File 'lib/stripe/resources/application_fee_refund.rb', line 14

def self.object_name
  "fee_refund"
end

.retrieve(_id, _api_key = nil) ⇒ Object

Raises:

  • (NotImplementedError)


55
56
57
58
59
60
# File 'lib/stripe/resources/application_fee_refund.rb', line 55

def self.retrieve(_id, _api_key = nil)
  raise NotImplementedError,
        "Application fee refunds cannot be retrieved without an " \
        "application fee ID. Retrieve an application fee refund using " \
        "`ApplicationFee.retrieve_refund('fee_id', 'refund_id')`"
end

.update(_id, _params = nil, _opts = nil) ⇒ Object

Raises:

  • (NotImplementedError)


47
48
49
50
51
52
53
# File 'lib/stripe/resources/application_fee_refund.rb', line 47

def self.update(_id, _params = nil, _opts = nil)
  raise NotImplementedError,
        "Application fee refunds cannot be updated without an " \
        "application fee ID. Update an application fee refund using " \
        "`ApplicationFee.update_refund('fee_id', 'refund_id', " \
        "update_params)`"
end

Instance Method Details

#resource_urlObject



42
43
44
45
# File 'lib/stripe/resources/application_fee_refund.rb', line 42

def resource_url
  "#{ApplicationFee.resource_url}/#{CGI.escape(fee)}/refunds" \
    "/#{CGI.escape(id)}"
end