Class: Stripe::ApplicationFeeRefundService::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/application_fee_refund_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, expand: nil, metadata: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



59
60
61
62
63
# File 'lib/stripe/services/application_fee_refund_service.rb', line 59

def initialize(amount: nil, expand: nil, metadata: nil)
  @amount = amount
  @expand = expand
  @metadata = 
end

Instance Attribute Details

#amountObject

A positive integer, in _cents (or local equivalent)_, representing how much of this fee to refund. Can refund only up to the remaining unrefunded amount of the fee.



51
52
53
# File 'lib/stripe/services/application_fee_refund_service.rb', line 51

def amount
  @amount
end

#expandObject

Specifies which fields in the response should be expanded.



54
55
56
# File 'lib/stripe/services/application_fee_refund_service.rb', line 54

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



57
58
59
# File 'lib/stripe/services/application_fee_refund_service.rb', line 57

def 
  @metadata
end