Class: Stripe::Apps::Install::ContentSecurityPolicyGranted
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Apps::Install::ContentSecurityPolicyGranted
- Defined in:
- lib/stripe/resources/apps/install.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#connect_src ⇒ Object
readonly
The URLs that the app can make network requests to.
-
#image_src ⇒ Object
readonly
The URLs that the app can load images from.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#connect_src ⇒ Object (readonly)
The URLs that the app can make network requests to.
22 23 24 |
# File 'lib/stripe/resources/apps/install.rb', line 22 def connect_src @connect_src end |
#image_src ⇒ Object (readonly)
The URLs that the app can load images from.
24 25 26 |
# File 'lib/stripe/resources/apps/install.rb', line 24 def image_src @image_src end |
Class Method Details
.field_remappings ⇒ Object
30 31 32 |
# File 'lib/stripe/resources/apps/install.rb', line 30 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
26 27 28 |
# File 'lib/stripe/resources/apps/install.rb', line 26 def self.inner_class_types @inner_class_types = {} end |