Class: Stripe::Apps::InstallListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/apps/install_list_params.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h

Constructor Details

#initialize(account: nil, app: nil, approval_required: nil, channel: nil, created: nil, created_by: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, status: nil) ⇒ InstallListParams

Returns a new instance of InstallListParams.



47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/stripe/params/apps/install_list_params.rb', line 47

def initialize(
  account: nil,
  app: nil,
  approval_required: nil,
  channel: nil,
  created: nil,
  created_by: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  starting_after: nil,
  status: nil
)
  @account = 
  @app = app
  @approval_required = approval_required
  @channel = channel
  @created = created
  @created_by = created_by
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
  @status = status
end

Instance Attribute Details

#account ⇒ Object

Only return installs made by this account. Only useful to app developers and embedding platforms, whose lists span the accounts that installed their app.



25
26
27
# File 'lib/stripe/params/apps/install_list_params.rb', line 25

def 
  @account
end

#app ⇒ Object

Only return installs for the app specified by this app ID.



27
28
29
# File 'lib/stripe/params/apps/install_list_params.rb', line 27

def app
  @app
end

#approval_required ⇒ Object

Only return installs whose installer must authorize pending permissions, content security policy entries, or endpoints.



29
30
31
# File 'lib/stripe/params/apps/install_list_params.rb', line 29

def approval_required
  @approval_required
end

#channel ⇒ Object

Only return installs in the distribution channel specified by this channel name.



31
32
33
# File 'lib/stripe/params/apps/install_list_params.rb', line 31

def channel
  @channel
end

#created ⇒ Object

Only return app installs that were created during the given date interval.



33
34
35
# File 'lib/stripe/params/apps/install_list_params.rb', line 33

def created
  @created
end

#created_by ⇒ Object

Only return installs created by the embedding platform specified by this account ID.



35
36
37
# File 'lib/stripe/params/apps/install_list_params.rb', line 35

def created_by
  @created_by
end

#ending_before ⇒ Object

A cursor for use in pagination. ending_before is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with obj_bar, your subsequent call can include ending_before=obj_bar in order to fetch the previous page of the list.



37
38
39
# File 'lib/stripe/params/apps/install_list_params.rb', line 37

def ending_before
  @ending_before
end

#expand ⇒ Object

Specifies which fields in the response should be expanded.



39
40
41
# File 'lib/stripe/params/apps/install_list_params.rb', line 39

def expand
  @expand
end

#limit ⇒ Object

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



41
42
43
# File 'lib/stripe/params/apps/install_list_params.rb', line 41

def limit
  @limit
end

#starting_after ⇒ Object

A cursor for use in pagination. starting_after is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with obj_foo, your subsequent call can include starting_after=obj_foo in order to fetch the next page of the list.



43
44
45
# File 'lib/stripe/params/apps/install_list_params.rb', line 43

def starting_after
  @starting_after
end

#status ⇒ Object

Only return installs with the given status.



45
46
47
# File 'lib/stripe/params/apps/install_list_params.rb', line 45

def status
  @status
end