Class: Stripe::Apps::Secret::DeleteWhereParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/apps/secret.rb

Defined Under Namespace

Classes: Scope

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, name: nil, scope: nil) ⇒ DeleteWhereParams

Returns a new instance of DeleteWhereParams.



148
149
150
151
152
# File 'lib/stripe/resources/apps/secret.rb', line 148

def initialize(expand: nil, name: nil, scope: nil)
  @expand = expand
  @name = name
  @scope = scope
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



142
143
144
# File 'lib/stripe/resources/apps/secret.rb', line 142

def expand
  @expand
end

#nameObject

A name for the secret that’s unique within the scope.



144
145
146
# File 'lib/stripe/resources/apps/secret.rb', line 144

def name
  @name
end

#scopeObject

Specifies the scoping of the secret. Requests originating from UI extensions can only access account-scoped secrets or secrets scoped to their own user.



146
147
148
# File 'lib/stripe/resources/apps/secret.rb', line 146

def scope
  @scope
end