Class: Stripe::Apps::Secret::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Apps::Secret::ListParams
- Defined in:
- lib/stripe/resources/apps/secret.rb
Defined Under Namespace
Classes: Scope
Instance Attribute Summary collapse
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#scope ⇒ Object
Specifies the scoping of the secret.
-
#starting_after ⇒ Object
A cursor for use in pagination.
Instance Method Summary collapse
-
#initialize(ending_before: nil, expand: nil, limit: nil, scope: nil, starting_after: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(ending_before: nil, expand: nil, limit: nil, scope: nil, starting_after: nil) ⇒ ListParams
Returns a new instance of ListParams.
54 55 56 57 58 59 60 |
# File 'lib/stripe/resources/apps/secret.rb', line 54 def initialize(ending_before: nil, expand: nil, limit: nil, scope: nil, starting_after: nil) @ending_before = ending_before @expand = @limit = limit @scope = scope @starting_after = starting_after end |
Instance Attribute Details
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
44 45 46 |
# File 'lib/stripe/resources/apps/secret.rb', line 44 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
46 47 48 |
# File 'lib/stripe/resources/apps/secret.rb', line 46 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
48 49 50 |
# File 'lib/stripe/resources/apps/secret.rb', line 48 def limit @limit end |
#scope ⇒ Object
Specifies the scoping of the secret. Requests originating from UI extensions can only access account-scoped secrets or secrets scoped to their own user.
50 51 52 |
# File 'lib/stripe/resources/apps/secret.rb', line 50 def scope @scope end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
52 53 54 |
# File 'lib/stripe/resources/apps/secret.rb', line 52 def starting_after @starting_after end |