Class: Stripe::Apps::SecretService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::Apps::SecretService
- Defined in:
- lib/stripe/services/apps/secret_service.rb
Defined Under Namespace
Classes: CreateParams, DeleteWhereParams, FindParams, ListParams
Instance Method Summary collapse
-
#create(params = {}, opts = {}) ⇒ Object
Create or replace a secret in the secret store.
-
#delete_where(params = {}, opts = {}) ⇒ Object
Deletes a secret from the secret store by name and scope.
-
#find(params = {}, opts = {}) ⇒ Object
Finds a secret in the secret store by name and scope.
-
#list(params = {}, opts = {}) ⇒ Object
List all secrets stored on the given scope.
Methods inherited from StripeService
#initialize, #request, #request_stream
Constructor Details
This class inherits a constructor from Stripe::StripeService
Instance Method Details
#create(params = {}, opts = {}) ⇒ Object
Create or replace a secret in the secret store.
140 141 142 143 144 145 146 147 148 |
# File 'lib/stripe/services/apps/secret_service.rb', line 140 def create(params = {}, opts = {}) request( method: :post, path: "/v1/apps/secrets", params: params, opts: opts, base_address: :api ) end |
#delete_where(params = {}, opts = {}) ⇒ Object
Deletes a secret from the secret store by name and scope.
151 152 153 154 155 156 157 158 159 |
# File 'lib/stripe/services/apps/secret_service.rb', line 151 def delete_where(params = {}, opts = {}) request( method: :post, path: "/v1/apps/secrets/delete", params: params, opts: opts, base_address: :api ) end |
#find(params = {}, opts = {}) ⇒ Object
Finds a secret in the secret store by name and scope.
162 163 164 165 166 167 168 169 170 |
# File 'lib/stripe/services/apps/secret_service.rb', line 162 def find(params = {}, opts = {}) request( method: :get, path: "/v1/apps/secrets/find", params: params, opts: opts, base_address: :api ) end |
#list(params = {}, opts = {}) ⇒ Object
List all secrets stored on the given scope.
173 174 175 176 177 178 179 180 181 |
# File 'lib/stripe/services/apps/secret_service.rb', line 173 def list(params = {}, opts = {}) request( method: :get, path: "/v1/apps/secrets", params: params, opts: opts, base_address: :api ) end |