Class: Stripe::Apps::SecretService::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/apps/secret_service.rb

Defined Under Namespace

Classes: Scope

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, expires_at: nil, name: nil, payload: nil, scope: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



62
63
64
65
66
67
68
# File 'lib/stripe/services/apps/secret_service.rb', line 62

def initialize(expand: nil, expires_at: nil, name: nil, payload: nil, scope: nil)
  @expand = expand
  @expires_at = expires_at
  @name = name
  @payload = payload
  @scope = scope
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



52
53
54
# File 'lib/stripe/services/apps/secret_service.rb', line 52

def expand
  @expand
end

#expires_atObject

The Unix timestamp for the expiry time of the secret, after which the secret deletes.



54
55
56
# File 'lib/stripe/services/apps/secret_service.rb', line 54

def expires_at
  @expires_at
end

#nameObject

A name for the secret that’s unique within the scope.



56
57
58
# File 'lib/stripe/services/apps/secret_service.rb', line 56

def name
  @name
end

#payloadObject

The plaintext secret value to be stored.



58
59
60
# File 'lib/stripe/services/apps/secret_service.rb', line 58

def payload
  @payload
end

#scopeObject

Specifies the scoping of the secret. Requests originating from UI extensions can only access account-scoped secrets or secrets scoped to their own user.



60
61
62
# File 'lib/stripe/services/apps/secret_service.rb', line 60

def scope
  @scope
end