Class: Stripe::Apps::SecretService::DeleteWhereParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/apps/secret_service.rb

Defined Under Namespace

Classes: Scope

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, name: nil, scope: nil) ⇒ DeleteWhereParams

Returns a new instance of DeleteWhereParams.



116
117
118
119
120
# File 'lib/stripe/services/apps/secret_service.rb', line 116

def initialize(expand: nil, name: nil, scope: nil)
  @expand = expand
  @name = name
  @scope = scope
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



110
111
112
# File 'lib/stripe/services/apps/secret_service.rb', line 110

def expand
  @expand
end

#nameObject

A name for the secret that’s unique within the scope.



112
113
114
# File 'lib/stripe/services/apps/secret_service.rb', line 112

def name
  @name
end

#scopeObject

Specifies the scoping of the secret. Requests originating from UI extensions can only access account-scoped secrets or secrets scoped to their own user.



114
115
116
# File 'lib/stripe/services/apps/secret_service.rb', line 114

def scope
  @scope
end