Class: Stripe::Apps::SecretService::FindParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/apps/secret_service.rb

Defined Under Namespace

Classes: Scope

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, name: nil, scope: nil) ⇒ FindParams

Returns a new instance of FindParams.



103
104
105
106
107
# File 'lib/stripe/services/apps/secret_service.rb', line 103

def initialize(expand: nil, name: nil, scope: nil)
  @expand = expand
  @name = name
  @scope = scope
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



95
96
97
# File 'lib/stripe/services/apps/secret_service.rb', line 95

def expand
  @expand
end

#nameObject

A name for the secret that’s unique within the scope.



98
99
100
# File 'lib/stripe/services/apps/secret_service.rb', line 98

def name
  @name
end

#scopeObject

Specifies the scoping of the secret. Requests originating from UI extensions can only access account-scoped secrets or secrets scoped to their own user.



101
102
103
# File 'lib/stripe/services/apps/secret_service.rb', line 101

def scope
  @scope
end