Class: Stripe::Balance::RetrieveParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Balance::RetrieveParams
- Defined in:
- lib/stripe/resources/balance.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ RetrieveParams
constructor
A new instance of RetrieveParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ RetrieveParams
Returns a new instance of RetrieveParams.
159 160 161 |
# File 'lib/stripe/resources/balance.rb', line 159 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
157 158 159 |
# File 'lib/stripe/resources/balance.rb', line 157 def @expand end |