Class: Stripe::Balance::RiskReserved::Pending::SourceTypes
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Balance::RiskReserved::Pending::SourceTypes
- Defined in:
- lib/stripe/resources/balance.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bank_account ⇒ Object
readonly
Amount coming from [legacy US ACH payments](docs.stripe.com/ach-deprecated).
-
#card ⇒ Object
readonly
Amount coming from most payment methods, including cards as well as [non-legacy bank debits](docs.stripe.com/payments/bank-debits).
-
#fpx ⇒ Object
readonly
Amount coming from [FPX](docs.stripe.com/payments/fpx), a Malaysian payment method.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bank_account ⇒ Object (readonly)
Amount coming from [legacy US ACH payments](docs.stripe.com/ach-deprecated).
346 347 348 |
# File 'lib/stripe/resources/balance.rb', line 346 def bank_account @bank_account end |
#card ⇒ Object (readonly)
Amount coming from most payment methods, including cards as well as [non-legacy bank debits](docs.stripe.com/payments/bank-debits).
348 349 350 |
# File 'lib/stripe/resources/balance.rb', line 348 def card @card end |
#fpx ⇒ Object (readonly)
Amount coming from [FPX](docs.stripe.com/payments/fpx), a Malaysian payment method.
350 351 352 |
# File 'lib/stripe/resources/balance.rb', line 350 def fpx @fpx end |
Class Method Details
.field_remappings ⇒ Object
356 357 358 |
# File 'lib/stripe/resources/balance.rb', line 356 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
352 353 354 |
# File 'lib/stripe/resources/balance.rb', line 352 def self.inner_class_types @inner_class_types = {} end |