Class: Stripe::BalanceSettings

Inherits:
SingletonAPIResource show all
Includes:
APIOperations::SingletonSave
Defined in:
lib/stripe/resources/balance_settings.rb

Overview

Options for customizing account balances and payout settings for a Stripe platform’s connected accounts.

This API is only available for users enrolled in the public preview for Accounts v2 on Stripe Connect. If you are not in this preview, please use the [Accounts v1 API](docs.stripe.com/api/accounts?api-version=2025-03-31.basil) to manage your connected accounts’ balance settings instead.

Defined Under Namespace

Classes: Payments, UpdateParams

Constant Summary collapse

OBJECT_NAME =
"balance_settings"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods included from APIOperations::SingletonSave

included, #save

Methods inherited from SingletonAPIResource

resource_url, #resource_url, retrieve

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



108
109
110
# File 'lib/stripe/resources/balance_settings.rb', line 108

def object
  @object
end

#paymentsObject (readonly)

Attribute for field payments



110
111
112
# File 'lib/stripe/resources/balance_settings.rb', line 110

def payments
  @payments
end

Class Method Details

.object_nameObject



14
15
16
# File 'lib/stripe/resources/balance_settings.rb', line 14

def self.object_name
  "balance_settings"
end