Class: Stripe::BalanceSettings::Payments::Payouts

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/balance_settings.rb

Defined Under Namespace

Classes: AutomaticTransferRulesByCurrency, Schedule

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#automatic_transfer_rules_by_currencyObject (readonly)

Configures per-currency rules for automatically transferring funds from the payments balance to a FinancialAccount.



50
51
52
# File 'lib/stripe/resources/balance_settings.rb', line 50

def automatic_transfer_rules_by_currency
  @automatic_transfer_rules_by_currency
end

#minimum_balance_by_currencyObject (readonly)

The minimum balance amount to retain per currency after automatic payouts. Only funds that exceed these amounts are paid out. Learn more about the [minimum balances for automatic payouts](/payouts/minimum-balances-for-automatic-payouts).



52
53
54
# File 'lib/stripe/resources/balance_settings.rb', line 52

def minimum_balance_by_currency
  @minimum_balance_by_currency
end

#scheduleObject (readonly)

Details on when funds from charges are available, and when they are paid out to an external account. See our [Setting Bank and Debit Card Payouts](docs.stripe.com/connect/bank-transfers#payout-information) documentation for details.



54
55
56
# File 'lib/stripe/resources/balance_settings.rb', line 54

def schedule
  @schedule
end

#statement_descriptorObject (readonly)

The text that appears on the bank account statement for payouts. If not set, this defaults to the platform’s bank descriptor as set in the Dashboard.



56
57
58
# File 'lib/stripe/resources/balance_settings.rb', line 56

def statement_descriptor
  @statement_descriptor
end

#statusObject (readonly)

Whether the funds in this account can be paid out.



58
59
60
# File 'lib/stripe/resources/balance_settings.rb', line 58

def status
  @status
end

Class Method Details

.field_remappingsObject



67
68
69
# File 'lib/stripe/resources/balance_settings.rb', line 67

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



60
61
62
63
64
65
# File 'lib/stripe/resources/balance_settings.rb', line 60

def self.inner_class_types
  @inner_class_types = {
    automatic_transfer_rules_by_currency: AutomaticTransferRulesByCurrency,
    schedule: Schedule,
  }
end