Class: Stripe::BalanceSettings::Payments::Payouts::AutomaticTransferRulesByCurrency
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::BalanceSettings::Payments::Payouts::AutomaticTransferRulesByCurrency
- Defined in:
- lib/stripe/resources/balance_settings.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#payout_method ⇒ Object
readonly
The ID of the FinancialAccount that funds will be transferred to during automatic transfers.
-
#transfer_up_to_amount ⇒ Object
readonly
The maximum amount in minor units to transfer to the FinancialAccount.
-
#type ⇒ Object
readonly
The type of automatic transfer rule.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#payout_method ⇒ Object (readonly)
The ID of the FinancialAccount that funds will be transferred to during automatic transfers.
18 19 20 |
# File 'lib/stripe/resources/balance_settings.rb', line 18 def payout_method @payout_method end |
#transfer_up_to_amount ⇒ Object (readonly)
The maximum amount in minor units to transfer to the FinancialAccount. Only applicable when ‘type` is `transfer_up_to_amount`.
20 21 22 |
# File 'lib/stripe/resources/balance_settings.rb', line 20 def transfer_up_to_amount @transfer_up_to_amount end |
#type ⇒ Object (readonly)
The type of automatic transfer rule.
22 23 24 |
# File 'lib/stripe/resources/balance_settings.rb', line 22 def type @type end |
Class Method Details
.field_remappings ⇒ Object
28 29 30 |
# File 'lib/stripe/resources/balance_settings.rb', line 28 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
24 25 26 |
# File 'lib/stripe/resources/balance_settings.rb', line 24 def self.inner_class_types @inner_class_types = {} end |