Class: Stripe::BalanceSettings::Payments::Payouts::Schedule

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/balance_settings.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#intervalObject (readonly)

How frequently funds will be paid out. One of manual (payouts only created via API call), daily, weekly, or monthly.



35
36
37
# File 'lib/stripe/resources/balance_settings.rb', line 35

def interval
  @interval
end

#monthly_payout_daysObject (readonly)

The day of the month funds will be paid out. Only shown if interval is monthly. Payouts scheduled between the 29th and 31st of the month are sent on the last day of shorter months.



37
38
39
# File 'lib/stripe/resources/balance_settings.rb', line 37

def monthly_payout_days
  @monthly_payout_days
end

#weekly_payout_daysObject (readonly)

The days of the week when available funds are paid out, specified as an array, for example, [monday, tuesday]. Only shown if interval is weekly.



39
40
41
# File 'lib/stripe/resources/balance_settings.rb', line 39

def weekly_payout_days
  @weekly_payout_days
end

Class Method Details

.field_remappingsObject



45
46
47
# File 'lib/stripe/resources/balance_settings.rb', line 45

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



41
42
43
# File 'lib/stripe/resources/balance_settings.rb', line 41

def self.inner_class_types
  @inner_class_types = {}
end