Class: Stripe::BalanceSettings::Payments::SettlementTiming
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::BalanceSettings::Payments::SettlementTiming
- Defined in:
- lib/stripe/resources/balance_settings.rb
Defined Under Namespace
Classes: StartOfDay
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#delay_days ⇒ Object
readonly
The number of days charge funds are held before becoming available.
-
#delay_days_override ⇒ Object
readonly
The number of days charge funds are held before becoming available.
-
#start_of_day ⇒ Object
readonly
Customized start of day configuration for automatic payouts to group and send payments in local timezones with a customized day starting time.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#delay_days ⇒ Object (readonly)
The number of days charge funds are held before becoming available.
90 91 92 |
# File 'lib/stripe/resources/balance_settings.rb', line 90 def delay_days @delay_days end |
#delay_days_override ⇒ Object (readonly)
The number of days charge funds are held before becoming available. If present, overrides the default, or minimum available, for the account.
92 93 94 |
# File 'lib/stripe/resources/balance_settings.rb', line 92 def delay_days_override @delay_days_override end |
#start_of_day ⇒ Object (readonly)
Customized start of day configuration for automatic payouts to group and send payments in local timezones with a customized day starting time. For details, see our [Customized start of day](/connect/customized-start-of-day) documentation.
94 95 96 |
# File 'lib/stripe/resources/balance_settings.rb', line 94 def start_of_day @start_of_day end |
Class Method Details
.field_remappings ⇒ Object
100 101 102 |
# File 'lib/stripe/resources/balance_settings.rb', line 100 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
96 97 98 |
# File 'lib/stripe/resources/balance_settings.rb', line 96 def self.inner_class_types @inner_class_types = { start_of_day: StartOfDay } end |