Class: Stripe::BalanceSettings::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::BalanceSettings::UpdateParams
- Defined in:
- lib/stripe/resources/balance_settings.rb
Defined Under Namespace
Classes: Payments
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#payments ⇒ Object
Settings that apply to the [Payments Balance](docs.stripe.com/api/balance).
Instance Method Summary collapse
-
#initialize(expand: nil, payments: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, payments: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
134 135 136 137 |
# File 'lib/stripe/resources/balance_settings.rb', line 134 def initialize(expand: nil, payments: nil) @expand = @payments = payments end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
130 131 132 |
# File 'lib/stripe/resources/balance_settings.rb', line 130 def @expand end |
#payments ⇒ Object
Settings that apply to the [Payments Balance](docs.stripe.com/api/balance).
132 133 134 |
# File 'lib/stripe/resources/balance_settings.rb', line 132 def payments @payments end |