Class: Stripe::BalanceSettings::UpdateParams::Payments::Payouts
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::BalanceSettings::UpdateParams::Payments::Payouts
- Defined in:
- lib/stripe/resources/balance_settings.rb
Defined Under Namespace
Classes: Schedule
Instance Attribute Summary collapse
-
#schedule ⇒ Object
Details on when funds from charges are available, and when they are paid out to an external account.
-
#statement_descriptor ⇒ Object
The text that appears on the bank account statement for payouts.
Instance Method Summary collapse
-
#initialize(schedule: nil, statement_descriptor: nil) ⇒ Payouts
constructor
A new instance of Payouts.
Methods inherited from RequestParams
Constructor Details
#initialize(schedule: nil, statement_descriptor: nil) ⇒ Payouts
Returns a new instance of Payouts.
102 103 104 105 |
# File 'lib/stripe/resources/balance_settings.rb', line 102 def initialize(schedule: nil, statement_descriptor: nil) @schedule = schedule @statement_descriptor = statement_descriptor end |
Instance Attribute Details
#schedule ⇒ Object
Details on when funds from charges are available, and when they are paid out to an external account. For details, see our [Setting Bank and Debit Card Payouts](/connect/bank-transfers#payout-information) documentation.
98 99 100 |
# File 'lib/stripe/resources/balance_settings.rb', line 98 def schedule @schedule end |
#statement_descriptor ⇒ Object
The text that appears on the bank account statement for payouts. If not set, this defaults to the platform’s bank descriptor as set in the Dashboard.
100 101 102 |
# File 'lib/stripe/resources/balance_settings.rb', line 100 def statement_descriptor @statement_descriptor end |