Class: Stripe::BalanceSettings::UpdateParams::Payouts::Schedule
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::BalanceSettings::UpdateParams::Payouts::Schedule
- Defined in:
- lib/stripe/resources/balance_settings.rb
Instance Attribute Summary collapse
-
#interval ⇒ Object
How frequently available funds are paid out.
-
#monthly_anchor ⇒ Object
The day of the month when available funds are paid out, specified as a number between 1–31.
-
#weekly_anchor ⇒ Object
The day of the week when available funds are paid out (required and applicable only if ‘interval` is `weekly`.).
Instance Method Summary collapse
-
#initialize(interval: nil, monthly_anchor: nil, weekly_anchor: nil) ⇒ Schedule
constructor
A new instance of Schedule.
Methods inherited from RequestParams
Constructor Details
#initialize(interval: nil, monthly_anchor: nil, weekly_anchor: nil) ⇒ Schedule
Returns a new instance of Schedule.
50 51 52 53 54 |
# File 'lib/stripe/resources/balance_settings.rb', line 50 def initialize(interval: nil, monthly_anchor: nil, weekly_anchor: nil) @interval = interval @monthly_anchor = monthly_anchor @weekly_anchor = weekly_anchor end |
Instance Attribute Details
#interval ⇒ Object
How frequently available funds are paid out. One of: ‘daily`, `manual`, `weekly`, or `monthly`. Default is `daily`.
44 45 46 |
# File 'lib/stripe/resources/balance_settings.rb', line 44 def interval @interval end |
#monthly_anchor ⇒ Object
The day of the month when available funds are paid out, specified as a number between 1–31. Payouts nominally scheduled between the 29th and 31st of the month are instead sent on the last day of a shorter month. Required and applicable only if ‘interval` is `monthly`.
46 47 48 |
# File 'lib/stripe/resources/balance_settings.rb', line 46 def monthly_anchor @monthly_anchor end |
#weekly_anchor ⇒ Object
The day of the week when available funds are paid out (required and applicable only if ‘interval` is `weekly`.)
48 49 50 |
# File 'lib/stripe/resources/balance_settings.rb', line 48 def weekly_anchor @weekly_anchor end |