Class: Stripe::BalanceSettingsService::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::BalanceSettingsService::UpdateParams
- Defined in:
- lib/stripe/services/balance_settings_service.rb
Defined Under Namespace
Classes: Payments
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#payments ⇒ Object
Settings that apply to the [Payments Balance](docs.stripe.com/api/balance).
Instance Method Summary collapse
-
#initialize(expand: nil, payments: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, payments: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
69 70 71 72 |
# File 'lib/stripe/services/balance_settings_service.rb', line 69 def initialize(expand: nil, payments: nil) @expand = @payments = payments end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
65 66 67 |
# File 'lib/stripe/services/balance_settings_service.rb', line 65 def @expand end |
#payments ⇒ Object
Settings that apply to the [Payments Balance](docs.stripe.com/api/balance).
67 68 69 |
# File 'lib/stripe/services/balance_settings_service.rb', line 67 def payments @payments end |