Class: Stripe::BalanceSettingsService::UpdateParams::Payments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::BalanceSettingsService::UpdateParams::Payments
- Defined in:
- lib/stripe/services/balance_settings_service.rb
Defined Under Namespace
Classes: Payouts, SettlementTiming
Instance Attribute Summary collapse
-
#debit_negative_balances ⇒ Object
A Boolean indicating whether Stripe should try to reclaim negative balances from an attached bank account.
-
#payouts ⇒ Object
Settings specific to the account’s payouts.
-
#settlement_timing ⇒ Object
Settings related to the account’s balance settlement timing.
Instance Method Summary collapse
-
#initialize(debit_negative_balances: nil, payouts: nil, settlement_timing: nil) ⇒ Payments
constructor
A new instance of Payments.
Methods inherited from RequestParams
Constructor Details
#initialize(debit_negative_balances: nil, payouts: nil, settlement_timing: nil) ⇒ Payments
Returns a new instance of Payments.
58 59 60 61 62 |
# File 'lib/stripe/services/balance_settings_service.rb', line 58 def initialize(debit_negative_balances: nil, payouts: nil, settlement_timing: nil) @debit_negative_balances = debit_negative_balances @payouts = payouts @settlement_timing = settlement_timing end |
Instance Attribute Details
#debit_negative_balances ⇒ Object
A Boolean indicating whether Stripe should try to reclaim negative balances from an attached bank account. For details, see [Understanding Connect Account Balances](/connect/account-balances).
52 53 54 |
# File 'lib/stripe/services/balance_settings_service.rb', line 52 def debit_negative_balances @debit_negative_balances end |
#payouts ⇒ Object
Settings specific to the account’s payouts.
54 55 56 |
# File 'lib/stripe/services/balance_settings_service.rb', line 54 def payouts @payouts end |
#settlement_timing ⇒ Object
Settings related to the account’s balance settlement timing.
56 57 58 |
# File 'lib/stripe/services/balance_settings_service.rb', line 56 def settlement_timing @settlement_timing end |