Class: Stripe::BalanceSettingsService::UpdateParams::Payments::Payouts
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::BalanceSettingsService::UpdateParams::Payments::Payouts
- Defined in:
- lib/stripe/services/balance_settings_service.rb
Defined Under Namespace
Classes: Schedule
Instance Attribute Summary collapse
-
#schedule ⇒ Object
Details on when funds from charges are available, and when they are paid out to an external account.
-
#statement_descriptor ⇒ Object
The text that appears on the bank account statement for payouts.
Instance Method Summary collapse
-
#initialize(schedule: nil, statement_descriptor: nil) ⇒ Payouts
constructor
A new instance of Payouts.
Methods inherited from RequestParams
Constructor Details
#initialize(schedule: nil, statement_descriptor: nil) ⇒ Payouts
Returns a new instance of Payouts.
37 38 39 40 |
# File 'lib/stripe/services/balance_settings_service.rb', line 37 def initialize(schedule: nil, statement_descriptor: nil) @schedule = schedule @statement_descriptor = statement_descriptor end |
Instance Attribute Details
#schedule ⇒ Object
Details on when funds from charges are available, and when they are paid out to an external account. For details, see our [Setting Bank and Debit Card Payouts](/connect/bank-transfers#payout-information) documentation.
33 34 35 |
# File 'lib/stripe/services/balance_settings_service.rb', line 33 def schedule @schedule end |
#statement_descriptor ⇒ Object
The text that appears on the bank account statement for payouts. If not set, this defaults to the platform’s bank descriptor as set in the Dashboard.
35 36 37 |
# File 'lib/stripe/services/balance_settings_service.rb', line 35 def statement_descriptor @statement_descriptor end |