Class: Stripe::BalanceSettingsService::UpdateParams::Payouts

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/balance_settings_service.rb

Defined Under Namespace

Classes: Schedule

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(schedule: nil, statement_descriptor: nil) ⇒ Payouts

Returns a new instance of Payouts.



36
37
38
39
# File 'lib/stripe/services/balance_settings_service.rb', line 36

def initialize(schedule: nil, statement_descriptor: nil)
  @schedule = schedule
  @statement_descriptor = statement_descriptor
end

Instance Attribute Details

#scheduleObject

Details on when funds from charges are available, and when they are paid out to an external account. For details, see our [Setting Bank and Debit Card Payouts](/connect/bank-transfers#payout-information) documentation.



32
33
34
# File 'lib/stripe/services/balance_settings_service.rb', line 32

def schedule
  @schedule
end

#statement_descriptorObject

The text that appears on the bank account statement for payouts. If not set, this defaults to the platform’s bank descriptor as set in the Dashboard.



34
35
36
# File 'lib/stripe/services/balance_settings_service.rb', line 34

def statement_descriptor
  @statement_descriptor
end