Class: Stripe::BalanceSettingsService::UpdateParams::Payouts::Schedule

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/balance_settings_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(interval: nil, monthly_anchor: nil, weekly_anchor: nil) ⇒ Schedule

Returns a new instance of Schedule.



25
26
27
28
29
# File 'lib/stripe/services/balance_settings_service.rb', line 25

def initialize(interval: nil, monthly_anchor: nil, weekly_anchor: nil)
  @interval = interval
  @monthly_anchor = monthly_anchor
  @weekly_anchor = weekly_anchor
end

Instance Attribute Details

#intervalObject

How frequently available funds are paid out. One of: ‘daily`, `manual`, `weekly`, or `monthly`. Default is `daily`.



19
20
21
# File 'lib/stripe/services/balance_settings_service.rb', line 19

def interval
  @interval
end

#monthly_anchorObject

The day of the month when available funds are paid out, specified as a number between 1–31. Payouts nominally scheduled between the 29th and 31st of the month are instead sent on the last day of a shorter month. Required and applicable only if ‘interval` is `monthly`.



21
22
23
# File 'lib/stripe/services/balance_settings_service.rb', line 21

def monthly_anchor
  @monthly_anchor
end

#weekly_anchorObject

The day of the week when available funds are paid out (required and applicable only if ‘interval` is `weekly`.)



23
24
25
# File 'lib/stripe/services/balance_settings_service.rb', line 23

def weekly_anchor
  @weekly_anchor
end