Class: Stripe::BalanceSettingsUpdateParams::Payments::Payouts
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::BalanceSettingsUpdateParams::Payments::Payouts
- Defined in:
- lib/stripe/params/balance_settings_update_params.rb
Defined Under Namespace
Classes: AutomaticTransferRulesByCurrency, Schedule
Instance Attribute Summary collapse
-
#automatic_transfer_rules_by_currency ⇒ Object
Configures per-currency rules for automatically transferring funds from the payments balance to a FinancialAccount.
-
#minimum_balance_by_currency ⇒ Object
The minimum balance amount to retain per currency after automatic payouts.
-
#schedule ⇒ Object
Details on when funds from charges are available, and when they are paid out to an external account.
-
#statement_descriptor ⇒ Object
The text that appears on the bank account statement for payouts.
Instance Method Summary collapse
-
#initialize(automatic_transfer_rules_by_currency: nil, minimum_balance_by_currency: nil, schedule: nil, statement_descriptor: nil) ⇒ Payouts
constructor
A new instance of Payouts.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(automatic_transfer_rules_by_currency: nil, minimum_balance_by_currency: nil, schedule: nil, statement_descriptor: nil) ⇒ Payouts
Returns a new instance of Payouts.
46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/stripe/params/balance_settings_update_params.rb', line 46 def initialize( automatic_transfer_rules_by_currency: nil, minimum_balance_by_currency: nil, schedule: nil, statement_descriptor: nil ) @automatic_transfer_rules_by_currency = automatic_transfer_rules_by_currency @minimum_balance_by_currency = minimum_balance_by_currency @schedule = schedule @statement_descriptor = statement_descriptor end |
Instance Attribute Details
#automatic_transfer_rules_by_currency ⇒ Object
Configures per-currency rules for automatically transferring funds from the payments balance to a FinancialAccount.
38 39 40 |
# File 'lib/stripe/params/balance_settings_update_params.rb', line 38 def automatic_transfer_rules_by_currency @automatic_transfer_rules_by_currency end |
#minimum_balance_by_currency ⇒ Object
The minimum balance amount to retain per currency after automatic payouts. Only funds that exceed these amounts are paid out. Learn more about the minimum balances for automatic payouts.
40 41 42 |
# File 'lib/stripe/params/balance_settings_update_params.rb', line 40 def minimum_balance_by_currency @minimum_balance_by_currency end |
#schedule ⇒ Object
Details on when funds from charges are available, and when they are paid out to an external account. For details, see our Setting Bank and Debit Card Payouts documentation.
42 43 44 |
# File 'lib/stripe/params/balance_settings_update_params.rb', line 42 def schedule @schedule end |
#statement_descriptor ⇒ Object
The text that appears on the bank account statement for payouts. If not set, this defaults to the platform's bank descriptor as set in the Dashboard.
44 45 46 |
# File 'lib/stripe/params/balance_settings_update_params.rb', line 44 def statement_descriptor @statement_descriptor end |