Class: Stripe::BalanceSettingsUpdateParams::Payments::Payouts::AutomaticTransferRulesByCurrency

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/balance_settings_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(payout_method: nil, transfer_up_to_amount: nil, type: nil) ⇒ AutomaticTransferRulesByCurrency

Returns a new instance of AutomaticTransferRulesByCurrency.



16
17
18
19
20
# File 'lib/stripe/params/balance_settings_update_params.rb', line 16

def initialize(payout_method: nil, transfer_up_to_amount: nil, type: nil)
  @payout_method = payout_method
  @transfer_up_to_amount = transfer_up_to_amount
  @type = type
end

Instance Attribute Details

#payout_methodObject

The ID of the FinancialAccount that funds will be transferred to during automatic transfers.



10
11
12
# File 'lib/stripe/params/balance_settings_update_params.rb', line 10

def payout_method
  @payout_method
end

#transfer_up_to_amountObject

The maximum amount in minor units to transfer to the FinancialAccount. Required and only applicable when ‘type` is `transfer_up_to_amount`.



12
13
14
# File 'lib/stripe/params/balance_settings_update_params.rb', line 12

def transfer_up_to_amount
  @transfer_up_to_amount
end

#typeObject

The type of automatic transfer rule.



14
15
16
# File 'lib/stripe/params/balance_settings_update_params.rb', line 14

def type
  @type
end