Class: Stripe::BalanceSettingsUpdateParams::Payments::SettlementTiming::StartOfDay

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/balance_settings_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(hour: nil, minutes: nil, timezone: nil) ⇒ StartOfDay

Returns a new instance of StartOfDay.



68
69
70
71
72
# File 'lib/stripe/params/balance_settings_update_params.rb', line 68

def initialize(hour: nil, minutes: nil, timezone: nil)
  @hour = hour
  @minutes = minutes
  @timezone = timezone
end

Instance Attribute Details

#hourObject

Hour at which the customized start of day begins according to the given timezone. Must be a [supported customized start of day hour](/connect/customized-start-of-day#available-timezones-and-cutoffs).



62
63
64
# File 'lib/stripe/params/balance_settings_update_params.rb', line 62

def hour
  @hour
end

#minutesObject

Minutes at which the customized start of day begins according to the given timezone. Must be either 0 or 30.



64
65
66
# File 'lib/stripe/params/balance_settings_update_params.rb', line 64

def minutes
  @minutes
end

#timezoneObject

Timezone for the customized start of day. Must be a [supported customized start of day timezone](/connect/customized-start-of-day#available-timezones-and-cutoffs).



66
67
68
# File 'lib/stripe/params/balance_settings_update_params.rb', line 66

def timezone
  @timezone
end