Class: Stripe::BalanceTransaction::FeeDetail
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::BalanceTransaction::FeeDetail
- Defined in:
- lib/stripe/resources/balance_transaction.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
Amount of the fee, in cents.
-
#application ⇒ Object
readonly
ID of the Connect application that earned the fee.
-
#currency ⇒ Object
readonly
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#description ⇒ Object
readonly
An arbitrary string attached to the object.
-
#type ⇒ Object
readonly
Type of the fee, one of: ‘application_fee`, `payment_method_passthrough_fee`, `stripe_fee` or `tax`.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
Amount of the fee, in cents.
19 20 21 |
# File 'lib/stripe/resources/balance_transaction.rb', line 19 def amount @amount end |
#application ⇒ Object (readonly)
ID of the Connect application that earned the fee.
22 23 24 |
# File 'lib/stripe/resources/balance_transaction.rb', line 22 def application @application end |
#currency ⇒ Object (readonly)
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
25 26 27 |
# File 'lib/stripe/resources/balance_transaction.rb', line 25 def currency @currency end |
#description ⇒ Object (readonly)
An arbitrary string attached to the object. Often useful for displaying to users.
28 29 30 |
# File 'lib/stripe/resources/balance_transaction.rb', line 28 def description @description end |
#type ⇒ Object (readonly)
Type of the fee, one of: ‘application_fee`, `payment_method_passthrough_fee`, `stripe_fee` or `tax`.
31 32 33 |
# File 'lib/stripe/resources/balance_transaction.rb', line 31 def type @type end |