Class: Stripe::BalanceTransaction::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/balance_transaction.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(created: nil, currency: nil, ending_before: nil, expand: nil, limit: nil, payout: nil, source: nil, starting_after: nil, type: nil) ⇒ ListParams

Returns a new instance of ListParams.



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/stripe/resources/balance_transaction.rb', line 82

def initialize(
  created: nil,
  currency: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  payout: nil,
  source: nil,
  starting_after: nil,
  type: nil
)
  @created = created
  @currency = currency
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @payout = payout
  @source = source
  @starting_after = starting_after
  @type = type
end

Instance Attribute Details

#createdObject

Only return transactions that were created during the given date interval.



56
57
58
# File 'lib/stripe/resources/balance_transaction.rb', line 56

def created
  @created
end

#currencyObject

Only return transactions in a certain currency. Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



59
60
61
# File 'lib/stripe/resources/balance_transaction.rb', line 59

def currency
  @currency
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



62
63
64
# File 'lib/stripe/resources/balance_transaction.rb', line 62

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



65
66
67
# File 'lib/stripe/resources/balance_transaction.rb', line 65

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



68
69
70
# File 'lib/stripe/resources/balance_transaction.rb', line 68

def limit
  @limit
end

#payoutObject

For automatic Stripe payouts only, only returns transactions that were paid out on the specified payout ID.



71
72
73
# File 'lib/stripe/resources/balance_transaction.rb', line 71

def payout
  @payout
end

#sourceObject

Only returns the original transaction.



74
75
76
# File 'lib/stripe/resources/balance_transaction.rb', line 74

def source
  @source
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



77
78
79
# File 'lib/stripe/resources/balance_transaction.rb', line 77

def starting_after
  @starting_after
end

#typeObject

Only returns transactions of the given type. One of: ‘adjustment`, `advance`, `advance_funding`, `anticipation_repayment`, `application_fee`, `application_fee_refund`, `charge`, `climate_order_purchase`, `climate_order_refund`, `connect_collection_transfer`, `contribution`, `issuing_authorization_hold`, `issuing_authorization_release`, `issuing_dispute`, `issuing_transaction`, `obligation_outbound`, `obligation_reversal_inbound`, `payment`, `payment_failure_refund`, `payment_network_reserve_hold`, `payment_network_reserve_release`, `payment_refund`, `payment_reversal`, `payment_unreconciled`, `payout`, `payout_cancel`, `payout_failure`, `payout_minimum_balance_hold`, `payout_minimum_balance_release`, `refund`, `refund_failure`, `reserve_transaction`, `reserved_funds`, `stripe_fee`, `stripe_fx_fee`, `tax_fee`, `topup`, `topup_reversal`, `transfer`, `transfer_cancel`, `transfer_failure`, or `transfer_refund`.



80
81
82
# File 'lib/stripe/resources/balance_transaction.rb', line 80

def type
  @type
end