Class: Stripe::BalanceTransferCreateParams::DestinationBalance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::BalanceTransferCreateParams::DestinationBalance
- Defined in:
- lib/stripe/params/balance_transfer_create_params.rb
Instance Attribute Summary collapse
-
#type ⇒ Object
Destination balance type to push funds into for the Balance Transfer.
Instance Method Summary collapse
-
#initialize(type: nil) ⇒ DestinationBalance
constructor
A new instance of DestinationBalance.
Methods inherited from RequestParams
Constructor Details
#initialize(type: nil) ⇒ DestinationBalance
Returns a new instance of DestinationBalance.
10 11 12 |
# File 'lib/stripe/params/balance_transfer_create_params.rb', line 10 def initialize(type: nil) @type = type end |
Instance Attribute Details
#type ⇒ Object
Destination balance type to push funds into for the Balance Transfer.
8 9 10 |
# File 'lib/stripe/params/balance_transfer_create_params.rb', line 8 def type @type end |