Class: Stripe::BalanceTransferCreateParams::SourceBalance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::BalanceTransferCreateParams::SourceBalance
- Defined in:
- lib/stripe/params/balance_transfer_create_params.rb
Defined Under Namespace
Classes: AllocatedFunds
Instance Attribute Summary collapse
-
#allocated_funds ⇒ Object
Attribute for param field allocated_funds.
-
#type ⇒ Object
Source balance type to pull funds from for the Balance Transfer.
Instance Method Summary collapse
-
#initialize(allocated_funds: nil, type: nil) ⇒ SourceBalance
constructor
A new instance of SourceBalance.
Methods inherited from RequestParams
Constructor Details
#initialize(allocated_funds: nil, type: nil) ⇒ SourceBalance
Returns a new instance of SourceBalance.
32 33 34 35 |
# File 'lib/stripe/params/balance_transfer_create_params.rb', line 32 def initialize(allocated_funds: nil, type: nil) @allocated_funds = allocated_funds @type = type end |
Instance Attribute Details
#allocated_funds ⇒ Object
Attribute for param field allocated_funds
28 29 30 |
# File 'lib/stripe/params/balance_transfer_create_params.rb', line 28 def allocated_funds @allocated_funds end |
#type ⇒ Object
Source balance type to pull funds from for the Balance Transfer.
30 31 32 |
# File 'lib/stripe/params/balance_transfer_create_params.rb', line 30 def type @type end |