Class: Stripe::BalanceTransferCreateParams::SourceBalance::AllocatedFunds
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::BalanceTransferCreateParams::SourceBalance::AllocatedFunds
- Defined in:
- lib/stripe/params/balance_transfer_create_params.rb
Instance Attribute Summary collapse
-
#charge ⇒ Object
The charge ID that the funds are originally sourced from.
-
#type ⇒ Object
The type of object that the funds are originally sourced from.
Instance Method Summary collapse
-
#initialize(charge: nil, type: nil) ⇒ AllocatedFunds
constructor
A new instance of AllocatedFunds.
Methods inherited from RequestParams
Constructor Details
#initialize(charge: nil, type: nil) ⇒ AllocatedFunds
Returns a new instance of AllocatedFunds.
22 23 24 25 |
# File 'lib/stripe/params/balance_transfer_create_params.rb', line 22 def initialize(charge: nil, type: nil) @charge = charge @type = type end |
Instance Attribute Details
#charge ⇒ Object
The charge ID that the funds are originally sourced from. Required if ‘type` is `charge`.
18 19 20 |
# File 'lib/stripe/params/balance_transfer_create_params.rb', line 18 def charge @charge end |
#type ⇒ Object
The type of object that the funds are originally sourced from. One of ‘charge`.
20 21 22 |
# File 'lib/stripe/params/balance_transfer_create_params.rb', line 20 def type @type end |