Class: Stripe::Billing::Alert::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Billing::Alert::CreateParams
- Defined in:
- lib/stripe/resources/billing/alert.rb
Defined Under Namespace
Classes: CreditBalanceThreshold, UsageThreshold
Instance Attribute Summary collapse
-
#alert_type ⇒ Object
The type of alert to create.
-
#credit_balance_threshold ⇒ Object
The configuration of the credit balance threshold.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#title ⇒ Object
The title of the alert.
-
#usage_threshold ⇒ Object
The configuration of the usage threshold.
Instance Method Summary collapse
-
#initialize(alert_type: nil, credit_balance_threshold: nil, expand: nil, title: nil, usage_threshold: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(alert_type: nil, credit_balance_threshold: nil, expand: nil, title: nil, usage_threshold: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/stripe/resources/billing/alert.rb', line 220 def initialize( alert_type: nil, credit_balance_threshold: nil, expand: nil, title: nil, usage_threshold: nil ) @alert_type = alert_type @credit_balance_threshold = credit_balance_threshold @expand = @title = title @usage_threshold = usage_threshold end |
Instance Attribute Details
#alert_type ⇒ Object
The type of alert to create.
210 211 212 |
# File 'lib/stripe/resources/billing/alert.rb', line 210 def alert_type @alert_type end |
#credit_balance_threshold ⇒ Object
The configuration of the credit balance threshold.
212 213 214 |
# File 'lib/stripe/resources/billing/alert.rb', line 212 def credit_balance_threshold @credit_balance_threshold end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
214 215 216 |
# File 'lib/stripe/resources/billing/alert.rb', line 214 def @expand end |
#title ⇒ Object
The title of the alert.
216 217 218 |
# File 'lib/stripe/resources/billing/alert.rb', line 216 def title @title end |
#usage_threshold ⇒ Object
The configuration of the usage threshold.
218 219 220 |
# File 'lib/stripe/resources/billing/alert.rb', line 218 def usage_threshold @usage_threshold end |