Class: Stripe::Billing::Alert::CreateParams::CreditBalanceThreshold
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Billing::Alert::CreateParams::CreditBalanceThreshold
- Defined in:
- lib/stripe/resources/billing/alert.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#filters ⇒ Object
The filters allows limiting the scope of this credit balance alert.
-
#lte ⇒ Object
Defines at which value the alert will fire.
Instance Method Summary collapse
-
#initialize(filters: nil, lte: nil) ⇒ CreditBalanceThreshold
constructor
A new instance of CreditBalanceThreshold.
Methods inherited from RequestParams
Constructor Details
#initialize(filters: nil, lte: nil) ⇒ CreditBalanceThreshold
Returns a new instance of CreditBalanceThreshold.
239 240 241 242 |
# File 'lib/stripe/resources/billing/alert.rb', line 239 def initialize(filters: nil, lte: nil) @filters = filters @lte = lte end |
Instance Attribute Details
#filters ⇒ Object
The filters allows limiting the scope of this credit balance alert. You must specify a customer filter at this time.
235 236 237 |
# File 'lib/stripe/resources/billing/alert.rb', line 235 def filters @filters end |
#lte ⇒ Object
Defines at which value the alert will fire.
237 238 239 |
# File 'lib/stripe/resources/billing/alert.rb', line 237 def lte @lte end |