Class: Stripe::Billing::Alert::CreateParams::CreditBalanceThreshold::Lte::CustomPricingUnit
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Billing::Alert::CreateParams::CreditBalanceThreshold::Lte::CustomPricingUnit
- Defined in:
- lib/stripe/resources/billing/alert.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
The ID of the custom pricing unit.
-
#value ⇒ Object
A positive decimal string representing the amount of the custom pricing unit threshold.
Instance Method Summary collapse
-
#initialize(id: nil, value: nil) ⇒ CustomPricingUnit
constructor
A new instance of CustomPricingUnit.
Methods inherited from RequestParams
Constructor Details
#initialize(id: nil, value: nil) ⇒ CustomPricingUnit
Returns a new instance of CustomPricingUnit.
204 205 206 207 |
# File 'lib/stripe/resources/billing/alert.rb', line 204 def initialize(id: nil, value: nil) @id = id @value = value end |
Instance Attribute Details
#id ⇒ Object
The ID of the custom pricing unit.
200 201 202 |
# File 'lib/stripe/resources/billing/alert.rb', line 200 def id @id end |
#value ⇒ Object
A positive decimal string representing the amount of the custom pricing unit threshold.
202 203 204 |
# File 'lib/stripe/resources/billing/alert.rb', line 202 def value @value end |