Class: Stripe::Billing::Alert::CreditBalanceThreshold
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Billing::Alert::CreditBalanceThreshold
- Defined in:
- lib/stripe/resources/billing/alert.rb
Defined Under Namespace
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#filters ⇒ Object
readonly
The filters allow limiting the scope of this credit balance alert.
-
#lte ⇒ Object
readonly
Attribute for field lte.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#filters ⇒ Object (readonly)
The filters allow limiting the scope of this credit balance alert. You must specify only a customer filter at this time.
112 113 114 |
# File 'lib/stripe/resources/billing/alert.rb', line 112 def filters @filters end |
#lte ⇒ Object (readonly)
Attribute for field lte
114 115 116 |
# File 'lib/stripe/resources/billing/alert.rb', line 114 def lte @lte end |
Class Method Details
.field_encodings ⇒ Object
124 125 126 127 128 129 130 131 |
# File 'lib/stripe/resources/billing/alert.rb', line 124 def self.field_encodings @field_encodings = { lte: { kind: :object, fields: { custom_pricing_unit: { kind: :object, fields: { value: :decimal_string } } }, }, } end |
.field_remappings ⇒ Object
120 121 122 |
# File 'lib/stripe/resources/billing/alert.rb', line 120 def self.field_remappings @field_remappings = {} end |