Class: Stripe::Billing::Alert::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/billing/alert.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(alert_type: nil, customer: nil, ending_before: nil, expand: nil, limit: nil, meter: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/stripe/resources/billing/alert.rb', line 164

def initialize(
  alert_type: nil,
  customer: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  meter: nil,
  starting_after: nil
)
  @alert_type = alert_type
  @customer = customer
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @meter = meter
  @starting_after = starting_after
end

Instance Attribute Details

#alert_typeObject

Filter results to only include this type of alert.



150
151
152
# File 'lib/stripe/resources/billing/alert.rb', line 150

def alert_type
  @alert_type
end

#customerObject

Filter results to only include alerts for the given customer.



152
153
154
# File 'lib/stripe/resources/billing/alert.rb', line 152

def customer
  @customer
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



154
155
156
# File 'lib/stripe/resources/billing/alert.rb', line 154

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



156
157
158
# File 'lib/stripe/resources/billing/alert.rb', line 156

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



158
159
160
# File 'lib/stripe/resources/billing/alert.rb', line 158

def limit
  @limit
end

#meterObject

Filter results to only include alerts with the given meter.



160
161
162
# File 'lib/stripe/resources/billing/alert.rb', line 160

def meter
  @meter
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



162
163
164
# File 'lib/stripe/resources/billing/alert.rb', line 162

def starting_after
  @starting_after
end