Class: Stripe::Billing::Alert::SpendThreshold
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Billing::Alert::SpendThreshold
- Defined in:
- lib/stripe/resources/billing/alert.rb
Defined Under Namespace
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#aggregation_period ⇒ Object
readonly
Defines the period over which spend is aggregated.
-
#filters ⇒ Object
readonly
Filters to scope the spend calculation.
-
#group_by ⇒ Object
readonly
Defines the granularity of spend aggregation.
-
#gte ⇒ Object
readonly
The threshold value configuration for a spend threshold alert.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#aggregation_period ⇒ Object (readonly)
Defines the period over which spend is aggregated.
232 233 234 |
# File 'lib/stripe/resources/billing/alert.rb', line 232 def aggregation_period @aggregation_period end |
#filters ⇒ Object (readonly)
Filters to scope the spend calculation.
234 235 236 |
# File 'lib/stripe/resources/billing/alert.rb', line 234 def filters @filters end |
#group_by ⇒ Object (readonly)
Defines the granularity of spend aggregation.
236 237 238 |
# File 'lib/stripe/resources/billing/alert.rb', line 236 def group_by @group_by end |
#gte ⇒ Object (readonly)
The threshold value configuration for a spend threshold alert.
238 239 240 |
# File 'lib/stripe/resources/billing/alert.rb', line 238 def gte @gte end |
Class Method Details
.field_encodings ⇒ Object
248 249 250 251 252 253 254 255 |
# File 'lib/stripe/resources/billing/alert.rb', line 248 def self.field_encodings @field_encodings = { gte: { kind: :object, fields: { custom_pricing_unit: { kind: :object, fields: { value: :decimal_string } } }, }, } end |
.field_remappings ⇒ Object
244 245 246 |
# File 'lib/stripe/resources/billing/alert.rb', line 244 def self.field_remappings @field_remappings = {} end |