Class: Stripe::Billing::Alert::UsageThreshold
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Billing::Alert::UsageThreshold
- Defined in:
- lib/stripe/resources/billing/alert.rb
Defined Under Namespace
Classes: Filter
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#filters ⇒ Object
readonly
The filters allow limiting the scope of this usage alert.
-
#gte ⇒ Object
readonly
The value at which this alert will trigger.
-
#meter ⇒ Object
readonly
The [Billing Meter](/api/billing/meter) ID whose usage is monitored.
-
#recurrence ⇒ Object
readonly
Defines how the alert will behave.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#filters ⇒ Object (readonly)
The filters allow limiting the scope of this usage alert. You can only specify up to one filter at this time.
131 132 133 |
# File 'lib/stripe/resources/billing/alert.rb', line 131 def filters @filters end |
#gte ⇒ Object (readonly)
The value at which this alert will trigger.
133 134 135 |
# File 'lib/stripe/resources/billing/alert.rb', line 133 def gte @gte end |
#meter ⇒ Object (readonly)
The [Billing Meter](/api/billing/meter) ID whose usage is monitored.
135 136 137 |
# File 'lib/stripe/resources/billing/alert.rb', line 135 def meter @meter end |
#recurrence ⇒ Object (readonly)
Defines how the alert will behave.
137 138 139 |
# File 'lib/stripe/resources/billing/alert.rb', line 137 def recurrence @recurrence end |
Class Method Details
.field_remappings ⇒ Object
143 144 145 |
# File 'lib/stripe/resources/billing/alert.rb', line 143 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
139 140 141 |
# File 'lib/stripe/resources/billing/alert.rb', line 139 def self.inner_class_types @inner_class_types = { filters: Filter } end |