Class: Stripe::Billing::AlertCreateParams::CreditBalanceThreshold

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/billing/alert_create_params.rb

Defined Under Namespace

Classes: Filter, Lte

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(filters: nil, lte: nil) ⇒ CreditBalanceThreshold

Returns a new instance of CreditBalanceThreshold.



122
123
124
125
# File 'lib/stripe/params/billing/alert_create_params.rb', line 122

def initialize(filters: nil, lte: nil)
  @filters = filters
  @lte = lte
end

Instance Attribute Details

#filtersObject

The filters allows limiting the scope of this credit balance alert. You must specify a customer filter at this time.



118
119
120
# File 'lib/stripe/params/billing/alert_create_params.rb', line 118

def filters
  @filters
end

#lteObject

Defines at which value the alert will fire.



120
121
122
# File 'lib/stripe/params/billing/alert_create_params.rb', line 120

def lte
  @lte
end

Class Method Details

.field_encodingsObject



127
128
129
130
131
132
133
134
# File 'lib/stripe/params/billing/alert_create_params.rb', line 127

def self.field_encodings
  @field_encodings = {
    lte: {
      kind: :object,
      fields: { custom_pricing_unit: { kind: :object, fields: { value: :decimal_string } } },
    },
  }
end