Class: Stripe::Billing::AlertCreateParams::CreditBalanceThreshold::Filter

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/billing/alert_create_params.rb

Defined Under Namespace

Classes: CreditGrants

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(credit_grants: nil, customer: nil, type: nil) ⇒ Filter

Returns a new instance of Filter.



63
64
65
66
67
# File 'lib/stripe/params/billing/alert_create_params.rb', line 63

def initialize(credit_grants: nil, customer: nil, type: nil)
  @credit_grants = credit_grants
  @customer = customer
  @type = type
end

Instance Attribute Details

#credit_grantsObject

The credit grants for which to configure the credit balance alert.



57
58
59
# File 'lib/stripe/params/billing/alert_create_params.rb', line 57

def credit_grants
  @credit_grants
end

#customerObject

Limit the scope to this credit balance alert only to this customer.



59
60
61
# File 'lib/stripe/params/billing/alert_create_params.rb', line 59

def customer
  @customer
end

#typeObject

What type of filter is being applied to this credit balance alert.



61
62
63
# File 'lib/stripe/params/billing/alert_create_params.rb', line 61

def type
  @type
end