Class: Stripe::Billing::AlertCreateParams::CreditBalanceThreshold::Lte::CustomPricingUnit
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Billing::AlertCreateParams::CreditBalanceThreshold::Lte::CustomPricingUnit
- Defined in:
- lib/stripe/params/billing/alert_create_params.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
The ID of the custom pricing unit.
-
#value ⇒ Object
A positive decimal string representing the amount of the custom pricing unit threshold.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id: nil, value: nil) ⇒ CustomPricingUnit
constructor
A new instance of CustomPricingUnit.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(id: nil, value: nil) ⇒ CustomPricingUnit
Returns a new instance of CustomPricingUnit.
77 78 79 80 |
# File 'lib/stripe/params/billing/alert_create_params.rb', line 77 def initialize(id: nil, value: nil) @id = id @value = value end |
Instance Attribute Details
#id ⇒ Object
The ID of the custom pricing unit.
73 74 75 |
# File 'lib/stripe/params/billing/alert_create_params.rb', line 73 def id @id end |
#value ⇒ Object
A positive decimal string representing the amount of the custom pricing unit threshold.
75 76 77 |
# File 'lib/stripe/params/billing/alert_create_params.rb', line 75 def value @value end |
Class Method Details
.field_encodings ⇒ Object
82 83 84 |
# File 'lib/stripe/params/billing/alert_create_params.rb', line 82 def self.field_encodings @field_encodings = { value: :decimal_string } end |