Class: Stripe::Billing::AlertCreateParams::SpendThreshold::Gte::CustomPricingUnit
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Billing::AlertCreateParams::SpendThreshold::Gte::CustomPricingUnit
- Defined in:
- lib/stripe/params/billing/alert_create_params.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
The ID of the custom pricing unit.
-
#value ⇒ Object
A positive decimal string representing the amount of the custom pricing unit threshold.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id: nil, value: nil) ⇒ CustomPricingUnit
constructor
A new instance of CustomPricingUnit.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(id: nil, value: nil) ⇒ CustomPricingUnit
Returns a new instance of CustomPricingUnit.
180 181 182 183 |
# File 'lib/stripe/params/billing/alert_create_params.rb', line 180 def initialize(id: nil, value: nil) @id = id @value = value end |
Instance Attribute Details
#id ⇒ Object
The ID of the custom pricing unit.
176 177 178 |
# File 'lib/stripe/params/billing/alert_create_params.rb', line 176 def id @id end |
#value ⇒ Object
A positive decimal string representing the amount of the custom pricing unit threshold.
178 179 180 |
# File 'lib/stripe/params/billing/alert_create_params.rb', line 178 def value @value end |
Class Method Details
.field_encodings ⇒ Object
185 186 187 |
# File 'lib/stripe/params/billing/alert_create_params.rb', line 185 def self.field_encodings @field_encodings = { value: :decimal_string } end |