Class: Stripe::Billing::AlertCreateParams::UsageThreshold::Filter

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/billing/alert_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(customer: nil, type: nil) ⇒ Filter

Returns a new instance of Filter.



241
242
243
244
# File 'lib/stripe/params/billing/alert_create_params.rb', line 241

def initialize(customer: nil, type: nil)
  @customer = customer
  @type = type
end

Instance Attribute Details

#customerObject

Limit the scope to this usage alert only to this customer.



237
238
239
# File 'lib/stripe/params/billing/alert_create_params.rb', line 237

def customer
  @customer
end

#typeObject

What type of filter is being applied to this usage alert.



239
240
241
# File 'lib/stripe/params/billing/alert_create_params.rb', line 239

def type
  @type
end