Class: Stripe::Billing::AlertNotificationService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::Billing::AlertNotificationService
- Defined in:
- lib/stripe/services/billing/alert_notification_service.rb
Instance Method Summary collapse
-
#list(id, params = {}, opts = {}) ⇒ Object
Lists sent billing alert triggered and recovered notifications for a billing alert.
Methods inherited from StripeService
#initialize, #request, #request_stream
Constructor Details
This class inherits a constructor from Stripe::StripeService
Instance Method Details
#list(id, params = {}, opts = {}) ⇒ Object
Lists sent billing alert triggered and recovered notifications for a billing alert.
8 9 10 11 12 13 14 15 16 |
# File 'lib/stripe/services/billing/alert_notification_service.rb', line 8 def list(id, params = {}, opts = {}) request( method: :get, path: format("/v1/billing/alerts/%<id>s/notifications", { id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |