Class: Stripe::Billing::AlertRecovered

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/billing/alert_recovered.rb

Defined Under Namespace

Classes: AggregationPeriod

Constant Summary collapse

OBJECT_NAME =
"billing.alert_recovered"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#aggregation_periodObject (readonly)

The aggregation period for which this alert recovered



27
28
29
# File 'lib/stripe/resources/billing/alert_recovered.rb', line 27

def aggregation_period
  @aggregation_period
end

#alertObject (readonly)

A billing alert is a resource that notifies you when a certain usage threshold on a meter is crossed. For example, you might create a billing alert to notify you when a certain user made 100 API requests.



29
30
31
# File 'lib/stripe/resources/billing/alert_recovered.rb', line 29

def alert
  @alert
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



31
32
33
# File 'lib/stripe/resources/billing/alert_recovered.rb', line 31

def created
  @created
end

#currencyObject (readonly)

Currency for the threshold value



33
34
35
# File 'lib/stripe/resources/billing/alert_recovered.rb', line 33

def currency
  @currency
end

#custom_pricing_unitObject (readonly)

Custom pricing unit for the threshold value



35
36
37
# File 'lib/stripe/resources/billing/alert_recovered.rb', line 35

def custom_pricing_unit
  @custom_pricing_unit
end

#customerObject (readonly)

ID of customer for which the alert recovered



37
38
39
# File 'lib/stripe/resources/billing/alert_recovered.rb', line 37

def customer
  @customer
end

#external_customer_idObject (readonly)

External customer ID for the customer for which the alert recovered



39
40
41
# File 'lib/stripe/resources/billing/alert_recovered.rb', line 39

def external_customer_id
  @external_customer_id
end

#livemodeObject (readonly)

If the object exists in live mode, the value is true. If the object exists in test mode, the value is false.



41
42
43
# File 'lib/stripe/resources/billing/alert_recovered.rb', line 41

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object's type. Objects of the same type share the same value.



43
44
45
# File 'lib/stripe/resources/billing/alert_recovered.rb', line 43

def object
  @object
end

#valueObject (readonly)

The value at which the alert recovered



45
46
47
# File 'lib/stripe/resources/billing/alert_recovered.rb', line 45

def value
  @value
end

Class Method Details

.field_encodingsObject



55
56
57
# File 'lib/stripe/resources/billing/alert_recovered.rb', line 55

def self.field_encodings
  @field_encodings = { value: :decimal_string }
end

.field_remappingsObject



51
52
53
# File 'lib/stripe/resources/billing/alert_recovered.rb', line 51

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



47
48
49
# File 'lib/stripe/resources/billing/alert_recovered.rb', line 47

def self.inner_class_types
  @inner_class_types = { aggregation_period: AggregationPeriod }
end

.object_nameObject



8
9
10
# File 'lib/stripe/resources/billing/alert_recovered.rb', line 8

def self.object_name
  "billing.alert_recovered"
end