Class: Stripe::Billing::AlertService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Billing::AlertService::CreateParams
- Defined in:
- lib/stripe/services/billing/alert_service.rb
Defined Under Namespace
Classes: CreditBalanceThreshold, UsageThreshold
Instance Attribute Summary collapse
-
#alert_type ⇒ Object
The type of alert to create.
-
#credit_balance_threshold ⇒ Object
The configuration of the credit balance threshold.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#title ⇒ Object
The title of the alert.
-
#usage_threshold ⇒ Object
The configuration of the usage threshold.
Instance Method Summary collapse
-
#initialize(alert_type: nil, credit_balance_threshold: nil, expand: nil, title: nil, usage_threshold: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(alert_type: nil, credit_balance_threshold: nil, expand: nil, title: nil, usage_threshold: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/stripe/services/billing/alert_service.rb', line 143 def initialize( alert_type: nil, credit_balance_threshold: nil, expand: nil, title: nil, usage_threshold: nil ) @alert_type = alert_type @credit_balance_threshold = credit_balance_threshold @expand = @title = title @usage_threshold = usage_threshold end |
Instance Attribute Details
#alert_type ⇒ Object
The type of alert to create.
133 134 135 |
# File 'lib/stripe/services/billing/alert_service.rb', line 133 def alert_type @alert_type end |
#credit_balance_threshold ⇒ Object
The configuration of the credit balance threshold.
135 136 137 |
# File 'lib/stripe/services/billing/alert_service.rb', line 135 def credit_balance_threshold @credit_balance_threshold end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
137 138 139 |
# File 'lib/stripe/services/billing/alert_service.rb', line 137 def @expand end |
#title ⇒ Object
The title of the alert.
139 140 141 |
# File 'lib/stripe/services/billing/alert_service.rb', line 139 def title @title end |
#usage_threshold ⇒ Object
The configuration of the usage threshold.
141 142 143 |
# File 'lib/stripe/services/billing/alert_service.rb', line 141 def usage_threshold @usage_threshold end |