Class: Stripe::Billing::AlertService::CreateParams::CreditBalanceThreshold
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Billing::AlertService::CreateParams::CreditBalanceThreshold
- Defined in:
- lib/stripe/services/billing/alert_service.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#filters ⇒ Object
The filters allows limiting the scope of this credit balance alert.
-
#lte ⇒ Object
Defines at which value the alert will fire.
Instance Method Summary collapse
-
#initialize(filters: nil, lte: nil) ⇒ CreditBalanceThreshold
constructor
A new instance of CreditBalanceThreshold.
Methods inherited from RequestParams
Constructor Details
#initialize(filters: nil, lte: nil) ⇒ CreditBalanceThreshold
Returns a new instance of CreditBalanceThreshold.
98 99 100 101 |
# File 'lib/stripe/services/billing/alert_service.rb', line 98 def initialize(filters: nil, lte: nil) @filters = filters @lte = lte end |
Instance Attribute Details
#filters ⇒ Object
The filters allows limiting the scope of this credit balance alert. You must specify a customer filter at this time.
94 95 96 |
# File 'lib/stripe/services/billing/alert_service.rb', line 94 def filters @filters end |
#lte ⇒ Object
Defines at which value the alert will fire.
96 97 98 |
# File 'lib/stripe/services/billing/alert_service.rb', line 96 def lte @lte end |