Class: Stripe::Billing::AlertService::CreateParams::CreditBalanceThreshold::Lte::CustomPricingUnit
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Billing::AlertService::CreateParams::CreditBalanceThreshold::Lte::CustomPricingUnit
- Defined in:
- lib/stripe/services/billing/alert_service.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
The ID of the custom pricing unit.
-
#value ⇒ Object
A positive decimal string representing the amount of the custom pricing unit threshold.
Instance Method Summary collapse
-
#initialize(id: nil, value: nil) ⇒ CustomPricingUnit
constructor
A new instance of CustomPricingUnit.
Methods inherited from RequestParams
Constructor Details
#initialize(id: nil, value: nil) ⇒ CustomPricingUnit
Returns a new instance of CustomPricingUnit.
63 64 65 66 |
# File 'lib/stripe/services/billing/alert_service.rb', line 63 def initialize(id: nil, value: nil) @id = id @value = value end |
Instance Attribute Details
#id ⇒ Object
The ID of the custom pricing unit.
59 60 61 |
# File 'lib/stripe/services/billing/alert_service.rb', line 59 def id @id end |
#value ⇒ Object
A positive decimal string representing the amount of the custom pricing unit threshold.
61 62 63 |
# File 'lib/stripe/services/billing/alert_service.rb', line 61 def value @value end |