Class: Stripe::Billing::AlertService::DeactivateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Billing::AlertService::DeactivateParams
- Defined in:
- lib/stripe/services/billing/alert_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ DeactivateParams
constructor
A new instance of DeactivateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ DeactivateParams
Returns a new instance of DeactivateParams.
189 190 191 |
# File 'lib/stripe/services/billing/alert_service.rb', line 189 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
187 188 189 |
# File 'lib/stripe/services/billing/alert_service.rb', line 187 def @expand end |