Class: Stripe::Billing::AlertTriggered

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/billing/alert_triggered.rb

Defined Under Namespace

Classes: AggregationPeriod, GroupBy

Constant Summary collapse

OBJECT_NAME =
"billing.alert_triggered"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#aggregation_periodObject (readonly)

The aggregation period for which this alert triggered



44
45
46
# File 'lib/stripe/resources/billing/alert_triggered.rb', line 44

def aggregation_period
  @aggregation_period
end

#alertObject (readonly)

A billing alert is a resource that notifies you when a certain usage threshold on a meter is crossed. For example, you might create a billing alert to notify you when a certain user made 100 API requests.



46
47
48
# File 'lib/stripe/resources/billing/alert_triggered.rb', line 46

def alert
  @alert
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



48
49
50
# File 'lib/stripe/resources/billing/alert_triggered.rb', line 48

def created
  @created
end

#currencyObject (readonly)

Currency for the threshold value



50
51
52
# File 'lib/stripe/resources/billing/alert_triggered.rb', line 50

def currency
  @currency
end

#custom_pricing_unitObject (readonly)

Custom pricing unit for the threshold value



52
53
54
# File 'lib/stripe/resources/billing/alert_triggered.rb', line 52

def custom_pricing_unit
  @custom_pricing_unit
end

#customerObject (readonly)

ID of customer for which the alert triggered



54
55
56
# File 'lib/stripe/resources/billing/alert_triggered.rb', line 54

def customer
  @customer
end

#external_customer_idObject (readonly)

External customer ID for the customer for which the alert triggered



56
57
58
# File 'lib/stripe/resources/billing/alert_triggered.rb', line 56

def external_customer_id
  @external_customer_id
end

#group_byObject (readonly)

Populated specifically for spend alerts to notify merchants which group_by entity has the exceeded spend



58
59
60
# File 'lib/stripe/resources/billing/alert_triggered.rb', line 58

def group_by
  @group_by
end

#livemodeObject (readonly)

If the object exists in live mode, the value is ‘true`. If the object exists in test mode, the value is `false`.



60
61
62
# File 'lib/stripe/resources/billing/alert_triggered.rb', line 60

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



62
63
64
# File 'lib/stripe/resources/billing/alert_triggered.rb', line 62

def object
  @object
end

#triggered_atObject (readonly)

Timestamp at which the threshold was crossed



64
65
66
# File 'lib/stripe/resources/billing/alert_triggered.rb', line 64

def triggered_at
  @triggered_at
end

#valueObject (readonly)

The value triggering the alert



66
67
68
# File 'lib/stripe/resources/billing/alert_triggered.rb', line 66

def value
  @value
end

Class Method Details

.field_encodingsObject



76
77
78
# File 'lib/stripe/resources/billing/alert_triggered.rb', line 76

def self.field_encodings
  @field_encodings = { value: :decimal_string }
end

.field_remappingsObject



72
73
74
# File 'lib/stripe/resources/billing/alert_triggered.rb', line 72

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



68
69
70
# File 'lib/stripe/resources/billing/alert_triggered.rb', line 68

def self.inner_class_types
  @inner_class_types = { aggregation_period: AggregationPeriod, group_by: GroupBy }
end

.object_nameObject



8
9
10
# File 'lib/stripe/resources/billing/alert_triggered.rb', line 8

def self.object_name
  "billing.alert_triggered"
end