Class: Stripe::Billing::Analytics::MeterUsage

Inherits:
SingletonAPIResource show all
Defined in:
lib/stripe/resources/billing/analytics/meter_usage.rb

Overview

A billing meter usage event represents an aggregated view of a customer’s billing meter events within a specified timeframe.

Constant Summary collapse

OBJECT_NAME =
"billing.analytics.meter_usage"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from SingletonAPIResource

resource_url, #resource_url, retrieve

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#livemodeObject (readonly)

If the object exists in live mode, the value is ‘true`. If the object exists in test mode, the value is `false`.



15
16
17
# File 'lib/stripe/resources/billing/analytics/meter_usage.rb', line 15

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



17
18
19
# File 'lib/stripe/resources/billing/analytics/meter_usage.rb', line 17

def object
  @object
end

#refreshed_atObject (readonly)

The timestamp to indicate data freshness, measured in seconds since the Unix epoch.



19
20
21
# File 'lib/stripe/resources/billing/analytics/meter_usage.rb', line 19

def refreshed_at
  @refreshed_at
end

#rowsObject (readonly)

Attribute for field rows



21
22
23
# File 'lib/stripe/resources/billing/analytics/meter_usage.rb', line 21

def rows
  @rows
end

Class Method Details

.field_remappingsObject



27
28
29
# File 'lib/stripe/resources/billing/analytics/meter_usage.rb', line 27

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



23
24
25
# File 'lib/stripe/resources/billing/analytics/meter_usage.rb', line 23

def self.inner_class_types
  @inner_class_types = {}
end

.object_nameObject



10
11
12
# File 'lib/stripe/resources/billing/analytics/meter_usage.rb', line 10

def self.object_name
  "billing.analytics.meter_usage"
end