Class: Stripe::Billing::CreditBalanceSummary::Balance::BalanceUpdateDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Billing::CreditBalanceSummary::Balance::BalanceUpdateDetails
- Defined in:
- lib/stripe/resources/billing/credit_balance_summary.rb
Defined Under Namespace
Classes: LatestMeterEvent
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#latest_meter_event ⇒ Object
readonly
The details of the most recent meter event included in the balance update.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#latest_meter_event ⇒ Object (readonly)
The details of the most recent meter event included in the balance update.
100 101 102 |
# File 'lib/stripe/resources/billing/credit_balance_summary.rb', line 100 def latest_meter_event @latest_meter_event end |
Class Method Details
.field_remappings ⇒ Object
106 107 108 |
# File 'lib/stripe/resources/billing/credit_balance_summary.rb', line 106 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
102 103 104 |
# File 'lib/stripe/resources/billing/credit_balance_summary.rb', line 102 def self.inner_class_types @inner_class_types = { latest_meter_event: LatestMeterEvent } end |