Class: Stripe::Billing::CreditBalanceSummary::RetrieveParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/billing/credit_balance_summary.rb

Defined Under Namespace

Classes: Filter

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(customer: nil, expand: nil, filter: nil) ⇒ RetrieveParams

Returns a new instance of RetrieveParams.



86
87
88
89
90
# File 'lib/stripe/resources/billing/credit_balance_summary.rb', line 86

def initialize(customer: nil, expand: nil, filter: nil)
  @customer = customer
  @expand = expand
  @filter = filter
end

Instance Attribute Details

#customerObject

The customer for which to fetch credit balance summary.



80
81
82
# File 'lib/stripe/resources/billing/credit_balance_summary.rb', line 80

def customer
  @customer
end

#expandObject

Specifies which fields in the response should be expanded.



82
83
84
# File 'lib/stripe/resources/billing/credit_balance_summary.rb', line 82

def expand
  @expand
end

#filterObject

The filter criteria for the credit balance summary.



84
85
86
# File 'lib/stripe/resources/billing/credit_balance_summary.rb', line 84

def filter
  @filter
end