Class: Stripe::Billing::CreditBalanceSummaryRetrieveParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Billing::CreditBalanceSummaryRetrieveParams
- Defined in:
- lib/stripe/params/billing/credit_balance_summary_retrieve_params.rb
Defined Under Namespace
Classes: Filter
Instance Attribute Summary collapse
-
#customer ⇒ Object
The customer for which to fetch credit balance summary.
-
#customer_account ⇒ Object
The account for which to fetch credit balance summary.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#filter ⇒ Object
The filter criteria for the credit balance summary.
Instance Method Summary collapse
-
#initialize(customer: nil, customer_account: nil, expand: nil, filter: nil) ⇒ CreditBalanceSummaryRetrieveParams
constructor
A new instance of CreditBalanceSummaryRetrieveParams.
Methods inherited from RequestParams
Constructor Details
#initialize(customer: nil, customer_account: nil, expand: nil, filter: nil) ⇒ CreditBalanceSummaryRetrieveParams
Returns a new instance of CreditBalanceSummaryRetrieveParams.
61 62 63 64 65 66 |
# File 'lib/stripe/params/billing/credit_balance_summary_retrieve_params.rb', line 61 def initialize(customer: nil, customer_account: nil, expand: nil, filter: nil) @customer = customer @customer_account = customer_account @expand = @filter = filter end |
Instance Attribute Details
#customer ⇒ Object
The customer for which to fetch credit balance summary.
53 54 55 |
# File 'lib/stripe/params/billing/credit_balance_summary_retrieve_params.rb', line 53 def customer @customer end |
#customer_account ⇒ Object
The account for which to fetch credit balance summary.
55 56 57 |
# File 'lib/stripe/params/billing/credit_balance_summary_retrieve_params.rb', line 55 def customer_account @customer_account end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
57 58 59 |
# File 'lib/stripe/params/billing/credit_balance_summary_retrieve_params.rb', line 57 def @expand end |
#filter ⇒ Object
The filter criteria for the credit balance summary.
59 60 61 |
# File 'lib/stripe/params/billing/credit_balance_summary_retrieve_params.rb', line 59 def filter @filter end |