Class: Stripe::Billing::CreditBalanceSummaryRetrieveParams::Filter

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/billing/credit_balance_summary_retrieve_params.rb

Defined Under Namespace

Classes: ApplicabilityScope

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(applicability_scope: nil, credit_grant: nil, type: nil) ⇒ Filter

Returns a new instance of Filter.



58
59
60
61
62
# File 'lib/stripe/params/billing/credit_balance_summary_retrieve_params.rb', line 58

def initialize(applicability_scope: nil, credit_grant: nil, type: nil)
  @applicability_scope = applicability_scope
  @credit_grant = credit_grant
  @type = type
end

Instance Attribute Details

#applicability_scopeObject

The billing credit applicability scope for which to fetch credit balance summary.



52
53
54
# File 'lib/stripe/params/billing/credit_balance_summary_retrieve_params.rb', line 52

def applicability_scope
  @applicability_scope
end

#credit_grantObject

The credit grant for which to fetch credit balance summary.



54
55
56
# File 'lib/stripe/params/billing/credit_balance_summary_retrieve_params.rb', line 54

def credit_grant
  @credit_grant
end

#typeObject

Specify the type of this filter.



56
57
58
# File 'lib/stripe/params/billing/credit_balance_summary_retrieve_params.rb', line 56

def type
  @type
end