Class: Stripe::Billing::CreditBalanceSummaryRetrieveParams::Filter::ApplicabilityScope
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Billing::CreditBalanceSummaryRetrieveParams::Filter::ApplicabilityScope
- Defined in:
- lib/stripe/params/billing/credit_balance_summary_retrieve_params.rb
Defined Under Namespace
Classes: BillableItem, Price, RateCard
Instance Attribute Summary collapse
-
#billable_items ⇒ Object
A list of billable items that the credit grant can apply to.
-
#price_type ⇒ Object
The price type that credit grants can apply to.
-
#prices ⇒ Object
A list of prices that the credit grant can apply to.
-
#rate_cards ⇒ Object
A list of rate cards that the credit grant can apply to.
Instance Method Summary collapse
-
#initialize(billable_items: nil, price_type: nil, prices: nil, rate_cards: nil) ⇒ ApplicabilityScope
constructor
A new instance of ApplicabilityScope.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(billable_items: nil, price_type: nil, prices: nil, rate_cards: nil) ⇒ ApplicabilityScope
Returns a new instance of ApplicabilityScope.
44 45 46 47 48 49 |
# File 'lib/stripe/params/billing/credit_balance_summary_retrieve_params.rb', line 44 def initialize(billable_items: nil, price_type: nil, prices: nil, rate_cards: nil) @billable_items = billable_items @price_type = price_type @prices = prices @rate_cards = rate_cards end |
Instance Attribute Details
#billable_items ⇒ Object
A list of billable items that the credit grant can apply to. We currently only support metered billable items. Cannot be used in combination with price_type or prices.
36 37 38 |
# File 'lib/stripe/params/billing/credit_balance_summary_retrieve_params.rb', line 36 def billable_items @billable_items end |
#price_type ⇒ Object
The price type that credit grants can apply to. We currently only support the metered price type. Cannot be used in combination with prices.
38 39 40 |
# File 'lib/stripe/params/billing/credit_balance_summary_retrieve_params.rb', line 38 def price_type @price_type end |
#prices ⇒ Object
A list of prices that the credit grant can apply to. We currently only support the metered prices. Cannot be used in combination with price_type. Limit 20 prices.
40 41 42 |
# File 'lib/stripe/params/billing/credit_balance_summary_retrieve_params.rb', line 40 def prices @prices end |
#rate_cards ⇒ Object
A list of rate cards that the credit grant can apply to. The credit grant applies to any metered item billed under one of these rate cards. Cannot be used in combination with price_type, prices, or billable_items.
42 43 44 |
# File 'lib/stripe/params/billing/credit_balance_summary_retrieve_params.rb', line 42 def rate_cards @rate_cards end |