Class: Stripe::Billing::CreditBalanceTransaction::Debit
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Billing::CreditBalanceTransaction::Debit
- Defined in:
- lib/stripe/resources/billing/credit_balance_transaction.rb
Defined Under Namespace
Classes: Amount, CreditsApplied
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
Attribute for field amount.
-
#credits_applied ⇒ Object
readonly
Details of how the billing credits were applied to an invoice.
-
#type ⇒ Object
readonly
The type of debit transaction.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
Attribute for field amount
234 235 236 |
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 234 def amount @amount end |
#credits_applied ⇒ Object (readonly)
Details of how the billing credits were applied to an invoice. Only present if ‘type` is `credits_applied`.
236 237 238 |
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 236 def credits_applied @credits_applied end |
#type ⇒ Object (readonly)
The type of debit transaction.
238 239 240 |
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 238 def type @type end |
Class Method Details
.field_encodings ⇒ Object
248 249 250 251 252 253 254 255 |
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 248 def self.field_encodings @field_encodings = { amount: { kind: :object, fields: { custom_pricing_unit: { kind: :object, fields: { value: :decimal_string } } }, }, } end |
.field_remappings ⇒ Object
244 245 246 |
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 244 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
240 241 242 |
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 240 def self.inner_class_types @inner_class_types = { amount: Amount, credits_applied: CreditsApplied } end |