Class: Stripe::Billing::CreditBalanceTransaction::ListParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/billing/credit_balance_transaction.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(credit_grant: nil, customer: nil, customer_account: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 236

def initialize(
  credit_grant: nil,
  customer: nil,
  customer_account: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  starting_after: nil
)
  @credit_grant = credit_grant
  @customer = customer
  @customer_account = 
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
end

Instance Attribute Details

#credit_grantObject

The credit grant for which to fetch credit balance transactions.



222
223
224
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 222

def credit_grant
  @credit_grant
end

#customerObject

The customer for which to fetch credit balance transactions.



224
225
226
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 224

def customer
  @customer
end

#customer_accountObject

The account for which to fetch credit balance transactions.



226
227
228
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 226

def 
  @customer_account
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



228
229
230
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 228

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



230
231
232
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 230

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



232
233
234
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 232

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



234
235
236
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 234

def starting_after
  @starting_after
end