Class: Stripe::Billing::CreditGrant::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/billing/credit_grant.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(customer: nil, customer_account: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'lib/stripe/resources/billing/credit_grant.rb', line 157

def initialize(
  customer: nil,
  customer_account: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  starting_after: nil
)
  @customer = customer
  @customer_account = 
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
end

Instance Attribute Details

#customerObject

Only return credit grants for this customer.



145
146
147
# File 'lib/stripe/resources/billing/credit_grant.rb', line 145

def customer
  @customer
end

#customer_accountObject

Only return credit grants for this account.



147
148
149
# File 'lib/stripe/resources/billing/credit_grant.rb', line 147

def 
  @customer_account
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



149
150
151
# File 'lib/stripe/resources/billing/credit_grant.rb', line 149

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



151
152
153
# File 'lib/stripe/resources/billing/credit_grant.rb', line 151

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



153
154
155
# File 'lib/stripe/resources/billing/credit_grant.rb', line 153

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



155
156
157
# File 'lib/stripe/resources/billing/credit_grant.rb', line 155

def starting_after
  @starting_after
end