Class: Stripe::Billing::CreditGrant::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Billing::CreditGrant::UpdateParams
- Defined in:
- lib/stripe/resources/billing/credit_grant.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#expires_at ⇒ Object
The time when the billing credits created by this credit grant expire.
-
#metadata ⇒ Object
Set of key-value pairs you can attach to an object.
Instance Method Summary collapse
-
#initialize(expand: nil, expires_at: nil, metadata: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, expires_at: nil, metadata: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
187 188 189 190 191 |
# File 'lib/stripe/resources/billing/credit_grant.rb', line 187 def initialize(expand: nil, expires_at: nil, metadata: nil) @expand = @expires_at = expires_at @metadata = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
181 182 183 |
# File 'lib/stripe/resources/billing/credit_grant.rb', line 181 def @expand end |
#expires_at ⇒ Object
The time when the billing credits created by this credit grant expire. If set to empty, the billing credits never expire.
183 184 185 |
# File 'lib/stripe/resources/billing/credit_grant.rb', line 183 def expires_at @expires_at end |
#metadata ⇒ Object
Set of key-value pairs you can attach to an object. You can use this to store additional information about the object (for example, cost basis) in a structured format.
185 186 187 |
# File 'lib/stripe/resources/billing/credit_grant.rb', line 185 def @metadata end |