Class: Stripe::Billing::CreditGrantCreateParams::Amount::CustomPricingUnit
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Billing::CreditGrantCreateParams::Amount::CustomPricingUnit
- Defined in:
- lib/stripe/params/billing/credit_grant_create_params.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
The ID of the custom pricing unit.
-
#value ⇒ Object
A positive integer representing the amount of the credit grant.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id: nil, value: nil) ⇒ CustomPricingUnit
constructor
A new instance of CustomPricingUnit.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(id: nil, value: nil) ⇒ CustomPricingUnit
Returns a new instance of CustomPricingUnit.
14 15 16 17 |
# File 'lib/stripe/params/billing/credit_grant_create_params.rb', line 14 def initialize(id: nil, value: nil) @id = id @value = value end |
Instance Attribute Details
#id ⇒ Object
The ID of the custom pricing unit.
10 11 12 |
# File 'lib/stripe/params/billing/credit_grant_create_params.rb', line 10 def id @id end |
#value ⇒ Object
A positive integer representing the amount of the credit grant.
12 13 14 |
# File 'lib/stripe/params/billing/credit_grant_create_params.rb', line 12 def value @value end |
Class Method Details
.field_encodings ⇒ Object
19 20 21 |
# File 'lib/stripe/params/billing/credit_grant_create_params.rb', line 19 def self.field_encodings @field_encodings = { value: :decimal_string } end |