Class: Stripe::Billing::CreditGrantCreateParams::Amount::Monetary
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Billing::CreditGrantCreateParams::Amount::Monetary
- Defined in:
- lib/stripe/params/billing/credit_grant_create_params.rb
Instance Attribute Summary collapse
-
#currency ⇒ Object
Three-letter [ISO code for the currency](stripe.com/docs/currencies) of the ‘value` parameter.
-
#value ⇒ Object
A positive integer representing the amount of the credit grant.
Instance Method Summary collapse
-
#initialize(currency: nil, value: nil) ⇒ Monetary
constructor
A new instance of Monetary.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(currency: nil, value: nil) ⇒ Monetary
Returns a new instance of Monetary.
30 31 32 33 |
# File 'lib/stripe/params/billing/credit_grant_create_params.rb', line 30 def initialize(currency: nil, value: nil) @currency = currency @value = value end |
Instance Attribute Details
#currency ⇒ Object
Three-letter [ISO code for the currency](stripe.com/docs/currencies) of the ‘value` parameter.
26 27 28 |
# File 'lib/stripe/params/billing/credit_grant_create_params.rb', line 26 def currency @currency end |
#value ⇒ Object
A positive integer representing the amount of the credit grant.
28 29 30 |
# File 'lib/stripe/params/billing/credit_grant_create_params.rb', line 28 def value @value end |