Class: Stripe::Billing::CreditGrantCreateParams::ApplicabilityConfig::Scope

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/billing/credit_grant_create_params.rb

Defined Under Namespace

Classes: BillableItem, Price, RateCard

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(billable_items: nil, price_type: nil, prices: nil, rate_cards: nil) ⇒ Scope

Returns a new instance of Scope.



92
93
94
95
96
97
# File 'lib/stripe/params/billing/credit_grant_create_params.rb', line 92

def initialize(billable_items: nil, price_type: nil, prices: nil, rate_cards: nil)
  @billable_items = billable_items
  @price_type = price_type
  @prices = prices
  @rate_cards = rate_cards
end

Instance Attribute Details

#billable_itemsObject

A list of billable items that the credit grant can apply to. We currently only support metered billable items. Cannot be used in combination with price_type or prices.



84
85
86
# File 'lib/stripe/params/billing/credit_grant_create_params.rb', line 84

def billable_items
  @billable_items
end

#price_typeObject

The price type that credit grants can apply to. We currently only support the metered price type. Cannot be used in combination with prices.



86
87
88
# File 'lib/stripe/params/billing/credit_grant_create_params.rb', line 86

def price_type
  @price_type
end

#pricesObject

A list of prices that the credit grant can apply to. We currently only support the metered prices. Cannot be used in combination with price_type. Limit 20 prices.



88
89
90
# File 'lib/stripe/params/billing/credit_grant_create_params.rb', line 88

def prices
  @prices
end

#rate_cardsObject

A list of rate cards that the credit grant can apply to. The credit grant applies to any metered item billed under one of these rate cards. Cannot be used in combination with price_type, prices, or billable_items.



90
91
92
# File 'lib/stripe/params/billing/credit_grant_create_params.rb', line 90

def rate_cards
  @rate_cards
end