Class: Stripe::Billing::CreditGrantService::CreateParams::Amount::Monetary
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Billing::CreditGrantService::CreateParams::Amount::Monetary
- Defined in:
- lib/stripe/services/billing/credit_grant_service.rb
Instance Attribute Summary collapse
-
#currency ⇒ Object
Three-letter [ISO code for the currency](stripe.com/docs/currencies) of the ‘value` parameter.
-
#value ⇒ Object
A positive integer representing the amount of the credit grant.
Instance Method Summary collapse
-
#initialize(currency: nil, value: nil) ⇒ Monetary
constructor
A new instance of Monetary.
Methods inherited from RequestParams
Constructor Details
#initialize(currency: nil, value: nil) ⇒ Monetary
Returns a new instance of Monetary.
58 59 60 61 |
# File 'lib/stripe/services/billing/credit_grant_service.rb', line 58 def initialize(currency: nil, value: nil) @currency = currency @value = value end |
Instance Attribute Details
#currency ⇒ Object
Three-letter [ISO code for the currency](stripe.com/docs/currencies) of the ‘value` parameter.
54 55 56 |
# File 'lib/stripe/services/billing/credit_grant_service.rb', line 54 def currency @currency end |
#value ⇒ Object
A positive integer representing the amount of the credit grant.
56 57 58 |
# File 'lib/stripe/services/billing/credit_grant_service.rb', line 56 def value @value end |