Class: Stripe::Billing::CreditGrantService::CreateParams::ApplicabilityConfig::Scope
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Billing::CreditGrantService::CreateParams::ApplicabilityConfig::Scope
- Defined in:
- lib/stripe/services/billing/credit_grant_service.rb
Instance Attribute Summary collapse
-
#price_type ⇒ Object
The price type that credit grants can apply to.
Instance Method Summary collapse
-
#initialize(price_type: nil) ⇒ Scope
constructor
A new instance of Scope.
Methods inherited from RequestParams
Constructor Details
#initialize(price_type: nil) ⇒ Scope
Returns a new instance of Scope.
63 64 65 |
# File 'lib/stripe/services/billing/credit_grant_service.rb', line 63 def initialize(price_type: nil) @price_type = price_type end |
Instance Attribute Details
#price_type ⇒ Object
The price type that credit grants can apply to. We currently only support the ‘metered` price type.
61 62 63 |
# File 'lib/stripe/services/billing/credit_grant_service.rb', line 61 def price_type @price_type end |