Class: Stripe::Billing::CreditGrantService::ExpireParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Billing::CreditGrantService::ExpireParams
- Defined in:
- lib/stripe/services/billing/credit_grant_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ ExpireParams
constructor
A new instance of ExpireParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ ExpireParams
Returns a new instance of ExpireParams.
144 145 146 |
# File 'lib/stripe/services/billing/credit_grant_service.rb', line 144 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
142 143 144 |
# File 'lib/stripe/services/billing/credit_grant_service.rb', line 142 def @expand end |