Class: Stripe::Billing::FeedbackOptionUpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Billing::FeedbackOptionUpdateParams
- Defined in:
- lib/stripe/params/billing/feedback_option_update_params.rb
Instance Attribute Summary collapse
-
#description ⇒ Object
Attribute for param field description.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(description: nil, expand: nil) ⇒ FeedbackOptionUpdateParams
constructor
A new instance of FeedbackOptionUpdateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(description: nil, expand: nil) ⇒ FeedbackOptionUpdateParams
Returns a new instance of FeedbackOptionUpdateParams.
12 13 14 15 |
# File 'lib/stripe/params/billing/feedback_option_update_params.rb', line 12 def initialize(description: nil, expand: nil) @description = description @expand = end |
Instance Attribute Details
#description ⇒ Object
Attribute for param field description
8 9 10 |
# File 'lib/stripe/params/billing/feedback_option_update_params.rb', line 8 def description @description end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
10 11 12 |
# File 'lib/stripe/params/billing/feedback_option_update_params.rb', line 10 def @expand end |