Class: Stripe::Billing::FeedbackOptions

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/billing/feedback_options.rb

Overview

A resource for the feedback options model (for custom cancellation reasons)

Defined Under Namespace

Classes: StatusTransitions

Constant Summary collapse

OBJECT_NAME =
"billing.feedback_options"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#descriptionObject (readonly)

An arbitrary string attached to the object. Often useful for displaying to users.



26
27
28
# File 'lib/stripe/resources/billing/feedback_options.rb', line 26

def description
  @description
end

#idObject (readonly)

Unique identifier for the object.



28
29
30
# File 'lib/stripe/resources/billing/feedback_options.rb', line 28

def id
  @id
end

#livemodeObject (readonly)

If the object exists in live mode, the value is true. If the object exists in test mode, the value is false.



30
31
32
# File 'lib/stripe/resources/billing/feedback_options.rb', line 30

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object's type. Objects of the same type share the same value.



32
33
34
# File 'lib/stripe/resources/billing/feedback_options.rb', line 32

def object
  @object
end

#statusObject (readonly)

The feedback option's status.



34
35
36
# File 'lib/stripe/resources/billing/feedback_options.rb', line 34

def status
  @status
end

#status_transitionsObject (readonly)

Attribute for field status_transitions



36
37
38
# File 'lib/stripe/resources/billing/feedback_options.rb', line 36

def status_transitions
  @status_transitions
end

Class Method Details

.field_remappingsObject



42
43
44
# File 'lib/stripe/resources/billing/feedback_options.rb', line 42

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



38
39
40
# File 'lib/stripe/resources/billing/feedback_options.rb', line 38

def self.inner_class_types
  @inner_class_types = { status_transitions: StatusTransitions }
end

.object_nameObject



9
10
11
# File 'lib/stripe/resources/billing/feedback_options.rb', line 9

def self.object_name
  "billing.feedback_options"
end