Class: Stripe::Billing::Meter::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Billing::Meter::CreateParams
- Defined in:
- lib/stripe/resources/billing/meter.rb
Defined Under Namespace
Classes: CustomerMapping, DefaultAggregation, ValueSettings
Instance Attribute Summary collapse
-
#customer_mapping ⇒ Object
Fields that specify how to map a meter event to a customer.
-
#default_aggregation ⇒ Object
The default settings to aggregate a meter’s events with.
-
#display_name ⇒ Object
The meter’s name.
-
#event_name ⇒ Object
The name of the meter event to record usage for.
-
#event_time_window ⇒ Object
The time window which meter events have been pre-aggregated for, if any.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#value_settings ⇒ Object
Fields that specify how to calculate a meter event’s value.
Instance Method Summary collapse
-
#initialize(customer_mapping: nil, default_aggregation: nil, display_name: nil, event_name: nil, event_time_window: nil, expand: nil, value_settings: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(customer_mapping: nil, default_aggregation: nil, display_name: nil, event_name: nil, event_time_window: nil, expand: nil, value_settings: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/stripe/resources/billing/meter.rb', line 150 def initialize( customer_mapping: nil, default_aggregation: nil, display_name: nil, event_name: nil, event_time_window: nil, expand: nil, value_settings: nil ) @customer_mapping = customer_mapping @default_aggregation = default_aggregation @display_name = display_name @event_name = event_name @event_time_window = event_time_window @expand = @value_settings = value_settings end |
Instance Attribute Details
#customer_mapping ⇒ Object
Fields that specify how to map a meter event to a customer.
136 137 138 |
# File 'lib/stripe/resources/billing/meter.rb', line 136 def customer_mapping @customer_mapping end |
#default_aggregation ⇒ Object
The default settings to aggregate a meter’s events with.
138 139 140 |
# File 'lib/stripe/resources/billing/meter.rb', line 138 def default_aggregation @default_aggregation end |
#display_name ⇒ Object
The meter’s name. Not visible to the customer.
140 141 142 |
# File 'lib/stripe/resources/billing/meter.rb', line 140 def display_name @display_name end |
#event_name ⇒ Object
The name of the meter event to record usage for. Corresponds with the ‘event_name` field on meter events.
142 143 144 |
# File 'lib/stripe/resources/billing/meter.rb', line 142 def event_name @event_name end |
#event_time_window ⇒ Object
The time window which meter events have been pre-aggregated for, if any.
144 145 146 |
# File 'lib/stripe/resources/billing/meter.rb', line 144 def event_time_window @event_time_window end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
146 147 148 |
# File 'lib/stripe/resources/billing/meter.rb', line 146 def @expand end |
#value_settings ⇒ Object
Fields that specify how to calculate a meter event’s value.
148 149 150 |
# File 'lib/stripe/resources/billing/meter.rb', line 148 def value_settings @value_settings end |