Class: Stripe::Billing::Meter::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Billing::Meter::UpdateParams
- Defined in:
- lib/stripe/resources/billing/meter.rb
Instance Attribute Summary collapse
-
#display_name ⇒ Object
The meter’s name.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(display_name: nil, expand: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(display_name: nil, expand: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
175 176 177 178 |
# File 'lib/stripe/resources/billing/meter.rb', line 175 def initialize(display_name: nil, expand: nil) @display_name = display_name @expand = end |
Instance Attribute Details
#display_name ⇒ Object
The meter’s name. Not visible to the customer.
171 172 173 |
# File 'lib/stripe/resources/billing/meter.rb', line 171 def display_name @display_name end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
173 174 175 |
# File 'lib/stripe/resources/billing/meter.rb', line 173 def @expand end |