Class: Stripe::Billing::MeterEvent
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Billing::MeterEvent
- Extended by:
- APIOperations::Create
- Defined in:
- lib/stripe/resources/billing/meter_event.rb
Overview
Meter events represent actions that customers take in your system. You can use meter events to bill a customer based on their usage. Meter events are associated with billing meters, which define both the contents of the event’s payload and how to aggregate those events.
Defined Under Namespace
Classes: CreateParams
Constant Summary collapse
- OBJECT_NAME =
"billing.meter_event"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#event_name ⇒ Object
readonly
The name of the meter event.
-
#identifier ⇒ Object
readonly
A unique identifier for the event.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#payload ⇒ Object
readonly
The payload of the event.
-
#timestamp ⇒ Object
readonly
The timestamp passed in when creating the event.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.create(params = {}, opts = {}) ⇒ Object
Creates a billing meter event.
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
- .object_name ⇒ Object
Methods included from APIOperations::Create
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
36 37 38 |
# File 'lib/stripe/resources/billing/meter_event.rb', line 36 def created @created end |
#event_name ⇒ Object (readonly)
The name of the meter event. Corresponds with the ‘event_name` field on a meter.
38 39 40 |
# File 'lib/stripe/resources/billing/meter_event.rb', line 38 def event_name @event_name end |
#identifier ⇒ Object (readonly)
A unique identifier for the event.
40 41 42 |
# File 'lib/stripe/resources/billing/meter_event.rb', line 40 def identifier @identifier end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
42 43 44 |
# File 'lib/stripe/resources/billing/meter_event.rb', line 42 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
44 45 46 |
# File 'lib/stripe/resources/billing/meter_event.rb', line 44 def object @object end |
#payload ⇒ Object (readonly)
The payload of the event. This contains the fields corresponding to a meter’s ‘customer_mapping.event_payload_key` (default is `stripe_customer_id`) and `value_settings.event_payload_key` (default is `value`). Read more about the [payload](stripe.com/docs/billing/subscriptions/usage-based/recording-usage#payload-key-overrides).
46 47 48 |
# File 'lib/stripe/resources/billing/meter_event.rb', line 46 def payload @payload end |
#timestamp ⇒ Object (readonly)
The timestamp passed in when creating the event. Measured in seconds since the Unix epoch.
48 49 50 |
# File 'lib/stripe/resources/billing/meter_event.rb', line 48 def @timestamp end |
Class Method Details
.create(params = {}, opts = {}) ⇒ Object
Creates a billing meter event.
51 52 53 54 55 56 57 58 |
# File 'lib/stripe/resources/billing/meter_event.rb', line 51 def self.create(params = {}, opts = {}) request_stripe_object( method: :post, path: "/v1/billing/meter_events", params: params, opts: opts ) end |
.field_remappings ⇒ Object
64 65 66 |
# File 'lib/stripe/resources/billing/meter_event.rb', line 64 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
60 61 62 |
# File 'lib/stripe/resources/billing/meter_event.rb', line 60 def self.inner_class_types @inner_class_types = {} end |
.object_name ⇒ Object
11 12 13 |
# File 'lib/stripe/resources/billing/meter_event.rb', line 11 def self.object_name "billing.meter_event" end |