Class: Stripe::Billing::MeterEventService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Billing::MeterEventService::CreateParams
- Defined in:
- lib/stripe/services/billing/meter_event_service.rb
Instance Attribute Summary collapse
-
#event_name ⇒ Object
The name of the meter event.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#identifier ⇒ Object
A unique identifier for the event.
-
#payload ⇒ Object
The payload of the event.
-
#timestamp ⇒ Object
The time of the event.
Instance Method Summary collapse
-
#initialize(event_name: nil, expand: nil, identifier: nil, payload: nil, timestamp: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(event_name: nil, expand: nil, identifier: nil, payload: nil, timestamp: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
19 20 21 22 23 24 25 |
# File 'lib/stripe/services/billing/meter_event_service.rb', line 19 def initialize(event_name: nil, expand: nil, identifier: nil, payload: nil, timestamp: nil) @event_name = event_name @expand = @identifier = identifier @payload = payload @timestamp = end |
Instance Attribute Details
#event_name ⇒ Object
The name of the meter event. Corresponds with the ‘event_name` field on a meter.
9 10 11 |
# File 'lib/stripe/services/billing/meter_event_service.rb', line 9 def event_name @event_name end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
11 12 13 |
# File 'lib/stripe/services/billing/meter_event_service.rb', line 11 def @expand end |
#identifier ⇒ Object
A unique identifier for the event. If not provided, one is generated. We recommend using UUID-like identifiers. We will enforce uniqueness within a rolling period of at least 24 hours. The enforcement of uniqueness primarily addresses issues arising from accidental retries or other problems occurring within extremely brief time intervals. This approach helps prevent duplicate entries and ensures data integrity in high-frequency operations.
13 14 15 |
# File 'lib/stripe/services/billing/meter_event_service.rb', line 13 def identifier @identifier end |
#payload ⇒ Object
The payload of the event. This must contain the fields corresponding to a meter’s ‘customer_mapping.event_payload_key` (default is `stripe_customer_id`) and `value_settings.event_payload_key` (default is `value`). Read more about the [payload](docs.stripe.com/billing/subscriptions/usage-based/recording-usage#payload-key-overrides).
15 16 17 |
# File 'lib/stripe/services/billing/meter_event_service.rb', line 15 def payload @payload end |
#timestamp ⇒ Object
The time of the event. Measured in seconds since the Unix epoch. Must be within the past 35 calendar days or up to 5 minutes in the future. Defaults to current timestamp if not specified.
17 18 19 |
# File 'lib/stripe/services/billing/meter_event_service.rb', line 17 def @timestamp end |