Class: Stripe::Billing::MeterService::CreateParams::ValueSettings

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/billing/meter_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(event_payload_key: nil) ⇒ ValueSettings

Returns a new instance of ValueSettings.



72
73
74
# File 'lib/stripe/services/billing/meter_service.rb', line 72

def initialize(event_payload_key: nil)
  @event_payload_key = event_payload_key
end

Instance Attribute Details

#event_payload_keyObject

The key in the usage event payload to use as the value for this meter. For example, if the event payload contains usage on a ‘bytes_used` field, then set the event_payload_key to “bytes_used”.



70
71
72
# File 'lib/stripe/services/billing/meter_service.rb', line 70

def event_payload_key
  @event_payload_key
end