Class: Stripe::Billing::MeterService::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Billing::MeterService::UpdateParams
- Defined in:
- lib/stripe/services/billing/meter_service.rb
Instance Attribute Summary collapse
-
#display_name ⇒ Object
The meter’s name.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(display_name: nil, expand: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(display_name: nil, expand: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
132 133 134 135 |
# File 'lib/stripe/services/billing/meter_service.rb', line 132 def initialize(display_name: nil, expand: nil) @display_name = display_name @expand = end |
Instance Attribute Details
#display_name ⇒ Object
The meter’s name. Not visible to the customer.
127 128 129 |
# File 'lib/stripe/services/billing/meter_service.rb', line 127 def display_name @display_name end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
130 131 132 |
# File 'lib/stripe/services/billing/meter_service.rb', line 130 def @expand end |