Class: Stripe::Billing::MeterUsage

Inherits:
SingletonAPIResource show all
Defined in:
lib/stripe/resources/billing/meter_usage.rb

Overview

A billing meter usage event represents an aggregated view of a customer’s billing meter events within a specified timeframe.

Constant Summary collapse

OBJECT_NAME =
"billing.meter_usage"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from SingletonAPIResource

resource_url, #resource_url, retrieve

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#dataObject (readonly)

The aggregated meter usage data for the specified customer and time range.



14
15
16
# File 'lib/stripe/resources/billing/meter_usage.rb', line 14

def data
  @data
end

#data_refreshed_atObject (readonly)

Timestamp indicating how fresh the data is. Measured in seconds since the Unix epoch.



16
17
18
# File 'lib/stripe/resources/billing/meter_usage.rb', line 16

def data_refreshed_at
  @data_refreshed_at
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



18
19
20
# File 'lib/stripe/resources/billing/meter_usage.rb', line 18

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



20
21
22
# File 'lib/stripe/resources/billing/meter_usage.rb', line 20

def object
  @object
end

Class Method Details

.field_remappingsObject



26
27
28
# File 'lib/stripe/resources/billing/meter_usage.rb', line 26

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



22
23
24
# File 'lib/stripe/resources/billing/meter_usage.rb', line 22

def self.inner_class_types
  @inner_class_types = {}
end

.object_nameObject



9
10
11
# File 'lib/stripe/resources/billing/meter_usage.rb', line 9

def self.object_name
  "billing.meter_usage"
end