Class: Stripe::Billing::MeterUsageService

Inherits:
StripeService show all
Defined in:
lib/stripe/services/billing/meter_usage_service.rb

Defined Under Namespace

Classes: RetrieveParams

Instance Method Summary collapse

Methods inherited from StripeService

#initialize, #request, #request_stream

Constructor Details

This class inherits a constructor from Stripe::StripeService

Instance Method Details

#retrieve(params = {}, opts = {}) ⇒ Object

Returns aggregated meter usage data for a customer within a specified time interval. The data can be grouped by various dimensions and can include multiple meters if specified.



65
66
67
68
69
70
71
72
73
# File 'lib/stripe/services/billing/meter_usage_service.rb', line 65

def retrieve(params = {}, opts = {})
  request(
    method: :get,
    path: "/v1/billing/analytics/meter_usage",
    params: params,
    opts: opts,
    base_address: :api
  )
end