Class: Stripe::BillingPortal::Configuration::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/billing_portal/configuration.rb

Defined Under Namespace

Classes: BusinessProfile, Features, LoginPage

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(business_profile: nil, default_return_url: nil, expand: nil, features: nil, login_page: nil, metadata: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 349

def initialize(
  business_profile: nil,
  default_return_url: nil,
  expand: nil,
  features: nil,
  login_page: nil,
  metadata: nil
)
  @business_profile = business_profile
  @default_return_url = default_return_url
  @expand = expand
  @features = features
  @login_page = 
  @metadata = 
end

Instance Attribute Details

#business_profileObject

The business information shown to customers in the portal.



337
338
339
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 337

def business_profile
  @business_profile
end

#default_return_urlObject

The default URL to redirect customers to when they click on the portal’s link to return to your website. This can be [overriden](stripe.com/docs/api/customer_portal/sessions/create#create_portal_session-return_url) when creating the session.



339
340
341
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 339

def default_return_url
  @default_return_url
end

#expandObject

Specifies which fields in the response should be expanded.



341
342
343
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 341

def expand
  @expand
end

#featuresObject

Information about the features available in the portal.



343
344
345
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 343

def features
  @features
end

#login_pageObject

The hosted login page for this configuration. Learn more about the portal login page in our [integration docs](stripe.com/docs/billing/subscriptions/integrating-customer-portal#share).



345
346
347
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 345

def 
  @login_page
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



347
348
349
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 347

def 
  @metadata
end