Class: Stripe::BillingPortal::Configuration::CreateParams::Features
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::BillingPortal::Configuration::CreateParams::Features
- Defined in:
- lib/stripe/resources/billing_portal/configuration.rb
Defined Under Namespace
Classes: CustomerUpdate, InvoiceHistory, PaymentMethodUpdate, SubscriptionCancel, SubscriptionUpdate
Instance Attribute Summary collapse
-
#customer_update ⇒ Object
Information about updating the customer details in the portal.
-
#invoice_history ⇒ Object
Information about showing the billing history in the portal.
-
#payment_method_update ⇒ Object
Information about updating payment methods in the portal.
-
#subscription_cancel ⇒ Object
Information about canceling subscriptions in the portal.
-
#subscription_update ⇒ Object
Information about updating subscriptions in the portal.
Instance Method Summary collapse
-
#initialize(customer_update: nil, invoice_history: nil, payment_method_update: nil, subscription_cancel: nil, subscription_update: nil) ⇒ Features
constructor
A new instance of Features.
Methods inherited from RequestParams
Constructor Details
#initialize(customer_update: nil, invoice_history: nil, payment_method_update: nil, subscription_cancel: nil, subscription_update: nil) ⇒ Features
Returns a new instance of Features.
423 424 425 426 427 428 429 430 431 432 433 434 435 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 423 def initialize( customer_update: nil, invoice_history: nil, payment_method_update: nil, subscription_cancel: nil, subscription_update: nil ) @customer_update = customer_update @invoice_history = invoice_history @payment_method_update = payment_method_update @subscription_cancel = subscription_cancel @subscription_update = subscription_update end |
Instance Attribute Details
#customer_update ⇒ Object
Information about updating the customer details in the portal.
413 414 415 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 413 def customer_update @customer_update end |
#invoice_history ⇒ Object
Information about showing the billing history in the portal.
415 416 417 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 415 def invoice_history @invoice_history end |
#payment_method_update ⇒ Object
Information about updating payment methods in the portal.
417 418 419 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 417 def payment_method_update @payment_method_update end |
#subscription_cancel ⇒ Object
Information about canceling subscriptions in the portal.
419 420 421 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 419 def subscription_cancel @subscription_cancel end |
#subscription_update ⇒ Object
Information about updating subscriptions in the portal.
421 422 423 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 421 def subscription_update @subscription_update end |