Class: Stripe::BillingPortal::Configuration::CreateParams::Features::SubscriptionUpdate::Product

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/billing_portal/configuration.rb

Defined Under Namespace

Classes: AdjustableQuantity

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(adjustable_quantity: nil, prices: nil, product: nil) ⇒ Product

Returns a new instance of Product.



364
365
366
367
368
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 364

def initialize(adjustable_quantity: nil, prices: nil, product: nil)
  @adjustable_quantity = adjustable_quantity
  @prices = prices
  @product = product
end

Instance Attribute Details

#adjustable_quantityObject

Control whether the quantity of the product can be adjusted.



358
359
360
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 358

def adjustable_quantity
  @adjustable_quantity
end

#pricesObject

The list of price IDs for the product that a subscription can be updated to.



360
361
362
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 360

def prices
  @prices
end

#productObject

The product id.



362
363
364
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 362

def product
  @product
end