Class: Stripe::BillingPortal::Configuration::Features::SubscriptionUpdate
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::BillingPortal::Configuration::Features::SubscriptionUpdate
- Defined in:
- lib/stripe/resources/billing_portal/configuration.rb
Defined Under Namespace
Classes: Product, ScheduleAtPeriodEnd
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#billing_cycle_anchor ⇒ Object
readonly
Determines the value to use for the billing cycle anchor on subscription updates.
-
#default_allowed_updates ⇒ Object
readonly
The types of subscription updates that are supported for items listed in the
productsattribute. -
#enabled ⇒ Object
readonly
Whether the feature is enabled.
-
#products ⇒ Object
readonly
The list of up to 10 products that support subscription updates.
-
#proration_behavior ⇒ Object
readonly
Determines how to handle prorations resulting from subscription updates.
-
#schedule_at_period_end ⇒ Object
readonly
Attribute for field schedule_at_period_end.
-
#trial_update_behavior ⇒ Object
readonly
Determines how handle updates to trialing subscriptions.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#billing_cycle_anchor ⇒ Object (readonly)
Determines the value to use for the billing cycle anchor on subscription updates. Valid values are now or unchanged, and the default value is unchanged. Setting the value to now resets the subscription's billing cycle anchor to the current time (in UTC). For more information, see the billing cycle documentation.
172 173 174 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 172 def billing_cycle_anchor @billing_cycle_anchor end |
#default_allowed_updates ⇒ Object (readonly)
The types of subscription updates that are supported for items listed in the products attribute. When empty, subscriptions are not updateable.
174 175 176 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 174 def default_allowed_updates @default_allowed_updates end |
#enabled ⇒ Object (readonly)
Whether the feature is enabled.
176 177 178 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 176 def enabled @enabled end |
#products ⇒ Object (readonly)
The list of up to 10 products that support subscription updates.
178 179 180 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 178 def products @products end |
#proration_behavior ⇒ Object (readonly)
Determines how to handle prorations resulting from subscription updates. Valid values are none, create_prorations, and always_invoice. Defaults to a value of none if you don't set it during creation.
180 181 182 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 180 def proration_behavior @proration_behavior end |
#schedule_at_period_end ⇒ Object (readonly)
Attribute for field schedule_at_period_end
182 183 184 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 182 def schedule_at_period_end @schedule_at_period_end end |
#trial_update_behavior ⇒ Object (readonly)
Determines how handle updates to trialing subscriptions. Valid values are end_trial and continue_trial. Defaults to a value of end_trial if you don't set it during creation.
184 185 186 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 184 def trial_update_behavior @trial_update_behavior end |
Class Method Details
.field_remappings ⇒ Object
190 191 192 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 190 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
186 187 188 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 186 def self.inner_class_types @inner_class_types = { products: Product, schedule_at_period_end: ScheduleAtPeriodEnd } end |