Class: Stripe::BillingPortal::Configuration::ListParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/billing_portal/configuration.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(active: nil, ending_before: nil, expand: nil, is_default: nil, limit: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 243

def initialize(
  active: nil,
  ending_before: nil,
  expand: nil,
  is_default: nil,
  limit: nil,
  starting_after: nil
)
  @active = active
  @ending_before = ending_before
  @expand = expand
  @is_default = is_default
  @limit = limit
  @starting_after = starting_after
end

Instance Attribute Details

#activeObject

Only return configurations that are active or inactive (e.g., pass ‘true` to only list active configurations).



231
232
233
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 231

def active
  @active
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



233
234
235
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 233

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



235
236
237
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 235

def expand
  @expand
end

#is_defaultObject

Only return the default or non-default configurations (e.g., pass ‘true` to only list the default configuration).



237
238
239
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 237

def is_default
  @is_default
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



239
240
241
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 239

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



241
242
243
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 241

def starting_after
  @starting_after
end