Class: Stripe::BillingPortal::Configuration::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/billing_portal/configuration.rb

Defined Under Namespace

Classes: BusinessProfile, Features, LoginPage

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(active: nil, business_profile: nil, default_return_url: nil, expand: nil, features: nil, login_page: nil, metadata: nil, name: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 685

def initialize(
  active: nil,
  business_profile: nil,
  default_return_url: nil,
  expand: nil,
  features: nil,
  login_page: nil,
  metadata: nil,
  name: nil
)
  @active = active
  @business_profile = business_profile
  @default_return_url = default_return_url
  @expand = expand
  @features = features
  @login_page = 
  @metadata = 
  @name = name
end

Instance Attribute Details

#activeObject

Whether the configuration is active and can be used to create portal sessions.



669
670
671
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 669

def active
  @active
end

#business_profileObject

The business information shown to customers in the portal.



671
672
673
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 671

def business_profile
  @business_profile
end

#default_return_urlObject

The default URL to redirect customers to when they click on the portal’s link to return to your website. This can be [overriden](stripe.com/docs/api/customer_portal/sessions/create#create_portal_session-return_url) when creating the session.



673
674
675
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 673

def default_return_url
  @default_return_url
end

#expandObject

Specifies which fields in the response should be expanded.



675
676
677
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 675

def expand
  @expand
end

#featuresObject

Information about the features available in the portal.



677
678
679
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 677

def features
  @features
end

#login_pageObject

The hosted login page for this configuration. Learn more about the portal login page in our [integration docs](stripe.com/docs/billing/subscriptions/integrating-customer-portal#share).



679
680
681
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 679

def 
  @login_page
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



681
682
683
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 681

def 
  @metadata
end

#nameObject

The name of the configuration.



683
684
685
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 683

def name
  @name
end