Class: Stripe::BillingPortal::Configuration::UpdateParams::Features
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::BillingPortal::Configuration::UpdateParams::Features
- Defined in:
- lib/stripe/resources/billing_portal/configuration.rb
Defined Under Namespace
Classes: CustomerUpdate, InvoiceHistory, PaymentMethodUpdate, SubscriptionCancel, SubscriptionUpdate
Instance Attribute Summary collapse
-
#customer_update ⇒ Object
Information about updating the customer details in the portal.
-
#invoice_history ⇒ Object
Information about showing the billing history in the portal.
-
#payment_method_update ⇒ Object
Information about updating payment methods in the portal.
-
#subscription_cancel ⇒ Object
Information about canceling subscriptions in the portal.
-
#subscription_update ⇒ Object
Information about updating subscriptions in the portal.
Instance Method Summary collapse
-
#initialize(customer_update: nil, invoice_history: nil, payment_method_update: nil, subscription_cancel: nil, subscription_update: nil) ⇒ Features
constructor
A new instance of Features.
Methods inherited from RequestParams
Constructor Details
#initialize(customer_update: nil, invoice_history: nil, payment_method_update: nil, subscription_cancel: nil, subscription_update: nil) ⇒ Features
Returns a new instance of Features.
643 644 645 646 647 648 649 650 651 652 653 654 655 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 643 def initialize( customer_update: nil, invoice_history: nil, payment_method_update: nil, subscription_cancel: nil, subscription_update: nil ) @customer_update = customer_update @invoice_history = invoice_history @payment_method_update = payment_method_update @subscription_cancel = subscription_cancel @subscription_update = subscription_update end |
Instance Attribute Details
#customer_update ⇒ Object
Information about updating the customer details in the portal.
633 634 635 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 633 def customer_update @customer_update end |
#invoice_history ⇒ Object
Information about showing the billing history in the portal.
635 636 637 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 635 def invoice_history @invoice_history end |
#payment_method_update ⇒ Object
Information about updating payment methods in the portal.
637 638 639 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 637 def payment_method_update @payment_method_update end |
#subscription_cancel ⇒ Object
Information about canceling subscriptions in the portal.
639 640 641 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 639 def subscription_cancel @subscription_cancel end |
#subscription_update ⇒ Object
Information about updating subscriptions in the portal.
641 642 643 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 641 def subscription_update @subscription_update end |