Class: Stripe::BillingPortal::Configuration::UpdateParams::Features::SubscriptionCancel::CancellationReason
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::BillingPortal::Configuration::UpdateParams::Features::SubscriptionCancel::CancellationReason
- Defined in:
- lib/stripe/resources/billing_portal/configuration.rb
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Whether the feature is enabled.
-
#options ⇒ Object
Which cancellation reasons will be given as options to the customer.
Instance Method Summary collapse
-
#initialize(enabled: nil, options: nil) ⇒ CancellationReason
constructor
A new instance of CancellationReason.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, options: nil) ⇒ CancellationReason
Returns a new instance of CancellationReason.
393 394 395 396 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 393 def initialize(enabled: nil, options: nil) @enabled = enabled @options = end |
Instance Attribute Details
#enabled ⇒ Object
Whether the feature is enabled.
389 390 391 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 389 def enabled @enabled end |
#options ⇒ Object
Which cancellation reasons will be given as options to the customer.
391 392 393 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 391 def @options end |