Class: Stripe::BillingPortal::Configuration::UpdateParams::Features::SubscriptionUpdate

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/billing_portal/configuration.rb

Defined Under Namespace

Classes: Product, ScheduleAtPeriodEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(default_allowed_updates: nil, enabled: nil, products: nil, proration_behavior: nil, schedule_at_period_end: nil) ⇒ SubscriptionUpdate

Returns a new instance of SubscriptionUpdate.



618
619
620
621
622
623
624
625
626
627
628
629
630
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 618

def initialize(
  default_allowed_updates: nil,
  enabled: nil,
  products: nil,
  proration_behavior: nil,
  schedule_at_period_end: nil
)
  @default_allowed_updates = default_allowed_updates
  @enabled = enabled
  @products = products
  @proration_behavior = proration_behavior
  @schedule_at_period_end = schedule_at_period_end
end

Instance Attribute Details

#default_allowed_updatesObject

The types of subscription updates that are supported. When empty, subscriptions are not updateable.



608
609
610
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 608

def default_allowed_updates
  @default_allowed_updates
end

#enabledObject

Whether the feature is enabled.



610
611
612
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 610

def enabled
  @enabled
end

#productsObject

The list of up to 10 products that support subscription updates.



612
613
614
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 612

def products
  @products
end

#proration_behaviorObject

Determines how to handle prorations resulting from subscription updates. Valid values are ‘none`, `create_prorations`, and `always_invoice`.



614
615
616
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 614

def proration_behavior
  @proration_behavior
end

#schedule_at_period_endObject

Setting to control when an update should be scheduled at the end of the period instead of applying immediately.



616
617
618
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 616

def schedule_at_period_end
  @schedule_at_period_end
end