Class: Stripe::BillingPortal::Configuration::UpdateParams::Features::SubscriptionUpdate::ScheduleAtPeriodEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/billing_portal/configuration.rb

Defined Under Namespace

Classes: Condition

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(conditions: nil) ⇒ ScheduleAtPeriodEnd

Returns a new instance of ScheduleAtPeriodEnd.



603
604
605
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 603

def initialize(conditions: nil)
  @conditions = conditions
end

Instance Attribute Details

#conditionsObject

List of conditions. When any condition is true, the update will be scheduled at the end of the current period.



601
602
603
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 601

def conditions
  @conditions
end