Class: Stripe::BillingPortal::ConfigurationCreateParams::Features::SubscriptionUpdate::Product

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/billing_portal/configuration_create_params.rb

Defined Under Namespace

Classes: AdjustableQuantity

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(adjustable_quantity: nil, prices: nil, product: nil) ⇒ Product

Returns a new instance of Product.



105
106
107
108
109
# File 'lib/stripe/params/billing_portal/configuration_create_params.rb', line 105

def initialize(adjustable_quantity: nil, prices: nil, product: nil)
  @adjustable_quantity = adjustable_quantity
  @prices = prices
  @product = product
end

Instance Attribute Details

#adjustable_quantityObject

Control whether the quantity of the product can be adjusted.



99
100
101
# File 'lib/stripe/params/billing_portal/configuration_create_params.rb', line 99

def adjustable_quantity
  @adjustable_quantity
end

#pricesObject

The list of price IDs for the product that a subscription can be updated to.



101
102
103
# File 'lib/stripe/params/billing_portal/configuration_create_params.rb', line 101

def prices
  @prices
end

#productObject

The product id.



103
104
105
# File 'lib/stripe/params/billing_portal/configuration_create_params.rb', line 103

def product
  @product
end