Class: Stripe::BillingPortal::ConfigurationCreateParams::Features::SubscriptionUpdate::Product::AdjustableQuantity
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::BillingPortal::ConfigurationCreateParams::Features::SubscriptionUpdate::Product::AdjustableQuantity
- Defined in:
- lib/stripe/params/billing_portal/configuration_create_params.rb
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Set to true if the quantity can be adjusted to any non-negative integer.
-
#maximum ⇒ Object
The maximum quantity that can be set for the product.
-
#minimum ⇒ Object
The minimum quantity that can be set for the product.
Instance Method Summary collapse
-
#initialize(enabled: nil, maximum: nil, minimum: nil) ⇒ AdjustableQuantity
constructor
A new instance of AdjustableQuantity.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(enabled: nil, maximum: nil, minimum: nil) ⇒ AdjustableQuantity
Returns a new instance of AdjustableQuantity.
98 99 100 101 102 |
# File 'lib/stripe/params/billing_portal/configuration_create_params.rb', line 98 def initialize(enabled: nil, maximum: nil, minimum: nil) @enabled = enabled @maximum = maximum @minimum = minimum end |
Instance Attribute Details
#enabled ⇒ Object
Set to true if the quantity can be adjusted to any non-negative integer.
92 93 94 |
# File 'lib/stripe/params/billing_portal/configuration_create_params.rb', line 92 def enabled @enabled end |
#maximum ⇒ Object
The maximum quantity that can be set for the product.
94 95 96 |
# File 'lib/stripe/params/billing_portal/configuration_create_params.rb', line 94 def maximum @maximum end |
#minimum ⇒ Object
The minimum quantity that can be set for the product.
96 97 98 |
# File 'lib/stripe/params/billing_portal/configuration_create_params.rb', line 96 def minimum @minimum end |