Class: Stripe::BillingPortal::ConfigurationService::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/billing_portal/configuration_service.rb

Defined Under Namespace

Classes: BusinessProfile, Features, LoginPage

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(business_profile: nil, default_return_url: nil, expand: nil, features: nil, login_page: nil, metadata: nil, name: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 239

def initialize(
  business_profile: nil,
  default_return_url: nil,
  expand: nil,
  features: nil,
  login_page: nil,
  metadata: nil,
  name: nil
)
  @business_profile = business_profile
  @default_return_url = default_return_url
  @expand = expand
  @features = features
  @login_page = 
  @metadata = 
  @name = name
end

Instance Attribute Details

#business_profileObject

The business information shown to customers in the portal.



225
226
227
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 225

def business_profile
  @business_profile
end

#default_return_urlObject

The default URL to redirect customers to when they click on the portal’s link to return to your website. This can be [overriden](stripe.com/docs/api/customer_portal/sessions/create#create_portal_session-return_url) when creating the session.



227
228
229
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 227

def default_return_url
  @default_return_url
end

#expandObject

Specifies which fields in the response should be expanded.



229
230
231
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 229

def expand
  @expand
end

#featuresObject

Information about the features available in the portal.



231
232
233
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 231

def features
  @features
end

#login_pageObject

The hosted login page for this configuration. Learn more about the portal login page in our [integration docs](stripe.com/docs/billing/subscriptions/integrating-customer-portal#share).



233
234
235
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 233

def 
  @login_page
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



235
236
237
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 235

def 
  @metadata
end

#nameObject

The name of the configuration.



237
238
239
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 237

def name
  @name
end