Class: Stripe::BillingPortal::ConfigurationService::CreateParams::Features
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::BillingPortal::ConfigurationService::CreateParams::Features
- Defined in:
- lib/stripe/services/billing_portal/configuration_service.rb
Defined Under Namespace
Classes: CustomerUpdate, InvoiceHistory, PaymentMethodUpdate, SubscriptionCancel, SubscriptionUpdate
Instance Attribute Summary collapse
-
#customer_update ⇒ Object
Information about updating the customer details in the portal.
-
#invoice_history ⇒ Object
Information about showing the billing history in the portal.
-
#payment_method_update ⇒ Object
Information about updating payment methods in the portal.
-
#subscription_cancel ⇒ Object
Information about canceling subscriptions in the portal.
-
#subscription_update ⇒ Object
Information about updating subscriptions in the portal.
Instance Method Summary collapse
-
#initialize(customer_update: nil, invoice_history: nil, payment_method_update: nil, subscription_cancel: nil, subscription_update: nil) ⇒ Features
constructor
A new instance of Features.
Methods inherited from RequestParams
Constructor Details
#initialize(customer_update: nil, invoice_history: nil, payment_method_update: nil, subscription_cancel: nil, subscription_update: nil) ⇒ Features
Returns a new instance of Features.
201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 201 def initialize( customer_update: nil, invoice_history: nil, payment_method_update: nil, subscription_cancel: nil, subscription_update: nil ) @customer_update = customer_update @invoice_history = invoice_history @payment_method_update = payment_method_update @subscription_cancel = subscription_cancel @subscription_update = subscription_update end |
Instance Attribute Details
#customer_update ⇒ Object
Information about updating the customer details in the portal.
191 192 193 |
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 191 def customer_update @customer_update end |
#invoice_history ⇒ Object
Information about showing the billing history in the portal.
193 194 195 |
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 193 def invoice_history @invoice_history end |
#payment_method_update ⇒ Object
Information about updating payment methods in the portal.
195 196 197 |
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 195 def payment_method_update @payment_method_update end |
#subscription_cancel ⇒ Object
Information about canceling subscriptions in the portal.
197 198 199 |
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 197 def subscription_cancel @subscription_cancel end |
#subscription_update ⇒ Object
Information about updating subscriptions in the portal.
199 200 201 |
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 199 def subscription_update @subscription_update end |