Class: Stripe::BillingPortal::ConfigurationService::CreateParams::Features::SubscriptionUpdate::Product
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::BillingPortal::ConfigurationService::CreateParams::Features::SubscriptionUpdate::Product
- Defined in:
- lib/stripe/services/billing_portal/configuration_service.rb
Defined Under Namespace
Classes: AdjustableQuantity
Instance Attribute Summary collapse
-
#adjustable_quantity ⇒ Object
Control whether the quantity of the product can be adjusted.
-
#prices ⇒ Object
The list of price IDs for the product that a subscription can be updated to.
-
#product ⇒ Object
The product id.
Instance Method Summary collapse
-
#initialize(adjustable_quantity: nil, prices: nil, product: nil) ⇒ Product
constructor
A new instance of Product.
Methods inherited from RequestParams
Constructor Details
#initialize(adjustable_quantity: nil, prices: nil, product: nil) ⇒ Product
Returns a new instance of Product.
142 143 144 145 146 |
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 142 def initialize(adjustable_quantity: nil, prices: nil, product: nil) @adjustable_quantity = adjustable_quantity @prices = prices @product = product end |
Instance Attribute Details
#adjustable_quantity ⇒ Object
Control whether the quantity of the product can be adjusted.
136 137 138 |
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 136 def adjustable_quantity @adjustable_quantity end |
#prices ⇒ Object
The list of price IDs for the product that a subscription can be updated to.
138 139 140 |
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 138 def prices @prices end |
#product ⇒ Object
The product id.
140 141 142 |
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 140 def product @product end |