Class: Stripe::BillingPortal::ConfigurationService::CreateParams::Features::SubscriptionUpdate::Product::AdjustableQuantity
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::BillingPortal::ConfigurationService::CreateParams::Features::SubscriptionUpdate::Product::AdjustableQuantity
- Defined in:
- lib/stripe/services/billing_portal/configuration_service.rb
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Set to true if the quantity can be adjusted to any non-negative integer.
-
#maximum ⇒ Object
The maximum quantity that can be set for the product.
-
#minimum ⇒ Object
The minimum quantity that can be set for the product.
Instance Method Summary collapse
-
#initialize(enabled: nil, maximum: nil, minimum: nil) ⇒ AdjustableQuantity
constructor
A new instance of AdjustableQuantity.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, maximum: nil, minimum: nil) ⇒ AdjustableQuantity
Returns a new instance of AdjustableQuantity.
129 130 131 132 133 |
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 129 def initialize(enabled: nil, maximum: nil, minimum: nil) @enabled = enabled @maximum = maximum @minimum = minimum end |
Instance Attribute Details
#enabled ⇒ Object
Set to true if the quantity can be adjusted to any non-negative integer.
123 124 125 |
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 123 def enabled @enabled end |
#maximum ⇒ Object
The maximum quantity that can be set for the product.
125 126 127 |
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 125 def maximum @maximum end |
#minimum ⇒ Object
The minimum quantity that can be set for the product.
127 128 129 |
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 127 def minimum @minimum end |