Class: Stripe::BillingPortal::ConfigurationService::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/billing_portal/configuration_service.rb

Defined Under Namespace

Classes: BusinessProfile, Features, LoginPage

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(active: nil, business_profile: nil, default_return_url: nil, expand: nil, features: nil, login_page: nil, metadata: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 466

def initialize(
  active: nil,
  business_profile: nil,
  default_return_url: nil,
  expand: nil,
  features: nil,
  login_page: nil,
  metadata: nil
)
  @active = active
  @business_profile = business_profile
  @default_return_url = default_return_url
  @expand = expand
  @features = features
  @login_page = 
  @metadata = 
end

Instance Attribute Details

#activeObject

Whether the configuration is active and can be used to create portal sessions.



452
453
454
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 452

def active
  @active
end

#business_profileObject

The business information shown to customers in the portal.



454
455
456
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 454

def business_profile
  @business_profile
end

#default_return_urlObject

The default URL to redirect customers to when they click on the portal’s link to return to your website. This can be [overriden](stripe.com/docs/api/customer_portal/sessions/create#create_portal_session-return_url) when creating the session.



456
457
458
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 456

def default_return_url
  @default_return_url
end

#expandObject

Specifies which fields in the response should be expanded.



458
459
460
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 458

def expand
  @expand
end

#featuresObject

Information about the features available in the portal.



460
461
462
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 460

def features
  @features
end

#login_pageObject

The hosted login page for this configuration. Learn more about the portal login page in our [integration docs](stripe.com/docs/billing/subscriptions/integrating-customer-portal#share).



462
463
464
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 462

def 
  @login_page
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



464
465
466
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 464

def 
  @metadata
end