Class: Stripe::BillingPortal::ConfigurationService::UpdateParams::Features
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::BillingPortal::ConfigurationService::UpdateParams::Features
- Defined in:
- lib/stripe/services/billing_portal/configuration_service.rb
Defined Under Namespace
Classes: CustomerUpdate, InvoiceHistory, PaymentMethodUpdate, SubscriptionCancel, SubscriptionUpdate
Instance Attribute Summary collapse
-
#customer_update ⇒ Object
Information about updating the customer details in the portal.
-
#invoice_history ⇒ Object
Information about showing the billing history in the portal.
-
#payment_method_update ⇒ Object
Information about updating payment methods in the portal.
-
#subscription_cancel ⇒ Object
Information about canceling subscriptions in the portal.
-
#subscription_update ⇒ Object
Information about updating subscriptions in the portal.
Instance Method Summary collapse
-
#initialize(customer_update: nil, invoice_history: nil, payment_method_update: nil, subscription_cancel: nil, subscription_update: nil) ⇒ Features
constructor
A new instance of Features.
Methods inherited from RequestParams
Constructor Details
#initialize(customer_update: nil, invoice_history: nil, payment_method_update: nil, subscription_cancel: nil, subscription_update: nil) ⇒ Features
Returns a new instance of Features.
430 431 432 433 434 435 436 437 438 439 440 441 442 |
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 430 def initialize( customer_update: nil, invoice_history: nil, payment_method_update: nil, subscription_cancel: nil, subscription_update: nil ) @customer_update = customer_update @invoice_history = invoice_history @payment_method_update = payment_method_update @subscription_cancel = subscription_cancel @subscription_update = subscription_update end |
Instance Attribute Details
#customer_update ⇒ Object
Information about updating the customer details in the portal.
420 421 422 |
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 420 def customer_update @customer_update end |
#invoice_history ⇒ Object
Information about showing the billing history in the portal.
422 423 424 |
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 422 def invoice_history @invoice_history end |
#payment_method_update ⇒ Object
Information about updating payment methods in the portal.
424 425 426 |
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 424 def payment_method_update @payment_method_update end |
#subscription_cancel ⇒ Object
Information about canceling subscriptions in the portal.
426 427 428 |
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 426 def subscription_cancel @subscription_cancel end |
#subscription_update ⇒ Object
Information about updating subscriptions in the portal.
428 429 430 |
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 428 def subscription_update @subscription_update end |