Class: Stripe::BillingPortal::ConfigurationService::UpdateParams::Features::SubscriptionUpdate
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::BillingPortal::ConfigurationService::UpdateParams::Features::SubscriptionUpdate
- Defined in:
- lib/stripe/services/billing_portal/configuration_service.rb
Defined Under Namespace
Classes: Product, ScheduleAtPeriodEnd
Instance Attribute Summary collapse
-
#default_allowed_updates ⇒ Object
The types of subscription updates that are supported.
-
#enabled ⇒ Object
Whether the feature is enabled.
-
#products ⇒ Object
The list of up to 10 products that support subscription updates.
-
#proration_behavior ⇒ Object
Determines how to handle prorations resulting from subscription updates.
-
#schedule_at_period_end ⇒ Object
Setting to control when an update should be scheduled at the end of the period instead of applying immediately.
Instance Method Summary collapse
-
#initialize(default_allowed_updates: nil, enabled: nil, products: nil, proration_behavior: nil, schedule_at_period_end: nil) ⇒ SubscriptionUpdate
constructor
A new instance of SubscriptionUpdate.
Methods inherited from RequestParams
Constructor Details
#initialize(default_allowed_updates: nil, enabled: nil, products: nil, proration_behavior: nil, schedule_at_period_end: nil) ⇒ SubscriptionUpdate
Returns a new instance of SubscriptionUpdate.
405 406 407 408 409 410 411 412 413 414 415 416 417 |
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 405 def initialize( default_allowed_updates: nil, enabled: nil, products: nil, proration_behavior: nil, schedule_at_period_end: nil ) @default_allowed_updates = default_allowed_updates @enabled = enabled @products = products @proration_behavior = proration_behavior @schedule_at_period_end = schedule_at_period_end end |
Instance Attribute Details
#default_allowed_updates ⇒ Object
The types of subscription updates that are supported. When empty, subscriptions are not updateable.
395 396 397 |
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 395 def default_allowed_updates @default_allowed_updates end |
#enabled ⇒ Object
Whether the feature is enabled.
397 398 399 |
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 397 def enabled @enabled end |
#products ⇒ Object
The list of up to 10 products that support subscription updates.
399 400 401 |
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 399 def products @products end |
#proration_behavior ⇒ Object
Determines how to handle prorations resulting from subscription updates. Valid values are ‘none`, `create_prorations`, and `always_invoice`.
401 402 403 |
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 401 def proration_behavior @proration_behavior end |
#schedule_at_period_end ⇒ Object
Setting to control when an update should be scheduled at the end of the period instead of applying immediately.
403 404 405 |
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 403 def schedule_at_period_end @schedule_at_period_end end |