Class: Stripe::BillingPortal::ConfigurationService::UpdateParams::Features::SubscriptionUpdate::Product

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/billing_portal/configuration_service.rb

Defined Under Namespace

Classes: AdjustableQuantity

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(adjustable_quantity: nil, prices: nil, product: nil) ⇒ Product

Returns a new instance of Product.



367
368
369
370
371
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 367

def initialize(adjustable_quantity: nil, prices: nil, product: nil)
  @adjustable_quantity = adjustable_quantity
  @prices = prices
  @product = product
end

Instance Attribute Details

#adjustable_quantityObject

Control whether the quantity of the product can be adjusted.



361
362
363
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 361

def adjustable_quantity
  @adjustable_quantity
end

#pricesObject

The list of price IDs for the product that a subscription can be updated to.



363
364
365
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 363

def prices
  @prices
end

#productObject

The product id.



365
366
367
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 365

def product
  @product
end