Class: Stripe::BillingPortal::ConfigurationService::UpdateParams::Features::SubscriptionUpdate::Product::AdjustableQuantity
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::BillingPortal::ConfigurationService::UpdateParams::Features::SubscriptionUpdate::Product::AdjustableQuantity
- Defined in:
- lib/stripe/services/billing_portal/configuration_service.rb
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Set to true if the quantity can be adjusted to any non-negative integer.
-
#maximum ⇒ Object
The maximum quantity that can be set for the product.
-
#minimum ⇒ Object
The minimum quantity that can be set for the product.
Instance Method Summary collapse
-
#initialize(enabled: nil, maximum: nil, minimum: nil) ⇒ AdjustableQuantity
constructor
A new instance of AdjustableQuantity.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, maximum: nil, minimum: nil) ⇒ AdjustableQuantity
Returns a new instance of AdjustableQuantity.
358 359 360 361 362 |
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 358 def initialize(enabled: nil, maximum: nil, minimum: nil) @enabled = enabled @maximum = maximum @minimum = minimum end |
Instance Attribute Details
#enabled ⇒ Object
Set to true if the quantity can be adjusted to any non-negative integer.
352 353 354 |
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 352 def enabled @enabled end |
#maximum ⇒ Object
The maximum quantity that can be set for the product.
354 355 356 |
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 354 def maximum @maximum end |
#minimum ⇒ Object
The minimum quantity that can be set for the product.
356 357 358 |
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 356 def minimum @minimum end |