Class: Stripe::BillingPortal::ConfigurationService::UpdateParams::Features::SubscriptionUpdate::ScheduleAtPeriodEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/billing_portal/configuration_service.rb

Defined Under Namespace

Classes: Condition

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(conditions: nil) ⇒ ScheduleAtPeriodEnd

Returns a new instance of ScheduleAtPeriodEnd.



386
387
388
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 386

def initialize(conditions: nil)
  @conditions = conditions
end

Instance Attribute Details

#conditionsObject

List of conditions. When any condition is true, the update will be scheduled at the end of the current period.



384
385
386
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 384

def conditions
  @conditions
end