Class: Stripe::BillingPortal::ConfigurationUpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/billing_portal/configuration_update_params.rb

Defined Under Namespace

Classes: BusinessProfile, Features, LoginPage

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h

Constructor Details

#initialize(active: nil, business_profile: nil, default_return_url: nil, expand: nil, features: nil, login_page: nil, metadata: nil, name: nil) ⇒ ConfigurationUpdateParams

Returns a new instance of ConfigurationUpdateParams.



220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
# File 'lib/stripe/params/billing_portal/configuration_update_params.rb', line 220

def initialize(
  active: nil,
  business_profile: nil,
  default_return_url: nil,
  expand: nil,
  features: nil,
  login_page: nil,
  metadata: nil,
  name: nil
)
  @active = active
  @business_profile = business_profile
  @default_return_url = default_return_url
  @expand = expand
  @features = features
  @login_page = 
  @metadata = 
  @name = name
end

Instance Attribute Details

#activeObject

Whether the configuration is active and can be used to create portal sessions.



204
205
206
# File 'lib/stripe/params/billing_portal/configuration_update_params.rb', line 204

def active
  @active
end

#business_profileObject

The business information shown to customers in the portal.



206
207
208
# File 'lib/stripe/params/billing_portal/configuration_update_params.rb', line 206

def business_profile
  @business_profile
end

#default_return_urlObject

The default URL to redirect customers to when they click on the portal's link to return to your website. This can be overridden when creating the session.



208
209
210
# File 'lib/stripe/params/billing_portal/configuration_update_params.rb', line 208

def default_return_url
  @default_return_url
end

#expandObject

Specifies which fields in the response should be expanded.



210
211
212
# File 'lib/stripe/params/billing_portal/configuration_update_params.rb', line 210

def expand
  @expand
end

#featuresObject

Information about the features available in the portal.



212
213
214
# File 'lib/stripe/params/billing_portal/configuration_update_params.rb', line 212

def features
  @features
end

#login_pageObject

The hosted login page for this configuration. Learn more about the portal login page in our integration docs.



214
215
216
# File 'lib/stripe/params/billing_portal/configuration_update_params.rb', line 214

def 
  @login_page
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.



216
217
218
# File 'lib/stripe/params/billing_portal/configuration_update_params.rb', line 216

def 
  @metadata
end

#nameObject

The name of the configuration.



218
219
220
# File 'lib/stripe/params/billing_portal/configuration_update_params.rb', line 218

def name
  @name
end