Class: Stripe::BillingPortal::ConfigurationUpdateParams::Features::SubscriptionUpdate

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/billing_portal/configuration_update_params.rb

Defined Under Namespace

Classes: Product, ScheduleAtPeriodEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h

Constructor Details

#initialize(billing_cycle_anchor: nil, default_allowed_updates: nil, enabled: nil, products: nil, proration_behavior: nil, schedule_at_period_end: nil, trial_update_behavior: nil) ⇒ SubscriptionUpdate

Returns a new instance of SubscriptionUpdate.



149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/stripe/params/billing_portal/configuration_update_params.rb', line 149

def initialize(
  billing_cycle_anchor: nil,
  default_allowed_updates: nil,
  enabled: nil,
  products: nil,
  proration_behavior: nil,
  schedule_at_period_end: nil,
  trial_update_behavior: nil
)
  @billing_cycle_anchor = billing_cycle_anchor
  @default_allowed_updates = default_allowed_updates
  @enabled = enabled
  @products = products
  @proration_behavior = proration_behavior
  @schedule_at_period_end = schedule_at_period_end
  @trial_update_behavior = trial_update_behavior
end

Instance Attribute Details

#billing_cycle_anchorObject

Determines the value to use for the billing cycle anchor on subscription updates. Valid values are now or unchanged, and the default value is unchanged. Setting the value to now resets the subscription's billing cycle anchor to the current time (in UTC). For more information, see the billing cycle documentation.



135
136
137
# File 'lib/stripe/params/billing_portal/configuration_update_params.rb', line 135

def billing_cycle_anchor
  @billing_cycle_anchor
end

#default_allowed_updatesObject

The types of subscription updates that are supported. When empty, subscriptions are not updateable.



137
138
139
# File 'lib/stripe/params/billing_portal/configuration_update_params.rb', line 137

def default_allowed_updates
  @default_allowed_updates
end

#enabledObject

Whether the feature is enabled.



139
140
141
# File 'lib/stripe/params/billing_portal/configuration_update_params.rb', line 139

def enabled
  @enabled
end

#productsObject

The list of up to 10 products that support subscription updates.



141
142
143
# File 'lib/stripe/params/billing_portal/configuration_update_params.rb', line 141

def products
  @products
end

#proration_behaviorObject

Determines how to handle prorations resulting from subscription updates. Valid values are none, create_prorations, and always_invoice.



143
144
145
# File 'lib/stripe/params/billing_portal/configuration_update_params.rb', line 143

def proration_behavior
  @proration_behavior
end

#schedule_at_period_endObject

Setting to control when an update should be scheduled at the end of the period instead of applying immediately.



145
146
147
# File 'lib/stripe/params/billing_portal/configuration_update_params.rb', line 145

def schedule_at_period_end
  @schedule_at_period_end
end

#trial_update_behaviorObject

The behavior when updating a subscription that is trialing.



147
148
149
# File 'lib/stripe/params/billing_portal/configuration_update_params.rb', line 147

def trial_update_behavior
  @trial_update_behavior
end