Class: Stripe::BillingPortal::ConfigurationUpdateParams::Features::SubscriptionUpdate::Product

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/billing_portal/configuration_update_params.rb

Defined Under Namespace

Classes: AdjustableQuantity

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h

Constructor Details

#initialize(adjustable_quantity: nil, prices: nil, product: nil) ⇒ Product

Returns a new instance of Product.



111
112
113
114
115
# File 'lib/stripe/params/billing_portal/configuration_update_params.rb', line 111

def initialize(adjustable_quantity: nil, prices: nil, product: nil)
  @adjustable_quantity = adjustable_quantity
  @prices = prices
  @product = product
end

Instance Attribute Details

#adjustable_quantityObject

Control whether the quantity of the product can be adjusted.



105
106
107
# File 'lib/stripe/params/billing_portal/configuration_update_params.rb', line 105

def adjustable_quantity
  @adjustable_quantity
end

#pricesObject

The list of price IDs for the product that a subscription can be updated to.



107
108
109
# File 'lib/stripe/params/billing_portal/configuration_update_params.rb', line 107

def prices
  @prices
end

#productObject

The product id.



109
110
111
# File 'lib/stripe/params/billing_portal/configuration_update_params.rb', line 109

def product
  @product
end