Class: Stripe::BillingPortal::Session::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/billing_portal/session.rb

Defined Under Namespace

Classes: FlowData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(configuration: nil, customer: nil, expand: nil, flow_data: nil, locale: nil, on_behalf_of: nil, return_url: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
# File 'lib/stripe/resources/billing_portal/session.rb', line 258

def initialize(
  configuration: nil,
  customer: nil,
  expand: nil,
  flow_data: nil,
  locale: nil,
  on_behalf_of: nil,
  return_url: nil
)
  @configuration = configuration
  @customer = customer
  @expand = expand
  @flow_data = flow_data
  @locale = locale
  @on_behalf_of = on_behalf_of
  @return_url = return_url
end

Instance Attribute Details

#configurationObject

The ID of an existing [configuration](stripe.com/docs/api/customer_portal/configuration) to use for this session, describing its functionality and features. If not specified, the session uses the default configuration.



244
245
246
# File 'lib/stripe/resources/billing_portal/session.rb', line 244

def configuration
  @configuration
end

#customerObject

The ID of an existing customer.



246
247
248
# File 'lib/stripe/resources/billing_portal/session.rb', line 246

def customer
  @customer
end

#expandObject

Specifies which fields in the response should be expanded.



248
249
250
# File 'lib/stripe/resources/billing_portal/session.rb', line 248

def expand
  @expand
end

#flow_dataObject

Information about a specific flow for the customer to go through. See the [docs](stripe.com/docs/customer-management/portal-deep-links) to learn more about using customer portal deep links and flows.



250
251
252
# File 'lib/stripe/resources/billing_portal/session.rb', line 250

def flow_data
  @flow_data
end

#localeObject

The IETF language tag of the locale customer portal is displayed in. If blank or auto, the customer’s ‘preferred_locales` or browser’s locale is used.



252
253
254
# File 'lib/stripe/resources/billing_portal/session.rb', line 252

def locale
  @locale
end

#on_behalf_ofObject

The ‘on_behalf_of` account to use for this session. When specified, only subscriptions and invoices with this `on_behalf_of` account appear in the portal. For more information, see the [docs](stripe.com/docs/connect/separate-charges-and-transfers#settlement-merchant). Use the [Accounts API](stripe.com/docs/api/accounts/object#account_object-settings-branding) to modify the `on_behalf_of` account’s branding settings, which the portal displays.



254
255
256
# File 'lib/stripe/resources/billing_portal/session.rb', line 254

def on_behalf_of
  @on_behalf_of
end

#return_urlObject

The default URL to redirect customers to when they click on the portal’s link to return to your website.



256
257
258
# File 'lib/stripe/resources/billing_portal/session.rb', line 256

def return_url
  @return_url
end