Class: Stripe::BillingPortal::Session::CreateParams::FlowData::AfterCompletion::HostedConfirmation
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::BillingPortal::Session::CreateParams::FlowData::AfterCompletion::HostedConfirmation
- Defined in:
- lib/stripe/resources/billing_portal/session.rb
Instance Attribute Summary collapse
-
#custom_message ⇒ Object
A custom message to display to the customer after the flow is completed.
Instance Method Summary collapse
-
#initialize(custom_message: nil) ⇒ HostedConfirmation
constructor
A new instance of HostedConfirmation.
Methods inherited from RequestParams
Constructor Details
#initialize(custom_message: nil) ⇒ HostedConfirmation
Returns a new instance of HostedConfirmation.
111 112 113 |
# File 'lib/stripe/resources/billing_portal/session.rb', line 111 def initialize(custom_message: nil) @custom_message = end |
Instance Attribute Details
#custom_message ⇒ Object
A custom message to display to the customer after the flow is completed.
109 110 111 |
# File 'lib/stripe/resources/billing_portal/session.rb', line 109 def @custom_message end |