Class: Stripe::BillingPortal::Session::CreateParams::FlowData::SubscriptionCancel::Retention
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::BillingPortal::Session::CreateParams::FlowData::SubscriptionCancel::Retention
- Defined in:
- lib/stripe/resources/billing_portal/session.rb
Defined Under Namespace
Classes: CouponOffer
Instance Attribute Summary collapse
-
#coupon_offer ⇒ Object
Configuration when ‘retention.type=coupon_offer`.
-
#type ⇒ Object
Type of retention strategy to use with the customer.
Instance Method Summary collapse
-
#initialize(coupon_offer: nil, type: nil) ⇒ Retention
constructor
A new instance of Retention.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon_offer: nil, type: nil) ⇒ Retention
Returns a new instance of Retention.
169 170 171 172 |
# File 'lib/stripe/resources/billing_portal/session.rb', line 169 def initialize(coupon_offer: nil, type: nil) @coupon_offer = coupon_offer @type = type end |
Instance Attribute Details
#coupon_offer ⇒ Object
Configuration when ‘retention.type=coupon_offer`.
164 165 166 |
# File 'lib/stripe/resources/billing_portal/session.rb', line 164 def coupon_offer @coupon_offer end |
#type ⇒ Object
Type of retention strategy to use with the customer.
167 168 169 |
# File 'lib/stripe/resources/billing_portal/session.rb', line 167 def type @type end |