Class: Stripe::BillingPortal::Session::CreateParams::FlowData::SubscriptionUpdateConfirm::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::BillingPortal::Session::CreateParams::FlowData::SubscriptionUpdateConfirm::Discount
- Defined in:
- lib/stripe/resources/billing_portal/session.rb
Instance Attribute Summary collapse
-
#coupon ⇒ Object
The ID of the coupon to apply to this subscription update.
-
#promotion_code ⇒ Object
The ID of a promotion code to apply to this subscription update.
Instance Method Summary collapse
-
#initialize(coupon: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
278 279 280 281 |
# File 'lib/stripe/resources/billing_portal/session.rb', line 278 def initialize(coupon: nil, promotion_code: nil) @coupon = coupon @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
The ID of the coupon to apply to this subscription update.
274 275 276 |
# File 'lib/stripe/resources/billing_portal/session.rb', line 274 def coupon @coupon end |
#promotion_code ⇒ Object
The ID of a promotion code to apply to this subscription update.
276 277 278 |
# File 'lib/stripe/resources/billing_portal/session.rb', line 276 def promotion_code @promotion_code end |