Class: Stripe::BillingPortal::Session::Flow
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::BillingPortal::Session::Flow
- Defined in:
- lib/stripe/resources/billing_portal/session.rb
Defined Under Namespace
Classes: AfterCompletion, CustomerUpdate, SubscriptionCancel, SubscriptionUpdate, SubscriptionUpdateConfirm
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#after_completion ⇒ Object
readonly
Attribute for field after_completion.
-
#customer_update ⇒ Object
readonly
Configuration when
flow.type=customer_update. -
#subscription_cancel ⇒ Object
readonly
Configuration when
flow.type=subscription_cancel. -
#subscription_update ⇒ Object
readonly
Configuration when
flow.type=subscription_update. -
#subscription_update_confirm ⇒ Object
readonly
Configuration when
flow.type=subscription_update_confirm. -
#type ⇒ Object
readonly
Type of flow that the customer will go through.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#after_completion ⇒ Object (readonly)
Attribute for field after_completion
183 184 185 |
# File 'lib/stripe/resources/billing_portal/session.rb', line 183 def after_completion @after_completion end |
#customer_update ⇒ Object (readonly)
Configuration when flow.type=customer_update.
185 186 187 |
# File 'lib/stripe/resources/billing_portal/session.rb', line 185 def customer_update @customer_update end |
#subscription_cancel ⇒ Object (readonly)
Configuration when flow.type=subscription_cancel.
187 188 189 |
# File 'lib/stripe/resources/billing_portal/session.rb', line 187 def subscription_cancel @subscription_cancel end |
#subscription_update ⇒ Object (readonly)
Configuration when flow.type=subscription_update.
189 190 191 |
# File 'lib/stripe/resources/billing_portal/session.rb', line 189 def subscription_update @subscription_update end |
#subscription_update_confirm ⇒ Object (readonly)
Configuration when flow.type=subscription_update_confirm.
191 192 193 |
# File 'lib/stripe/resources/billing_portal/session.rb', line 191 def subscription_update_confirm @subscription_update_confirm end |
#type ⇒ Object (readonly)
Type of flow that the customer will go through.
193 194 195 |
# File 'lib/stripe/resources/billing_portal/session.rb', line 193 def type @type end |
Class Method Details
.field_remappings ⇒ Object
205 206 207 |
# File 'lib/stripe/resources/billing_portal/session.rb', line 205 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
195 196 197 198 199 200 201 202 203 |
# File 'lib/stripe/resources/billing_portal/session.rb', line 195 def self.inner_class_types @inner_class_types = { after_completion: AfterCompletion, customer_update: CustomerUpdate, subscription_cancel: SubscriptionCancel, subscription_update: SubscriptionUpdate, subscription_update_confirm: SubscriptionUpdateConfirm, } end |