Class: Stripe::BillingPortal::Session::Flow::AfterCompletion
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::BillingPortal::Session::Flow::AfterCompletion
- Defined in:
- lib/stripe/resources/billing_portal/session.rb
Defined Under Namespace
Classes: HostedConfirmation, Redirect
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#hosted_confirmation ⇒ Object
readonly
Configuration when ‘after_completion.type=hosted_confirmation`.
-
#redirect ⇒ Object
readonly
Configuration when ‘after_completion.type=redirect`.
-
#type ⇒ Object
readonly
The specified type of behavior after the flow is completed.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#hosted_confirmation ⇒ Object (readonly)
Configuration when ‘after_completion.type=hosted_confirmation`.
40 41 42 |
# File 'lib/stripe/resources/billing_portal/session.rb', line 40 def hosted_confirmation @hosted_confirmation end |
#redirect ⇒ Object (readonly)
Configuration when ‘after_completion.type=redirect`.
43 44 45 |
# File 'lib/stripe/resources/billing_portal/session.rb', line 43 def redirect @redirect end |
#type ⇒ Object (readonly)
The specified type of behavior after the flow is completed.
46 47 48 |
# File 'lib/stripe/resources/billing_portal/session.rb', line 46 def type @type end |