Class: Stripe::BillingPortal::Session::Flow::SubscriptionUpdateConfirm

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/billing_portal/session.rb

Defined Under Namespace

Classes: Discount, Item

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#discountsObject (readonly)

The coupon or promotion code to apply to this subscription update.



168
169
170
# File 'lib/stripe/resources/billing_portal/session.rb', line 168

def discounts
  @discounts
end

#itemsObject (readonly)

The subscription item to be updated through this flow. Currently, only up to one may be specified and subscriptions with multiple items are not updatable.



170
171
172
# File 'lib/stripe/resources/billing_portal/session.rb', line 170

def items
  @items
end

#subscriptionObject (readonly)

The ID of the subscription to be updated.



172
173
174
# File 'lib/stripe/resources/billing_portal/session.rb', line 172

def subscription
  @subscription
end

Class Method Details

.field_remappingsObject



178
179
180
# File 'lib/stripe/resources/billing_portal/session.rb', line 178

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



174
175
176
# File 'lib/stripe/resources/billing_portal/session.rb', line 174

def self.inner_class_types
  @inner_class_types = { discounts: Discount, items: Item }
end