Class: Stripe::BillingPortal::Session::Flow::SubscriptionUpdateConfirm::Item
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::BillingPortal::Session::Flow::SubscriptionUpdateConfirm::Item
- Defined in:
- lib/stripe/resources/billing_portal/session.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#id ⇒ Object
readonly
The ID of the [subscription item](stripe.com/docs/api/subscriptions/object#subscription_object-items-data-id) to be updated.
-
#price ⇒ Object
readonly
The price the customer should subscribe to through this flow.
-
#quantity ⇒ Object
readonly
[Quantity](stripe.com/docs/subscriptions/quantities) for this item that the customer should subscribe to through this flow.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#id ⇒ Object (readonly)
The ID of the [subscription item](stripe.com/docs/api/subscriptions/object#subscription_object-items-data-id) to be updated.
79 80 81 |
# File 'lib/stripe/resources/billing_portal/session.rb', line 79 def id @id end |
#price ⇒ Object (readonly)
The price the customer should subscribe to through this flow. The price must also be included in the configuration’s [‘features.subscription_update.products`](stripe.com/docs/api/customer_portal/configuration#portal_configuration_object-features-subscription_update-products).
81 82 83 |
# File 'lib/stripe/resources/billing_portal/session.rb', line 81 def price @price end |
#quantity ⇒ Object (readonly)
[Quantity](stripe.com/docs/subscriptions/quantities) for this item that the customer should subscribe to through this flow.
83 84 85 |
# File 'lib/stripe/resources/billing_portal/session.rb', line 83 def quantity @quantity end |