Class: Stripe::BillingPortal::SessionService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::BillingPortal::SessionService::CreateParams
- Defined in:
- lib/stripe/services/billing_portal/session_service.rb
Defined Under Namespace
Classes: FlowData
Instance Attribute Summary collapse
-
#configuration ⇒ Object
The ID of an existing [configuration](stripe.com/docs/api/customer_portal/configuration) to use for this session, describing its functionality and features.
-
#customer ⇒ Object
The ID of an existing customer.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#flow_data ⇒ Object
Information about a specific flow for the customer to go through.
-
#locale ⇒ Object
The IETF language tag of the locale customer portal is displayed in.
-
#on_behalf_of ⇒ Object
The ‘on_behalf_of` account to use for this session.
-
#return_url ⇒ Object
The default URL to redirect customers to when they click on the portal’s link to return to your website.
Instance Method Summary collapse
-
#initialize(configuration: nil, customer: nil, expand: nil, flow_data: nil, locale: nil, on_behalf_of: nil, return_url: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(configuration: nil, customer: nil, expand: nil, flow_data: nil, locale: nil, on_behalf_of: nil, return_url: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'lib/stripe/services/billing_portal/session_service.rb', line 180 def initialize( configuration: nil, customer: nil, expand: nil, flow_data: nil, locale: nil, on_behalf_of: nil, return_url: nil ) @configuration = configuration @customer = customer @expand = @flow_data = flow_data @locale = locale @on_behalf_of = on_behalf_of @return_url = return_url end |
Instance Attribute Details
#configuration ⇒ Object
The ID of an existing [configuration](stripe.com/docs/api/customer_portal/configuration) to use for this session, describing its functionality and features. If not specified, the session uses the default configuration.
160 161 162 |
# File 'lib/stripe/services/billing_portal/session_service.rb', line 160 def configuration @configuration end |
#customer ⇒ Object
The ID of an existing customer.
163 164 165 |
# File 'lib/stripe/services/billing_portal/session_service.rb', line 163 def customer @customer end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
166 167 168 |
# File 'lib/stripe/services/billing_portal/session_service.rb', line 166 def @expand end |
#flow_data ⇒ Object
Information about a specific flow for the customer to go through. See the [docs](stripe.com/docs/customer-management/portal-deep-links) to learn more about using customer portal deep links and flows.
169 170 171 |
# File 'lib/stripe/services/billing_portal/session_service.rb', line 169 def flow_data @flow_data end |
#locale ⇒ Object
The IETF language tag of the locale customer portal is displayed in. If blank or auto, the customer’s ‘preferred_locales` or browser’s locale is used.
172 173 174 |
# File 'lib/stripe/services/billing_portal/session_service.rb', line 172 def locale @locale end |
#on_behalf_of ⇒ Object
The ‘on_behalf_of` account to use for this session. When specified, only subscriptions and invoices with this `on_behalf_of` account appear in the portal. For more information, see the [docs](stripe.com/docs/connect/separate-charges-and-transfers#settlement-merchant). Use the [Accounts API](stripe.com/docs/api/accounts/object#account_object-settings-branding) to modify the `on_behalf_of` account’s branding settings, which the portal displays.
175 176 177 |
# File 'lib/stripe/services/billing_portal/session_service.rb', line 175 def on_behalf_of @on_behalf_of end |
#return_url ⇒ Object
The default URL to redirect customers to when they click on the portal’s link to return to your website.
178 179 180 |
# File 'lib/stripe/services/billing_portal/session_service.rb', line 178 def return_url @return_url end |