Class: Stripe::BillingPortal::SessionService::CreateParams::FlowData::SubscriptionCancel::Retention
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::BillingPortal::SessionService::CreateParams::FlowData::SubscriptionCancel::Retention
- Defined in:
- lib/stripe/services/billing_portal/session_service.rb
Defined Under Namespace
Classes: CouponOffer
Instance Attribute Summary collapse
-
#coupon_offer ⇒ Object
Configuration when ‘retention.type=coupon_offer`.
-
#type ⇒ Object
Type of retention strategy to use with the customer.
Instance Method Summary collapse
-
#initialize(coupon_offer: nil, type: nil) ⇒ Retention
constructor
A new instance of Retention.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon_offer: nil, type: nil) ⇒ Retention
Returns a new instance of Retention.
56 57 58 59 |
# File 'lib/stripe/services/billing_portal/session_service.rb', line 56 def initialize(coupon_offer: nil, type: nil) @coupon_offer = coupon_offer @type = type end |
Instance Attribute Details
#coupon_offer ⇒ Object
Configuration when ‘retention.type=coupon_offer`.
52 53 54 |
# File 'lib/stripe/services/billing_portal/session_service.rb', line 52 def coupon_offer @coupon_offer end |
#type ⇒ Object
Type of retention strategy to use with the customer.
54 55 56 |
# File 'lib/stripe/services/billing_portal/session_service.rb', line 54 def type @type end |