Class: Stripe::BillingPortal::SessionService::CreateParams::FlowData::SubscriptionUpdateConfirm::Item
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::BillingPortal::SessionService::CreateParams::FlowData::SubscriptionUpdateConfirm::Item
- Defined in:
- lib/stripe/services/billing_portal/session_service.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
The ID of the [subscription item](stripe.com/docs/api/subscriptions/object#subscription_object-items-data-id) to be updated.
-
#price ⇒ Object
The price the customer should subscribe to through this flow.
-
#quantity ⇒ Object
[Quantity](stripe.com/docs/subscriptions/quantities) for this item that the customer should subscribe to through this flow.
Instance Method Summary collapse
-
#initialize(id: nil, price: nil, quantity: nil) ⇒ Item
constructor
A new instance of Item.
Methods inherited from RequestParams
Constructor Details
#initialize(id: nil, price: nil, quantity: nil) ⇒ Item
Returns a new instance of Item.
102 103 104 105 106 |
# File 'lib/stripe/services/billing_portal/session_service.rb', line 102 def initialize(id: nil, price: nil, quantity: nil) @id = id @price = price @quantity = quantity end |
Instance Attribute Details
#id ⇒ Object
The ID of the [subscription item](stripe.com/docs/api/subscriptions/object#subscription_object-items-data-id) to be updated.
96 97 98 |
# File 'lib/stripe/services/billing_portal/session_service.rb', line 96 def id @id end |
#price ⇒ Object
The price the customer should subscribe to through this flow. The price must also be included in the configuration’s [‘features.subscription_update.products`](stripe.com/docs/api/customer_portal/configuration#portal_configuration_object-features-subscription_update-products).
98 99 100 |
# File 'lib/stripe/services/billing_portal/session_service.rb', line 98 def price @price end |
#quantity ⇒ Object
[Quantity](stripe.com/docs/subscriptions/quantities) for this item that the customer should subscribe to through this flow.
100 101 102 |
# File 'lib/stripe/services/billing_portal/session_service.rb', line 100 def quantity @quantity end |