Class: Stripe::Capability::Requirements
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Capability::Requirements
- Defined in:
- lib/stripe/resources/capability.rb
Defined Under Namespace
Classes: Alternative, Error
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#alternatives ⇒ Object
readonly
Fields that are due and can be resolved by providing the corresponding alternative fields instead.
-
#current_deadline ⇒ Object
readonly
The date by which all required account information must be both submitted and verified.
-
#currently_due ⇒ Object
readonly
Fields that need to be resolved to keep the capability enabled.
-
#disabled_reason ⇒ Object
readonly
Description of why the capability is disabled.
-
#errors ⇒ Object
readonly
Details about validation and verification failures for ‘due` requirements that must be resolved.
-
#eventually_due ⇒ Object
readonly
Fields you must collect when all thresholds are reached.
-
#past_due ⇒ Object
readonly
Fields that haven’t been resolved by ‘current_deadline`.
-
#pending_verification ⇒ Object
readonly
Fields that are being reviewed, or might become required depending on the results of a review.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#alternatives ⇒ Object (readonly)
Fields that are due and can be resolved by providing the corresponding alternative fields instead. Multiple alternatives can reference the same ‘original_fields_due`. When this happens, any of these alternatives can serve as a pathway for attempting to resolve the fields. Additionally, providing `original_fields_due` again also serves as a pathway for attempting to resolve the fields.
136 137 138 |
# File 'lib/stripe/resources/capability.rb', line 136 def alternatives @alternatives end |
#current_deadline ⇒ Object (readonly)
The date by which all required account information must be both submitted and verified. This includes fields listed in ‘currently_due` as well as those in `pending_verification`. If any required information is missing or unverified by this date, the account may be disabled. Note that `current_deadline` may change if additional `currently_due` requirements are requested.
138 139 140 |
# File 'lib/stripe/resources/capability.rb', line 138 def current_deadline @current_deadline end |
#currently_due ⇒ Object (readonly)
Fields that need to be resolved to keep the capability enabled. If not resolved by ‘current_deadline`, these fields will appear in `past_due` as well, and the capability is disabled.
140 141 142 |
# File 'lib/stripe/resources/capability.rb', line 140 def currently_due @currently_due end |
#disabled_reason ⇒ Object (readonly)
Description of why the capability is disabled. [Learn more about handling verification issues](docs.stripe.com/connect/handling-api-verification).
142 143 144 |
# File 'lib/stripe/resources/capability.rb', line 142 def disabled_reason @disabled_reason end |
#errors ⇒ Object (readonly)
Details about validation and verification failures for ‘due` requirements that must be resolved.
144 145 146 |
# File 'lib/stripe/resources/capability.rb', line 144 def errors @errors end |
#eventually_due ⇒ Object (readonly)
Fields you must collect when all thresholds are reached. As they become required, they appear in ‘currently_due` as well, and `current_deadline` becomes set.
146 147 148 |
# File 'lib/stripe/resources/capability.rb', line 146 def eventually_due @eventually_due end |
#past_due ⇒ Object (readonly)
Fields that haven’t been resolved by ‘current_deadline`. These fields need to be resolved to enable the capability on the account.
148 149 150 |
# File 'lib/stripe/resources/capability.rb', line 148 def past_due @past_due end |
#pending_verification ⇒ Object (readonly)
Fields that are being reviewed, or might become required depending on the results of a review. If the review fails, these fields can move to ‘eventually_due`, `currently_due`, `past_due` or `alternatives`. Fields might appear in `eventually_due`, `currently_due`, `past_due` or `alternatives` and in `pending_verification` if one verification fails but another is still pending.
150 151 152 |
# File 'lib/stripe/resources/capability.rb', line 150 def pending_verification @pending_verification end |
Class Method Details
.field_remappings ⇒ Object
156 157 158 |
# File 'lib/stripe/resources/capability.rb', line 156 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
152 153 154 |
# File 'lib/stripe/resources/capability.rb', line 152 def self.inner_class_types @inner_class_types = { alternatives: Alternative, errors: Error } end |