Class: Stripe::Capital::FinancingOffer::AcceptedTerms

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/capital/financing_offer.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#advance_amountObject (readonly)

Amount of financing offered, in minor units. For example, 1,000 USD is represented as 100000.



18
19
20
# File 'lib/stripe/resources/capital/financing_offer.rb', line 18

def advance_amount
  @advance_amount
end

#currencyObject (readonly)

Currency that the financing offer is transacted in. For example, ‘usd`.



20
21
22
# File 'lib/stripe/resources/capital/financing_offer.rb', line 20

def currency
  @currency
end

#fee_amountObject (readonly)

Fixed fee amount, in minor units. For example, 100 USD is represented as 10000.



22
23
24
# File 'lib/stripe/resources/capital/financing_offer.rb', line 22

def fee_amount
  @fee_amount
end

#previous_financing_fee_discount_amountObject (readonly)

Populated when the ‘product_type` of the `financingoffer` is `refill`. Represents the discount amount on remaining premium for the existing loan at payout time.



25
26
27
# File 'lib/stripe/resources/capital/financing_offer.rb', line 25

def previous_financing_fee_discount_amount
  @previous_financing_fee_discount_amount
end

#withhold_rateObject (readonly)

Per-transaction rate at which Stripe withholds funds to repay the financing.



27
28
29
# File 'lib/stripe/resources/capital/financing_offer.rb', line 27

def withhold_rate
  @withhold_rate
end

Class Method Details

.field_remappingsObject



33
34
35
# File 'lib/stripe/resources/capital/financing_offer.rb', line 33

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



29
30
31
# File 'lib/stripe/resources/capital/financing_offer.rb', line 29

def self.inner_class_types
  @inner_class_types = {}
end