Class: Stripe::Capital::FinancingOffer::ListParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/capital/financing_offer.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(connected_account: nil, created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, status: nil) ⇒ ListParams

Returns a new instance of ListParams.



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/stripe/resources/capital/financing_offer.rb', line 97

def initialize(
  connected_account: nil,
  created: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  starting_after: nil,
  status: nil
)
  @connected_account = 
  @created = created
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
  @status = status
end

Instance Attribute Details

#connected_accountObject

limit list to offers belonging to given connected account



83
84
85
# File 'lib/stripe/resources/capital/financing_offer.rb', line 83

def 
  @connected_account
end

#createdObject

Only return offers that were created during the given date interval.



85
86
87
# File 'lib/stripe/resources/capital/financing_offer.rb', line 85

def created
  @created
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



87
88
89
# File 'lib/stripe/resources/capital/financing_offer.rb', line 87

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



89
90
91
# File 'lib/stripe/resources/capital/financing_offer.rb', line 89

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



91
92
93
# File 'lib/stripe/resources/capital/financing_offer.rb', line 91

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



93
94
95
# File 'lib/stripe/resources/capital/financing_offer.rb', line 93

def starting_after
  @starting_after
end

#statusObject

limit list to offers with given status



95
96
97
# File 'lib/stripe/resources/capital/financing_offer.rb', line 95

def status
  @status
end