Class: Stripe::Capital::FinancingOffer::MarkDeliveredParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Capital::FinancingOffer::MarkDeliveredParams
- Defined in:
- lib/stripe/resources/capital/financing_offer.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ MarkDeliveredParams
constructor
A new instance of MarkDeliveredParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ MarkDeliveredParams
Returns a new instance of MarkDeliveredParams.
104 105 106 |
# File 'lib/stripe/resources/capital/financing_offer.rb', line 104 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
102 103 104 |
# File 'lib/stripe/resources/capital/financing_offer.rb', line 102 def @expand end |