Class: Stripe::Capital::FinancingOffer::OfferedTerms

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/capital/financing_offer.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#advance_amountObject (readonly)

Amount of financing offered, in minor units. For example, 1,000 USD is represented as 100000.



40
41
42
# File 'lib/stripe/resources/capital/financing_offer.rb', line 40

def advance_amount
  @advance_amount
end

#campaign_typeObject (readonly)

Describes the type of user the offer is being extended to.



42
43
44
# File 'lib/stripe/resources/capital/financing_offer.rb', line 42

def campaign_type
  @campaign_type
end

#currencyObject (readonly)

Currency that the financing offer is transacted in. For example, ‘usd`.



44
45
46
# File 'lib/stripe/resources/capital/financing_offer.rb', line 44

def currency
  @currency
end

#fee_amountObject (readonly)

Fixed fee amount, in minor units. For example, 100 USD is represented as 10000.



46
47
48
# File 'lib/stripe/resources/capital/financing_offer.rb', line 46

def fee_amount
  @fee_amount
end

#previous_financing_fee_discount_rateObject (readonly)

Populated when the ‘product_type` of the `financingoffer` is `refill`. Represents the discount rate percentage on remaining fee on the existing loan. When the `financing_offer` is paid out, the `previous_financing_fee_discount_amount` will be computed as the multiple of this rate and the remaining fee.



51
52
53
# File 'lib/stripe/resources/capital/financing_offer.rb', line 51

def previous_financing_fee_discount_rate
  @previous_financing_fee_discount_rate
end

#withhold_rateObject (readonly)

Per-transaction rate at which Stripe withholds funds to repay the financing.



53
54
55
# File 'lib/stripe/resources/capital/financing_offer.rb', line 53

def withhold_rate
  @withhold_rate
end

Class Method Details

.field_remappingsObject



59
60
61
# File 'lib/stripe/resources/capital/financing_offer.rb', line 59

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



55
56
57
# File 'lib/stripe/resources/capital/financing_offer.rb', line 55

def self.inner_class_types
  @inner_class_types = {}
end