Class: Stripe::Capital::FinancingOfferService

Inherits:
StripeService show all
Defined in:
lib/stripe/services/capital/financing_offer_service.rb

Instance Method Summary collapse

Methods inherited from StripeService

#initialize, #request, #request_stream

Constructor Details

This class inherits a constructor from Stripe::StripeService

Instance Method Details

#list(params = {}, opts = {}) ⇒ Object

Retrieves the financing offers available for Connected accounts that belong to your platform.



8
9
10
11
12
13
14
15
16
# File 'lib/stripe/services/capital/financing_offer_service.rb', line 8

def list(params = {}, opts = {})
  request(
    method: :get,
    path: "/v1/capital/financing_offers",
    params: params,
    opts: opts,
    base_address: :api
  )
end

#mark_delivered(financing_offer, params = {}, opts = {}) ⇒ Object

Acknowledges that platform has received and delivered the financing_offer to the intended merchant recipient.



20
21
22
23
24
25
26
27
28
# File 'lib/stripe/services/capital/financing_offer_service.rb', line 20

def mark_delivered(financing_offer, params = {}, opts = {})
  request(
    method: :post,
    path: format("/v1/capital/financing_offers/%<financing_offer>s/mark_delivered", { financing_offer: CGI.escape(financing_offer) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end

#retrieve(financing_offer, params = {}, opts = {}) ⇒ Object

Get the details of the financing offer



31
32
33
34
35
36
37
38
39
# File 'lib/stripe/services/capital/financing_offer_service.rb', line 31

def retrieve(financing_offer, params = {}, opts = {})
  request(
    method: :get,
    path: format("/v1/capital/financing_offers/%<financing_offer>s", { financing_offer: CGI.escape(financing_offer) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end