Class: Stripe::Capital::FinancingOfferService::ListParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/capital/financing_offer_service.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(connected_account: nil, created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, status: nil) ⇒ ListParams

Returns a new instance of ListParams.



49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
# File 'lib/stripe/services/capital/financing_offer_service.rb', line 49

def initialize(
  connected_account: nil,
  created: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  starting_after: nil,
  status: nil
)
  @connected_account = 
  @created = created
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
  @status = status
end

Instance Attribute Details

#connected_accountObject

limit list to offers belonging to given connected account



29
30
31
# File 'lib/stripe/services/capital/financing_offer_service.rb', line 29

def 
  @connected_account
end

#createdObject

Only return offers that were created during the given date interval.



32
33
34
# File 'lib/stripe/services/capital/financing_offer_service.rb', line 32

def created
  @created
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



35
36
37
# File 'lib/stripe/services/capital/financing_offer_service.rb', line 35

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



38
39
40
# File 'lib/stripe/services/capital/financing_offer_service.rb', line 38

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



41
42
43
# File 'lib/stripe/services/capital/financing_offer_service.rb', line 41

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



44
45
46
# File 'lib/stripe/services/capital/financing_offer_service.rb', line 44

def starting_after
  @starting_after
end

#statusObject

limit list to offers with given status



47
48
49
# File 'lib/stripe/services/capital/financing_offer_service.rb', line 47

def status
  @status
end