Class: Stripe::Capital::FinancingSummary::Details
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Capital::FinancingSummary::Details
- Defined in:
- lib/stripe/resources/capital/financing_summary.rb
Defined Under Namespace
Classes: CurrentRepaymentInterval
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#advance_amount ⇒ Object
readonly
Amount of financing offered, in minor units.
-
#advance_paid_out_at ⇒ Object
readonly
The time at which the funds were paid out to the connected account’s Stripe balance.
-
#currency ⇒ Object
readonly
Currency that the financing offer is transacted in.
-
#current_repayment_interval ⇒ Object
readonly
The chronologically current repayment interval for the financing offer.
-
#fee_amount ⇒ Object
readonly
Fixed fee amount, in minor units.
-
#paid_amount ⇒ Object
readonly
The amount the Connected account has paid toward the financing debt so far, in minor units.
-
#remaining_amount ⇒ Object
readonly
The balance remaining to be paid on the financing, in minor units.
-
#repayments_begin_at ⇒ Object
readonly
The time at which Capital will begin withholding from payments.
-
#withhold_rate ⇒ Object
readonly
Per-transaction rate at which Stripe withholds funds to repay the financing.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#advance_amount ⇒ Object (readonly)
Amount of financing offered, in minor units. For example, 1,000 USD is represented as 100000.
34 35 36 |
# File 'lib/stripe/resources/capital/financing_summary.rb', line 34 def advance_amount @advance_amount end |
#advance_paid_out_at ⇒ Object (readonly)
The time at which the funds were paid out to the connected account’s Stripe balance. Given in milliseconds since unix epoch.
36 37 38 |
# File 'lib/stripe/resources/capital/financing_summary.rb', line 36 def advance_paid_out_at @advance_paid_out_at end |
#currency ⇒ Object (readonly)
Currency that the financing offer is transacted in. For example, ‘usd`.
38 39 40 |
# File 'lib/stripe/resources/capital/financing_summary.rb', line 38 def currency @currency end |
#current_repayment_interval ⇒ Object (readonly)
The chronologically current repayment interval for the financing offer.
40 41 42 |
# File 'lib/stripe/resources/capital/financing_summary.rb', line 40 def current_repayment_interval @current_repayment_interval end |
#fee_amount ⇒ Object (readonly)
Fixed fee amount, in minor units. For example, 100 USD is represented as 10000.
42 43 44 |
# File 'lib/stripe/resources/capital/financing_summary.rb', line 42 def fee_amount @fee_amount end |
#paid_amount ⇒ Object (readonly)
The amount the Connected account has paid toward the financing debt so far, in minor units. For example, 1,000 USD is represented as 100000.
44 45 46 |
# File 'lib/stripe/resources/capital/financing_summary.rb', line 44 def paid_amount @paid_amount end |
#remaining_amount ⇒ Object (readonly)
The balance remaining to be paid on the financing, in minor units. For example, 1,000 USD is represented as 100000.
46 47 48 |
# File 'lib/stripe/resources/capital/financing_summary.rb', line 46 def remaining_amount @remaining_amount end |
#repayments_begin_at ⇒ Object (readonly)
The time at which Capital will begin withholding from payments. Given in seconds since unix epoch.
48 49 50 |
# File 'lib/stripe/resources/capital/financing_summary.rb', line 48 def repayments_begin_at @repayments_begin_at end |
#withhold_rate ⇒ Object (readonly)
Per-transaction rate at which Stripe withholds funds to repay the financing.
50 51 52 |
# File 'lib/stripe/resources/capital/financing_summary.rb', line 50 def withhold_rate @withhold_rate end |
Class Method Details
.field_remappings ⇒ Object
56 57 58 |
# File 'lib/stripe/resources/capital/financing_summary.rb', line 56 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
52 53 54 |
# File 'lib/stripe/resources/capital/financing_summary.rb', line 52 def self.inner_class_types @inner_class_types = { current_repayment_interval: CurrentRepaymentInterval } end |