Class: Stripe::Capital::FinancingSummary::Details::CurrentRepaymentInterval
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Capital::FinancingSummary::Details::CurrentRepaymentInterval
- Defined in:
- lib/stripe/resources/capital/financing_summary.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#due_at ⇒ Object
readonly
The time at which the minimum payment amount will be due.
-
#paid_amount ⇒ Object
readonly
The amount that has already been paid in the current repayment interval, in minor units.
-
#remaining_amount ⇒ Object
readonly
The amount that is yet to be paid in the current repayment interval, in minor units.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#due_at ⇒ Object (readonly)
The time at which the minimum payment amount will be due. If not met through withholding, the Connected account’s linked bank account or account balance will be debited. Given in seconds since unix epoch.
19 20 21 |
# File 'lib/stripe/resources/capital/financing_summary.rb', line 19 def due_at @due_at end |
#paid_amount ⇒ Object (readonly)
The amount that has already been paid in the current repayment interval, in minor units. For example, 100 USD is represented as 10000.
21 22 23 |
# File 'lib/stripe/resources/capital/financing_summary.rb', line 21 def paid_amount @paid_amount end |
#remaining_amount ⇒ Object (readonly)
The amount that is yet to be paid in the current repayment interval, in minor units. For example, 100 USD is represented as 10000.
23 24 25 |
# File 'lib/stripe/resources/capital/financing_summary.rb', line 23 def remaining_amount @remaining_amount end |
Class Method Details
.field_remappings ⇒ Object
29 30 31 |
# File 'lib/stripe/resources/capital/financing_summary.rb', line 29 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
25 26 27 |
# File 'lib/stripe/resources/capital/financing_summary.rb', line 25 def self.inner_class_types @inner_class_types = {} end |