Class: Stripe::Capital::FinancingTransaction
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Capital::FinancingTransaction
- Extended by:
- APIOperations::List
- Defined in:
- lib/stripe/resources/capital/financing_transaction.rb
Overview
This is an object representing the details of a transaction on a Capital financing object.
Defined Under Namespace
Classes: Details
Constant Summary collapse
- OBJECT_NAME =
"capital.financing_transaction"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account ⇒ Object
readonly
The ID of the merchant associated with this financing transaction.
-
#created_at ⇒ Object
readonly
Time at which the financing transaction was created.
-
#details ⇒ Object
readonly
This is an object representing a transaction on a Capital financing offer.
-
#financing_offer ⇒ Object
readonly
The Capital financing offer for this financing transaction.
-
#id ⇒ Object
readonly
A unique identifier for the financing transaction object.
-
#legacy_balance_transaction_source ⇒ Object
readonly
The Capital transaction object that predates the Financing Transactions API and corresponds with the balance transaction that was created as a result of this financing transaction.
-
#livemode ⇒ Object
readonly
If the object exists in live mode, the value is ‘true`.
-
#object ⇒ Object
readonly
The object type: financing_transaction.
-
#type ⇒ Object
readonly
The type of the financing transaction.
-
#user_facing_description ⇒ Object
readonly
A human-friendly description of the financing transaction.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
-
.list(params = {}, opts = {}) ⇒ Object
Returns a list of financing transactions.
- .object_name ⇒ Object
Methods included from APIOperations::List
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account ⇒ Object (readonly)
The ID of the merchant associated with this financing transaction.
57 58 59 |
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 57 def account @account end |
#created_at ⇒ Object (readonly)
Time at which the financing transaction was created. Given in seconds since unix epoch.
59 60 61 |
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 59 def created_at @created_at end |
#details ⇒ Object (readonly)
This is an object representing a transaction on a Capital financing offer.
61 62 63 |
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 61 def details @details end |
#financing_offer ⇒ Object (readonly)
The Capital financing offer for this financing transaction.
63 64 65 |
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 63 def financing_offer @financing_offer end |
#id ⇒ Object (readonly)
A unique identifier for the financing transaction object.
65 66 67 |
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 65 def id @id end |
#legacy_balance_transaction_source ⇒ Object (readonly)
The Capital transaction object that predates the Financing Transactions API and corresponds with the balance transaction that was created as a result of this financing transaction.
69 70 71 |
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 69 def legacy_balance_transaction_source @legacy_balance_transaction_source end |
#livemode ⇒ Object (readonly)
If the object exists in live mode, the value is ‘true`. If the object exists in test mode, the value is `false`.
71 72 73 |
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 71 def livemode @livemode end |
#object ⇒ Object (readonly)
The object type: financing_transaction
73 74 75 |
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 73 def object @object end |
#type ⇒ Object (readonly)
The type of the financing transaction.
75 76 77 |
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 75 def type @type end |
#user_facing_description ⇒ Object (readonly)
A human-friendly description of the financing transaction.
77 78 79 |
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 77 def user_facing_description @user_facing_description end |
Class Method Details
.field_remappings ⇒ Object
94 95 96 |
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 94 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
90 91 92 |
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 90 def self.inner_class_types @inner_class_types = { details: Details } end |
.list(params = {}, opts = {}) ⇒ Object
Returns a list of financing transactions. The transactions are returned in sorted order, with the most recent transactions appearing first.
81 82 83 84 85 86 87 88 |
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 81 def self.list(params = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/capital/financing_transactions", params: params, opts: opts ) end |
.object_name ⇒ Object
11 12 13 |
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 11 def self.object_name "capital.financing_transaction" end |