Class: Stripe::Capital::FinancingTransaction::ListParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/capital/financing_transaction.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(charge: nil, ending_before: nil, expand: nil, financing_offer: nil, limit: nil, reversed_transaction: nil, starting_after: nil, treasury_transaction: nil) ⇒ ListParams

Returns a new instance of ListParams.



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 75

def initialize(
  charge: nil,
  ending_before: nil,
  expand: nil,
  financing_offer: nil,
  limit: nil,
  reversed_transaction: nil,
  starting_after: nil,
  treasury_transaction: nil
)
  @charge = charge
  @ending_before = ending_before
  @expand = expand
  @financing_offer = financing_offer
  @limit = limit
  @reversed_transaction = reversed_transaction
  @starting_after = starting_after
  @treasury_transaction = treasury_transaction
end

Instance Attribute Details

#chargeObject

For transactions of type ‘paydown` and reason `automatic_withholding` only, only returns transactions that were created as a result of this charge.



59
60
61
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 59

def charge
  @charge
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



61
62
63
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 61

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



63
64
65
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 63

def expand
  @expand
end

#financing_offerObject

Returns transactions that were created that apply to this financing offer ID.



65
66
67
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 65

def financing_offer
  @financing_offer
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



67
68
69
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 67

def limit
  @limit
end

#reversed_transactionObject

Only returns transactions that are responsible for reversing this financing transaction ID.



69
70
71
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 69

def reversed_transaction
  @reversed_transaction
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



71
72
73
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 71

def starting_after
  @starting_after
end

#treasury_transactionObject

For transactions of type ‘paydown` and reason `automatic_withholding` only, only returns transactions that were created as a result of this Treasury Transaction.



73
74
75
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 73

def treasury_transaction
  @treasury_transaction
end