Class: Stripe::Capital::FinancingTransactionRetrieveParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Capital::FinancingTransactionRetrieveParams
- Defined in:
- lib/stripe/params/capital/financing_transaction_retrieve_params.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ FinancingTransactionRetrieveParams
constructor
A new instance of FinancingTransactionRetrieveParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(expand: nil) ⇒ FinancingTransactionRetrieveParams
Returns a new instance of FinancingTransactionRetrieveParams.
10 11 12 |
# File 'lib/stripe/params/capital/financing_transaction_retrieve_params.rb', line 10 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
8 9 10 |
# File 'lib/stripe/params/capital/financing_transaction_retrieve_params.rb', line 8 def @expand end |