Class: Stripe::Capital::FinancingTransactionService::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Capital::FinancingTransactionService::ListParams
- Defined in:
- lib/stripe/services/capital/financing_transaction_service.rb
Instance Attribute Summary collapse
-
#charge ⇒ Object
For transactions of type ‘paydown` and reason `automatic_withholding` only, only returns transactions that were created as a result of this charge.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#financing_offer ⇒ Object
Returns transactions that were created that apply to this financing offer ID.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#reversed_transaction ⇒ Object
Only returns transactions that are responsible for reversing this financing transaction ID.
-
#starting_after ⇒ Object
A cursor for use in pagination.
-
#treasury_transaction ⇒ Object
For transactions of type ‘paydown` and reason `automatic_withholding` only, only returns transactions that were created as a result of this Treasury Transaction.
Instance Method Summary collapse
-
#initialize(charge: nil, ending_before: nil, expand: nil, financing_offer: nil, limit: nil, reversed_transaction: nil, starting_after: nil, treasury_transaction: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(charge: nil, ending_before: nil, expand: nil, financing_offer: nil, limit: nil, reversed_transaction: nil, starting_after: nil, treasury_transaction: nil) ⇒ ListParams
Returns a new instance of ListParams.
25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 |
# File 'lib/stripe/services/capital/financing_transaction_service.rb', line 25 def initialize( charge: nil, ending_before: nil, expand: nil, financing_offer: nil, limit: nil, reversed_transaction: nil, starting_after: nil, treasury_transaction: nil ) @charge = charge @ending_before = ending_before @expand = @financing_offer = financing_offer @limit = limit @reversed_transaction = reversed_transaction @starting_after = starting_after @treasury_transaction = treasury_transaction end |
Instance Attribute Details
#charge ⇒ Object
For transactions of type ‘paydown` and reason `automatic_withholding` only, only returns transactions that were created as a result of this charge.
9 10 11 |
# File 'lib/stripe/services/capital/financing_transaction_service.rb', line 9 def charge @charge end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
11 12 13 |
# File 'lib/stripe/services/capital/financing_transaction_service.rb', line 11 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
13 14 15 |
# File 'lib/stripe/services/capital/financing_transaction_service.rb', line 13 def @expand end |
#financing_offer ⇒ Object
Returns transactions that were created that apply to this financing offer ID.
15 16 17 |
# File 'lib/stripe/services/capital/financing_transaction_service.rb', line 15 def financing_offer @financing_offer end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
17 18 19 |
# File 'lib/stripe/services/capital/financing_transaction_service.rb', line 17 def limit @limit end |
#reversed_transaction ⇒ Object
Only returns transactions that are responsible for reversing this financing transaction ID.
19 20 21 |
# File 'lib/stripe/services/capital/financing_transaction_service.rb', line 19 def reversed_transaction @reversed_transaction end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
21 22 23 |
# File 'lib/stripe/services/capital/financing_transaction_service.rb', line 21 def starting_after @starting_after end |
#treasury_transaction ⇒ Object
For transactions of type ‘paydown` and reason `automatic_withholding` only, only returns transactions that were created as a result of this Treasury Transaction.
23 24 25 |
# File 'lib/stripe/services/capital/financing_transaction_service.rb', line 23 def treasury_transaction @treasury_transaction end |