Class: Stripe::Charge::CaptureParams::PaymentDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Defined Under Namespace

Classes: CarRental, EventDetails, Flight, Lodging, Subscription

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails

Returns a new instance of PaymentDetails.



3056
3057
3058
3059
3060
3061
3062
3063
3064
3065
3066
3067
3068
3069
3070
3071
3072
# File 'lib/stripe/resources/charge.rb', line 3056

def initialize(
  car_rental: nil,
  customer_reference: nil,
  event_details: nil,
  flight: nil,
  lodging: nil,
  order_reference: nil,
  subscription: nil
)
  @car_rental = car_rental
  @customer_reference = customer_reference
  @event_details = event_details
  @flight = flight
  @lodging = lodging
  @order_reference = order_reference
  @subscription = subscription
end

Instance Attribute Details

#car_rentalObject

Car rental details for this PaymentIntent.



3042
3043
3044
# File 'lib/stripe/resources/charge.rb', line 3042

def car_rental
  @car_rental
end

#customer_referenceObject

Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.



3044
3045
3046
# File 'lib/stripe/resources/charge.rb', line 3044

def customer_reference
  @customer_reference
end

#event_detailsObject

Event details for this PaymentIntent



3046
3047
3048
# File 'lib/stripe/resources/charge.rb', line 3046

def event_details
  @event_details
end

#flightObject

Flight reservation details for this PaymentIntent



3048
3049
3050
# File 'lib/stripe/resources/charge.rb', line 3048

def flight
  @flight
end

#lodgingObject

Lodging reservation details for this PaymentIntent



3050
3051
3052
# File 'lib/stripe/resources/charge.rb', line 3050

def lodging
  @lodging
end

#order_referenceObject

A unique value assigned by the business to identify the transaction.



3052
3053
3054
# File 'lib/stripe/resources/charge.rb', line 3052

def order_reference
  @order_reference
end

#subscriptionObject

Subscription details for this PaymentIntent



3054
3055
3056
# File 'lib/stripe/resources/charge.rb', line 3054

def subscription
  @subscription
end