Class: Stripe::Charge::CaptureParams::PaymentDetails::CarRental::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::CaptureParams::PaymentDetails::CarRental::Delivery::Recipient
- Defined in:
- lib/stripe/resources/charge.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
2357 2358 2359 2360 2361 |
# File 'lib/stripe/resources/charge.rb', line 2357 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
2351 2352 2353 |
# File 'lib/stripe/resources/charge.rb', line 2351 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
2353 2354 2355 |
# File 'lib/stripe/resources/charge.rb', line 2353 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
2355 2356 2357 |
# File 'lib/stripe/resources/charge.rb', line 2355 def phone @phone end |