Class: Stripe::Charge::CaptureParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::CaptureParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
3700 3701 3702 3703 3704 3705 3706 3707 3708 3709 3710 3711 3712 3713 3714 3715 3716 3717 3718 3719 3720 |
# File 'lib/stripe/resources/charge.rb', line 3700 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
3682 3683 3684 |
# File 'lib/stripe/resources/charge.rb', line 3682 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
3684 3685 3686 |
# File 'lib/stripe/resources/charge.rb', line 3684 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
3686 3687 3688 |
# File 'lib/stripe/resources/charge.rb', line 3686 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
3688 3689 3690 |
# File 'lib/stripe/resources/charge.rb', line 3688 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
3690 3691 3692 |
# File 'lib/stripe/resources/charge.rb', line 3690 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
3692 3693 3694 |
# File 'lib/stripe/resources/charge.rb', line 3692 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
3694 3695 3696 |
# File 'lib/stripe/resources/charge.rb', line 3694 def genre @genre end |
#name ⇒ Object
The name of the event.
3696 3697 3698 |
# File 'lib/stripe/resources/charge.rb', line 3696 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
3698 3699 3700 |
# File 'lib/stripe/resources/charge.rb', line 3698 def starts_at @starts_at end |