Class: Stripe::Charge::CaptureParams::PaymentDetails::EventDetails::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



2647
2648
2649
2650
2651
# File 'lib/stripe/resources/charge.rb', line 2647

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



2641
2642
2643
# File 'lib/stripe/resources/charge.rb', line 2641

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



2643
2644
2645
# File 'lib/stripe/resources/charge.rb', line 2643

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



2645
2646
2647
# File 'lib/stripe/resources/charge.rb', line 2645

def phone
  @phone
end