Class: Stripe::Charge::CaptureParams::PaymentDetails::Flight::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



3742
3743
3744
3745
3746
# File 'lib/stripe/resources/charge.rb', line 3742

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



3736
3737
3738
# File 'lib/stripe/resources/charge.rb', line 3736

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



3738
3739
3740
# File 'lib/stripe/resources/charge.rb', line 3738

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



3740
3741
3742
# File 'lib/stripe/resources/charge.rb', line 3740

def phone
  @phone
end