Class: Stripe::Charge::CaptureParams::PaymentDetails::Lodging

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Defined Under Namespace

Classes: Address, Affiliate, Delivery, Passenger

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging

Returns a new instance of Lodging.



3962
3963
3964
3965
3966
3967
3968
3969
3970
3971
3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
4001
4002
4003
4004
4005
4006
# File 'lib/stripe/resources/charge.rb', line 3962

def initialize(
  address: nil,
  adults: nil,
  affiliate: nil,
  booking_number: nil,
  category: nil,
  checkin_at: nil,
  checkout_at: nil,
  customer_service_phone_number: nil,
  daily_room_rate_amount: nil,
  delivery: nil,
  extra_charges: nil,
  fire_safety_act_compliance: nil,
  name: nil,
  no_show: nil,
  number_of_rooms: nil,
  passengers: nil,
  property_phone_number: nil,
  room_class: nil,
  room_nights: nil,
  total_room_tax_amount: nil,
  total_tax_amount: nil
)
  @address = address
  @adults = adults
  @affiliate = affiliate
  @booking_number = booking_number
  @category = category
  @checkin_at = checkin_at
  @checkout_at = checkout_at
  @customer_service_phone_number = customer_service_phone_number
  @daily_room_rate_amount = daily_room_rate_amount
  @delivery = delivery
  @extra_charges = extra_charges
  @fire_safety_act_compliance = fire_safety_act_compliance
  @name = name
  @no_show = no_show
  @number_of_rooms = number_of_rooms
  @passengers = passengers
  @property_phone_number = property_phone_number
  @room_class = room_class
  @room_nights = room_nights
  @total_room_tax_amount = total_room_tax_amount
  @total_tax_amount = total_tax_amount
end

Instance Attribute Details

#addressObject

The lodging location’s address.



3920
3921
3922
# File 'lib/stripe/resources/charge.rb', line 3920

def address
  @address
end

#adultsObject

The number of adults on the booking



3922
3923
3924
# File 'lib/stripe/resources/charge.rb', line 3922

def adults
  @adults
end

#affiliateObject

Affiliate details for this purchase.



3924
3925
3926
# File 'lib/stripe/resources/charge.rb', line 3924

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the lodging reservation.



3926
3927
3928
# File 'lib/stripe/resources/charge.rb', line 3926

def booking_number
  @booking_number
end

#categoryObject

The lodging category



3928
3929
3930
# File 'lib/stripe/resources/charge.rb', line 3928

def category
  @category
end

#checkin_atObject

Lodging check-in time. Measured in seconds since the Unix epoch.



3930
3931
3932
# File 'lib/stripe/resources/charge.rb', line 3930

def checkin_at
  @checkin_at
end

#checkout_atObject

Lodging check-out time. Measured in seconds since the Unix epoch.



3932
3933
3934
# File 'lib/stripe/resources/charge.rb', line 3932

def checkout_at
  @checkout_at
end

#customer_service_phone_numberObject

The customer service phone number of the lodging company.



3934
3935
3936
# File 'lib/stripe/resources/charge.rb', line 3934

def customer_service_phone_number
  @customer_service_phone_number
end

#daily_room_rate_amountObject

The daily lodging room rate.



3936
3937
3938
# File 'lib/stripe/resources/charge.rb', line 3936

def daily_room_rate_amount
  @daily_room_rate_amount
end

#deliveryObject

Delivery details for this purchase.



3938
3939
3940
# File 'lib/stripe/resources/charge.rb', line 3938

def delivery
  @delivery
end

#extra_chargesObject

List of additional charges being billed.



3940
3941
3942
# File 'lib/stripe/resources/charge.rb', line 3940

def extra_charges
  @extra_charges
end

#fire_safety_act_complianceObject

Indicates whether the lodging location is compliant with the Fire Safety Act.



3942
3943
3944
# File 'lib/stripe/resources/charge.rb', line 3942

def fire_safety_act_compliance
  @fire_safety_act_compliance
end

#nameObject

The name of the lodging location.



3944
3945
3946
# File 'lib/stripe/resources/charge.rb', line 3944

def name
  @name
end

#no_showObject

Indicates if the customer did not keep their booking while failing to cancel the reservation.



3946
3947
3948
# File 'lib/stripe/resources/charge.rb', line 3946

def no_show
  @no_show
end

#number_of_roomsObject

The number of rooms on the booking



3948
3949
3950
# File 'lib/stripe/resources/charge.rb', line 3948

def number_of_rooms
  @number_of_rooms
end

#passengersObject

The details of the passengers in the travel reservation



3950
3951
3952
# File 'lib/stripe/resources/charge.rb', line 3950

def passengers
  @passengers
end

#property_phone_numberObject

The phone number of the lodging location.



3952
3953
3954
# File 'lib/stripe/resources/charge.rb', line 3952

def property_phone_number
  @property_phone_number
end

#room_classObject

The room class for this purchase.



3954
3955
3956
# File 'lib/stripe/resources/charge.rb', line 3954

def room_class
  @room_class
end

#room_nightsObject

The number of room nights



3956
3957
3958
# File 'lib/stripe/resources/charge.rb', line 3956

def room_nights
  @room_nights
end

#total_room_tax_amountObject

The total tax amount associating with the room reservation.



3958
3959
3960
# File 'lib/stripe/resources/charge.rb', line 3958

def total_room_tax_amount
  @total_room_tax_amount
end

#total_tax_amountObject

The total tax amount



3960
3961
3962
# File 'lib/stripe/resources/charge.rb', line 3960

def total_tax_amount
  @total_tax_amount
end