Class: Stripe::Charge::CaptureParams::PaymentDetails::Lodging::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



3894
3895
3896
3897
3898
# File 'lib/stripe/resources/charge.rb', line 3894

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



3888
3889
3890
# File 'lib/stripe/resources/charge.rb', line 3888

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



3890
3891
3892
# File 'lib/stripe/resources/charge.rb', line 3890

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



3892
3893
3894
# File 'lib/stripe/resources/charge.rb', line 3892

def phone
  @phone
end