Class: Stripe::Charge::CaptureParams::TransferData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::CaptureParams::TransferData
- Defined in:
- lib/stripe/resources/charge.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount transferred to the destination account, if specified.
Instance Method Summary collapse
-
#initialize(amount: nil) ⇒ TransferData
constructor
A new instance of TransferData.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil) ⇒ TransferData
Returns a new instance of TransferData.
3033 3034 3035 |
# File 'lib/stripe/resources/charge.rb', line 3033 def initialize(amount: nil) @amount = amount end |
Instance Attribute Details
#amount ⇒ Object
The amount transferred to the destination account, if specified. By default, the entire charge amount is transferred to the destination account.
3031 3032 3033 |
# File 'lib/stripe/resources/charge.rb', line 3031 def amount @amount end |