Class: Stripe::Charge::CreateParams::TransferData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::CreateParams::TransferData
- Defined in:
- lib/stripe/resources/charge.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount transferred to the destination account, if specified.
-
#destination ⇒ Object
ID of an existing, connected Stripe account.
Instance Method Summary collapse
-
#initialize(amount: nil, destination: nil) ⇒ TransferData
constructor
A new instance of TransferData.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, destination: nil) ⇒ TransferData
Returns a new instance of TransferData.
1455 1456 1457 1458 |
# File 'lib/stripe/resources/charge.rb', line 1455 def initialize(amount: nil, destination: nil) @amount = amount @destination = destination end |
Instance Attribute Details
#amount ⇒ Object
The amount transferred to the destination account, if specified. By default, the entire charge amount is transferred to the destination account.
1451 1452 1453 |
# File 'lib/stripe/resources/charge.rb', line 1451 def amount @amount end |
#destination ⇒ Object
ID of an existing, connected Stripe account.
1453 1454 1455 |
# File 'lib/stripe/resources/charge.rb', line 1453 def destination @destination end |