Class: Stripe::Charge::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/charge.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(created: nil, customer: nil, ending_before: nil, expand: nil, limit: nil, payment_intent: nil, starting_after: nil, transfer_group: nil) ⇒ ListParams

Returns a new instance of ListParams.



1355
1356
1357
1358
1359
1360
1361
1362
1363
1364
1365
1366
1367
1368
1369
1370
1371
1372
1373
# File 'lib/stripe/resources/charge.rb', line 1355

def initialize(
  created: nil,
  customer: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  payment_intent: nil,
  starting_after: nil,
  transfer_group: nil
)
  @created = created
  @customer = customer
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @payment_intent = payment_intent
  @starting_after = starting_after
  @transfer_group = transfer_group
end

Instance Attribute Details

#createdObject

Only return charges that were created during the given date interval.



1339
1340
1341
# File 'lib/stripe/resources/charge.rb', line 1339

def created
  @created
end

#customerObject

Only return charges for the customer specified by this customer ID.



1341
1342
1343
# File 'lib/stripe/resources/charge.rb', line 1341

def customer
  @customer
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



1343
1344
1345
# File 'lib/stripe/resources/charge.rb', line 1343

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



1345
1346
1347
# File 'lib/stripe/resources/charge.rb', line 1345

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



1347
1348
1349
# File 'lib/stripe/resources/charge.rb', line 1347

def limit
  @limit
end

#payment_intentObject

Only return charges that were created by the PaymentIntent specified by this PaymentIntent ID.



1349
1350
1351
# File 'lib/stripe/resources/charge.rb', line 1349

def payment_intent
  @payment_intent
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



1351
1352
1353
# File 'lib/stripe/resources/charge.rb', line 1351

def starting_after
  @starting_after
end

#transfer_groupObject

Only return charges for this transfer group, limited to 100.



1353
1354
1355
# File 'lib/stripe/resources/charge.rb', line 1353

def transfer_group
  @transfer_group
end