Class: Stripe::Charge::Outcome

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/charge.rb

Defined Under Namespace

Classes: Rule

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#advice_codeObject (readonly)

An enumerated value providing a more detailed explanation on [how to proceed with an error](stripe.com/docs/declines#retrying-issuer-declines).



144
145
146
# File 'lib/stripe/resources/charge.rb', line 144

def advice_code
  @advice_code
end

#network_advice_codeObject (readonly)

For charges declined by the network, a 2 digit code which indicates the advice returned by the network on how to proceed with an error.



146
147
148
# File 'lib/stripe/resources/charge.rb', line 146

def network_advice_code
  @network_advice_code
end

#network_decline_codeObject (readonly)

For charges declined by the network, an alphanumeric code which indicates the reason the charge failed.



148
149
150
# File 'lib/stripe/resources/charge.rb', line 148

def network_decline_code
  @network_decline_code
end

#network_statusObject (readonly)

Possible values are ‘approved_by_network`, `declined_by_network`, `not_sent_to_network`, and `reversed_after_approval`. The value `reversed_after_approval` indicates the payment was [blocked by Stripe](stripe.com/docs/declines#blocked-payments) after bank authorization, and may temporarily appear as “pending” on a cardholder’s statement.



150
151
152
# File 'lib/stripe/resources/charge.rb', line 150

def network_status
  @network_status
end

#reasonObject (readonly)

An enumerated value providing a more detailed explanation of the outcome’s ‘type`. Charges blocked by Radar’s default block rule have the value ‘highest_risk_level`. Charges placed in review by Radar’s default review rule have the value ‘elevated_risk_level`. Charges blocked because the payment is unlikely to be authorized have the value `low_probability_of_authorization`. Charges authorized, blocked, or placed in review by custom rules have the value `rule`. See [understanding declines](stripe.com/docs/declines) for more details.



152
153
154
# File 'lib/stripe/resources/charge.rb', line 152

def reason
  @reason
end

#risk_levelObject (readonly)

Stripe Radar’s evaluation of the riskiness of the payment. Possible values for evaluated payments are ‘normal`, `elevated`, `highest`. For non-card payments, and card-based payments predating the public assignment of risk levels, this field will have the value `not_assessed`. In the event of an error in the evaluation, this field will have the value `unknown`. This field is only available with Radar.



154
155
156
# File 'lib/stripe/resources/charge.rb', line 154

def risk_level
  @risk_level
end

#risk_scoreObject (readonly)

Stripe Radar’s evaluation of the riskiness of the payment. Possible values for evaluated payments are between 0 and 100. For non-card payments, card-based payments predating the public assignment of risk scores, or in the event of an error during evaluation, this field will not be present. This field is only available with Radar for Fraud Teams.



156
157
158
# File 'lib/stripe/resources/charge.rb', line 156

def risk_score
  @risk_score
end

#ruleObject (readonly)

The ID of the Radar rule that matched the payment, if applicable.



158
159
160
# File 'lib/stripe/resources/charge.rb', line 158

def rule
  @rule
end

#seller_messageObject (readonly)

A human-readable description of the outcome type and reason, designed for you (the recipient of the payment), not your customer.



160
161
162
# File 'lib/stripe/resources/charge.rb', line 160

def seller_message
  @seller_message
end

#typeObject (readonly)

Possible values are ‘authorized`, `manual_review`, `issuer_declined`, `blocked`, and `invalid`. See [understanding declines](stripe.com/docs/declines) and [Radar reviews](stripe.com/docs/radar/reviews) for details.



162
163
164
# File 'lib/stripe/resources/charge.rb', line 162

def type
  @type
end

Class Method Details

.field_remappingsObject



168
169
170
# File 'lib/stripe/resources/charge.rb', line 168

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



164
165
166
# File 'lib/stripe/resources/charge.rb', line 164

def self.inner_class_types
  @inner_class_types = { rule: Rule }
end