Class: Stripe::Charge::PaymentMethodDetails

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/charge.rb

Defined Under Namespace

Classes: AchCreditTransfer, AchDebit, AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, Bizum, Blik, Boleto, Card, CardPresent, Cashapp, Crypto, CustomerBalance, Eps, Fpx, Giropay, Grabpay, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Paypay, Payto, Pix, Promptpay, RevolutPay, SamsungPay, Satispay, Scalapay, SepaCreditTransfer, SepaDebit, Sequra, Sofort, StripeAccount, Sunbit, Swish, Twint, Upi, UsBankAccount, Wechat, WechatPay, Zip

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#ach_credit_transfer ⇒ Object (readonly)

Attribute for field ach_credit_transfer



1991
1992
1993
# File 'lib/stripe/resources/charge.rb', line 1991

def ach_credit_transfer
  @ach_credit_transfer
end

#ach_debit ⇒ Object (readonly)

Attribute for field ach_debit



1993
1994
1995
# File 'lib/stripe/resources/charge.rb', line 1993

def ach_debit
  @ach_debit
end

#acss_debit ⇒ Object (readonly)

Attribute for field acss_debit



1995
1996
1997
# File 'lib/stripe/resources/charge.rb', line 1995

def acss_debit
  @acss_debit
end

#affirm ⇒ Object (readonly)

Attribute for field affirm



1997
1998
1999
# File 'lib/stripe/resources/charge.rb', line 1997

def affirm
  @affirm
end

#afterpay_clearpay ⇒ Object (readonly)

Attribute for field afterpay_clearpay



1999
2000
2001
# File 'lib/stripe/resources/charge.rb', line 1999

def afterpay_clearpay
  @afterpay_clearpay
end

#alipay ⇒ Object (readonly)

Attribute for field alipay



2001
2002
2003
# File 'lib/stripe/resources/charge.rb', line 2001

def alipay
  @alipay
end

#alma ⇒ Object (readonly)

Attribute for field alma



2003
2004
2005
# File 'lib/stripe/resources/charge.rb', line 2003

def alma
  @alma
end

#amazon_pay ⇒ Object (readonly)

Attribute for field amazon_pay



2005
2006
2007
# File 'lib/stripe/resources/charge.rb', line 2005

def amazon_pay
  @amazon_pay
end

#au_becs_debit ⇒ Object (readonly)

Attribute for field au_becs_debit



2007
2008
2009
# File 'lib/stripe/resources/charge.rb', line 2007

def au_becs_debit
  @au_becs_debit
end

#bacs_debit ⇒ Object (readonly)

Attribute for field bacs_debit



2009
2010
2011
# File 'lib/stripe/resources/charge.rb', line 2009

def bacs_debit
  @bacs_debit
end

#bancontact ⇒ Object (readonly)

Attribute for field bancontact



2011
2012
2013
# File 'lib/stripe/resources/charge.rb', line 2011

def bancontact
  @bancontact
end

#billie ⇒ Object (readonly)

Attribute for field billie



2013
2014
2015
# File 'lib/stripe/resources/charge.rb', line 2013

def billie
  @billie
end

#bizum ⇒ Object (readonly)

Attribute for field bizum



2015
2016
2017
# File 'lib/stripe/resources/charge.rb', line 2015

def bizum
  @bizum
end

#blik ⇒ Object (readonly)

Attribute for field blik



2017
2018
2019
# File 'lib/stripe/resources/charge.rb', line 2017

def blik
  @blik
end

#boleto ⇒ Object (readonly)

Attribute for field boleto



2019
2020
2021
# File 'lib/stripe/resources/charge.rb', line 2019

def boleto
  @boleto
end

#card ⇒ Object (readonly)

Attribute for field card



2021
2022
2023
# File 'lib/stripe/resources/charge.rb', line 2021

def card
  @card
end

#card_present ⇒ Object (readonly)

Attribute for field card_present



2023
2024
2025
# File 'lib/stripe/resources/charge.rb', line 2023

def card_present
  @card_present
end

#cashapp ⇒ Object (readonly)

Attribute for field cashapp



2025
2026
2027
# File 'lib/stripe/resources/charge.rb', line 2025

def cashapp
  @cashapp
end

#crypto ⇒ Object (readonly)

Attribute for field crypto



2027
2028
2029
# File 'lib/stripe/resources/charge.rb', line 2027

def crypto
  @crypto
end

#customer_balance ⇒ Object (readonly)

Attribute for field customer_balance



2029
2030
2031
# File 'lib/stripe/resources/charge.rb', line 2029

def customer_balance
  @customer_balance
end

#eps ⇒ Object (readonly)

Attribute for field eps



2031
2032
2033
# File 'lib/stripe/resources/charge.rb', line 2031

def eps
  @eps
end

#fpx ⇒ Object (readonly)

Attribute for field fpx



2033
2034
2035
# File 'lib/stripe/resources/charge.rb', line 2033

def fpx
  @fpx
end

#giropay ⇒ Object (readonly)

Attribute for field giropay



2035
2036
2037
# File 'lib/stripe/resources/charge.rb', line 2035

def giropay
  @giropay
end

#grabpay ⇒ Object (readonly)

Attribute for field grabpay



2037
2038
2039
# File 'lib/stripe/resources/charge.rb', line 2037

def grabpay
  @grabpay
end

#ideal ⇒ Object (readonly)

Attribute for field ideal



2039
2040
2041
# File 'lib/stripe/resources/charge.rb', line 2039

def ideal
  @ideal
end

#interac_present ⇒ Object (readonly)

Attribute for field interac_present



2041
2042
2043
# File 'lib/stripe/resources/charge.rb', line 2041

def interac_present
  @interac_present
end

#kakao_pay ⇒ Object (readonly)

Attribute for field kakao_pay



2043
2044
2045
# File 'lib/stripe/resources/charge.rb', line 2043

def kakao_pay
  @kakao_pay
end

#klarna ⇒ Object (readonly)

Attribute for field klarna



2045
2046
2047
# File 'lib/stripe/resources/charge.rb', line 2045

def klarna
  @klarna
end

#konbini ⇒ Object (readonly)

Attribute for field konbini



2047
2048
2049
# File 'lib/stripe/resources/charge.rb', line 2047

def konbini
  @konbini
end

#kr_card ⇒ Object (readonly)

Attribute for field kr_card



2049
2050
2051
# File 'lib/stripe/resources/charge.rb', line 2049

def kr_card
  @kr_card
end

Attribute for field link



2051
2052
2053
# File 'lib/stripe/resources/charge.rb', line 2051

def link
  @link
end

#mb_way ⇒ Object (readonly)

Attribute for field mb_way



2053
2054
2055
# File 'lib/stripe/resources/charge.rb', line 2053

def mb_way
  @mb_way
end

#mobilepay ⇒ Object (readonly)

Attribute for field mobilepay



2055
2056
2057
# File 'lib/stripe/resources/charge.rb', line 2055

def mobilepay
  @mobilepay
end

#multibanco ⇒ Object (readonly)

Attribute for field multibanco



2057
2058
2059
# File 'lib/stripe/resources/charge.rb', line 2057

def multibanco
  @multibanco
end

Attribute for field naver_pay



2059
2060
2061
# File 'lib/stripe/resources/charge.rb', line 2059

def naver_pay
  @naver_pay
end

#nz_bank_account ⇒ Object (readonly)

Attribute for field nz_bank_account



2061
2062
2063
# File 'lib/stripe/resources/charge.rb', line 2061

def 
  @nz_bank_account
end

#oxxo ⇒ Object (readonly)

Attribute for field oxxo



2063
2064
2065
# File 'lib/stripe/resources/charge.rb', line 2063

def oxxo
  @oxxo
end

#p24 ⇒ Object (readonly)

Attribute for field p24



2065
2066
2067
# File 'lib/stripe/resources/charge.rb', line 2065

def p24
  @p24
end

#pay_by_bank ⇒ Object (readonly)

Attribute for field pay_by_bank



2067
2068
2069
# File 'lib/stripe/resources/charge.rb', line 2067

def pay_by_bank
  @pay_by_bank
end

#payco ⇒ Object (readonly)

Attribute for field payco



2069
2070
2071
# File 'lib/stripe/resources/charge.rb', line 2069

def payco
  @payco
end

#paynow ⇒ Object (readonly)

Attribute for field paynow



2071
2072
2073
# File 'lib/stripe/resources/charge.rb', line 2071

def paynow
  @paynow
end

#paypal ⇒ Object (readonly)

Attribute for field paypal



2073
2074
2075
# File 'lib/stripe/resources/charge.rb', line 2073

def paypal
  @paypal
end

#paypay ⇒ Object (readonly)

Attribute for field paypay



2075
2076
2077
# File 'lib/stripe/resources/charge.rb', line 2075

def paypay
  @paypay
end

#payto ⇒ Object (readonly)

Attribute for field payto



2077
2078
2079
# File 'lib/stripe/resources/charge.rb', line 2077

def payto
  @payto
end

#pix ⇒ Object (readonly)

Attribute for field pix



2079
2080
2081
# File 'lib/stripe/resources/charge.rb', line 2079

def pix
  @pix
end

#promptpay ⇒ Object (readonly)

Attribute for field promptpay



2081
2082
2083
# File 'lib/stripe/resources/charge.rb', line 2081

def promptpay
  @promptpay
end

#revolut_pay ⇒ Object (readonly)

Attribute for field revolut_pay



2083
2084
2085
# File 'lib/stripe/resources/charge.rb', line 2083

def revolut_pay
  @revolut_pay
end

#samsung_pay ⇒ Object (readonly)

Attribute for field samsung_pay



2085
2086
2087
# File 'lib/stripe/resources/charge.rb', line 2085

def samsung_pay
  @samsung_pay
end

#satispay ⇒ Object (readonly)

Attribute for field satispay



2087
2088
2089
# File 'lib/stripe/resources/charge.rb', line 2087

def satispay
  @satispay
end

#scalapay ⇒ Object (readonly)

Attribute for field scalapay



2089
2090
2091
# File 'lib/stripe/resources/charge.rb', line 2089

def scalapay
  @scalapay
end

#sepa_credit_transfer ⇒ Object (readonly)

Attribute for field sepa_credit_transfer



2091
2092
2093
# File 'lib/stripe/resources/charge.rb', line 2091

def sepa_credit_transfer
  @sepa_credit_transfer
end

#sepa_debit ⇒ Object (readonly)

Attribute for field sepa_debit



2093
2094
2095
# File 'lib/stripe/resources/charge.rb', line 2093

def sepa_debit
  @sepa_debit
end

#sequra ⇒ Object (readonly)

Attribute for field sequra



2095
2096
2097
# File 'lib/stripe/resources/charge.rb', line 2095

def sequra
  @sequra
end

#sofort ⇒ Object (readonly)

Attribute for field sofort



2097
2098
2099
# File 'lib/stripe/resources/charge.rb', line 2097

def sofort
  @sofort
end

#stripe_account ⇒ Object (readonly)

Attribute for field stripe_account



2099
2100
2101
# File 'lib/stripe/resources/charge.rb', line 2099

def 
  @stripe_account
end

#sunbit ⇒ Object (readonly)

Attribute for field sunbit



2101
2102
2103
# File 'lib/stripe/resources/charge.rb', line 2101

def sunbit
  @sunbit
end

#swish ⇒ Object (readonly)

Attribute for field swish



2103
2104
2105
# File 'lib/stripe/resources/charge.rb', line 2103

def swish
  @swish
end

#twint ⇒ Object (readonly)

Attribute for field twint



2105
2106
2107
# File 'lib/stripe/resources/charge.rb', line 2105

def twint
  @twint
end

#type ⇒ Object (readonly)

The type of transaction-specific details of the payment method used in the payment. See PaymentMethod.type for the full list of possible types. An additional hash is included on payment_method_details with a name matching this value. It contains information specific to the payment method.



2109
2110
2111
# File 'lib/stripe/resources/charge.rb', line 2109

def type
  @type
end

#upi ⇒ Object (readonly)

Attribute for field upi



2111
2112
2113
# File 'lib/stripe/resources/charge.rb', line 2111

def upi
  @upi
end

#us_bank_account ⇒ Object (readonly)

Attribute for field us_bank_account



2113
2114
2115
# File 'lib/stripe/resources/charge.rb', line 2113

def 
  @us_bank_account
end

#wechat ⇒ Object (readonly)

Attribute for field wechat



2115
2116
2117
# File 'lib/stripe/resources/charge.rb', line 2115

def wechat
  @wechat
end

#wechat_pay ⇒ Object (readonly)

Attribute for field wechat_pay



2117
2118
2119
# File 'lib/stripe/resources/charge.rb', line 2117

def wechat_pay
  @wechat_pay
end

#zip ⇒ Object (readonly)

Attribute for field zip



2119
2120
2121
# File 'lib/stripe/resources/charge.rb', line 2119

def zip
  @zip
end

Class Method Details

.field_remappings ⇒ Object



2189
2190
2191
# File 'lib/stripe/resources/charge.rb', line 2189

def self.field_remappings
  @field_remappings = {}
end

.inner_class_types ⇒ Object



2121
2122
2123
2124
2125
2126
2127
2128
2129
2130
2131
2132
2133
2134
2135
2136
2137
2138
2139
2140
2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
2154
2155
2156
2157
2158
2159
2160
2161
2162
2163
2164
2165
2166
2167
2168
2169
2170
2171
2172
2173
2174
2175
2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
# File 'lib/stripe/resources/charge.rb', line 2121

def self.inner_class_types
  @inner_class_types = {
    ach_credit_transfer: AchCreditTransfer,
    ach_debit: AchDebit,
    acss_debit: AcssDebit,
    affirm: Affirm,
    afterpay_clearpay: AfterpayClearpay,
    alipay: Alipay,
    alma: Alma,
    amazon_pay: AmazonPay,
    au_becs_debit: AuBecsDebit,
    bacs_debit: BacsDebit,
    bancontact: Bancontact,
    billie: Billie,
    bizum: Bizum,
    blik: Blik,
    boleto: Boleto,
    card: Card,
    card_present: CardPresent,
    cashapp: Cashapp,
    crypto: Crypto,
    customer_balance: CustomerBalance,
    eps: Eps,
    fpx: Fpx,
    giropay: Giropay,
    grabpay: Grabpay,
    ideal: Ideal,
    interac_present: InteracPresent,
    kakao_pay: KakaoPay,
    klarna: Klarna,
    konbini: Konbini,
    kr_card: KrCard,
    link: Link,
    mb_way: MbWay,
    mobilepay: Mobilepay,
    multibanco: Multibanco,
    naver_pay: NaverPay,
    nz_bank_account: NzBankAccount,
    oxxo: Oxxo,
    p24: P24,
    pay_by_bank: PayByBank,
    payco: Payco,
    paynow: Paynow,
    paypal: Paypal,
    paypay: Paypay,
    payto: Payto,
    pix: Pix,
    promptpay: Promptpay,
    revolut_pay: RevolutPay,
    samsung_pay: SamsungPay,
    satispay: Satispay,
    scalapay: Scalapay,
    sepa_credit_transfer: SepaCreditTransfer,
    sepa_debit: SepaDebit,
    sequra: Sequra,
    sofort: Sofort,
    stripe_account: StripeAccount,
    sunbit: Sunbit,
    swish: Swish,
    twint: Twint,
    upi: Upi,
    us_bank_account: UsBankAccount,
    wechat: Wechat,
    wechat_pay: WechatPay,
    zip: Zip,
  }
end