Class: Stripe::Charge::PaymentMethodDetails::AchCreditTransfer

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_numberObject (readonly)

Account number to transfer funds to.



120
121
122
# File 'lib/stripe/resources/charge.rb', line 120

def 
  @account_number
end

#bank_nameObject (readonly)

Name of the bank associated with the routing number.



122
123
124
# File 'lib/stripe/resources/charge.rb', line 122

def bank_name
  @bank_name
end

#routing_numberObject (readonly)

Routing transit number for the bank account to transfer funds to.



124
125
126
# File 'lib/stripe/resources/charge.rb', line 124

def routing_number
  @routing_number
end

#swift_codeObject (readonly)

SWIFT code of the bank associated with the routing number.



126
127
128
# File 'lib/stripe/resources/charge.rb', line 126

def swift_code
  @swift_code
end