Class: Stripe::Charge::PaymentMethodDetails::AchDebit

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_holder_typeObject (readonly)

Type of entity that holds the account. This can be either ‘individual` or `company`.



195
196
197
# File 'lib/stripe/resources/charge.rb', line 195

def 
  @account_holder_type
end

#bank_nameObject (readonly)

Name of the bank associated with the bank account.



197
198
199
# File 'lib/stripe/resources/charge.rb', line 197

def bank_name
  @bank_name
end

#countryObject (readonly)

Two-letter ISO code representing the country the bank account is located in.



199
200
201
# File 'lib/stripe/resources/charge.rb', line 199

def country
  @country
end

#fingerprintObject (readonly)

Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.



201
202
203
# File 'lib/stripe/resources/charge.rb', line 201

def fingerprint
  @fingerprint
end

#last4Object (readonly)

Last four digits of the bank account number.



203
204
205
# File 'lib/stripe/resources/charge.rb', line 203

def last4
  @last4
end

#routing_numberObject (readonly)

Routing transit number of the bank account.



205
206
207
# File 'lib/stripe/resources/charge.rb', line 205

def routing_number
  @routing_number
end

Class Method Details

.field_remappingsObject



211
212
213
# File 'lib/stripe/resources/charge.rb', line 211

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



207
208
209
# File 'lib/stripe/resources/charge.rb', line 207

def self.inner_class_types
  @inner_class_types = {}
end