Class: Stripe::Charge::PaymentMethodDetails::AcssDebit

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_nameObject (readonly)

Name of the bank associated with the bank account.



218
219
220
# File 'lib/stripe/resources/charge.rb', line 218

def bank_name
  @bank_name
end

#fingerprintObject (readonly)

Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.



220
221
222
# File 'lib/stripe/resources/charge.rb', line 220

def fingerprint
  @fingerprint
end

#institution_numberObject (readonly)

Institution number of the bank account



222
223
224
# File 'lib/stripe/resources/charge.rb', line 222

def institution_number
  @institution_number
end

#last4Object (readonly)

Last four digits of the bank account number.



224
225
226
# File 'lib/stripe/resources/charge.rb', line 224

def last4
  @last4
end

#mandateObject (readonly)

ID of the mandate used to make this payment.



226
227
228
# File 'lib/stripe/resources/charge.rb', line 226

def mandate
  @mandate
end

#transit_numberObject (readonly)

Transit number of the bank account.



228
229
230
# File 'lib/stripe/resources/charge.rb', line 228

def transit_number
  @transit_number
end

Class Method Details

.field_remappingsObject



234
235
236
# File 'lib/stripe/resources/charge.rb', line 234

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



230
231
232
# File 'lib/stripe/resources/charge.rb', line 230

def self.inner_class_types
  @inner_class_types = {}
end