Class: Stripe::Charge::PaymentMethodDetails::AmazonPay::Funding::Card
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::PaymentMethodDetails::AmazonPay::Funding::Card
- Defined in:
- lib/stripe/resources/charge.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#brand ⇒ Object
readonly
Card brand.
-
#brand_product ⇒ Object
readonly
The [product code](stripe.com/docs/card-product-codes) that identifies the specific program or product associated with a card.
-
#country ⇒ Object
readonly
Two-letter ISO code representing the country of the card.
-
#exp_month ⇒ Object
readonly
Two-digit number representing the card’s expiration month.
-
#exp_year ⇒ Object
readonly
Four-digit number representing the card’s expiration year.
-
#funding ⇒ Object
readonly
Card funding type.
-
#last4 ⇒ Object
readonly
The last four digits of the card.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#brand ⇒ Object (readonly)
Card brand. Can be ‘amex`, `diners`, `discover`, `eftpos_au`, `jcb`, `link`, `mastercard`, `unionpay`, `visa`, or `unknown`.
186 187 188 |
# File 'lib/stripe/resources/charge.rb', line 186 def brand @brand end |
#brand_product ⇒ Object (readonly)
The [product code](stripe.com/docs/card-product-codes) that identifies the specific program or product associated with a card. (For internal use only and not typically available in standard API requests.)
188 189 190 |
# File 'lib/stripe/resources/charge.rb', line 188 def brand_product @brand_product end |
#country ⇒ Object (readonly)
Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you’ve collected.
190 191 192 |
# File 'lib/stripe/resources/charge.rb', line 190 def country @country end |
#exp_month ⇒ Object (readonly)
Two-digit number representing the card’s expiration month.
192 193 194 |
# File 'lib/stripe/resources/charge.rb', line 192 def exp_month @exp_month end |
#exp_year ⇒ Object (readonly)
Four-digit number representing the card’s expiration year.
194 195 196 |
# File 'lib/stripe/resources/charge.rb', line 194 def exp_year @exp_year end |
#funding ⇒ Object (readonly)
Card funding type. Can be ‘credit`, `debit`, `prepaid`, or `unknown`.
196 197 198 |
# File 'lib/stripe/resources/charge.rb', line 196 def funding @funding end |
#last4 ⇒ Object (readonly)
The last four digits of the card.
198 199 200 |
# File 'lib/stripe/resources/charge.rb', line 198 def last4 @last4 end |