Class: Stripe::Charge::PaymentMethodDetails::BacsDebit
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::PaymentMethodDetails::BacsDebit
- Defined in:
- lib/stripe/resources/charge.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#fingerprint ⇒ Object
readonly
Uniquely identifies this particular bank account.
-
#last4 ⇒ Object
readonly
Last four digits of the bank account number.
-
#mandate ⇒ Object
readonly
ID of the mandate used to make this payment.
-
#sort_code ⇒ Object
readonly
Sort code of the bank account.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#fingerprint ⇒ Object (readonly)
Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.
222 223 224 |
# File 'lib/stripe/resources/charge.rb', line 222 def fingerprint @fingerprint end |
#last4 ⇒ Object (readonly)
Last four digits of the bank account number.
224 225 226 |
# File 'lib/stripe/resources/charge.rb', line 224 def last4 @last4 end |
#mandate ⇒ Object (readonly)
ID of the mandate used to make this payment.
226 227 228 |
# File 'lib/stripe/resources/charge.rb', line 226 def mandate @mandate end |
#sort_code ⇒ Object (readonly)
Sort code of the bank account. (e.g., ‘10-20-30`)
228 229 230 |
# File 'lib/stripe/resources/charge.rb', line 228 def sort_code @sort_code end |