Class: Stripe::Charge::PaymentMethodDetails::Bancontact

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_codeObject (readonly)

Bank code of bank associated with the bank account.



413
414
415
# File 'lib/stripe/resources/charge.rb', line 413

def bank_code
  @bank_code
end

#bank_nameObject (readonly)

Name of the bank associated with the bank account.



415
416
417
# File 'lib/stripe/resources/charge.rb', line 415

def bank_name
  @bank_name
end

#bicObject (readonly)

Bank Identifier Code of the bank associated with the bank account.



417
418
419
# File 'lib/stripe/resources/charge.rb', line 417

def bic
  @bic
end

#generated_sepa_debitObject (readonly)

The ID of the SEPA Direct Debit PaymentMethod which was generated by this Charge.



419
420
421
# File 'lib/stripe/resources/charge.rb', line 419

def generated_sepa_debit
  @generated_sepa_debit
end

#generated_sepa_debit_mandateObject (readonly)

The mandate for the SEPA Direct Debit PaymentMethod which was generated by this Charge.



421
422
423
# File 'lib/stripe/resources/charge.rb', line 421

def generated_sepa_debit_mandate
  @generated_sepa_debit_mandate
end

#iban_last4Object (readonly)

Last four characters of the IBAN.



423
424
425
# File 'lib/stripe/resources/charge.rb', line 423

def iban_last4
  @iban_last4
end

#preferred_languageObject (readonly)

Preferred language of the Bancontact authorization page that the customer is redirected to. Can be one of ‘en`, `de`, `fr`, or `nl`



426
427
428
# File 'lib/stripe/resources/charge.rb', line 426

def preferred_language
  @preferred_language
end

#verified_nameObject (readonly)

Owner’s verified full name. Values are verified or provided by Bancontact directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



429
430
431
# File 'lib/stripe/resources/charge.rb', line 429

def verified_name
  @verified_name
end

Class Method Details

.field_remappingsObject



435
436
437
# File 'lib/stripe/resources/charge.rb', line 435

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



431
432
433
# File 'lib/stripe/resources/charge.rb', line 431

def self.inner_class_types
  @inner_class_types = {}
end