Class: Stripe::Charge::PaymentMethodDetails::Card::Installments::Plan

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#countObject (readonly)

For ‘fixed_count` installment plans, this is the number of installment payments your customer will make to their credit card.



539
540
541
# File 'lib/stripe/resources/charge.rb', line 539

def count
  @count
end

#intervalObject (readonly)

For ‘fixed_count` installment plans, this is the interval between installment payments your customer will make to their credit card. One of `month`.



542
543
544
# File 'lib/stripe/resources/charge.rb', line 542

def interval
  @interval
end

#typeObject (readonly)

Type of installment plan, one of ‘fixed_count`, `bonus`, or `revolving`.



544
545
546
# File 'lib/stripe/resources/charge.rb', line 544

def type
  @type
end

Class Method Details

.field_remappingsObject



550
551
552
# File 'lib/stripe/resources/charge.rb', line 550

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



546
547
548
# File 'lib/stripe/resources/charge.rb', line 546

def self.inner_class_types
  @inner_class_types = {}
end