Class: Stripe::Charge::PaymentMethodDetails::Card::Overcapture
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::PaymentMethodDetails::Card::Overcapture
- Defined in:
- lib/stripe/resources/charge.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#maximum_amount_capturable ⇒ Object
readonly
The maximum amount that can be captured.
-
#status ⇒ Object
readonly
Indicates whether or not the authorized amount can be over-captured.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#maximum_amount_capturable ⇒ Object (readonly)
The maximum amount that can be captured.
312 313 314 |
# File 'lib/stripe/resources/charge.rb', line 312 def maximum_amount_capturable @maximum_amount_capturable end |
#status ⇒ Object (readonly)
Indicates whether or not the authorized amount can be over-captured.
314 315 316 |
# File 'lib/stripe/resources/charge.rb', line 314 def status @status end |