Class: Stripe::Charge::PaymentMethodDetails::Card::Wallet

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Defined Under Namespace

Classes: AmexExpressCheckout, ApplePay, GooglePay, Link, Masterpass, SamsungPay, VisaCheckout

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amex_express_checkoutObject (readonly)

Attribute for field amex_express_checkout



905
906
907
# File 'lib/stripe/resources/charge.rb', line 905

def amex_express_checkout
  @amex_express_checkout
end

#apple_payObject (readonly)

Attribute for field apple_pay



907
908
909
# File 'lib/stripe/resources/charge.rb', line 907

def apple_pay
  @apple_pay
end

#dynamic_last4Object (readonly)

(For tokenized numbers only.) The last four digits of the device account number.



909
910
911
# File 'lib/stripe/resources/charge.rb', line 909

def dynamic_last4
  @dynamic_last4
end

#google_payObject (readonly)

Attribute for field google_pay



911
912
913
# File 'lib/stripe/resources/charge.rb', line 911

def google_pay
  @google_pay
end

Attribute for field link



913
914
915
# File 'lib/stripe/resources/charge.rb', line 913

def link
  @link
end

#masterpassObject (readonly)

Attribute for field masterpass



915
916
917
# File 'lib/stripe/resources/charge.rb', line 915

def masterpass
  @masterpass
end

#samsung_payObject (readonly)

Attribute for field samsung_pay



917
918
919
# File 'lib/stripe/resources/charge.rb', line 917

def samsung_pay
  @samsung_pay
end

#typeObject (readonly)

The type of the card wallet, one of amex_express_checkout, apple_pay, google_pay, masterpass, samsung_pay, visa_checkout, or link. An additional hash is included on the Wallet subhash with a name matching this value. It contains additional information specific to the card wallet type.



919
920
921
# File 'lib/stripe/resources/charge.rb', line 919

def type
  @type
end

#visa_checkoutObject (readonly)

Attribute for field visa_checkout



921
922
923
# File 'lib/stripe/resources/charge.rb', line 921

def visa_checkout
  @visa_checkout
end

Class Method Details

.field_remappingsObject



935
936
937
# File 'lib/stripe/resources/charge.rb', line 935

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



923
924
925
926
927
928
929
930
931
932
933
# File 'lib/stripe/resources/charge.rb', line 923

def self.inner_class_types
  @inner_class_types = {
    amex_express_checkout: AmexExpressCheckout,
    apple_pay: ApplePay,
    google_pay: GooglePay,
    link: Link,
    masterpass: Masterpass,
    samsung_pay: SamsungPay,
    visa_checkout: VisaCheckout,
  }
end