Class: Stripe::Charge::PaymentMethodDetails::Card::Wallet::Masterpass

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Defined Under Namespace

Classes: BillingAddress, ShippingAddress

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#billing_addressObject (readonly)

Owner's verified billing address. Values are verified or provided by the wallet directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



758
759
760
# File 'lib/stripe/resources/charge.rb', line 758

def billing_address
  @billing_address
end

#emailObject (readonly)

Owner's verified email. Values are verified or provided by the wallet directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



760
761
762
# File 'lib/stripe/resources/charge.rb', line 760

def email
  @email
end

#nameObject (readonly)

Owner's verified full name. Values are verified or provided by the wallet directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



762
763
764
# File 'lib/stripe/resources/charge.rb', line 762

def name
  @name
end

#shipping_addressObject (readonly)

Owner's verified shipping address. Values are verified or provided by the wallet directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



764
765
766
# File 'lib/stripe/resources/charge.rb', line 764

def shipping_address
  @shipping_address
end

Class Method Details

.field_remappingsObject



773
774
775
# File 'lib/stripe/resources/charge.rb', line 773

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



766
767
768
769
770
771
# File 'lib/stripe/resources/charge.rb', line 766

def self.inner_class_types
  @inner_class_types = {
    billing_address: BillingAddress,
    shipping_address: ShippingAddress,
  }
end