Class: Stripe::Charge::PaymentMethodDetails::CardPresent
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::PaymentMethodDetails::CardPresent
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: Offline, Receipt, Wallet
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount_authorized ⇒ Object
readonly
The authorized amount.
-
#brand ⇒ Object
readonly
Card brand.
-
#brand_product ⇒ Object
readonly
The product code that identifies the specific program or product associated with a card.
-
#capture_before ⇒ Object
readonly
When using manual capture, a future timestamp after which the charge will be automatically refunded if uncaptured.
-
#cardholder_name ⇒ Object
readonly
The cardholder name as read from the card, in ISO 7813 format.
-
#country ⇒ Object
readonly
Two-letter ISO code representing the country of the card.
-
#description ⇒ Object
readonly
A high-level description of the type of cards issued in this range.
-
#emv_auth_data ⇒ Object
readonly
Authorization response cryptogram.
-
#exp_month ⇒ Object
readonly
Two-digit number representing the card's expiration month.
-
#exp_year ⇒ Object
readonly
Four-digit number representing the card's expiration year.
-
#fingerprint ⇒ Object
readonly
Uniquely identifies this particular card number.
-
#funding ⇒ Object
readonly
Card funding type.
-
#generated_card ⇒ Object
readonly
ID of a card PaymentMethod generated from the card_present PaymentMethod that may be attached to a Customer for future transactions.
-
#iin ⇒ Object
readonly
Issuer identification number of the card.
-
#incremental_authorization_supported ⇒ Object
readonly
Whether this PaymentIntent is eligible for incremental authorizations.
-
#issuer ⇒ Object
readonly
The name of the card's issuing bank.
-
#last4 ⇒ Object
readonly
The last four digits of the card.
-
#location ⇒ Object
readonly
ID of the location that this transaction's reader is assigned to.
-
#network ⇒ Object
readonly
Identifies which network this charge was processed on.
-
#network_transaction_id ⇒ Object
readonly
This is used by the financial networks to identify a transaction.
-
#offline ⇒ Object
readonly
Details about payments collected offline.
-
#overcapture_supported ⇒ Object
readonly
Defines whether the authorized amount can be over-captured or not.
-
#preferred_locales ⇒ Object
readonly
The languages that the issuing bank recommends using for localizing any customer-facing text, as read from the card.
-
#read_method ⇒ Object
readonly
How card details were read in this transaction.
-
#reader ⇒ Object
readonly
ID of the reader this transaction was made on.
-
#receipt ⇒ Object
readonly
A collection of fields required to be displayed on receipts.
-
#wallet ⇒ Object
readonly
Attribute for field wallet.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount_authorized ⇒ Object (readonly)
The authorized amount
999 1000 1001 |
# File 'lib/stripe/resources/charge.rb', line 999 def @amount_authorized end |
#brand ⇒ Object (readonly)
Card brand. Can be amex, cartes_bancaires, diners, discover, eftpos_au, jcb, link, mastercard, unionpay, visa or unknown.
1001 1002 1003 |
# File 'lib/stripe/resources/charge.rb', line 1001 def brand @brand end |
#brand_product ⇒ Object (readonly)
The product code that identifies the specific program or product associated with a card.
1003 1004 1005 |
# File 'lib/stripe/resources/charge.rb', line 1003 def brand_product @brand_product end |
#capture_before ⇒ Object (readonly)
When using manual capture, a future timestamp after which the charge will be automatically refunded if uncaptured.
1005 1006 1007 |
# File 'lib/stripe/resources/charge.rb', line 1005 def capture_before @capture_before end |
#cardholder_name ⇒ Object (readonly)
The cardholder name as read from the card, in ISO 7813 format. May include alphanumeric characters, special characters and first/last name separator (/). In some cases, the cardholder name may not be available depending on how the issuer has configured the card. Cardholder name is typically not available on swipe or contactless payments, such as those made with Apple Pay and Google Pay.
1007 1008 1009 |
# File 'lib/stripe/resources/charge.rb', line 1007 def cardholder_name @cardholder_name end |
#country ⇒ Object (readonly)
Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you've collected.
1009 1010 1011 |
# File 'lib/stripe/resources/charge.rb', line 1009 def country @country end |
#description ⇒ Object (readonly)
A high-level description of the type of cards issued in this range. (For internal use only and not typically available in standard API requests.)
1011 1012 1013 |
# File 'lib/stripe/resources/charge.rb', line 1011 def description @description end |
#emv_auth_data ⇒ Object (readonly)
Authorization response cryptogram.
1013 1014 1015 |
# File 'lib/stripe/resources/charge.rb', line 1013 def emv_auth_data @emv_auth_data end |
#exp_month ⇒ Object (readonly)
Two-digit number representing the card's expiration month.
1015 1016 1017 |
# File 'lib/stripe/resources/charge.rb', line 1015 def exp_month @exp_month end |
#exp_year ⇒ Object (readonly)
Four-digit number representing the card's expiration year.
1017 1018 1019 |
# File 'lib/stripe/resources/charge.rb', line 1017 def exp_year @exp_year end |
#fingerprint ⇒ Object (readonly)
Uniquely identifies this particular card number. You can use this attribute to check whether two customers who’ve signed up with you are using the same card number, for example. For payment methods that tokenize card information (Apple Pay, Google Pay), the tokenized number might be provided instead of the underlying card number.
As of May 1, 2021, card fingerprint in India for Connect changed to allow two fingerprints for the same card---one for India and one for the rest of the world.
1021 1022 1023 |
# File 'lib/stripe/resources/charge.rb', line 1021 def fingerprint @fingerprint end |
#funding ⇒ Object (readonly)
Card funding type. Can be credit, debit, prepaid, or unknown.
1023 1024 1025 |
# File 'lib/stripe/resources/charge.rb', line 1023 def funding @funding end |
#generated_card ⇒ Object (readonly)
ID of a card PaymentMethod generated from the card_present PaymentMethod that may be attached to a Customer for future transactions. Only present if it was possible to generate a card PaymentMethod.
1025 1026 1027 |
# File 'lib/stripe/resources/charge.rb', line 1025 def generated_card @generated_card end |
#iin ⇒ Object (readonly)
Issuer identification number of the card. (For internal use only and not typically available in standard API requests.)
1027 1028 1029 |
# File 'lib/stripe/resources/charge.rb', line 1027 def iin @iin end |
#incremental_authorization_supported ⇒ Object (readonly)
Whether this PaymentIntent is eligible for incremental authorizations. Request support using request_incremental_authorization_support.
1029 1030 1031 |
# File 'lib/stripe/resources/charge.rb', line 1029 def @incremental_authorization_supported end |
#issuer ⇒ Object (readonly)
The name of the card's issuing bank. (For internal use only and not typically available in standard API requests.)
1031 1032 1033 |
# File 'lib/stripe/resources/charge.rb', line 1031 def issuer @issuer end |
#last4 ⇒ Object (readonly)
The last four digits of the card.
1033 1034 1035 |
# File 'lib/stripe/resources/charge.rb', line 1033 def last4 @last4 end |
#location ⇒ Object (readonly)
ID of the location that this transaction's reader is assigned to.
1035 1036 1037 |
# File 'lib/stripe/resources/charge.rb', line 1035 def location @location end |
#network ⇒ Object (readonly)
Identifies which network this charge was processed on. Can be amex, cartes_bancaires, diners, discover, eftpos_au, interac, jcb, link, mastercard, unionpay, visa, or unknown.
1037 1038 1039 |
# File 'lib/stripe/resources/charge.rb', line 1037 def network @network end |
#network_transaction_id ⇒ Object (readonly)
This is used by the financial networks to identify a transaction. Visa calls this the Transaction ID, Mastercard calls this the Trace ID, and American Express calls this the Acquirer Reference Data. This value will be present if it is returned by the financial network in the authorization response, and null otherwise.
1039 1040 1041 |
# File 'lib/stripe/resources/charge.rb', line 1039 def network_transaction_id @network_transaction_id end |
#offline ⇒ Object (readonly)
Details about payments collected offline.
1041 1042 1043 |
# File 'lib/stripe/resources/charge.rb', line 1041 def offline @offline end |
#overcapture_supported ⇒ Object (readonly)
Defines whether the authorized amount can be over-captured or not
1043 1044 1045 |
# File 'lib/stripe/resources/charge.rb', line 1043 def overcapture_supported @overcapture_supported end |
#preferred_locales ⇒ Object (readonly)
The languages that the issuing bank recommends using for localizing any customer-facing text, as read from the card. Referenced from EMV tag 5F2D, data encoded on the card's chip.
1045 1046 1047 |
# File 'lib/stripe/resources/charge.rb', line 1045 def preferred_locales @preferred_locales end |
#read_method ⇒ Object (readonly)
How card details were read in this transaction.
1047 1048 1049 |
# File 'lib/stripe/resources/charge.rb', line 1047 def read_method @read_method end |
#reader ⇒ Object (readonly)
ID of the reader this transaction was made on.
1049 1050 1051 |
# File 'lib/stripe/resources/charge.rb', line 1049 def reader @reader end |
#receipt ⇒ Object (readonly)
A collection of fields required to be displayed on receipts. Only required for EMV transactions.
1051 1052 1053 |
# File 'lib/stripe/resources/charge.rb', line 1051 def receipt @receipt end |
#wallet ⇒ Object (readonly)
Attribute for field wallet
1053 1054 1055 |
# File 'lib/stripe/resources/charge.rb', line 1053 def wallet @wallet end |
Class Method Details
.field_remappings ⇒ Object
1059 1060 1061 |
# File 'lib/stripe/resources/charge.rb', line 1059 def self.field_remappings @field_remappings = {} end |