Class: Stripe::Charge::PaymentMethodDetails::Cashapp
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::PaymentMethodDetails::Cashapp
- Defined in:
- lib/stripe/resources/charge.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#buyer_id ⇒ Object
readonly
A unique and immutable identifier assigned by Cash App to every buyer.
-
#cashtag ⇒ Object
readonly
A public identifier for buyers using Cash App.
-
#transaction_id ⇒ Object
readonly
A unique and immutable identifier of payments assigned by Cash App.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#buyer_id ⇒ Object (readonly)
A unique and immutable identifier assigned by Cash App to every buyer.
1095 1096 1097 |
# File 'lib/stripe/resources/charge.rb', line 1095 def buyer_id @buyer_id end |
#cashtag ⇒ Object (readonly)
A public identifier for buyers using Cash App.
1097 1098 1099 |
# File 'lib/stripe/resources/charge.rb', line 1097 def cashtag @cashtag end |
#transaction_id ⇒ Object (readonly)
A unique and immutable identifier of payments assigned by Cash App
1099 1100 1101 |
# File 'lib/stripe/resources/charge.rb', line 1099 def transaction_id @transaction_id end |
Class Method Details
.field_remappings ⇒ Object
1105 1106 1107 |
# File 'lib/stripe/resources/charge.rb', line 1105 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1101 1102 1103 |
# File 'lib/stripe/resources/charge.rb', line 1101 def self.inner_class_types @inner_class_types = {} end |