Class: Stripe::Charge::PaymentMethodDetails::Crypto
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::PaymentMethodDetails::Crypto
- Defined in:
- lib/stripe/resources/charge.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#buyer_address ⇒ Object
readonly
The wallet address of the customer.
-
#network ⇒ Object
readonly
The blockchain network that the transaction was sent on.
-
#token_currency ⇒ Object
readonly
The token currency that the transaction was sent with.
-
#transaction_hash ⇒ Object
readonly
The blockchain transaction hash of the crypto payment.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#buyer_address ⇒ Object (readonly)
The wallet address of the customer.
1112 1113 1114 |
# File 'lib/stripe/resources/charge.rb', line 1112 def buyer_address @buyer_address end |
#network ⇒ Object (readonly)
The blockchain network that the transaction was sent on.
1114 1115 1116 |
# File 'lib/stripe/resources/charge.rb', line 1114 def network @network end |
#token_currency ⇒ Object (readonly)
The token currency that the transaction was sent with.
1116 1117 1118 |
# File 'lib/stripe/resources/charge.rb', line 1116 def token_currency @token_currency end |
#transaction_hash ⇒ Object (readonly)
The blockchain transaction hash of the crypto payment.
1118 1119 1120 |
# File 'lib/stripe/resources/charge.rb', line 1118 def transaction_hash @transaction_hash end |
Class Method Details
.field_remappings ⇒ Object
1124 1125 1126 |
# File 'lib/stripe/resources/charge.rb', line 1124 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1120 1121 1122 |
# File 'lib/stripe/resources/charge.rb', line 1120 def self.inner_class_types @inner_class_types = {} end |