Class: Stripe::Charge::PaymentMethodDetails::GiftCard

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Defined Under Namespace

Classes: Balance

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#balanceObject (readonly)

Attribute for field balance



1303
1304
1305
# File 'lib/stripe/resources/charge.rb', line 1303

def balance
  @balance
end

#brandObject (readonly)

The brand of the gift card.



1305
1306
1307
# File 'lib/stripe/resources/charge.rb', line 1305

def brand
  @brand
end

#exp_monthObject (readonly)

The expiration month of the gift card.



1307
1308
1309
# File 'lib/stripe/resources/charge.rb', line 1307

def exp_month
  @exp_month
end

#exp_yearObject (readonly)

The expiration year of the gift card.



1309
1310
1311
# File 'lib/stripe/resources/charge.rb', line 1309

def exp_year
  @exp_year
end

#fingerprintObject (readonly)

Uniquely identifies this particular gift card number. You can use this attribute to check whether two transactions were made using the same gift card.



1311
1312
1313
# File 'lib/stripe/resources/charge.rb', line 1311

def fingerprint
  @fingerprint
end

#first6Object (readonly)

The first six digits of the gift card number.



1313
1314
1315
# File 'lib/stripe/resources/charge.rb', line 1313

def first6
  @first6
end

#last4Object (readonly)

The last four digits of the gift card number.



1315
1316
1317
# File 'lib/stripe/resources/charge.rb', line 1315

def last4
  @last4
end

#locationObject (readonly)

ID of the location that this transaction's reader is assigned to.



1317
1318
1319
# File 'lib/stripe/resources/charge.rb', line 1317

def location
  @location
end

#readerObject (readonly)

ID of the reader this transaction was made on.



1319
1320
1321
# File 'lib/stripe/resources/charge.rb', line 1319

def reader
  @reader
end

#transaction_idObject (readonly)

The transaction ID from the gift card processor.



1321
1322
1323
# File 'lib/stripe/resources/charge.rb', line 1321

def transaction_id
  @transaction_id
end

Class Method Details

.field_remappingsObject



1327
1328
1329
# File 'lib/stripe/resources/charge.rb', line 1327

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1323
1324
1325
# File 'lib/stripe/resources/charge.rb', line 1323

def self.inner_class_types
  @inner_class_types = { balance: Balance }
end