Class: Stripe::Charge::PaymentMethodDetails::KrCard

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#brandObject (readonly)

The local credit or debit card brand.



1367
1368
1369
# File 'lib/stripe/resources/charge.rb', line 1367

def brand
  @brand
end

#buyer_idObject (readonly)

A unique identifier for the buyer as determined by the local payment processor.



1369
1370
1371
# File 'lib/stripe/resources/charge.rb', line 1369

def buyer_id
  @buyer_id
end

#last4Object (readonly)

The last four digits of the card. This may not be present for American Express cards.



1371
1372
1373
# File 'lib/stripe/resources/charge.rb', line 1371

def last4
  @last4
end

#transaction_idObject (readonly)

The Korean Card transaction ID associated with this payment.



1373
1374
1375
# File 'lib/stripe/resources/charge.rb', line 1373

def transaction_id
  @transaction_id
end

Class Method Details

.field_remappingsObject



1379
1380
1381
# File 'lib/stripe/resources/charge.rb', line 1379

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1375
1376
1377
# File 'lib/stripe/resources/charge.rb', line 1375

def self.inner_class_types
  @inner_class_types = {}
end