Class: Stripe::Charge::PaymentMethodDetails::Link
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::PaymentMethodDetails::Link
- Defined in:
- lib/stripe/resources/charge.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#country ⇒ Object
readonly
Two-letter ISO code representing the funding source country beneath the Link payment.
-
#funding_source_group ⇒ Object
readonly
The funding source group applied to this Link payment at confirmation time.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#country ⇒ Object (readonly)
Two-letter ISO code representing the funding source country beneath the Link payment. You could use this attribute to get a sense of international fees.
1613 1614 1615 |
# File 'lib/stripe/resources/charge.rb', line 1613 def country @country end |
#funding_source_group ⇒ Object (readonly)
The funding source group applied to this Link payment at confirmation time. Maps to a bundle in your Stripe pricing contract and on Stripe's published pricing page. Omitted if group lookup failed at confirmation time.
1615 1616 1617 |
# File 'lib/stripe/resources/charge.rb', line 1615 def funding_source_group @funding_source_group end |
Class Method Details
.field_remappings ⇒ Object
1621 1622 1623 |
# File 'lib/stripe/resources/charge.rb', line 1621 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1617 1618 1619 |
# File 'lib/stripe/resources/charge.rb', line 1617 def self.inner_class_types @inner_class_types = {} end |