Class: Stripe::Charge::PaymentMethodDetails::Paynow
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::PaymentMethodDetails::Paynow
- Defined in:
- lib/stripe/resources/charge.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#location ⇒ Object
readonly
ID of the location that this transaction's reader is assigned to.
-
#reader ⇒ Object
readonly
ID of the reader this transaction was made on.
-
#reference ⇒ Object
readonly
Reference number associated with this PayNow payment.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#location ⇒ Object (readonly)
ID of the location that this transaction's reader is assigned to.
1564 1565 1566 |
# File 'lib/stripe/resources/charge.rb', line 1564 def location @location end |
#reader ⇒ Object (readonly)
ID of the reader this transaction was made on.
1566 1567 1568 |
# File 'lib/stripe/resources/charge.rb', line 1566 def reader @reader end |
#reference ⇒ Object (readonly)
Reference number associated with this PayNow payment
1568 1569 1570 |
# File 'lib/stripe/resources/charge.rb', line 1568 def reference @reference end |
Class Method Details
.field_remappings ⇒ Object
1574 1575 1576 |
# File 'lib/stripe/resources/charge.rb', line 1574 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1570 1571 1572 |
# File 'lib/stripe/resources/charge.rb', line 1570 def self.inner_class_types @inner_class_types = {} end |