Class: Stripe::Charge::PaymentMethodDetails::Paypal
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::PaymentMethodDetails::Paypal
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: SellerProtection
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#country ⇒ Object
readonly
Two-letter ISO code representing the buyer's country.
-
#payer_email ⇒ Object
readonly
Owner's email.
-
#payer_id ⇒ Object
readonly
PayPal account PayerID.
-
#payer_name ⇒ Object
readonly
Owner's full name.
-
#seller_protection ⇒ Object
readonly
The level of protection offered as defined by PayPal Seller Protection for Merchants, for this transaction.
-
#transaction_id ⇒ Object
readonly
A unique ID generated by PayPal for this transaction.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#country ⇒ Object (readonly)
Two-letter ISO code representing the buyer's country. Values are provided by PayPal directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.
1595 1596 1597 |
# File 'lib/stripe/resources/charge.rb', line 1595 def country @country end |
#payer_email ⇒ Object (readonly)
Owner's email. Values are provided by PayPal directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.
1598 1599 1600 |
# File 'lib/stripe/resources/charge.rb', line 1598 def payer_email @payer_email end |
#payer_id ⇒ Object (readonly)
PayPal account PayerID. This identifier uniquely identifies the PayPal customer.
1600 1601 1602 |
# File 'lib/stripe/resources/charge.rb', line 1600 def payer_id @payer_id end |
#payer_name ⇒ Object (readonly)
Owner's full name. Values provided by PayPal directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.
1603 1604 1605 |
# File 'lib/stripe/resources/charge.rb', line 1603 def payer_name @payer_name end |
#seller_protection ⇒ Object (readonly)
The level of protection offered as defined by PayPal Seller Protection for Merchants, for this transaction.
1605 1606 1607 |
# File 'lib/stripe/resources/charge.rb', line 1605 def seller_protection @seller_protection end |
#transaction_id ⇒ Object (readonly)
A unique ID generated by PayPal for this transaction.
1607 1608 1609 |
# File 'lib/stripe/resources/charge.rb', line 1607 def transaction_id @transaction_id end |
Class Method Details
.field_remappings ⇒ Object
1613 1614 1615 |
# File 'lib/stripe/resources/charge.rb', line 1613 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1609 1610 1611 |
# File 'lib/stripe/resources/charge.rb', line 1609 def self.inner_class_types @inner_class_types = { seller_protection: SellerProtection } end |