Class: Stripe::Charge::PaymentMethodDetails::Payto
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::PaymentMethodDetails::Payto
- Defined in:
- lib/stripe/resources/charge.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bsb_number ⇒ Object
readonly
Bank-State-Branch number of the bank account.
-
#last4 ⇒ Object
readonly
Last four digits of the bank account number.
-
#mandate ⇒ Object
readonly
ID of the mandate used to make this payment.
-
#pay_id ⇒ Object
readonly
The PayID alias for the bank account.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bsb_number ⇒ Object (readonly)
Bank-State-Branch number of the bank account.
1752 1753 1754 |
# File 'lib/stripe/resources/charge.rb', line 1752 def bsb_number @bsb_number end |
#last4 ⇒ Object (readonly)
Last four digits of the bank account number.
1754 1755 1756 |
# File 'lib/stripe/resources/charge.rb', line 1754 def last4 @last4 end |
#mandate ⇒ Object (readonly)
ID of the mandate used to make this payment.
1756 1757 1758 |
# File 'lib/stripe/resources/charge.rb', line 1756 def mandate @mandate end |
#pay_id ⇒ Object (readonly)
The PayID alias for the bank account.
1758 1759 1760 |
# File 'lib/stripe/resources/charge.rb', line 1758 def pay_id @pay_id end |
Class Method Details
.field_remappings ⇒ Object
1764 1765 1766 |
# File 'lib/stripe/resources/charge.rb', line 1764 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1760 1761 1762 |
# File 'lib/stripe/resources/charge.rb', line 1760 def self.inner_class_types @inner_class_types = {} end |