Class: Stripe::Charge::PaymentMethodDetails::Pix

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_transaction_idObject (readonly)

Unique transaction id generated by BCB



1932
1933
1934
# File 'lib/stripe/resources/charge.rb', line 1932

def bank_transaction_id
  @bank_transaction_id
end

#fingerprintObject (readonly)

Uniquely identifies this particular Pix account. You can use this attribute to check whether two Pix accounts are the same.



1934
1935
1936
# File 'lib/stripe/resources/charge.rb', line 1934

def fingerprint
  @fingerprint
end

#mandateObject (readonly)

ID of the multi use Mandate generated by the PaymentIntent or SetupIntent.



1936
1937
1938
# File 'lib/stripe/resources/charge.rb', line 1936

def mandate
  @mandate
end

Class Method Details

.field_remappingsObject



1942
1943
1944
# File 'lib/stripe/resources/charge.rb', line 1942

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1938
1939
1940
# File 'lib/stripe/resources/charge.rb', line 1938

def self.inner_class_types
  @inner_class_types = {}
end