Class: Stripe::Charge::PaymentMethodDetails::RevolutPay::Funding::Card

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#brand ⇒ Object (readonly)

Card brand. Can be American Express, Cartes Bancaires, Diners Club, Discover, Eftpos Australia, Girocard, JCB, MasterCard, UnionPay, Visa, or Unknown.



1683
1684
1685
# File 'lib/stripe/resources/charge.rb', line 1683

def brand
  @brand
end

#country ⇒ Object (readonly)

Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you've collected.



1685
1686
1687
# File 'lib/stripe/resources/charge.rb', line 1685

def country
  @country
end

#exp_month ⇒ Object (readonly)

Two-digit number representing the card's expiration month.



1687
1688
1689
# File 'lib/stripe/resources/charge.rb', line 1687

def exp_month
  @exp_month
end

#exp_year ⇒ Object (readonly)

Four-digit number representing the card's expiration year.



1689
1690
1691
# File 'lib/stripe/resources/charge.rb', line 1689

def exp_year
  @exp_year
end

#funding ⇒ Object (readonly)

Card funding type. Can be credit, debit, prepaid, or unknown.



1691
1692
1693
# File 'lib/stripe/resources/charge.rb', line 1691

def funding
  @funding
end

#last4 ⇒ Object (readonly)

The last four digits of the card.



1693
1694
1695
# File 'lib/stripe/resources/charge.rb', line 1693

def last4
  @last4
end

Class Method Details

.field_remappings ⇒ Object



1699
1700
1701
# File 'lib/stripe/resources/charge.rb', line 1699

def self.field_remappings
  @field_remappings = {}
end

.inner_class_types ⇒ Object



1695
1696
1697
# File 'lib/stripe/resources/charge.rb', line 1695

def self.inner_class_types
  @inner_class_types = {}
end