Class: Stripe::Charge::PaymentMethodDetails::SepaDebit

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_code ⇒ Object (readonly)

Bank code of bank associated with the bank account.



1790
1791
1792
# File 'lib/stripe/resources/charge.rb', line 1790

def bank_code
  @bank_code
end

#branch_code ⇒ Object (readonly)

Branch code of bank associated with the bank account.



1792
1793
1794
# File 'lib/stripe/resources/charge.rb', line 1792

def branch_code
  @branch_code
end

#country ⇒ Object (readonly)

Two-letter ISO code representing the country the bank account is located in.



1794
1795
1796
# File 'lib/stripe/resources/charge.rb', line 1794

def country
  @country
end

#expected_debit_date ⇒ Object (readonly)

Estimated date to debit the customer's bank account. A date string in YYYY-MM-DD format.



1796
1797
1798
# File 'lib/stripe/resources/charge.rb', line 1796

def expected_debit_date
  @expected_debit_date
end

#fingerprint ⇒ Object (readonly)

Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.



1798
1799
1800
# File 'lib/stripe/resources/charge.rb', line 1798

def fingerprint
  @fingerprint
end

#last4 ⇒ Object (readonly)

Last four characters of the IBAN.



1800
1801
1802
# File 'lib/stripe/resources/charge.rb', line 1800

def last4
  @last4
end

#mandate ⇒ Object (readonly)

Find the ID of the mandate used for this payment under the payment_method_details.sepa_debit.mandate property on the Charge. Use this mandate ID to retrieve the Mandate.



1802
1803
1804
# File 'lib/stripe/resources/charge.rb', line 1802

def mandate
  @mandate
end

Class Method Details

.field_remappings ⇒ Object



1808
1809
1810
# File 'lib/stripe/resources/charge.rb', line 1808

def self.field_remappings
  @field_remappings = {}
end

.inner_class_types ⇒ Object



1804
1805
1806
# File 'lib/stripe/resources/charge.rb', line 1804

def self.inner_class_types
  @inner_class_types = {}
end