Class: Stripe::Charge::PaymentMethodDetails::Sofort

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_codeObject (readonly)

Bank code of bank associated with the bank account.



1803
1804
1805
# File 'lib/stripe/resources/charge.rb', line 1803

def bank_code
  @bank_code
end

#bank_nameObject (readonly)

Name of the bank associated with the bank account.



1805
1806
1807
# File 'lib/stripe/resources/charge.rb', line 1805

def bank_name
  @bank_name
end

#bicObject (readonly)

Bank Identifier Code of the bank associated with the bank account.



1807
1808
1809
# File 'lib/stripe/resources/charge.rb', line 1807

def bic
  @bic
end

#countryObject (readonly)

Two-letter ISO code representing the country the bank account is located in.



1809
1810
1811
# File 'lib/stripe/resources/charge.rb', line 1809

def country
  @country
end

#generated_sepa_debitObject (readonly)

The ID of the SEPA Direct Debit PaymentMethod which was generated by this Charge.



1811
1812
1813
# File 'lib/stripe/resources/charge.rb', line 1811

def generated_sepa_debit
  @generated_sepa_debit
end

#generated_sepa_debit_mandateObject (readonly)

The mandate for the SEPA Direct Debit PaymentMethod which was generated by this Charge.



1813
1814
1815
# File 'lib/stripe/resources/charge.rb', line 1813

def generated_sepa_debit_mandate
  @generated_sepa_debit_mandate
end

#iban_last4Object (readonly)

Last four characters of the IBAN.



1815
1816
1817
# File 'lib/stripe/resources/charge.rb', line 1815

def iban_last4
  @iban_last4
end

#preferred_languageObject (readonly)

Preferred language of the SOFORT authorization page that the customer is redirected to. Can be one of de, en, es, fr, it, nl, or pl



1818
1819
1820
# File 'lib/stripe/resources/charge.rb', line 1818

def preferred_language
  @preferred_language
end

#verified_nameObject (readonly)

Owner's verified full name. Values are verified or provided by SOFORT directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



1821
1822
1823
# File 'lib/stripe/resources/charge.rb', line 1821

def verified_name
  @verified_name
end

Class Method Details

.field_remappingsObject



1827
1828
1829
# File 'lib/stripe/resources/charge.rb', line 1827

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1823
1824
1825
# File 'lib/stripe/resources/charge.rb', line 1823

def self.inner_class_types
  @inner_class_types = {}
end