Class: Stripe::Charge::PaymentMethodDetails::StripeBalance
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::PaymentMethodDetails::StripeBalance
- Defined in:
- lib/stripe/resources/charge.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account ⇒ Object
readonly
The connected account ID whose Stripe balance to use as the source of payment.
-
#source_type ⇒ Object
readonly
The [source_type](docs.stripe.com/api/balance/balance_object#balance_object-available-source_types) of the balance.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account ⇒ Object (readonly)
The connected account ID whose Stripe balance to use as the source of payment
1043 1044 1045 |
# File 'lib/stripe/resources/charge.rb', line 1043 def account @account end |
#source_type ⇒ Object (readonly)
The [source_type](docs.stripe.com/api/balance/balance_object#balance_object-available-source_types) of the balance
1045 1046 1047 |
# File 'lib/stripe/resources/charge.rb', line 1045 def source_type @source_type end |