Class: Stripe::Charge::PaymentMethodDetails::Swish
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::PaymentMethodDetails::Swish
- Defined in:
- lib/stripe/resources/charge.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#fingerprint ⇒ Object
readonly
Uniquely identifies the payer’s Swish account.
-
#payment_reference ⇒ Object
readonly
Payer bank reference number for the payment.
-
#verified_phone_last4 ⇒ Object
readonly
The last four digits of the Swish account phone number.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#fingerprint ⇒ Object (readonly)
Uniquely identifies the payer’s Swish account. You can use this attribute to check whether two Swish transactions were paid for by the same payer
2009 2010 2011 |
# File 'lib/stripe/resources/charge.rb', line 2009 def fingerprint @fingerprint end |
#payment_reference ⇒ Object (readonly)
Payer bank reference number for the payment
2011 2012 2013 |
# File 'lib/stripe/resources/charge.rb', line 2011 def payment_reference @payment_reference end |
#verified_phone_last4 ⇒ Object (readonly)
The last four digits of the Swish account phone number
2013 2014 2015 |
# File 'lib/stripe/resources/charge.rb', line 2013 def verified_phone_last4 @verified_phone_last4 end |
Class Method Details
.field_remappings ⇒ Object
2019 2020 2021 |
# File 'lib/stripe/resources/charge.rb', line 2019 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2015 2016 2017 |
# File 'lib/stripe/resources/charge.rb', line 2015 def self.inner_class_types @inner_class_types = {} end |