Class: Stripe::Charge::PaymentMethodDetails::UsBankAccount

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_holder_typeObject (readonly)

Account holder type: individual or company.



1900
1901
1902
# File 'lib/stripe/resources/charge.rb', line 1900

def 
  @account_holder_type
end

#account_typeObject (readonly)

Account type: checkings or savings. Defaults to checking if omitted.



1902
1903
1904
# File 'lib/stripe/resources/charge.rb', line 1902

def 
  @account_type
end

#bank_nameObject (readonly)

Name of the bank associated with the bank account.



1904
1905
1906
# File 'lib/stripe/resources/charge.rb', line 1904

def bank_name
  @bank_name
end

#expected_debit_dateObject (readonly)

Estimated date to debit the customer's bank account. A date string in YYYY-MM-DD format.



1906
1907
1908
# File 'lib/stripe/resources/charge.rb', line 1906

def expected_debit_date
  @expected_debit_date
end

#fingerprintObject (readonly)

Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.



1908
1909
1910
# File 'lib/stripe/resources/charge.rb', line 1908

def fingerprint
  @fingerprint
end

#last4Object (readonly)

Last four digits of the bank account number.



1910
1911
1912
# File 'lib/stripe/resources/charge.rb', line 1910

def last4
  @last4
end

#mandateObject (readonly)

ID of the mandate used to make this payment.



1912
1913
1914
# File 'lib/stripe/resources/charge.rb', line 1912

def mandate
  @mandate
end

#payment_referenceObject (readonly)

Reference number to locate ACH payments with customer's bank.



1914
1915
1916
# File 'lib/stripe/resources/charge.rb', line 1914

def payment_reference
  @payment_reference
end

#routing_numberObject (readonly)

Routing number of the bank account.



1916
1917
1918
# File 'lib/stripe/resources/charge.rb', line 1916

def routing_number
  @routing_number
end

Class Method Details

.field_remappingsObject



1922
1923
1924
# File 'lib/stripe/resources/charge.rb', line 1922

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1918
1919
1920
# File 'lib/stripe/resources/charge.rb', line 1918

def self.inner_class_types
  @inner_class_types = {}
end