Class: Stripe::Charge::PaymentMethodDetails::WechatPay

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#fingerprintObject (readonly)

Uniquely identifies this particular WeChat Pay account. You can use this attribute to check whether two WeChat accounts are the same.



2128
2129
2130
# File 'lib/stripe/resources/charge.rb', line 2128

def fingerprint
  @fingerprint
end

#locationObject (readonly)

ID of the location that this transaction's reader is assigned to.



2130
2131
2132
# File 'lib/stripe/resources/charge.rb', line 2130

def location
  @location
end

#readerObject (readonly)

ID of the reader this transaction was made on.



2132
2133
2134
# File 'lib/stripe/resources/charge.rb', line 2132

def reader
  @reader
end

#transaction_idObject (readonly)

Transaction ID of this particular WeChat Pay transaction.



2134
2135
2136
# File 'lib/stripe/resources/charge.rb', line 2134

def transaction_id
  @transaction_id
end

Class Method Details

.field_remappingsObject



2140
2141
2142
# File 'lib/stripe/resources/charge.rb', line 2140

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2136
2137
2138
# File 'lib/stripe/resources/charge.rb', line 2136

def self.inner_class_types
  @inner_class_types = {}
end