Class: Stripe::Charge::RadarOptions
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::RadarOptions
- Defined in:
- lib/stripe/resources/charge.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#session ⇒ Object
readonly
A [Radar Session](docs.stripe.com/radar/radar-session) is a snapshot of the browser metadata and device details that help Radar make more accurate predictions on your payments.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#session ⇒ Object (readonly)
A [Radar Session](docs.stripe.com/radar/radar-session) is a snapshot of the browser metadata and device details that help Radar make more accurate predictions on your payments.
2112 2113 2114 |
# File 'lib/stripe/resources/charge.rb', line 2112 def session @session end |
Class Method Details
.field_remappings ⇒ Object
2118 2119 2120 |
# File 'lib/stripe/resources/charge.rb', line 2118 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2114 2115 2116 |
# File 'lib/stripe/resources/charge.rb', line 2114 def self.inner_class_types @inner_class_types = {} end |