Class: Stripe::Charge::RetrieveParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::RetrieveParams
- Defined in:
- lib/stripe/resources/charge.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ RetrieveParams
constructor
A new instance of RetrieveParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ RetrieveParams
Returns a new instance of RetrieveParams.
1443 1444 1445 |
# File 'lib/stripe/resources/charge.rb', line 1443 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1441 1442 1443 |
# File 'lib/stripe/resources/charge.rb', line 1441 def @expand end |