Class: Stripe::Charge::SearchParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::SearchParams
- Defined in:
- lib/stripe/resources/charge.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#page ⇒ Object
A cursor for pagination across multiple pages of results.
-
#query ⇒ Object
The search query string.
Instance Method Summary collapse
-
#initialize(expand: nil, limit: nil, page: nil, query: nil) ⇒ SearchParams
constructor
A new instance of SearchParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, limit: nil, page: nil, query: nil) ⇒ SearchParams
Returns a new instance of SearchParams.
3379 3380 3381 3382 3383 3384 |
# File 'lib/stripe/resources/charge.rb', line 3379 def initialize(expand: nil, limit: nil, page: nil, query: nil) @expand = @limit = limit @page = page @query = query end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
3371 3372 3373 |
# File 'lib/stripe/resources/charge.rb', line 3371 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
3373 3374 3375 |
# File 'lib/stripe/resources/charge.rb', line 3373 def limit @limit end |
#page ⇒ Object
A cursor for pagination across multiple pages of results. Don’t include this parameter on the first call. Use the next_page value returned in a previous response to request subsequent results.
3375 3376 3377 |
# File 'lib/stripe/resources/charge.rb', line 3375 def page @page end |
#query ⇒ Object
The search query string. See [search query language](stripe.com/docs/search#search-query-language) and the list of supported [query fields for charges](stripe.com/docs/search#query-fields-for-charges).
3377 3378 3379 |
# File 'lib/stripe/resources/charge.rb', line 3377 def query @query end |