Class: Stripe::Charge::Shipping

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/charge.rb

Defined Under Namespace

Classes: Address

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#addressObject (readonly)

Attribute for field address



2438
2439
2440
# File 'lib/stripe/resources/charge.rb', line 2438

def address
  @address
end

#carrierObject (readonly)

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



2440
2441
2442
# File 'lib/stripe/resources/charge.rb', line 2440

def carrier
  @carrier
end

#nameObject (readonly)

Recipient name.



2442
2443
2444
# File 'lib/stripe/resources/charge.rb', line 2442

def name
  @name
end

#phoneObject (readonly)

Recipient phone (including extension).



2444
2445
2446
# File 'lib/stripe/resources/charge.rb', line 2444

def phone
  @phone
end

#tracking_numberObject (readonly)

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



2446
2447
2448
# File 'lib/stripe/resources/charge.rb', line 2446

def tracking_number
  @tracking_number
end

Class Method Details

.field_remappingsObject



2452
2453
2454
# File 'lib/stripe/resources/charge.rb', line 2452

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2448
2449
2450
# File 'lib/stripe/resources/charge.rb', line 2448

def self.inner_class_types
  @inner_class_types = { address: Address }
end