Class: Stripe::Charge::TransferData

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/charge.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

The amount transferred to the destination account, if specified. By default, the entire charge amount is transferred to the destination account.



2231
2232
2233
# File 'lib/stripe/resources/charge.rb', line 2231

def amount
  @amount
end

#destinationObject (readonly)

ID of an existing, connected Stripe account to transfer funds to if transfer_data was specified in the charge request.



2233
2234
2235
# File 'lib/stripe/resources/charge.rb', line 2233

def destination
  @destination
end

Class Method Details

.field_remappingsObject



2239
2240
2241
# File 'lib/stripe/resources/charge.rb', line 2239

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2235
2236
2237
# File 'lib/stripe/resources/charge.rb', line 2235

def self.inner_class_types
  @inner_class_types = {}
end