Class: Stripe::Charge::UpdateParams::PaymentDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::UpdateParams::PaymentDetails
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: CarRental, EventDetails, Flight, Lodging, Subscription
Instance Attribute Summary collapse
-
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
-
#customer_reference ⇒ Object
Some customers might be required by their company or organization to provide this information.
-
#event_details ⇒ Object
Event details for this PaymentIntent.
-
#flight ⇒ Object
Flight reservation details for this PaymentIntent.
-
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent.
-
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
-
#subscription ⇒ Object
Subscription details for this PaymentIntent.
Instance Method Summary collapse
-
#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
constructor
A new instance of PaymentDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
Returns a new instance of PaymentDetails.
2240 2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 2256 |
# File 'lib/stripe/resources/charge.rb', line 2240 def initialize( car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil ) @car_rental = car_rental @customer_reference = customer_reference @event_details = event_details @flight = flight @lodging = lodging @order_reference = order_reference @subscription = subscription end |
Instance Attribute Details
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
2226 2227 2228 |
# File 'lib/stripe/resources/charge.rb', line 2226 def car_rental @car_rental end |
#customer_reference ⇒ Object
Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.
2228 2229 2230 |
# File 'lib/stripe/resources/charge.rb', line 2228 def customer_reference @customer_reference end |
#event_details ⇒ Object
Event details for this PaymentIntent
2230 2231 2232 |
# File 'lib/stripe/resources/charge.rb', line 2230 def event_details @event_details end |
#flight ⇒ Object
Flight reservation details for this PaymentIntent
2232 2233 2234 |
# File 'lib/stripe/resources/charge.rb', line 2232 def flight @flight end |
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent
2234 2235 2236 |
# File 'lib/stripe/resources/charge.rb', line 2234 def lodging @lodging end |
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
2236 2237 2238 |
# File 'lib/stripe/resources/charge.rb', line 2236 def order_reference @order_reference end |
#subscription ⇒ Object
Subscription details for this PaymentIntent
2238 2239 2240 |
# File 'lib/stripe/resources/charge.rb', line 2238 def subscription @subscription end |