Class: Stripe::Charge::UpdateParams::PaymentDetails::CarRental::Affiliate
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::UpdateParams::PaymentDetails::CarRental::Affiliate
- Defined in:
- lib/stripe/resources/charge.rb
Instance Attribute Summary collapse
-
#name ⇒ Object
The name of the affiliate that originated the purchase.
Instance Method Summary collapse
-
#initialize(name: nil) ⇒ Affiliate
constructor
A new instance of Affiliate.
Methods inherited from RequestParams
Constructor Details
#initialize(name: nil) ⇒ Affiliate
Returns a new instance of Affiliate.
2578 2579 2580 |
# File 'lib/stripe/resources/charge.rb', line 2578 def initialize(name: nil) @name = name end |
Instance Attribute Details
#name ⇒ Object
The name of the affiliate that originated the purchase.
2576 2577 2578 |
# File 'lib/stripe/resources/charge.rb', line 2576 def name @name end |