Class: Stripe::Charge::UpdateParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::UpdateParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
1866 1867 1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 |
# File 'lib/stripe/resources/charge.rb', line 1866 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
1848 1849 1850 |
# File 'lib/stripe/resources/charge.rb', line 1848 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
1850 1851 1852 |
# File 'lib/stripe/resources/charge.rb', line 1850 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
1852 1853 1854 |
# File 'lib/stripe/resources/charge.rb', line 1852 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
1854 1855 1856 |
# File 'lib/stripe/resources/charge.rb', line 1854 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
1856 1857 1858 |
# File 'lib/stripe/resources/charge.rb', line 1856 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
1858 1859 1860 |
# File 'lib/stripe/resources/charge.rb', line 1858 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
1860 1861 1862 |
# File 'lib/stripe/resources/charge.rb', line 1860 def genre @genre end |
#name ⇒ Object
The name of the event.
1862 1863 1864 |
# File 'lib/stripe/resources/charge.rb', line 1862 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
1864 1865 1866 |
# File 'lib/stripe/resources/charge.rb', line 1864 def starts_at @starts_at end |