Class: Stripe::Charge::UpdateParams::PaymentDetails::EventDetails::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



1831
1832
1833
1834
1835
# File 'lib/stripe/resources/charge.rb', line 1831

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



1825
1826
1827
# File 'lib/stripe/resources/charge.rb', line 1825

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



1827
1828
1829
# File 'lib/stripe/resources/charge.rb', line 1827

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



1829
1830
1831
# File 'lib/stripe/resources/charge.rb', line 1829

def phone
  @phone
end