Class: Stripe::Charge::UpdateParams::PaymentDetails::Flight::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



1908
1909
1910
1911
1912
# File 'lib/stripe/resources/charge.rb', line 1908

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



1902
1903
1904
# File 'lib/stripe/resources/charge.rb', line 1902

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



1904
1905
1906
# File 'lib/stripe/resources/charge.rb', line 1904

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



1906
1907
1908
# File 'lib/stripe/resources/charge.rb', line 1906

def phone
  @phone
end