Class: Stripe::Charge::UpdateParams::PaymentDetails::Lodging::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::UpdateParams::PaymentDetails::Lodging::Delivery::Recipient
- Defined in:
- lib/stripe/resources/charge.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
3078 3079 3080 3081 3082 |
# File 'lib/stripe/resources/charge.rb', line 3078 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
3072 3073 3074 |
# File 'lib/stripe/resources/charge.rb', line 3072 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
3074 3075 3076 |
# File 'lib/stripe/resources/charge.rb', line 3074 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
3076 3077 3078 |
# File 'lib/stripe/resources/charge.rb', line 3076 def phone @phone end |