Class: Stripe::ChargeCaptureParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/charge_capture_params.rb

Defined Under Namespace

Classes: PaymentDetails, TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, application_fee: nil, application_fee_amount: nil, expand: nil, payment_details: nil, receipt_email: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil, transfer_group: nil) ⇒ ChargeCaptureParams

Returns a new instance of ChargeCaptureParams.



1776
1777
1778
1779
1780
1781
1782
1783
1784
1785
1786
1787
1788
1789
1790
1791
1792
1793
1794
1795
1796
1797
1798
# File 'lib/stripe/params/charge_capture_params.rb', line 1776

def initialize(
  amount: nil,
  application_fee: nil,
  application_fee_amount: nil,
  expand: nil,
  payment_details: nil,
  receipt_email: nil,
  statement_descriptor: nil,
  statement_descriptor_suffix: nil,
  transfer_data: nil,
  transfer_group: nil
)
  @amount = amount
  @application_fee = application_fee
  @application_fee_amount = application_fee_amount
  @expand = expand
  @payment_details = payment_details
  @receipt_email = receipt_email
  @statement_descriptor = statement_descriptor
  @statement_descriptor_suffix = statement_descriptor_suffix
  @transfer_data = transfer_data
  @transfer_group = transfer_group
end

Instance Attribute Details

#amountObject

The amount to capture, which must be less than or equal to the original amount.



1754
1755
1756
# File 'lib/stripe/params/charge_capture_params.rb', line 1754

def amount
  @amount
end

#application_feeObject

An application fee to add on to this charge.



1756
1757
1758
# File 'lib/stripe/params/charge_capture_params.rb', line 1756

def application_fee
  @application_fee
end

#application_fee_amountObject

An application fee amount to add on to this charge, which must be less than or equal to the original amount.



1758
1759
1760
# File 'lib/stripe/params/charge_capture_params.rb', line 1758

def application_fee_amount
  @application_fee_amount
end

#expandObject

Specifies which fields in the response should be expanded.



1760
1761
1762
# File 'lib/stripe/params/charge_capture_params.rb', line 1760

def expand
  @expand
end

#payment_detailsObject

Provides industry-specific information about the charge.



1762
1763
1764
# File 'lib/stripe/params/charge_capture_params.rb', line 1762

def payment_details
  @payment_details
end

#receipt_emailObject

The email address to send this charge's receipt to. This will override the previously-specified email address for this charge, if one was set. Receipts will not be sent in test mode.



1764
1765
1766
# File 'lib/stripe/params/charge_capture_params.rb', line 1764

def receipt_email
  @receipt_email
end

#statement_descriptorObject

For a non-card charge, text that appears on the customer's statement as the statement descriptor. This value overrides the account's default statement descriptor. For information about requirements, including the 22-character limit, see the Statement Descriptor docs.

For a card charge, this value is ignored unless you don't specify a statement_descriptor_suffix, in which case this value is used as the suffix.



1768
1769
1770
# File 'lib/stripe/params/charge_capture_params.rb', line 1768

def statement_descriptor
  @statement_descriptor
end

#statement_descriptor_suffixObject

Provides information about a card charge. Concatenated to the account's statement descriptor prefix to form the complete statement descriptor that appears on the customer's statement. If the account has no prefix value, the suffix is concatenated to the account's statement descriptor.



1770
1771
1772
# File 'lib/stripe/params/charge_capture_params.rb', line 1770

def statement_descriptor_suffix
  @statement_descriptor_suffix
end

#transfer_dataObject

An optional dictionary including the account to automatically transfer to as part of a destination charge. See the Connect documentation for details.



1772
1773
1774
# File 'lib/stripe/params/charge_capture_params.rb', line 1772

def transfer_data
  @transfer_data
end

#transfer_groupObject

A string that identifies this transaction as part of a group. transfer_group may only be provided if it has not been set. See the Connect documentation for details.



1774
1775
1776
# File 'lib/stripe/params/charge_capture_params.rb', line 1774

def transfer_group
  @transfer_group
end