Class: Stripe::ChargeCaptureParams::PaymentDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/charge_capture_params.rb

Defined Under Namespace

Classes: CarRental, CarRentalDatum, EventDetails, FleetDatum, Flight, FlightDatum, Lodging, LodgingDatum, Subscription

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(car_rental: nil, car_rental_data: nil, customer_reference: nil, event_details: nil, fleet_data: nil, flight: nil, flight_data: nil, lodging: nil, lodging_data: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails

Returns a new instance of PaymentDetails.



1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
# File 'lib/stripe/params/charge_capture_params.rb', line 1718

def initialize(
  car_rental: nil,
  car_rental_data: nil,
  customer_reference: nil,
  event_details: nil,
  fleet_data: nil,
  flight: nil,
  flight_data: nil,
  lodging: nil,
  lodging_data: nil,
  order_reference: nil,
  subscription: nil
)
  @car_rental = car_rental
  @car_rental_data = car_rental_data
  @customer_reference = customer_reference
  @event_details = event_details
  @fleet_data = fleet_data
  @flight = flight
  @flight_data = flight_data
  @lodging = lodging
  @lodging_data = lodging_data
  @order_reference = order_reference
  @subscription = subscription
end

Instance Attribute Details

#car_rentalObject

Car rental details for this PaymentIntent.



1692
1693
1694
# File 'lib/stripe/params/charge_capture_params.rb', line 1692

def car_rental
  @car_rental
end

#car_rental_dataObject

Car rental data for this PaymentIntent.



1694
1695
1696
# File 'lib/stripe/params/charge_capture_params.rb', line 1694

def car_rental_data
  @car_rental_data
end

#customer_referenceObject

A unique value to identify the customer. This field is available only for card payments.

This field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks.



1698
1699
1700
# File 'lib/stripe/params/charge_capture_params.rb', line 1698

def customer_reference
  @customer_reference
end

#event_detailsObject

Event details for this PaymentIntent



1700
1701
1702
# File 'lib/stripe/params/charge_capture_params.rb', line 1700

def event_details
  @event_details
end

#fleet_dataObject

Fleet data for this PaymentIntent.



1702
1703
1704
# File 'lib/stripe/params/charge_capture_params.rb', line 1702

def fleet_data
  @fleet_data
end

#flightObject

Flight reservation details for this PaymentIntent



1704
1705
1706
# File 'lib/stripe/params/charge_capture_params.rb', line 1704

def flight
  @flight
end

#flight_dataObject

Flight data for this PaymentIntent.



1706
1707
1708
# File 'lib/stripe/params/charge_capture_params.rb', line 1706

def flight_data
  @flight_data
end

#lodgingObject

Lodging reservation details for this PaymentIntent



1708
1709
1710
# File 'lib/stripe/params/charge_capture_params.rb', line 1708

def lodging
  @lodging
end

#lodging_dataObject

Lodging data for this PaymentIntent.



1710
1711
1712
# File 'lib/stripe/params/charge_capture_params.rb', line 1710

def lodging_data
  @lodging_data
end

#order_referenceObject

A unique value assigned by the business to identify the transaction. Required for L2 and L3 rates.

For Cards, this field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks. For Klarna, this field is truncated to 255 characters and is visible to customers when they view the order in the Klarna app.



1714
1715
1716
# File 'lib/stripe/params/charge_capture_params.rb', line 1714

def order_reference
  @order_reference
end

#subscriptionObject

Subscription details for this PaymentIntent



1716
1717
1718
# File 'lib/stripe/params/charge_capture_params.rb', line 1716

def subscription
  @subscription
end