Class: Stripe::ChargeCaptureParams::PaymentDetails::CarRental

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/charge_capture_params.rb

Defined Under Namespace

Classes: Affiliate, Delivery, Distance, Driver, PickupAddress, ReturnAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil) ⇒ CarRental

Returns a new instance of CarRental.



180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/stripe/params/charge_capture_params.rb', line 180

def initialize(
  affiliate: nil,
  booking_number: nil,
  car_class_code: nil,
  car_make: nil,
  car_model: nil,
  company: nil,
  customer_service_phone_number: nil,
  days_rented: nil,
  delivery: nil,
  distance: nil,
  drivers: nil,
  extra_charges: nil,
  no_show: nil,
  pickup_address: nil,
  pickup_at: nil,
  pickup_location_name: nil,
  rate_amount: nil,
  rate_interval: nil,
  renter_name: nil,
  return_address: nil,
  return_at: nil,
  return_location_name: nil,
  tax_exempt: nil,
  vehicle_identification_number: nil
)
  @affiliate = affiliate
  @booking_number = booking_number
  @car_class_code = car_class_code
  @car_make = car_make
  @car_model = car_model
  @company = company
  @customer_service_phone_number = customer_service_phone_number
  @days_rented = days_rented
  @delivery = delivery
  @distance = distance
  @drivers = drivers
  @extra_charges = extra_charges
  @no_show = no_show
  @pickup_address = pickup_address
  @pickup_at = pickup_at
  @pickup_location_name = pickup_location_name
  @rate_amount = rate_amount
  @rate_interval = rate_interval
  @renter_name = renter_name
  @return_address = return_address
  @return_at = return_at
  @return_location_name = return_location_name
  @tax_exempt = tax_exempt
  @vehicle_identification_number = vehicle_identification_number
end

Instance Attribute Details

#affiliateObject

Affiliate details for this purchase.



132
133
134
# File 'lib/stripe/params/charge_capture_params.rb', line 132

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the car rental.



134
135
136
# File 'lib/stripe/params/charge_capture_params.rb', line 134

def booking_number
  @booking_number
end

#car_class_codeObject

Class code of the car.



136
137
138
# File 'lib/stripe/params/charge_capture_params.rb', line 136

def car_class_code
  @car_class_code
end

#car_makeObject

Make of the car.



138
139
140
# File 'lib/stripe/params/charge_capture_params.rb', line 138

def car_make
  @car_make
end

#car_modelObject

Model of the car.



140
141
142
# File 'lib/stripe/params/charge_capture_params.rb', line 140

def car_model
  @car_model
end

#companyObject

The name of the rental car company.



142
143
144
# File 'lib/stripe/params/charge_capture_params.rb', line 142

def company
  @company
end

#customer_service_phone_numberObject

The customer service phone number of the car rental company.



144
145
146
# File 'lib/stripe/params/charge_capture_params.rb', line 144

def customer_service_phone_number
  @customer_service_phone_number
end

#days_rentedObject

Number of days the car is being rented.



146
147
148
# File 'lib/stripe/params/charge_capture_params.rb', line 146

def days_rented
  @days_rented
end

#deliveryObject

Delivery details for this purchase.



148
149
150
# File 'lib/stripe/params/charge_capture_params.rb', line 148

def delivery
  @delivery
end

#distanceObject

The details of the distance traveled during the rental period.



150
151
152
# File 'lib/stripe/params/charge_capture_params.rb', line 150

def distance
  @distance
end

#driversObject

The details of the passengers in the travel reservation



152
153
154
# File 'lib/stripe/params/charge_capture_params.rb', line 152

def drivers
  @drivers
end

#extra_chargesObject

List of additional charges being billed.



154
155
156
# File 'lib/stripe/params/charge_capture_params.rb', line 154

def extra_charges
  @extra_charges
end

#no_showObject

Indicates if the customer did not keep nor cancel their booking.



156
157
158
# File 'lib/stripe/params/charge_capture_params.rb', line 156

def no_show
  @no_show
end

#pickup_addressObject

Car pick-up address.



158
159
160
# File 'lib/stripe/params/charge_capture_params.rb', line 158

def pickup_address
  @pickup_address
end

#pickup_atObject

Car pick-up time. Measured in seconds since the Unix epoch.



160
161
162
# File 'lib/stripe/params/charge_capture_params.rb', line 160

def pickup_at
  @pickup_at
end

#pickup_location_nameObject

Name of the pickup location.



162
163
164
# File 'lib/stripe/params/charge_capture_params.rb', line 162

def pickup_location_name
  @pickup_location_name
end

#rate_amountObject

Rental rate.



164
165
166
# File 'lib/stripe/params/charge_capture_params.rb', line 164

def rate_amount
  @rate_amount
end

#rate_intervalObject

The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`



166
167
168
# File 'lib/stripe/params/charge_capture_params.rb', line 166

def rate_interval
  @rate_interval
end

#renter_nameObject

The name of the person or entity renting the car.



168
169
170
# File 'lib/stripe/params/charge_capture_params.rb', line 168

def renter_name
  @renter_name
end

#return_addressObject

Car return address.



170
171
172
# File 'lib/stripe/params/charge_capture_params.rb', line 170

def return_address
  @return_address
end

#return_atObject

Car return time. Measured in seconds since the Unix epoch.



172
173
174
# File 'lib/stripe/params/charge_capture_params.rb', line 172

def return_at
  @return_at
end

#return_location_nameObject

Name of the return location.



174
175
176
# File 'lib/stripe/params/charge_capture_params.rb', line 174

def return_location_name
  @return_location_name
end

#tax_exemptObject

Indicates whether the goods or services are tax-exempt or tax is not collected.



176
177
178
# File 'lib/stripe/params/charge_capture_params.rb', line 176

def tax_exempt
  @tax_exempt
end

#vehicle_identification_numberObject

The vehicle identification number.



178
179
180
# File 'lib/stripe/params/charge_capture_params.rb', line 178

def vehicle_identification_number
  @vehicle_identification_number
end