Class: Stripe::ChargeCaptureParams::PaymentDetails::CarRental::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/charge_capture_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



26
27
28
29
30
# File 'lib/stripe/params/charge_capture_params.rb', line 26

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



20
21
22
# File 'lib/stripe/params/charge_capture_params.rb', line 20

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



22
23
24
# File 'lib/stripe/params/charge_capture_params.rb', line 22

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



24
25
26
# File 'lib/stripe/params/charge_capture_params.rb', line 24

def phone
  @phone
end