Class: Stripe::ChargeCaptureParams::PaymentDetails::CarRental::Driver
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ChargeCaptureParams::PaymentDetails::CarRental::Driver
- Defined in:
- lib/stripe/params/charge_capture_params.rb
Instance Attribute Summary collapse
-
#driver_identification_number ⇒ Object
Driver’s identification number.
-
#driver_tax_number ⇒ Object
Driver’s tax number.
-
#name ⇒ Object
Full name of the person or entity on the car reservation.
Instance Method Summary collapse
-
#initialize(driver_identification_number: nil, driver_tax_number: nil, name: nil) ⇒ Driver
constructor
A new instance of Driver.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(driver_identification_number: nil, driver_tax_number: nil, name: nil) ⇒ Driver
Returns a new instance of Driver.
63 64 65 66 67 |
# File 'lib/stripe/params/charge_capture_params.rb', line 63 def initialize(driver_identification_number: nil, driver_tax_number: nil, name: nil) @driver_identification_number = driver_identification_number @driver_tax_number = driver_tax_number @name = name end |
Instance Attribute Details
#driver_identification_number ⇒ Object
Driver’s identification number.
57 58 59 |
# File 'lib/stripe/params/charge_capture_params.rb', line 57 def driver_identification_number @driver_identification_number end |
#driver_tax_number ⇒ Object
Driver’s tax number.
59 60 61 |
# File 'lib/stripe/params/charge_capture_params.rb', line 59 def driver_tax_number @driver_tax_number end |
#name ⇒ Object
Full name of the person or entity on the car reservation.
61 62 63 |
# File 'lib/stripe/params/charge_capture_params.rb', line 61 def name @name end |