Class: Stripe::ChargeCaptureParams::PaymentDetails::CarRentalDatum
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ChargeCaptureParams::PaymentDetails::CarRentalDatum
- Defined in:
- lib/stripe/params/charge_capture_params.rb
Defined Under Namespace
Classes: Affiliate, Distance, Driver, DropOff, Insurance, Pickup, Total, Vehicle
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate (such as travel agency) details for the rental.
-
#booking_number ⇒ Object
Booking confirmation number for the car rental.
-
#carrier_name ⇒ Object
Name of the car rental company.
-
#customer_service_phone_number ⇒ Object
Customer service phone number for the car rental company.
-
#days_rented ⇒ Object
Number of days the car is being rented.
-
#distance ⇒ Object
Distance details for the rental.
-
#drivers ⇒ Object
List of drivers for the rental.
-
#drop_off ⇒ Object
Drop-off location details.
-
#insurances ⇒ Object
Insurance details for the rental.
-
#no_show_indicator ⇒ Object
Indicates if the customer was a no-show.
-
#pickup ⇒ Object
Pickup location details.
-
#renter_name ⇒ Object
Name of the person renting the vehicle.
-
#total ⇒ Object
Total cost breakdown for the rental.
-
#vehicle ⇒ Object
Vehicle details for the rental.
Instance Method Summary collapse
-
#initialize(affiliate: nil, booking_number: nil, carrier_name: nil, customer_service_phone_number: nil, days_rented: nil, distance: nil, drivers: nil, drop_off: nil, insurances: nil, no_show_indicator: nil, pickup: nil, renter_name: nil, total: nil, vehicle: nil) ⇒ CarRentalDatum
constructor
A new instance of CarRentalDatum.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate: nil, booking_number: nil, carrier_name: nil, customer_service_phone_number: nil, days_rented: nil, distance: nil, drivers: nil, drop_off: nil, insurances: nil, no_show_indicator: nil, pickup: nil, renter_name: nil, total: nil, vehicle: nil) ⇒ CarRentalDatum
Returns a new instance of CarRentalDatum.
558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 |
# File 'lib/stripe/params/charge_capture_params.rb', line 558 def initialize( affiliate: nil, booking_number: nil, carrier_name: nil, customer_service_phone_number: nil, days_rented: nil, distance: nil, drivers: nil, drop_off: nil, insurances: nil, no_show_indicator: nil, pickup: nil, renter_name: nil, total: nil, vehicle: nil ) @affiliate = affiliate @booking_number = booking_number @carrier_name = carrier_name @customer_service_phone_number = customer_service_phone_number @days_rented = days_rented @distance = distance @drivers = drivers @drop_off = drop_off @insurances = insurances @no_show_indicator = no_show_indicator @pickup = pickup @renter_name = renter_name @total = total @vehicle = vehicle end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate (such as travel agency) details for the rental.
530 531 532 |
# File 'lib/stripe/params/charge_capture_params.rb', line 530 def affiliate @affiliate end |
#booking_number ⇒ Object
Booking confirmation number for the car rental.
532 533 534 |
# File 'lib/stripe/params/charge_capture_params.rb', line 532 def booking_number @booking_number end |
#carrier_name ⇒ Object
Name of the car rental company.
534 535 536 |
# File 'lib/stripe/params/charge_capture_params.rb', line 534 def carrier_name @carrier_name end |
#customer_service_phone_number ⇒ Object
Customer service phone number for the car rental company.
536 537 538 |
# File 'lib/stripe/params/charge_capture_params.rb', line 536 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object
Number of days the car is being rented.
538 539 540 |
# File 'lib/stripe/params/charge_capture_params.rb', line 538 def days_rented @days_rented end |
#distance ⇒ Object
Distance details for the rental.
540 541 542 |
# File 'lib/stripe/params/charge_capture_params.rb', line 540 def distance @distance end |
#drivers ⇒ Object
List of drivers for the rental.
542 543 544 |
# File 'lib/stripe/params/charge_capture_params.rb', line 542 def drivers @drivers end |
#drop_off ⇒ Object
Drop-off location details.
544 545 546 |
# File 'lib/stripe/params/charge_capture_params.rb', line 544 def drop_off @drop_off end |
#insurances ⇒ Object
Insurance details for the rental.
546 547 548 |
# File 'lib/stripe/params/charge_capture_params.rb', line 546 def insurances @insurances end |
#no_show_indicator ⇒ Object
Indicates if the customer was a no-show.
548 549 550 |
# File 'lib/stripe/params/charge_capture_params.rb', line 548 def no_show_indicator @no_show_indicator end |
#pickup ⇒ Object
Pickup location details.
550 551 552 |
# File 'lib/stripe/params/charge_capture_params.rb', line 550 def pickup @pickup end |
#renter_name ⇒ Object
Name of the person renting the vehicle.
552 553 554 |
# File 'lib/stripe/params/charge_capture_params.rb', line 552 def renter_name @renter_name end |
#total ⇒ Object
Total cost breakdown for the rental.
554 555 556 |
# File 'lib/stripe/params/charge_capture_params.rb', line 554 def total @total end |
#vehicle ⇒ Object
Vehicle details for the rental.
556 557 558 |
# File 'lib/stripe/params/charge_capture_params.rb', line 556 def vehicle @vehicle end |