Class: Stripe::ChargeCaptureParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ChargeCaptureParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/params/charge_capture_params.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 |
# File 'lib/stripe/params/charge_capture_params.rb', line 676 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
658 659 660 |
# File 'lib/stripe/params/charge_capture_params.rb', line 658 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
660 661 662 |
# File 'lib/stripe/params/charge_capture_params.rb', line 660 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
662 663 664 |
# File 'lib/stripe/params/charge_capture_params.rb', line 662 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
664 665 666 |
# File 'lib/stripe/params/charge_capture_params.rb', line 664 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
666 667 668 |
# File 'lib/stripe/params/charge_capture_params.rb', line 666 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
668 669 670 |
# File 'lib/stripe/params/charge_capture_params.rb', line 668 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
670 671 672 |
# File 'lib/stripe/params/charge_capture_params.rb', line 670 def genre @genre end |
#name ⇒ Object
The name of the event.
672 673 674 |
# File 'lib/stripe/params/charge_capture_params.rb', line 672 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
674 675 676 |
# File 'lib/stripe/params/charge_capture_params.rb', line 674 def starts_at @starts_at end |