Class: Stripe::ChargeCaptureParams::PaymentDetails::EventDetails::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/charge_capture_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



641
642
643
644
645
# File 'lib/stripe/params/charge_capture_params.rb', line 641

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



635
636
637
# File 'lib/stripe/params/charge_capture_params.rb', line 635

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



637
638
639
# File 'lib/stripe/params/charge_capture_params.rb', line 637

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



639
640
641
# File 'lib/stripe/params/charge_capture_params.rb', line 639

def phone
  @phone
end