Class: Stripe::ChargeCaptureParams::PaymentDetails::FlightDatum
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ChargeCaptureParams::PaymentDetails::FlightDatum
- Defined in:
- lib/stripe/params/charge_capture_params.rb
Defined Under Namespace
Classes: Affiliate, Insurance, Passenger, Segment, Total
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details if applicable.
-
#booking_number ⇒ Object
Reservation reference.
-
#computerized_reservation_system ⇒ Object
Computerized reservation system used to make the reservation and purchase the ticket.
-
#endorsements_and_restrictions ⇒ Object
Ticket restrictions.
-
#insurances ⇒ Object
List of insurances.
-
#passengers ⇒ Object
List of passengers.
-
#segments ⇒ Object
List of flight segments.
-
#ticket_electronically_issued_indicator ⇒ Object
Electronic ticket indicator.
-
#total ⇒ Object
Total cost breakdown.
-
#transaction_type ⇒ Object
Type of flight transaction.
Instance Method Summary collapse
-
#initialize(affiliate: nil, booking_number: nil, computerized_reservation_system: nil, endorsements_and_restrictions: nil, insurances: nil, passengers: nil, segments: nil, ticket_electronically_issued_indicator: nil, total: nil, transaction_type: nil) ⇒ FlightDatum
constructor
A new instance of FlightDatum.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate: nil, booking_number: nil, computerized_reservation_system: nil, endorsements_and_restrictions: nil, insurances: nil, passengers: nil, segments: nil, ticket_electronically_issued_indicator: nil, total: nil, transaction_type: nil) ⇒ FlightDatum
Returns a new instance of FlightDatum.
1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 1177 1178 1179 |
# File 'lib/stripe/params/charge_capture_params.rb', line 1157 def initialize( affiliate: nil, booking_number: nil, computerized_reservation_system: nil, endorsements_and_restrictions: nil, insurances: nil, passengers: nil, segments: nil, ticket_electronically_issued_indicator: nil, total: nil, transaction_type: nil ) @affiliate = affiliate @booking_number = booking_number @computerized_reservation_system = computerized_reservation_system @endorsements_and_restrictions = endorsements_and_restrictions @insurances = insurances @passengers = passengers @segments = segments @ticket_electronically_issued_indicator = ticket_electronically_issued_indicator @total = total @transaction_type = transaction_type end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details if applicable.
1137 1138 1139 |
# File 'lib/stripe/params/charge_capture_params.rb', line 1137 def affiliate @affiliate end |
#booking_number ⇒ Object
Reservation reference.
1139 1140 1141 |
# File 'lib/stripe/params/charge_capture_params.rb', line 1139 def booking_number @booking_number end |
#computerized_reservation_system ⇒ Object
Computerized reservation system used to make the reservation and purchase the ticket.
1141 1142 1143 |
# File 'lib/stripe/params/charge_capture_params.rb', line 1141 def computerized_reservation_system @computerized_reservation_system end |
#endorsements_and_restrictions ⇒ Object
Ticket restrictions.
1143 1144 1145 |
# File 'lib/stripe/params/charge_capture_params.rb', line 1143 def endorsements_and_restrictions @endorsements_and_restrictions end |
#insurances ⇒ Object
List of insurances.
1145 1146 1147 |
# File 'lib/stripe/params/charge_capture_params.rb', line 1145 def insurances @insurances end |
#passengers ⇒ Object
List of passengers.
1147 1148 1149 |
# File 'lib/stripe/params/charge_capture_params.rb', line 1147 def passengers @passengers end |
#segments ⇒ Object
List of flight segments.
1149 1150 1151 |
# File 'lib/stripe/params/charge_capture_params.rb', line 1149 def segments @segments end |
#ticket_electronically_issued_indicator ⇒ Object
Electronic ticket indicator.
1151 1152 1153 |
# File 'lib/stripe/params/charge_capture_params.rb', line 1151 def ticket_electronically_issued_indicator @ticket_electronically_issued_indicator end |
#total ⇒ Object
Total cost breakdown.
1153 1154 1155 |
# File 'lib/stripe/params/charge_capture_params.rb', line 1153 def total @total end |
#transaction_type ⇒ Object
Type of flight transaction.
1155 1156 1157 |
# File 'lib/stripe/params/charge_capture_params.rb', line 1155 def transaction_type @transaction_type end |