Class: Stripe::ChargeCaptureParams::PaymentDetails::FlightDatum::Affiliate
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ChargeCaptureParams::PaymentDetails::FlightDatum::Affiliate
- Defined in:
- lib/stripe/params/charge_capture_params.rb
Instance Attribute Summary collapse
-
#code ⇒ Object
Affiliate partner code.
-
#name ⇒ Object
Name of affiliate partner.
-
#travel_authorization_code ⇒ Object
Code provided by the company to a travel agent authorizing ticket issuance.
Instance Method Summary collapse
-
#initialize(code: nil, name: nil, travel_authorization_code: nil) ⇒ Affiliate
constructor
A new instance of Affiliate.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(code: nil, name: nil, travel_authorization_code: nil) ⇒ Affiliate
Returns a new instance of Affiliate.
829 830 831 832 833 |
# File 'lib/stripe/params/charge_capture_params.rb', line 829 def initialize(code: nil, name: nil, travel_authorization_code: nil) @code = code @name = name @travel_authorization_code = end |
Instance Attribute Details
#code ⇒ Object
Affiliate partner code.
823 824 825 |
# File 'lib/stripe/params/charge_capture_params.rb', line 823 def code @code end |
#name ⇒ Object
Name of affiliate partner.
825 826 827 |
# File 'lib/stripe/params/charge_capture_params.rb', line 825 def name @name end |
#travel_authorization_code ⇒ Object
Code provided by the company to a travel agent authorizing ticket issuance.
827 828 829 |
# File 'lib/stripe/params/charge_capture_params.rb', line 827 def @travel_authorization_code end |