Class: Stripe::ChargeCaptureParams::PaymentDetails::Lodging

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/charge_capture_params.rb

Defined Under Namespace

Classes: Address, Affiliate, Delivery, Passenger

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging

Returns a new instance of Lodging.



1300
1301
1302
1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
1315
1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
1342
1343
1344
# File 'lib/stripe/params/charge_capture_params.rb', line 1300

def initialize(
  address: nil,
  adults: nil,
  affiliate: nil,
  booking_number: nil,
  category: nil,
  checkin_at: nil,
  checkout_at: nil,
  customer_service_phone_number: nil,
  daily_room_rate_amount: nil,
  delivery: nil,
  extra_charges: nil,
  fire_safety_act_compliance: nil,
  name: nil,
  no_show: nil,
  number_of_rooms: nil,
  passengers: nil,
  property_phone_number: nil,
  room_class: nil,
  room_nights: nil,
  total_room_tax_amount: nil,
  total_tax_amount: nil
)
  @address = address
  @adults = adults
  @affiliate = affiliate
  @booking_number = booking_number
  @category = category
  @checkin_at = checkin_at
  @checkout_at = checkout_at
  @customer_service_phone_number = customer_service_phone_number
  @daily_room_rate_amount = daily_room_rate_amount
  @delivery = delivery
  @extra_charges = extra_charges
  @fire_safety_act_compliance = fire_safety_act_compliance
  @name = name
  @no_show = no_show
  @number_of_rooms = number_of_rooms
  @passengers = passengers
  @property_phone_number = property_phone_number
  @room_class = room_class
  @room_nights = room_nights
  @total_room_tax_amount = total_room_tax_amount
  @total_tax_amount = total_tax_amount
end

Instance Attribute Details

#addressObject

The lodging location’s address.



1258
1259
1260
# File 'lib/stripe/params/charge_capture_params.rb', line 1258

def address
  @address
end

#adultsObject

The number of adults on the booking



1260
1261
1262
# File 'lib/stripe/params/charge_capture_params.rb', line 1260

def adults
  @adults
end

#affiliateObject

Affiliate details for this purchase.



1262
1263
1264
# File 'lib/stripe/params/charge_capture_params.rb', line 1262

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the lodging reservation.



1264
1265
1266
# File 'lib/stripe/params/charge_capture_params.rb', line 1264

def booking_number
  @booking_number
end

#categoryObject

The lodging category



1266
1267
1268
# File 'lib/stripe/params/charge_capture_params.rb', line 1266

def category
  @category
end

#checkin_atObject

Lodging check-in time. Measured in seconds since the Unix epoch.



1268
1269
1270
# File 'lib/stripe/params/charge_capture_params.rb', line 1268

def checkin_at
  @checkin_at
end

#checkout_atObject

Lodging check-out time. Measured in seconds since the Unix epoch.



1270
1271
1272
# File 'lib/stripe/params/charge_capture_params.rb', line 1270

def checkout_at
  @checkout_at
end

#customer_service_phone_numberObject

The customer service phone number of the lodging company.



1272
1273
1274
# File 'lib/stripe/params/charge_capture_params.rb', line 1272

def customer_service_phone_number
  @customer_service_phone_number
end

#daily_room_rate_amountObject

The daily lodging room rate.



1274
1275
1276
# File 'lib/stripe/params/charge_capture_params.rb', line 1274

def daily_room_rate_amount
  @daily_room_rate_amount
end

#deliveryObject

Delivery details for this purchase.



1276
1277
1278
# File 'lib/stripe/params/charge_capture_params.rb', line 1276

def delivery
  @delivery
end

#extra_chargesObject

List of additional charges being billed.



1278
1279
1280
# File 'lib/stripe/params/charge_capture_params.rb', line 1278

def extra_charges
  @extra_charges
end

#fire_safety_act_complianceObject

Indicates whether the lodging location is compliant with the Fire Safety Act.



1280
1281
1282
# File 'lib/stripe/params/charge_capture_params.rb', line 1280

def fire_safety_act_compliance
  @fire_safety_act_compliance
end

#nameObject

The name of the lodging location.



1282
1283
1284
# File 'lib/stripe/params/charge_capture_params.rb', line 1282

def name
  @name
end

#no_showObject

Indicates if the customer did not keep their booking while failing to cancel the reservation.



1284
1285
1286
# File 'lib/stripe/params/charge_capture_params.rb', line 1284

def no_show
  @no_show
end

#number_of_roomsObject

The number of rooms on the booking



1286
1287
1288
# File 'lib/stripe/params/charge_capture_params.rb', line 1286

def number_of_rooms
  @number_of_rooms
end

#passengersObject

The details of the passengers in the travel reservation



1288
1289
1290
# File 'lib/stripe/params/charge_capture_params.rb', line 1288

def passengers
  @passengers
end

#property_phone_numberObject

The phone number of the lodging location.



1290
1291
1292
# File 'lib/stripe/params/charge_capture_params.rb', line 1290

def property_phone_number
  @property_phone_number
end

#room_classObject

The room class for this purchase.



1292
1293
1294
# File 'lib/stripe/params/charge_capture_params.rb', line 1292

def room_class
  @room_class
end

#room_nightsObject

The number of room nights



1294
1295
1296
# File 'lib/stripe/params/charge_capture_params.rb', line 1294

def room_nights
  @room_nights
end

#total_room_tax_amountObject

The total tax amount associating with the room reservation.



1296
1297
1298
# File 'lib/stripe/params/charge_capture_params.rb', line 1296

def total_room_tax_amount
  @total_room_tax_amount
end

#total_tax_amountObject

The total tax amount



1298
1299
1300
# File 'lib/stripe/params/charge_capture_params.rb', line 1298

def total_tax_amount
  @total_tax_amount
end