Class: Stripe::ChargeCaptureParams::PaymentDetails::Lodging::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/charge_capture_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



1232
1233
1234
1235
1236
# File 'lib/stripe/params/charge_capture_params.rb', line 1232

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



1226
1227
1228
# File 'lib/stripe/params/charge_capture_params.rb', line 1226

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



1228
1229
1230
# File 'lib/stripe/params/charge_capture_params.rb', line 1228

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



1230
1231
1232
# File 'lib/stripe/params/charge_capture_params.rb', line 1230

def phone
  @phone
end