Class: Stripe::ChargeCaptureParams::PaymentDetails::Lodging::Passenger
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ChargeCaptureParams::PaymentDetails::Lodging::Passenger
- Defined in:
- lib/stripe/params/charge_capture_params.rb
Instance Attribute Summary collapse
-
#name ⇒ Object
Full name of the person or entity on the lodging reservation.
Instance Method Summary collapse
-
#initialize(name: nil) ⇒ Passenger
constructor
A new instance of Passenger.
Methods inherited from RequestParams
Constructor Details
#initialize(name: nil) ⇒ Passenger
Returns a new instance of Passenger.
533 534 535 |
# File 'lib/stripe/params/charge_capture_params.rb', line 533 def initialize(name: nil) @name = name end |
Instance Attribute Details
#name ⇒ Object
Full name of the person or entity on the lodging reservation.
531 532 533 |
# File 'lib/stripe/params/charge_capture_params.rb', line 531 def name @name end |