Class: Stripe::ChargeCaptureParams::PaymentDetails::LodgingDatum
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ChargeCaptureParams::PaymentDetails::LodgingDatum
- Defined in:
- lib/stripe/params/charge_capture_params.rb
Defined Under Namespace
Classes: Accommodation, Affiliate, Guest, Host, Insurance, Total
Instance Attribute Summary collapse
-
#accommodation ⇒ Object
Accommodation details for the lodging.
-
#affiliate ⇒ Object
Affiliate details if applicable.
-
#booking_number ⇒ Object
Booking confirmation number for the lodging.
-
#checkin_at ⇒ Object
Check-in date.
-
#checkout_at ⇒ Object
Check-out date.
-
#customer_service_phone_number ⇒ Object
Customer service phone number for the lodging company.
-
#fire_safety_act_compliance_indicator ⇒ Object
Whether the lodging is compliant with any hotel fire safety regulations.
-
#guests ⇒ Object
List of guests for the lodging.
-
#host ⇒ Object
Host details for the lodging.
-
#insurances ⇒ Object
List of insurances for the lodging.
-
#no_show_indicator ⇒ Object
Whether the renter is a no-show.
-
#renter_id_number ⇒ Object
Renter ID number for the lodging.
-
#renter_name ⇒ Object
Renter name for the lodging.
-
#total ⇒ Object
Total details for the lodging.
Instance Method Summary collapse
-
#initialize(accommodation: nil, affiliate: nil, booking_number: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, fire_safety_act_compliance_indicator: nil, guests: nil, host: nil, insurances: nil, no_show_indicator: nil, renter_id_number: nil, renter_name: nil, total: nil) ⇒ LodgingDatum
constructor
A new instance of LodgingDatum.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(accommodation: nil, affiliate: nil, booking_number: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, fire_safety_act_compliance_indicator: nil, guests: nil, host: nil, insurances: nil, no_show_indicator: nil, renter_id_number: nil, renter_name: nil, total: nil) ⇒ LodgingDatum
Returns a new instance of LodgingDatum.
1608 1609 1610 1611 1612 1613 1614 1615 1616 1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 1628 1629 1630 1631 1632 1633 1634 1635 1636 1637 1638 |
# File 'lib/stripe/params/charge_capture_params.rb', line 1608 def initialize( accommodation: nil, affiliate: nil, booking_number: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, fire_safety_act_compliance_indicator: nil, guests: nil, host: nil, insurances: nil, no_show_indicator: nil, renter_id_number: nil, renter_name: nil, total: nil ) @accommodation = accommodation @affiliate = affiliate @booking_number = booking_number @checkin_at = checkin_at @checkout_at = checkout_at @customer_service_phone_number = customer_service_phone_number @fire_safety_act_compliance_indicator = fire_safety_act_compliance_indicator @guests = guests @host = host @insurances = insurances @no_show_indicator = no_show_indicator @renter_id_number = renter_id_number @renter_name = renter_name @total = total end |
Instance Attribute Details
#accommodation ⇒ Object
Accommodation details for the lodging.
1580 1581 1582 |
# File 'lib/stripe/params/charge_capture_params.rb', line 1580 def accommodation @accommodation end |
#affiliate ⇒ Object
Affiliate details if applicable.
1582 1583 1584 |
# File 'lib/stripe/params/charge_capture_params.rb', line 1582 def affiliate @affiliate end |
#booking_number ⇒ Object
Booking confirmation number for the lodging.
1584 1585 1586 |
# File 'lib/stripe/params/charge_capture_params.rb', line 1584 def booking_number @booking_number end |
#checkin_at ⇒ Object
Check-in date.
1586 1587 1588 |
# File 'lib/stripe/params/charge_capture_params.rb', line 1586 def checkin_at @checkin_at end |
#checkout_at ⇒ Object
Check-out date.
1588 1589 1590 |
# File 'lib/stripe/params/charge_capture_params.rb', line 1588 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object
Customer service phone number for the lodging company.
1590 1591 1592 |
# File 'lib/stripe/params/charge_capture_params.rb', line 1590 def customer_service_phone_number @customer_service_phone_number end |
#fire_safety_act_compliance_indicator ⇒ Object
Whether the lodging is compliant with any hotel fire safety regulations.
1592 1593 1594 |
# File 'lib/stripe/params/charge_capture_params.rb', line 1592 def fire_safety_act_compliance_indicator @fire_safety_act_compliance_indicator end |
#guests ⇒ Object
List of guests for the lodging.
1594 1595 1596 |
# File 'lib/stripe/params/charge_capture_params.rb', line 1594 def guests @guests end |
#host ⇒ Object
Host details for the lodging.
1596 1597 1598 |
# File 'lib/stripe/params/charge_capture_params.rb', line 1596 def host @host end |
#insurances ⇒ Object
List of insurances for the lodging.
1598 1599 1600 |
# File 'lib/stripe/params/charge_capture_params.rb', line 1598 def insurances @insurances end |
#no_show_indicator ⇒ Object
Whether the renter is a no-show.
1600 1601 1602 |
# File 'lib/stripe/params/charge_capture_params.rb', line 1600 def no_show_indicator @no_show_indicator end |
#renter_id_number ⇒ Object
Renter ID number for the lodging.
1602 1603 1604 |
# File 'lib/stripe/params/charge_capture_params.rb', line 1602 def renter_id_number @renter_id_number end |
#renter_name ⇒ Object
Renter name for the lodging.
1604 1605 1606 |
# File 'lib/stripe/params/charge_capture_params.rb', line 1604 def renter_name @renter_name end |
#total ⇒ Object
Total details for the lodging.
1606 1607 1608 |
# File 'lib/stripe/params/charge_capture_params.rb', line 1606 def total @total end |