Class: Stripe::ChargeCaptureParams::PaymentDetails::Subscription::Affiliate
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ChargeCaptureParams::PaymentDetails::Subscription::Affiliate
- Defined in:
- lib/stripe/params/charge_capture_params.rb
Instance Attribute Summary collapse
-
#name ⇒ Object
The name of the affiliate that originated the purchase.
Instance Method Summary collapse
-
#initialize(name: nil) ⇒ Affiliate
constructor
A new instance of Affiliate.
Methods inherited from RequestParams
Constructor Details
#initialize(name: nil) ⇒ Affiliate
Returns a new instance of Affiliate.
632 633 634 |
# File 'lib/stripe/params/charge_capture_params.rb', line 632 def initialize(name: nil) @name = name end |
Instance Attribute Details
#name ⇒ Object
The name of the affiliate that originated the purchase.
630 631 632 |
# File 'lib/stripe/params/charge_capture_params.rb', line 630 def name @name end |