Class: Stripe::ChargeCaptureParams::PaymentDetails::Subscription::BillingInterval

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/charge_capture_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(count: nil, interval: nil) ⇒ BillingInterval

Returns a new instance of BillingInterval.



1657
1658
1659
1660
# File 'lib/stripe/params/charge_capture_params.rb', line 1657

def initialize(count: nil, interval: nil)
  @count = count
  @interval = interval
end

Instance Attribute Details

#countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



1653
1654
1655
# File 'lib/stripe/params/charge_capture_params.rb', line 1653

def count
  @count
end

#intervalObject

Specifies a type of interval unit. Either day, week, month or year.



1655
1656
1657
# File 'lib/stripe/params/charge_capture_params.rb', line 1655

def interval
  @interval
end