Class: Stripe::ChargeService::CaptureParams::PaymentDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/charge_service.rb

Defined Under Namespace

Classes: CarRental, EventDetails, Flight, Lodging, Subscription

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails

Returns a new instance of PaymentDetails.



1751
1752
1753
1754
1755
1756
1757
1758
1759
1760
1761
1762
1763
1764
1765
1766
1767
# File 'lib/stripe/services/charge_service.rb', line 1751

def initialize(
  car_rental: nil,
  customer_reference: nil,
  event_details: nil,
  flight: nil,
  lodging: nil,
  order_reference: nil,
  subscription: nil
)
  @car_rental = car_rental
  @customer_reference = customer_reference
  @event_details = event_details
  @flight = flight
  @lodging = lodging
  @order_reference = order_reference
  @subscription = subscription
end

Instance Attribute Details

#car_rentalObject

Car rental details for this PaymentIntent.



1737
1738
1739
# File 'lib/stripe/services/charge_service.rb', line 1737

def car_rental
  @car_rental
end

#customer_referenceObject

Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.



1739
1740
1741
# File 'lib/stripe/services/charge_service.rb', line 1739

def customer_reference
  @customer_reference
end

#event_detailsObject

Event details for this PaymentIntent



1741
1742
1743
# File 'lib/stripe/services/charge_service.rb', line 1741

def event_details
  @event_details
end

#flightObject

Flight reservation details for this PaymentIntent



1743
1744
1745
# File 'lib/stripe/services/charge_service.rb', line 1743

def flight
  @flight
end

#lodgingObject

Lodging reservation details for this PaymentIntent



1745
1746
1747
# File 'lib/stripe/services/charge_service.rb', line 1745

def lodging
  @lodging
end

#order_referenceObject

A unique value assigned by the business to identify the transaction.



1747
1748
1749
# File 'lib/stripe/services/charge_service.rb', line 1747

def order_reference
  @order_reference
end

#subscriptionObject

Subscription details for this PaymentIntent



1749
1750
1751
# File 'lib/stripe/services/charge_service.rb', line 1749

def subscription
  @subscription
end