Class: Stripe::ChargeService::CaptureParams::PaymentDetails::CarRental

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/charge_service.rb

Defined Under Namespace

Classes: Affiliate, Delivery, Distance, Driver, PickupAddress, ReturnAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil) ⇒ CarRental

Returns a new instance of CarRental.



1239
1240
1241
1242
1243
1244
1245
1246
1247
1248
1249
1250
1251
1252
1253
1254
1255
1256
1257
1258
1259
1260
1261
1262
1263
1264
1265
1266
1267
1268
1269
1270
1271
1272
1273
1274
1275
1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
# File 'lib/stripe/services/charge_service.rb', line 1239

def initialize(
  affiliate: nil,
  booking_number: nil,
  car_class_code: nil,
  car_make: nil,
  car_model: nil,
  company: nil,
  customer_service_phone_number: nil,
  days_rented: nil,
  delivery: nil,
  distance: nil,
  drivers: nil,
  extra_charges: nil,
  no_show: nil,
  pickup_address: nil,
  pickup_at: nil,
  pickup_location_name: nil,
  rate_amount: nil,
  rate_interval: nil,
  renter_name: nil,
  return_address: nil,
  return_at: nil,
  return_location_name: nil,
  tax_exempt: nil,
  vehicle_identification_number: nil
)
  @affiliate = affiliate
  @booking_number = booking_number
  @car_class_code = car_class_code
  @car_make = car_make
  @car_model = car_model
  @company = company
  @customer_service_phone_number = customer_service_phone_number
  @days_rented = days_rented
  @delivery = delivery
  @distance = distance
  @drivers = drivers
  @extra_charges = extra_charges
  @no_show = no_show
  @pickup_address = pickup_address
  @pickup_at = pickup_at
  @pickup_location_name = pickup_location_name
  @rate_amount = rate_amount
  @rate_interval = rate_interval
  @renter_name = renter_name
  @return_address = return_address
  @return_at = return_at
  @return_location_name = return_location_name
  @tax_exempt = tax_exempt
  @vehicle_identification_number = vehicle_identification_number
end

Instance Attribute Details

#affiliateObject

Affiliate details for this purchase.



1191
1192
1193
# File 'lib/stripe/services/charge_service.rb', line 1191

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the car rental.



1193
1194
1195
# File 'lib/stripe/services/charge_service.rb', line 1193

def booking_number
  @booking_number
end

#car_class_codeObject

Class code of the car.



1195
1196
1197
# File 'lib/stripe/services/charge_service.rb', line 1195

def car_class_code
  @car_class_code
end

#car_makeObject

Make of the car.



1197
1198
1199
# File 'lib/stripe/services/charge_service.rb', line 1197

def car_make
  @car_make
end

#car_modelObject

Model of the car.



1199
1200
1201
# File 'lib/stripe/services/charge_service.rb', line 1199

def car_model
  @car_model
end

#companyObject

The name of the rental car company.



1201
1202
1203
# File 'lib/stripe/services/charge_service.rb', line 1201

def company
  @company
end

#customer_service_phone_numberObject

The customer service phone number of the car rental company.



1203
1204
1205
# File 'lib/stripe/services/charge_service.rb', line 1203

def customer_service_phone_number
  @customer_service_phone_number
end

#days_rentedObject

Number of days the car is being rented.



1205
1206
1207
# File 'lib/stripe/services/charge_service.rb', line 1205

def days_rented
  @days_rented
end

#deliveryObject

Delivery details for this purchase.



1207
1208
1209
# File 'lib/stripe/services/charge_service.rb', line 1207

def delivery
  @delivery
end

#distanceObject

The details of the distance traveled during the rental period.



1209
1210
1211
# File 'lib/stripe/services/charge_service.rb', line 1209

def distance
  @distance
end

#driversObject

The details of the passengers in the travel reservation



1211
1212
1213
# File 'lib/stripe/services/charge_service.rb', line 1211

def drivers
  @drivers
end

#extra_chargesObject

List of additional charges being billed.



1213
1214
1215
# File 'lib/stripe/services/charge_service.rb', line 1213

def extra_charges
  @extra_charges
end

#no_showObject

Indicates if the customer did not keep nor cancel their booking.



1215
1216
1217
# File 'lib/stripe/services/charge_service.rb', line 1215

def no_show
  @no_show
end

#pickup_addressObject

Car pick-up address.



1217
1218
1219
# File 'lib/stripe/services/charge_service.rb', line 1217

def pickup_address
  @pickup_address
end

#pickup_atObject

Car pick-up time. Measured in seconds since the Unix epoch.



1219
1220
1221
# File 'lib/stripe/services/charge_service.rb', line 1219

def pickup_at
  @pickup_at
end

#pickup_location_nameObject

Name of the pickup location.



1221
1222
1223
# File 'lib/stripe/services/charge_service.rb', line 1221

def pickup_location_name
  @pickup_location_name
end

#rate_amountObject

Rental rate.



1223
1224
1225
# File 'lib/stripe/services/charge_service.rb', line 1223

def rate_amount
  @rate_amount
end

#rate_intervalObject

The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`



1225
1226
1227
# File 'lib/stripe/services/charge_service.rb', line 1225

def rate_interval
  @rate_interval
end

#renter_nameObject

The name of the person or entity renting the car.



1227
1228
1229
# File 'lib/stripe/services/charge_service.rb', line 1227

def renter_name
  @renter_name
end

#return_addressObject

Car return address.



1229
1230
1231
# File 'lib/stripe/services/charge_service.rb', line 1229

def return_address
  @return_address
end

#return_atObject

Car return time. Measured in seconds since the Unix epoch.



1231
1232
1233
# File 'lib/stripe/services/charge_service.rb', line 1231

def return_at
  @return_at
end

#return_location_nameObject

Name of the return location.



1233
1234
1235
# File 'lib/stripe/services/charge_service.rb', line 1233

def return_location_name
  @return_location_name
end

#tax_exemptObject

Indicates whether the goods or services are tax-exempt or tax is not collected.



1235
1236
1237
# File 'lib/stripe/services/charge_service.rb', line 1235

def tax_exempt
  @tax_exempt
end

#vehicle_identification_numberObject

The vehicle identification number.



1237
1238
1239
# File 'lib/stripe/services/charge_service.rb', line 1237

def vehicle_identification_number
  @vehicle_identification_number
end