Class: Stripe::ChargeService::CaptureParams::PaymentDetails::CarRental::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/charge_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



1085
1086
1087
1088
1089
# File 'lib/stripe/services/charge_service.rb', line 1085

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



1079
1080
1081
# File 'lib/stripe/services/charge_service.rb', line 1079

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



1081
1082
1083
# File 'lib/stripe/services/charge_service.rb', line 1081

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



1083
1084
1085
# File 'lib/stripe/services/charge_service.rb', line 1083

def phone
  @phone
end