Class: Stripe::ChargeService::CaptureParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ChargeService::CaptureParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/services/charge_service.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
1377 1378 1379 1380 1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 1397 |
# File 'lib/stripe/services/charge_service.rb', line 1377 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
1359 1360 1361 |
# File 'lib/stripe/services/charge_service.rb', line 1359 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
1361 1362 1363 |
# File 'lib/stripe/services/charge_service.rb', line 1361 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
1363 1364 1365 |
# File 'lib/stripe/services/charge_service.rb', line 1363 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
1365 1366 1367 |
# File 'lib/stripe/services/charge_service.rb', line 1365 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
1367 1368 1369 |
# File 'lib/stripe/services/charge_service.rb', line 1367 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
1369 1370 1371 |
# File 'lib/stripe/services/charge_service.rb', line 1369 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
1371 1372 1373 |
# File 'lib/stripe/services/charge_service.rb', line 1371 def genre @genre end |
#name ⇒ Object
The name of the event.
1373 1374 1375 |
# File 'lib/stripe/services/charge_service.rb', line 1373 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
1375 1376 1377 |
# File 'lib/stripe/services/charge_service.rb', line 1375 def starts_at @starts_at end |