Class: Stripe::ChargeService::CaptureParams::PaymentDetails::EventDetails::Affiliate
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ChargeService::CaptureParams::PaymentDetails::EventDetails::Affiliate
- Defined in:
- lib/stripe/services/charge_service.rb
Instance Attribute Summary collapse
-
#name ⇒ Object
The name of the affiliate that originated the purchase.
Instance Method Summary collapse
-
#initialize(name: nil) ⇒ Affiliate
constructor
A new instance of Affiliate.
Methods inherited from RequestParams
Constructor Details
#initialize(name: nil) ⇒ Affiliate
Returns a new instance of Affiliate.
1260 1261 1262 |
# File 'lib/stripe/services/charge_service.rb', line 1260 def initialize(name: nil) @name = name end |
Instance Attribute Details
#name ⇒ Object
The name of the affiliate that originated the purchase.
1258 1259 1260 |
# File 'lib/stripe/services/charge_service.rb', line 1258 def name @name end |