Class: Stripe::ChargeService::CaptureParams::PaymentDetails::EventDetails::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/charge_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



1342
1343
1344
1345
1346
# File 'lib/stripe/services/charge_service.rb', line 1342

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



1336
1337
1338
# File 'lib/stripe/services/charge_service.rb', line 1336

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



1338
1339
1340
# File 'lib/stripe/services/charge_service.rb', line 1338

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



1340
1341
1342
# File 'lib/stripe/services/charge_service.rb', line 1340

def phone
  @phone
end