Class: Stripe::ChargeService::CaptureParams::PaymentDetails::Flight::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/charge_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



1419
1420
1421
1422
1423
# File 'lib/stripe/services/charge_service.rb', line 1419

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



1413
1414
1415
# File 'lib/stripe/services/charge_service.rb', line 1413

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



1415
1416
1417
# File 'lib/stripe/services/charge_service.rb', line 1415

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



1417
1418
1419
# File 'lib/stripe/services/charge_service.rb', line 1417

def phone
  @phone
end