Class: Stripe::ChargeService::CaptureParams::PaymentDetails::Lodging::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ChargeService::CaptureParams::PaymentDetails::Lodging::Delivery::Recipient
- Defined in:
- lib/stripe/services/charge_service.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
1571 1572 1573 1574 1575 |
# File 'lib/stripe/services/charge_service.rb', line 1571 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
1565 1566 1567 |
# File 'lib/stripe/services/charge_service.rb', line 1565 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
1567 1568 1569 |
# File 'lib/stripe/services/charge_service.rb', line 1567 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
1569 1570 1571 |
# File 'lib/stripe/services/charge_service.rb', line 1569 def phone @phone end |