Class: Stripe::ChargeService::CaptureParams::PaymentDetails::Subscription::BillingInterval

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/charge_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(count: nil, interval: nil) ⇒ BillingInterval

Returns a new instance of BillingInterval.



1882
1883
1884
1885
# File 'lib/stripe/services/charge_service.rb', line 1882

def initialize(count: nil, interval: nil)
  @count = count
  @interval = interval
end

Instance Attribute Details

#countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



1877
1878
1879
# File 'lib/stripe/services/charge_service.rb', line 1877

def count
  @count
end

#intervalObject

Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.



1880
1881
1882
# File 'lib/stripe/services/charge_service.rb', line 1880

def interval
  @interval
end