Class: Stripe::ChargeService::CaptureParams::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/charge_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil) ⇒ TransferData

Returns a new instance of TransferData.



1706
1707
1708
# File 'lib/stripe/services/charge_service.rb', line 1706

def initialize(amount: nil)
  @amount = amount
end

Instance Attribute Details

#amountObject

The amount transferred to the destination account, if specified. By default, the entire charge amount is transferred to the destination account.



1704
1705
1706
# File 'lib/stripe/services/charge_service.rb', line 1704

def amount
  @amount
end