Class: Stripe::ChargeService::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/charge_service.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(created: nil, customer: nil, ending_before: nil, expand: nil, limit: nil, payment_intent: nil, starting_after: nil, transfer_group: nil) ⇒ ListParams

Returns a new instance of ListParams.



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
# File 'lib/stripe/services/charge_service.rb', line 41

def initialize(
  created: nil,
  customer: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  payment_intent: nil,
  starting_after: nil,
  transfer_group: nil
)
  @created = created
  @customer = customer
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @payment_intent = payment_intent
  @starting_after = starting_after
  @transfer_group = transfer_group
end

Instance Attribute Details

#createdObject

Only return charges that were created during the given date interval.



25
26
27
# File 'lib/stripe/services/charge_service.rb', line 25

def created
  @created
end

#customerObject

Only return charges for the customer specified by this customer ID.



27
28
29
# File 'lib/stripe/services/charge_service.rb', line 27

def customer
  @customer
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



29
30
31
# File 'lib/stripe/services/charge_service.rb', line 29

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



31
32
33
# File 'lib/stripe/services/charge_service.rb', line 31

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



33
34
35
# File 'lib/stripe/services/charge_service.rb', line 33

def limit
  @limit
end

#payment_intentObject

Only return charges that were created by the PaymentIntent specified by this PaymentIntent ID.



35
36
37
# File 'lib/stripe/services/charge_service.rb', line 35

def payment_intent
  @payment_intent
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



37
38
39
# File 'lib/stripe/services/charge_service.rb', line 37

def starting_after
  @starting_after
end

#transfer_groupObject

Only return charges for this transfer group, limited to 100.



39
40
41
# File 'lib/stripe/services/charge_service.rb', line 39

def transfer_group
  @transfer_group
end