Class: Stripe::ChargeService::UpdateParams::PaymentDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/charge_service.rb

Defined Under Namespace

Classes: CarRental, EventDetails, Flight, Lodging, Subscription

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails

Returns a new instance of PaymentDetails.



935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
951
# File 'lib/stripe/services/charge_service.rb', line 935

def initialize(
  car_rental: nil,
  customer_reference: nil,
  event_details: nil,
  flight: nil,
  lodging: nil,
  order_reference: nil,
  subscription: nil
)
  @car_rental = car_rental
  @customer_reference = customer_reference
  @event_details = event_details
  @flight = flight
  @lodging = lodging
  @order_reference = order_reference
  @subscription = subscription
end

Instance Attribute Details

#car_rentalObject

Car rental details for this PaymentIntent.



921
922
923
# File 'lib/stripe/services/charge_service.rb', line 921

def car_rental
  @car_rental
end

#customer_referenceObject

Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.



923
924
925
# File 'lib/stripe/services/charge_service.rb', line 923

def customer_reference
  @customer_reference
end

#event_detailsObject

Event details for this PaymentIntent



925
926
927
# File 'lib/stripe/services/charge_service.rb', line 925

def event_details
  @event_details
end

#flightObject

Flight reservation details for this PaymentIntent



927
928
929
# File 'lib/stripe/services/charge_service.rb', line 927

def flight
  @flight
end

#lodgingObject

Lodging reservation details for this PaymentIntent



929
930
931
# File 'lib/stripe/services/charge_service.rb', line 929

def lodging
  @lodging
end

#order_referenceObject

A unique value assigned by the business to identify the transaction.



931
932
933
# File 'lib/stripe/services/charge_service.rb', line 931

def order_reference
  @order_reference
end

#subscriptionObject

Subscription details for this PaymentIntent



933
934
935
# File 'lib/stripe/services/charge_service.rb', line 933

def subscription
  @subscription
end