Class: Stripe::ChargeService::UpdateParams::PaymentDetails::CarRental::Driver
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ChargeService::UpdateParams::PaymentDetails::CarRental::Driver
- Defined in:
- lib/stripe/services/charge_service.rb
Instance Attribute Summary collapse
-
#name ⇒ Object
Full name of the person or entity on the car reservation.
Instance Method Summary collapse
-
#initialize(name: nil) ⇒ Driver
constructor
A new instance of Driver.
Methods inherited from RequestParams
Constructor Details
#initialize(name: nil) ⇒ Driver
Returns a new instance of Driver.
332 333 334 |
# File 'lib/stripe/services/charge_service.rb', line 332 def initialize(name: nil) @name = name end |
Instance Attribute Details
#name ⇒ Object
Full name of the person or entity on the car reservation.
330 331 332 |
# File 'lib/stripe/services/charge_service.rb', line 330 def name @name end |