Class: Stripe::ChargeService::UpdateParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ChargeService::UpdateParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/services/charge_service.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 |
# File 'lib/stripe/services/charge_service.rb', line 527 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
509 510 511 |
# File 'lib/stripe/services/charge_service.rb', line 509 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
511 512 513 |
# File 'lib/stripe/services/charge_service.rb', line 511 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
513 514 515 |
# File 'lib/stripe/services/charge_service.rb', line 513 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
515 516 517 |
# File 'lib/stripe/services/charge_service.rb', line 515 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
517 518 519 |
# File 'lib/stripe/services/charge_service.rb', line 517 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
519 520 521 |
# File 'lib/stripe/services/charge_service.rb', line 519 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
521 522 523 |
# File 'lib/stripe/services/charge_service.rb', line 521 def genre @genre end |
#name ⇒ Object
The name of the event.
523 524 525 |
# File 'lib/stripe/services/charge_service.rb', line 523 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
525 526 527 |
# File 'lib/stripe/services/charge_service.rb', line 525 def starts_at @starts_at end |