Class: Stripe::ChargeService::UpdateParams::PaymentDetails::EventDetails::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/charge_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



526
527
528
529
530
# File 'lib/stripe/services/charge_service.rb', line 526

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



520
521
522
# File 'lib/stripe/services/charge_service.rb', line 520

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



522
523
524
# File 'lib/stripe/services/charge_service.rb', line 522

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



524
525
526
# File 'lib/stripe/services/charge_service.rb', line 524

def phone
  @phone
end