Class: Stripe::ChargeService::UpdateParams::PaymentDetails::Flight::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/charge_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



658
659
660
661
662
# File 'lib/stripe/services/charge_service.rb', line 658

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



650
651
652
# File 'lib/stripe/services/charge_service.rb', line 650

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



653
654
655
# File 'lib/stripe/services/charge_service.rb', line 653

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



656
657
658
# File 'lib/stripe/services/charge_service.rb', line 656

def phone
  @phone
end