Class: Stripe::ChargeService::UpdateParams::PaymentDetails::Lodging::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/charge_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



755
756
757
758
759
# File 'lib/stripe/services/charge_service.rb', line 755

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



749
750
751
# File 'lib/stripe/services/charge_service.rb', line 749

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



751
752
753
# File 'lib/stripe/services/charge_service.rb', line 751

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



753
754
755
# File 'lib/stripe/services/charge_service.rb', line 753

def phone
  @phone
end