Class: Stripe::ChargeUpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/charge_update_params.rb

Defined Under Namespace

Classes: FraudDetails, PaymentDetails, Shipping

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(customer: nil, description: nil, expand: nil, fraud_details: nil, metadata: nil, payment_details: nil, receipt_email: nil, shipping: nil, transfer_group: nil) ⇒ ChargeUpdateParams

Returns a new instance of ChargeUpdateParams.



1823
1824
1825
1826
1827
1828
1829
1830
1831
1832
1833
1834
1835
1836
1837
1838
1839
1840
1841
1842
1843
# File 'lib/stripe/params/charge_update_params.rb', line 1823

def initialize(
  customer: nil,
  description: nil,
  expand: nil,
  fraud_details: nil,
  metadata: nil,
  payment_details: nil,
  receipt_email: nil,
  shipping: nil,
  transfer_group: nil
)
  @customer = customer
  @description = description
  @expand = expand
  @fraud_details = fraud_details
  @metadata = 
  @payment_details = payment_details
  @receipt_email = receipt_email
  @shipping = shipping
  @transfer_group = transfer_group
end

Instance Attribute Details

#customerObject

The ID of an existing customer that will be associated with this request. This field may only be updated if there is no existing associated customer with this charge.



1805
1806
1807
# File 'lib/stripe/params/charge_update_params.rb', line 1805

def customer
  @customer
end

#descriptionObject

An arbitrary string which you can attach to a charge object. It is displayed when in the web interface alongside the charge. Note that if you use Stripe to send automatic email receipts to your customers, your receipt emails will include the description of the charge(s) that they are describing.



1807
1808
1809
# File 'lib/stripe/params/charge_update_params.rb', line 1807

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



1809
1810
1811
# File 'lib/stripe/params/charge_update_params.rb', line 1809

def expand
  @expand
end

#fraud_detailsObject

A set of key-value pairs you can attach to a charge giving information about its riskiness. If you believe a charge is fraudulent, include a user_report key with a value of fraudulent. If you believe a charge is safe, include a user_report key with a value of safe. Stripe will use the information you send to improve our fraud detection algorithms.



1811
1812
1813
# File 'lib/stripe/params/charge_update_params.rb', line 1811

def fraud_details
  @fraud_details
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.



1813
1814
1815
# File 'lib/stripe/params/charge_update_params.rb', line 1813

def 
  @metadata
end

#payment_detailsObject

Provides industry-specific information about the charge.



1815
1816
1817
# File 'lib/stripe/params/charge_update_params.rb', line 1815

def payment_details
  @payment_details
end

#receipt_emailObject

This is the email address that the receipt for this charge will be sent to. If this field is updated, then a new email receipt will be sent to the updated address.



1817
1818
1819
# File 'lib/stripe/params/charge_update_params.rb', line 1817

def receipt_email
  @receipt_email
end

#shippingObject

Shipping information for the charge. Helps prevent fraud on charges for physical goods.



1819
1820
1821
# File 'lib/stripe/params/charge_update_params.rb', line 1819

def shipping
  @shipping
end

#transfer_groupObject

A string that identifies this transaction as part of a group. transfer_group may only be provided if it has not been set. See the Connect documentation for details.



1821
1822
1823
# File 'lib/stripe/params/charge_update_params.rb', line 1821

def transfer_group
  @transfer_group
end