Class: Stripe::ChargeUpdateParams::PaymentDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ChargeUpdateParams::PaymentDetails
- Defined in:
- lib/stripe/params/charge_update_params.rb
Defined Under Namespace
Classes: CarRental, CarRentalDatum, EventDetails, FleetDatum, Flight, FlightDatum, Lodging, LodgingDatum, Subscription
Instance Attribute Summary collapse
-
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
-
#car_rental_data ⇒ Object
Car rental data for this PaymentIntent.
-
#customer_reference ⇒ Object
A unique value to identify the customer.
-
#event_details ⇒ Object
Event details for this PaymentIntent.
-
#fleet_data ⇒ Object
Fleet data for this PaymentIntent.
-
#flight ⇒ Object
Flight reservation details for this PaymentIntent.
-
#flight_data ⇒ Object
Flight data for this PaymentIntent.
-
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent.
-
#lodging_data ⇒ Object
Lodging data for this PaymentIntent.
-
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
-
#subscription ⇒ Object
Subscription details for this PaymentIntent.
Instance Method Summary collapse
-
#initialize(car_rental: nil, car_rental_data: nil, customer_reference: nil, event_details: nil, fleet_data: nil, flight: nil, flight_data: nil, lodging: nil, lodging_data: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
constructor
A new instance of PaymentDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(car_rental: nil, car_rental_data: nil, customer_reference: nil, event_details: nil, fleet_data: nil, flight: nil, flight_data: nil, lodging: nil, lodging_data: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
Returns a new instance of PaymentDetails.
1727 1728 1729 1730 1731 1732 1733 1734 1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 1747 1748 1749 1750 1751 |
# File 'lib/stripe/params/charge_update_params.rb', line 1727 def initialize( car_rental: nil, car_rental_data: nil, customer_reference: nil, event_details: nil, fleet_data: nil, flight: nil, flight_data: nil, lodging: nil, lodging_data: nil, order_reference: nil, subscription: nil ) @car_rental = car_rental @car_rental_data = car_rental_data @customer_reference = customer_reference @event_details = event_details @fleet_data = fleet_data @flight = flight @flight_data = flight_data @lodging = lodging @lodging_data = lodging_data @order_reference = order_reference @subscription = subscription end |
Instance Attribute Details
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
1701 1702 1703 |
# File 'lib/stripe/params/charge_update_params.rb', line 1701 def car_rental @car_rental end |
#car_rental_data ⇒ Object
Car rental data for this PaymentIntent.
1703 1704 1705 |
# File 'lib/stripe/params/charge_update_params.rb', line 1703 def car_rental_data @car_rental_data end |
#customer_reference ⇒ Object
A unique value to identify the customer. This field is available only for card payments.
This field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks.
1707 1708 1709 |
# File 'lib/stripe/params/charge_update_params.rb', line 1707 def customer_reference @customer_reference end |
#event_details ⇒ Object
Event details for this PaymentIntent
1709 1710 1711 |
# File 'lib/stripe/params/charge_update_params.rb', line 1709 def event_details @event_details end |
#fleet_data ⇒ Object
Fleet data for this PaymentIntent.
1711 1712 1713 |
# File 'lib/stripe/params/charge_update_params.rb', line 1711 def fleet_data @fleet_data end |
#flight ⇒ Object
Flight reservation details for this PaymentIntent
1713 1714 1715 |
# File 'lib/stripe/params/charge_update_params.rb', line 1713 def flight @flight end |
#flight_data ⇒ Object
Flight data for this PaymentIntent.
1715 1716 1717 |
# File 'lib/stripe/params/charge_update_params.rb', line 1715 def flight_data @flight_data end |
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent
1717 1718 1719 |
# File 'lib/stripe/params/charge_update_params.rb', line 1717 def lodging @lodging end |
#lodging_data ⇒ Object
Lodging data for this PaymentIntent.
1719 1720 1721 |
# File 'lib/stripe/params/charge_update_params.rb', line 1719 def lodging_data @lodging_data end |
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction. Required for L2 and L3 rates.
For Cards, this field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks. For Klarna, this field is truncated to 255 characters and is visible to customers when they view the order in the Klarna app.
1723 1724 1725 |
# File 'lib/stripe/params/charge_update_params.rb', line 1723 def order_reference @order_reference end |
#subscription ⇒ Object
Subscription details for this PaymentIntent
1725 1726 1727 |
# File 'lib/stripe/params/charge_update_params.rb', line 1725 def subscription @subscription end |