Class: Stripe::ChargeUpdateParams::PaymentDetails::CarRental

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/charge_update_params.rb

Defined Under Namespace

Classes: Affiliate, Delivery, Distance, Driver, PickupAddress, ReturnAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil) ⇒ CarRental

Returns a new instance of CarRental.



189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
# File 'lib/stripe/params/charge_update_params.rb', line 189

def initialize(
  affiliate: nil,
  booking_number: nil,
  car_class_code: nil,
  car_make: nil,
  car_model: nil,
  company: nil,
  customer_service_phone_number: nil,
  days_rented: nil,
  delivery: nil,
  distance: nil,
  drivers: nil,
  extra_charges: nil,
  no_show: nil,
  pickup_address: nil,
  pickup_at: nil,
  pickup_location_name: nil,
  rate_amount: nil,
  rate_interval: nil,
  renter_name: nil,
  return_address: nil,
  return_at: nil,
  return_location_name: nil,
  tax_exempt: nil,
  vehicle_identification_number: nil
)
  @affiliate = affiliate
  @booking_number = booking_number
  @car_class_code = car_class_code
  @car_make = car_make
  @car_model = car_model
  @company = company
  @customer_service_phone_number = customer_service_phone_number
  @days_rented = days_rented
  @delivery = delivery
  @distance = distance
  @drivers = drivers
  @extra_charges = extra_charges
  @no_show = no_show
  @pickup_address = pickup_address
  @pickup_at = pickup_at
  @pickup_location_name = pickup_location_name
  @rate_amount = rate_amount
  @rate_interval = rate_interval
  @renter_name = renter_name
  @return_address = return_address
  @return_at = return_at
  @return_location_name = return_location_name
  @tax_exempt = tax_exempt
  @vehicle_identification_number = vehicle_identification_number
end

Instance Attribute Details

#affiliateObject

Affiliate details for this purchase.



141
142
143
# File 'lib/stripe/params/charge_update_params.rb', line 141

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the car rental.



143
144
145
# File 'lib/stripe/params/charge_update_params.rb', line 143

def booking_number
  @booking_number
end

#car_class_codeObject

Class code of the car.



145
146
147
# File 'lib/stripe/params/charge_update_params.rb', line 145

def car_class_code
  @car_class_code
end

#car_makeObject

Make of the car.



147
148
149
# File 'lib/stripe/params/charge_update_params.rb', line 147

def car_make
  @car_make
end

#car_modelObject

Model of the car.



149
150
151
# File 'lib/stripe/params/charge_update_params.rb', line 149

def car_model
  @car_model
end

#companyObject

The name of the rental car company.



151
152
153
# File 'lib/stripe/params/charge_update_params.rb', line 151

def company
  @company
end

#customer_service_phone_numberObject

The customer service phone number of the car rental company.



153
154
155
# File 'lib/stripe/params/charge_update_params.rb', line 153

def customer_service_phone_number
  @customer_service_phone_number
end

#days_rentedObject

Number of days the car is being rented.



155
156
157
# File 'lib/stripe/params/charge_update_params.rb', line 155

def days_rented
  @days_rented
end

#deliveryObject

Delivery details for this purchase.



157
158
159
# File 'lib/stripe/params/charge_update_params.rb', line 157

def delivery
  @delivery
end

#distanceObject

The details of the distance traveled during the rental period.



159
160
161
# File 'lib/stripe/params/charge_update_params.rb', line 159

def distance
  @distance
end

#driversObject

The details of the passengers in the travel reservation



161
162
163
# File 'lib/stripe/params/charge_update_params.rb', line 161

def drivers
  @drivers
end

#extra_chargesObject

List of additional charges being billed.



163
164
165
# File 'lib/stripe/params/charge_update_params.rb', line 163

def extra_charges
  @extra_charges
end

#no_showObject

Indicates if the customer did not keep nor cancel their booking.



165
166
167
# File 'lib/stripe/params/charge_update_params.rb', line 165

def no_show
  @no_show
end

#pickup_addressObject

Car pick-up address.



167
168
169
# File 'lib/stripe/params/charge_update_params.rb', line 167

def pickup_address
  @pickup_address
end

#pickup_atObject

Car pick-up time. Measured in seconds since the Unix epoch.



169
170
171
# File 'lib/stripe/params/charge_update_params.rb', line 169

def pickup_at
  @pickup_at
end

#pickup_location_nameObject

Name of the pickup location.



171
172
173
# File 'lib/stripe/params/charge_update_params.rb', line 171

def pickup_location_name
  @pickup_location_name
end

#rate_amountObject

Rental rate.



173
174
175
# File 'lib/stripe/params/charge_update_params.rb', line 173

def rate_amount
  @rate_amount
end

#rate_intervalObject

The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`



175
176
177
# File 'lib/stripe/params/charge_update_params.rb', line 175

def rate_interval
  @rate_interval
end

#renter_nameObject

The name of the person or entity renting the car.



177
178
179
# File 'lib/stripe/params/charge_update_params.rb', line 177

def renter_name
  @renter_name
end

#return_addressObject

Car return address.



179
180
181
# File 'lib/stripe/params/charge_update_params.rb', line 179

def return_address
  @return_address
end

#return_atObject

Car return time. Measured in seconds since the Unix epoch.



181
182
183
# File 'lib/stripe/params/charge_update_params.rb', line 181

def return_at
  @return_at
end

#return_location_nameObject

Name of the return location.



183
184
185
# File 'lib/stripe/params/charge_update_params.rb', line 183

def return_location_name
  @return_location_name
end

#tax_exemptObject

Indicates whether the goods or services are tax-exempt or tax is not collected.



185
186
187
# File 'lib/stripe/params/charge_update_params.rb', line 185

def tax_exempt
  @tax_exempt
end

#vehicle_identification_numberObject

The vehicle identification number.



187
188
189
# File 'lib/stripe/params/charge_update_params.rb', line 187

def vehicle_identification_number
  @vehicle_identification_number
end