Class: Stripe::ChargeUpdateParams::PaymentDetails::CarRentalDatum
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ChargeUpdateParams::PaymentDetails::CarRentalDatum
- Defined in:
- lib/stripe/params/charge_update_params.rb
Defined Under Namespace
Classes: Affiliate, Distance, Driver, DropOff, Insurance, Pickup, Total, Vehicle
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate (such as travel agency) details for the rental.
-
#booking_number ⇒ Object
Booking confirmation number for the car rental.
-
#carrier_name ⇒ Object
Name of the car rental company.
-
#customer_service_phone_number ⇒ Object
Customer service phone number for the car rental company.
-
#days_rented ⇒ Object
Number of days the car is being rented.
-
#distance ⇒ Object
Distance details for the rental.
-
#drivers ⇒ Object
List of drivers for the rental.
-
#drop_off ⇒ Object
Drop-off location details.
-
#insurances ⇒ Object
Insurance details for the rental.
-
#no_show_indicator ⇒ Object
Indicates if the customer was a no-show.
-
#pickup ⇒ Object
Pickup location details.
-
#renter_name ⇒ Object
Name of the person renting the vehicle.
-
#total ⇒ Object
Total cost breakdown for the rental.
-
#vehicle ⇒ Object
Vehicle details for the rental.
Instance Method Summary collapse
-
#initialize(affiliate: nil, booking_number: nil, carrier_name: nil, customer_service_phone_number: nil, days_rented: nil, distance: nil, drivers: nil, drop_off: nil, insurances: nil, no_show_indicator: nil, pickup: nil, renter_name: nil, total: nil, vehicle: nil) ⇒ CarRentalDatum
constructor
A new instance of CarRentalDatum.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate: nil, booking_number: nil, carrier_name: nil, customer_service_phone_number: nil, days_rented: nil, distance: nil, drivers: nil, drop_off: nil, insurances: nil, no_show_indicator: nil, pickup: nil, renter_name: nil, total: nil, vehicle: nil) ⇒ CarRentalDatum
Returns a new instance of CarRentalDatum.
567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 |
# File 'lib/stripe/params/charge_update_params.rb', line 567 def initialize( affiliate: nil, booking_number: nil, carrier_name: nil, customer_service_phone_number: nil, days_rented: nil, distance: nil, drivers: nil, drop_off: nil, insurances: nil, no_show_indicator: nil, pickup: nil, renter_name: nil, total: nil, vehicle: nil ) @affiliate = affiliate @booking_number = booking_number @carrier_name = carrier_name @customer_service_phone_number = customer_service_phone_number @days_rented = days_rented @distance = distance @drivers = drivers @drop_off = drop_off @insurances = insurances @no_show_indicator = no_show_indicator @pickup = pickup @renter_name = renter_name @total = total @vehicle = vehicle end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate (such as travel agency) details for the rental.
539 540 541 |
# File 'lib/stripe/params/charge_update_params.rb', line 539 def affiliate @affiliate end |
#booking_number ⇒ Object
Booking confirmation number for the car rental.
541 542 543 |
# File 'lib/stripe/params/charge_update_params.rb', line 541 def booking_number @booking_number end |
#carrier_name ⇒ Object
Name of the car rental company.
543 544 545 |
# File 'lib/stripe/params/charge_update_params.rb', line 543 def carrier_name @carrier_name end |
#customer_service_phone_number ⇒ Object
Customer service phone number for the car rental company.
545 546 547 |
# File 'lib/stripe/params/charge_update_params.rb', line 545 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object
Number of days the car is being rented.
547 548 549 |
# File 'lib/stripe/params/charge_update_params.rb', line 547 def days_rented @days_rented end |
#distance ⇒ Object
Distance details for the rental.
549 550 551 |
# File 'lib/stripe/params/charge_update_params.rb', line 549 def distance @distance end |
#drivers ⇒ Object
List of drivers for the rental.
551 552 553 |
# File 'lib/stripe/params/charge_update_params.rb', line 551 def drivers @drivers end |
#drop_off ⇒ Object
Drop-off location details.
553 554 555 |
# File 'lib/stripe/params/charge_update_params.rb', line 553 def drop_off @drop_off end |
#insurances ⇒ Object
Insurance details for the rental.
555 556 557 |
# File 'lib/stripe/params/charge_update_params.rb', line 555 def insurances @insurances end |
#no_show_indicator ⇒ Object
Indicates if the customer was a no-show.
557 558 559 |
# File 'lib/stripe/params/charge_update_params.rb', line 557 def no_show_indicator @no_show_indicator end |
#pickup ⇒ Object
Pickup location details.
559 560 561 |
# File 'lib/stripe/params/charge_update_params.rb', line 559 def pickup @pickup end |
#renter_name ⇒ Object
Name of the person renting the vehicle.
561 562 563 |
# File 'lib/stripe/params/charge_update_params.rb', line 561 def renter_name @renter_name end |
#total ⇒ Object
Total cost breakdown for the rental.
563 564 565 |
# File 'lib/stripe/params/charge_update_params.rb', line 563 def total @total end |
#vehicle ⇒ Object
Vehicle details for the rental.
565 566 567 |
# File 'lib/stripe/params/charge_update_params.rb', line 565 def vehicle @vehicle end |