Class: Stripe::ChargeUpdateParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ChargeUpdateParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/params/charge_update_params.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 |
# File 'lib/stripe/params/charge_update_params.rb', line 685 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
667 668 669 |
# File 'lib/stripe/params/charge_update_params.rb', line 667 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
669 670 671 |
# File 'lib/stripe/params/charge_update_params.rb', line 669 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
671 672 673 |
# File 'lib/stripe/params/charge_update_params.rb', line 671 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
673 674 675 |
# File 'lib/stripe/params/charge_update_params.rb', line 673 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
675 676 677 |
# File 'lib/stripe/params/charge_update_params.rb', line 675 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
677 678 679 |
# File 'lib/stripe/params/charge_update_params.rb', line 677 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
679 680 681 |
# File 'lib/stripe/params/charge_update_params.rb', line 679 def genre @genre end |
#name ⇒ Object
The name of the event.
681 682 683 |
# File 'lib/stripe/params/charge_update_params.rb', line 681 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
683 684 685 |
# File 'lib/stripe/params/charge_update_params.rb', line 683 def starts_at @starts_at end |