Class: Stripe::ChargeUpdateParams::PaymentDetails::EventDetails::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/charge_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



650
651
652
653
654
# File 'lib/stripe/params/charge_update_params.rb', line 650

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



644
645
646
# File 'lib/stripe/params/charge_update_params.rb', line 644

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



646
647
648
# File 'lib/stripe/params/charge_update_params.rb', line 646

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



648
649
650
# File 'lib/stripe/params/charge_update_params.rb', line 648

def phone
  @phone
end