Class: Stripe::ChargeUpdateParams::PaymentDetails::Flight::Affiliate
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ChargeUpdateParams::PaymentDetails::Flight::Affiliate
- Defined in:
- lib/stripe/params/charge_update_params.rb
Instance Attribute Summary collapse
-
#name ⇒ Object
The name of the affiliate that originated the purchase.
Instance Method Summary collapse
-
#initialize(name: nil) ⇒ Affiliate
constructor
A new instance of Affiliate.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(name: nil) ⇒ Affiliate
Returns a new instance of Affiliate.
713 714 715 |
# File 'lib/stripe/params/charge_update_params.rb', line 713 def initialize(name: nil) @name = name end |
Instance Attribute Details
#name ⇒ Object
The name of the affiliate that originated the purchase.
711 712 713 |
# File 'lib/stripe/params/charge_update_params.rb', line 711 def name @name end |