Class: Stripe::ChargeUpdateParams::PaymentDetails::Flight::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ChargeUpdateParams::PaymentDetails::Flight::Delivery::Recipient
- Defined in:
- lib/stripe/params/charge_update_params.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
727 728 729 730 731 |
# File 'lib/stripe/params/charge_update_params.rb', line 727 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
721 722 723 |
# File 'lib/stripe/params/charge_update_params.rb', line 721 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
723 724 725 |
# File 'lib/stripe/params/charge_update_params.rb', line 723 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
725 726 727 |
# File 'lib/stripe/params/charge_update_params.rb', line 725 def phone @phone end |