Class: Stripe::ChargeUpdateParams::PaymentDetails::FlightDatum
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ChargeUpdateParams::PaymentDetails::FlightDatum
- Defined in:
- lib/stripe/params/charge_update_params.rb
Defined Under Namespace
Classes: Affiliate, Insurance, Passenger, Segment, Total
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details if applicable.
-
#booking_number ⇒ Object
Reservation reference.
-
#computerized_reservation_system ⇒ Object
Computerized reservation system used to make the reservation and purchase the ticket.
-
#endorsements_and_restrictions ⇒ Object
Ticket restrictions.
-
#insurances ⇒ Object
List of insurances.
-
#passengers ⇒ Object
List of passengers.
-
#segments ⇒ Object
List of flight segments.
-
#ticket_electronically_issued_indicator ⇒ Object
Electronic ticket indicator.
-
#total ⇒ Object
Total cost breakdown.
-
#transaction_type ⇒ Object
Type of flight transaction.
Instance Method Summary collapse
-
#initialize(affiliate: nil, booking_number: nil, computerized_reservation_system: nil, endorsements_and_restrictions: nil, insurances: nil, passengers: nil, segments: nil, ticket_electronically_issued_indicator: nil, total: nil, transaction_type: nil) ⇒ FlightDatum
constructor
A new instance of FlightDatum.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate: nil, booking_number: nil, computerized_reservation_system: nil, endorsements_and_restrictions: nil, insurances: nil, passengers: nil, segments: nil, ticket_electronically_issued_indicator: nil, total: nil, transaction_type: nil) ⇒ FlightDatum
Returns a new instance of FlightDatum.
1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 |
# File 'lib/stripe/params/charge_update_params.rb', line 1073 def initialize( affiliate: nil, booking_number: nil, computerized_reservation_system: nil, endorsements_and_restrictions: nil, insurances: nil, passengers: nil, segments: nil, ticket_electronically_issued_indicator: nil, total: nil, transaction_type: nil ) @affiliate = affiliate @booking_number = booking_number @computerized_reservation_system = computerized_reservation_system @endorsements_and_restrictions = endorsements_and_restrictions @insurances = insurances @passengers = passengers @segments = segments @ticket_electronically_issued_indicator = ticket_electronically_issued_indicator @total = total @transaction_type = transaction_type end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details if applicable.
1053 1054 1055 |
# File 'lib/stripe/params/charge_update_params.rb', line 1053 def affiliate @affiliate end |
#booking_number ⇒ Object
Reservation reference.
1055 1056 1057 |
# File 'lib/stripe/params/charge_update_params.rb', line 1055 def booking_number @booking_number end |
#computerized_reservation_system ⇒ Object
Computerized reservation system used to make the reservation and purchase the ticket.
1057 1058 1059 |
# File 'lib/stripe/params/charge_update_params.rb', line 1057 def computerized_reservation_system @computerized_reservation_system end |
#endorsements_and_restrictions ⇒ Object
Ticket restrictions.
1059 1060 1061 |
# File 'lib/stripe/params/charge_update_params.rb', line 1059 def endorsements_and_restrictions @endorsements_and_restrictions end |
#insurances ⇒ Object
List of insurances.
1061 1062 1063 |
# File 'lib/stripe/params/charge_update_params.rb', line 1061 def insurances @insurances end |
#passengers ⇒ Object
List of passengers.
1063 1064 1065 |
# File 'lib/stripe/params/charge_update_params.rb', line 1063 def passengers @passengers end |
#segments ⇒ Object
List of flight segments.
1065 1066 1067 |
# File 'lib/stripe/params/charge_update_params.rb', line 1065 def segments @segments end |
#ticket_electronically_issued_indicator ⇒ Object
Electronic ticket indicator.
1067 1068 1069 |
# File 'lib/stripe/params/charge_update_params.rb', line 1067 def ticket_electronically_issued_indicator @ticket_electronically_issued_indicator end |
#total ⇒ Object
Total cost breakdown.
1069 1070 1071 |
# File 'lib/stripe/params/charge_update_params.rb', line 1069 def total @total end |
#transaction_type ⇒ Object
Type of flight transaction.
1071 1072 1073 |
# File 'lib/stripe/params/charge_update_params.rb', line 1071 def transaction_type @transaction_type end |