Class: Stripe::ChargeUpdateParams::PaymentDetails::FlightDatum::Affiliate
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ChargeUpdateParams::PaymentDetails::FlightDatum::Affiliate
- Defined in:
- lib/stripe/params/charge_update_params.rb
Instance Attribute Summary collapse
-
#code ⇒ Object
Affiliate partner code.
-
#name ⇒ Object
Name of affiliate partner.
-
#travel_authorization_code ⇒ Object
Code provided by the company to a travel agent authorizing ticket issuance.
Instance Method Summary collapse
-
#initialize(code: nil, name: nil, travel_authorization_code: nil) ⇒ Affiliate
constructor
A new instance of Affiliate.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(code: nil, name: nil, travel_authorization_code: nil) ⇒ Affiliate
Returns a new instance of Affiliate.
838 839 840 841 842 |
# File 'lib/stripe/params/charge_update_params.rb', line 838 def initialize(code: nil, name: nil, travel_authorization_code: nil) @code = code @name = name @travel_authorization_code = end |
Instance Attribute Details
#code ⇒ Object
Affiliate partner code.
832 833 834 |
# File 'lib/stripe/params/charge_update_params.rb', line 832 def code @code end |
#name ⇒ Object
Name of affiliate partner.
834 835 836 |
# File 'lib/stripe/params/charge_update_params.rb', line 834 def name @name end |
#travel_authorization_code ⇒ Object
Code provided by the company to a travel agent authorizing ticket issuance.
836 837 838 |
# File 'lib/stripe/params/charge_update_params.rb', line 836 def @travel_authorization_code end |