Class: Stripe::ChargeUpdateParams::PaymentDetails::MoneyServices
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ChargeUpdateParams::PaymentDetails::MoneyServices
- Defined in:
- lib/stripe/params/charge_update_params.rb
Defined Under Namespace
Classes: AccountFunding
Instance Attribute Summary collapse
-
#account_funding ⇒ Object
Account funding transaction details including sender and beneficiary information.
-
#transaction_type ⇒ Object
The type of money services transaction.
Instance Method Summary collapse
-
#initialize(account_funding: nil, transaction_type: nil) ⇒ MoneyServices
constructor
A new instance of MoneyServices.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(account_funding: nil, transaction_type: nil) ⇒ MoneyServices
Returns a new instance of MoneyServices.
1809 1810 1811 1812 |
# File 'lib/stripe/params/charge_update_params.rb', line 1809 def initialize(account_funding: nil, transaction_type: nil) @account_funding = account_funding @transaction_type = transaction_type end |
Instance Attribute Details
#account_funding ⇒ Object
Account funding transaction details including sender and beneficiary information.
1805 1806 1807 |
# File 'lib/stripe/params/charge_update_params.rb', line 1805 def account_funding @account_funding end |
#transaction_type ⇒ Object
The type of money services transaction.
1807 1808 1809 |
# File 'lib/stripe/params/charge_update_params.rb', line 1807 def transaction_type @transaction_type end |