Class: Stripe::ChargeUpdateParams::PaymentDetails::Subscription::BillingInterval

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/charge_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(count: nil, interval: nil) ⇒ BillingInterval

Returns a new instance of BillingInterval.



1666
1667
1668
1669
# File 'lib/stripe/params/charge_update_params.rb', line 1666

def initialize(count: nil, interval: nil)
  @count = count
  @interval = interval
end

Instance Attribute Details

#countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



1662
1663
1664
# File 'lib/stripe/params/charge_update_params.rb', line 1662

def count
  @count
end

#intervalObject

Specifies a type of interval unit. Either day, week, month or year.



1664
1665
1666
# File 'lib/stripe/params/charge_update_params.rb', line 1664

def interval
  @interval
end