Class: Stripe::ChargeUpdateParams::Shipping

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/charge_update_params.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



1796
1797
1798
1799
1800
1801
1802
# File 'lib/stripe/params/charge_update_params.rb', line 1796

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



1786
1787
1788
# File 'lib/stripe/params/charge_update_params.rb', line 1786

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



1788
1789
1790
# File 'lib/stripe/params/charge_update_params.rb', line 1788

def carrier
  @carrier
end

#nameObject

Recipient name.



1790
1791
1792
# File 'lib/stripe/params/charge_update_params.rb', line 1790

def name
  @name
end

#phoneObject

Recipient phone (including extension).



1792
1793
1794
# File 'lib/stripe/params/charge_update_params.rb', line 1792

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



1794
1795
1796
# File 'lib/stripe/params/charge_update_params.rb', line 1794

def tracking_number
  @tracking_number
end