Class: Stripe::Checkout::Session::AutomaticSurcharge

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#calculation_basisObject (readonly)

Determines which amount serves as the basis for calculating the surcharge.



78
79
80
# File 'lib/stripe/resources/checkout/session.rb', line 78

def calculation_basis
  @calculation_basis
end

#enabledObject (readonly)

Indicates whether automatic surcharge is enabled for the session.



80
81
82
# File 'lib/stripe/resources/checkout/session.rb', line 80

def enabled
  @enabled
end

#providerObject (readonly)

The surcharge provider used for this session.



82
83
84
# File 'lib/stripe/resources/checkout/session.rb', line 82

def provider
  @provider
end

#statusObject (readonly)

The status of the most recent surcharge calculation for this session.



84
85
86
# File 'lib/stripe/resources/checkout/session.rb', line 84

def status
  @status
end

#tax_behaviorObject (readonly)

Specifies whether the surcharge is considered inclusive or exclusive of taxes.



86
87
88
# File 'lib/stripe/resources/checkout/session.rb', line 86

def tax_behavior
  @tax_behavior
end

Class Method Details

.field_remappingsObject



92
93
94
# File 'lib/stripe/resources/checkout/session.rb', line 92

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



88
89
90
# File 'lib/stripe/resources/checkout/session.rb', line 88

def self.inner_class_types
  @inner_class_types = {}
end