Class: Stripe::Checkout::Session::Consent
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Checkout::Session::Consent
- Defined in:
- lib/stripe/resources/checkout/session.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#promotions ⇒ Object
readonly
If ‘opt_in`, the customer consents to receiving promotional communications from the merchant about this Checkout Session.
-
#terms_of_service ⇒ Object
readonly
If ‘accepted`, the customer in this Checkout Session has agreed to the merchant’s terms of service.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#promotions ⇒ Object (readonly)
If ‘opt_in`, the customer consents to receiving promotional communications from the merchant about this Checkout Session.
97 98 99 |
# File 'lib/stripe/resources/checkout/session.rb', line 97 def promotions @promotions end |
#terms_of_service ⇒ Object (readonly)
If ‘accepted`, the customer in this Checkout Session has agreed to the merchant’s terms of service.
99 100 101 |
# File 'lib/stripe/resources/checkout/session.rb', line 99 def terms_of_service @terms_of_service end |