Class: Stripe::Checkout::Session::CreateParams::CustomText
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::CreateParams::CustomText
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: AfterSubmit, ShippingAddress, Submit, TermsOfServiceAcceptance
Instance Attribute Summary collapse
-
#after_submit ⇒ Object
Custom text that should be displayed after the payment confirmation button.
-
#shipping_address ⇒ Object
Custom text that should be displayed alongside shipping address collection.
-
#submit ⇒ Object
Custom text that should be displayed alongside the payment confirmation button.
-
#terms_of_service_acceptance ⇒ Object
Custom text that should be displayed in place of the default terms of service agreement text.
Instance Method Summary collapse
-
#initialize(after_submit: nil, shipping_address: nil, submit: nil, terms_of_service_acceptance: nil) ⇒ CustomText
constructor
A new instance of CustomText.
Methods inherited from RequestParams
Constructor Details
#initialize(after_submit: nil, shipping_address: nil, submit: nil, terms_of_service_acceptance: nil) ⇒ CustomText
Returns a new instance of CustomText.
2494 2495 2496 2497 2498 2499 2500 2501 2502 2503 2504 |
# File 'lib/stripe/resources/checkout/session.rb', line 2494 def initialize( after_submit: nil, shipping_address: nil, submit: nil, terms_of_service_acceptance: nil ) @after_submit = after_submit @shipping_address = shipping_address @submit = submit @terms_of_service_acceptance = terms_of_service_acceptance end |
Instance Attribute Details
#after_submit ⇒ Object
Custom text that should be displayed after the payment confirmation button.
2486 2487 2488 |
# File 'lib/stripe/resources/checkout/session.rb', line 2486 def after_submit @after_submit end |
#shipping_address ⇒ Object
Custom text that should be displayed alongside shipping address collection.
2488 2489 2490 |
# File 'lib/stripe/resources/checkout/session.rb', line 2488 def shipping_address @shipping_address end |
#submit ⇒ Object
Custom text that should be displayed alongside the payment confirmation button.
2490 2491 2492 |
# File 'lib/stripe/resources/checkout/session.rb', line 2490 def submit @submit end |
#terms_of_service_acceptance ⇒ Object
Custom text that should be displayed in place of the default terms of service agreement text.
2492 2493 2494 |
# File 'lib/stripe/resources/checkout/session.rb', line 2492 def terms_of_service_acceptance @terms_of_service_acceptance end |