Class: Stripe::Checkout::Session::CreateParams::CustomerUpdate

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, name: nil, shipping: nil) ⇒ CustomerUpdate

Returns a new instance of CustomerUpdate.



2517
2518
2519
2520
2521
# File 'lib/stripe/resources/checkout/session.rb', line 2517

def initialize(address: nil, name: nil, shipping: nil)
  @address = address
  @name = name
  @shipping = shipping
end

Instance Attribute Details

#addressObject

Describes whether Checkout saves the billing address onto ‘customer.address`. To always collect a full billing address, use `billing_address_collection`. Defaults to `never`.



2510
2511
2512
# File 'lib/stripe/resources/checkout/session.rb', line 2510

def address
  @address
end

#nameObject

Describes whether Checkout saves the name onto ‘customer.name`. Defaults to `never`.



2512
2513
2514
# File 'lib/stripe/resources/checkout/session.rb', line 2512

def name
  @name
end

#shippingObject

Describes whether Checkout saves shipping information onto ‘customer.shipping`. To collect shipping information, use `shipping_address_collection`. Defaults to `never`.



2515
2516
2517
# File 'lib/stripe/resources/checkout/session.rb', line 2515

def shipping
  @shipping
end