Class: Stripe::Checkout::Session::CreateParams::Discount::CouponData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::CreateParams::Discount::CouponData
- Defined in:
- lib/stripe/resources/checkout/session.rb
Instance Attribute Summary collapse
-
#amount_off ⇒ Object
A positive integer representing the amount to subtract from an invoice total (required if ‘percent_off` is not passed).
-
#currency ⇒ Object
Three-letter [ISO code for the currency](stripe.com/docs/currencies) of the ‘amount_off` parameter (required if `amount_off` is passed).
-
#duration ⇒ Object
Specifies how long the discount will be in effect if used on a subscription.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#name ⇒ Object
Name of the coupon displayed to customers on, for instance invoices, or receipts.
-
#percent_off ⇒ Object
A positive float larger than 0, and smaller or equal to 100, that represents the discount the coupon will apply (required if ‘amount_off` is not passed).
Instance Method Summary collapse
-
#initialize(amount_off: nil, currency: nil, duration: nil, metadata: nil, name: nil, percent_off: nil) ⇒ CouponData
constructor
A new instance of CouponData.
Methods inherited from RequestParams
Constructor Details
#initialize(amount_off: nil, currency: nil, duration: nil, metadata: nil, name: nil, percent_off: nil) ⇒ CouponData
Returns a new instance of CouponData.
1624 1625 1626 1627 1628 1629 1630 1631 1632 1633 1634 1635 1636 1637 1638 |
# File 'lib/stripe/resources/checkout/session.rb', line 1624 def initialize( amount_off: nil, currency: nil, duration: nil, metadata: nil, name: nil, percent_off: nil ) @amount_off = amount_off @currency = currency @duration = duration @metadata = @name = name @percent_off = percent_off end |
Instance Attribute Details
#amount_off ⇒ Object
A positive integer representing the amount to subtract from an invoice total (required if ‘percent_off` is not passed).
1612 1613 1614 |
# File 'lib/stripe/resources/checkout/session.rb', line 1612 def amount_off @amount_off end |
#currency ⇒ Object
Three-letter [ISO code for the currency](stripe.com/docs/currencies) of the ‘amount_off` parameter (required if `amount_off` is passed).
1614 1615 1616 |
# File 'lib/stripe/resources/checkout/session.rb', line 1614 def currency @currency end |
#duration ⇒ Object
Specifies how long the discount will be in effect if used on a subscription. Defaults to ‘once`.
1616 1617 1618 |
# File 'lib/stripe/resources/checkout/session.rb', line 1616 def duration @duration end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
1618 1619 1620 |
# File 'lib/stripe/resources/checkout/session.rb', line 1618 def @metadata end |
#name ⇒ Object
Name of the coupon displayed to customers on, for instance invoices, or receipts. By default the ‘id` is shown if `name` is not set.
1620 1621 1622 |
# File 'lib/stripe/resources/checkout/session.rb', line 1620 def name @name end |
#percent_off ⇒ Object
A positive float larger than 0, and smaller or equal to 100, that represents the discount the coupon will apply (required if ‘amount_off` is not passed).
1622 1623 1624 |
# File 'lib/stripe/resources/checkout/session.rb', line 1622 def percent_off @percent_off end |