Class: Stripe::Checkout::Session::CreateParams::InvoiceCreation::InvoiceData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Defined Under Namespace

Classes: CustomField, Issuer, RenderingOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_tax_ids: nil, custom_fields: nil, description: nil, footer: nil, issuer: nil, metadata: nil, rendering_options: nil) ⇒ InvoiceData

Returns a new instance of InvoiceData.



2621
2622
2623
2624
2625
2626
2627
2628
2629
2630
2631
2632
2633
2634
2635
2636
2637
# File 'lib/stripe/resources/checkout/session.rb', line 2621

def initialize(
  account_tax_ids: nil,
  custom_fields: nil,
  description: nil,
  footer: nil,
  issuer: nil,
  metadata: nil,
  rendering_options: nil
)
  @account_tax_ids = 
  @custom_fields = custom_fields
  @description = description
  @footer = footer
  @issuer = issuer
  @metadata = 
  @rendering_options = rendering_options
end

Instance Attribute Details

#account_tax_idsObject

The account tax IDs associated with the invoice.



2607
2608
2609
# File 'lib/stripe/resources/checkout/session.rb', line 2607

def 
  @account_tax_ids
end

#custom_fieldsObject

Default custom fields to be displayed on invoices for this customer.



2609
2610
2611
# File 'lib/stripe/resources/checkout/session.rb', line 2609

def custom_fields
  @custom_fields
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



2611
2612
2613
# File 'lib/stripe/resources/checkout/session.rb', line 2611

def description
  @description
end

Default footer to be displayed on invoices for this customer.



2613
2614
2615
# File 'lib/stripe/resources/checkout/session.rb', line 2613

def footer
  @footer
end

#issuerObject

The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.



2615
2616
2617
# File 'lib/stripe/resources/checkout/session.rb', line 2615

def issuer
  @issuer
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2617
2618
2619
# File 'lib/stripe/resources/checkout/session.rb', line 2617

def 
  @metadata
end

#rendering_optionsObject

Default options for invoice PDF rendering for this customer.



2619
2620
2621
# File 'lib/stripe/resources/checkout/session.rb', line 2619

def rendering_options
  @rendering_options
end