Class: Stripe::Checkout::Session::CreateParams::LineItem::AdjustableQuantity
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::CreateParams::LineItem::AdjustableQuantity
- Defined in:
- lib/stripe/resources/checkout/session.rb
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Set to true if the quantity can be adjusted to any non-negative integer.
-
#maximum ⇒ Object
The maximum quantity the customer can purchase for the Checkout Session.
-
#minimum ⇒ Object
The minimum quantity the customer must purchase for the Checkout Session.
Instance Method Summary collapse
-
#initialize(enabled: nil, maximum: nil, minimum: nil) ⇒ AdjustableQuantity
constructor
A new instance of AdjustableQuantity.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, maximum: nil, minimum: nil) ⇒ AdjustableQuantity
Returns a new instance of AdjustableQuantity.
1529 1530 1531 1532 1533 |
# File 'lib/stripe/resources/checkout/session.rb', line 1529 def initialize(enabled: nil, maximum: nil, minimum: nil) @enabled = enabled @maximum = maximum @minimum = minimum end |
Instance Attribute Details
#enabled ⇒ Object
Set to true if the quantity can be adjusted to any non-negative integer.
1523 1524 1525 |
# File 'lib/stripe/resources/checkout/session.rb', line 1523 def enabled @enabled end |
#maximum ⇒ Object
The maximum quantity the customer can purchase for the Checkout Session. By default this value is 99. You can specify a value up to 999999.
1525 1526 1527 |
# File 'lib/stripe/resources/checkout/session.rb', line 1525 def maximum @maximum end |
#minimum ⇒ Object
The minimum quantity the customer must purchase for the Checkout Session. By default this value is 0.
1527 1528 1529 |
# File 'lib/stripe/resources/checkout/session.rb', line 1527 def minimum @minimum end |