Class: Stripe::Checkout::Session::CreateParams::LineItem::PriceData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::CreateParams::LineItem::PriceData
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: ProductData, Recurring
Instance Attribute Summary collapse
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#product ⇒ Object
The ID of the product that this price will belong to.
-
#product_data ⇒ Object
Data used to generate a new product object inline.
-
#recurring ⇒ Object
The recurring components of a price such as ‘interval` and `interval_count`.
-
#tax_behavior ⇒ Object
Only required if a [default tax behavior](stripe.com/docs/tax/products-prices-tax-categories-tax-behavior#setting-a-default-tax-behavior-(recommended)) was not provided in the Stripe Tax settings.
-
#unit_amount ⇒ Object
A non-negative integer in cents (or local equivalent) representing how much to charge.
-
#unit_amount_decimal ⇒ Object
Same as ‘unit_amount`, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places.
Instance Method Summary collapse
-
#initialize(currency: nil, product: nil, product_data: nil, recurring: nil, tax_behavior: nil, unit_amount: nil, unit_amount_decimal: nil) ⇒ PriceData
constructor
A new instance of PriceData.
Methods inherited from RequestParams
Constructor Details
#initialize(currency: nil, product: nil, product_data: nil, recurring: nil, tax_behavior: nil, unit_amount: nil, unit_amount_decimal: nil) ⇒ PriceData
Returns a new instance of PriceData.
1567 1568 1569 1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 |
# File 'lib/stripe/resources/checkout/session.rb', line 1567 def initialize( currency: nil, product: nil, product_data: nil, recurring: nil, tax_behavior: nil, unit_amount: nil, unit_amount_decimal: nil ) @currency = currency @product = product @product_data = product_data @recurring = recurring @tax_behavior = tax_behavior @unit_amount = unit_amount @unit_amount_decimal = unit_amount_decimal end |
Instance Attribute Details
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
1553 1554 1555 |
# File 'lib/stripe/resources/checkout/session.rb', line 1553 def currency @currency end |
#product ⇒ Object
The ID of the product that this price will belong to. One of ‘product` or `product_data` is required.
1555 1556 1557 |
# File 'lib/stripe/resources/checkout/session.rb', line 1555 def product @product end |
#product_data ⇒ Object
Data used to generate a new product object inline. One of ‘product` or `product_data` is required.
1557 1558 1559 |
# File 'lib/stripe/resources/checkout/session.rb', line 1557 def product_data @product_data end |
#recurring ⇒ Object
The recurring components of a price such as ‘interval` and `interval_count`.
1559 1560 1561 |
# File 'lib/stripe/resources/checkout/session.rb', line 1559 def recurring @recurring end |
#tax_behavior ⇒ Object
Only required if a [default tax behavior](stripe.com/docs/tax/products-prices-tax-categories-tax-behavior#setting-a-default-tax-behavior-(recommended)) was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`. Once specified as either `inclusive` or `exclusive`, it cannot be changed.
1561 1562 1563 |
# File 'lib/stripe/resources/checkout/session.rb', line 1561 def tax_behavior @tax_behavior end |
#unit_amount ⇒ Object
A non-negative integer in cents (or local equivalent) representing how much to charge. One of ‘unit_amount` or `unit_amount_decimal` is required.
1563 1564 1565 |
# File 'lib/stripe/resources/checkout/session.rb', line 1563 def unit_amount @unit_amount end |
#unit_amount_decimal ⇒ Object
Same as ‘unit_amount`, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places. Only one of `unit_amount` and `unit_amount_decimal` can be set.
1565 1566 1567 |
# File 'lib/stripe/resources/checkout/session.rb', line 1565 def unit_amount_decimal @unit_amount_decimal end |