Class: Stripe::Checkout::Session::CreateParams::LineItem::PriceData::ProductData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil) ⇒ ProductData

Returns a new instance of ProductData.



1588
1589
1590
1591
1592
1593
1594
# File 'lib/stripe/resources/checkout/session.rb', line 1588

def initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil)
  @description = description
  @images = images
  @metadata = 
  @name = name
  @tax_code = tax_code
end

Instance Attribute Details

#descriptionObject

The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.



1578
1579
1580
# File 'lib/stripe/resources/checkout/session.rb', line 1578

def description
  @description
end

#imagesObject

A list of up to 8 URLs of images for this product, meant to be displayable to the customer.



1580
1581
1582
# File 'lib/stripe/resources/checkout/session.rb', line 1580

def images
  @images
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1582
1583
1584
# File 'lib/stripe/resources/checkout/session.rb', line 1582

def 
  @metadata
end

#nameObject

The product’s name, meant to be displayable to the customer.



1584
1585
1586
# File 'lib/stripe/resources/checkout/session.rb', line 1584

def name
  @name
end

#tax_codeObject



1586
1587
1588
# File 'lib/stripe/resources/checkout/session.rb', line 1586

def tax_code
  @tax_code
end