Class: Stripe::Checkout::Session::CreateParams::PaymentIntentData::Shipping
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::CreateParams::PaymentIntentData::Shipping
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Shipping address.
-
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
-
#name ⇒ Object
Recipient name.
-
#phone ⇒ Object
Recipient phone (including extension).
-
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service.
Instance Method Summary collapse
-
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
constructor
A new instance of Shipping.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
Returns a new instance of Shipping.
1747 1748 1749 1750 1751 1752 1753 |
# File 'lib/stripe/resources/checkout/session.rb', line 1747 def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) @address = address @carrier = carrier @name = name @phone = phone @tracking_number = tracking_number end |
Instance Attribute Details
#address ⇒ Object
Shipping address.
1737 1738 1739 |
# File 'lib/stripe/resources/checkout/session.rb', line 1737 def address @address end |
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
1739 1740 1741 |
# File 'lib/stripe/resources/checkout/session.rb', line 1739 def carrier @carrier end |
#name ⇒ Object
Recipient name.
1741 1742 1743 |
# File 'lib/stripe/resources/checkout/session.rb', line 1741 def name @name end |
#phone ⇒ Object
Recipient phone (including extension).
1743 1744 1745 |
# File 'lib/stripe/resources/checkout/session.rb', line 1743 def phone @phone end |
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
1745 1746 1747 |
# File 'lib/stripe/resources/checkout/session.rb', line 1745 def tracking_number @tracking_number end |