Class: Stripe::Checkout::Session::CreateParams::PaymentMethodOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::CreateParams::PaymentMethodOptions
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Boleto, Card, Cashapp, CustomerBalance, Eps, Fpx, Giropay, Grabpay, Ideal, KakaoPay, Klarna, Konbini, KrCard, Link, Mobilepay, Multibanco, NaverPay, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Payto, Pix, RevolutPay, SamsungPay, SepaDebit, Sofort, Swish, UsBankAccount, WechatPay
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
contains details about the ACSS Debit payment method options.
-
#affirm ⇒ Object
contains details about the Affirm payment method options.
-
#afterpay_clearpay ⇒ Object
contains details about the Afterpay Clearpay payment method options.
-
#alipay ⇒ Object
contains details about the Alipay payment method options.
-
#amazon_pay ⇒ Object
contains details about the AmazonPay payment method options.
-
#au_becs_debit ⇒ Object
contains details about the AU Becs Debit payment method options.
-
#bacs_debit ⇒ Object
contains details about the Bacs Debit payment method options.
-
#bancontact ⇒ Object
contains details about the Bancontact payment method options.
-
#boleto ⇒ Object
contains details about the Boleto payment method options.
-
#card ⇒ Object
contains details about the Card payment method options.
-
#cashapp ⇒ Object
contains details about the Cashapp Pay payment method options.
-
#customer_balance ⇒ Object
contains details about the Customer Balance payment method options.
-
#eps ⇒ Object
contains details about the EPS payment method options.
-
#fpx ⇒ Object
contains details about the FPX payment method options.
-
#giropay ⇒ Object
contains details about the Giropay payment method options.
-
#grabpay ⇒ Object
contains details about the Grabpay payment method options.
-
#ideal ⇒ Object
contains details about the Ideal payment method options.
-
#kakao_pay ⇒ Object
contains details about the Kakao Pay payment method options.
-
#klarna ⇒ Object
contains details about the Klarna payment method options.
-
#konbini ⇒ Object
contains details about the Konbini payment method options.
-
#kr_card ⇒ Object
contains details about the Korean card payment method options.
-
#link ⇒ Object
contains details about the Link payment method options.
-
#mobilepay ⇒ Object
contains details about the Mobilepay payment method options.
-
#multibanco ⇒ Object
contains details about the Multibanco payment method options.
-
#naver_pay ⇒ Object
contains details about the Naver Pay payment method options.
-
#oxxo ⇒ Object
contains details about the OXXO payment method options.
-
#p24 ⇒ Object
contains details about the P24 payment method options.
-
#pay_by_bank ⇒ Object
contains details about the Pay By Bank payment method options.
-
#payco ⇒ Object
contains details about the PAYCO payment method options.
-
#paynow ⇒ Object
contains details about the PayNow payment method options.
-
#paypal ⇒ Object
contains details about the PayPal payment method options.
-
#payto ⇒ Object
contains details about the PayTo payment method options.
-
#pix ⇒ Object
contains details about the Pix payment method options.
-
#revolut_pay ⇒ Object
contains details about the RevolutPay payment method options.
-
#samsung_pay ⇒ Object
contains details about the Samsung Pay payment method options.
-
#sepa_debit ⇒ Object
contains details about the Sepa Debit payment method options.
-
#sofort ⇒ Object
contains details about the Sofort payment method options.
-
#swish ⇒ Object
contains details about the Swish payment method options.
-
#us_bank_account ⇒ Object
contains details about the Us Bank Account payment method options.
-
#wechat_pay ⇒ Object
contains details about the WeChat Pay payment method options.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, amazon_pay: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, boleto: nil, card: nil, cashapp: nil, customer_balance: nil, eps: nil, fpx: nil, giropay: nil, grabpay: nil, ideal: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, mobilepay: nil, multibanco: nil, naver_pay: nil, oxxo: nil, p24: nil, pay_by_bank: nil, payco: nil, paynow: nil, paypal: nil, payto: nil, pix: nil, revolut_pay: nil, samsung_pay: nil, sepa_debit: nil, sofort: nil, swish: nil, us_bank_account: nil, wechat_pay: nil) ⇒ PaymentMethodOptions
Returns a new instance of PaymentMethodOptions.
3974 3975 3976 3977 3978 3979 3980 3981 3982 3983 3984 3985 3986 3987 3988 3989 3990 3991 3992 3993 3994 3995 3996 3997 3998 3999 4000 4001 4002 4003 4004 4005 4006 4007 4008 4009 4010 4011 4012 4013 4014 4015 4016 4017 4018 4019 4020 4021 4022 4023 4024 4025 4026 4027 4028 4029 4030 4031 4032 4033 4034 4035 4036 4037 4038 4039 4040 4041 4042 4043 4044 4045 4046 4047 4048 4049 4050 4051 4052 4053 4054 4055 4056 |
# File 'lib/stripe/resources/checkout/session.rb', line 3974 def initialize( acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, amazon_pay: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, boleto: nil, card: nil, cashapp: nil, customer_balance: nil, eps: nil, fpx: nil, giropay: nil, grabpay: nil, ideal: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, mobilepay: nil, multibanco: nil, naver_pay: nil, oxxo: nil, p24: nil, pay_by_bank: nil, payco: nil, paynow: nil, paypal: nil, payto: nil, pix: nil, revolut_pay: nil, samsung_pay: nil, sepa_debit: nil, sofort: nil, swish: nil, us_bank_account: nil, wechat_pay: nil ) @acss_debit = acss_debit @affirm = affirm @afterpay_clearpay = afterpay_clearpay @alipay = alipay @amazon_pay = amazon_pay @au_becs_debit = au_becs_debit @bacs_debit = bacs_debit @bancontact = bancontact @boleto = boleto @card = card @cashapp = cashapp @customer_balance = customer_balance @eps = eps @fpx = fpx @giropay = giropay @grabpay = grabpay @ideal = ideal @kakao_pay = kakao_pay @klarna = klarna @konbini = konbini @kr_card = kr_card @link = link @mobilepay = mobilepay @multibanco = multibanco @naver_pay = naver_pay @oxxo = oxxo @p24 = p24 @pay_by_bank = pay_by_bank @payco = payco @paynow = paynow @paypal = paypal @payto = payto @pix = pix @revolut_pay = revolut_pay @samsung_pay = samsung_pay @sepa_debit = sepa_debit @sofort = sofort @swish = swish @us_bank_account = us_bank_account @wechat_pay = wechat_pay end |
Instance Attribute Details
#acss_debit ⇒ Object
contains details about the ACSS Debit payment method options.
3894 3895 3896 |
# File 'lib/stripe/resources/checkout/session.rb', line 3894 def acss_debit @acss_debit end |
#affirm ⇒ Object
contains details about the Affirm payment method options.
3896 3897 3898 |
# File 'lib/stripe/resources/checkout/session.rb', line 3896 def affirm @affirm end |
#afterpay_clearpay ⇒ Object
contains details about the Afterpay Clearpay payment method options.
3898 3899 3900 |
# File 'lib/stripe/resources/checkout/session.rb', line 3898 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object
contains details about the Alipay payment method options.
3900 3901 3902 |
# File 'lib/stripe/resources/checkout/session.rb', line 3900 def alipay @alipay end |
#amazon_pay ⇒ Object
contains details about the AmazonPay payment method options.
3902 3903 3904 |
# File 'lib/stripe/resources/checkout/session.rb', line 3902 def amazon_pay @amazon_pay end |
#au_becs_debit ⇒ Object
contains details about the AU Becs Debit payment method options.
3904 3905 3906 |
# File 'lib/stripe/resources/checkout/session.rb', line 3904 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object
contains details about the Bacs Debit payment method options.
3906 3907 3908 |
# File 'lib/stripe/resources/checkout/session.rb', line 3906 def bacs_debit @bacs_debit end |
#bancontact ⇒ Object
contains details about the Bancontact payment method options.
3908 3909 3910 |
# File 'lib/stripe/resources/checkout/session.rb', line 3908 def bancontact @bancontact end |
#boleto ⇒ Object
contains details about the Boleto payment method options.
3910 3911 3912 |
# File 'lib/stripe/resources/checkout/session.rb', line 3910 def boleto @boleto end |
#card ⇒ Object
contains details about the Card payment method options.
3912 3913 3914 |
# File 'lib/stripe/resources/checkout/session.rb', line 3912 def card @card end |
#cashapp ⇒ Object
contains details about the Cashapp Pay payment method options.
3914 3915 3916 |
# File 'lib/stripe/resources/checkout/session.rb', line 3914 def cashapp @cashapp end |
#customer_balance ⇒ Object
contains details about the Customer Balance payment method options.
3916 3917 3918 |
# File 'lib/stripe/resources/checkout/session.rb', line 3916 def customer_balance @customer_balance end |
#eps ⇒ Object
contains details about the EPS payment method options.
3918 3919 3920 |
# File 'lib/stripe/resources/checkout/session.rb', line 3918 def eps @eps end |
#fpx ⇒ Object
contains details about the FPX payment method options.
3920 3921 3922 |
# File 'lib/stripe/resources/checkout/session.rb', line 3920 def fpx @fpx end |
#giropay ⇒ Object
contains details about the Giropay payment method options.
3922 3923 3924 |
# File 'lib/stripe/resources/checkout/session.rb', line 3922 def giropay @giropay end |
#grabpay ⇒ Object
contains details about the Grabpay payment method options.
3924 3925 3926 |
# File 'lib/stripe/resources/checkout/session.rb', line 3924 def grabpay @grabpay end |
#ideal ⇒ Object
contains details about the Ideal payment method options.
3926 3927 3928 |
# File 'lib/stripe/resources/checkout/session.rb', line 3926 def ideal @ideal end |
#kakao_pay ⇒ Object
contains details about the Kakao Pay payment method options.
3928 3929 3930 |
# File 'lib/stripe/resources/checkout/session.rb', line 3928 def kakao_pay @kakao_pay end |
#klarna ⇒ Object
contains details about the Klarna payment method options.
3930 3931 3932 |
# File 'lib/stripe/resources/checkout/session.rb', line 3930 def klarna @klarna end |
#konbini ⇒ Object
contains details about the Konbini payment method options.
3932 3933 3934 |
# File 'lib/stripe/resources/checkout/session.rb', line 3932 def konbini @konbini end |
#kr_card ⇒ Object
contains details about the Korean card payment method options.
3934 3935 3936 |
# File 'lib/stripe/resources/checkout/session.rb', line 3934 def kr_card @kr_card end |
#link ⇒ Object
contains details about the Link payment method options.
3936 3937 3938 |
# File 'lib/stripe/resources/checkout/session.rb', line 3936 def link @link end |
#mobilepay ⇒ Object
contains details about the Mobilepay payment method options.
3938 3939 3940 |
# File 'lib/stripe/resources/checkout/session.rb', line 3938 def mobilepay @mobilepay end |
#multibanco ⇒ Object
contains details about the Multibanco payment method options.
3940 3941 3942 |
# File 'lib/stripe/resources/checkout/session.rb', line 3940 def multibanco @multibanco end |
#naver_pay ⇒ Object
contains details about the Naver Pay payment method options.
3942 3943 3944 |
# File 'lib/stripe/resources/checkout/session.rb', line 3942 def naver_pay @naver_pay end |
#oxxo ⇒ Object
contains details about the OXXO payment method options.
3944 3945 3946 |
# File 'lib/stripe/resources/checkout/session.rb', line 3944 def oxxo @oxxo end |
#p24 ⇒ Object
contains details about the P24 payment method options.
3946 3947 3948 |
# File 'lib/stripe/resources/checkout/session.rb', line 3946 def p24 @p24 end |
#pay_by_bank ⇒ Object
contains details about the Pay By Bank payment method options.
3948 3949 3950 |
# File 'lib/stripe/resources/checkout/session.rb', line 3948 def pay_by_bank @pay_by_bank end |
#payco ⇒ Object
contains details about the PAYCO payment method options.
3950 3951 3952 |
# File 'lib/stripe/resources/checkout/session.rb', line 3950 def payco @payco end |
#paynow ⇒ Object
contains details about the PayNow payment method options.
3952 3953 3954 |
# File 'lib/stripe/resources/checkout/session.rb', line 3952 def paynow @paynow end |
#paypal ⇒ Object
contains details about the PayPal payment method options.
3954 3955 3956 |
# File 'lib/stripe/resources/checkout/session.rb', line 3954 def paypal @paypal end |
#payto ⇒ Object
contains details about the PayTo payment method options.
3956 3957 3958 |
# File 'lib/stripe/resources/checkout/session.rb', line 3956 def payto @payto end |
#pix ⇒ Object
contains details about the Pix payment method options.
3958 3959 3960 |
# File 'lib/stripe/resources/checkout/session.rb', line 3958 def pix @pix end |
#revolut_pay ⇒ Object
contains details about the RevolutPay payment method options.
3960 3961 3962 |
# File 'lib/stripe/resources/checkout/session.rb', line 3960 def revolut_pay @revolut_pay end |
#samsung_pay ⇒ Object
contains details about the Samsung Pay payment method options.
3962 3963 3964 |
# File 'lib/stripe/resources/checkout/session.rb', line 3962 def samsung_pay @samsung_pay end |
#sepa_debit ⇒ Object
contains details about the Sepa Debit payment method options.
3964 3965 3966 |
# File 'lib/stripe/resources/checkout/session.rb', line 3964 def sepa_debit @sepa_debit end |
#sofort ⇒ Object
contains details about the Sofort payment method options.
3966 3967 3968 |
# File 'lib/stripe/resources/checkout/session.rb', line 3966 def sofort @sofort end |
#swish ⇒ Object
contains details about the Swish payment method options.
3968 3969 3970 |
# File 'lib/stripe/resources/checkout/session.rb', line 3968 def swish @swish end |
#us_bank_account ⇒ Object
contains details about the Us Bank Account payment method options.
3970 3971 3972 |
# File 'lib/stripe/resources/checkout/session.rb', line 3970 def us_bank_account @us_bank_account end |
#wechat_pay ⇒ Object
contains details about the WeChat Pay payment method options.
3972 3973 3974 |
# File 'lib/stripe/resources/checkout/session.rb', line 3972 def wechat_pay @wechat_pay end |