Class: Stripe::Checkout::Session::CreateParams::PaymentMethodOptions::AcssDebit
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::CreateParams::PaymentMethodOptions::AcssDebit
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: MandateOptions
Instance Attribute Summary collapse
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#mandate_options ⇒ Object
Additional fields for Mandate creation.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
-
#target_date ⇒ Object
Controls when Stripe will attempt to debit the funds from the customer’s account.
-
#verification_method ⇒ Object
Verification method for the intent.
Instance Method Summary collapse
-
#initialize(currency: nil, mandate_options: nil, setup_future_usage: nil, target_date: nil, verification_method: nil) ⇒ AcssDebit
constructor
A new instance of AcssDebit.
Methods inherited from RequestParams
Constructor Details
#initialize(currency: nil, mandate_options: nil, setup_future_usage: nil, target_date: nil, verification_method: nil) ⇒ AcssDebit
Returns a new instance of AcssDebit.
2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 |
# File 'lib/stripe/resources/checkout/session.rb', line 2080 def initialize( currency: nil, mandate_options: nil, setup_future_usage: nil, target_date: nil, verification_method: nil ) @currency = currency @mandate_options = @setup_future_usage = setup_future_usage @target_date = target_date @verification_method = verification_method end |
Instance Attribute Details
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies). This is only accepted for Checkout Sessions in ‘setup` mode.
2064 2065 2066 |
# File 'lib/stripe/resources/checkout/session.rb', line 2064 def currency @currency end |
#mandate_options ⇒ Object
Additional fields for Mandate creation
2066 2067 2068 |
# File 'lib/stripe/resources/checkout/session.rb', line 2066 def @mandate_options end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.
If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.
When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).
2074 2075 2076 |
# File 'lib/stripe/resources/checkout/session.rb', line 2074 def setup_future_usage @setup_future_usage end |
#target_date ⇒ Object
Controls when Stripe will attempt to debit the funds from the customer’s account. The date must be a string in YYYY-MM-DD format. The date must be in the future and between 3 and 15 calendar days from now.
2076 2077 2078 |
# File 'lib/stripe/resources/checkout/session.rb', line 2076 def target_date @target_date end |
#verification_method ⇒ Object
Verification method for the intent
2078 2079 2080 |
# File 'lib/stripe/resources/checkout/session.rb', line 2078 def verification_method @verification_method end |