Class: Stripe::Checkout::Session::CreateParams::PaymentMethodOptions::AcssDebit::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(custom_mandate_url: nil, default_for: nil, interval_description: nil, payment_schedule: nil, transaction_type: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
# File 'lib/stripe/resources/checkout/session.rb', line 1873

def initialize(
  custom_mandate_url: nil,
  default_for: nil,
  interval_description: nil,
  payment_schedule: nil,
  transaction_type: nil
)
  @custom_mandate_url = custom_mandate_url
  @default_for = default_for
  @interval_description = interval_description
  @payment_schedule = payment_schedule
  @transaction_type = transaction_type
end

Instance Attribute Details

#custom_mandate_urlObject

A URL for custom mandate text to render during confirmation step. The URL will be rendered with additional GET parameters ‘payment_intent` and `payment_intent_client_secret` when confirming a Payment Intent, or `setup_intent` and `setup_intent_client_secret` when confirming a Setup Intent.



1863
1864
1865
# File 'lib/stripe/resources/checkout/session.rb', line 1863

def custom_mandate_url
  @custom_mandate_url
end

#default_forObject

List of Stripe products where this mandate can be selected automatically. Only usable in ‘setup` mode.



1865
1866
1867
# File 'lib/stripe/resources/checkout/session.rb', line 1865

def default_for
  @default_for
end

#interval_descriptionObject

Description of the mandate interval. Only required if ‘payment_schedule’ parameter is ‘interval’ or ‘combined’.



1867
1868
1869
# File 'lib/stripe/resources/checkout/session.rb', line 1867

def interval_description
  @interval_description
end

#payment_scheduleObject

Payment schedule for the mandate.



1869
1870
1871
# File 'lib/stripe/resources/checkout/session.rb', line 1869

def payment_schedule
  @payment_schedule
end

#transaction_typeObject

Transaction type of the mandate.



1871
1872
1873
# File 'lib/stripe/resources/checkout/session.rb', line 1871

def transaction_type
  @transaction_type
end