Class: Stripe::Checkout::Session::CreateParams::PaymentMethodOptions::Card::Installments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::CreateParams::PaymentMethodOptions::Card::Installments
- Defined in:
- lib/stripe/resources/checkout/session.rb
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Setting to true enables installments for this Checkout Session.
Instance Method Summary collapse
-
#initialize(enabled: nil) ⇒ Installments
constructor
A new instance of Installments.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil) ⇒ Installments
Returns a new instance of Installments.
2065 2066 2067 |
# File 'lib/stripe/resources/checkout/session.rb', line 2065 def initialize(enabled: nil) @enabled = enabled end |
Instance Attribute Details
#enabled ⇒ Object
Setting to true enables installments for this Checkout Session. Setting to false will prevent any installment plan from applying to a payment.
2063 2064 2065 |
# File 'lib/stripe/resources/checkout/session.rb', line 2063 def enabled @enabled end |