Class: Stripe::Checkout::Session::CreateParams::PaymentMethodOptions::Card::Restrictions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(brands_blocked: nil) ⇒ Restrictions

Returns a new instance of Restrictions.



1972
1973
1974
# File 'lib/stripe/resources/checkout/session.rb', line 1972

def initialize(brands_blocked: nil)
  @brands_blocked = brands_blocked
end

Instance Attribute Details

#brands_blockedObject

Specify the card brands to block in the Checkout Session. If a customer enters or selects a card belonging to a blocked brand, they can’t complete the Session.



1970
1971
1972
# File 'lib/stripe/resources/checkout/session.rb', line 1970

def brands_blocked
  @brands_blocked
end