Class: Stripe::Checkout::Session::CreateParams::PaymentMethodOptions::Klarna::Subscription::NextBilling

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, date: nil) ⇒ NextBilling

Returns a new instance of NextBilling.



2471
2472
2473
2474
# File 'lib/stripe/resources/checkout/session.rb', line 2471

def initialize(amount: nil, date: nil)
  @amount = amount
  @date = date
end

Instance Attribute Details

#amountObject

The amount of the next charge for the subscription.



2467
2468
2469
# File 'lib/stripe/resources/checkout/session.rb', line 2467

def amount
  @amount
end

#dateObject

The date of the next charge for the subscription in YYYY-MM-DD format.



2469
2470
2471
# File 'lib/stripe/resources/checkout/session.rb', line 2469

def date
  @date
end