Class: Stripe::Checkout::Session::CreateParams::PaymentMethodOptions::Payco
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::CreateParams::PaymentMethodOptions::Payco
- Defined in:
- lib/stripe/resources/checkout/session.rb
Instance Attribute Summary collapse
-
#capture_method ⇒ Object
Controls when the funds will be captured from the customer’s account.
Instance Method Summary collapse
-
#initialize(capture_method: nil) ⇒ Payco
constructor
A new instance of Payco.
Methods inherited from RequestParams
Constructor Details
#initialize(capture_method: nil) ⇒ Payco
Returns a new instance of Payco.
3574 3575 3576 |
# File 'lib/stripe/resources/checkout/session.rb', line 3574 def initialize(capture_method: nil) @capture_method = capture_method end |
Instance Attribute Details
#capture_method ⇒ Object
Controls when the funds will be captured from the customer’s account.
3572 3573 3574 |
# File 'lib/stripe/resources/checkout/session.rb', line 3572 def capture_method @capture_method end |