Class: Stripe::Checkout::Session::CreateParams::PaymentMethodOptions::Pix

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_includes_iof: nil, expires_after_seconds: nil, setup_future_usage: nil) ⇒ Pix

Returns a new instance of Pix.



2461
2462
2463
2464
2465
2466
2467
2468
2469
# File 'lib/stripe/resources/checkout/session.rb', line 2461

def initialize(
  amount_includes_iof: nil,
  expires_after_seconds: nil,
  setup_future_usage: nil
)
  @amount_includes_iof = amount_includes_iof
  @expires_after_seconds = expires_after_seconds
  @setup_future_usage = setup_future_usage
end

Instance Attribute Details

#amount_includes_iofObject

Determines if the amount includes the IOF tax. Defaults to ‘never`.



2449
2450
2451
# File 'lib/stripe/resources/checkout/session.rb', line 2449

def amount_includes_iof
  @amount_includes_iof
end

#expires_after_secondsObject

The number of seconds (between 10 and 1209600) after which Pix payment will expire. Defaults to 86400 seconds.



2451
2452
2453
# File 'lib/stripe/resources/checkout/session.rb', line 2451

def expires_after_seconds
  @expires_after_seconds
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent’s payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.

If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.

When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).



2459
2460
2461
# File 'lib/stripe/resources/checkout/session.rb', line 2459

def setup_future_usage
  @setup_future_usage
end