Class: Stripe::Checkout::Session::CreateParams::PaymentMethodOptions::Pix::MandateOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::CreateParams::PaymentMethodOptions::Pix::MandateOptions
- Defined in:
- lib/stripe/resources/checkout/session.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount to be charged for future payments.
-
#amount_includes_iof ⇒ Object
Determines if the amount includes the IOF tax.
-
#amount_type ⇒ Object
Type of amount.
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#end_date ⇒ Object
Date when the mandate expires and no further payments will be charged, in ‘YYYY-MM-DD`.
-
#payment_schedule ⇒ Object
Schedule at which the future payments will be charged.
-
#reference ⇒ Object
Subscription name displayed to buyers in their bank app.
-
#start_date ⇒ Object
Start date of the mandate, in ‘YYYY-MM-DD`.
Instance Method Summary collapse
-
#initialize(amount: nil, amount_includes_iof: nil, amount_type: nil, currency: nil, end_date: nil, payment_schedule: nil, reference: nil, start_date: nil) ⇒ MandateOptions
constructor
A new instance of MandateOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, amount_includes_iof: nil, amount_type: nil, currency: nil, end_date: nil, payment_schedule: nil, reference: nil, start_date: nil) ⇒ MandateOptions
Returns a new instance of MandateOptions.
3708 3709 3710 3711 3712 3713 3714 3715 3716 3717 3718 3719 3720 3721 3722 3723 3724 3725 3726 |
# File 'lib/stripe/resources/checkout/session.rb', line 3708 def initialize( amount: nil, amount_includes_iof: nil, amount_type: nil, currency: nil, end_date: nil, payment_schedule: nil, reference: nil, start_date: nil ) @amount = amount @amount_includes_iof = amount_includes_iof @amount_type = amount_type @currency = currency @end_date = end_date @payment_schedule = payment_schedule @reference = reference @start_date = start_date end |
Instance Attribute Details
#amount ⇒ Object
Amount to be charged for future payments. Required when ‘amount_type=fixed`. If not provided for `amount_type=maximum`, defaults to 40000.
3692 3693 3694 |
# File 'lib/stripe/resources/checkout/session.rb', line 3692 def amount @amount end |
#amount_includes_iof ⇒ Object
Determines if the amount includes the IOF tax. Defaults to ‘never`.
3694 3695 3696 |
# File 'lib/stripe/resources/checkout/session.rb', line 3694 def amount_includes_iof @amount_includes_iof end |
#amount_type ⇒ Object
Type of amount. Defaults to ‘maximum`.
3696 3697 3698 |
# File 'lib/stripe/resources/checkout/session.rb', line 3696 def amount_type @amount_type end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Only ‘brl` is supported currently.
3698 3699 3700 |
# File 'lib/stripe/resources/checkout/session.rb', line 3698 def currency @currency end |
#end_date ⇒ Object
Date when the mandate expires and no further payments will be charged, in ‘YYYY-MM-DD`. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.
3700 3701 3702 |
# File 'lib/stripe/resources/checkout/session.rb', line 3700 def end_date @end_date end |
#payment_schedule ⇒ Object
Schedule at which the future payments will be charged. Defaults to ‘weekly`.
3702 3703 3704 |
# File 'lib/stripe/resources/checkout/session.rb', line 3702 def payment_schedule @payment_schedule end |
#reference ⇒ Object
Subscription name displayed to buyers in their bank app. Defaults to the displayable business name.
3704 3705 3706 |
# File 'lib/stripe/resources/checkout/session.rb', line 3704 def reference @reference end |
#start_date ⇒ Object
Start date of the mandate, in ‘YYYY-MM-DD`. Start date should be at least 3 days in the future. Defaults to 3 days after the current date.
3706 3707 3708 |
# File 'lib/stripe/resources/checkout/session.rb', line 3706 def start_date @start_date end |