Class: Stripe::Checkout::Session::CreateParams::PaymentMethodOptions::SamsungPay
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::CreateParams::PaymentMethodOptions::SamsungPay
- Defined in:
- lib/stripe/resources/checkout/session.rb
Instance Attribute Summary collapse
-
#capture_method ⇒ Object
Controls when the funds will be captured from the customer’s account.
Instance Method Summary collapse
-
#initialize(capture_method: nil) ⇒ SamsungPay
constructor
A new instance of SamsungPay.
Methods inherited from RequestParams
Constructor Details
#initialize(capture_method: nil) ⇒ SamsungPay
Returns a new instance of SamsungPay.
2491 2492 2493 |
# File 'lib/stripe/resources/checkout/session.rb', line 2491 def initialize(capture_method: nil) @capture_method = capture_method end |
Instance Attribute Details
#capture_method ⇒ Object
Controls when the funds will be captured from the customer’s account.
2489 2490 2491 |
# File 'lib/stripe/resources/checkout/session.rb', line 2489 def capture_method @capture_method end |