Class: Stripe::Checkout::Session::CreateParams::PaymentMethodOptions::Swish
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::CreateParams::PaymentMethodOptions::Swish
- Defined in:
- lib/stripe/resources/checkout/session.rb
Instance Attribute Summary collapse
-
#reference ⇒ Object
The order reference that will be displayed to customers in the Swish application.
Instance Method Summary collapse
-
#initialize(reference: nil) ⇒ Swish
constructor
A new instance of Swish.
Methods inherited from RequestParams
Constructor Details
#initialize(reference: nil) ⇒ Swish
Returns a new instance of Swish.
2535 2536 2537 |
# File 'lib/stripe/resources/checkout/session.rb', line 2535 def initialize(reference: nil) @reference = reference end |
Instance Attribute Details
#reference ⇒ Object
The order reference that will be displayed to customers in the Swish application. Defaults to the ‘id` of the Payment Intent.
2533 2534 2535 |
# File 'lib/stripe/resources/checkout/session.rb', line 2533 def reference @reference end |