Class: Stripe::Checkout::Session::CreateParams::PaymentMethodOptions::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::CreateParams::PaymentMethodOptions::UsBankAccount
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: FinancialConnections
Instance Attribute Summary collapse
-
#financial_connections ⇒ Object
Additional fields for Financial Connections Session creation.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
-
#target_date ⇒ Object
Controls when Stripe will attempt to debit the funds from the customer’s account.
-
#verification_method ⇒ Object
Verification method for the intent.
Instance Method Summary collapse
-
#initialize(financial_connections: nil, setup_future_usage: nil, target_date: nil, verification_method: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(financial_connections: nil, setup_future_usage: nil, target_date: nil, verification_method: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
2576 2577 2578 2579 2580 2581 2582 2583 2584 2585 2586 |
# File 'lib/stripe/resources/checkout/session.rb', line 2576 def initialize( financial_connections: nil, setup_future_usage: nil, target_date: nil, verification_method: nil ) @financial_connections = financial_connections @setup_future_usage = setup_future_usage @target_date = target_date @verification_method = verification_method end |
Instance Attribute Details
#financial_connections ⇒ Object
Additional fields for Financial Connections Session creation
2562 2563 2564 |
# File 'lib/stripe/resources/checkout/session.rb', line 2562 def financial_connections @financial_connections end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.
If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.
When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).
2570 2571 2572 |
# File 'lib/stripe/resources/checkout/session.rb', line 2570 def setup_future_usage @setup_future_usage end |
#target_date ⇒ Object
Controls when Stripe will attempt to debit the funds from the customer’s account. The date must be a string in YYYY-MM-DD format. The date must be in the future and between 3 and 15 calendar days from now.
2572 2573 2574 |
# File 'lib/stripe/resources/checkout/session.rb', line 2572 def target_date @target_date end |
#verification_method ⇒ Object
Verification method for the intent
2574 2575 2576 |
# File 'lib/stripe/resources/checkout/session.rb', line 2574 def verification_method @verification_method end |