Class: Stripe::Checkout::Session::CreateParams::Permissions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Defined Under Namespace

Classes: Update

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(update: nil, update_discounts: nil, update_line_items: nil, update_shipping_details: nil) ⇒ Permissions

Returns a new instance of Permissions.



3183
3184
3185
3186
3187
3188
3189
3190
3191
3192
3193
# File 'lib/stripe/resources/checkout/session.rb', line 3183

def initialize(
  update: nil,
  update_discounts: nil,
  update_line_items: nil,
  update_shipping_details: nil
)
  @update = update
  @update_discounts = update_discounts
  @update_line_items = update_line_items
  @update_shipping_details = update_shipping_details
end

Instance Attribute Details

#updateObject

Permissions for updating the Checkout Session.



3165
3166
3167
# File 'lib/stripe/resources/checkout/session.rb', line 3165

def update
  @update
end

#update_discountsObject

Determines which entity is allowed to update the discounts (coupons or promotion codes) that apply to this session.

Default is ‘client_only`. Stripe Checkout client will automatically handle discount updates. If set to `server_only`, only your server is allowed to update discounts.



3169
3170
3171
# File 'lib/stripe/resources/checkout/session.rb', line 3169

def update_discounts
  @update_discounts
end

#update_line_itemsObject

Determines which entity is allowed to update the line items.

Default is ‘client_only`. Stripe Checkout client will automatically update the line items. If set to `server_only`, only your server is allowed to update the line items.

When set to ‘server_only`, you must add the onLineItemsChange event handler when initializing the Stripe Checkout client and manually update the line items from your server using the Stripe API.



3175
3176
3177
# File 'lib/stripe/resources/checkout/session.rb', line 3175

def update_line_items
  @update_line_items
end

#update_shipping_detailsObject

Determines which entity is allowed to update the shipping details.

Default is ‘client_only`. Stripe Checkout client will automatically update the shipping details. If set to `server_only`, only your server is allowed to update the shipping details.

When set to ‘server_only`, you must add the onShippingDetailsChange event handler when initializing the Stripe Checkout client and manually update the shipping details from your server using the Stripe API.



3181
3182
3183
# File 'lib/stripe/resources/checkout/session.rb', line 3181

def update_shipping_details
  @update_shipping_details
end