Class: Stripe::Checkout::Session::CreateParams::Permissions::Update
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::CreateParams::Permissions::Update
- Defined in:
- lib/stripe/resources/checkout/session.rb
Instance Attribute Summary collapse
-
#line_items ⇒ Object
Determines which entity is allowed to update the line items.
-
#shipping_details ⇒ Object
Determines which entity is allowed to update the shipping details.
Instance Method Summary collapse
-
#initialize(line_items: nil, shipping_details: nil) ⇒ Update
constructor
A new instance of Update.
Methods inherited from RequestParams
Constructor Details
#initialize(line_items: nil, shipping_details: nil) ⇒ Update
Returns a new instance of Update.
2912 2913 2914 2915 |
# File 'lib/stripe/resources/checkout/session.rb', line 2912 def initialize(line_items: nil, shipping_details: nil) @line_items = line_items @shipping_details = shipping_details end |
Instance Attribute Details
#line_items ⇒ Object
Determines which entity is allowed to update the line items.
Default is ‘client_only`. Stripe Checkout client will automatically update the line items. If set to `server_only`, only your server is allowed to update the line items.
When set to ‘server_only`, you must add the onLineItemsChange event handler when initializing the Stripe Checkout client and manually update the line items from your server using the Stripe API.
2904 2905 2906 |
# File 'lib/stripe/resources/checkout/session.rb', line 2904 def line_items @line_items end |
#shipping_details ⇒ Object
Determines which entity is allowed to update the shipping details.
Default is ‘client_only`. Stripe Checkout client will automatically update the shipping details. If set to `server_only`, only your server is allowed to update the shipping details.
When set to ‘server_only`, you must add the onShippingDetailsChange event handler when initializing the Stripe Checkout client and manually update the shipping details from your server using the Stripe API.
2910 2911 2912 |
# File 'lib/stripe/resources/checkout/session.rb', line 2910 def shipping_details @shipping_details end |