Class: Stripe::Checkout::Session::CreateParams::SetupIntentData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, metadata: nil, on_behalf_of: nil) ⇒ SetupIntentData

Returns a new instance of SetupIntentData.



3234
3235
3236
3237
3238
# File 'lib/stripe/resources/checkout/session.rb', line 3234

def initialize(description: nil, metadata: nil, on_behalf_of: nil)
  @description = description
  @metadata = 
  @on_behalf_of = on_behalf_of
end

Instance Attribute Details

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



3228
3229
3230
# File 'lib/stripe/resources/checkout/session.rb', line 3228

def description
  @description
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



3230
3231
3232
# File 'lib/stripe/resources/checkout/session.rb', line 3230

def 
  @metadata
end

#on_behalf_ofObject

The Stripe account for which the setup is intended.



3232
3233
3234
# File 'lib/stripe/resources/checkout/session.rb', line 3232

def on_behalf_of
  @on_behalf_of
end