Class: Stripe::Checkout::Session::CreateParams::ShippingAddressCollection
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::CreateParams::ShippingAddressCollection
- Defined in:
- lib/stripe/resources/checkout/session.rb
Instance Attribute Summary collapse
-
#allowed_countries ⇒ Object
An array of two-letter ISO country codes representing which countries Checkout should provide as options for shipping locations.
Instance Method Summary collapse
-
#initialize(allowed_countries: nil) ⇒ ShippingAddressCollection
constructor
A new instance of ShippingAddressCollection.
Methods inherited from RequestParams
Constructor Details
#initialize(allowed_countries: nil) ⇒ ShippingAddressCollection
Returns a new instance of ShippingAddressCollection.
2827 2828 2829 |
# File 'lib/stripe/resources/checkout/session.rb', line 2827 def initialize(allowed_countries: nil) @allowed_countries = allowed_countries end |
Instance Attribute Details
#allowed_countries ⇒ Object
An array of two-letter ISO country codes representing which countries Checkout should provide as options for shipping locations.
2825 2826 2827 |
# File 'lib/stripe/resources/checkout/session.rb', line 2825 def allowed_countries @allowed_countries end |