Class: Stripe::Checkout::Session::CreateParams::ShippingOption

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Defined Under Namespace

Classes: ShippingRateData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(shipping_rate: nil, shipping_rate_data: nil) ⇒ ShippingOption

Returns a new instance of ShippingOption.



3351
3352
3353
3354
# File 'lib/stripe/resources/checkout/session.rb', line 3351

def initialize(shipping_rate: nil, shipping_rate_data: nil)
  @shipping_rate = shipping_rate
  @shipping_rate_data = shipping_rate_data
end

Instance Attribute Details

#shipping_rateObject

The ID of the Shipping Rate to use for this shipping option.



3347
3348
3349
# File 'lib/stripe/resources/checkout/session.rb', line 3347

def shipping_rate
  @shipping_rate
end

#shipping_rate_dataObject

Parameters to be passed to Shipping Rate creation for this shipping option.



3349
3350
3351
# File 'lib/stripe/resources/checkout/session.rb', line 3349

def shipping_rate_data
  @shipping_rate_data
end