Class: Stripe::Checkout::Session::CreateParams::SubscriptionData::TrialSettings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::CreateParams::SubscriptionData::TrialSettings
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: EndBehavior
Instance Attribute Summary collapse
-
#end_behavior ⇒ Object
Defines how the subscription should behave when the user’s free trial ends.
Instance Method Summary collapse
-
#initialize(end_behavior: nil) ⇒ TrialSettings
constructor
A new instance of TrialSettings.
Methods inherited from RequestParams
Constructor Details
#initialize(end_behavior: nil) ⇒ TrialSettings
Returns a new instance of TrialSettings.
3003 3004 3005 |
# File 'lib/stripe/resources/checkout/session.rb', line 3003 def initialize(end_behavior: nil) @end_behavior = end_behavior end |
Instance Attribute Details
#end_behavior ⇒ Object
Defines how the subscription should behave when the user’s free trial ends.
3001 3002 3003 |
# File 'lib/stripe/resources/checkout/session.rb', line 3001 def end_behavior @end_behavior end |