Class: Stripe::Checkout::Session::CreateParams::WalletOptions::Link

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(display: nil) ⇒ Link

Returns a new instance of Link.



3001
3002
3003
# File 'lib/stripe/resources/checkout/session.rb', line 3001

def initialize(display: nil)
  @display = display
end

Instance Attribute Details

#displayObject

Specifies whether Checkout should display Link as a payment option. By default, Checkout will display all the supported wallets that the Checkout Session was created with. This is the ‘auto` behavior, and it is the default choice.



2999
3000
3001
# File 'lib/stripe/resources/checkout/session.rb', line 2999

def display
  @display
end