Class: Stripe::Checkout::Session::CurrencyConversion

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amount_subtotalObject (readonly)

Total of all items in source currency before discounts or taxes are applied.



292
293
294
# File 'lib/stripe/resources/checkout/session.rb', line 292

def amount_subtotal
  @amount_subtotal
end

#amount_totalObject (readonly)

Total of all items in source currency after discounts and taxes are applied.



294
295
296
# File 'lib/stripe/resources/checkout/session.rb', line 294

def amount_total
  @amount_total
end

#fx_rateObject (readonly)

Exchange rate used to convert source currency amounts to customer currency amounts



296
297
298
# File 'lib/stripe/resources/checkout/session.rb', line 296

def fx_rate
  @fx_rate
end

#source_currencyObject (readonly)

Creation currency of the CheckoutSession before localization



298
299
300
# File 'lib/stripe/resources/checkout/session.rb', line 298

def source_currency
  @source_currency
end

Class Method Details

.field_encodingsObject



308
309
310
# File 'lib/stripe/resources/checkout/session.rb', line 308

def self.field_encodings
  @field_encodings = { fx_rate: :decimal_string }
end

.field_remappingsObject



304
305
306
# File 'lib/stripe/resources/checkout/session.rb', line 304

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



300
301
302
# File 'lib/stripe/resources/checkout/session.rb', line 300

def self.inner_class_types
  @inner_class_types = {}
end