Class: Stripe::Checkout::Session::CurrentAttempt::PaymentMethodDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Checkout::Session::CurrentAttempt::PaymentMethodDetails
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: AuBecsDebit, BacsDebit, Boleto, Card, Link, Pix, SepaDebit, UsBankAccount
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#allow_redisplay ⇒ Object
readonly
Indicates whether this payment method can be shown again to its customer in a checkout flow.
-
#au_becs_debit ⇒ Object
readonly
Attribute for field au_becs_debit.
-
#bacs_debit ⇒ Object
readonly
Attribute for field bacs_debit.
-
#boleto ⇒ Object
readonly
Attribute for field boleto.
-
#card ⇒ Object
readonly
Attribute for field card.
-
#link ⇒ Object
readonly
Attribute for field link.
-
#pix ⇒ Object
readonly
Attribute for field pix.
-
#sepa_debit ⇒ Object
readonly
Attribute for field sepa_debit.
-
#type ⇒ Object
readonly
The type of payment method the customer is attempting to pay with.
-
#us_bank_account ⇒ Object
readonly
Attribute for field us_bank_account.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#allow_redisplay ⇒ Object (readonly)
Indicates whether this payment method can be shown again to its customer in a checkout flow.
509 510 511 |
# File 'lib/stripe/resources/checkout/session.rb', line 509 def allow_redisplay @allow_redisplay end |
#au_becs_debit ⇒ Object (readonly)
Attribute for field au_becs_debit
511 512 513 |
# File 'lib/stripe/resources/checkout/session.rb', line 511 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object (readonly)
Attribute for field bacs_debit
513 514 515 |
# File 'lib/stripe/resources/checkout/session.rb', line 513 def bacs_debit @bacs_debit end |
#boleto ⇒ Object (readonly)
Attribute for field boleto
515 516 517 |
# File 'lib/stripe/resources/checkout/session.rb', line 515 def boleto @boleto end |
#card ⇒ Object (readonly)
Attribute for field card
517 518 519 |
# File 'lib/stripe/resources/checkout/session.rb', line 517 def card @card end |
#link ⇒ Object (readonly)
Attribute for field link
519 520 521 |
# File 'lib/stripe/resources/checkout/session.rb', line 519 def link @link end |
#pix ⇒ Object (readonly)
Attribute for field pix
521 522 523 |
# File 'lib/stripe/resources/checkout/session.rb', line 521 def pix @pix end |
#sepa_debit ⇒ Object (readonly)
Attribute for field sepa_debit
523 524 525 |
# File 'lib/stripe/resources/checkout/session.rb', line 523 def sepa_debit @sepa_debit end |
#type ⇒ Object (readonly)
The type of payment method the customer is attempting to pay with. An additional hash is included in the payment method details with a name matching this value. It contains additional information specific to the payment method type.
525 526 527 |
# File 'lib/stripe/resources/checkout/session.rb', line 525 def type @type end |
#us_bank_account ⇒ Object (readonly)
Attribute for field us_bank_account
527 528 529 |
# File 'lib/stripe/resources/checkout/session.rb', line 527 def us_bank_account @us_bank_account end |
Class Method Details
.field_remappings ⇒ Object
542 543 544 |
# File 'lib/stripe/resources/checkout/session.rb', line 542 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
529 530 531 532 533 534 535 536 537 538 539 540 |
# File 'lib/stripe/resources/checkout/session.rb', line 529 def self.inner_class_types @inner_class_types = { au_becs_debit: AuBecsDebit, bacs_debit: BacsDebit, boleto: Boleto, card: Card, link: Link, pix: Pix, sepa_debit: SepaDebit, us_bank_account: UsBankAccount, } end |