Class: Stripe::Checkout::Session::CurrentAttempt::PaymentMethodDetails::Card
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Checkout::Session::CurrentAttempt::PaymentMethodDetails::Card
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: Wallet
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#brand ⇒ Object
readonly
The brand of the card, accounting for customer's brand choice on dual-branded cards.
-
#country ⇒ Object
readonly
Two-letter ISO code representing the country of the card.
-
#exp_month ⇒ Object
readonly
Two-digit number representing the card's expiration month.
-
#exp_year ⇒ Object
readonly
Four-digit number representing the card's expiration year.
-
#fingerprint ⇒ Object
readonly
Uniquely identifies this particular card number.
-
#funding ⇒ Object
readonly
Card funding type.
-
#iin ⇒ Object
readonly
Issuer identification number of the card.
-
#last4 ⇒ Object
readonly
The last four digits of the card.
-
#wallet ⇒ Object
readonly
If this Card is part of a card wallet, this contains the details of the card wallet.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#brand ⇒ Object (readonly)
The brand of the card, accounting for customer's brand choice on dual-branded cards.
428 429 430 |
# File 'lib/stripe/resources/checkout/session.rb', line 428 def brand @brand end |
#country ⇒ Object (readonly)
Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you've collected.
430 431 432 |
# File 'lib/stripe/resources/checkout/session.rb', line 430 def country @country end |
#exp_month ⇒ Object (readonly)
Two-digit number representing the card's expiration month.
432 433 434 |
# File 'lib/stripe/resources/checkout/session.rb', line 432 def exp_month @exp_month end |
#exp_year ⇒ Object (readonly)
Four-digit number representing the card's expiration year.
434 435 436 |
# File 'lib/stripe/resources/checkout/session.rb', line 434 def exp_year @exp_year end |
#fingerprint ⇒ Object (readonly)
Uniquely identifies this particular card number. You can use this attribute to check whether two customers who’ve signed up with you are using the same card number, for example. For payment methods that tokenize card information (Apple Pay, Google Pay), the tokenized number might be provided instead of the underlying card number.
As of May 1, 2021, card fingerprint in India for Connect changed to allow two fingerprints for the same card---one for India and one for the rest of the world.
438 439 440 |
# File 'lib/stripe/resources/checkout/session.rb', line 438 def fingerprint @fingerprint end |
#funding ⇒ Object (readonly)
Card funding type. Can be credit, debit, prepaid, or unknown.
440 441 442 |
# File 'lib/stripe/resources/checkout/session.rb', line 440 def funding @funding end |
#iin ⇒ Object (readonly)
Issuer identification number of the card. (For internal use only and not typically available in standard API requests.)
442 443 444 |
# File 'lib/stripe/resources/checkout/session.rb', line 442 def iin @iin end |
#last4 ⇒ Object (readonly)
The last four digits of the card.
444 445 446 |
# File 'lib/stripe/resources/checkout/session.rb', line 444 def last4 @last4 end |
#wallet ⇒ Object (readonly)
If this Card is part of a card wallet, this contains the details of the card wallet.
446 447 448 |
# File 'lib/stripe/resources/checkout/session.rb', line 446 def wallet @wallet end |
Class Method Details
.field_remappings ⇒ Object
452 453 454 |
# File 'lib/stripe/resources/checkout/session.rb', line 452 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
448 449 450 |
# File 'lib/stripe/resources/checkout/session.rb', line 448 def self.inner_class_types @inner_class_types = { wallet: Wallet } end |