Class: Stripe::Checkout::Session::CustomField::Dropdown::Option

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#labelObject (readonly)

The label for the option, displayed to the customer. Up to 100 characters.



613
614
615
# File 'lib/stripe/resources/checkout/session.rb', line 613

def label
  @label
end

#valueObject (readonly)

The value for this option, not displayed to the customer, used by your integration to reconcile the option selected by the customer. Must be unique to this option, alphanumeric, and up to 100 characters.



615
616
617
# File 'lib/stripe/resources/checkout/session.rb', line 615

def value
  @value
end

Class Method Details

.field_remappingsObject



621
622
623
# File 'lib/stripe/resources/checkout/session.rb', line 621

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



617
618
619
# File 'lib/stripe/resources/checkout/session.rb', line 617

def self.inner_class_types
  @inner_class_types = {}
end