Class: Stripe::Checkout::Session::CustomerDetails

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Defined Under Namespace

Classes: Address, TaxId

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#addressObject (readonly)

The customer's address after a completed Checkout Session. Note: This property is populated only for sessions on or after March 30, 2022.



831
832
833
# File 'lib/stripe/resources/checkout/session.rb', line 831

def address
  @address
end

#business_nameObject (readonly)

The customer's business name after a completed Checkout Session.



833
834
835
# File 'lib/stripe/resources/checkout/session.rb', line 833

def business_name
  @business_name
end

#emailObject (readonly)

The email associated with the Customer, if one exists, on the Checkout Session after a completed Checkout Session or at time of session expiry. Otherwise, if the customer has consented to promotional content, this value is the most recent valid email provided by the customer on the Checkout form.



836
837
838
# File 'lib/stripe/resources/checkout/session.rb', line 836

def email
  @email
end

#individual_nameObject (readonly)

The customer's individual name after a completed Checkout Session.



838
839
840
# File 'lib/stripe/resources/checkout/session.rb', line 838

def individual_name
  @individual_name
end

#nameObject (readonly)

The customer's name after a completed Checkout Session. Note: This property is populated only for sessions on or after March 30, 2022.



840
841
842
# File 'lib/stripe/resources/checkout/session.rb', line 840

def name
  @name
end

#phoneObject (readonly)

The customer's phone number after a completed Checkout Session.



842
843
844
# File 'lib/stripe/resources/checkout/session.rb', line 842

def phone
  @phone
end

#tax_exemptObject (readonly)

The customer’s tax exempt status after a completed Checkout Session.



844
845
846
# File 'lib/stripe/resources/checkout/session.rb', line 844

def tax_exempt
  @tax_exempt
end

#tax_idsObject (readonly)

The customer’s tax IDs after a completed Checkout Session.



846
847
848
# File 'lib/stripe/resources/checkout/session.rb', line 846

def tax_ids
  @tax_ids
end

Class Method Details

.field_remappingsObject



852
853
854
# File 'lib/stripe/resources/checkout/session.rb', line 852

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



848
849
850
# File 'lib/stripe/resources/checkout/session.rb', line 848

def self.inner_class_types
  @inner_class_types = { address: Address, tax_ids: TaxId }
end