Class: Stripe::Checkout::Session::ExpireParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::ExpireParams
- Defined in:
- lib/stripe/resources/checkout/session.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ ExpireParams
constructor
A new instance of ExpireParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ ExpireParams
Returns a new instance of ExpireParams.
3927 3928 3929 |
# File 'lib/stripe/resources/checkout/session.rb', line 3927 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
3925 3926 3927 |
# File 'lib/stripe/resources/checkout/session.rb', line 3925 def @expand end |