Class: Stripe::Checkout::Session::InvoiceCreation::InvoiceData
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Checkout::Session::InvoiceCreation::InvoiceData
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: CustomField, Issuer, RenderingOptions
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_tax_ids ⇒ Object
readonly
The account tax IDs associated with the invoice.
-
#custom_fields ⇒ Object
readonly
Custom fields displayed on the invoice.
-
#description ⇒ Object
readonly
An arbitrary string attached to the object.
-
#footer ⇒ Object
readonly
Footer displayed on the invoice.
-
#issuer ⇒ Object
readonly
The connected account that issues the invoice.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#rendering_options ⇒ Object
readonly
Options for invoice PDF rendering.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_tax_ids ⇒ Object (readonly)
The account tax IDs associated with the invoice.
302 303 304 |
# File 'lib/stripe/resources/checkout/session.rb', line 302 def account_tax_ids @account_tax_ids end |
#custom_fields ⇒ Object (readonly)
Custom fields displayed on the invoice.
304 305 306 |
# File 'lib/stripe/resources/checkout/session.rb', line 304 def custom_fields @custom_fields end |
#description ⇒ Object (readonly)
An arbitrary string attached to the object. Often useful for displaying to users.
306 307 308 |
# File 'lib/stripe/resources/checkout/session.rb', line 306 def description @description end |
#footer ⇒ Object (readonly)
Footer displayed on the invoice.
308 309 310 |
# File 'lib/stripe/resources/checkout/session.rb', line 308 def @footer end |
#issuer ⇒ Object (readonly)
The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.
310 311 312 |
# File 'lib/stripe/resources/checkout/session.rb', line 310 def issuer @issuer end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
312 313 314 |
# File 'lib/stripe/resources/checkout/session.rb', line 312 def @metadata end |
#rendering_options ⇒ Object (readonly)
Options for invoice PDF rendering.
314 315 316 |
# File 'lib/stripe/resources/checkout/session.rb', line 314 def @rendering_options end |