Class: Stripe::Checkout::Session::InvoiceCreation::InvoiceData::RenderingOptions

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amount_tax_displayObject (readonly)

How line-item prices and amounts will be displayed with respect to tax on invoice PDFs.



610
611
612
# File 'lib/stripe/resources/checkout/session.rb', line 610

def amount_tax_display
  @amount_tax_display
end

#templateObject (readonly)

ID of the invoice rendering template to be used for the generated invoice.



612
613
614
# File 'lib/stripe/resources/checkout/session.rb', line 612

def template
  @template
end

Class Method Details

.field_remappingsObject



618
619
620
# File 'lib/stripe/resources/checkout/session.rb', line 618

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



614
615
616
# File 'lib/stripe/resources/checkout/session.rb', line 614

def self.inner_class_types
  @inner_class_types = {}
end