Class: Stripe::Checkout::Session::Item::Subscription
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Checkout::Session::Item::Subscription
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: Item, PendingInvoiceItemInterval, TrialSettings
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#description ⇒ Object
readonly
The description for the subscription.
-
#items ⇒ Object
readonly
The items in the subscription.
-
#metadata ⇒ Object
readonly
Set of key-value pairs attached to the subscription.
-
#pending_invoice_item_interval ⇒ Object
readonly
Specifies an interval for how often to bill for any pending invoice items.
-
#proration_behavior ⇒ Object
readonly
Determines how to handle prorations when the subscription is updated.
-
#subscription ⇒ Object
readonly
The ID of the Subscription.
-
#trial_end ⇒ Object
readonly
The Unix timestamp marking when the trial period ends.
-
#trial_period_days ⇒ Object
readonly
The number of trial period days before the customer is charged for the first time.
-
#trial_settings ⇒ Object
readonly
Settings related to subscription trials.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#description ⇒ Object (readonly)
The description for the subscription.
1016 1017 1018 |
# File 'lib/stripe/resources/checkout/session.rb', line 1016 def description @description end |
#items ⇒ Object (readonly)
The items in the subscription.
1018 1019 1020 |
# File 'lib/stripe/resources/checkout/session.rb', line 1018 def items @items end |
#metadata ⇒ Object (readonly)
Set of key-value pairs attached to the subscription.
1020 1021 1022 |
# File 'lib/stripe/resources/checkout/session.rb', line 1020 def @metadata end |
#pending_invoice_item_interval ⇒ Object (readonly)
Specifies an interval for how often to bill for any pending invoice items.
1022 1023 1024 |
# File 'lib/stripe/resources/checkout/session.rb', line 1022 def pending_invoice_item_interval @pending_invoice_item_interval end |
#proration_behavior ⇒ Object (readonly)
Determines how to handle prorations when the subscription is updated.
1024 1025 1026 |
# File 'lib/stripe/resources/checkout/session.rb', line 1024 def proration_behavior @proration_behavior end |
#subscription ⇒ Object (readonly)
The ID of the Subscription.
1026 1027 1028 |
# File 'lib/stripe/resources/checkout/session.rb', line 1026 def subscription @subscription end |
#trial_end ⇒ Object (readonly)
The Unix timestamp marking when the trial period ends.
1028 1029 1030 |
# File 'lib/stripe/resources/checkout/session.rb', line 1028 def trial_end @trial_end end |
#trial_period_days ⇒ Object (readonly)
The number of trial period days before the customer is charged for the first time.
1030 1031 1032 |
# File 'lib/stripe/resources/checkout/session.rb', line 1030 def trial_period_days @trial_period_days end |
#trial_settings ⇒ Object (readonly)
Settings related to subscription trials.
1032 1033 1034 |
# File 'lib/stripe/resources/checkout/session.rb', line 1032 def trial_settings @trial_settings end |
Class Method Details
.field_remappings ⇒ Object
1042 1043 1044 |
# File 'lib/stripe/resources/checkout/session.rb', line 1042 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1034 1035 1036 1037 1038 1039 1040 |
# File 'lib/stripe/resources/checkout/session.rb', line 1034 def self.inner_class_types @inner_class_types = { items: Item, pending_invoice_item_interval: PendingInvoiceItemInterval, trial_settings: TrialSettings, } end |