Class: Stripe::Checkout::Session::ListLineItemsParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListLineItemsParams

Returns a new instance of ListLineItemsParams.



5059
5060
5061
5062
5063
5064
# File 'lib/stripe/resources/checkout/session.rb', line 5059

def initialize(ending_before: nil, expand: nil, limit: nil, starting_after: nil)
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
end

Instance Attribute Details

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



5051
5052
5053
# File 'lib/stripe/resources/checkout/session.rb', line 5051

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



5053
5054
5055
# File 'lib/stripe/resources/checkout/session.rb', line 5053

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



5055
5056
5057
# File 'lib/stripe/resources/checkout/session.rb', line 5055

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



5057
5058
5059
# File 'lib/stripe/resources/checkout/session.rb', line 5057

def starting_after
  @starting_after
end