Class: Stripe::Checkout::Session::PaymentMethodOptions::Card

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Defined Under Namespace

Classes: Installments, Restrictions

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#capture_methodObject (readonly)

Controls when the funds will be captured from the customer's account.



1470
1471
1472
# File 'lib/stripe/resources/checkout/session.rb', line 1470

def capture_method
  @capture_method
end

#installmentsObject (readonly)

Attribute for field installments



1472
1473
1474
# File 'lib/stripe/resources/checkout/session.rb', line 1472

def installments
  @installments
end

#request_decremental_authorizationObject (readonly)

Request ability to capture beyond the standard authorization validity window for this CheckoutSession.



1474
1475
1476
# File 'lib/stripe/resources/checkout/session.rb', line 1474

def request_decremental_authorization
  @request_decremental_authorization
end

#request_extended_authorizationObject (readonly)

Request ability to capture beyond the standard authorization validity window for this CheckoutSession.



1476
1477
1478
# File 'lib/stripe/resources/checkout/session.rb', line 1476

def request_extended_authorization
  @request_extended_authorization
end

#request_incremental_authorizationObject (readonly)

Request ability to increment the authorization for this CheckoutSession.



1478
1479
1480
# File 'lib/stripe/resources/checkout/session.rb', line 1478

def request_incremental_authorization
  @request_incremental_authorization
end

#request_multicaptureObject (readonly)

Request ability to make multiple captures for this CheckoutSession.



1480
1481
1482
# File 'lib/stripe/resources/checkout/session.rb', line 1480

def request_multicapture
  @request_multicapture
end

#request_overcaptureObject (readonly)

Request ability to overcapture for this CheckoutSession.



1482
1483
1484
# File 'lib/stripe/resources/checkout/session.rb', line 1482

def request_overcapture
  @request_overcapture
end

#request_three_d_secureObject (readonly)

We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and other requirements. However, if you wish to request 3D Secure based on logic from your own fraud engine, provide this option. If not provided, this value defaults to automatic. Read our guide on manually requesting 3D Secure for more information on how this configuration interacts with Radar and our SCA Engine.



1484
1485
1486
# File 'lib/stripe/resources/checkout/session.rb', line 1484

def request_three_d_secure
  @request_three_d_secure
end

#restrictionsObject (readonly)

Attribute for field restrictions



1486
1487
1488
# File 'lib/stripe/resources/checkout/session.rb', line 1486

def restrictions
  @restrictions
end

#setup_future_usageObject (readonly)

Indicates that you intend to make future payments with this PaymentIntent's payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.

If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.

When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.



1494
1495
1496
# File 'lib/stripe/resources/checkout/session.rb', line 1494

def setup_future_usage
  @setup_future_usage
end

#statement_descriptor_suffix_kanaObject (readonly)

Provides information about a card payment that customers see on their statements. Concatenated with the Kana prefix (shortened Kana descriptor) or Kana statement descriptor that’s set on the account to form the complete statement descriptor. Maximum 22 characters. On card statements, the concatenation of both prefix and suffix (including separators) will appear truncated to 22 characters.



1496
1497
1498
# File 'lib/stripe/resources/checkout/session.rb', line 1496

def statement_descriptor_suffix_kana
  @statement_descriptor_suffix_kana
end

#statement_descriptor_suffix_kanjiObject (readonly)

Provides information about a card payment that customers see on their statements. Concatenated with the Kanji prefix (shortened Kanji descriptor) or Kanji statement descriptor that’s set on the account to form the complete statement descriptor. Maximum 17 characters. On card statements, the concatenation of both prefix and suffix (including separators) will appear truncated to 17 characters.



1498
1499
1500
# File 'lib/stripe/resources/checkout/session.rb', line 1498

def statement_descriptor_suffix_kanji
  @statement_descriptor_suffix_kanji
end

Class Method Details

.field_remappingsObject



1504
1505
1506
# File 'lib/stripe/resources/checkout/session.rb', line 1504

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1500
1501
1502
# File 'lib/stripe/resources/checkout/session.rb', line 1500

def self.inner_class_types
  @inner_class_types = { installments: Installments, restrictions: Restrictions }
end