Class: Stripe::Checkout::Session::PaymentMethodOptions::CustomerBalance::BankTransfer
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Checkout::Session::PaymentMethodOptions::CustomerBalance::BankTransfer
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: EuBankTransfer
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#eu_bank_transfer ⇒ Object
readonly
Attribute for field eu_bank_transfer.
-
#requested_address_types ⇒ Object
readonly
List of address types that should be returned in the financial_addresses response.
-
#type ⇒ Object
readonly
The bank transfer type that this PaymentIntent is allowed to use for funding Permitted values include: ‘eu_bank_transfer`, `gb_bank_transfer`, `jp_bank_transfer`, `mx_bank_transfer`, or `us_bank_transfer`.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#eu_bank_transfer ⇒ Object (readonly)
Attribute for field eu_bank_transfer
1122 1123 1124 |
# File 'lib/stripe/resources/checkout/session.rb', line 1122 def eu_bank_transfer @eu_bank_transfer end |
#requested_address_types ⇒ Object (readonly)
List of address types that should be returned in the financial_addresses response. If not specified, all valid types will be returned.
Permitted values include: ‘sort_code`, `zengin`, `iban`, or `spei`.
1126 1127 1128 |
# File 'lib/stripe/resources/checkout/session.rb', line 1126 def requested_address_types @requested_address_types end |
#type ⇒ Object (readonly)
The bank transfer type that this PaymentIntent is allowed to use for funding Permitted values include: ‘eu_bank_transfer`, `gb_bank_transfer`, `jp_bank_transfer`, `mx_bank_transfer`, or `us_bank_transfer`.
1128 1129 1130 |
# File 'lib/stripe/resources/checkout/session.rb', line 1128 def type @type end |
Class Method Details
.field_remappings ⇒ Object
1134 1135 1136 |
# File 'lib/stripe/resources/checkout/session.rb', line 1134 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1130 1131 1132 |
# File 'lib/stripe/resources/checkout/session.rb', line 1130 def self.inner_class_types @inner_class_types = { eu_bank_transfer: EuBankTransfer } end |