Class: Stripe::Checkout::Session::PaymentMethodOptions::Payto
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Checkout::Session::PaymentMethodOptions::Payto
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: MandateOptions
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#mandate_options ⇒ Object
readonly
Attribute for field mandate_options.
-
#setup_future_usage ⇒ Object
readonly
Indicates that you intend to make future payments with this PaymentIntent's payment method.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#mandate_options ⇒ Object (readonly)
Attribute for field mandate_options
1531 1532 1533 |
# File 'lib/stripe/resources/checkout/session.rb', line 1531 def end |
#setup_future_usage ⇒ Object (readonly)
Indicates that you intend to make future payments with this PaymentIntent's payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.
If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.
When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.
1539 1540 1541 |
# File 'lib/stripe/resources/checkout/session.rb', line 1539 def setup_future_usage @setup_future_usage end |
Class Method Details
.field_remappings ⇒ Object
1545 1546 1547 |
# File 'lib/stripe/resources/checkout/session.rb', line 1545 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1541 1542 1543 |
# File 'lib/stripe/resources/checkout/session.rb', line 1541 def self.inner_class_types @inner_class_types = { mandate_options: MandateOptions } end |