Class: Stripe::Checkout::Session::PaymentMethodOptions::Upi

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Defined Under Namespace

Classes: MandateOptions

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#mandate_optionsObject (readonly)

Attribute for field mandate_options



1821
1822
1823
# File 'lib/stripe/resources/checkout/session.rb', line 1821

def mandate_options
  @mandate_options
end

#setup_future_usageObject (readonly)

Indicates that you intend to make future payments with this PaymentIntent's payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.

If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.

When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.



1829
1830
1831
# File 'lib/stripe/resources/checkout/session.rb', line 1829

def setup_future_usage
  @setup_future_usage
end

Class Method Details

.field_remappingsObject



1835
1836
1837
# File 'lib/stripe/resources/checkout/session.rb', line 1835

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1831
1832
1833
# File 'lib/stripe/resources/checkout/session.rb', line 1831

def self.inner_class_types
  @inner_class_types = { mandate_options: MandateOptions }
end