Class: Stripe::Checkout::Session::PaymentMethodOptions::Upi::MandateOptions

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Amount to be charged for future payments.



1804
1805
1806
# File 'lib/stripe/resources/checkout/session.rb', line 1804

def amount
  @amount
end

#amount_typeObject (readonly)

One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.



1806
1807
1808
# File 'lib/stripe/resources/checkout/session.rb', line 1806

def amount_type
  @amount_type
end

#descriptionObject (readonly)

A description of the mandate or subscription that is meant to be displayed to the customer.



1808
1809
1810
# File 'lib/stripe/resources/checkout/session.rb', line 1808

def description
  @description
end

#end_dateObject (readonly)

End date of the mandate or subscription.



1810
1811
1812
# File 'lib/stripe/resources/checkout/session.rb', line 1810

def end_date
  @end_date
end

Class Method Details

.field_remappingsObject



1816
1817
1818
# File 'lib/stripe/resources/checkout/session.rb', line 1816

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1812
1813
1814
# File 'lib/stripe/resources/checkout/session.rb', line 1812

def self.inner_class_types
  @inner_class_types = {}
end