Class: Stripe::Checkout::Session::Permissions

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Defined Under Namespace

Classes: Update

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#updateObject (readonly)

Permissions for updating the Checkout Session.



2107
2108
2109
# File 'lib/stripe/resources/checkout/session.rb', line 2107

def update
  @update
end

#update_line_itemsObject (readonly)

Determines which entity is allowed to update the line items.

Default is client_only. Stripe Checkout client will automatically update the line items. If set to server_only, only your server is allowed to update the line items.

When set to server_only, you must add the onLineItemsChange event handler when initializing the Stripe Checkout client and manually update the line items from your server using the Stripe API.



2113
2114
2115
# File 'lib/stripe/resources/checkout/session.rb', line 2113

def update_line_items
  @update_line_items
end

#update_shipping_detailsObject (readonly)

Determines which entity is allowed to update the shipping details.

Default is client_only. Stripe Checkout client will automatically update the shipping details. If set to server_only, only your server is allowed to update the shipping details.

This parameter is only supported when ui_mode=elements.



2119
2120
2121
# File 'lib/stripe/resources/checkout/session.rb', line 2119

def update_shipping_details
  @update_shipping_details
end

Class Method Details

.field_remappingsObject



2125
2126
2127
# File 'lib/stripe/resources/checkout/session.rb', line 2125

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2121
2122
2123
# File 'lib/stripe/resources/checkout/session.rb', line 2121

def self.inner_class_types
  @inner_class_types = { update: Update }
end