Class: Stripe::Checkout::Session::Permissions::Update

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#line_itemsObject (readonly)

Determines which entity is allowed to update the line items.

Default is client_only. Stripe Checkout client will automatically update the line items. If set to server_only, only your server is allowed to update the line items.

When set to server_only, you must add the onLineItemsChange event handler when initializing the Stripe Checkout client and manually update the line items from your server using the Stripe API.



2530
2531
2532
# File 'lib/stripe/resources/checkout/session.rb', line 2530

def line_items
  @line_items
end

#shipping_detailsObject (readonly)

Determines which entity is allowed to update the shipping details.

Default is client_only. Stripe Checkout client will automatically update the shipping details. If set to server_only, only your server is allowed to update the shipping details.

When set to server_only, you must add the onShippingDetailsChange event handler when initializing the Stripe Checkout client and manually update the shipping details from your server using the Stripe API.



2536
2537
2538
# File 'lib/stripe/resources/checkout/session.rb', line 2536

def shipping_details
  @shipping_details
end

Class Method Details

.field_remappingsObject



2542
2543
2544
# File 'lib/stripe/resources/checkout/session.rb', line 2542

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2538
2539
2540
# File 'lib/stripe/resources/checkout/session.rb', line 2538

def self.inner_class_types
  @inner_class_types = {}
end