Class: Stripe::Checkout::Session::RetrieveParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::RetrieveParams
- Defined in:
- lib/stripe/resources/checkout/session.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ RetrieveParams
constructor
A new instance of RetrieveParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ RetrieveParams
Returns a new instance of RetrieveParams.
3313 3314 3315 |
# File 'lib/stripe/resources/checkout/session.rb', line 3313 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
3311 3312 3313 |
# File 'lib/stripe/resources/checkout/session.rb', line 3311 def @expand end |