Class: Stripe::Checkout::Session::ShippingCost
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Checkout::Session::ShippingCost
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: Tax
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount_subtotal ⇒ Object
readonly
Total shipping cost before any discounts or taxes are applied.
-
#amount_tax ⇒ Object
readonly
Total tax amount applied due to shipping costs.
-
#amount_total ⇒ Object
readonly
Total shipping cost after discounts and taxes are applied.
-
#shipping_rate ⇒ Object
readonly
The ID of the ShippingRate for this order.
-
#taxes ⇒ Object
readonly
The taxes applied to the shipping rate.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount_subtotal ⇒ Object (readonly)
Total shipping cost before any discounts or taxes are applied.
2206 2207 2208 |
# File 'lib/stripe/resources/checkout/session.rb', line 2206 def amount_subtotal @amount_subtotal end |
#amount_tax ⇒ Object (readonly)
Total tax amount applied due to shipping costs. If no tax was applied, defaults to 0.
2208 2209 2210 |
# File 'lib/stripe/resources/checkout/session.rb', line 2208 def amount_tax @amount_tax end |
#amount_total ⇒ Object (readonly)
Total shipping cost after discounts and taxes are applied.
2210 2211 2212 |
# File 'lib/stripe/resources/checkout/session.rb', line 2210 def amount_total @amount_total end |
#shipping_rate ⇒ Object (readonly)
The ID of the ShippingRate for this order.
2212 2213 2214 |
# File 'lib/stripe/resources/checkout/session.rb', line 2212 def shipping_rate @shipping_rate end |
#taxes ⇒ Object (readonly)
The taxes applied to the shipping rate.
2214 2215 2216 |
# File 'lib/stripe/resources/checkout/session.rb', line 2214 def taxes @taxes end |
Class Method Details
.field_remappings ⇒ Object
2220 2221 2222 |
# File 'lib/stripe/resources/checkout/session.rb', line 2220 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2216 2217 2218 |
# File 'lib/stripe/resources/checkout/session.rb', line 2216 def self.inner_class_types @inner_class_types = { taxes: Tax } end |