Class: Stripe::Checkout::Session::TotalDetails

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Defined Under Namespace

Classes: Breakdown

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amount_discountObject (readonly)

This is the sum of all the discounts.



2566
2567
2568
# File 'lib/stripe/resources/checkout/session.rb', line 2566

def amount_discount
  @amount_discount
end

#amount_shippingObject (readonly)

This is the sum of all the shipping amounts.



2568
2569
2570
# File 'lib/stripe/resources/checkout/session.rb', line 2568

def amount_shipping
  @amount_shipping
end

#amount_surchargeObject (readonly)

The surcharge amount that was applied to the Checkout Session.



2570
2571
2572
# File 'lib/stripe/resources/checkout/session.rb', line 2570

def amount_surcharge
  @amount_surcharge
end

#amount_taxObject (readonly)

This is the sum of all the tax amounts.



2572
2573
2574
# File 'lib/stripe/resources/checkout/session.rb', line 2572

def amount_tax
  @amount_tax
end

#breakdownObject (readonly)

Attribute for field breakdown



2574
2575
2576
# File 'lib/stripe/resources/checkout/session.rb', line 2574

def breakdown
  @breakdown
end

Class Method Details

.field_remappingsObject



2580
2581
2582
# File 'lib/stripe/resources/checkout/session.rb', line 2580

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2576
2577
2578
# File 'lib/stripe/resources/checkout/session.rb', line 2576

def self.inner_class_types
  @inner_class_types = { breakdown: Breakdown }
end