Class: Stripe::Checkout::Session::TotalDetails::Breakdown::Discount

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amount ⇒ Object (readonly)

The amount discounted.



2208
2209
2210
# File 'lib/stripe/resources/checkout/session.rb', line 2208

def amount
  @amount
end

#discount ⇒ Object (readonly)

A discount represents the actual application of a coupon or promotion code. It contains information about when the discount began, when it will end, and what it is applied to.

Related guide: Applying discounts to subscriptions



2213
2214
2215
# File 'lib/stripe/resources/checkout/session.rb', line 2213

def discount
  @discount
end

Class Method Details

.field_remappings ⇒ Object



2219
2220
2221
# File 'lib/stripe/resources/checkout/session.rb', line 2219

def self.field_remappings
  @field_remappings = {}
end

.inner_class_types ⇒ Object



2215
2216
2217
# File 'lib/stripe/resources/checkout/session.rb', line 2215

def self.inner_class_types
  @inner_class_types = {}
end