Class: Stripe::Checkout::Session::UpdateParams::Discount::CouponData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::UpdateParams::Discount::CouponData
- Defined in:
- lib/stripe/resources/checkout/session.rb
Instance Attribute Summary collapse
-
#amount_off ⇒ Object
A positive integer representing the amount to subtract from an invoice total (required if ‘percent_off` is not passed).
-
#currency ⇒ Object
Three-letter [ISO code for the currency](stripe.com/docs/currencies) of the ‘amount_off` parameter (required if `amount_off` is passed).
-
#duration ⇒ Object
Specifies how long the discount will be in effect if used on a subscription.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#name ⇒ Object
Name of the coupon displayed to customers on, for instance invoices, or receipts.
-
#percent_off ⇒ Object
A positive float larger than 0, and smaller or equal to 100, that represents the discount the coupon will apply (required if ‘amount_off` is not passed).
Instance Method Summary collapse
-
#initialize(amount_off: nil, currency: nil, duration: nil, metadata: nil, name: nil, percent_off: nil) ⇒ CouponData
constructor
A new instance of CouponData.
Methods inherited from RequestParams
Constructor Details
#initialize(amount_off: nil, currency: nil, duration: nil, metadata: nil, name: nil, percent_off: nil) ⇒ CouponData
Returns a new instance of CouponData.
4743 4744 4745 4746 4747 4748 4749 4750 4751 4752 4753 4754 4755 4756 4757 |
# File 'lib/stripe/resources/checkout/session.rb', line 4743 def initialize( amount_off: nil, currency: nil, duration: nil, metadata: nil, name: nil, percent_off: nil ) @amount_off = amount_off @currency = currency @duration = duration @metadata = @name = name @percent_off = percent_off end |
Instance Attribute Details
#amount_off ⇒ Object
A positive integer representing the amount to subtract from an invoice total (required if ‘percent_off` is not passed).
4731 4732 4733 |
# File 'lib/stripe/resources/checkout/session.rb', line 4731 def amount_off @amount_off end |
#currency ⇒ Object
Three-letter [ISO code for the currency](stripe.com/docs/currencies) of the ‘amount_off` parameter (required if `amount_off` is passed).
4733 4734 4735 |
# File 'lib/stripe/resources/checkout/session.rb', line 4733 def currency @currency end |
#duration ⇒ Object
Specifies how long the discount will be in effect if used on a subscription. Defaults to ‘once`.
4735 4736 4737 |
# File 'lib/stripe/resources/checkout/session.rb', line 4735 def duration @duration end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
4737 4738 4739 |
# File 'lib/stripe/resources/checkout/session.rb', line 4737 def @metadata end |
#name ⇒ Object
Name of the coupon displayed to customers on, for instance invoices, or receipts. By default the ‘id` is shown if `name` is not set.
4739 4740 4741 |
# File 'lib/stripe/resources/checkout/session.rb', line 4739 def name @name end |
#percent_off ⇒ Object
A positive float larger than 0, and smaller or equal to 100, that represents the discount the coupon will apply (required if ‘amount_off` is not passed).
4741 4742 4743 |
# File 'lib/stripe/resources/checkout/session.rb', line 4741 def percent_off @percent_off end |