Class: Stripe::Checkout::Session::UpdateParams::LineItem::AdjustableQuantity
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::UpdateParams::LineItem::AdjustableQuantity
- Defined in:
- lib/stripe/resources/checkout/session.rb
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Set to true if the quantity can be adjusted to any positive integer.
-
#maximum ⇒ Object
The maximum quantity the customer can purchase for the Checkout Session.
-
#minimum ⇒ Object
The minimum quantity the customer must purchase for the Checkout Session.
Instance Method Summary collapse
-
#initialize(enabled: nil, maximum: nil, minimum: nil) ⇒ AdjustableQuantity
constructor
A new instance of AdjustableQuantity.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, maximum: nil, minimum: nil) ⇒ AdjustableQuantity
Returns a new instance of AdjustableQuantity.
3635 3636 3637 3638 3639 |
# File 'lib/stripe/resources/checkout/session.rb', line 3635 def initialize(enabled: nil, maximum: nil, minimum: nil) @enabled = enabled @maximum = maximum @minimum = minimum end |
Instance Attribute Details
#enabled ⇒ Object
Set to true if the quantity can be adjusted to any positive integer. Setting to false will remove any previously specified constraints on quantity.
3629 3630 3631 |
# File 'lib/stripe/resources/checkout/session.rb', line 3629 def enabled @enabled end |
#maximum ⇒ Object
The maximum quantity the customer can purchase for the Checkout Session. By default this value is 99. You can specify a value up to 999999.
3631 3632 3633 |
# File 'lib/stripe/resources/checkout/session.rb', line 3631 def maximum @maximum end |
#minimum ⇒ Object
The minimum quantity the customer must purchase for the Checkout Session. By default this value is 0.
3633 3634 3635 |
# File 'lib/stripe/resources/checkout/session.rb', line 3633 def minimum @minimum end |