Class: Stripe::Checkout::Session::UpdateParams::LineItem::PriceData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Defined Under Namespace

Classes: ProductData, Recurring

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(currency: nil, product: nil, product_data: nil, recurring: nil, tax_behavior: nil, unit_amount: nil, unit_amount_decimal: nil) ⇒ PriceData

Returns a new instance of PriceData.



3919
3920
3921
3922
3923
3924
3925
3926
3927
3928
3929
3930
3931
3932
3933
3934
3935
# File 'lib/stripe/resources/checkout/session.rb', line 3919

def initialize(
  currency: nil,
  product: nil,
  product_data: nil,
  recurring: nil,
  tax_behavior: nil,
  unit_amount: nil,
  unit_amount_decimal: nil
)
  @currency = currency
  @product = product
  @product_data = product_data
  @recurring = recurring
  @tax_behavior = tax_behavior
  @unit_amount = unit_amount
  @unit_amount_decimal = unit_amount_decimal
end

Instance Attribute Details

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



3905
3906
3907
# File 'lib/stripe/resources/checkout/session.rb', line 3905

def currency
  @currency
end

#productObject

The ID of the [Product](docs.stripe.com/api/products) that this [Price](docs.stripe.com/api/prices) will belong to. One of ‘product` or `product_data` is required.



3907
3908
3909
# File 'lib/stripe/resources/checkout/session.rb', line 3907

def product
  @product
end

#product_dataObject

Data used to generate a new [Product](docs.stripe.com/api/products) object inline. One of ‘product` or `product_data` is required.



3909
3910
3911
# File 'lib/stripe/resources/checkout/session.rb', line 3909

def product_data
  @product_data
end

#recurringObject

The recurring components of a price such as ‘interval` and `interval_count`.



3911
3912
3913
# File 'lib/stripe/resources/checkout/session.rb', line 3911

def recurring
  @recurring
end

#tax_behaviorObject

Only required if a [default tax behavior](stripe.com/docs/tax/products-prices-tax-categories-tax-behavior#setting-a-default-tax-behavior-(recommended)) was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`. Once specified as either `inclusive` or `exclusive`, it cannot be changed.



3913
3914
3915
# File 'lib/stripe/resources/checkout/session.rb', line 3913

def tax_behavior
  @tax_behavior
end

#unit_amountObject

A non-negative integer in cents (or local equivalent) representing how much to charge. One of ‘unit_amount` or `unit_amount_decimal` is required.



3915
3916
3917
# File 'lib/stripe/resources/checkout/session.rb', line 3915

def unit_amount
  @unit_amount
end

#unit_amount_decimalObject

Same as ‘unit_amount`, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places. Only one of `unit_amount` and `unit_amount_decimal` can be set.



3917
3918
3919
# File 'lib/stripe/resources/checkout/session.rb', line 3917

def unit_amount_decimal
  @unit_amount_decimal
end