Class: Stripe::Checkout::Session::UpdateParams::LineItem::PriceData::ProductData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil) ⇒ ProductData

Returns a new instance of ProductData.



3884
3885
3886
3887
3888
3889
3890
# File 'lib/stripe/resources/checkout/session.rb', line 3884

def initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil)
  @description = description
  @images = images
  @metadata = 
  @name = name
  @tax_code = tax_code
end

Instance Attribute Details

#descriptionObject

The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.



3874
3875
3876
# File 'lib/stripe/resources/checkout/session.rb', line 3874

def description
  @description
end

#imagesObject

A list of up to 8 URLs of images for this product, meant to be displayable to the customer.



3876
3877
3878
# File 'lib/stripe/resources/checkout/session.rb', line 3876

def images
  @images
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



3878
3879
3880
# File 'lib/stripe/resources/checkout/session.rb', line 3878

def 
  @metadata
end

#nameObject

The product’s name, meant to be displayable to the customer.



3880
3881
3882
# File 'lib/stripe/resources/checkout/session.rb', line 3880

def name
  @name
end

#tax_codeObject



3882
3883
3884
# File 'lib/stripe/resources/checkout/session.rb', line 3882

def tax_code
  @tax_code
end