Class: Stripe::Checkout::Session::UpdateParams::ShippingOption::ShippingRateData::FixedAmount::CurrencyOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, tax_behavior: nil) ⇒ CurrencyOptions

Returns a new instance of CurrencyOptions.



4930
4931
4932
4933
# File 'lib/stripe/resources/checkout/session.rb', line 4930

def initialize(amount: nil, tax_behavior: nil)
  @amount = amount
  @tax_behavior = tax_behavior
end

Instance Attribute Details

#amountObject

A non-negative integer in cents representing how much to charge.



4926
4927
4928
# File 'lib/stripe/resources/checkout/session.rb', line 4926

def amount
  @amount
end

#tax_behaviorObject

Specifies whether the rate is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`.



4928
4929
4930
# File 'lib/stripe/resources/checkout/session.rb', line 4928

def tax_behavior
  @tax_behavior
end