Class: Stripe::Checkout::Session::UpdateParams::SubscriptionData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(trial_end: nil, trial_period_days: nil) ⇒ SubscriptionData

Returns a new instance of SubscriptionData.



4998
4999
5000
5001
# File 'lib/stripe/resources/checkout/session.rb', line 4998

def initialize(trial_end: nil, trial_period_days: nil)
  @trial_end = trial_end
  @trial_period_days = trial_period_days
end

Instance Attribute Details

#trial_endObject

Unix timestamp representing the end of the trial period the customer will get before being charged for the first time. Has to be at least 48 hours in the future.



4994
4995
4996
# File 'lib/stripe/resources/checkout/session.rb', line 4994

def trial_end
  @trial_end
end

#trial_period_daysObject

Integer representing the number of trial period days before the customer is charged for the first time. Has to be at least 1.



4996
4997
4998
# File 'lib/stripe/resources/checkout/session.rb', line 4996

def trial_period_days
  @trial_period_days
end