Class: Stripe::Checkout::SessionApproveParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionApproveParams
- Defined in:
- lib/stripe/params/checkout/session_approve_params.rb
Defined Under Namespace
Classes: PaymentIntentData, SubscriptionData
Instance Attribute Summary collapse
-
#attempt ⇒ Object
The ID of the customer’s attempt to pay to approve.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#payment_intent_data ⇒ Object
A subset of parameters to be passed to PaymentIntent creation for Checkout Sessions in ‘payment` mode.
-
#return_url ⇒ Object
The URL to redirect your customer back to after they authenticate or cancel their payment on the payment method’s app or site.
-
#subscription_data ⇒ Object
A subset of parameters to be passed to subscription creation for Checkout Sessions in ‘subscription` mode.
Instance Method Summary collapse
-
#initialize(attempt: nil, expand: nil, payment_intent_data: nil, return_url: nil, subscription_data: nil) ⇒ SessionApproveParams
constructor
A new instance of SessionApproveParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(attempt: nil, expand: nil, payment_intent_data: nil, return_url: nil, subscription_data: nil) ⇒ SessionApproveParams
Returns a new instance of SessionApproveParams.
37 38 39 40 41 42 43 44 45 46 47 48 49 |
# File 'lib/stripe/params/checkout/session_approve_params.rb', line 37 def initialize( attempt: nil, expand: nil, payment_intent_data: nil, return_url: nil, subscription_data: nil ) @attempt = attempt @expand = @payment_intent_data = payment_intent_data @return_url = return_url @subscription_data = subscription_data end |
Instance Attribute Details
#attempt ⇒ Object
The ID of the customer’s attempt to pay to approve.
25 26 27 |
# File 'lib/stripe/params/checkout/session_approve_params.rb', line 25 def attempt @attempt end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
27 28 29 |
# File 'lib/stripe/params/checkout/session_approve_params.rb', line 27 def @expand end |
#payment_intent_data ⇒ Object
A subset of parameters to be passed to PaymentIntent creation for Checkout Sessions in ‘payment` mode.
29 30 31 |
# File 'lib/stripe/params/checkout/session_approve_params.rb', line 29 def payment_intent_data @payment_intent_data end |
#return_url ⇒ Object
The URL to redirect your customer back to after they authenticate or cancel their payment on the payment method’s app or site. This parameter is allowed and required if and only if you did not set the return URL during Checkout Session creation or in ‘checkout.confirm()` in Stripe.js.
33 34 35 |
# File 'lib/stripe/params/checkout/session_approve_params.rb', line 33 def return_url @return_url end |
#subscription_data ⇒ Object
A subset of parameters to be passed to subscription creation for Checkout Sessions in ‘subscription` mode.
35 36 37 |
# File 'lib/stripe/params/checkout/session_approve_params.rb', line 35 def subscription_data @subscription_data end |