Class: Stripe::Checkout::SessionCreateParams::BrandingSettings

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Defined Under Namespace

Classes: Icon, Logo

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(background_color: nil, border_style: nil, button_color: nil, display_name: nil, font_family: nil, icon: nil, logo: nil) ⇒ BrandingSettings

Returns a new instance of BrandingSettings.



130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/stripe/params/checkout/session_create_params.rb', line 130

def initialize(
  background_color: nil,
  border_style: nil,
  button_color: nil,
  display_name: nil,
  font_family: nil,
  icon: nil,
  logo: nil
)
  @background_color = background_color
  @border_style = border_style
  @button_color = button_color
  @display_name = display_name
  @font_family = font_family
  @icon = icon
  @logo = 
end

Instance Attribute Details

#background_colorObject

A hex color value starting with # representing the background color for the Checkout Session.



116
117
118
# File 'lib/stripe/params/checkout/session_create_params.rb', line 116

def background_color
  @background_color
end

#border_styleObject

The border style for the Checkout Session.



118
119
120
# File 'lib/stripe/params/checkout/session_create_params.rb', line 118

def border_style
  @border_style
end

#button_colorObject

A hex color value starting with # representing the button color for the Checkout Session.



120
121
122
# File 'lib/stripe/params/checkout/session_create_params.rb', line 120

def button_color
  @button_color
end

#display_nameObject

A string to override the business name shown on the Checkout Session. This only shows at the top of the Checkout page, and your business name still appears in terms, receipts, and other places.



122
123
124
# File 'lib/stripe/params/checkout/session_create_params.rb', line 122

def display_name
  @display_name
end

#font_familyObject

The font family for the Checkout Session corresponding to one of the supported font families.



124
125
126
# File 'lib/stripe/params/checkout/session_create_params.rb', line 124

def font_family
  @font_family
end

#iconObject

The icon for the Checkout Session. For best results, use a square image.



126
127
128
# File 'lib/stripe/params/checkout/session_create_params.rb', line 126

def icon
  @icon
end

#logoObject

The logo for the Checkout Session.



128
129
130
# File 'lib/stripe/params/checkout/session_create_params.rb', line 128

def 
  @logo
end