Class: Stripe::Checkout::SessionCreateParams::ConsentCollection::PaymentMethodReuseAgreement

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(position: nil) ⇒ PaymentMethodReuseAgreement

Returns a new instance of PaymentMethodReuseAgreement.



230
231
232
# File 'lib/stripe/params/checkout/session_create_params.rb', line 230

def initialize(position: nil)
  @position = position
end

Instance Attribute Details

#positionObject

Determines the position and visibility of the payment method reuse agreement in the UI. When set to auto, Stripe's defaults will be used. When set to hidden, the payment method reuse agreement text will always be hidden in the UI.



228
229
230
# File 'lib/stripe/params/checkout/session_create_params.rb', line 228

def position
  @position
end