Class: Stripe::Checkout::SessionCreateParams::CustomField::Label
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionCreateParams::CustomField::Label
- Defined in:
- lib/stripe/params/checkout/session_create_params.rb
Instance Attribute Summary collapse
-
#custom ⇒ Object
Custom text for the label, displayed to the customer.
-
#type ⇒ Object
The type of the label.
Instance Method Summary collapse
-
#initialize(custom: nil, type: nil) ⇒ Label
constructor
A new instance of Label.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(custom: nil, type: nil) ⇒ Label
Returns a new instance of Label.
259 260 261 262 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 259 def initialize(custom: nil, type: nil) @custom = custom @type = type end |
Instance Attribute Details
#custom ⇒ Object
Custom text for the label, displayed to the customer. Up to 50 characters.
255 256 257 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 255 def custom @custom end |
#type ⇒ Object
The type of the label.
257 258 259 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 257 def type @type end |