Class: Stripe::Checkout::SessionCreateParams::CustomerUpdate
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionCreateParams::CustomerUpdate
- Defined in:
- lib/stripe/params/checkout/session_create_params.rb
Instance Attribute Summary collapse
-
#address ⇒ Object
Describes whether Checkout saves the billing address onto
customer.address. -
#name ⇒ Object
Describes whether Checkout saves the name onto
customer.name. -
#shipping ⇒ Object
Describes whether Checkout saves shipping information onto
customer.shipping.
Instance Method Summary collapse
-
#initialize(address: nil, name: nil, shipping: nil) ⇒ CustomerUpdate
constructor
A new instance of CustomerUpdate.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(address: nil, name: nil, shipping: nil) ⇒ CustomerUpdate
Returns a new instance of CustomerUpdate.
418 419 420 421 422 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 418 def initialize(address: nil, name: nil, shipping: nil) @address = address @name = name @shipping = shipping end |
Instance Attribute Details
#address ⇒ Object
Describes whether Checkout saves the billing address onto customer.address.
To always collect a full billing address, use billing_address_collection. Defaults to never.
411 412 413 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 411 def address @address end |
#name ⇒ Object
Describes whether Checkout saves the name onto customer.name. Defaults to never.
413 414 415 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 413 def name @name end |
#shipping ⇒ Object
Describes whether Checkout saves shipping information onto customer.shipping.
To collect shipping information, use shipping_address_collection. Defaults to never.
416 417 418 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 416 def shipping @shipping end |