Class: Stripe::Checkout::SessionCreateParams::InvoiceCreation::InvoiceData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Defined Under Namespace

Classes: CustomField, Issuer, RenderingOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(account_tax_ids: nil, custom_fields: nil, description: nil, footer: nil, issuer: nil, metadata: nil, rendering_options: nil) ⇒ InvoiceData

Returns a new instance of InvoiceData.



425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
# File 'lib/stripe/params/checkout/session_create_params.rb', line 425

def initialize(
  account_tax_ids: nil,
  custom_fields: nil,
  description: nil,
  footer: nil,
  issuer: nil,
  metadata: nil,
  rendering_options: nil
)
  @account_tax_ids = 
  @custom_fields = custom_fields
  @description = description
  @footer = footer
  @issuer = issuer
  @metadata = 
  @rendering_options = rendering_options
end

Instance Attribute Details

#account_tax_idsObject

The account tax IDs associated with the invoice.



411
412
413
# File 'lib/stripe/params/checkout/session_create_params.rb', line 411

def 
  @account_tax_ids
end

#custom_fieldsObject

Default custom fields to be displayed on invoices for this customer.



413
414
415
# File 'lib/stripe/params/checkout/session_create_params.rb', line 413

def custom_fields
  @custom_fields
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



415
416
417
# File 'lib/stripe/params/checkout/session_create_params.rb', line 415

def description
  @description
end

Default footer to be displayed on invoices for this customer.



417
418
419
# File 'lib/stripe/params/checkout/session_create_params.rb', line 417

def footer
  @footer
end

#issuerObject

The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.



419
420
421
# File 'lib/stripe/params/checkout/session_create_params.rb', line 419

def issuer
  @issuer
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



421
422
423
# File 'lib/stripe/params/checkout/session_create_params.rb', line 421

def 
  @metadata
end

#rendering_optionsObject

Default options for invoice PDF rendering for this customer.



423
424
425
# File 'lib/stripe/params/checkout/session_create_params.rb', line 423

def rendering_options
  @rendering_options
end