Class: Stripe::Checkout::SessionCreateParams::InvoiceCreation::InvoiceData::RenderingOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount_tax_display: nil, template: nil) ⇒ RenderingOptions

Returns a new instance of RenderingOptions.



405
406
407
408
# File 'lib/stripe/params/checkout/session_create_params.rb', line 405

def initialize(amount_tax_display: nil, template: nil)
  @amount_tax_display = amount_tax_display
  @template = template
end

Instance Attribute Details

#amount_tax_displayObject

How line-item prices and amounts will be displayed with respect to tax on invoice PDFs. One of ‘exclude_tax` or `include_inclusive_tax`. `include_inclusive_tax` will include inclusive tax (and exclude exclusive tax) in invoice PDF amounts. `exclude_tax` will exclude all tax (inclusive and exclusive alike) from invoice PDF amounts.



401
402
403
# File 'lib/stripe/params/checkout/session_create_params.rb', line 401

def amount_tax_display
  @amount_tax_display
end

#templateObject

ID of the invoice rendering template to use for this invoice.



403
404
405
# File 'lib/stripe/params/checkout/session_create_params.rb', line 403

def template
  @template
end