Class: Stripe::Checkout::SessionCreateParams::Item::Subscription::BillingCycleAnchorConfig
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionCreateParams::Item::Subscription::BillingCycleAnchorConfig
- Defined in:
- lib/stripe/params/checkout/session_create_params.rb
Instance Attribute Summary collapse
-
#day_of_month ⇒ Object
The day of the month the anchor should be.
-
#hour ⇒ Object
The hour of the day the anchor should be.
-
#minute ⇒ Object
The minute of the hour the anchor should be.
-
#month ⇒ Object
The month to start full cycle periods.
-
#second ⇒ Object
The second of the minute the anchor should be.
Instance Method Summary collapse
-
#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ BillingCycleAnchorConfig
constructor
A new instance of BillingCycleAnchorConfig.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ BillingCycleAnchorConfig
Returns a new instance of BillingCycleAnchorConfig.
565 566 567 568 569 570 571 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 565 def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) @day_of_month = day_of_month @hour = hour @minute = minute @month = month @second = second end |
Instance Attribute Details
#day_of_month ⇒ Object
The day of the month the anchor should be. Ranges from 1 to 31.
555 556 557 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 555 def day_of_month @day_of_month end |
#hour ⇒ Object
The hour of the day the anchor should be. Ranges from 0 to 23.
557 558 559 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 557 def hour @hour end |
#minute ⇒ Object
The minute of the hour the anchor should be. Ranges from 0 to 59.
559 560 561 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 559 def minute @minute end |
#month ⇒ Object
The month to start full cycle periods. Ranges from 1 to 12.
561 562 563 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 561 def month @month end |
#second ⇒ Object
The second of the minute the anchor should be. Ranges from 0 to 59.
563 564 565 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 563 def second @second end |