Class: Stripe::Checkout::SessionCreateParams::Item::Subscription::BillingMode

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Defined Under Namespace

Classes: Flexible

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(flexible: nil, type: nil) ⇒ BillingMode

Returns a new instance of BillingMode.



588
589
590
591
# File 'lib/stripe/params/checkout/session_create_params.rb', line 588

def initialize(flexible: nil, type: nil)
  @flexible = flexible
  @type = type
end

Instance Attribute Details

#flexibleObject

Configure behavior for flexible billing mode.



584
585
586
# File 'lib/stripe/params/checkout/session_create_params.rb', line 584

def flexible
  @flexible
end

#typeObject

Controls the calculation and orchestration of prorations and invoices for subscriptions. If no value is passed, the default is flexible.



586
587
588
# File 'lib/stripe/params/checkout/session_create_params.rb', line 586

def type
  @type
end