Class: Stripe::Checkout::SessionCreateParams::NameCollection::Individual
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionCreateParams::NameCollection::Individual
- Defined in:
- lib/stripe/params/checkout/session_create_params.rb
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Enable individual name collection on the Checkout Session.
-
#optional ⇒ Object
Whether the customer is required to provide their name before completing the Checkout Session.
Instance Method Summary collapse
-
#initialize(enabled: nil, optional: nil) ⇒ Individual
constructor
A new instance of Individual.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(enabled: nil, optional: nil) ⇒ Individual
Returns a new instance of Individual.
576 577 578 579 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 576 def initialize(enabled: nil, optional: nil) @enabled = enabled @optional = optional end |
Instance Attribute Details
#enabled ⇒ Object
Enable individual name collection on the Checkout Session. Defaults to false.
572 573 574 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 572 def enabled @enabled end |
#optional ⇒ Object
Whether the customer is required to provide their name before completing the Checkout Session. Defaults to false.
574 575 576 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 574 def optional @optional end |