Class: Stripe::Checkout::SessionCreateParams::OptionalItem::AdjustableQuantity
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionCreateParams::OptionalItem::AdjustableQuantity
- Defined in:
- lib/stripe/params/checkout/session_create_params.rb
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Set to true if the quantity can be adjusted to any non-negative integer.
-
#maximum ⇒ Object
The maximum quantity of this item the customer can purchase.
-
#minimum ⇒ Object
The minimum quantity of this item the customer must purchase, if they choose to purchase it.
Instance Method Summary collapse
-
#initialize(enabled: nil, maximum: nil, minimum: nil) ⇒ AdjustableQuantity
constructor
A new instance of AdjustableQuantity.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(enabled: nil, maximum: nil, minimum: nil) ⇒ AdjustableQuantity
Returns a new instance of AdjustableQuantity.
1027 1028 1029 1030 1031 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1027 def initialize(enabled: nil, maximum: nil, minimum: nil) @enabled = enabled @maximum = maximum @minimum = minimum end |
Instance Attribute Details
#enabled ⇒ Object
Set to true if the quantity can be adjusted to any non-negative integer.
1021 1022 1023 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1021 def enabled @enabled end |
#maximum ⇒ Object
The maximum quantity of this item the customer can purchase. By default this value is 99. You can specify a value up to 999999.
1023 1024 1025 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1023 def maximum @maximum end |
#minimum ⇒ Object
The minimum quantity of this item the customer must purchase, if they choose to purchase it. Because this item is optional, the customer will always be able to remove it from their order, even if the minimum configured here is greater than 0. By default this value is 0.
1025 1026 1027 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1025 def minimum @minimum end |