Class: Stripe::Checkout::SessionCreateParams::PaymentIntentData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Defined Under Namespace

Classes: Shipping, TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(application_fee_amount: nil, capture_method: nil, description: nil, metadata: nil, on_behalf_of: nil, receipt_email: nil, setup_future_usage: nil, shipping: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil, transfer_group: nil) ⇒ PaymentIntentData

Returns a new instance of PaymentIntentData.



736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
# File 'lib/stripe/params/checkout/session_create_params.rb', line 736

def initialize(
  application_fee_amount: nil,
  capture_method: nil,
  description: nil,
  metadata: nil,
  on_behalf_of: nil,
  receipt_email: nil,
  setup_future_usage: nil,
  shipping: nil,
  statement_descriptor: nil,
  statement_descriptor_suffix: nil,
  transfer_data: nil,
  transfer_group: nil
)
  @application_fee_amount = application_fee_amount
  @capture_method = capture_method
  @description = description
   = 
  @on_behalf_of = on_behalf_of
  @receipt_email = receipt_email
  @setup_future_usage = setup_future_usage
  @shipping = shipping
  @statement_descriptor = statement_descriptor
  @statement_descriptor_suffix = statement_descriptor_suffix
  @transfer_data = transfer_data
  @transfer_group = transfer_group
end

Instance Attribute Details

#application_fee_amountObject

The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents [use case for connected accounts](docs.stripe.com/payments/connected-accounts).



688
689
690
# File 'lib/stripe/params/checkout/session_create_params.rb', line 688

def application_fee_amount
  @application_fee_amount
end

#capture_methodObject

Controls when the funds will be captured from the customer’s account.



690
691
692
# File 'lib/stripe/params/checkout/session_create_params.rb', line 690

def capture_method
  @capture_method
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



692
693
694
# File 'lib/stripe/params/checkout/session_create_params.rb', line 692

def description
  @description
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.



694
695
696
# File 'lib/stripe/params/checkout/session_create_params.rb', line 694

def 
  
end

#on_behalf_ofObject

The Stripe account ID for which these funds are intended. For details, see the PaymentIntents [use case for connected accounts](/docs/payments/connected-accounts).



698
699
700
# File 'lib/stripe/params/checkout/session_create_params.rb', line 698

def on_behalf_of
  @on_behalf_of
end

#receipt_emailObject

Email address that the receipt for the resulting payment will be sent to. If receipt_email is specified for a payment in live mode, a receipt will be sent regardless of your [email settings](dashboard.stripe.com/account/emails).



700
701
702
# File 'lib/stripe/params/checkout/session_create_params.rb', line 700

def receipt_email
  @receipt_email
end

#setup_future_usageObject

Indicates that you intend to [make future payments](docs.stripe.com/payments/payment-intents#future-usage) with the payment method collected by this Checkout Session.

When setting this to on_session, Checkout will show a notice to the customer that their payment details will be saved.

When setting this to off_session, Checkout will show a notice to the customer that their payment details will be saved and used for future payments.

If a Customer has been provided or Checkout creates a new Customer, Checkout will attach the payment method to the Customer.

If Checkout does not create a Customer, the payment method is not attached to a Customer. To reuse the payment method, you can retrieve it from the Checkout Session’s PaymentIntent.

When processing card payments, Checkout also uses setup_future_usage to dynamically optimize your payment flow and comply with regional legislation and network rules, such as SCA.



721
722
723
# File 'lib/stripe/params/checkout/session_create_params.rb', line 721

def setup_future_usage
  @setup_future_usage
end

#shippingObject

Shipping information for this payment.



723
724
725
# File 'lib/stripe/params/checkout/session_create_params.rb', line 723

def shipping
  @shipping
end

#statement_descriptorObject

Text that appears on the customer’s statement as the statement descriptor for a non-card charge. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).

Setting this value for a card charge returns an error. For card charges, set the [statement_descriptor_suffix](docs.stripe.com/get-started/account/statement-descriptors#dynamic) instead.



727
728
729
# File 'lib/stripe/params/checkout/session_create_params.rb', line 727

def statement_descriptor
  @statement_descriptor
end

#statement_descriptor_suffixObject

Provides information about a card charge. Concatenated to the account’s [statement descriptor prefix](docs.stripe.com/get-started/account/statement-descriptors#static) to form the complete statement descriptor that appears on the customer’s statement.



729
730
731
# File 'lib/stripe/params/checkout/session_create_params.rb', line 729

def statement_descriptor_suffix
  @statement_descriptor_suffix
end

#transfer_dataObject

The parameters used to automatically create a Transfer when the payment succeeds. For more information, see the PaymentIntents [use case for connected accounts](docs.stripe.com/payments/connected-accounts).



732
733
734
# File 'lib/stripe/params/checkout/session_create_params.rb', line 732

def transfer_data
  @transfer_data
end

#transfer_groupObject

A string that identifies the resulting payment as part of a group. See the PaymentIntents [use case for connected accounts](docs.stripe.com/connect/separate-charges-and-transfers) for details.



734
735
736
# File 'lib/stripe/params/checkout/session_create_params.rb', line 734

def transfer_group
  @transfer_group
end