Class: Stripe::Checkout::SessionCreateParams::PaymentIntentData::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



1108
1109
1110
1111
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1108

def initialize(amount: nil, destination: nil)
  @amount = amount
  @destination = destination
end

Instance Attribute Details

#amountObject

The amount that will be transferred automatically when a charge succeeds.



1101
1102
1103
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1101

def amount
  @amount
end

#destinationObject

If specified, successful charges will be attributed to the destination account for tax reporting, and the funds from charges will be transferred to the destination account. The ID of the resulting transfer will be returned on the successful charge's transfer field.



1106
1107
1108
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1106

def destination
  @destination
end