Class: Stripe::Checkout::SessionCreateParams::PaymentMethodData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionCreateParams::PaymentMethodData
- Defined in:
- lib/stripe/params/checkout/session_create_params.rb
Instance Attribute Summary collapse
-
#allow_redisplay ⇒ Object
Allow redisplay will be set on the payment method on confirmation and indicates whether this payment method can be shown again to the customer in a checkout flow.
Instance Method Summary collapse
-
#initialize(allow_redisplay: nil) ⇒ PaymentMethodData
constructor
A new instance of PaymentMethodData.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(allow_redisplay: nil) ⇒ PaymentMethodData
Returns a new instance of PaymentMethodData.
826 827 828 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 826 def initialize(allow_redisplay: nil) @allow_redisplay = allow_redisplay end |
Instance Attribute Details
#allow_redisplay ⇒ Object
Allow redisplay will be set on the payment method on confirmation and indicates whether this payment method can be shown again to the customer in a checkout flow. Only set this field if you wish to override the allow_redisplay value determined by Checkout.
824 825 826 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 824 def allow_redisplay @allow_redisplay end |