Class: Stripe::Checkout::SessionCreateParams::PaymentMethodOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionCreateParams::PaymentMethodOptions
- Defined in:
- lib/stripe/params/checkout/session_create_params.rb
Defined Under Namespace
Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, Boleto, Card, Cashapp, CustomerBalance, DemoPay, Eps, Fpx, Giropay, Grabpay, Ideal, KakaoPay, Klarna, Konbini, KrCard, Link, Mobilepay, Multibanco, NaverPay, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Payto, Pix, RevolutPay, SamsungPay, Satispay, SepaDebit, Sofort, Swish, Twint, UsBankAccount, WechatPay
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
contains details about the ACSS Debit payment method options.
-
#affirm ⇒ Object
contains details about the Affirm payment method options.
-
#afterpay_clearpay ⇒ Object
contains details about the Afterpay Clearpay payment method options.
-
#alipay ⇒ Object
contains details about the Alipay payment method options.
-
#alma ⇒ Object
contains details about the Alma payment method options.
-
#amazon_pay ⇒ Object
contains details about the AmazonPay payment method options.
-
#au_becs_debit ⇒ Object
contains details about the AU Becs Debit payment method options.
-
#bacs_debit ⇒ Object
contains details about the Bacs Debit payment method options.
-
#bancontact ⇒ Object
contains details about the Bancontact payment method options.
-
#billie ⇒ Object
contains details about the Billie payment method options.
-
#boleto ⇒ Object
contains details about the Boleto payment method options.
-
#card ⇒ Object
contains details about the Card payment method options.
-
#cashapp ⇒ Object
contains details about the Cashapp Pay payment method options.
-
#customer_balance ⇒ Object
contains details about the Customer Balance payment method options.
-
#demo_pay ⇒ Object
contains details about the DemoPay payment method options.
-
#eps ⇒ Object
contains details about the EPS payment method options.
-
#fpx ⇒ Object
contains details about the FPX payment method options.
-
#giropay ⇒ Object
contains details about the Giropay payment method options.
-
#grabpay ⇒ Object
contains details about the Grabpay payment method options.
-
#ideal ⇒ Object
contains details about the Ideal payment method options.
-
#kakao_pay ⇒ Object
contains details about the Kakao Pay payment method options.
-
#klarna ⇒ Object
contains details about the Klarna payment method options.
-
#konbini ⇒ Object
contains details about the Konbini payment method options.
-
#kr_card ⇒ Object
contains details about the Korean card payment method options.
-
#link ⇒ Object
contains details about the Link payment method options.
-
#mobilepay ⇒ Object
contains details about the Mobilepay payment method options.
-
#multibanco ⇒ Object
contains details about the Multibanco payment method options.
-
#naver_pay ⇒ Object
contains details about the Naver Pay payment method options.
-
#oxxo ⇒ Object
contains details about the OXXO payment method options.
-
#p24 ⇒ Object
contains details about the P24 payment method options.
-
#pay_by_bank ⇒ Object
contains details about the Pay By Bank payment method options.
-
#payco ⇒ Object
contains details about the PAYCO payment method options.
-
#paynow ⇒ Object
contains details about the PayNow payment method options.
-
#paypal ⇒ Object
contains details about the PayPal payment method options.
-
#payto ⇒ Object
contains details about the PayTo payment method options.
-
#pix ⇒ Object
contains details about the Pix payment method options.
-
#revolut_pay ⇒ Object
contains details about the RevolutPay payment method options.
-
#samsung_pay ⇒ Object
contains details about the Samsung Pay payment method options.
-
#satispay ⇒ Object
contains details about the Satispay payment method options.
-
#sepa_debit ⇒ Object
contains details about the Sepa Debit payment method options.
-
#sofort ⇒ Object
contains details about the Sofort payment method options.
-
#swish ⇒ Object
contains details about the Swish payment method options.
-
#twint ⇒ Object
contains details about the TWINT payment method options.
-
#us_bank_account ⇒ Object
contains details about the Us Bank Account payment method options.
-
#wechat_pay ⇒ Object
contains details about the WeChat Pay payment method options.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, alma: nil, amazon_pay: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, billie: nil, boleto: nil, card: nil, cashapp: nil, customer_balance: nil, demo_pay: nil, eps: nil, fpx: nil, giropay: nil, grabpay: nil, ideal: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, mobilepay: nil, multibanco: nil, naver_pay: nil, oxxo: nil, p24: nil, pay_by_bank: nil, payco: nil, paynow: nil, paypal: nil, payto: nil, pix: nil, revolut_pay: nil, samsung_pay: nil, satispay: nil, sepa_debit: nil, sofort: nil, swish: nil, twint: nil, us_bank_account: nil, wechat_pay: nil) ⇒ PaymentMethodOptions
Returns a new instance of PaymentMethodOptions.
1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008 2009 2010 2011 2012 2013 2014 2015 2016 2017 2018 2019 2020 2021 2022 2023 2024 2025 2026 2027 2028 2029 2030 2031 2032 2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 2058 2059 2060 2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1993 def initialize( acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, alma: nil, amazon_pay: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, billie: nil, boleto: nil, card: nil, cashapp: nil, customer_balance: nil, demo_pay: nil, eps: nil, fpx: nil, giropay: nil, grabpay: nil, ideal: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, mobilepay: nil, multibanco: nil, naver_pay: nil, oxxo: nil, p24: nil, pay_by_bank: nil, payco: nil, paynow: nil, paypal: nil, payto: nil, pix: nil, revolut_pay: nil, samsung_pay: nil, satispay: nil, sepa_debit: nil, sofort: nil, swish: nil, twint: nil, us_bank_account: nil, wechat_pay: nil ) @acss_debit = acss_debit @affirm = affirm @afterpay_clearpay = afterpay_clearpay @alipay = alipay @alma = alma @amazon_pay = amazon_pay @au_becs_debit = au_becs_debit @bacs_debit = bacs_debit @bancontact = bancontact @billie = billie @boleto = boleto @card = card @cashapp = cashapp @customer_balance = customer_balance @demo_pay = demo_pay @eps = eps @fpx = fpx @giropay = giropay @grabpay = grabpay @ideal = ideal @kakao_pay = kakao_pay @klarna = klarna @konbini = konbini @kr_card = kr_card @link = link @mobilepay = mobilepay @multibanco = multibanco @naver_pay = naver_pay @oxxo = oxxo @p24 = p24 @pay_by_bank = pay_by_bank @payco = payco @paynow = paynow @paypal = paypal @payto = payto @pix = pix @revolut_pay = revolut_pay @samsung_pay = samsung_pay @satispay = satispay @sepa_debit = sepa_debit @sofort = sofort @swish = swish @twint = twint @us_bank_account = us_bank_account @wechat_pay = wechat_pay end |
Instance Attribute Details
#acss_debit ⇒ Object
contains details about the ACSS Debit payment method options.
1903 1904 1905 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1903 def acss_debit @acss_debit end |
#affirm ⇒ Object
contains details about the Affirm payment method options.
1905 1906 1907 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1905 def affirm @affirm end |
#afterpay_clearpay ⇒ Object
contains details about the Afterpay Clearpay payment method options.
1907 1908 1909 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1907 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object
contains details about the Alipay payment method options.
1909 1910 1911 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1909 def alipay @alipay end |
#alma ⇒ Object
contains details about the Alma payment method options.
1911 1912 1913 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1911 def alma @alma end |
#amazon_pay ⇒ Object
contains details about the AmazonPay payment method options.
1913 1914 1915 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1913 def amazon_pay @amazon_pay end |
#au_becs_debit ⇒ Object
contains details about the AU Becs Debit payment method options.
1915 1916 1917 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1915 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object
contains details about the Bacs Debit payment method options.
1917 1918 1919 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1917 def bacs_debit @bacs_debit end |
#bancontact ⇒ Object
contains details about the Bancontact payment method options.
1919 1920 1921 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1919 def bancontact @bancontact end |
#billie ⇒ Object
contains details about the Billie payment method options.
1921 1922 1923 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1921 def billie @billie end |
#boleto ⇒ Object
contains details about the Boleto payment method options.
1923 1924 1925 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1923 def boleto @boleto end |
#card ⇒ Object
contains details about the Card payment method options.
1925 1926 1927 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1925 def card @card end |
#cashapp ⇒ Object
contains details about the Cashapp Pay payment method options.
1927 1928 1929 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1927 def cashapp @cashapp end |
#customer_balance ⇒ Object
contains details about the Customer Balance payment method options.
1929 1930 1931 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1929 def customer_balance @customer_balance end |
#demo_pay ⇒ Object
contains details about the DemoPay payment method options.
1931 1932 1933 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1931 def demo_pay @demo_pay end |
#eps ⇒ Object
contains details about the EPS payment method options.
1933 1934 1935 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1933 def eps @eps end |
#fpx ⇒ Object
contains details about the FPX payment method options.
1935 1936 1937 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1935 def fpx @fpx end |
#giropay ⇒ Object
contains details about the Giropay payment method options.
1937 1938 1939 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1937 def giropay @giropay end |
#grabpay ⇒ Object
contains details about the Grabpay payment method options.
1939 1940 1941 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1939 def grabpay @grabpay end |
#ideal ⇒ Object
contains details about the Ideal payment method options.
1941 1942 1943 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1941 def ideal @ideal end |
#kakao_pay ⇒ Object
contains details about the Kakao Pay payment method options.
1943 1944 1945 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1943 def kakao_pay @kakao_pay end |
#klarna ⇒ Object
contains details about the Klarna payment method options.
1945 1946 1947 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1945 def klarna @klarna end |
#konbini ⇒ Object
contains details about the Konbini payment method options.
1947 1948 1949 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1947 def konbini @konbini end |
#kr_card ⇒ Object
contains details about the Korean card payment method options.
1949 1950 1951 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1949 def kr_card @kr_card end |
#link ⇒ Object
contains details about the Link payment method options.
1951 1952 1953 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1951 def link @link end |
#mobilepay ⇒ Object
contains details about the Mobilepay payment method options.
1953 1954 1955 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1953 def mobilepay @mobilepay end |
#multibanco ⇒ Object
contains details about the Multibanco payment method options.
1955 1956 1957 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1955 def multibanco @multibanco end |
#naver_pay ⇒ Object
contains details about the Naver Pay payment method options.
1957 1958 1959 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1957 def naver_pay @naver_pay end |
#oxxo ⇒ Object
contains details about the OXXO payment method options.
1959 1960 1961 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1959 def oxxo @oxxo end |
#p24 ⇒ Object
contains details about the P24 payment method options.
1961 1962 1963 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1961 def p24 @p24 end |
#pay_by_bank ⇒ Object
contains details about the Pay By Bank payment method options.
1963 1964 1965 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1963 def pay_by_bank @pay_by_bank end |
#payco ⇒ Object
contains details about the PAYCO payment method options.
1965 1966 1967 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1965 def payco @payco end |
#paynow ⇒ Object
contains details about the PayNow payment method options.
1967 1968 1969 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1967 def paynow @paynow end |
#paypal ⇒ Object
contains details about the PayPal payment method options.
1969 1970 1971 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1969 def paypal @paypal end |
#payto ⇒ Object
contains details about the PayTo payment method options.
1971 1972 1973 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1971 def payto @payto end |
#pix ⇒ Object
contains details about the Pix payment method options.
1973 1974 1975 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1973 def pix @pix end |
#revolut_pay ⇒ Object
contains details about the RevolutPay payment method options.
1975 1976 1977 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1975 def revolut_pay @revolut_pay end |
#samsung_pay ⇒ Object
contains details about the Samsung Pay payment method options.
1977 1978 1979 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1977 def samsung_pay @samsung_pay end |
#satispay ⇒ Object
contains details about the Satispay payment method options.
1979 1980 1981 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1979 def satispay @satispay end |
#sepa_debit ⇒ Object
contains details about the Sepa Debit payment method options.
1981 1982 1983 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1981 def sepa_debit @sepa_debit end |
#sofort ⇒ Object
contains details about the Sofort payment method options.
1983 1984 1985 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1983 def sofort @sofort end |
#swish ⇒ Object
contains details about the Swish payment method options.
1985 1986 1987 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1985 def swish @swish end |
#twint ⇒ Object
contains details about the TWINT payment method options.
1987 1988 1989 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1987 def twint @twint end |
#us_bank_account ⇒ Object
contains details about the Us Bank Account payment method options.
1989 1990 1991 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1989 def us_bank_account @us_bank_account end |
#wechat_pay ⇒ Object
contains details about the WeChat Pay payment method options.
1991 1992 1993 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1991 def wechat_pay @wechat_pay end |