Class: Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::AcssDebit::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(custom_mandate_url: nil, default_for: nil, interval_description: nil, payment_schedule: nil, transaction_type: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



790
791
792
793
794
795
796
797
798
799
800
801
802
# File 'lib/stripe/params/checkout/session_create_params.rb', line 790

def initialize(
  custom_mandate_url: nil,
  default_for: nil,
  interval_description: nil,
  payment_schedule: nil,
  transaction_type: nil
)
  @custom_mandate_url = custom_mandate_url
  @default_for = default_for
  @interval_description = interval_description
  @payment_schedule = payment_schedule
  @transaction_type = transaction_type
end

Instance Attribute Details

#custom_mandate_urlObject

A URL for custom mandate text to render during confirmation step. The URL will be rendered with additional GET parameters payment_intent and payment_intent_client_secret when confirming a Payment Intent, or setup_intent and setup_intent_client_secret when confirming a Setup Intent.



780
781
782
# File 'lib/stripe/params/checkout/session_create_params.rb', line 780

def custom_mandate_url
  @custom_mandate_url
end

#default_forObject

List of Stripe products where this mandate can be selected automatically. Only usable in setup mode.



782
783
784
# File 'lib/stripe/params/checkout/session_create_params.rb', line 782

def default_for
  @default_for
end

#interval_descriptionObject

Description of the mandate interval. Only required if ‘payment_schedule’ parameter is ‘interval’ or ‘combined’.



784
785
786
# File 'lib/stripe/params/checkout/session_create_params.rb', line 784

def interval_description
  @interval_description
end

#payment_scheduleObject

Payment schedule for the mandate.



786
787
788
# File 'lib/stripe/params/checkout/session_create_params.rb', line 786

def payment_schedule
  @payment_schedule
end

#transaction_typeObject

Transaction type of the mandate.



788
789
790
# File 'lib/stripe/params/checkout/session_create_params.rb', line 788

def transaction_type
  @transaction_type
end