Class: Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::AuBecsDebit
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::AuBecsDebit
- Defined in:
- lib/stripe/params/checkout/session_create_params.rb
Instance Attribute Summary collapse
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent's payment method.
-
#target_date ⇒ Object
Controls when Stripe will attempt to debit the funds from the customer's account.
Instance Method Summary collapse
-
#initialize(setup_future_usage: nil, target_date: nil) ⇒ AuBecsDebit
constructor
A new instance of AuBecsDebit.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(setup_future_usage: nil, target_date: nil) ⇒ AuBecsDebit
Returns a new instance of AuBecsDebit.
931 932 933 934 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 931 def initialize(setup_future_usage: nil, target_date: nil) @setup_future_usage = setup_future_usage @target_date = target_date end |
Instance Attribute Details
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent's payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.
If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.
When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.
927 928 929 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 927 def setup_future_usage @setup_future_usage end |
#target_date ⇒ Object
Controls when Stripe will attempt to debit the funds from the customer's account. The date must be a string in YYYY-MM-DD format. The date must be in the future and between 3 and 15 calendar days from now.
929 930 931 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 929 def target_date @target_date end |