Class: Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::Blik::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h

Constructor Details

#initialize(expires_at: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



1001
1002
1003
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1001

def initialize(expires_at: nil)
  @expires_at = expires_at
end

Instance Attribute Details

#expires_at ⇒ Object

Date when the mandate expires and no further payments will be charged. If not provided, the mandate will be set to be indefinite.



999
1000
1001
# File 'lib/stripe/params/checkout/session_create_params.rb', line 999

def expires_at
  @expires_at
end