Class: Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::Card::Installments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(enabled: nil) ⇒ Installments

Returns a new instance of Installments.



1086
1087
1088
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1086

def initialize(enabled: nil)
  @enabled = enabled
end

Instance Attribute Details

#enabledObject

Setting to true enables installments for this Checkout Session. Setting to false will prevent any installment plan from applying to a payment.



1084
1085
1086
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1084

def enabled
  @enabled
end