Class: Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::Card::Restrictions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h

Constructor Details

#initialize(brands_blocked: nil, funding_types_blocked: nil) ⇒ Restrictions

Returns a new instance of Restrictions.



1084
1085
1086
1087
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1084

def initialize(brands_blocked: nil, funding_types_blocked: nil)
  @brands_blocked = brands_blocked
  @funding_types_blocked = funding_types_blocked
end

Instance Attribute Details

#brands_blockedObject

The card brands to block. If a customer enters or selects a card belonging to a blocked brand, they can't complete the payment.



1080
1081
1082
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1080

def brands_blocked
  @brands_blocked
end

#funding_types_blockedObject

Card funding types to block for this Checkout Session. Supported values are credit, debit, and prepaid.



1082
1083
1084
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1082

def funding_types_blocked
  @funding_types_blocked
end