Class: Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::CustomerBalance::BankTransfer

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Defined Under Namespace

Classes: EuBankTransfer

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(eu_bank_transfer: nil, requested_address_types: nil, type: nil) ⇒ BankTransfer

Returns a new instance of BankTransfer.



1590
1591
1592
1593
1594
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1590

def initialize(eu_bank_transfer: nil, requested_address_types: nil, type: nil)
  @eu_bank_transfer = eu_bank_transfer
  @requested_address_types = requested_address_types
  @type = type
end

Instance Attribute Details

#eu_bank_transferObject

Configuration for eu_bank_transfer funding type.



1582
1583
1584
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1582

def eu_bank_transfer
  @eu_bank_transfer
end

#requested_address_typesObject

List of address types that should be returned in the financial_addresses response. If not specified, all valid types will be returned.

Permitted values include: sort_code, zengin, iban, or spei.



1586
1587
1588
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1586

def requested_address_types
  @requested_address_types
end

#typeObject

The list of bank transfer types that this PaymentIntent is allowed to use for funding.



1588
1589
1590
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1588

def type
  @type
end