Class: Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::Ideal

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(setup_future_usage: nil) ⇒ Ideal

Returns a new instance of Ideal.



1318
1319
1320
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1318

def initialize(setup_future_usage: nil)
  @setup_future_usage = setup_future_usage
end

Instance Attribute Details

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent's payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.

If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.

When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.



1316
1317
1318
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1316

def setup_future_usage
  @setup_future_usage
end