Class: Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::Klarna::Subscription
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::Klarna::Subscription
- Defined in:
- lib/stripe/params/checkout/session_create_params.rb
Defined Under Namespace
Classes: NextBilling
Instance Attribute Summary collapse
-
#interval ⇒ Object
Unit of time between subscription charges.
-
#interval_count ⇒ Object
The number of intervals (specified in the
intervalattribute) between subscription charges. -
#name ⇒ Object
Name for subscription.
-
#next_billing ⇒ Object
Describes the upcoming charge for this subscription.
-
#reference ⇒ Object
A non-customer-facing reference to correlate subscription charges in the Klarna app.
Instance Method Summary collapse
-
#initialize(interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil) ⇒ Subscription
constructor
A new instance of Subscription.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil) ⇒ Subscription
Returns a new instance of Subscription.
1287 1288 1289 1290 1291 1292 1293 1294 1295 1296 1297 1298 1299 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1287 def initialize( interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil ) @interval = interval @interval_count = interval_count @name = name @next_billing = next_billing @reference = reference end |
Instance Attribute Details
#interval ⇒ Object
Unit of time between subscription charges.
1277 1278 1279 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1277 def interval @interval end |
#interval_count ⇒ Object
The number of intervals (specified in the interval attribute) between subscription charges. For example, interval=month and interval_count=3 charges every 3 months.
1279 1280 1281 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1279 def interval_count @interval_count end |
#name ⇒ Object
Name for subscription.
1281 1282 1283 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1281 def name @name end |
#next_billing ⇒ Object
Describes the upcoming charge for this subscription.
1283 1284 1285 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1283 def next_billing @next_billing end |
#reference ⇒ Object
A non-customer-facing reference to correlate subscription charges in the Klarna app. Use a value that persists across subscription charges.
1285 1286 1287 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1285 def reference @reference end |