Class: Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::Oxxo
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::Oxxo
- Defined in:
- lib/stripe/params/checkout/session_create_params.rb
Instance Attribute Summary collapse
-
#expires_after_days ⇒ Object
The number of calendar days before an OXXO voucher expires.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent's payment method.
Instance Method Summary collapse
-
#initialize(expires_after_days: nil, setup_future_usage: nil) ⇒ Oxxo
constructor
A new instance of Oxxo.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(expires_after_days: nil, setup_future_usage: nil) ⇒ Oxxo
Returns a new instance of Oxxo.
1516 1517 1518 1519 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1516 def initialize(expires_after_days: nil, setup_future_usage: nil) @expires_after_days = expires_after_days @setup_future_usage = setup_future_usage end |
Instance Attribute Details
#expires_after_days ⇒ Object
The number of calendar days before an OXXO voucher expires. For example, if you create an OXXO voucher on Monday and you set expires_after_days to 2, the OXXO invoice will expire on Wednesday at 23:59 America/Mexico_City time.
1506 1507 1508 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1506 def expires_after_days @expires_after_days end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent's payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.
If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.
When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.
1514 1515 1516 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1514 def setup_future_usage @setup_future_usage end |