Class: Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::P24

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h

Constructor Details

#initialize(setup_future_usage: nil, tos_shown_and_accepted: nil) ⇒ P24

Returns a new instance of P24.



1528
1529
1530
1531
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1528

def initialize(setup_future_usage: nil, tos_shown_and_accepted: nil)
  @setup_future_usage = setup_future_usage
  @tos_shown_and_accepted = tos_shown_and_accepted
end

Instance Attribute Details

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent's payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.

If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.

When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.



1524
1525
1526
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1524

def setup_future_usage
  @setup_future_usage
end

#tos_shown_and_acceptedObject

Confirm that the payer has accepted the P24 terms and conditions.



1526
1527
1528
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1526

def tos_shown_and_accepted
  @tos_shown_and_accepted
end