Class: Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::Payco
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::Payco
- Defined in:
- lib/stripe/params/checkout/session_create_params.rb
Instance Attribute Summary collapse
-
#capture_method ⇒ Object
Controls when the funds will be captured from the customer’s account.
Instance Method Summary collapse
-
#initialize(capture_method: nil) ⇒ Payco
constructor
A new instance of Payco.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(capture_method: nil) ⇒ Payco
Returns a new instance of Payco.
1469 1470 1471 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1469 def initialize(capture_method: nil) @capture_method = capture_method end |
Instance Attribute Details
#capture_method ⇒ Object
Controls when the funds will be captured from the customer’s account.
1467 1468 1469 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1467 def capture_method @capture_method end |