Class: Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::Payto
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::Payto
- Defined in:
- lib/stripe/params/checkout/session_create_params.rb
Defined Under Namespace
Classes: MandateOptions
Instance Attribute Summary collapse
-
#mandate_options ⇒ Object
Additional fields for Mandate creation.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent's payment method.
Instance Method Summary collapse
-
#initialize(mandate_options: nil, setup_future_usage: nil) ⇒ Payto
constructor
A new instance of Payto.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(mandate_options: nil, setup_future_usage: nil) ⇒ Payto
Returns a new instance of Payto.
2047 2048 2049 2050 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2047 def initialize(mandate_options: nil, setup_future_usage: nil) @mandate_options = @setup_future_usage = setup_future_usage end |
Instance Attribute Details
#mandate_options ⇒ Object
Additional fields for Mandate creation
2037 2038 2039 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2037 def @mandate_options end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent's payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.
If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.
When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.
2045 2046 2047 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2045 def setup_future_usage @setup_future_usage end |