Class: Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::Pix::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_includes_iof: nil, amount_type: nil, currency: nil, end_date: nil, payment_schedule: nil, reference: nil, start_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
1626
1627
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1609

def initialize(
  amount: nil,
  amount_includes_iof: nil,
  amount_type: nil,
  currency: nil,
  end_date: nil,
  payment_schedule: nil,
  reference: nil,
  start_date: nil
)
  @amount = amount
  @amount_includes_iof = amount_includes_iof
  @amount_type = amount_type
  @currency = currency
  @end_date = end_date
  @payment_schedule = payment_schedule
  @reference = reference
  @start_date = start_date
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments. Required when amount_type=fixed. If not provided for amount_type=maximum, defaults to 40000.



1593
1594
1595
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1593

def amount
  @amount
end

#amount_includes_iofObject

Determines if the amount includes the IOF tax. Defaults to never.



1595
1596
1597
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1595

def amount_includes_iof
  @amount_includes_iof
end

#amount_typeObject

Type of amount. Defaults to maximum.



1597
1598
1599
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1597

def amount_type
  @amount_type
end

#currencyObject

Three-letter ISO currency code, in lowercase. Only brl is supported currently.



1599
1600
1601
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1599

def currency
  @currency
end

#end_dateObject

Date when the mandate expires and no further payments will be charged, in YYYY-MM-DD. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.



1601
1602
1603
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1601

def end_date
  @end_date
end

#payment_scheduleObject

Schedule at which the future payments will be charged. Defaults to monthly.



1603
1604
1605
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1603

def payment_schedule
  @payment_schedule
end

#referenceObject

Subscription name displayed to buyers in their bank app. Defaults to the displayable business name.



1605
1606
1607
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1605

def reference
  @reference
end

#start_dateObject

Start date of the mandate, in YYYY-MM-DD. Start date should be at least 3 days in the future. Defaults to 3 days after the current date.



1607
1608
1609
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1607

def start_date
  @start_date
end