Class: Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::SamsungPay

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(capture_method: nil, setup_future_usage: nil) ⇒ SamsungPay

Returns a new instance of SamsungPay.



1767
1768
1769
1770
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1767

def initialize(capture_method: nil, setup_future_usage: nil)
  @capture_method = capture_method
  @setup_future_usage = setup_future_usage
end

Instance Attribute Details

#capture_methodObject

Controls when the funds will be captured from the customer's account.



1757
1758
1759
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1757

def capture_method
  @capture_method
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent's payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.

If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.

When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.



1765
1766
1767
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1765

def setup_future_usage
  @setup_future_usage
end