Class: Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::Satispay
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::Satispay
- Defined in:
- lib/stripe/params/checkout/session_create_params.rb
Instance Attribute Summary collapse
-
#capture_method ⇒ Object
Controls when the funds will be captured from the customer’s account.
Instance Method Summary collapse
-
#initialize(capture_method: nil) ⇒ Satispay
constructor
A new instance of Satispay.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(capture_method: nil) ⇒ Satispay
Returns a new instance of Satispay.
1763 1764 1765 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1763 def initialize(capture_method: nil) @capture_method = capture_method end |
Instance Attribute Details
#capture_method ⇒ Object
Controls when the funds will be captured from the customer’s account.
1761 1762 1763 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1761 def capture_method @capture_method end |