Class: Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::UsBankAccount
- Defined in:
- lib/stripe/params/checkout/session_create_params.rb
Defined Under Namespace
Classes: FinancialConnections
Instance Attribute Summary collapse
-
#financial_connections ⇒ Object
Additional fields for Financial Connections Session creation.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent's payment method.
-
#target_date ⇒ Object
Controls when Stripe will attempt to debit the funds from the customer's account.
-
#verification_method ⇒ Object
Verification method for the intent.
Instance Method Summary collapse
-
#initialize(financial_connections: nil, setup_future_usage: nil, target_date: nil, verification_method: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(financial_connections: nil, setup_future_usage: nil, target_date: nil, verification_method: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
2316 2317 2318 2319 2320 2321 2322 2323 2324 2325 2326 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2316 def initialize( financial_connections: nil, setup_future_usage: nil, target_date: nil, verification_method: nil ) @financial_connections = financial_connections @setup_future_usage = setup_future_usage @target_date = target_date @verification_method = verification_method end |
Instance Attribute Details
#financial_connections ⇒ Object
Additional fields for Financial Connections Session creation
2302 2303 2304 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2302 def financial_connections @financial_connections end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent's payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.
If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.
When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.
2310 2311 2312 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2310 def setup_future_usage @setup_future_usage end |
#target_date ⇒ Object
Controls when Stripe will attempt to debit the funds from the customer's account. The date must be a string in YYYY-MM-DD format. The date must be in the future and between 3 and 15 calendar days from now.
2312 2313 2314 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2312 def target_date @target_date end |
#verification_method ⇒ Object
Verification method for the intent
2314 2315 2316 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2314 def verification_method @verification_method end |