Class: Stripe::Checkout::SessionCreateParams::Permissions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Defined Under Namespace

Classes: Update

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(update: nil, update_discounts: nil, update_line_items: nil, update_shipping_details: nil) ⇒ Permissions

Returns a new instance of Permissions.



2211
2212
2213
2214
2215
2216
2217
2218
2219
2220
2221
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2211

def initialize(
  update: nil,
  update_discounts: nil,
  update_line_items: nil,
  update_shipping_details: nil
)
  @update = update
  @update_discounts = update_discounts
  @update_line_items = update_line_items
  @update_shipping_details = update_shipping_details
end

Instance Attribute Details

#updateObject

Permissions for updating the Checkout Session.



2193
2194
2195
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2193

def update
  @update
end

#update_discountsObject

Determines which entity is allowed to update the discounts (coupons or promotion codes) that apply to this session.

Default is client_only. Stripe Checkout client will automatically handle discount updates. If set to server_only, only your server is allowed to update discounts.



2197
2198
2199
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2197

def update_discounts
  @update_discounts
end

#update_line_itemsObject

Determines which entity is allowed to update the line items.

Default is client_only. Stripe Checkout client will automatically update the line items. If set to server_only, only your server is allowed to update the line items.

When set to server_only, you must add the onLineItemsChange event handler when initializing the Stripe Checkout client and manually update the line items from your server using the Stripe API.



2203
2204
2205
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2203

def update_line_items
  @update_line_items
end

#update_shipping_detailsObject

Determines which entity is allowed to update the shipping details.

Default is client_only. Stripe Checkout client will automatically update the shipping details. If set to server_only, only your server is allowed to update the shipping details.

When set to server_only, you must add the onShippingDetailsChange event handler when initializing the Stripe Checkout client and manually update the shipping details from your server using the Stripe API.



2209
2210
2211
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2209

def update_shipping_details
  @update_shipping_details
end