Class: Stripe::Checkout::SessionCreateParams::SavedPaymentMethodOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionCreateParams::SavedPaymentMethodOptions
- Defined in:
- lib/stripe/params/checkout/session_create_params.rb
Instance Attribute Summary collapse
-
#allow_redisplay_filters ⇒ Object
Uses the
allow_redisplayvalue of each saved payment method to filter the set presented to a returning customer. -
#payment_method_remove ⇒ Object
Enable customers to choose if they wish to remove their saved payment methods.
-
#payment_method_save ⇒ Object
Enable customers to choose if they wish to save their payment method for future use.
Instance Method Summary collapse
-
#initialize(allow_redisplay_filters: nil, payment_method_remove: nil, payment_method_save: nil) ⇒ SavedPaymentMethodOptions
constructor
A new instance of SavedPaymentMethodOptions.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(allow_redisplay_filters: nil, payment_method_remove: nil, payment_method_save: nil) ⇒ SavedPaymentMethodOptions
Returns a new instance of SavedPaymentMethodOptions.
2120 2121 2122 2123 2124 2125 2126 2127 2128 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2120 def initialize( allow_redisplay_filters: nil, payment_method_remove: nil, payment_method_save: nil ) @allow_redisplay_filters = allow_redisplay_filters @payment_method_remove = payment_method_remove @payment_method_save = payment_method_save end |
Instance Attribute Details
#allow_redisplay_filters ⇒ Object
Uses the allow_redisplay value of each saved payment method to filter the set presented to a returning customer. By default, only saved payment methods with ’allow_redisplay: ‘always’ are shown in Checkout.
2114 2115 2116 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2114 def allow_redisplay_filters @allow_redisplay_filters end |
#payment_method_remove ⇒ Object
Enable customers to choose if they wish to remove their saved payment methods. Disabled by default.
2116 2117 2118 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2116 def payment_method_remove @payment_method_remove end |
#payment_method_save ⇒ Object
Enable customers to choose if they wish to save their payment method for future use. Disabled by default.
2118 2119 2120 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2118 def payment_method_save @payment_method_save end |