Class: Stripe::Checkout::SessionCreateParams::SetupIntentData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(description: nil, metadata: nil, on_behalf_of: nil) ⇒ SetupIntentData

Returns a new instance of SetupIntentData.



2248
2249
2250
2251
2252
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2248

def initialize(description: nil, metadata: nil, on_behalf_of: nil)
  @description = description
  @metadata = 
  @on_behalf_of = on_behalf_of
end

Instance Attribute Details

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



2242
2243
2244
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2242

def description
  @description
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2244
2245
2246
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2244

def 
  @metadata
end

#on_behalf_ofObject

The Stripe account for which the setup is intended.



2246
2247
2248
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2246

def on_behalf_of
  @on_behalf_of
end