Class: Stripe::Checkout::SessionCreateParams::ShippingAddressCollection
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionCreateParams::ShippingAddressCollection
- Defined in:
- lib/stripe/params/checkout/session_create_params.rb
Instance Attribute Summary collapse
-
#allowed_countries ⇒ Object
An array of two-letter ISO country codes representing which countries Checkout should provide as options for shipping locations.
Instance Method Summary collapse
-
#initialize(allowed_countries: nil) ⇒ ShippingAddressCollection
constructor
A new instance of ShippingAddressCollection.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(allowed_countries: nil) ⇒ ShippingAddressCollection
Returns a new instance of ShippingAddressCollection.
2051 2052 2053 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2051 def initialize(allowed_countries: nil) @allowed_countries = allowed_countries end |
Instance Attribute Details
#allowed_countries ⇒ Object
An array of two-letter ISO country codes representing which countries Checkout should provide as options for shipping locations.
2049 2050 2051 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2049 def allowed_countries @allowed_countries end |