Class: Stripe::Checkout::SessionCreateParams::ShippingOption::ShippingRateData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionCreateParams::ShippingOption::ShippingRateData
- Defined in:
- lib/stripe/params/checkout/session_create_params.rb
Defined Under Namespace
Classes: DeliveryEstimate, FixedAmount
Instance Attribute Summary collapse
-
#delivery_estimate ⇒ Object
The estimated range for how long shipping will take, meant to be displayable to the customer.
-
#display_name ⇒ Object
The name of the shipping rate, meant to be displayable to the customer.
-
#fixed_amount ⇒ Object
Describes a fixed amount to charge for shipping.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#tax_behavior ⇒ Object
Specifies whether the rate is considered inclusive of taxes or exclusive of taxes.
-
#tax_code ⇒ Object
A tax code ID.
-
#type ⇒ Object
The type of calculation to use on the shipping rate.
Instance Method Summary collapse
-
#initialize(delivery_estimate: nil, display_name: nil, fixed_amount: nil, metadata: nil, tax_behavior: nil, tax_code: nil, type: nil) ⇒ ShippingRateData
constructor
A new instance of ShippingRateData.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(delivery_estimate: nil, display_name: nil, fixed_amount: nil, metadata: nil, tax_behavior: nil, tax_code: nil, type: nil) ⇒ ShippingRateData
Returns a new instance of ShippingRateData.
2279 2280 2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 2294 2295 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2279 def initialize( delivery_estimate: nil, display_name: nil, fixed_amount: nil, metadata: nil, tax_behavior: nil, tax_code: nil, type: nil ) @delivery_estimate = delivery_estimate @display_name = display_name @fixed_amount = fixed_amount = @tax_behavior = tax_behavior @tax_code = tax_code @type = type end |
Instance Attribute Details
#delivery_estimate ⇒ Object
The estimated range for how long shipping will take, meant to be displayable to the customer. This will appear on CheckoutSessions.
2265 2266 2267 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2265 def delivery_estimate @delivery_estimate end |
#display_name ⇒ Object
The name of the shipping rate, meant to be displayable to the customer. This will appear on CheckoutSessions.
2267 2268 2269 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2267 def display_name @display_name end |
#fixed_amount ⇒ Object
Describes a fixed amount to charge for shipping. Must be present if type is fixed_amount.
2269 2270 2271 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2269 def fixed_amount @fixed_amount end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
2271 2272 2273 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2271 def end |
#tax_behavior ⇒ Object
Specifies whether the rate is considered inclusive of taxes or exclusive of taxes. One of inclusive, exclusive, or unspecified.
2273 2274 2275 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2273 def tax_behavior @tax_behavior end |
#tax_code ⇒ Object
A tax code ID. The Shipping tax code is txcd_92010001.
2275 2276 2277 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2275 def tax_code @tax_code end |
#type ⇒ Object
The type of calculation to use on the shipping rate.
2277 2278 2279 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2277 def type @type end |