Class: Stripe::Checkout::SessionCreateParams::ShippingOption::ShippingRateData::FixedAmount::CurrencyOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, tax_behavior: nil) ⇒ CurrencyOptions

Returns a new instance of CurrencyOptions.



2378
2379
2380
2381
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2378

def initialize(amount: nil, tax_behavior: nil)
  @amount = amount
  @tax_behavior = tax_behavior
end

Instance Attribute Details

#amountObject

A non-negative integer in cents representing how much to charge.



2374
2375
2376
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2374

def amount
  @amount
end

#tax_behaviorObject

Specifies whether the rate is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`.



2376
2377
2378
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2376

def tax_behavior
  @tax_behavior
end