Class: Stripe::Checkout::SessionCreateParams::SubscriptionData::BillingCycleAnchorConfig

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ BillingCycleAnchorConfig

Returns a new instance of BillingCycleAnchorConfig.



2788
2789
2790
2791
2792
2793
2794
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2788

def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil)
  @day_of_month = day_of_month
  @hour = hour
  @minute = minute
  @month = month
  @second = second
end

Instance Attribute Details

#day_of_monthObject

The day of the month the anchor should be. Ranges from 1 to 31.



2778
2779
2780
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2778

def day_of_month
  @day_of_month
end

#hourObject

The hour of the day the anchor should be. Ranges from 0 to 23.



2780
2781
2782
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2780

def hour
  @hour
end

#minuteObject

The minute of the hour the anchor should be. Ranges from 0 to 59.



2782
2783
2784
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2782

def minute
  @minute
end

#monthObject

The month to start full cycle periods. Ranges from 1 to 12.



2784
2785
2786
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2784

def month
  @month
end

#secondObject

The second of the minute the anchor should be. Ranges from 0 to 59.



2786
2787
2788
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2786

def second
  @second
end