Class: Stripe::Checkout::SessionCreateParams::SubscriptionData::BillingMode

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Defined Under Namespace

Classes: Flexible

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(flexible: nil, type: nil) ⇒ BillingMode

Returns a new instance of BillingMode.



2177
2178
2179
2180
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2177

def initialize(flexible: nil, type: nil)
  @flexible = flexible
  @type = type
end

Instance Attribute Details

#flexibleObject

Configure behavior for flexible billing mode.



2173
2174
2175
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2173

def flexible
  @flexible
end

#typeObject

Controls the calculation and orchestration of prorations and invoices for subscriptions. If no value is passed, the default is flexible.



2175
2176
2177
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2175

def type
  @type
end