Class: Stripe::Checkout::SessionService::CreateParams::AutomaticTax

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/checkout/session_service.rb

Defined Under Namespace

Classes: Liability

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(enabled: nil, liability: nil) ⇒ AutomaticTax

Returns a new instance of AutomaticTax.



142
143
144
145
# File 'lib/stripe/services/checkout/session_service.rb', line 142

def initialize(enabled: nil, liability: nil)
  @enabled = enabled
  @liability = liability
end

Instance Attribute Details

#enabledObject

Set to ‘true` to [calculate tax automatically](docs.stripe.com/tax) using the customer’s location.

Enabling this parameter causes Checkout to collect any billing address information necessary for tax calculation.



138
139
140
# File 'lib/stripe/services/checkout/session_service.rb', line 138

def enabled
  @enabled
end

#liabilityObject

The account that’s liable for tax. If set, the business address and tax registrations required to perform the tax calculation are loaded from this account. The tax transaction is returned in the report of the connected account.



140
141
142
# File 'lib/stripe/services/checkout/session_service.rb', line 140

def liability
  @liability
end