Class: Stripe::Checkout::SessionService::CreateParams::CustomField::Label
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionService::CreateParams::CustomField::Label
- Defined in:
- lib/stripe/services/checkout/session_service.rb
Instance Attribute Summary collapse
-
#custom ⇒ Object
Custom text for the label, displayed to the customer.
-
#type ⇒ Object
The type of the label.
Instance Method Summary collapse
-
#initialize(custom: nil, type: nil) ⇒ Label
constructor
A new instance of Label.
Methods inherited from RequestParams
Constructor Details
#initialize(custom: nil, type: nil) ⇒ Label
Returns a new instance of Label.
288 289 290 291 |
# File 'lib/stripe/services/checkout/session_service.rb', line 288 def initialize(custom: nil, type: nil) @custom = custom @type = type end |
Instance Attribute Details
#custom ⇒ Object
Custom text for the label, displayed to the customer. Up to 50 characters.
284 285 286 |
# File 'lib/stripe/services/checkout/session_service.rb', line 284 def custom @custom end |
#type ⇒ Object
The type of the label.
286 287 288 |
# File 'lib/stripe/services/checkout/session_service.rb', line 286 def type @type end |