Class: Stripe::Checkout::SessionService::CreateParams::CustomText

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/checkout/session_service.rb

Defined Under Namespace

Classes: AfterSubmit, ShippingAddress, Submit, TermsOfServiceAcceptance

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(after_submit: nil, shipping_address: nil, submit: nil, terms_of_service_acceptance: nil) ⇒ CustomText

Returns a new instance of CustomText.



402
403
404
405
406
407
408
409
410
411
412
# File 'lib/stripe/services/checkout/session_service.rb', line 402

def initialize(
  after_submit: nil,
  shipping_address: nil,
  submit: nil,
  terms_of_service_acceptance: nil
)
  @after_submit = after_submit
  @shipping_address = shipping_address
  @submit = submit
  @terms_of_service_acceptance = terms_of_service_acceptance
end

Instance Attribute Details

#after_submitObject

Custom text that should be displayed after the payment confirmation button.



394
395
396
# File 'lib/stripe/services/checkout/session_service.rb', line 394

def after_submit
  @after_submit
end

#shipping_addressObject

Custom text that should be displayed alongside shipping address collection.



396
397
398
# File 'lib/stripe/services/checkout/session_service.rb', line 396

def shipping_address
  @shipping_address
end

#submitObject

Custom text that should be displayed alongside the payment confirmation button.



398
399
400
# File 'lib/stripe/services/checkout/session_service.rb', line 398

def submit
  @submit
end

#terms_of_service_acceptanceObject

Custom text that should be displayed in place of the default terms of service agreement text.



400
401
402
# File 'lib/stripe/services/checkout/session_service.rb', line 400

def terms_of_service_acceptance
  @terms_of_service_acceptance
end