Class: Stripe::Checkout::SessionService::CreateParams::CustomerUpdate
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionService::CreateParams::CustomerUpdate
- Defined in:
- lib/stripe/services/checkout/session_service.rb
Instance Attribute Summary collapse
-
#address ⇒ Object
Describes whether Checkout saves the billing address onto ‘customer.address`.
-
#name ⇒ Object
Describes whether Checkout saves the name onto ‘customer.name`.
-
#shipping ⇒ Object
Describes whether Checkout saves shipping information onto ‘customer.shipping`.
Instance Method Summary collapse
-
#initialize(address: nil, name: nil, shipping: nil) ⇒ CustomerUpdate
constructor
A new instance of CustomerUpdate.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, name: nil, shipping: nil) ⇒ CustomerUpdate
Returns a new instance of CustomerUpdate.
350 351 352 353 354 |
# File 'lib/stripe/services/checkout/session_service.rb', line 350 def initialize(address: nil, name: nil, shipping: nil) @address = address @name = name @shipping = shipping end |
Instance Attribute Details
#address ⇒ Object
Describes whether Checkout saves the billing address onto ‘customer.address`. To always collect a full billing address, use `billing_address_collection`. Defaults to `never`.
343 344 345 |
# File 'lib/stripe/services/checkout/session_service.rb', line 343 def address @address end |
#name ⇒ Object
Describes whether Checkout saves the name onto ‘customer.name`. Defaults to `never`.
345 346 347 |
# File 'lib/stripe/services/checkout/session_service.rb', line 345 def name @name end |
#shipping ⇒ Object
Describes whether Checkout saves shipping information onto ‘customer.shipping`. To collect shipping information, use `shipping_address_collection`. Defaults to `never`.
348 349 350 |
# File 'lib/stripe/services/checkout/session_service.rb', line 348 def shipping @shipping end |