Class: Stripe::Checkout::SessionService::CreateParams::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/checkout/session_service.rb

Defined Under Namespace

Classes: CouponData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, coupon_data: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



470
471
472
473
474
# File 'lib/stripe/services/checkout/session_service.rb', line 470

def initialize(coupon: nil, coupon_data: nil, promotion_code: nil)
  @coupon = coupon
  @coupon_data = coupon_data
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The ID of the coupon to apply to this Session.



464
465
466
# File 'lib/stripe/services/checkout/session_service.rb', line 464

def coupon
  @coupon
end

#coupon_dataObject

Data used to generate a new [Coupon](stripe.com/docs/api/coupon) object inline. One of ‘coupon` or `coupon_data` is required when updating discounts.



466
467
468
# File 'lib/stripe/services/checkout/session_service.rb', line 466

def coupon_data
  @coupon_data
end

#promotion_codeObject

The ID of a promotion code to apply to this Session.



468
469
470
# File 'lib/stripe/services/checkout/session_service.rb', line 468

def promotion_code
  @promotion_code
end