Class: Stripe::Checkout::SessionService::CreateParams::InvoiceCreation::InvoiceData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/checkout/session_service.rb

Defined Under Namespace

Classes: CustomField, Issuer, RenderingOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_tax_ids: nil, custom_fields: nil, description: nil, footer: nil, issuer: nil, metadata: nil, rendering_options: nil) ⇒ InvoiceData

Returns a new instance of InvoiceData.



459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
# File 'lib/stripe/services/checkout/session_service.rb', line 459

def initialize(
  account_tax_ids: nil,
  custom_fields: nil,
  description: nil,
  footer: nil,
  issuer: nil,
  metadata: nil,
  rendering_options: nil
)
  @account_tax_ids = 
  @custom_fields = custom_fields
  @description = description
  @footer = footer
  @issuer = issuer
  @metadata = 
  @rendering_options = rendering_options
end

Instance Attribute Details

#account_tax_idsObject

The account tax IDs associated with the invoice.



439
440
441
# File 'lib/stripe/services/checkout/session_service.rb', line 439

def 
  @account_tax_ids
end

#custom_fieldsObject

Default custom fields to be displayed on invoices for this customer.



442
443
444
# File 'lib/stripe/services/checkout/session_service.rb', line 442

def custom_fields
  @custom_fields
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



445
446
447
# File 'lib/stripe/services/checkout/session_service.rb', line 445

def description
  @description
end

Default footer to be displayed on invoices for this customer.



448
449
450
# File 'lib/stripe/services/checkout/session_service.rb', line 448

def footer
  @footer
end

#issuerObject

The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.



451
452
453
# File 'lib/stripe/services/checkout/session_service.rb', line 451

def issuer
  @issuer
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



454
455
456
# File 'lib/stripe/services/checkout/session_service.rb', line 454

def 
  @metadata
end

#rendering_optionsObject

Default options for invoice PDF rendering for this customer.



457
458
459
# File 'lib/stripe/services/checkout/session_service.rb', line 457

def rendering_options
  @rendering_options
end