Class: Stripe::Checkout::SessionService::CreateParams::LineItem::PriceData::ProductData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/checkout/session_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil) ⇒ ProductData

Returns a new instance of ProductData.



587
588
589
590
591
592
593
# File 'lib/stripe/services/checkout/session_service.rb', line 587

def initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil)
  @description = description
  @images = images
  @metadata = 
  @name = name
  @tax_code = tax_code
end

Instance Attribute Details

#descriptionObject

The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.



577
578
579
# File 'lib/stripe/services/checkout/session_service.rb', line 577

def description
  @description
end

#imagesObject

A list of up to 8 URLs of images for this product, meant to be displayable to the customer.



579
580
581
# File 'lib/stripe/services/checkout/session_service.rb', line 579

def images
  @images
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



581
582
583
# File 'lib/stripe/services/checkout/session_service.rb', line 581

def 
  @metadata
end

#nameObject

The product’s name, meant to be displayable to the customer.



583
584
585
# File 'lib/stripe/services/checkout/session_service.rb', line 583

def name
  @name
end

#tax_codeObject



585
586
587
# File 'lib/stripe/services/checkout/session_service.rb', line 585

def tax_code
  @tax_code
end