Class: Stripe::Checkout::SessionService::CreateParams::OptionalItem::AdjustableQuantity

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/checkout/session_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(enabled: nil, maximum: nil, minimum: nil) ⇒ AdjustableQuantity

Returns a new instance of AdjustableQuantity.



683
684
685
686
687
# File 'lib/stripe/services/checkout/session_service.rb', line 683

def initialize(enabled: nil, maximum: nil, minimum: nil)
  @enabled = enabled
  @maximum = maximum
  @minimum = minimum
end

Instance Attribute Details

#enabledObject

Set to true if the quantity can be adjusted to any non-negative integer.



677
678
679
# File 'lib/stripe/services/checkout/session_service.rb', line 677

def enabled
  @enabled
end

#maximumObject

The maximum quantity of this item the customer can purchase. By default this value is 99. You can specify a value up to 999999.



679
680
681
# File 'lib/stripe/services/checkout/session_service.rb', line 679

def maximum
  @maximum
end

#minimumObject

The minimum quantity of this item the customer must purchase, if they choose to purchase it. Because this item is optional, the customer will always be able to remove it from their order, even if the ‘minimum` configured here is greater than 0. By default this value is 0.



681
682
683
# File 'lib/stripe/services/checkout/session_service.rb', line 681

def minimum
  @minimum
end