Class: Stripe::Checkout::SessionService::CreateParams::PaymentIntentData::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/checkout/session_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



648
649
650
651
# File 'lib/stripe/services/checkout/session_service.rb', line 648

def initialize(amount: nil, destination: nil)
  @amount = amount
  @destination = destination
end

Instance Attribute Details

#amountObject

The amount that will be transferred automatically when a charge succeeds.



641
642
643
# File 'lib/stripe/services/checkout/session_service.rb', line 641

def amount
  @amount
end

#destinationObject

If specified, successful charges will be attributed to the destination account for tax reporting, and the funds from charges will be transferred to the destination account. The ID of the resulting transfer will be returned on the successful charge’s ‘transfer` field.



646
647
648
# File 'lib/stripe/services/checkout/session_service.rb', line 646

def destination
  @destination
end