Class: Stripe::Checkout::SessionService::CreateParams::PaymentMethodOptions::AcssDebit

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/checkout/session_service.rb

Defined Under Namespace

Classes: MandateOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(currency: nil, mandate_options: nil, setup_future_usage: nil, verification_method: nil) ⇒ AcssDebit

Returns a new instance of AcssDebit.



850
851
852
853
854
855
856
857
858
859
860
# File 'lib/stripe/services/checkout/session_service.rb', line 850

def initialize(
  currency: nil,
  mandate_options: nil,
  setup_future_usage: nil,
  verification_method: nil
)
  @currency = currency
  @mandate_options = mandate_options
  @setup_future_usage = setup_future_usage
  @verification_method = verification_method
end

Instance Attribute Details

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies). This is only accepted for Checkout Sessions in ‘setup` mode.



833
834
835
# File 'lib/stripe/services/checkout/session_service.rb', line 833

def currency
  @currency
end

#mandate_optionsObject

Additional fields for Mandate creation



836
837
838
# File 'lib/stripe/services/checkout/session_service.rb', line 836

def mandate_options
  @mandate_options
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent’s payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.

If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.

When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).



845
846
847
# File 'lib/stripe/services/checkout/session_service.rb', line 845

def setup_future_usage
  @setup_future_usage
end

#verification_methodObject

Verification method for the intent



848
849
850
# File 'lib/stripe/services/checkout/session_service.rb', line 848

def verification_method
  @verification_method
end