Class: Stripe::Checkout::SessionService::CreateParams::PaymentMethodOptions::AcssDebit::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/checkout/session_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(custom_mandate_url: nil, default_for: nil, interval_description: nil, payment_schedule: nil, transaction_type: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



753
754
755
756
757
758
759
760
761
762
763
764
765
# File 'lib/stripe/services/checkout/session_service.rb', line 753

def initialize(
  custom_mandate_url: nil,
  default_for: nil,
  interval_description: nil,
  payment_schedule: nil,
  transaction_type: nil
)
  @custom_mandate_url = custom_mandate_url
  @default_for = default_for
  @interval_description = interval_description
  @payment_schedule = payment_schedule
  @transaction_type = transaction_type
end

Instance Attribute Details

#custom_mandate_urlObject

A URL for custom mandate text to render during confirmation step. The URL will be rendered with additional GET parameters ‘payment_intent` and `payment_intent_client_secret` when confirming a Payment Intent, or `setup_intent` and `setup_intent_client_secret` when confirming a Setup Intent.



743
744
745
# File 'lib/stripe/services/checkout/session_service.rb', line 743

def custom_mandate_url
  @custom_mandate_url
end

#default_forObject

List of Stripe products where this mandate can be selected automatically. Only usable in ‘setup` mode.



745
746
747
# File 'lib/stripe/services/checkout/session_service.rb', line 745

def default_for
  @default_for
end

#interval_descriptionObject

Description of the mandate interval. Only required if ‘payment_schedule’ parameter is ‘interval’ or ‘combined’.



747
748
749
# File 'lib/stripe/services/checkout/session_service.rb', line 747

def interval_description
  @interval_description
end

#payment_scheduleObject

Payment schedule for the mandate.



749
750
751
# File 'lib/stripe/services/checkout/session_service.rb', line 749

def payment_schedule
  @payment_schedule
end

#transaction_typeObject

Transaction type of the mandate.



751
752
753
# File 'lib/stripe/services/checkout/session_service.rb', line 751

def transaction_type
  @transaction_type
end