Class: Stripe::Checkout::SessionService::CreateParams::PaymentMethodOptions::Card
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionService::CreateParams::PaymentMethodOptions::Card
- Defined in:
- lib/stripe/services/checkout/session_service.rb
Defined Under Namespace
Classes: Installments, Restrictions
Instance Attribute Summary collapse
-
#installments ⇒ Object
Installment options for card payments.
-
#request_decremental_authorization ⇒ Object
Request ability to [capture beyond the standard authorization validity window](/payments/extended-authorization) for this CheckoutSession.
-
#request_extended_authorization ⇒ Object
Request ability to [capture beyond the standard authorization validity window](/payments/extended-authorization) for this CheckoutSession.
-
#request_incremental_authorization ⇒ Object
Request ability to [increment the authorization](/payments/incremental-authorization) for this CheckoutSession.
-
#request_multicapture ⇒ Object
Request ability to make [multiple captures](/payments/multicapture) for this CheckoutSession.
-
#request_overcapture ⇒ Object
Request ability to [overcapture](/payments/overcapture) for this CheckoutSession.
-
#request_three_d_secure ⇒ Object
We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and [other requirements](stripe.com/docs/strong-customer-authentication).
-
#restrictions ⇒ Object
Restrictions to apply to the card payment method.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
-
#statement_descriptor_suffix_kana ⇒ Object
Provides information about a card payment that customers see on their statements.
-
#statement_descriptor_suffix_kanji ⇒ Object
Provides information about a card payment that customers see on their statements.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(installments: nil, request_decremental_authorization: nil, request_extended_authorization: nil, request_incremental_authorization: nil, request_multicapture: nil, request_overcapture: nil, request_three_d_secure: nil, restrictions: nil, setup_future_usage: nil, statement_descriptor_suffix_kana: nil, statement_descriptor_suffix_kanji: nil) ⇒ Card
Returns a new instance of Card.
1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 |
# File 'lib/stripe/services/checkout/session_service.rb', line 1106 def initialize( installments: nil, request_decremental_authorization: nil, request_extended_authorization: nil, request_incremental_authorization: nil, request_multicapture: nil, request_overcapture: nil, request_three_d_secure: nil, restrictions: nil, setup_future_usage: nil, statement_descriptor_suffix_kana: nil, statement_descriptor_suffix_kanji: nil ) @installments = installments @request_decremental_authorization = @request_extended_authorization = @request_incremental_authorization = @request_multicapture = request_multicapture @request_overcapture = request_overcapture @request_three_d_secure = request_three_d_secure @restrictions = restrictions @setup_future_usage = setup_future_usage @statement_descriptor_suffix_kana = statement_descriptor_suffix_kana @statement_descriptor_suffix_kanji = statement_descriptor_suffix_kanji end |
Instance Attribute Details
#installments ⇒ Object
Installment options for card payments
1078 1079 1080 |
# File 'lib/stripe/services/checkout/session_service.rb', line 1078 def installments @installments end |
#request_decremental_authorization ⇒ Object
Request ability to [capture beyond the standard authorization validity window](/payments/extended-authorization) for this CheckoutSession.
1080 1081 1082 |
# File 'lib/stripe/services/checkout/session_service.rb', line 1080 def @request_decremental_authorization end |
#request_extended_authorization ⇒ Object
Request ability to [capture beyond the standard authorization validity window](/payments/extended-authorization) for this CheckoutSession.
1082 1083 1084 |
# File 'lib/stripe/services/checkout/session_service.rb', line 1082 def @request_extended_authorization end |
#request_incremental_authorization ⇒ Object
Request ability to [increment the authorization](/payments/incremental-authorization) for this CheckoutSession.
1084 1085 1086 |
# File 'lib/stripe/services/checkout/session_service.rb', line 1084 def @request_incremental_authorization end |
#request_multicapture ⇒ Object
Request ability to make [multiple captures](/payments/multicapture) for this CheckoutSession.
1086 1087 1088 |
# File 'lib/stripe/services/checkout/session_service.rb', line 1086 def request_multicapture @request_multicapture end |
#request_overcapture ⇒ Object
Request ability to [overcapture](/payments/overcapture) for this CheckoutSession.
1088 1089 1090 |
# File 'lib/stripe/services/checkout/session_service.rb', line 1088 def request_overcapture @request_overcapture end |
#request_three_d_secure ⇒ Object
We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and [other requirements](stripe.com/docs/strong-customer-authentication). However, if you wish to request 3D Secure based on logic from your own fraud engine, provide this option. If not provided, this value defaults to ‘automatic`. Read our guide on [manually requesting 3D Secure](stripe.com/docs/payments/3d-secure/authentication-flow#manual-three-ds) for more information on how this configuration interacts with Radar and our SCA Engine.
1090 1091 1092 |
# File 'lib/stripe/services/checkout/session_service.rb', line 1090 def request_three_d_secure @request_three_d_secure end |
#restrictions ⇒ Object
Restrictions to apply to the card payment method. For example, you can block specific card brands.
1092 1093 1094 |
# File 'lib/stripe/services/checkout/session_service.rb', line 1092 def restrictions @restrictions end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.
If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.
When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).
1100 1101 1102 |
# File 'lib/stripe/services/checkout/session_service.rb', line 1100 def setup_future_usage @setup_future_usage end |
#statement_descriptor_suffix_kana ⇒ Object
Provides information about a card payment that customers see on their statements. Concatenated with the Kana prefix (shortened Kana descriptor) or Kana statement descriptor that’s set on the account to form the complete statement descriptor. Maximum 22 characters. On card statements, the concatenation of both prefix and suffix (including separators) will appear truncated to 22 characters.
1102 1103 1104 |
# File 'lib/stripe/services/checkout/session_service.rb', line 1102 def statement_descriptor_suffix_kana @statement_descriptor_suffix_kana end |
#statement_descriptor_suffix_kanji ⇒ Object
Provides information about a card payment that customers see on their statements. Concatenated with the Kanji prefix (shortened Kanji descriptor) or Kanji statement descriptor that’s set on the account to form the complete statement descriptor. Maximum 17 characters. On card statements, the concatenation of both prefix and suffix (including separators) will appear truncated to 17 characters.
1104 1105 1106 |
# File 'lib/stripe/services/checkout/session_service.rb', line 1104 def statement_descriptor_suffix_kanji @statement_descriptor_suffix_kanji end |