Class: Stripe::Checkout::SessionService::CreateParams::PaymentMethodOptions::Card::Installments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/checkout/session_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(enabled: nil) ⇒ Installments

Returns a new instance of Installments.



956
957
958
# File 'lib/stripe/services/checkout/session_service.rb', line 956

def initialize(enabled: nil)
  @enabled = enabled
end

Instance Attribute Details

#enabledObject

Setting to true enables installments for this Checkout Session. Setting to false will prevent any installment plan from applying to a payment.



954
955
956
# File 'lib/stripe/services/checkout/session_service.rb', line 954

def enabled
  @enabled
end