Class: Stripe::Checkout::SessionService::CreateParams::PaymentMethodOptions::CustomerBalance::BankTransfer::EuBankTransfer
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionService::CreateParams::PaymentMethodOptions::CustomerBalance::BankTransfer::EuBankTransfer
- Defined in:
- lib/stripe/services/checkout/session_service.rb
Instance Attribute Summary collapse
-
#country ⇒ Object
The desired country code of the bank account information.
Instance Method Summary collapse
-
#initialize(country: nil) ⇒ EuBankTransfer
constructor
A new instance of EuBankTransfer.
Methods inherited from RequestParams
Constructor Details
#initialize(country: nil) ⇒ EuBankTransfer
Returns a new instance of EuBankTransfer.
987 988 989 |
# File 'lib/stripe/services/checkout/session_service.rb', line 987 def initialize(country: nil) @country = country end |
Instance Attribute Details
#country ⇒ Object
The desired country code of the bank account information. Permitted values include: ‘BE`, `DE`, `ES`, `FR`, `IE`, or `NL`.
985 986 987 |
# File 'lib/stripe/services/checkout/session_service.rb', line 985 def country @country end |