Class: Stripe::Checkout::SessionService::CreateParams::PaymentMethodOptions::Pix
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionService::CreateParams::PaymentMethodOptions::Pix
- Defined in:
- lib/stripe/services/checkout/session_service.rb
Instance Attribute Summary collapse
-
#expires_after_seconds ⇒ Object
The number of seconds (between 10 and 1209600) after which Pix payment will expire.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
Instance Method Summary collapse
-
#initialize(expires_after_seconds: nil, setup_future_usage: nil) ⇒ Pix
constructor
A new instance of Pix.
Methods inherited from RequestParams
Constructor Details
#initialize(expires_after_seconds: nil, setup_future_usage: nil) ⇒ Pix
Returns a new instance of Pix.
1501 1502 1503 1504 |
# File 'lib/stripe/services/checkout/session_service.rb', line 1501 def initialize(expires_after_seconds: nil, setup_future_usage: nil) @expires_after_seconds = expires_after_seconds @setup_future_usage = setup_future_usage end |
Instance Attribute Details
#expires_after_seconds ⇒ Object
The number of seconds (between 10 and 1209600) after which Pix payment will expire. Defaults to 86400 seconds.
1491 1492 1493 |
# File 'lib/stripe/services/checkout/session_service.rb', line 1491 def expires_after_seconds @expires_after_seconds end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.
If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.
When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).
1499 1500 1501 |
# File 'lib/stripe/services/checkout/session_service.rb', line 1499 def setup_future_usage @setup_future_usage end |