Class: Stripe::Checkout::SessionService::CreateParams::PaymentMethodOptions::SamsungPay
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionService::CreateParams::PaymentMethodOptions::SamsungPay
- Defined in:
- lib/stripe/services/checkout/session_service.rb
Instance Attribute Summary collapse
-
#capture_method ⇒ Object
Controls when the funds will be captured from the customer’s account.
Instance Method Summary collapse
-
#initialize(capture_method: nil) ⇒ SamsungPay
constructor
A new instance of SamsungPay.
Methods inherited from RequestParams
Constructor Details
#initialize(capture_method: nil) ⇒ SamsungPay
Returns a new instance of SamsungPay.
1543 1544 1545 |
# File 'lib/stripe/services/checkout/session_service.rb', line 1543 def initialize(capture_method: nil) @capture_method = capture_method end |
Instance Attribute Details
#capture_method ⇒ Object
Controls when the funds will be captured from the customer’s account.
1541 1542 1543 |
# File 'lib/stripe/services/checkout/session_service.rb', line 1541 def capture_method @capture_method end |