Class: Stripe::Checkout::SessionService::CreateParams::PaymentMethodOptions::SepaDebit
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionService::CreateParams::PaymentMethodOptions::SepaDebit
- Defined in:
- lib/stripe/services/checkout/session_service.rb
Defined Under Namespace
Classes: MandateOptions
Instance Attribute Summary collapse
-
#mandate_options ⇒ Object
Additional fields for Mandate creation.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
Instance Method Summary collapse
-
#initialize(mandate_options: nil, setup_future_usage: nil) ⇒ SepaDebit
constructor
A new instance of SepaDebit.
Methods inherited from RequestParams
Constructor Details
#initialize(mandate_options: nil, setup_future_usage: nil) ⇒ SepaDebit
Returns a new instance of SepaDebit.
1441 1442 1443 1444 |
# File 'lib/stripe/services/checkout/session_service.rb', line 1441 def initialize(mandate_options: nil, setup_future_usage: nil) @mandate_options = @setup_future_usage = setup_future_usage end |
Instance Attribute Details
#mandate_options ⇒ Object
Additional fields for Mandate creation
1431 1432 1433 |
# File 'lib/stripe/services/checkout/session_service.rb', line 1431 def @mandate_options end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.
If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.
When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).
1439 1440 1441 |
# File 'lib/stripe/services/checkout/session_service.rb', line 1439 def setup_future_usage @setup_future_usage end |