Class: Stripe::Checkout::SessionService::CreateParams::Permissions::Update

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/checkout/session_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(line_items: nil, shipping_details: nil) ⇒ Update

Returns a new instance of Update.



1741
1742
1743
1744
# File 'lib/stripe/services/checkout/session_service.rb', line 1741

def initialize(line_items: nil, shipping_details: nil)
  @line_items = line_items
  @shipping_details = shipping_details
end

Instance Attribute Details

#line_itemsObject

Determines which entity is allowed to update the line items.

Default is ‘client_only`. Stripe Checkout client will automatically update the line items. If set to `server_only`, only your server is allowed to update the line items.

When set to ‘server_only`, you must add the onLineItemsChange event handler when initializing the Stripe Checkout client and manually update the line items from your server using the Stripe API.



1733
1734
1735
# File 'lib/stripe/services/checkout/session_service.rb', line 1733

def line_items
  @line_items
end

#shipping_detailsObject

Determines which entity is allowed to update the shipping details.

Default is ‘client_only`. Stripe Checkout client will automatically update the shipping details. If set to `server_only`, only your server is allowed to update the shipping details.

When set to ‘server_only`, you must add the onShippingDetailsChange event handler when initializing the Stripe Checkout client and manually update the shipping details from your server using the Stripe API.



1739
1740
1741
# File 'lib/stripe/services/checkout/session_service.rb', line 1739

def shipping_details
  @shipping_details
end