Class: Stripe::Checkout::SessionService::CreateParams::SavedPaymentMethodOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/checkout/session_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(allow_redisplay_filters: nil, payment_method_remove: nil, payment_method_save: nil) ⇒ SavedPaymentMethodOptions

Returns a new instance of SavedPaymentMethodOptions.



2038
2039
2040
2041
2042
2043
2044
2045
2046
# File 'lib/stripe/services/checkout/session_service.rb', line 2038

def initialize(
  allow_redisplay_filters: nil,
  payment_method_remove: nil,
  payment_method_save: nil
)
  @allow_redisplay_filters = allow_redisplay_filters
  @payment_method_remove = payment_method_remove
  @payment_method_save = payment_method_save
end

Instance Attribute Details

#allow_redisplay_filtersObject

Uses the ‘allow_redisplay` value of each saved payment method to filter the set presented to a returning customer. By default, only saved payment methods with ’allow_redisplay: ‘always’ are shown in Checkout.



2032
2033
2034
# File 'lib/stripe/services/checkout/session_service.rb', line 2032

def allow_redisplay_filters
  @allow_redisplay_filters
end

#payment_method_removeObject

Enable customers to choose if they wish to remove their saved payment methods. Disabled by default.



2034
2035
2036
# File 'lib/stripe/services/checkout/session_service.rb', line 2034

def payment_method_remove
  @payment_method_remove
end

#payment_method_saveObject

Enable customers to choose if they wish to save their payment method for future use. Disabled by default.



2036
2037
2038
# File 'lib/stripe/services/checkout/session_service.rb', line 2036

def payment_method_save
  @payment_method_save
end