Class: Stripe::Checkout::SessionService::CreateParams::SubscriptionData::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/checkout/session_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_percent: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



2216
2217
2218
2219
# File 'lib/stripe/services/checkout/session_service.rb', line 2216

def initialize(amount_percent: nil, destination: nil)
  @amount_percent = amount_percent
  @destination = destination
end

Instance Attribute Details

#amount_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination.



2212
2213
2214
# File 'lib/stripe/services/checkout/session_service.rb', line 2212

def amount_percent
  @amount_percent
end

#destinationObject

ID of an existing, connected Stripe account.



2214
2215
2216
# File 'lib/stripe/services/checkout/session_service.rb', line 2214

def destination
  @destination
end