Class: Stripe::Checkout::SessionService::CreateParams::SubscriptionData::TrialSettings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionService::CreateParams::SubscriptionData::TrialSettings
- Defined in:
- lib/stripe/services/checkout/session_service.rb
Defined Under Namespace
Classes: EndBehavior
Instance Attribute Summary collapse
-
#end_behavior ⇒ Object
Defines how the subscription should behave when the user’s free trial ends.
Instance Method Summary collapse
-
#initialize(end_behavior: nil) ⇒ TrialSettings
constructor
A new instance of TrialSettings.
Methods inherited from RequestParams
Constructor Details
#initialize(end_behavior: nil) ⇒ TrialSettings
Returns a new instance of TrialSettings.
2006 2007 2008 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2006 def initialize(end_behavior: nil) @end_behavior = end_behavior end |
Instance Attribute Details
#end_behavior ⇒ Object
Defines how the subscription should behave when the user’s free trial ends.
2004 2005 2006 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2004 def end_behavior @end_behavior end |