Class: Stripe::Checkout::SessionService::CreateParams::WalletOptions::Link

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/checkout/session_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(display: nil) ⇒ Link

Returns a new instance of Link.



2138
2139
2140
# File 'lib/stripe/services/checkout/session_service.rb', line 2138

def initialize(display: nil)
  @display = display
end

Instance Attribute Details

#displayObject

Specifies whether Checkout should display Link as a payment option. By default, Checkout will display all the supported wallets that the Checkout Session was created with. This is the ‘auto` behavior, and it is the default choice.



2136
2137
2138
# File 'lib/stripe/services/checkout/session_service.rb', line 2136

def display
  @display
end