Class: Stripe::Checkout::SessionService::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionService::ListParams
- Defined in:
- lib/stripe/services/checkout/session_service.rb
Defined Under Namespace
Classes: Created, CustomerDetails
Instance Attribute Summary collapse
-
#created ⇒ Object
Only return Checkout Sessions that were created during the given date interval.
-
#customer ⇒ Object
Only return the Checkout Sessions for the Customer specified.
-
#customer_account ⇒ Object
Only return the Checkout Sessions for the Account specified.
-
#customer_details ⇒ Object
Only return the Checkout Sessions for the Customer details specified.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#payment_intent ⇒ Object
Only return the Checkout Session for the PaymentIntent specified.
-
#payment_link ⇒ Object
Only return the Checkout Sessions for the Payment Link specified.
-
#starting_after ⇒ Object
A cursor for use in pagination.
-
#status ⇒ Object
Only return the Checkout Sessions matching the given status.
-
#subscription ⇒ Object
Only return the Checkout Session for the subscription specified.
Instance Method Summary collapse
-
#initialize(created: nil, customer: nil, customer_account: nil, customer_details: nil, ending_before: nil, expand: nil, limit: nil, payment_intent: nil, payment_link: nil, starting_after: nil, status: nil, subscription: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(created: nil, customer: nil, customer_account: nil, customer_details: nil, ending_before: nil, expand: nil, limit: nil, payment_intent: nil, payment_link: nil, starting_after: nil, status: nil, subscription: nil) ⇒ ListParams
Returns a new instance of ListParams.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/stripe/services/checkout/session_service.rb', line 66 def initialize( created: nil, customer: nil, customer_account: nil, customer_details: nil, ending_before: nil, expand: nil, limit: nil, payment_intent: nil, payment_link: nil, starting_after: nil, status: nil, subscription: nil ) @created = created @customer = customer @customer_account = customer_account @customer_details = customer_details @ending_before = ending_before @expand = @limit = limit @payment_intent = payment_intent @payment_link = payment_link @starting_after = starting_after @status = status @subscription = subscription end |
Instance Attribute Details
#created ⇒ Object
Only return Checkout Sessions that were created during the given date interval.
42 43 44 |
# File 'lib/stripe/services/checkout/session_service.rb', line 42 def created @created end |
#customer ⇒ Object
Only return the Checkout Sessions for the Customer specified.
44 45 46 |
# File 'lib/stripe/services/checkout/session_service.rb', line 44 def customer @customer end |
#customer_account ⇒ Object
Only return the Checkout Sessions for the Account specified.
46 47 48 |
# File 'lib/stripe/services/checkout/session_service.rb', line 46 def customer_account @customer_account end |
#customer_details ⇒ Object
Only return the Checkout Sessions for the Customer details specified.
48 49 50 |
# File 'lib/stripe/services/checkout/session_service.rb', line 48 def customer_details @customer_details end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
50 51 52 |
# File 'lib/stripe/services/checkout/session_service.rb', line 50 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
52 53 54 |
# File 'lib/stripe/services/checkout/session_service.rb', line 52 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
54 55 56 |
# File 'lib/stripe/services/checkout/session_service.rb', line 54 def limit @limit end |
#payment_intent ⇒ Object
Only return the Checkout Session for the PaymentIntent specified.
56 57 58 |
# File 'lib/stripe/services/checkout/session_service.rb', line 56 def payment_intent @payment_intent end |
#payment_link ⇒ Object
Only return the Checkout Sessions for the Payment Link specified.
58 59 60 |
# File 'lib/stripe/services/checkout/session_service.rb', line 58 def payment_link @payment_link end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
60 61 62 |
# File 'lib/stripe/services/checkout/session_service.rb', line 60 def starting_after @starting_after end |
#status ⇒ Object
Only return the Checkout Sessions matching the given status.
62 63 64 |
# File 'lib/stripe/services/checkout/session_service.rb', line 62 def status @status end |
#subscription ⇒ Object
Only return the Checkout Session for the subscription specified.
64 65 66 |
# File 'lib/stripe/services/checkout/session_service.rb', line 64 def subscription @subscription end |