Class: Stripe::Checkout::SessionService::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionService::UpdateParams
- Defined in:
- lib/stripe/services/checkout/session_service.rb
Defined Under Namespace
Classes: CollectedInformation, Discount, LineItem, ShippingOption, SubscriptionData
Instance Attribute Summary collapse
-
#collected_information ⇒ Object
Information about the customer collected within the Checkout Session.
-
#discounts ⇒ Object
List of coupons and promotion codes attached to the Checkout Session.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#line_items ⇒ Object
A list of items the customer is purchasing.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#shipping_options ⇒ Object
The shipping rate options to apply to this Session.
-
#subscription_data ⇒ Object
A subset of parameters to be passed to subscription creation for Checkout Sessions in ‘subscription` mode.
Instance Method Summary collapse
-
#initialize(collected_information: nil, discounts: nil, expand: nil, line_items: nil, metadata: nil, shipping_options: nil, subscription_data: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(collected_information: nil, discounts: nil, expand: nil, line_items: nil, metadata: nil, shipping_options: nil, subscription_data: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
2947 2948 2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 2963 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2947 def initialize( collected_information: nil, discounts: nil, expand: nil, line_items: nil, metadata: nil, shipping_options: nil, subscription_data: nil ) @collected_information = collected_information @discounts = discounts @expand = @line_items = line_items @metadata = @shipping_options = @subscription_data = subscription_data end |
Instance Attribute Details
#collected_information ⇒ Object
Information about the customer collected within the Checkout Session. Can only be set when updating ‘embedded` or `custom` sessions.
2921 2922 2923 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2921 def collected_information @collected_information end |
#discounts ⇒ Object
List of coupons and promotion codes attached to the Checkout Session.
2923 2924 2925 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2923 def discounts @discounts end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2925 2926 2927 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2925 def @expand end |
#line_items ⇒ Object
A list of items the customer is purchasing.
When updating line items, you must retransmit the entire array of line items.
To retain an existing line item, specify its ‘id`.
To update an existing line item, specify its ‘id` along with the new values of the fields to update.
To add a new line item, specify one of ‘price` or `price_data` and `quantity`.
To remove an existing line item, omit the line item’s ID from the retransmitted array.
To reorder a line item, specify it at the desired position in the retransmitted array.
2939 2940 2941 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2939 def line_items @line_items end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
2941 2942 2943 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2941 def @metadata end |
#shipping_options ⇒ Object
The shipping rate options to apply to this Session. Up to a maximum of 5.
2943 2944 2945 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2943 def @shipping_options end |
#subscription_data ⇒ Object
A subset of parameters to be passed to subscription creation for Checkout Sessions in ‘subscription` mode.
2945 2946 2947 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2945 def subscription_data @subscription_data end |