Class: Stripe::Checkout::SessionService::UpdateParams::LineItem::AdjustableQuantity

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/checkout/session_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(enabled: nil, maximum: nil, minimum: nil) ⇒ AdjustableQuantity

Returns a new instance of AdjustableQuantity.



2421
2422
2423
2424
2425
# File 'lib/stripe/services/checkout/session_service.rb', line 2421

def initialize(enabled: nil, maximum: nil, minimum: nil)
  @enabled = enabled
  @maximum = maximum
  @minimum = minimum
end

Instance Attribute Details

#enabledObject

Set to true if the quantity can be adjusted to any positive integer. Setting to false will remove any previously specified constraints on quantity.



2415
2416
2417
# File 'lib/stripe/services/checkout/session_service.rb', line 2415

def enabled
  @enabled
end

#maximumObject

The maximum quantity the customer can purchase for the Checkout Session. By default this value is 99. You can specify a value up to 999999.



2417
2418
2419
# File 'lib/stripe/services/checkout/session_service.rb', line 2417

def maximum
  @maximum
end

#minimumObject

The minimum quantity the customer must purchase for the Checkout Session. By default this value is 0.



2419
2420
2421
# File 'lib/stripe/services/checkout/session_service.rb', line 2419

def minimum
  @minimum
end