Class: Stripe::Checkout::SessionService::UpdateParams::LineItem::PriceData::ProductData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/checkout/session_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil) ⇒ ProductData

Returns a new instance of ProductData.



2716
2717
2718
2719
2720
2721
2722
# File 'lib/stripe/services/checkout/session_service.rb', line 2716

def initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil)
  @description = description
  @images = images
  @metadata = 
  @name = name
  @tax_code = tax_code
end

Instance Attribute Details

#descriptionObject

The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.



2706
2707
2708
# File 'lib/stripe/services/checkout/session_service.rb', line 2706

def description
  @description
end

#imagesObject

A list of up to 8 URLs of images for this product, meant to be displayable to the customer.



2708
2709
2710
# File 'lib/stripe/services/checkout/session_service.rb', line 2708

def images
  @images
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2710
2711
2712
# File 'lib/stripe/services/checkout/session_service.rb', line 2710

def 
  @metadata
end

#nameObject

The product’s name, meant to be displayable to the customer.



2712
2713
2714
# File 'lib/stripe/services/checkout/session_service.rb', line 2712

def name
  @name
end

#tax_codeObject



2714
2715
2716
# File 'lib/stripe/services/checkout/session_service.rb', line 2714

def tax_code
  @tax_code
end