Class: Stripe::Checkout::SessionService::UpdateParams::ShippingOption

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/checkout/session_service.rb

Defined Under Namespace

Classes: ShippingRateData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(shipping_rate: nil, shipping_rate_data: nil) ⇒ ShippingOption

Returns a new instance of ShippingOption.



2903
2904
2905
2906
# File 'lib/stripe/services/checkout/session_service.rb', line 2903

def initialize(shipping_rate: nil, shipping_rate_data: nil)
  @shipping_rate = shipping_rate
  @shipping_rate_data = shipping_rate_data
end

Instance Attribute Details

#shipping_rateObject

The ID of the Shipping Rate to use for this shipping option.



2899
2900
2901
# File 'lib/stripe/services/checkout/session_service.rb', line 2899

def shipping_rate
  @shipping_rate
end

#shipping_rate_dataObject

Parameters to be passed to Shipping Rate creation for this shipping option.



2901
2902
2903
# File 'lib/stripe/services/checkout/session_service.rb', line 2901

def shipping_rate_data
  @shipping_rate_data
end