Class: Stripe::Checkout::SessionService::UpdateParams::ShippingOption::ShippingRateData::FixedAmount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionService::UpdateParams::ShippingOption::ShippingRateData::FixedAmount
- Defined in:
- lib/stripe/services/checkout/session_service.rb
Defined Under Namespace
Classes: CurrencyOptions
Instance Attribute Summary collapse
-
#amount ⇒ Object
A non-negative integer in cents representing how much to charge.
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#currency_options ⇒ Object
Shipping rates defined in each available currency option.
Instance Method Summary collapse
-
#initialize(amount: nil, currency: nil, currency_options: nil) ⇒ FixedAmount
constructor
A new instance of FixedAmount.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, currency: nil, currency_options: nil) ⇒ FixedAmount
Returns a new instance of FixedAmount.
2584 2585 2586 2587 2588 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2584 def initialize(amount: nil, currency: nil, currency_options: nil) @amount = amount @currency = currency @currency_options = end |
Instance Attribute Details
#amount ⇒ Object
A non-negative integer in cents representing how much to charge.
2578 2579 2580 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2578 def amount @amount end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
2580 2581 2582 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2580 def currency @currency end |
#currency_options ⇒ Object
Shipping rates defined in each available currency option. Each key must be a three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html) and a [supported currency](stripe.com/docs/currencies).
2582 2583 2584 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2582 def @currency_options end |