Class: Stripe::Checkout::SessionService::UpdateParams::SubscriptionData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/checkout/session_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(trial_end: nil, trial_period_days: nil) ⇒ SubscriptionData

Returns a new instance of SubscriptionData.



2915
2916
2917
2918
# File 'lib/stripe/services/checkout/session_service.rb', line 2915

def initialize(trial_end: nil, trial_period_days: nil)
  @trial_end = trial_end
  @trial_period_days = trial_period_days
end

Instance Attribute Details

#trial_endObject

Unix timestamp representing the end of the trial period the customer will get before being charged for the first time. Has to be at least 48 hours in the future.



2911
2912
2913
# File 'lib/stripe/services/checkout/session_service.rb', line 2911

def trial_end
  @trial_end
end

#trial_period_daysObject

Integer representing the number of trial period days before the customer is charged for the first time. Has to be at least 1.



2913
2914
2915
# File 'lib/stripe/services/checkout/session_service.rb', line 2913

def trial_period_days
  @trial_period_days
end