Class: Stripe::Checkout::SessionUpdateParams::AutomaticTax
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionUpdateParams::AutomaticTax
- Defined in:
- lib/stripe/params/checkout/session_update_params.rb
Defined Under Namespace
Classes: Liability
Instance Attribute Summary collapse
-
#liability ⇒ Object
The account that’s liable for tax.
Instance Method Summary collapse
-
#initialize(liability: nil) ⇒ AutomaticTax
constructor
A new instance of AutomaticTax.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(liability: nil) ⇒ AutomaticTax
Returns a new instance of AutomaticTax.
22 23 24 |
# File 'lib/stripe/params/checkout/session_update_params.rb', line 22 def initialize(liability: nil) @liability = liability end |
Instance Attribute Details
#liability ⇒ Object
The account that’s liable for tax. If set, the business address and tax registrations required to perform the tax calculation are loaded from this account. The tax transaction is returned in the report of the connected account.
20 21 22 |
# File 'lib/stripe/params/checkout/session_update_params.rb', line 20 def liability @liability end |