Class: Stripe::Checkout::SessionUpdateParams::Discount::CouponData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount_off: nil, currency: nil, duration: nil, metadata: nil, name: nil, percent_off: nil) ⇒ CouponData

Returns a new instance of CouponData.



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/stripe/params/checkout/session_update_params.rb', line 92

def initialize(
  amount_off: nil,
  currency: nil,
  duration: nil,
  metadata: nil,
  name: nil,
  percent_off: nil
)
  @amount_off = amount_off
  @currency = currency
  @duration = duration
  @metadata = 
  @name = name
  @percent_off = percent_off
end

Instance Attribute Details

#amount_offObject

A positive integer representing the amount to subtract from an invoice total (required if ‘percent_off` is not passed).



80
81
82
# File 'lib/stripe/params/checkout/session_update_params.rb', line 80

def amount_off
  @amount_off
end

#currencyObject

Three-letter [ISO code for the currency](stripe.com/docs/currencies) of the ‘amount_off` parameter (required if `amount_off` is passed).



82
83
84
# File 'lib/stripe/params/checkout/session_update_params.rb', line 82

def currency
  @currency
end

#durationObject

Specifies how long the discount will be in effect if used on a subscription. Defaults to ‘once`.



84
85
86
# File 'lib/stripe/params/checkout/session_update_params.rb', line 84

def duration
  @duration
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



86
87
88
# File 'lib/stripe/params/checkout/session_update_params.rb', line 86

def 
  @metadata
end

#nameObject

Name of the coupon displayed to customers on, for instance invoices, or receipts. By default the ‘id` is shown if `name` is not set.



88
89
90
# File 'lib/stripe/params/checkout/session_update_params.rb', line 88

def name
  @name
end

#percent_offObject

A positive float larger than 0, and smaller or equal to 100, that represents the discount the coupon will apply (required if ‘amount_off` is not passed).



90
91
92
# File 'lib/stripe/params/checkout/session_update_params.rb', line 90

def percent_off
  @percent_off
end