Class: Stripe::Checkout::SessionUpdateParams::ShippingOption

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_update_params.rb

Defined Under Namespace

Classes: ShippingRateData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(shipping_rate: nil, shipping_rate_data: nil, tax_rates: nil) ⇒ ShippingOption

Returns a new instance of ShippingOption.



400
401
402
403
404
# File 'lib/stripe/params/checkout/session_update_params.rb', line 400

def initialize(shipping_rate: nil, shipping_rate_data: nil, tax_rates: nil)
  @shipping_rate = shipping_rate
  @shipping_rate_data = shipping_rate_data
  @tax_rates = tax_rates
end

Instance Attribute Details

#shipping_rateObject

The ID of the Shipping Rate to use for this shipping option.



394
395
396
# File 'lib/stripe/params/checkout/session_update_params.rb', line 394

def shipping_rate
  @shipping_rate
end

#shipping_rate_dataObject

Parameters to be passed to Shipping Rate creation for this shipping option.



396
397
398
# File 'lib/stripe/params/checkout/session_update_params.rb', line 396

def shipping_rate_data
  @shipping_rate_data
end

#tax_ratesObject

The tax rates that will be applied to this shipping option. This parameter is only supported for Checkout Sessions with ui_mode set to form or elements.



398
399
400
# File 'lib/stripe/params/checkout/session_update_params.rb', line 398

def tax_rates
  @tax_rates
end