Class: Stripe::Checkout::SessionUpdateParams::SubscriptionData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_update_params.rb

Defined Under Namespace

Classes: InvoiceSettings, PendingInvoiceItemInterval

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(invoice_settings: nil, pending_invoice_item_interval: nil, trial_end: nil, trial_period_days: nil) ⇒ SubscriptionData

Returns a new instance of SubscriptionData.



448
449
450
451
452
453
454
455
456
457
458
# File 'lib/stripe/params/checkout/session_update_params.rb', line 448

def initialize(
  invoice_settings: nil,
  pending_invoice_item_interval: nil,
  trial_end: nil,
  trial_period_days: nil
)
  @invoice_settings = invoice_settings
  @pending_invoice_item_interval = pending_invoice_item_interval
  @trial_end = trial_end
  @trial_period_days = trial_period_days
end

Instance Attribute Details

#invoice_settingsObject

All invoices will be billed using the specified settings.



440
441
442
# File 'lib/stripe/params/checkout/session_update_params.rb', line 440

def invoice_settings
  @invoice_settings
end

#pending_invoice_item_intervalObject

Specifies an interval for how often to bill for any pending invoice items. It is analogous to calling Create an invoice for the given subscription at the specified interval.



442
443
444
# File 'lib/stripe/params/checkout/session_update_params.rb', line 442

def pending_invoice_item_interval
  @pending_invoice_item_interval
end

#trial_endObject

Unix timestamp representing the end of the trial period the customer will get before being charged for the first time. Has to be at least 48 hours in the future.



444
445
446
# File 'lib/stripe/params/checkout/session_update_params.rb', line 444

def trial_end
  @trial_end
end

#trial_period_daysObject

Integer representing the number of trial period days before the customer is charged for the first time. Has to be at least 1.



446
447
448
# File 'lib/stripe/params/checkout/session_update_params.rb', line 446

def trial_period_days
  @trial_period_days
end