Class: Stripe::Climate::Order::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/climate/order.rb

Defined Under Namespace

Classes: Beneficiary

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, beneficiary: nil, currency: nil, expand: nil, metadata: nil, metric_tons: nil, product: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/stripe/resources/climate/order.rb', line 114

def initialize(
  amount: nil,
  beneficiary: nil,
  currency: nil,
  expand: nil,
  metadata: nil,
  metric_tons: nil,
  product: nil
)
  @amount = amount
  @beneficiary = beneficiary
  @currency = currency
  @expand = expand
  @metadata = 
  @metric_tons = metric_tons
  @product = product
end

Instance Attribute Details

#amountObject

Requested amount of carbon removal units. Either this or ‘metric_tons` must be specified.



100
101
102
# File 'lib/stripe/resources/climate/order.rb', line 100

def amount
  @amount
end

#beneficiaryObject

Publicly sharable reference for the end beneficiary of carbon removal. Assumed to be the Stripe account if not set.



102
103
104
# File 'lib/stripe/resources/climate/order.rb', line 102

def beneficiary
  @beneficiary
end

#currencyObject

Request currency for the order as a three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a supported [settlement currency for your account](stripe.com/docs/currencies). If omitted, the account’s default currency will be used.



104
105
106
# File 'lib/stripe/resources/climate/order.rb', line 104

def currency
  @currency
end

#expandObject

Specifies which fields in the response should be expanded.



106
107
108
# File 'lib/stripe/resources/climate/order.rb', line 106

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



108
109
110
# File 'lib/stripe/resources/climate/order.rb', line 108

def 
  @metadata
end

#metric_tonsObject

Requested number of tons for the order. Either this or ‘amount` must be specified.



110
111
112
# File 'lib/stripe/resources/climate/order.rb', line 110

def metric_tons
  @metric_tons
end

#productObject

Unique identifier of the Climate product.



112
113
114
# File 'lib/stripe/resources/climate/order.rb', line 112

def product
  @product
end