Class: Stripe::Climate::Order::DeliveryDetail
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Climate::Order::DeliveryDetail
- Defined in:
- lib/stripe/resources/climate/order.rb
Defined Under Namespace
Classes: Location
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#delivered_at ⇒ Object
readonly
Time at which the delivery occurred.
-
#location ⇒ Object
readonly
Specific location of this delivery.
-
#metric_tons ⇒ Object
readonly
Quantity of carbon removal supplied by this delivery.
-
#registry_url ⇒ Object
readonly
Once retired, a URL to the registry entry for the tons from this delivery.
-
#supplier ⇒ Object
readonly
A supplier of carbon removal.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#delivered_at ⇒ Object (readonly)
Time at which the delivery occurred. Measured in seconds since the Unix epoch.
41 42 43 |
# File 'lib/stripe/resources/climate/order.rb', line 41 def delivered_at @delivered_at end |
#location ⇒ Object (readonly)
Specific location of this delivery.
44 45 46 |
# File 'lib/stripe/resources/climate/order.rb', line 44 def location @location end |
#metric_tons ⇒ Object (readonly)
Quantity of carbon removal supplied by this delivery.
47 48 49 |
# File 'lib/stripe/resources/climate/order.rb', line 47 def metric_tons @metric_tons end |
#registry_url ⇒ Object (readonly)
Once retired, a URL to the registry entry for the tons from this delivery.
50 51 52 |
# File 'lib/stripe/resources/climate/order.rb', line 50 def registry_url @registry_url end |
#supplier ⇒ Object (readonly)
A supplier of carbon removal.
53 54 55 |
# File 'lib/stripe/resources/climate/order.rb', line 53 def supplier @supplier end |