Class: Stripe::Climate::Order::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/climate/order.rb

Defined Under Namespace

Classes: Beneficiary

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(beneficiary: nil, expand: nil, metadata: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



153
154
155
156
157
# File 'lib/stripe/resources/climate/order.rb', line 153

def initialize(beneficiary: nil, expand: nil, metadata: nil)
  @beneficiary = beneficiary
  @expand = expand
  @metadata = 
end

Instance Attribute Details

#beneficiaryObject

Publicly sharable reference for the end beneficiary of carbon removal. Assumed to be the Stripe account if not set.



145
146
147
# File 'lib/stripe/resources/climate/order.rb', line 145

def beneficiary
  @beneficiary
end

#expandObject

Specifies which fields in the response should be expanded.



148
149
150
# File 'lib/stripe/resources/climate/order.rb', line 148

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



151
152
153
# File 'lib/stripe/resources/climate/order.rb', line 151

def 
  @metadata
end