Class: Stripe::Climate::Product::CurrentPricesPerMetricTon
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Climate::Product::CurrentPricesPerMetricTon
- Defined in:
- lib/stripe/resources/climate/product.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount_fees ⇒ Object
readonly
Fees for one metric ton of carbon removal in the currency’s smallest unit.
-
#amount_subtotal ⇒ Object
readonly
Subtotal for one metric ton of carbon removal (excluding fees) in the currency’s smallest unit.
-
#amount_total ⇒ Object
readonly
Total for one metric ton of carbon removal (including fees) in the currency’s smallest unit.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount_fees ⇒ Object (readonly)
Fees for one metric ton of carbon removal in the currency’s smallest unit.
18 19 20 |
# File 'lib/stripe/resources/climate/product.rb', line 18 def amount_fees @amount_fees end |
#amount_subtotal ⇒ Object (readonly)
Subtotal for one metric ton of carbon removal (excluding fees) in the currency’s smallest unit.
20 21 22 |
# File 'lib/stripe/resources/climate/product.rb', line 20 def amount_subtotal @amount_subtotal end |
#amount_total ⇒ Object (readonly)
Total for one metric ton of carbon removal (including fees) in the currency’s smallest unit.
22 23 24 |
# File 'lib/stripe/resources/climate/product.rb', line 22 def amount_total @amount_total end |