Class: Stripe::Climate::ProductService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::Climate::ProductService
- Defined in:
- lib/stripe/services/climate/product_service.rb
Defined Under Namespace
Classes: ListParams, RetrieveParams
Instance Method Summary collapse
-
#list(params = {}, opts = {}) ⇒ Object
Lists all available Climate product objects.
-
#retrieve(product, params = {}, opts = {}) ⇒ Object
Retrieves the details of a Climate product with the given ID.
Methods inherited from StripeService
#initialize, #request, #request_stream
Constructor Details
This class inherits a constructor from Stripe::StripeService
Instance Method Details
#list(params = {}, opts = {}) ⇒ Object
Lists all available Climate product objects.
35 36 37 38 39 40 41 42 43 |
# File 'lib/stripe/services/climate/product_service.rb', line 35 def list(params = {}, opts = {}) request( method: :get, path: "/v1/climate/products", params: params, opts: opts, base_address: :api ) end |
#retrieve(product, params = {}, opts = {}) ⇒ Object
Retrieves the details of a Climate product with the given ID.
46 47 48 49 50 51 52 53 54 |
# File 'lib/stripe/services/climate/product_service.rb', line 46 def retrieve(product, params = {}, opts = {}) request( method: :get, path: format("/v1/climate/products/%<product>s", { product: CGI.escape(product) }), params: params, opts: opts, base_address: :api ) end |