Class: Stripe::Climate::Supplier

Inherits:
APIResource show all
Extended by:
APIOperations::List
Defined in:
lib/stripe/resources/climate/supplier.rb

Overview

A supplier of carbon removal.

Defined Under Namespace

Classes: ListParams, Location

Constant Summary collapse

OBJECT_NAME =
"climate.supplier"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods included from APIOperations::List

list

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#idObject (readonly)

Unique identifier for the object.



54
55
56
# File 'lib/stripe/resources/climate/supplier.rb', line 54

def id
  @id
end

#info_urlObject (readonly)

Link to a webpage to learn more about the supplier.



56
57
58
# File 'lib/stripe/resources/climate/supplier.rb', line 56

def info_url
  @info_url
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



58
59
60
# File 'lib/stripe/resources/climate/supplier.rb', line 58

def livemode
  @livemode
end

#locationsObject (readonly)

The locations in which this supplier operates.



60
61
62
# File 'lib/stripe/resources/climate/supplier.rb', line 60

def locations
  @locations
end

#nameObject (readonly)

Name of this carbon removal supplier.



62
63
64
# File 'lib/stripe/resources/climate/supplier.rb', line 62

def name
  @name
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



64
65
66
# File 'lib/stripe/resources/climate/supplier.rb', line 64

def object
  @object
end

#removal_pathwayObject (readonly)

The scientific pathway used for carbon removal.



66
67
68
# File 'lib/stripe/resources/climate/supplier.rb', line 66

def removal_pathway
  @removal_pathway
end

Class Method Details

.field_remappingsObject



82
83
84
# File 'lib/stripe/resources/climate/supplier.rb', line 82

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



78
79
80
# File 'lib/stripe/resources/climate/supplier.rb', line 78

def self.inner_class_types
  @inner_class_types = { locations: Location }
end

.list(params = {}, opts = {}) ⇒ Object

Lists all available Climate supplier objects.



69
70
71
72
73
74
75
76
# File 'lib/stripe/resources/climate/supplier.rb', line 69

def self.list(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/climate/suppliers",
    params: params,
    opts: opts
  )
end

.object_nameObject



11
12
13
# File 'lib/stripe/resources/climate/supplier.rb', line 11

def self.object_name
  "climate.supplier"
end