Class: Stripe::ConfirmationToken

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/confirmation_token.rb

Overview

ConfirmationTokens help transport client side data collected by Stripe JS over to your server for confirming a PaymentIntent or SetupIntent. If the confirmation is successful, values present on the ConfirmationToken are written onto the Intent.

To learn more about how to use ConfirmationToken, visit the related guides:

Defined Under Namespace

Classes: MandateData, PaymentMethodOptions, PaymentMethodPreview, Shipping, TestHelpers

Constant Summary collapse

OBJECT_NAME =
"confirmation_token"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



1998
1999
2000
# File 'lib/stripe/resources/confirmation_token.rb', line 1998

def created
  @created
end

#expires_atObject (readonly)

Time at which this ConfirmationToken expires and can no longer be used to confirm a PaymentIntent or SetupIntent.



2000
2001
2002
# File 'lib/stripe/resources/confirmation_token.rb', line 2000

def expires_at
  @expires_at
end

#idObject (readonly)

Unique identifier for the object.



2002
2003
2004
# File 'lib/stripe/resources/confirmation_token.rb', line 2002

def id
  @id
end

#livemodeObject (readonly)

If the object exists in live mode, the value is true. If the object exists in test mode, the value is false.



2004
2005
2006
# File 'lib/stripe/resources/confirmation_token.rb', line 2004

def livemode
  @livemode
end

#mandate_dataObject (readonly)

Data used for generating a Mandate.



2006
2007
2008
# File 'lib/stripe/resources/confirmation_token.rb', line 2006

def mandate_data
  @mandate_data
end

#objectObject (readonly)

String representing the object's type. Objects of the same type share the same value.



2008
2009
2010
# File 'lib/stripe/resources/confirmation_token.rb', line 2008

def object
  @object
end

#payment_intentObject (readonly)

ID of the PaymentIntent that this ConfirmationToken was used to confirm, or null if this ConfirmationToken has not yet been used.



2010
2011
2012
# File 'lib/stripe/resources/confirmation_token.rb', line 2010

def payment_intent
  @payment_intent
end

#payment_method_optionsObject (readonly)

Payment-method-specific configuration for this ConfirmationToken.



2012
2013
2014
# File 'lib/stripe/resources/confirmation_token.rb', line 2012

def payment_method_options
  @payment_method_options
end

#payment_method_previewObject (readonly)

Payment details collected by the Payment Element, used to create a PaymentMethod when a PaymentIntent or SetupIntent is confirmed with this ConfirmationToken.



2014
2015
2016
# File 'lib/stripe/resources/confirmation_token.rb', line 2014

def payment_method_preview
  @payment_method_preview
end

#return_urlObject (readonly)

Return URL used to confirm the Intent.



2016
2017
2018
# File 'lib/stripe/resources/confirmation_token.rb', line 2016

def return_url
  @return_url
end

#setup_future_usageObject (readonly)

Indicates that you intend to make future payments with this ConfirmationToken's payment method.

The presence of this property will attach the payment method to the PaymentIntent's Customer, if present, after the PaymentIntent is confirmed and any required actions from the user are complete.



2020
2021
2022
# File 'lib/stripe/resources/confirmation_token.rb', line 2020

def setup_future_usage
  @setup_future_usage
end

#setup_intentObject (readonly)

ID of the SetupIntent that this ConfirmationToken was used to confirm, or null if this ConfirmationToken has not yet been used.



2022
2023
2024
# File 'lib/stripe/resources/confirmation_token.rb', line 2022

def setup_intent
  @setup_intent
end

#shippingObject (readonly)

Shipping information collected on this ConfirmationToken.



2024
2025
2026
# File 'lib/stripe/resources/confirmation_token.rb', line 2024

def shipping
  @shipping
end

#use_stripe_sdkObject (readonly)

Indicates whether the Stripe SDK is used to handle confirmation flow. Defaults to true on ConfirmationToken.



2026
2027
2028
# File 'lib/stripe/resources/confirmation_token.rb', line 2026

def use_stripe_sdk
  @use_stripe_sdk
end

Class Method Details

.field_remappingsObject



2058
2059
2060
# File 'lib/stripe/resources/confirmation_token.rb', line 2058

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2049
2050
2051
2052
2053
2054
2055
2056
# File 'lib/stripe/resources/confirmation_token.rb', line 2049

def self.inner_class_types
  @inner_class_types = {
    mandate_data: MandateData,
    payment_method_options: PaymentMethodOptions,
    payment_method_preview: PaymentMethodPreview,
    shipping: Shipping,
  }
end

.object_nameObject



14
15
16
# File 'lib/stripe/resources/confirmation_token.rb', line 14

def self.object_name
  "confirmation_token"
end

Instance Method Details

#test_helpersObject



2028
2029
2030
# File 'lib/stripe/resources/confirmation_token.rb', line 2028

def test_helpers
  TestHelpers.new(self)
end