Class: Stripe::ConfirmationToken::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/confirmation_token.rb

Defined Under Namespace

Classes: PaymentMethodData, PaymentMethodOptions, Shipping

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, return_url: nil, setup_future_usage: nil, shipping: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



2515
2516
2517
2518
2519
2520
2521
2522
2523
2524
2525
2526
2527
2528
2529
2530
2531
# File 'lib/stripe/resources/confirmation_token.rb', line 2515

def initialize(
  expand: nil,
  payment_method: nil,
  payment_method_data: nil,
  payment_method_options: nil,
  return_url: nil,
  setup_future_usage: nil,
  shipping: nil
)
  @expand = expand
  @payment_method = payment_method
  @payment_method_data = payment_method_data
  @payment_method_options = payment_method_options
  @return_url = return_url
  @setup_future_usage = setup_future_usage
  @shipping = shipping
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



2499
2500
2501
# File 'lib/stripe/resources/confirmation_token.rb', line 2499

def expand
  @expand
end

#payment_methodObject

ID of an existing PaymentMethod.



2501
2502
2503
# File 'lib/stripe/resources/confirmation_token.rb', line 2501

def payment_method
  @payment_method
end

#payment_method_dataObject

If provided, this hash will be used to create a PaymentMethod.



2503
2504
2505
# File 'lib/stripe/resources/confirmation_token.rb', line 2503

def payment_method_data
  @payment_method_data
end

#payment_method_optionsObject

Payment-method-specific configuration for this ConfirmationToken.



2505
2506
2507
# File 'lib/stripe/resources/confirmation_token.rb', line 2505

def payment_method_options
  @payment_method_options
end

#return_urlObject

Return URL used to confirm the Intent.



2507
2508
2509
# File 'lib/stripe/resources/confirmation_token.rb', line 2507

def return_url
  @return_url
end

#setup_future_usageObject

Indicates that you intend to make future payments with this ConfirmationToken’s payment method.

The presence of this property will [attach the payment method](stripe.com/docs/payments/save-during-payment) to the PaymentIntent’s Customer, if present, after the PaymentIntent is confirmed and any required actions from the user are complete.



2511
2512
2513
# File 'lib/stripe/resources/confirmation_token.rb', line 2511

def setup_future_usage
  @setup_future_usage
end

#shippingObject

Shipping information for this ConfirmationToken.



2513
2514
2515
# File 'lib/stripe/resources/confirmation_token.rb', line 2513

def shipping
  @shipping
end