Class: Stripe::ConfirmationToken::CreateParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/confirmation_token.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



2011
2012
2013
2014
2015
2016
2017
2018
2019
2020
2021
2022
2023
2024
2025
# File 'lib/stripe/resources/confirmation_token.rb', line 2011

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



1999
2000
2001
# File 'lib/stripe/resources/confirmation_token.rb', line 1999

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



2001
2002
2003
# File 'lib/stripe/resources/confirmation_token.rb', line 2001

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



2003
2004
2005
# File 'lib/stripe/resources/confirmation_token.rb', line 2003

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



2005
2006
2007
# File 'lib/stripe/resources/confirmation_token.rb', line 2005

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



2007
2008
2009
# File 'lib/stripe/resources/confirmation_token.rb', line 2007

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



2009
2010
2011
# File 'lib/stripe/resources/confirmation_token.rb', line 2009

def suffix
  @suffix
end