Class: Stripe::ConfirmationToken::CreateParams::PaymentMethodData::RadarOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/confirmation_token.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(session: nil) ⇒ RadarOptions

Returns a new instance of RadarOptions.



2067
2068
2069
# File 'lib/stripe/resources/confirmation_token.rb', line 2067

def initialize(session: nil)
  @session = session
end

Instance Attribute Details

#sessionObject

A [Radar Session](stripe.com/docs/radar/radar-session) is a snapshot of the browser metadata and device details that help Radar make more accurate predictions on your payments.



2065
2066
2067
# File 'lib/stripe/resources/confirmation_token.rb', line 2065

def session
  @session
end