Class: Stripe::ConfirmationToken::CreateParams::PaymentMethodData::StripeBalance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ConfirmationToken::CreateParams::PaymentMethodData::StripeBalance
- Defined in:
- lib/stripe/resources/confirmation_token.rb
Instance Attribute Summary collapse
-
#account ⇒ Object
The connected account ID whose Stripe balance to use as the source of payment.
-
#source_type ⇒ Object
The [source_type](docs.stripe.com/api/balance/balance_object#balance_object-available-source_types) of the balance.
Instance Method Summary collapse
-
#initialize(account: nil, source_type: nil) ⇒ StripeBalance
constructor
A new instance of StripeBalance.
Methods inherited from RequestParams
Constructor Details
#initialize(account: nil, source_type: nil) ⇒ StripeBalance
Returns a new instance of StripeBalance.
1212 1213 1214 1215 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1212 def initialize(account: nil, source_type: nil) @account = account @source_type = source_type end |
Instance Attribute Details
#account ⇒ Object
The connected account ID whose Stripe balance to use as the source of payment
1208 1209 1210 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1208 def account @account end |
#source_type ⇒ Object
The [source_type](docs.stripe.com/api/balance/balance_object#balance_object-available-source_types) of the balance
1210 1211 1212 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1210 def source_type @source_type end |