Class: Stripe::ConfirmationToken::CreateParams::PaymentMethodOptions::Card::Installments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ConfirmationToken::CreateParams::PaymentMethodOptions::Card::Installments
- Defined in:
- lib/stripe/resources/confirmation_token.rb
Defined Under Namespace
Classes: Plan
Instance Attribute Summary collapse
-
#plan ⇒ Object
The selected installment plan to use for this payment attempt.
Instance Method Summary collapse
-
#initialize(plan: nil) ⇒ Installments
constructor
A new instance of Installments.
Methods inherited from RequestParams
Constructor Details
#initialize(plan: nil) ⇒ Installments
Returns a new instance of Installments.
1526 1527 1528 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1526 def initialize(plan: nil) @plan = plan end |
Instance Attribute Details
#plan ⇒ Object
The selected installment plan to use for this payment attempt. This parameter can only be provided during confirmation.
1524 1525 1526 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1524 def plan @plan end |