Class: Stripe::ConfirmationToken::CreateParams::PaymentMethodOptions::Card::Installments::Plan

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/confirmation_token.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(count: nil, interval: nil, type: nil) ⇒ Plan

Returns a new instance of Plan.



2425
2426
2427
2428
2429
# File 'lib/stripe/resources/confirmation_token.rb', line 2425

def initialize(count: nil, interval: nil, type: nil)
  @count = count
  @interval = interval
  @type = type
end

Instance Attribute Details

#countObject

For ‘fixed_count` installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.



2418
2419
2420
# File 'lib/stripe/resources/confirmation_token.rb', line 2418

def count
  @count
end

#intervalObject

For ‘fixed_count` installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of `month`.



2421
2422
2423
# File 'lib/stripe/resources/confirmation_token.rb', line 2421

def interval
  @interval
end

#typeObject

Type of installment plan, one of ‘fixed_count`, `bonus`, or `revolving`.



2423
2424
2425
# File 'lib/stripe/resources/confirmation_token.rb', line 2423

def type
  @type
end