Class: Stripe::ConfirmationToken::PaymentMethodPreview

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/confirmation_token.rb

Defined Under Namespace

Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, BillingDetails, Bizum, Blik, Boleto, Card, CardPresent, Cashapp, Crypto, CustomerBalance, Eps, Fpx, GiftCard, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Paypay, Payto, Pix, Promptpay, Qris, Rechnung, RevolutPay, SamsungPay, Satispay, Scalapay, SepaDebit, Sequra, Shopeepay, Sofort, StripeBalance, Sunbit, Swish, Tamara, Twint, Upi, UsBankAccount, Vipps, WechatPay, Zip

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#acss_debitObject (readonly)

Attribute for field acss_debit



1737
1738
1739
# File 'lib/stripe/resources/confirmation_token.rb', line 1737

def acss_debit
  @acss_debit
end

#affirmObject (readonly)

Attribute for field affirm



1739
1740
1741
# File 'lib/stripe/resources/confirmation_token.rb', line 1739

def affirm
  @affirm
end

#afterpay_clearpayObject (readonly)

Attribute for field afterpay_clearpay



1741
1742
1743
# File 'lib/stripe/resources/confirmation_token.rb', line 1741

def afterpay_clearpay
  @afterpay_clearpay
end

#alipayObject (readonly)

Attribute for field alipay



1743
1744
1745
# File 'lib/stripe/resources/confirmation_token.rb', line 1743

def alipay
  @alipay
end

#allow_redisplayObject (readonly)

This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. The field defaults to “unspecified”.



1745
1746
1747
# File 'lib/stripe/resources/confirmation_token.rb', line 1745

def allow_redisplay
  @allow_redisplay
end

#almaObject (readonly)

Attribute for field alma



1747
1748
1749
# File 'lib/stripe/resources/confirmation_token.rb', line 1747

def alma
  @alma
end

#amazon_payObject (readonly)

Attribute for field amazon_pay



1749
1750
1751
# File 'lib/stripe/resources/confirmation_token.rb', line 1749

def amazon_pay
  @amazon_pay
end

#au_becs_debitObject (readonly)

Attribute for field au_becs_debit



1751
1752
1753
# File 'lib/stripe/resources/confirmation_token.rb', line 1751

def au_becs_debit
  @au_becs_debit
end

#bacs_debitObject (readonly)

Attribute for field bacs_debit



1753
1754
1755
# File 'lib/stripe/resources/confirmation_token.rb', line 1753

def bacs_debit
  @bacs_debit
end

#bancontactObject (readonly)

Attribute for field bancontact



1755
1756
1757
# File 'lib/stripe/resources/confirmation_token.rb', line 1755

def bancontact
  @bancontact
end

#billieObject (readonly)

Attribute for field billie



1757
1758
1759
# File 'lib/stripe/resources/confirmation_token.rb', line 1757

def billie
  @billie
end

#billing_detailsObject (readonly)

Attribute for field billing_details



1759
1760
1761
# File 'lib/stripe/resources/confirmation_token.rb', line 1759

def billing_details
  @billing_details
end

#bizumObject (readonly)

Attribute for field bizum



1761
1762
1763
# File 'lib/stripe/resources/confirmation_token.rb', line 1761

def bizum
  @bizum
end

#blikObject (readonly)

Attribute for field blik



1763
1764
1765
# File 'lib/stripe/resources/confirmation_token.rb', line 1763

def blik
  @blik
end

#boletoObject (readonly)

Attribute for field boleto



1765
1766
1767
# File 'lib/stripe/resources/confirmation_token.rb', line 1765

def boleto
  @boleto
end

#cardObject (readonly)

Attribute for field card



1767
1768
1769
# File 'lib/stripe/resources/confirmation_token.rb', line 1767

def card
  @card
end

#card_presentObject (readonly)

Attribute for field card_present



1769
1770
1771
# File 'lib/stripe/resources/confirmation_token.rb', line 1769

def card_present
  @card_present
end

#cashappObject (readonly)

Attribute for field cashapp



1771
1772
1773
# File 'lib/stripe/resources/confirmation_token.rb', line 1771

def cashapp
  @cashapp
end

#cryptoObject (readonly)

Attribute for field crypto



1773
1774
1775
# File 'lib/stripe/resources/confirmation_token.rb', line 1773

def crypto
  @crypto
end

#customerObject (readonly)

The ID of the Customer to which this PaymentMethod is saved. This will not be set when the PaymentMethod has not been saved to a Customer.



1775
1776
1777
# File 'lib/stripe/resources/confirmation_token.rb', line 1775

def customer
  @customer
end

#customer_accountObject (readonly)

Attribute for field customer_account



1777
1778
1779
# File 'lib/stripe/resources/confirmation_token.rb', line 1777

def 
  @customer_account
end

#customer_balanceObject (readonly)

Attribute for field customer_balance



1779
1780
1781
# File 'lib/stripe/resources/confirmation_token.rb', line 1779

def customer_balance
  @customer_balance
end

#epsObject (readonly)

Attribute for field eps



1781
1782
1783
# File 'lib/stripe/resources/confirmation_token.rb', line 1781

def eps
  @eps
end

#fpxObject (readonly)

Attribute for field fpx



1783
1784
1785
# File 'lib/stripe/resources/confirmation_token.rb', line 1783

def fpx
  @fpx
end

#gift_cardObject (readonly)

Attribute for field gift_card



1785
1786
1787
# File 'lib/stripe/resources/confirmation_token.rb', line 1785

def gift_card
  @gift_card
end

#giropayObject (readonly)

Attribute for field giropay



1787
1788
1789
# File 'lib/stripe/resources/confirmation_token.rb', line 1787

def giropay
  @giropay
end

#gopayObject (readonly)

Attribute for field gopay



1789
1790
1791
# File 'lib/stripe/resources/confirmation_token.rb', line 1789

def gopay
  @gopay
end

#grabpayObject (readonly)

Attribute for field grabpay



1791
1792
1793
# File 'lib/stripe/resources/confirmation_token.rb', line 1791

def grabpay
  @grabpay
end

#id_bank_transferObject (readonly)

Attribute for field id_bank_transfer



1793
1794
1795
# File 'lib/stripe/resources/confirmation_token.rb', line 1793

def id_bank_transfer
  @id_bank_transfer
end

#idealObject (readonly)

Attribute for field ideal



1795
1796
1797
# File 'lib/stripe/resources/confirmation_token.rb', line 1795

def ideal
  @ideal
end

#interac_presentObject (readonly)

Attribute for field interac_present



1797
1798
1799
# File 'lib/stripe/resources/confirmation_token.rb', line 1797

def interac_present
  @interac_present
end

#kakao_payObject (readonly)

Attribute for field kakao_pay



1799
1800
1801
# File 'lib/stripe/resources/confirmation_token.rb', line 1799

def kakao_pay
  @kakao_pay
end

#klarnaObject (readonly)

Attribute for field klarna



1801
1802
1803
# File 'lib/stripe/resources/confirmation_token.rb', line 1801

def klarna
  @klarna
end

#konbiniObject (readonly)

Attribute for field konbini



1803
1804
1805
# File 'lib/stripe/resources/confirmation_token.rb', line 1803

def konbini
  @konbini
end

#kr_cardObject (readonly)

Attribute for field kr_card



1805
1806
1807
# File 'lib/stripe/resources/confirmation_token.rb', line 1805

def kr_card
  @kr_card
end

Attribute for field link



1807
1808
1809
# File 'lib/stripe/resources/confirmation_token.rb', line 1807

def link
  @link
end

#mb_wayObject (readonly)

Attribute for field mb_way



1809
1810
1811
# File 'lib/stripe/resources/confirmation_token.rb', line 1809

def mb_way
  @mb_way
end

#mobilepayObject (readonly)

Attribute for field mobilepay



1811
1812
1813
# File 'lib/stripe/resources/confirmation_token.rb', line 1811

def mobilepay
  @mobilepay
end

#multibancoObject (readonly)

Attribute for field multibanco



1813
1814
1815
# File 'lib/stripe/resources/confirmation_token.rb', line 1813

def multibanco
  @multibanco
end

Attribute for field naver_pay



1815
1816
1817
# File 'lib/stripe/resources/confirmation_token.rb', line 1815

def naver_pay
  @naver_pay
end

#nz_bank_accountObject (readonly)

Attribute for field nz_bank_account



1817
1818
1819
# File 'lib/stripe/resources/confirmation_token.rb', line 1817

def 
  @nz_bank_account
end

#oxxoObject (readonly)

Attribute for field oxxo



1819
1820
1821
# File 'lib/stripe/resources/confirmation_token.rb', line 1819

def oxxo
  @oxxo
end

#p24Object (readonly)

Attribute for field p24



1821
1822
1823
# File 'lib/stripe/resources/confirmation_token.rb', line 1821

def p24
  @p24
end

#pay_by_bankObject (readonly)

Attribute for field pay_by_bank



1823
1824
1825
# File 'lib/stripe/resources/confirmation_token.rb', line 1823

def pay_by_bank
  @pay_by_bank
end

#paycoObject (readonly)

Attribute for field payco



1825
1826
1827
# File 'lib/stripe/resources/confirmation_token.rb', line 1825

def payco
  @payco
end

#paynowObject (readonly)

Attribute for field paynow



1827
1828
1829
# File 'lib/stripe/resources/confirmation_token.rb', line 1827

def paynow
  @paynow
end

#paypalObject (readonly)

Attribute for field paypal



1829
1830
1831
# File 'lib/stripe/resources/confirmation_token.rb', line 1829

def paypal
  @paypal
end

#paypayObject (readonly)

Attribute for field paypay



1831
1832
1833
# File 'lib/stripe/resources/confirmation_token.rb', line 1831

def paypay
  @paypay
end

#paytoObject (readonly)

Attribute for field payto



1833
1834
1835
# File 'lib/stripe/resources/confirmation_token.rb', line 1833

def payto
  @payto
end

#pixObject (readonly)

Attribute for field pix



1835
1836
1837
# File 'lib/stripe/resources/confirmation_token.rb', line 1835

def pix
  @pix
end

#promptpayObject (readonly)

Attribute for field promptpay



1837
1838
1839
# File 'lib/stripe/resources/confirmation_token.rb', line 1837

def promptpay
  @promptpay
end

#qrisObject (readonly)

Attribute for field qris



1839
1840
1841
# File 'lib/stripe/resources/confirmation_token.rb', line 1839

def qris
  @qris
end

#rechnungObject (readonly)

Attribute for field rechnung



1841
1842
1843
# File 'lib/stripe/resources/confirmation_token.rb', line 1841

def rechnung
  @rechnung
end

#revolut_payObject (readonly)

Attribute for field revolut_pay



1843
1844
1845
# File 'lib/stripe/resources/confirmation_token.rb', line 1843

def revolut_pay
  @revolut_pay
end

#samsung_payObject (readonly)

Attribute for field samsung_pay



1845
1846
1847
# File 'lib/stripe/resources/confirmation_token.rb', line 1845

def samsung_pay
  @samsung_pay
end

#satispayObject (readonly)

Attribute for field satispay



1847
1848
1849
# File 'lib/stripe/resources/confirmation_token.rb', line 1847

def satispay
  @satispay
end

#scalapayObject (readonly)

Attribute for field scalapay



1849
1850
1851
# File 'lib/stripe/resources/confirmation_token.rb', line 1849

def scalapay
  @scalapay
end

#sepa_debitObject (readonly)

Attribute for field sepa_debit



1851
1852
1853
# File 'lib/stripe/resources/confirmation_token.rb', line 1851

def sepa_debit
  @sepa_debit
end

#sequraObject (readonly)

Attribute for field sequra



1853
1854
1855
# File 'lib/stripe/resources/confirmation_token.rb', line 1853

def sequra
  @sequra
end

#shopeepayObject (readonly)

Attribute for field shopeepay



1855
1856
1857
# File 'lib/stripe/resources/confirmation_token.rb', line 1855

def shopeepay
  @shopeepay
end

#sofortObject (readonly)

Attribute for field sofort



1857
1858
1859
# File 'lib/stripe/resources/confirmation_token.rb', line 1857

def sofort
  @sofort
end

#stripe_balanceObject (readonly)

Attribute for field stripe_balance



1859
1860
1861
# File 'lib/stripe/resources/confirmation_token.rb', line 1859

def stripe_balance
  @stripe_balance
end

#sunbitObject (readonly)

Attribute for field sunbit



1861
1862
1863
# File 'lib/stripe/resources/confirmation_token.rb', line 1861

def sunbit
  @sunbit
end

#swishObject (readonly)

Attribute for field swish



1863
1864
1865
# File 'lib/stripe/resources/confirmation_token.rb', line 1863

def swish
  @swish
end

#tamaraObject (readonly)

Attribute for field tamara



1865
1866
1867
# File 'lib/stripe/resources/confirmation_token.rb', line 1865

def tamara
  @tamara
end

#twintObject (readonly)

Attribute for field twint



1867
1868
1869
# File 'lib/stripe/resources/confirmation_token.rb', line 1867

def twint
  @twint
end

#typeObject (readonly)

The type of the PaymentMethod. An additional hash is included on the PaymentMethod with a name matching this value. It contains additional information specific to the PaymentMethod type.



1869
1870
1871
# File 'lib/stripe/resources/confirmation_token.rb', line 1869

def type
  @type
end

#upiObject (readonly)

Attribute for field upi



1871
1872
1873
# File 'lib/stripe/resources/confirmation_token.rb', line 1871

def upi
  @upi
end

#us_bank_accountObject (readonly)

Attribute for field us_bank_account



1873
1874
1875
# File 'lib/stripe/resources/confirmation_token.rb', line 1873

def 
  @us_bank_account
end

#vippsObject (readonly)

Attribute for field vipps



1875
1876
1877
# File 'lib/stripe/resources/confirmation_token.rb', line 1875

def vipps
  @vipps
end

#wechat_payObject (readonly)

Attribute for field wechat_pay



1877
1878
1879
# File 'lib/stripe/resources/confirmation_token.rb', line 1877

def wechat_pay
  @wechat_pay
end

#zipObject (readonly)

Attribute for field zip



1879
1880
1881
# File 'lib/stripe/resources/confirmation_token.rb', line 1879

def zip
  @zip
end

Class Method Details

.field_remappingsObject



1954
1955
1956
# File 'lib/stripe/resources/confirmation_token.rb', line 1954

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
1916
1917
1918
1919
1920
1921
1922
1923
1924
1925
1926
1927
1928
1929
1930
1931
1932
1933
1934
1935
1936
1937
1938
1939
1940
1941
1942
1943
1944
1945
1946
1947
1948
1949
1950
1951
1952
# File 'lib/stripe/resources/confirmation_token.rb', line 1881

def self.inner_class_types
  @inner_class_types = {
    acss_debit: AcssDebit,
    affirm: Affirm,
    afterpay_clearpay: AfterpayClearpay,
    alipay: Alipay,
    alma: Alma,
    amazon_pay: AmazonPay,
    au_becs_debit: AuBecsDebit,
    bacs_debit: BacsDebit,
    bancontact: Bancontact,
    billie: Billie,
    billing_details: BillingDetails,
    bizum: Bizum,
    blik: Blik,
    boleto: Boleto,
    card: Card,
    card_present: CardPresent,
    cashapp: Cashapp,
    crypto: Crypto,
    customer_balance: CustomerBalance,
    eps: Eps,
    fpx: Fpx,
    gift_card: GiftCard,
    giropay: Giropay,
    gopay: Gopay,
    grabpay: Grabpay,
    id_bank_transfer: IdBankTransfer,
    ideal: Ideal,
    interac_present: InteracPresent,
    kakao_pay: KakaoPay,
    klarna: Klarna,
    konbini: Konbini,
    kr_card: KrCard,
    link: Link,
    mb_way: MbWay,
    mobilepay: Mobilepay,
    multibanco: Multibanco,
    naver_pay: NaverPay,
    nz_bank_account: NzBankAccount,
    oxxo: Oxxo,
    p24: P24,
    pay_by_bank: PayByBank,
    payco: Payco,
    paynow: Paynow,
    paypal: Paypal,
    paypay: Paypay,
    payto: Payto,
    pix: Pix,
    promptpay: Promptpay,
    qris: Qris,
    rechnung: Rechnung,
    revolut_pay: RevolutPay,
    samsung_pay: SamsungPay,
    satispay: Satispay,
    scalapay: Scalapay,
    sepa_debit: SepaDebit,
    sequra: Sequra,
    shopeepay: Shopeepay,
    sofort: Sofort,
    stripe_balance: StripeBalance,
    sunbit: Sunbit,
    swish: Swish,
    tamara: Tamara,
    twint: Twint,
    upi: Upi,
    us_bank_account: UsBankAccount,
    vipps: Vipps,
    wechat_pay: WechatPay,
    zip: Zip,
  }
end