Class: Stripe::ConfirmationToken::PaymentMethodPreview::AcssDebit

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/confirmation_token.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_nameObject (readonly)

Name of the bank associated with the bank account.



62
63
64
# File 'lib/stripe/resources/confirmation_token.rb', line 62

def bank_name
  @bank_name
end

#fingerprintObject (readonly)

Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.



64
65
66
# File 'lib/stripe/resources/confirmation_token.rb', line 64

def fingerprint
  @fingerprint
end

#institution_numberObject (readonly)

Institution number of the bank account.



66
67
68
# File 'lib/stripe/resources/confirmation_token.rb', line 66

def institution_number
  @institution_number
end

#last4Object (readonly)

Last four digits of the bank account number.



68
69
70
# File 'lib/stripe/resources/confirmation_token.rb', line 68

def last4
  @last4
end

#transit_numberObject (readonly)

Transit number of the bank account.



70
71
72
# File 'lib/stripe/resources/confirmation_token.rb', line 70

def transit_number
  @transit_number
end