Class: Stripe::ConfirmationToken::PaymentMethodPreview::AuBecsDebit

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/confirmation_token.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bsb_numberObject (readonly)

Six-digit number identifying bank and branch associated with this bank account.



81
82
83
# File 'lib/stripe/resources/confirmation_token.rb', line 81

def bsb_number
  @bsb_number
end

#fingerprintObject (readonly)

Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.



83
84
85
# File 'lib/stripe/resources/confirmation_token.rb', line 83

def fingerprint
  @fingerprint
end

#last4Object (readonly)

Last four digits of the bank account number.



85
86
87
# File 'lib/stripe/resources/confirmation_token.rb', line 85

def last4
  @last4
end