Class: Stripe::ConfirmationToken::PaymentMethodPreview::Card::GeneratedFrom::PaymentMethodDetails::CardPresent

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/confirmation_token.rb

Defined Under Namespace

Classes: Multicapture, Offline, Reauthorization, Receipt, Wallet

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amount_authorizedObject (readonly)

The authorized amount



444
445
446
# File 'lib/stripe/resources/confirmation_token.rb', line 444

def amount_authorized
  @amount_authorized
end

#brandObject (readonly)

Card brand. Can be amex, cartes_bancaires, diners, discover, eftpos_au, jcb, link, mastercard, unionpay, visa or unknown.



446
447
448
# File 'lib/stripe/resources/confirmation_token.rb', line 446

def brand
  @brand
end

#brand_productObject (readonly)

The product code that identifies the specific program or product associated with a card.



448
449
450
# File 'lib/stripe/resources/confirmation_token.rb', line 448

def brand_product
  @brand_product
end

#capture_beforeObject (readonly)

When using manual capture, a future timestamp after which the charge will be automatically refunded if uncaptured.



450
451
452
# File 'lib/stripe/resources/confirmation_token.rb', line 450

def capture_before
  @capture_before
end

#cardholder_nameObject (readonly)

The cardholder name as read from the card, in ISO 7813 format. May include alphanumeric characters, special characters and first/last name separator (/). In some cases, the cardholder name may not be available depending on how the issuer has configured the card. Cardholder name is typically not available on swipe or contactless payments, such as those made with Apple Pay and Google Pay.



452
453
454
# File 'lib/stripe/resources/confirmation_token.rb', line 452

def cardholder_name
  @cardholder_name
end

#countryObject (readonly)

Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you've collected.



454
455
456
# File 'lib/stripe/resources/confirmation_token.rb', line 454

def country
  @country
end

#descriptionObject (readonly)

A high-level description of the type of cards issued in this range. (For internal use only and not typically available in standard API requests.)



456
457
458
# File 'lib/stripe/resources/confirmation_token.rb', line 456

def description
  @description
end

#emv_auth_dataObject (readonly)

Authorization response cryptogram.



458
459
460
# File 'lib/stripe/resources/confirmation_token.rb', line 458

def emv_auth_data
  @emv_auth_data
end

#exp_monthObject (readonly)

Two-digit number representing the card's expiration month.



460
461
462
# File 'lib/stripe/resources/confirmation_token.rb', line 460

def exp_month
  @exp_month
end

#exp_yearObject (readonly)

Four-digit number representing the card's expiration year.



462
463
464
# File 'lib/stripe/resources/confirmation_token.rb', line 462

def exp_year
  @exp_year
end

#fingerprintObject (readonly)

Uniquely identifies this particular card number. You can use this attribute to check whether two customers who’ve signed up with you are using the same card number, for example. For payment methods that tokenize card information (Apple Pay, Google Pay), the tokenized number might be provided instead of the underlying card number.

As of May 1, 2021, card fingerprint in India for Connect changed to allow two fingerprints for the same card---one for India and one for the rest of the world.



466
467
468
# File 'lib/stripe/resources/confirmation_token.rb', line 466

def fingerprint
  @fingerprint
end

#fundingObject (readonly)

Card funding type. Can be credit, debit, prepaid, or unknown.



468
469
470
# File 'lib/stripe/resources/confirmation_token.rb', line 468

def funding
  @funding
end

#generated_cardObject (readonly)

ID of a card PaymentMethod generated from the card_present PaymentMethod that may be attached to a Customer for future transactions. Only present if it was possible to generate a card PaymentMethod.



470
471
472
# File 'lib/stripe/resources/confirmation_token.rb', line 470

def generated_card
  @generated_card
end

#iinObject (readonly)

Issuer identification number of the card. (For internal use only and not typically available in standard API requests.)



472
473
474
# File 'lib/stripe/resources/confirmation_token.rb', line 472

def iin
  @iin
end

#incremental_authorization_supportedObject (readonly)

Whether this PaymentIntent is eligible for incremental authorizations. Request support using request_incremental_authorization_support.



474
475
476
# File 'lib/stripe/resources/confirmation_token.rb', line 474

def incremental_authorization_supported
  @incremental_authorization_supported
end

#issuerObject (readonly)

The name of the card's issuing bank. (For internal use only and not typically available in standard API requests.)



476
477
478
# File 'lib/stripe/resources/confirmation_token.rb', line 476

def issuer
  @issuer
end

#last4Object (readonly)

The last four digits of the card.



478
479
480
# File 'lib/stripe/resources/confirmation_token.rb', line 478

def last4
  @last4
end

#locationObject (readonly)

ID of the location that this transaction's reader is assigned to.



480
481
482
# File 'lib/stripe/resources/confirmation_token.rb', line 480

def location
  @location
end

#multicaptureObject (readonly)

Attribute for field multicapture



482
483
484
# File 'lib/stripe/resources/confirmation_token.rb', line 482

def multicapture
  @multicapture
end

#networkObject (readonly)

Identifies which network this charge was processed on. Can be amex, cartes_bancaires, diners, discover, eftpos_au, interac, jcb, link, mastercard, unionpay, visa, or unknown.



484
485
486
# File 'lib/stripe/resources/confirmation_token.rb', line 484

def network
  @network
end

#network_transaction_idObject (readonly)

This is used by the financial networks to identify a transaction. Visa calls this the Transaction ID, Mastercard calls this the Trace ID, and American Express calls this the Acquirer Reference Data. This value will be present if it is returned by the financial network in the authorization response, and null otherwise.



486
487
488
# File 'lib/stripe/resources/confirmation_token.rb', line 486

def network_transaction_id
  @network_transaction_id
end

#offlineObject (readonly)

Details about payments collected offline.



488
489
490
# File 'lib/stripe/resources/confirmation_token.rb', line 488

def offline
  @offline
end

#overcapture_supportedObject (readonly)

Defines whether the authorized amount can be over-captured or not



490
491
492
# File 'lib/stripe/resources/confirmation_token.rb', line 490

def overcapture_supported
  @overcapture_supported
end

#preferred_localesObject (readonly)

The languages that the issuing bank recommends using for localizing any customer-facing text, as read from the card. Referenced from EMV tag 5F2D, data encoded on the card's chip.



492
493
494
# File 'lib/stripe/resources/confirmation_token.rb', line 492

def preferred_locales
  @preferred_locales
end

#read_methodObject (readonly)

How card details were read in this transaction.



494
495
496
# File 'lib/stripe/resources/confirmation_token.rb', line 494

def read_method
  @read_method
end

#readerObject (readonly)

ID of the reader this transaction was made on.



496
497
498
# File 'lib/stripe/resources/confirmation_token.rb', line 496

def reader
  @reader
end

#reauthorizationObject (readonly)

Whether the PaymentIntent can be reauthorized or not.



498
499
500
# File 'lib/stripe/resources/confirmation_token.rb', line 498

def reauthorization
  @reauthorization
end

#reauthorize_beforeObject (readonly)

The time at which the associated PaymentIntent will transition to a terminal state if it is not reauthorized.



500
501
502
# File 'lib/stripe/resources/confirmation_token.rb', line 500

def reauthorize_before
  @reauthorize_before
end

#receiptObject (readonly)

A collection of fields required to be displayed on receipts. Only required for EMV transactions.



502
503
504
# File 'lib/stripe/resources/confirmation_token.rb', line 502

def receipt
  @receipt
end

#retrieval_reference_numberObject (readonly)

The retrieval reference number assigned to this transaction.



504
505
506
# File 'lib/stripe/resources/confirmation_token.rb', line 504

def retrieval_reference_number
  @retrieval_reference_number
end

#walletObject (readonly)

Attribute for field wallet



506
507
508
# File 'lib/stripe/resources/confirmation_token.rb', line 506

def wallet
  @wallet
end

Class Method Details

.field_remappingsObject



518
519
520
# File 'lib/stripe/resources/confirmation_token.rb', line 518

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



508
509
510
511
512
513
514
515
516
# File 'lib/stripe/resources/confirmation_token.rb', line 508

def self.inner_class_types
  @inner_class_types = {
    multicapture: Multicapture,
    offline: Offline,
    reauthorization: Reauthorization,
    receipt: Receipt,
    wallet: Wallet,
  }
end