Class: Stripe::ConfirmationToken::PaymentMethodPreview::Card::Wallet

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/confirmation_token.rb

Defined Under Namespace

Classes: AmexExpressCheckout, ApplePay, GooglePay, Link, Masterpass, SamsungPay, VisaCheckout

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amex_express_checkoutObject (readonly)

Attribute for field amex_express_checkout



764
765
766
# File 'lib/stripe/resources/confirmation_token.rb', line 764

def amex_express_checkout
  @amex_express_checkout
end

#apple_payObject (readonly)

Attribute for field apple_pay



766
767
768
# File 'lib/stripe/resources/confirmation_token.rb', line 766

def apple_pay
  @apple_pay
end

#dynamic_last4Object (readonly)

(For tokenized numbers only.) The last four digits of the device account number.



768
769
770
# File 'lib/stripe/resources/confirmation_token.rb', line 768

def dynamic_last4
  @dynamic_last4
end

#google_payObject (readonly)

Attribute for field google_pay



770
771
772
# File 'lib/stripe/resources/confirmation_token.rb', line 770

def google_pay
  @google_pay
end

Attribute for field link



772
773
774
# File 'lib/stripe/resources/confirmation_token.rb', line 772

def link
  @link
end

#masterpassObject (readonly)

Attribute for field masterpass



774
775
776
# File 'lib/stripe/resources/confirmation_token.rb', line 774

def masterpass
  @masterpass
end

#samsung_payObject (readonly)

Attribute for field samsung_pay



776
777
778
# File 'lib/stripe/resources/confirmation_token.rb', line 776

def samsung_pay
  @samsung_pay
end

#typeObject (readonly)

The type of the card wallet, one of amex_express_checkout, apple_pay, google_pay, masterpass, samsung_pay, visa_checkout, or link. An additional hash is included on the Wallet subhash with a name matching this value. It contains additional information specific to the card wallet type.



778
779
780
# File 'lib/stripe/resources/confirmation_token.rb', line 778

def type
  @type
end

#visa_checkoutObject (readonly)

Attribute for field visa_checkout



780
781
782
# File 'lib/stripe/resources/confirmation_token.rb', line 780

def visa_checkout
  @visa_checkout
end

Class Method Details

.field_remappingsObject



794
795
796
# File 'lib/stripe/resources/confirmation_token.rb', line 794

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



782
783
784
785
786
787
788
789
790
791
792
# File 'lib/stripe/resources/confirmation_token.rb', line 782

def self.inner_class_types
  @inner_class_types = {
    amex_express_checkout: AmexExpressCheckout,
    apple_pay: ApplePay,
    google_pay: GooglePay,
    link: Link,
    masterpass: Masterpass,
    samsung_pay: SamsungPay,
    visa_checkout: VisaCheckout,
  }
end