Class: Stripe::ConfirmationToken::PaymentMethodPreview::CardPresent
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::ConfirmationToken::PaymentMethodPreview::CardPresent
- Defined in:
- lib/stripe/resources/confirmation_token.rb
Defined Under Namespace
Classes: Networks, Offline, Wallet
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#brand ⇒ Object
readonly
Card brand.
-
#brand_product ⇒ Object
readonly
The product code that identifies the specific program or product associated with a card.
-
#cardholder_name ⇒ Object
readonly
The cardholder name as read from the card, in ISO 7813 format.
-
#country ⇒ Object
readonly
Two-letter ISO code representing the country of the card.
-
#description ⇒ Object
readonly
A high-level description of the type of cards issued in this range.
-
#exp_month ⇒ Object
readonly
Two-digit number representing the card's expiration month.
-
#exp_year ⇒ Object
readonly
Four-digit number representing the card's expiration year.
-
#fingerprint ⇒ Object
readonly
Uniquely identifies this particular card number.
-
#funding ⇒ Object
readonly
Card funding type.
-
#iin ⇒ Object
readonly
Issuer identification number of the card.
-
#issuer ⇒ Object
readonly
The name of the card's issuing bank.
-
#last4 ⇒ Object
readonly
The last four digits of the card.
-
#networks ⇒ Object
readonly
Contains information about card networks that can be used to process the payment.
-
#offline ⇒ Object
readonly
Details about payment methods collected offline.
-
#preferred_locales ⇒ Object
readonly
The languages that the issuing bank recommends using for localizing any customer-facing text, as read from the card.
-
#read_method ⇒ Object
readonly
How card details were read in this transaction.
-
#wallet ⇒ Object
readonly
Attribute for field wallet.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#brand ⇒ Object (readonly)
Card brand. Can be amex, cartes_bancaires, diners, discover, eftpos_au, jcb, link, mastercard, unionpay, visa or unknown.
897 898 899 |
# File 'lib/stripe/resources/confirmation_token.rb', line 897 def brand @brand end |
#brand_product ⇒ Object (readonly)
The product code that identifies the specific program or product associated with a card.
899 900 901 |
# File 'lib/stripe/resources/confirmation_token.rb', line 899 def brand_product @brand_product end |
#cardholder_name ⇒ Object (readonly)
The cardholder name as read from the card, in ISO 7813 format. May include alphanumeric characters, special characters and first/last name separator (/). In some cases, the cardholder name may not be available depending on how the issuer has configured the card. Cardholder name is typically not available on swipe or contactless payments, such as those made with Apple Pay and Google Pay.
901 902 903 |
# File 'lib/stripe/resources/confirmation_token.rb', line 901 def cardholder_name @cardholder_name end |
#country ⇒ Object (readonly)
Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you've collected.
903 904 905 |
# File 'lib/stripe/resources/confirmation_token.rb', line 903 def country @country end |
#description ⇒ Object (readonly)
A high-level description of the type of cards issued in this range. (For internal use only and not typically available in standard API requests.)
905 906 907 |
# File 'lib/stripe/resources/confirmation_token.rb', line 905 def description @description end |
#exp_month ⇒ Object (readonly)
Two-digit number representing the card's expiration month.
907 908 909 |
# File 'lib/stripe/resources/confirmation_token.rb', line 907 def exp_month @exp_month end |
#exp_year ⇒ Object (readonly)
Four-digit number representing the card's expiration year.
909 910 911 |
# File 'lib/stripe/resources/confirmation_token.rb', line 909 def exp_year @exp_year end |
#fingerprint ⇒ Object (readonly)
Uniquely identifies this particular card number. You can use this attribute to check whether two customers who’ve signed up with you are using the same card number, for example. For payment methods that tokenize card information (Apple Pay, Google Pay), the tokenized number might be provided instead of the underlying card number.
As of May 1, 2021, card fingerprint in India for Connect changed to allow two fingerprints for the same card---one for India and one for the rest of the world.
913 914 915 |
# File 'lib/stripe/resources/confirmation_token.rb', line 913 def fingerprint @fingerprint end |
#funding ⇒ Object (readonly)
Card funding type. Can be credit, debit, prepaid, or unknown.
915 916 917 |
# File 'lib/stripe/resources/confirmation_token.rb', line 915 def funding @funding end |
#iin ⇒ Object (readonly)
Issuer identification number of the card. (For internal use only and not typically available in standard API requests.)
917 918 919 |
# File 'lib/stripe/resources/confirmation_token.rb', line 917 def iin @iin end |
#issuer ⇒ Object (readonly)
The name of the card's issuing bank. (For internal use only and not typically available in standard API requests.)
919 920 921 |
# File 'lib/stripe/resources/confirmation_token.rb', line 919 def issuer @issuer end |
#last4 ⇒ Object (readonly)
The last four digits of the card.
921 922 923 |
# File 'lib/stripe/resources/confirmation_token.rb', line 921 def last4 @last4 end |
#networks ⇒ Object (readonly)
Contains information about card networks that can be used to process the payment.
923 924 925 |
# File 'lib/stripe/resources/confirmation_token.rb', line 923 def networks @networks end |
#offline ⇒ Object (readonly)
Details about payment methods collected offline.
925 926 927 |
# File 'lib/stripe/resources/confirmation_token.rb', line 925 def offline @offline end |
#preferred_locales ⇒ Object (readonly)
The languages that the issuing bank recommends using for localizing any customer-facing text, as read from the card. Referenced from EMV tag 5F2D, data encoded on the card's chip.
927 928 929 |
# File 'lib/stripe/resources/confirmation_token.rb', line 927 def preferred_locales @preferred_locales end |
#read_method ⇒ Object (readonly)
How card details were read in this transaction.
929 930 931 |
# File 'lib/stripe/resources/confirmation_token.rb', line 929 def read_method @read_method end |
#wallet ⇒ Object (readonly)
Attribute for field wallet
931 932 933 |
# File 'lib/stripe/resources/confirmation_token.rb', line 931 def wallet @wallet end |
Class Method Details
.field_remappings ⇒ Object
937 938 939 |
# File 'lib/stripe/resources/confirmation_token.rb', line 937 def self.field_remappings @field_remappings = {} end |