Class: Stripe::ConfirmationToken::PaymentMethodPreview::GiftCard

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/confirmation_token.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#brandObject (readonly)

The brand of the gift card.



983
984
985
# File 'lib/stripe/resources/confirmation_token.rb', line 983

def brand
  @brand
end

#exp_monthObject (readonly)

The expiration month of the gift card.



985
986
987
# File 'lib/stripe/resources/confirmation_token.rb', line 985

def exp_month
  @exp_month
end

#exp_yearObject (readonly)

The expiration year of the gift card.



987
988
989
# File 'lib/stripe/resources/confirmation_token.rb', line 987

def exp_year
  @exp_year
end

#fingerprintObject (readonly)

Uniquely identifies the gift card.



989
990
991
# File 'lib/stripe/resources/confirmation_token.rb', line 989

def fingerprint
  @fingerprint
end

#first6Object (readonly)

The first six digits of the gift card number.



991
992
993
# File 'lib/stripe/resources/confirmation_token.rb', line 991

def first6
  @first6
end

#last4Object (readonly)

The last four digits of the gift card number.



993
994
995
# File 'lib/stripe/resources/confirmation_token.rb', line 993

def last4
  @last4
end

Class Method Details

.field_remappingsObject



999
1000
1001
# File 'lib/stripe/resources/confirmation_token.rb', line 999

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



995
996
997
# File 'lib/stripe/resources/confirmation_token.rb', line 995

def self.inner_class_types
  @inner_class_types = {}
end