Class: Stripe::ConfirmationToken::PaymentMethodPreview::NaverPay

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/confirmation_token.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#buyer_idObject (readonly)

Uniquely identifies this particular Naver Pay account. You can use this attribute to check whether two Naver Pay accounts are the same.



1171
1172
1173
# File 'lib/stripe/resources/confirmation_token.rb', line 1171

def buyer_id
  @buyer_id
end

#fundingObject (readonly)

Whether to fund this transaction with Naver Pay points or a card.



1173
1174
1175
# File 'lib/stripe/resources/confirmation_token.rb', line 1173

def funding
  @funding
end

Class Method Details

.field_remappingsObject



1179
1180
1181
# File 'lib/stripe/resources/confirmation_token.rb', line 1179

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1175
1176
1177
# File 'lib/stripe/resources/confirmation_token.rb', line 1175

def self.inner_class_types
  @inner_class_types = {}
end