Class: Stripe::ConfirmationToken::PaymentMethodPreview::SepaDebit

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/confirmation_token.rb

Defined Under Namespace

Classes: GeneratedFrom

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_codeObject (readonly)

Bank code of bank associated with the bank account.



1405
1406
1407
# File 'lib/stripe/resources/confirmation_token.rb', line 1405

def bank_code
  @bank_code
end

#branch_codeObject (readonly)

Branch code of bank associated with the bank account.



1407
1408
1409
# File 'lib/stripe/resources/confirmation_token.rb', line 1407

def branch_code
  @branch_code
end

#countryObject (readonly)

Two-letter ISO code representing the country the bank account is located in.



1409
1410
1411
# File 'lib/stripe/resources/confirmation_token.rb', line 1409

def country
  @country
end

#fingerprintObject (readonly)

Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.



1411
1412
1413
# File 'lib/stripe/resources/confirmation_token.rb', line 1411

def fingerprint
  @fingerprint
end

#generated_fromObject (readonly)

Information about the object that generated this PaymentMethod.



1413
1414
1415
# File 'lib/stripe/resources/confirmation_token.rb', line 1413

def generated_from
  @generated_from
end

#last4Object (readonly)

Last four characters of the IBAN.



1415
1416
1417
# File 'lib/stripe/resources/confirmation_token.rb', line 1415

def last4
  @last4
end

Class Method Details

.field_remappingsObject



1421
1422
1423
# File 'lib/stripe/resources/confirmation_token.rb', line 1421

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1417
1418
1419
# File 'lib/stripe/resources/confirmation_token.rb', line 1417

def self.inner_class_types
  @inner_class_types = { generated_from: GeneratedFrom }
end