Class: Stripe::ConfirmationToken::PaymentMethodPreview::Sofort
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::ConfirmationToken::PaymentMethodPreview::Sofort
- Defined in:
- lib/stripe/resources/confirmation_token.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#country ⇒ Object
readonly
Two-letter ISO code representing the country the bank account is located in.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#country ⇒ Object (readonly)
Two-letter ISO code representing the country the bank account is located in.
681 682 683 |
# File 'lib/stripe/resources/confirmation_token.rb', line 681 def country @country end |