Class: Stripe::ConfirmationToken::PaymentMethodPreview::StripeBalance
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::ConfirmationToken::PaymentMethodPreview::StripeBalance
- Defined in:
- lib/stripe/resources/confirmation_token.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account ⇒ Object
readonly
The connected account ID whose Stripe balance to use as the source of payment.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account ⇒ Object (readonly)
The connected account ID whose Stripe balance to use as the source of payment
1451 1452 1453 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1451 def account @account end |
Class Method Details
.field_remappings ⇒ Object
1457 1458 1459 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1457 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1453 1454 1455 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1453 def self.inner_class_types @inner_class_types = {} end |