Class: Stripe::ConfirmationToken::PaymentMethodPreview::UsBankAccount

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/confirmation_token.rb

Defined Under Namespace

Classes: Networks, StatusDetails

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_holder_typeObject (readonly)

Account holder type: individual or company.



1633
1634
1635
# File 'lib/stripe/resources/confirmation_token.rb', line 1633

def 
  @account_holder_type
end

#account_numberObject (readonly)

Account number of the bank account.



1635
1636
1637
# File 'lib/stripe/resources/confirmation_token.rb', line 1635

def 
  @account_number
end

#account_typeObject (readonly)

Account type: checkings or savings. Defaults to checking if omitted.



1637
1638
1639
# File 'lib/stripe/resources/confirmation_token.rb', line 1637

def 
  @account_type
end

#bank_nameObject (readonly)

The name of the bank.



1639
1640
1641
# File 'lib/stripe/resources/confirmation_token.rb', line 1639

def bank_name
  @bank_name
end

#financial_connections_accountObject (readonly)

The ID of the Financial Connections Account used to create the payment method.



1641
1642
1643
# File 'lib/stripe/resources/confirmation_token.rb', line 1641

def 
  @financial_connections_account
end

#fingerprintObject (readonly)

Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.



1643
1644
1645
# File 'lib/stripe/resources/confirmation_token.rb', line 1643

def fingerprint
  @fingerprint
end

#last4Object (readonly)

Last four digits of the bank account number.



1645
1646
1647
# File 'lib/stripe/resources/confirmation_token.rb', line 1645

def last4
  @last4
end

#networksObject (readonly)

Contains information about US bank account networks that can be used.



1647
1648
1649
# File 'lib/stripe/resources/confirmation_token.rb', line 1647

def networks
  @networks
end

#routing_numberObject (readonly)

Routing number of the bank account.



1649
1650
1651
# File 'lib/stripe/resources/confirmation_token.rb', line 1649

def routing_number
  @routing_number
end

#status_detailsObject (readonly)

Contains information about the future reusability of this PaymentMethod.



1651
1652
1653
# File 'lib/stripe/resources/confirmation_token.rb', line 1651

def status_details
  @status_details
end

Class Method Details

.field_remappingsObject



1657
1658
1659
# File 'lib/stripe/resources/confirmation_token.rb', line 1657

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1653
1654
1655
# File 'lib/stripe/resources/confirmation_token.rb', line 1653

def self.inner_class_types
  @inner_class_types = { networks: Networks, status_details: StatusDetails }
end