Class: Stripe::ConfirmationToken::RetrieveParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ConfirmationToken::RetrieveParams
- Defined in:
- lib/stripe/resources/confirmation_token.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ RetrieveParams
constructor
A new instance of RetrieveParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ RetrieveParams
Returns a new instance of RetrieveParams.
1063 1064 1065 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1063 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1061 1062 1063 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1061 def @expand end |