Class: Stripe::ConfirmationTokenCreateParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/confirmation_token_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/stripe/params/confirmation_token_create_params.rb', line 229

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



217
218
219
# File 'lib/stripe/params/confirmation_token_create_params.rb', line 217

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



219
220
221
# File 'lib/stripe/params/confirmation_token_create_params.rb', line 219

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



221
222
223
# File 'lib/stripe/params/confirmation_token_create_params.rb', line 221

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



223
224
225
# File 'lib/stripe/params/confirmation_token_create_params.rb', line 223

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



225
226
227
# File 'lib/stripe/params/confirmation_token_create_params.rb', line 225

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



227
228
229
# File 'lib/stripe/params/confirmation_token_create_params.rb', line 227

def suffix
  @suffix
end