Class: Stripe::ConfirmationTokenCreateParams::PaymentMethodData::Upi::MandateOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ConfirmationTokenCreateParams::PaymentMethodData::Upi::MandateOptions
- Defined in:
- lib/stripe/params/confirmation_token_create_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount to be charged for future payments.
-
#amount_type ⇒ Object
One of
fixedormaximum. -
#description ⇒ Object
A description of the mandate or subscription that is meant to be displayed to the customer.
-
#end_date ⇒ Object
End date of the mandate or subscription.
Instance Method Summary collapse
-
#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions
constructor
A new instance of MandateOptions.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions
Returns a new instance of MandateOptions.
306 307 308 309 310 311 |
# File 'lib/stripe/params/confirmation_token_create_params.rb', line 306 def initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) @amount = amount @amount_type = amount_type @description = description @end_date = end_date end |
Instance Attribute Details
#amount ⇒ Object
Amount to be charged for future payments.
298 299 300 |
# File 'lib/stripe/params/confirmation_token_create_params.rb', line 298 def amount @amount end |
#amount_type ⇒ Object
One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.
300 301 302 |
# File 'lib/stripe/params/confirmation_token_create_params.rb', line 300 def amount_type @amount_type end |
#description ⇒ Object
A description of the mandate or subscription that is meant to be displayed to the customer.
302 303 304 |
# File 'lib/stripe/params/confirmation_token_create_params.rb', line 302 def description @description end |
#end_date ⇒ Object
End date of the mandate or subscription.
304 305 306 |
# File 'lib/stripe/params/confirmation_token_create_params.rb', line 304 def end_date @end_date end |