Class: Stripe::ConfirmationTokenCreateParams::PaymentMethodOptions::Card::Installments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ConfirmationTokenCreateParams::PaymentMethodOptions::Card::Installments
- Defined in:
- lib/stripe/params/confirmation_token_create_params.rb
Defined Under Namespace
Classes: Plan
Instance Attribute Summary collapse
-
#plan ⇒ Object
The selected installment plan to use for this payment attempt.
Instance Method Summary collapse
-
#initialize(plan: nil) ⇒ Installments
constructor
A new instance of Installments.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(plan: nil) ⇒ Installments
Returns a new instance of Installments.
602 603 604 |
# File 'lib/stripe/params/confirmation_token_create_params.rb', line 602 def initialize(plan: nil) @plan = plan end |
Instance Attribute Details
#plan ⇒ Object
The selected installment plan to use for this payment attempt. This parameter can only be provided during confirmation.
600 601 602 |
# File 'lib/stripe/params/confirmation_token_create_params.rb', line 600 def plan @plan end |