Class: Stripe::Coupon::Script
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Coupon::Script
- Defined in:
- lib/stripe/resources/coupon.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#configuration ⇒ Object
readonly
The configuration values of the script.
-
#display_name ⇒ Object
readonly
The name of the script used to calculate the discount.
-
#id ⇒ Object
readonly
The script implementation ID for this coupon.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#configuration ⇒ Object (readonly)
The configuration values of the script. The keys and values are specific to the script implementation.
47 48 49 |
# File 'lib/stripe/resources/coupon.rb', line 47 def configuration @configuration end |
#display_name ⇒ Object (readonly)
The name of the script used to calculate the discount.
49 50 51 |
# File 'lib/stripe/resources/coupon.rb', line 49 def display_name @display_name end |
#id ⇒ Object (readonly)
The script implementation ID for this coupon.
51 52 53 |
# File 'lib/stripe/resources/coupon.rb', line 51 def id @id end |
Class Method Details
.field_remappings ⇒ Object
57 58 59 |
# File 'lib/stripe/resources/coupon.rb', line 57 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
53 54 55 |
# File 'lib/stripe/resources/coupon.rb', line 53 def self.inner_class_types @inner_class_types = {} end |