Class: Stripe::Coupon::UpdateParams::CurrencyOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Coupon::UpdateParams::CurrencyOptions
- Defined in:
- lib/stripe/resources/coupon.rb
Instance Attribute Summary collapse
-
#amount_off ⇒ Object
A positive integer representing the amount to subtract from an invoice total.
Instance Method Summary collapse
-
#initialize(amount_off: nil) ⇒ CurrencyOptions
constructor
A new instance of CurrencyOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(amount_off: nil) ⇒ CurrencyOptions
Returns a new instance of CurrencyOptions.
36 37 38 |
# File 'lib/stripe/resources/coupon.rb', line 36 def initialize(amount_off: nil) @amount_off = amount_off end |
Instance Attribute Details
#amount_off ⇒ Object
A positive integer representing the amount to subtract from an invoice total.
34 35 36 |
# File 'lib/stripe/resources/coupon.rb', line 34 def amount_off @amount_off end |