Class: Stripe::CouponCreateParams::ServicePeriod::Iterations
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::CouponCreateParams::ServicePeriod::Iterations
- Defined in:
- lib/stripe/params/coupon_create_params.rb
Instance Attribute Summary collapse
-
#count ⇒ Object
The number of iterations the service period will repeat for.
-
#type ⇒ Object
The type of iterations, defaults to ‘count` if omitted.
Instance Method Summary collapse
-
#initialize(count: nil, type: nil) ⇒ Iterations
constructor
A new instance of Iterations.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(count: nil, type: nil) ⇒ Iterations
Returns a new instance of Iterations.
43 44 45 46 |
# File 'lib/stripe/params/coupon_create_params.rb', line 43 def initialize(count: nil, type: nil) @count = count @type = type end |
Instance Attribute Details
#count ⇒ Object
The number of iterations the service period will repeat for. Only used when type is ‘count`, defaults to 1.
39 40 41 |
# File 'lib/stripe/params/coupon_create_params.rb', line 39 def count @count end |
#type ⇒ Object
The type of iterations, defaults to ‘count` if omitted.
41 42 43 |
# File 'lib/stripe/params/coupon_create_params.rb', line 41 def type @type end |