Class: Stripe::CouponService::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::CouponService::ListParams
- Defined in:
- lib/stripe/services/coupon_service.rb
Defined Under Namespace
Classes: Created
Instance Attribute Summary collapse
-
#created ⇒ Object
A filter on the list, based on the object ‘created` field.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#starting_after ⇒ Object
A cursor for use in pagination.
Instance Method Summary collapse
-
#initialize(created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams
Returns a new instance of ListParams.
72 73 74 75 76 77 78 |
# File 'lib/stripe/services/coupon_service.rb', line 72 def initialize(created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) @created = created @ending_before = ending_before @expand = @limit = limit @starting_after = starting_after end |
Instance Attribute Details
#created ⇒ Object
A filter on the list, based on the object ‘created` field. The value can be a string with an integer Unix timestamp, or it can be a dictionary with a number of different query options.
62 63 64 |
# File 'lib/stripe/services/coupon_service.rb', line 62 def created @created end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
64 65 66 |
# File 'lib/stripe/services/coupon_service.rb', line 64 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
66 67 68 |
# File 'lib/stripe/services/coupon_service.rb', line 66 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
68 69 70 |
# File 'lib/stripe/services/coupon_service.rb', line 68 def limit @limit end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
70 71 72 |
# File 'lib/stripe/services/coupon_service.rb', line 70 def starting_after @starting_after end |