Class: Stripe::CouponService::UpdateParams::CurrencyOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::CouponService::UpdateParams::CurrencyOptions
- Defined in:
- lib/stripe/services/coupon_service.rb
Instance Attribute Summary collapse
-
#amount_off ⇒ Object
A positive integer representing the amount to subtract from an invoice total.
Instance Method Summary collapse
-
#initialize(amount_off: nil) ⇒ CurrencyOptions
constructor
A new instance of CurrencyOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(amount_off: nil) ⇒ CurrencyOptions
Returns a new instance of CurrencyOptions.
23 24 25 |
# File 'lib/stripe/services/coupon_service.rb', line 23 def initialize(amount_off: nil) @amount_off = amount_off end |
Instance Attribute Details
#amount_off ⇒ Object
A positive integer representing the amount to subtract from an invoice total.
21 22 23 |
# File 'lib/stripe/services/coupon_service.rb', line 21 def amount_off @amount_off end |