Class: Stripe::CreditNote::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::CreditNote::CreateParams
- Defined in:
- lib/stripe/resources/credit_note.rb
Defined Under Namespace
Classes: Line, Refund, ShippingCost
Instance Attribute Summary collapse
-
#amount ⇒ Object
The integer amount in cents (or local equivalent) representing the total amount of the credit note.
-
#credit_amount ⇒ Object
The integer amount in cents (or local equivalent) representing the amount to credit the customer’s balance, which will be automatically applied to their next invoice.
-
#effective_at ⇒ Object
The date when this credit note is in effect.
-
#email_type ⇒ Object
Type of email to send to the customer, one of ‘credit_note` or `none` and the default is `credit_note`.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#invoice ⇒ Object
ID of the invoice.
-
#lines ⇒ Object
Line items that make up the credit note.
-
#memo ⇒ Object
The credit note’s memo appears on the credit note PDF.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#out_of_band_amount ⇒ Object
The integer amount in cents (or local equivalent) representing the amount that is credited outside of Stripe.
-
#reason ⇒ Object
Reason for issuing this credit note, one of ‘duplicate`, `fraudulent`, `order_change`, or `product_unsatisfactory`.
-
#refund_amount ⇒ Object
The integer amount in cents (or local equivalent) representing the amount to refund.
-
#refunds ⇒ Object
Refunds to link to this credit note.
-
#shipping_cost ⇒ Object
When shipping_cost contains the shipping_rate from the invoice, the shipping_cost is included in the credit note.
Instance Method Summary collapse
-
#initialize(amount: nil, credit_amount: nil, effective_at: nil, email_type: nil, expand: nil, invoice: nil, lines: nil, memo: nil, metadata: nil, out_of_band_amount: nil, reason: nil, refund_amount: nil, refunds: nil, shipping_cost: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, credit_amount: nil, effective_at: nil, email_type: nil, expand: nil, invoice: nil, lines: nil, memo: nil, metadata: nil, out_of_band_amount: nil, reason: nil, refund_amount: nil, refunds: nil, shipping_cost: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 |
# File 'lib/stripe/resources/credit_note.rb', line 306 def initialize( amount: nil, credit_amount: nil, effective_at: nil, email_type: nil, expand: nil, invoice: nil, lines: nil, memo: nil, metadata: nil, out_of_band_amount: nil, reason: nil, refund_amount: nil, refunds: nil, shipping_cost: nil ) @amount = amount @credit_amount = credit_amount @effective_at = effective_at @email_type = email_type @expand = @invoice = invoice @lines = lines @memo = memo @metadata = @out_of_band_amount = out_of_band_amount @reason = reason @refund_amount = refund_amount @refunds = refunds @shipping_cost = shipping_cost end |
Instance Attribute Details
#amount ⇒ Object
The integer amount in cents (or local equivalent) representing the total amount of the credit note. One of ‘amount`, `lines`, or `shipping_cost` must be provided.
278 279 280 |
# File 'lib/stripe/resources/credit_note.rb', line 278 def amount @amount end |
#credit_amount ⇒ Object
The integer amount in cents (or local equivalent) representing the amount to credit the customer’s balance, which will be automatically applied to their next invoice.
280 281 282 |
# File 'lib/stripe/resources/credit_note.rb', line 280 def credit_amount @credit_amount end |
#effective_at ⇒ Object
The date when this credit note is in effect. Same as ‘created` unless overwritten. When defined, this value replaces the system-generated ’Date of issue’ printed on the credit note PDF.
282 283 284 |
# File 'lib/stripe/resources/credit_note.rb', line 282 def effective_at @effective_at end |
#email_type ⇒ Object
Type of email to send to the customer, one of ‘credit_note` or `none` and the default is `credit_note`.
284 285 286 |
# File 'lib/stripe/resources/credit_note.rb', line 284 def email_type @email_type end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
286 287 288 |
# File 'lib/stripe/resources/credit_note.rb', line 286 def @expand end |
#invoice ⇒ Object
ID of the invoice.
288 289 290 |
# File 'lib/stripe/resources/credit_note.rb', line 288 def invoice @invoice end |
#lines ⇒ Object
Line items that make up the credit note. One of ‘amount`, `lines`, or `shipping_cost` must be provided.
290 291 292 |
# File 'lib/stripe/resources/credit_note.rb', line 290 def lines @lines end |
#memo ⇒ Object
The credit note’s memo appears on the credit note PDF.
292 293 294 |
# File 'lib/stripe/resources/credit_note.rb', line 292 def memo @memo end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
294 295 296 |
# File 'lib/stripe/resources/credit_note.rb', line 294 def @metadata end |
#out_of_band_amount ⇒ Object
The integer amount in cents (or local equivalent) representing the amount that is credited outside of Stripe.
296 297 298 |
# File 'lib/stripe/resources/credit_note.rb', line 296 def out_of_band_amount @out_of_band_amount end |
#reason ⇒ Object
Reason for issuing this credit note, one of ‘duplicate`, `fraudulent`, `order_change`, or `product_unsatisfactory`
298 299 300 |
# File 'lib/stripe/resources/credit_note.rb', line 298 def reason @reason end |
#refund_amount ⇒ Object
The integer amount in cents (or local equivalent) representing the amount to refund. If set, a refund will be created for the charge associated with the invoice.
300 301 302 |
# File 'lib/stripe/resources/credit_note.rb', line 300 def refund_amount @refund_amount end |
#refunds ⇒ Object
Refunds to link to this credit note.
302 303 304 |
# File 'lib/stripe/resources/credit_note.rb', line 302 def refunds @refunds end |
#shipping_cost ⇒ Object
When shipping_cost contains the shipping_rate from the invoice, the shipping_cost is included in the credit note. One of ‘amount`, `lines`, or `shipping_cost` must be provided.
304 305 306 |
# File 'lib/stripe/resources/credit_note.rb', line 304 def shipping_cost @shipping_cost end |