Class: Stripe::CreditNote::CreateParams::Refund

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/credit_note.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_refunded: nil, refund: nil) ⇒ Refund

Returns a new instance of Refund.



207
208
209
210
# File 'lib/stripe/resources/credit_note.rb', line 207

def initialize(amount_refunded: nil, refund: nil)
  @amount_refunded = amount_refunded
  @refund = refund
end

Instance Attribute Details

#amount_refundedObject

Amount of the refund that applies to this credit note, in cents (or local equivalent). Defaults to the entire refund amount.



203
204
205
# File 'lib/stripe/resources/credit_note.rb', line 203

def amount_refunded
  @amount_refunded
end

#refundObject

ID of an existing refund to link this credit note to.



205
206
207
# File 'lib/stripe/resources/credit_note.rb', line 205

def refund
  @refund
end