Class: Stripe::CreditNote::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/credit_note.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(created: nil, customer: nil, customer_account: nil, ending_before: nil, expand: nil, invoice: nil, limit: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/stripe/resources/credit_note.rb', line 178

def initialize(
  created: nil,
  customer: nil,
  customer_account: nil,
  ending_before: nil,
  expand: nil,
  invoice: nil,
  limit: nil,
  starting_after: nil
)
  @created = created
  @customer = customer
  @customer_account = 
  @ending_before = ending_before
  @expand = expand
  @invoice = invoice
  @limit = limit
  @starting_after = starting_after
end

Instance Attribute Details

#createdObject

Only return credit notes that were created during the given date interval.



162
163
164
# File 'lib/stripe/resources/credit_note.rb', line 162

def created
  @created
end

#customerObject

Only return credit notes for the customer specified by this customer ID.



164
165
166
# File 'lib/stripe/resources/credit_note.rb', line 164

def customer
  @customer
end

#customer_accountObject

Only return credit notes for the account specified by this account ID.



166
167
168
# File 'lib/stripe/resources/credit_note.rb', line 166

def 
  @customer_account
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



168
169
170
# File 'lib/stripe/resources/credit_note.rb', line 168

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



170
171
172
# File 'lib/stripe/resources/credit_note.rb', line 170

def expand
  @expand
end

#invoiceObject

Only return credit notes for the invoice specified by this invoice ID.



172
173
174
# File 'lib/stripe/resources/credit_note.rb', line 172

def invoice
  @invoice
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



174
175
176
# File 'lib/stripe/resources/credit_note.rb', line 174

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



176
177
178
# File 'lib/stripe/resources/credit_note.rb', line 176

def starting_after
  @starting_after
end