Class: Stripe::CreditNote::ListPreviewLineItemsParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/credit_note.rb

Defined Under Namespace

Classes: Line, Refund, ShippingCost

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, credit_amount: nil, effective_at: nil, email_type: nil, ending_before: nil, expand: nil, invoice: nil, limit: nil, lines: nil, memo: nil, metadata: nil, out_of_band_amount: nil, reason: nil, refund_amount: nil, refunds: nil, shipping_cost: nil, starting_after: nil) ⇒ ListPreviewLineItemsParams

Returns a new instance of ListPreviewLineItemsParams.



607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
# File 'lib/stripe/resources/credit_note.rb', line 607

def initialize(
  amount: nil,
  credit_amount: nil,
  effective_at: nil,
  email_type: nil,
  ending_before: nil,
  expand: nil,
  invoice: nil,
  limit: nil,
  lines: nil,
  memo: nil,
  metadata: nil,
  out_of_band_amount: nil,
  reason: nil,
  refund_amount: nil,
  refunds: nil,
  shipping_cost: nil,
  starting_after: nil
)
  @amount = amount
  @credit_amount = credit_amount
  @effective_at = effective_at
  @email_type = email_type
  @ending_before = ending_before
  @expand = expand
  @invoice = invoice
  @limit = limit
  @lines = lines
  @memo = memo
  @metadata = 
  @out_of_band_amount = out_of_band_amount
  @reason = reason
  @refund_amount = refund_amount
  @refunds = refunds
  @shipping_cost = shipping_cost
  @starting_after = starting_after
end

Instance Attribute Details

#amountObject

The integer amount in cents (or local equivalent) representing the total amount of the credit note. One of ‘amount`, `lines`, or `shipping_cost` must be provided.



573
574
575
# File 'lib/stripe/resources/credit_note.rb', line 573

def amount
  @amount
end

#credit_amountObject

The integer amount in cents (or local equivalent) representing the amount to credit the customer’s balance, which will be automatically applied to their next invoice.



575
576
577
# File 'lib/stripe/resources/credit_note.rb', line 575

def credit_amount
  @credit_amount
end

#effective_atObject

The date when this credit note is in effect. Same as ‘created` unless overwritten. When defined, this value replaces the system-generated ’Date of issue’ printed on the credit note PDF.



577
578
579
# File 'lib/stripe/resources/credit_note.rb', line 577

def effective_at
  @effective_at
end

#email_typeObject

Type of email to send to the customer, one of ‘credit_note` or `none` and the default is `credit_note`.



579
580
581
# File 'lib/stripe/resources/credit_note.rb', line 579

def email_type
  @email_type
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



581
582
583
# File 'lib/stripe/resources/credit_note.rb', line 581

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



583
584
585
# File 'lib/stripe/resources/credit_note.rb', line 583

def expand
  @expand
end

#invoiceObject

ID of the invoice.



585
586
587
# File 'lib/stripe/resources/credit_note.rb', line 585

def invoice
  @invoice
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



587
588
589
# File 'lib/stripe/resources/credit_note.rb', line 587

def limit
  @limit
end

#linesObject

Line items that make up the credit note. One of ‘amount`, `lines`, or `shipping_cost` must be provided.



589
590
591
# File 'lib/stripe/resources/credit_note.rb', line 589

def lines
  @lines
end

#memoObject

The credit note’s memo appears on the credit note PDF.



591
592
593
# File 'lib/stripe/resources/credit_note.rb', line 591

def memo
  @memo
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



593
594
595
# File 'lib/stripe/resources/credit_note.rb', line 593

def 
  @metadata
end

#out_of_band_amountObject

The integer amount in cents (or local equivalent) representing the amount that is credited outside of Stripe.



595
596
597
# File 'lib/stripe/resources/credit_note.rb', line 595

def out_of_band_amount
  @out_of_band_amount
end

#reasonObject

Reason for issuing this credit note, one of ‘duplicate`, `fraudulent`, `order_change`, or `product_unsatisfactory`



597
598
599
# File 'lib/stripe/resources/credit_note.rb', line 597

def reason
  @reason
end

#refund_amountObject

The integer amount in cents (or local equivalent) representing the amount to refund. If set, a refund will be created for the charge associated with the invoice.



599
600
601
# File 'lib/stripe/resources/credit_note.rb', line 599

def refund_amount
  @refund_amount
end

#refundsObject

Refunds to link to this credit note.



601
602
603
# File 'lib/stripe/resources/credit_note.rb', line 601

def refunds
  @refunds
end

#shipping_costObject

When shipping_cost contains the shipping_rate from the invoice, the shipping_cost is included in the credit note. One of ‘amount`, `lines`, or `shipping_cost` must be provided.



603
604
605
# File 'lib/stripe/resources/credit_note.rb', line 603

def shipping_cost
  @shipping_cost
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



605
606
607
# File 'lib/stripe/resources/credit_note.rb', line 605

def starting_after
  @starting_after
end