Class: Stripe::CreditNote::ListPreviewLineItemsParams::Line

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/credit_note.rb

Defined Under Namespace

Classes: TaxAmount

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, description: nil, invoice_line_item: nil, quantity: nil, tax_amounts: nil, tax_rates: nil, type: nil, unit_amount: nil, unit_amount_decimal: nil) ⇒ Line

Returns a new instance of Line.



529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
# File 'lib/stripe/resources/credit_note.rb', line 529

def initialize(
  amount: nil,
  description: nil,
  invoice_line_item: nil,
  quantity: nil,
  tax_amounts: nil,
  tax_rates: nil,
  type: nil,
  unit_amount: nil,
  unit_amount_decimal: nil
)
  @amount = amount
  @description = description
  @invoice_line_item = invoice_line_item
  @quantity = quantity
  @tax_amounts = tax_amounts
  @tax_rates = tax_rates
  @type = type
  @unit_amount = unit_amount
  @unit_amount_decimal = unit_amount_decimal
end

Instance Attribute Details

#amountObject

The line item amount to credit. Only valid when ‘type` is `invoice_line_item`. If invoice is set up with `automatic_tax=true`, this amount is tax exclusive



511
512
513
# File 'lib/stripe/resources/credit_note.rb', line 511

def amount
  @amount
end

#descriptionObject

The description of the credit note line item. Only valid when the ‘type` is `custom_line_item`.



513
514
515
# File 'lib/stripe/resources/credit_note.rb', line 513

def description
  @description
end

#invoice_line_itemObject

The invoice line item to credit. Only valid when the ‘type` is `invoice_line_item`.



515
516
517
# File 'lib/stripe/resources/credit_note.rb', line 515

def invoice_line_item
  @invoice_line_item
end

#quantityObject

The line item quantity to credit.



517
518
519
# File 'lib/stripe/resources/credit_note.rb', line 517

def quantity
  @quantity
end

#tax_amountsObject

A list of up to 10 tax amounts for the credit note line item. Cannot be mixed with ‘tax_rates`.



519
520
521
# File 'lib/stripe/resources/credit_note.rb', line 519

def tax_amounts
  @tax_amounts
end

#tax_ratesObject

The tax rates which apply to the credit note line item. Only valid when the ‘type` is `custom_line_item` and cannot be mixed with `tax_amounts`.



521
522
523
# File 'lib/stripe/resources/credit_note.rb', line 521

def tax_rates
  @tax_rates
end

#typeObject

Type of the credit note line item, one of ‘invoice_line_item` or `custom_line_item`



523
524
525
# File 'lib/stripe/resources/credit_note.rb', line 523

def type
  @type
end

#unit_amountObject

The integer unit amount in cents (or local equivalent) of the credit note line item. This ‘unit_amount` will be multiplied by the quantity to get the full amount to credit for this line item. Only valid when `type` is `custom_line_item`.



525
526
527
# File 'lib/stripe/resources/credit_note.rb', line 525

def unit_amount
  @unit_amount
end

#unit_amount_decimalObject

Same as ‘unit_amount`, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places. Only one of `unit_amount` and `unit_amount_decimal` can be set.



527
528
529
# File 'lib/stripe/resources/credit_note.rb', line 527

def unit_amount_decimal
  @unit_amount_decimal
end