Class: Stripe::CreditNote::PreviewParams::Refund

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/credit_note.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_refunded: nil, refund: nil) ⇒ Refund

Returns a new instance of Refund.



362
363
364
365
# File 'lib/stripe/resources/credit_note.rb', line 362

def initialize(amount_refunded: nil, refund: nil)
  @amount_refunded = amount_refunded
  @refund = refund
end

Instance Attribute Details

#amount_refundedObject

Amount of the refund that applies to this credit note, in cents (or local equivalent). Defaults to the entire refund amount.



358
359
360
# File 'lib/stripe/resources/credit_note.rb', line 358

def amount_refunded
  @amount_refunded
end

#refundObject

ID of an existing refund to link this credit note to. Required when ‘type` is `refund`.



360
361
362
# File 'lib/stripe/resources/credit_note.rb', line 360

def refund
  @refund
end