Class: Stripe::CreditNote::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/credit_note.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, memo: nil, metadata: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



347
348
349
350
351
# File 'lib/stripe/resources/credit_note.rb', line 347

def initialize(expand: nil, memo: nil, metadata: nil)
  @expand = expand
  @memo = memo
  @metadata = 
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



341
342
343
# File 'lib/stripe/resources/credit_note.rb', line 341

def expand
  @expand
end

#memoObject

Credit note memo.



343
344
345
# File 'lib/stripe/resources/credit_note.rb', line 343

def memo
  @memo
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



345
346
347
# File 'lib/stripe/resources/credit_note.rb', line 345

def 
  @metadata
end