Class: Stripe::CreditNoteCreateParams::Refund::PaymentRecordRefund

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/credit_note_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(payment_record: nil, refund_group: nil) ⇒ PaymentRecordRefund

Returns a new instance of PaymentRecordRefund.



78
79
80
81
# File 'lib/stripe/params/credit_note_create_params.rb', line 78

def initialize(payment_record: nil, refund_group: nil)
  @payment_record = payment_record
  @refund_group = refund_group
end

Instance Attribute Details

#payment_recordObject

The ID of the PaymentRecord with the refund to link to this credit note.



74
75
76
# File 'lib/stripe/params/credit_note_create_params.rb', line 74

def payment_record
  @payment_record
end

#refund_groupObject

The PaymentRecord refund group to link to this credit note. For refunds processed off-Stripe, this will correspond to the processor_details.custom.refund_reference field provided when reporting the refund on the PaymentRecord.



76
77
78
# File 'lib/stripe/params/credit_note_create_params.rb', line 76

def refund_group
  @refund_group
end