Class: Stripe::CreditNoteLineItem::DiscountAmount
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::CreditNoteLineItem::DiscountAmount
- Defined in:
- lib/stripe/resources/credit_note_line_item.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The amount, in cents (or local equivalent), of the discount.
-
#discount ⇒ Object
readonly
The discount that was applied to get this discount amount.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The amount, in cents (or local equivalent), of the discount.
14 15 16 |
# File 'lib/stripe/resources/credit_note_line_item.rb', line 14 def amount @amount end |
#discount ⇒ Object (readonly)
The discount that was applied to get this discount amount.
16 17 18 |
# File 'lib/stripe/resources/credit_note_line_item.rb', line 16 def discount @discount end |