Class: Stripe::CreditNoteLineItem::TaxAmount
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::CreditNoteLineItem::TaxAmount
- Defined in:
- lib/stripe/resources/credit_note_line_item.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The amount, in cents (or local equivalent), of the tax.
-
#inclusive ⇒ Object
readonly
Whether this tax amount is inclusive or exclusive.
-
#tax_rate ⇒ Object
readonly
The tax rate that was applied to get this tax amount.
-
#taxability_reason ⇒ Object
readonly
The reasoning behind this tax, for example, if the product is tax exempt.
-
#taxable_amount ⇒ Object
readonly
The amount on which tax is calculated, in cents (or local equivalent).
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The amount, in cents (or local equivalent), of the tax.
32 33 34 |
# File 'lib/stripe/resources/credit_note_line_item.rb', line 32 def amount @amount end |
#inclusive ⇒ Object (readonly)
Whether this tax amount is inclusive or exclusive.
34 35 36 |
# File 'lib/stripe/resources/credit_note_line_item.rb', line 34 def inclusive @inclusive end |
#tax_rate ⇒ Object (readonly)
The tax rate that was applied to get this tax amount.
36 37 38 |
# File 'lib/stripe/resources/credit_note_line_item.rb', line 36 def tax_rate @tax_rate end |
#taxability_reason ⇒ Object (readonly)
The reasoning behind this tax, for example, if the product is tax exempt. The possible values for this field may be extended as new tax rules are supported.
38 39 40 |
# File 'lib/stripe/resources/credit_note_line_item.rb', line 38 def taxability_reason @taxability_reason end |
#taxable_amount ⇒ Object (readonly)
The amount on which tax is calculated, in cents (or local equivalent).
40 41 42 |
# File 'lib/stripe/resources/credit_note_line_item.rb', line 40 def taxable_amount @taxable_amount end |