Class: Stripe::CreditNoteLineItem::TaxCalculationReference
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::CreditNoteLineItem::TaxCalculationReference
- Defined in:
- lib/stripe/resources/credit_note_line_item.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#calculation_id ⇒ Object
readonly
The calculation identifier for tax calculation response.
-
#calculation_item_id ⇒ Object
readonly
The calculation identifier for tax calculation response line item.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#calculation_id ⇒ Object (readonly)
The calculation identifier for tax calculation response.
32 33 34 |
# File 'lib/stripe/resources/credit_note_line_item.rb', line 32 def calculation_id @calculation_id end |
#calculation_item_id ⇒ Object (readonly)
The calculation identifier for tax calculation response line item.
34 35 36 |
# File 'lib/stripe/resources/credit_note_line_item.rb', line 34 def calculation_item_id @calculation_item_id end |