Class: Stripe::CreditNotePreviewLinesListParams::Refund

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/credit_note_preview_lines_list_params.rb

Defined Under Namespace

Classes: PaymentRecordRefund

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount_refunded: nil, payment_record_refund: nil, refund: nil, type: nil) ⇒ Refund

Returns a new instance of Refund.



92
93
94
95
96
97
# File 'lib/stripe/params/credit_note_preview_lines_list_params.rb', line 92

def initialize(amount_refunded: nil, payment_record_refund: nil, refund: nil, type: nil)
  @amount_refunded = amount_refunded
  @payment_record_refund = payment_record_refund
  @refund = refund
  @type = type
end

Instance Attribute Details

#amount_refundedObject

Amount of the refund that applies to this credit note, in cents (or local equivalent). Defaults to the entire refund amount.



84
85
86
# File 'lib/stripe/params/credit_note_preview_lines_list_params.rb', line 84

def amount_refunded
  @amount_refunded
end

#payment_record_refundObject

The PaymentRecord refund details to link to this credit note. Required when ‘type` is `payment_record_refund`.



86
87
88
# File 'lib/stripe/params/credit_note_preview_lines_list_params.rb', line 86

def payment_record_refund
  @payment_record_refund
end

#refundObject

ID of an existing refund to link this credit note to. Required when ‘type` is `refund`.



88
89
90
# File 'lib/stripe/params/credit_note_preview_lines_list_params.rb', line 88

def refund
  @refund
end

#typeObject

Type of the refund, one of ‘refund` or `payment_record_refund`. Defaults to `refund`.



90
91
92
# File 'lib/stripe/params/credit_note_preview_lines_list_params.rb', line 90

def type
  @type
end