Class: Stripe::CreditNotePreviewLinesService::ListParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/credit_note_preview_lines_service.rb

Defined Under Namespace

Classes: Line, Refund, ShippingCost

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, credit_amount: nil, effective_at: nil, email_type: nil, ending_before: nil, expand: nil, invoice: nil, limit: nil, lines: nil, memo: nil, metadata: nil, out_of_band_amount: nil, reason: nil, refund: nil, refund_amount: nil, refunds: nil, shipping_cost: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
# File 'lib/stripe/services/credit_note_preview_lines_service.rb', line 149

def initialize(
  amount: nil,
  credit_amount: nil,
  effective_at: nil,
  email_type: nil,
  ending_before: nil,
  expand: nil,
  invoice: nil,
  limit: nil,
  lines: nil,
  memo: nil,
  metadata: nil,
  out_of_band_amount: nil,
  reason: nil,
  refund: nil,
  refund_amount: nil,
  refunds: nil,
  shipping_cost: nil,
  starting_after: nil
)
  @amount = amount
  @credit_amount = credit_amount
  @effective_at = effective_at
  @email_type = email_type
  @ending_before = ending_before
  @expand = expand
  @invoice = invoice
  @limit = limit
  @lines = lines
  @memo = memo
  @metadata = 
  @out_of_band_amount = out_of_band_amount
  @reason = reason
  @refund = refund
  @refund_amount = refund_amount
  @refunds = refunds
  @shipping_cost = shipping_cost
  @starting_after = starting_after
end

Instance Attribute Details

#amountObject

The integer amount in cents (or local equivalent) representing the total amount of the credit note.



96
97
98
# File 'lib/stripe/services/credit_note_preview_lines_service.rb', line 96

def amount
  @amount
end

#credit_amountObject

The integer amount in cents (or local equivalent) representing the amount to credit the customer’s balance, which will be automatically applied to their next invoice.



99
100
101
# File 'lib/stripe/services/credit_note_preview_lines_service.rb', line 99

def credit_amount
  @credit_amount
end

#effective_atObject

The date when this credit note is in effect. Same as ‘created` unless overwritten. When defined, this value replaces the system-generated ’Date of issue’ printed on the credit note PDF.



102
103
104
# File 'lib/stripe/services/credit_note_preview_lines_service.rb', line 102

def effective_at
  @effective_at
end

#email_typeObject

Type of email to send to the customer, one of ‘credit_note` or `none` and the default is `credit_note`.



105
106
107
# File 'lib/stripe/services/credit_note_preview_lines_service.rb', line 105

def email_type
  @email_type
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



108
109
110
# File 'lib/stripe/services/credit_note_preview_lines_service.rb', line 108

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



111
112
113
# File 'lib/stripe/services/credit_note_preview_lines_service.rb', line 111

def expand
  @expand
end

#invoiceObject

ID of the invoice.



114
115
116
# File 'lib/stripe/services/credit_note_preview_lines_service.rb', line 114

def invoice
  @invoice
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



117
118
119
# File 'lib/stripe/services/credit_note_preview_lines_service.rb', line 117

def limit
  @limit
end

#linesObject

Line items that make up the credit note.



120
121
122
# File 'lib/stripe/services/credit_note_preview_lines_service.rb', line 120

def lines
  @lines
end

#memoObject

The credit note’s memo appears on the credit note PDF.



123
124
125
# File 'lib/stripe/services/credit_note_preview_lines_service.rb', line 123

def memo
  @memo
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



126
127
128
# File 'lib/stripe/services/credit_note_preview_lines_service.rb', line 126

def 
  @metadata
end

#out_of_band_amountObject

The integer amount in cents (or local equivalent) representing the amount that is credited outside of Stripe.



129
130
131
# File 'lib/stripe/services/credit_note_preview_lines_service.rb', line 129

def out_of_band_amount
  @out_of_band_amount
end

#reasonObject

Reason for issuing this credit note, one of ‘duplicate`, `fraudulent`, `order_change`, or `product_unsatisfactory`



132
133
134
# File 'lib/stripe/services/credit_note_preview_lines_service.rb', line 132

def reason
  @reason
end

#refundObject

ID of an existing refund to link this credit note to.



135
136
137
# File 'lib/stripe/services/credit_note_preview_lines_service.rb', line 135

def refund
  @refund
end

#refund_amountObject

The integer amount in cents (or local equivalent) representing the amount to refund. If set, a refund will be created for the charge associated with the invoice.



138
139
140
# File 'lib/stripe/services/credit_note_preview_lines_service.rb', line 138

def refund_amount
  @refund_amount
end

#refundsObject

Refunds to link to this credit note.



141
142
143
# File 'lib/stripe/services/credit_note_preview_lines_service.rb', line 141

def refunds
  @refunds
end

#shipping_costObject

When shipping_cost contains the shipping_rate from the invoice, the shipping_cost is included in the credit note.



144
145
146
# File 'lib/stripe/services/credit_note_preview_lines_service.rb', line 144

def shipping_cost
  @shipping_cost
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



147
148
149
# File 'lib/stripe/services/credit_note_preview_lines_service.rb', line 147

def starting_after
  @starting_after
end