Class: Stripe::CreditNotePreviewLinesService::ListParams::Refund

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/credit_note_preview_lines_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_refunded: nil, refund: nil) ⇒ Refund

Returns a new instance of Refund.



81
82
83
84
# File 'lib/stripe/services/credit_note_preview_lines_service.rb', line 81

def initialize(amount_refunded: nil, refund: nil)
  @amount_refunded = amount_refunded
  @refund = refund
end

Instance Attribute Details

#amount_refundedObject

Amount of the refund that applies to this credit note, in cents (or local equivalent). Defaults to the entire refund amount.



76
77
78
# File 'lib/stripe/services/credit_note_preview_lines_service.rb', line 76

def amount_refunded
  @amount_refunded
end

#refundObject

ID of an existing refund to link this credit note to.



79
80
81
# File 'lib/stripe/services/credit_note_preview_lines_service.rb', line 79

def refund
  @refund
end