Class: Stripe::CreditNoteService::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/credit_note_service.rb

Defined Under Namespace

Classes: Line, Refund, ShippingCost

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, credit_amount: nil, effective_at: nil, email_type: nil, expand: nil, invoice: nil, lines: nil, memo: nil, metadata: nil, out_of_band_amount: nil, reason: nil, refund_amount: nil, refunds: nil, shipping_cost: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/stripe/services/credit_note_service.rb', line 177

def initialize(
  amount: nil,
  credit_amount: nil,
  effective_at: nil,
  email_type: nil,
  expand: nil,
  invoice: nil,
  lines: nil,
  memo: nil,
  metadata: nil,
  out_of_band_amount: nil,
  reason: nil,
  refund_amount: nil,
  refunds: nil,
  shipping_cost: nil
)
  @amount = amount
  @credit_amount = credit_amount
  @effective_at = effective_at
  @email_type = email_type
  @expand = expand
  @invoice = invoice
  @lines = lines
  @memo = memo
  @metadata = 
  @out_of_band_amount = out_of_band_amount
  @reason = reason
  @refund_amount = refund_amount
  @refunds = refunds
  @shipping_cost = shipping_cost
end

Instance Attribute Details

#amountObject

The integer amount in cents (or local equivalent) representing the total amount of the credit note. One of ‘amount`, `lines`, or `shipping_cost` must be provided.



149
150
151
# File 'lib/stripe/services/credit_note_service.rb', line 149

def amount
  @amount
end

#credit_amountObject

The integer amount in cents (or local equivalent) representing the amount to credit the customer’s balance, which will be automatically applied to their next invoice.



151
152
153
# File 'lib/stripe/services/credit_note_service.rb', line 151

def credit_amount
  @credit_amount
end

#effective_atObject

The date when this credit note is in effect. Same as ‘created` unless overwritten. When defined, this value replaces the system-generated ’Date of issue’ printed on the credit note PDF.



153
154
155
# File 'lib/stripe/services/credit_note_service.rb', line 153

def effective_at
  @effective_at
end

#email_typeObject

Type of email to send to the customer, one of ‘credit_note` or `none` and the default is `credit_note`.



155
156
157
# File 'lib/stripe/services/credit_note_service.rb', line 155

def email_type
  @email_type
end

#expandObject

Specifies which fields in the response should be expanded.



157
158
159
# File 'lib/stripe/services/credit_note_service.rb', line 157

def expand
  @expand
end

#invoiceObject

ID of the invoice.



159
160
161
# File 'lib/stripe/services/credit_note_service.rb', line 159

def invoice
  @invoice
end

#linesObject

Line items that make up the credit note. One of ‘amount`, `lines`, or `shipping_cost` must be provided.



161
162
163
# File 'lib/stripe/services/credit_note_service.rb', line 161

def lines
  @lines
end

#memoObject

The credit note’s memo appears on the credit note PDF.



163
164
165
# File 'lib/stripe/services/credit_note_service.rb', line 163

def memo
  @memo
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



165
166
167
# File 'lib/stripe/services/credit_note_service.rb', line 165

def 
  @metadata
end

#out_of_band_amountObject

The integer amount in cents (or local equivalent) representing the amount that is credited outside of Stripe.



167
168
169
# File 'lib/stripe/services/credit_note_service.rb', line 167

def out_of_band_amount
  @out_of_band_amount
end

#reasonObject

Reason for issuing this credit note, one of ‘duplicate`, `fraudulent`, `order_change`, or `product_unsatisfactory`



169
170
171
# File 'lib/stripe/services/credit_note_service.rb', line 169

def reason
  @reason
end

#refund_amountObject

The integer amount in cents (or local equivalent) representing the amount to refund. If set, a refund will be created for the charge associated with the invoice.



171
172
173
# File 'lib/stripe/services/credit_note_service.rb', line 171

def refund_amount
  @refund_amount
end

#refundsObject

Refunds to link to this credit note.



173
174
175
# File 'lib/stripe/services/credit_note_service.rb', line 173

def refunds
  @refunds
end

#shipping_costObject

When shipping_cost contains the shipping_rate from the invoice, the shipping_cost is included in the credit note. One of ‘amount`, `lines`, or `shipping_cost` must be provided.



175
176
177
# File 'lib/stripe/services/credit_note_service.rb', line 175

def shipping_cost
  @shipping_cost
end