Class: Stripe::CreditNoteService::CreateParams::Line::TaxAmount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::CreditNoteService::CreateParams::Line::TaxAmount
- Defined in:
- lib/stripe/services/credit_note_service.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount, in cents (or local equivalent), of the tax.
-
#tax_rate ⇒ Object
The id of the tax rate for this tax amount.
-
#taxable_amount ⇒ Object
The amount on which tax is calculated, in cents (or local equivalent).
Instance Method Summary collapse
-
#initialize(amount: nil, tax_rate: nil, taxable_amount: nil) ⇒ TaxAmount
constructor
A new instance of TaxAmount.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, tax_rate: nil, taxable_amount: nil) ⇒ TaxAmount
Returns a new instance of TaxAmount.
87 88 89 90 91 |
# File 'lib/stripe/services/credit_note_service.rb', line 87 def initialize(amount: nil, tax_rate: nil, taxable_amount: nil) @amount = amount @tax_rate = tax_rate @taxable_amount = taxable_amount end |
Instance Attribute Details
#amount ⇒ Object
The amount, in cents (or local equivalent), of the tax.
79 80 81 |
# File 'lib/stripe/services/credit_note_service.rb', line 79 def amount @amount end |
#tax_rate ⇒ Object
The id of the tax rate for this tax amount. The tax rate must have been automatically created by Stripe.
82 83 84 |
# File 'lib/stripe/services/credit_note_service.rb', line 82 def tax_rate @tax_rate end |
#taxable_amount ⇒ Object
The amount on which tax is calculated, in cents (or local equivalent).
85 86 87 |
# File 'lib/stripe/services/credit_note_service.rb', line 85 def taxable_amount @taxable_amount end |