Class: Stripe::CreditNoteService::PreviewParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::CreditNoteService::PreviewParams
- Defined in:
- lib/stripe/services/credit_note_service.rb
Defined Under Namespace
Classes: Line, Refund, ShippingCost
Instance Attribute Summary collapse
-
#amount ⇒ Object
The integer amount in cents (or local equivalent) representing the total amount of the credit note.
-
#credit_amount ⇒ Object
The integer amount in cents (or local equivalent) representing the amount to credit the customer’s balance, which will be automatically applied to their next invoice.
-
#effective_at ⇒ Object
The date when this credit note is in effect.
-
#email_type ⇒ Object
Type of email to send to the customer, one of ‘credit_note` or `none` and the default is `credit_note`.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#invoice ⇒ Object
ID of the invoice.
-
#lines ⇒ Object
Line items that make up the credit note.
-
#memo ⇒ Object
The credit note’s memo appears on the credit note PDF.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#out_of_band_amount ⇒ Object
The integer amount in cents (or local equivalent) representing the amount that is credited outside of Stripe.
-
#reason ⇒ Object
Reason for issuing this credit note, one of ‘duplicate`, `fraudulent`, `order_change`, or `product_unsatisfactory`.
-
#refund_amount ⇒ Object
The integer amount in cents (or local equivalent) representing the amount to refund.
-
#refunds ⇒ Object
Refunds to link to this credit note.
-
#shipping_cost ⇒ Object
When shipping_cost contains the shipping_rate from the invoice, the shipping_cost is included in the credit note.
Instance Method Summary collapse
-
#initialize(amount: nil, credit_amount: nil, effective_at: nil, email_type: nil, expand: nil, invoice: nil, lines: nil, memo: nil, metadata: nil, out_of_band_amount: nil, reason: nil, refund_amount: nil, refunds: nil, shipping_cost: nil) ⇒ PreviewParams
constructor
A new instance of PreviewParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, credit_amount: nil, effective_at: nil, email_type: nil, expand: nil, invoice: nil, lines: nil, memo: nil, metadata: nil, out_of_band_amount: nil, reason: nil, refund_amount: nil, refunds: nil, shipping_cost: nil) ⇒ PreviewParams
Returns a new instance of PreviewParams.
341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 |
# File 'lib/stripe/services/credit_note_service.rb', line 341 def initialize( amount: nil, credit_amount: nil, effective_at: nil, email_type: nil, expand: nil, invoice: nil, lines: nil, memo: nil, metadata: nil, out_of_band_amount: nil, reason: nil, refund_amount: nil, refunds: nil, shipping_cost: nil ) @amount = amount @credit_amount = credit_amount @effective_at = effective_at @email_type = email_type @expand = @invoice = invoice @lines = lines @memo = memo @metadata = @out_of_band_amount = out_of_band_amount @reason = reason @refund_amount = refund_amount @refunds = refunds @shipping_cost = shipping_cost end |
Instance Attribute Details
#amount ⇒ Object
The integer amount in cents (or local equivalent) representing the total amount of the credit note.
313 314 315 |
# File 'lib/stripe/services/credit_note_service.rb', line 313 def amount @amount end |
#credit_amount ⇒ Object
The integer amount in cents (or local equivalent) representing the amount to credit the customer’s balance, which will be automatically applied to their next invoice.
315 316 317 |
# File 'lib/stripe/services/credit_note_service.rb', line 315 def credit_amount @credit_amount end |
#effective_at ⇒ Object
The date when this credit note is in effect. Same as ‘created` unless overwritten. When defined, this value replaces the system-generated ’Date of issue’ printed on the credit note PDF.
317 318 319 |
# File 'lib/stripe/services/credit_note_service.rb', line 317 def effective_at @effective_at end |
#email_type ⇒ Object
Type of email to send to the customer, one of ‘credit_note` or `none` and the default is `credit_note`.
319 320 321 |
# File 'lib/stripe/services/credit_note_service.rb', line 319 def email_type @email_type end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
321 322 323 |
# File 'lib/stripe/services/credit_note_service.rb', line 321 def @expand end |
#invoice ⇒ Object
ID of the invoice.
323 324 325 |
# File 'lib/stripe/services/credit_note_service.rb', line 323 def invoice @invoice end |
#lines ⇒ Object
Line items that make up the credit note.
325 326 327 |
# File 'lib/stripe/services/credit_note_service.rb', line 325 def lines @lines end |
#memo ⇒ Object
The credit note’s memo appears on the credit note PDF.
327 328 329 |
# File 'lib/stripe/services/credit_note_service.rb', line 327 def memo @memo end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
329 330 331 |
# File 'lib/stripe/services/credit_note_service.rb', line 329 def @metadata end |
#out_of_band_amount ⇒ Object
The integer amount in cents (or local equivalent) representing the amount that is credited outside of Stripe.
331 332 333 |
# File 'lib/stripe/services/credit_note_service.rb', line 331 def out_of_band_amount @out_of_band_amount end |
#reason ⇒ Object
Reason for issuing this credit note, one of ‘duplicate`, `fraudulent`, `order_change`, or `product_unsatisfactory`
333 334 335 |
# File 'lib/stripe/services/credit_note_service.rb', line 333 def reason @reason end |
#refund_amount ⇒ Object
The integer amount in cents (or local equivalent) representing the amount to refund. If set, a refund will be created for the charge associated with the invoice.
335 336 337 |
# File 'lib/stripe/services/credit_note_service.rb', line 335 def refund_amount @refund_amount end |
#refunds ⇒ Object
Refunds to link to this credit note.
337 338 339 |
# File 'lib/stripe/services/credit_note_service.rb', line 337 def refunds @refunds end |
#shipping_cost ⇒ Object
When shipping_cost contains the shipping_rate from the invoice, the shipping_cost is included in the credit note.
339 340 341 |
# File 'lib/stripe/services/credit_note_service.rb', line 339 def shipping_cost @shipping_cost end |