Class: Stripe::CreditNoteService::PreviewParams::Line

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/credit_note_service.rb

Defined Under Namespace

Classes: TaxAmount

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, description: nil, invoice_line_item: nil, quantity: nil, tax_amounts: nil, tax_rates: nil, type: nil, unit_amount: nil, unit_amount_decimal: nil) ⇒ Line

Returns a new instance of Line.



265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
# File 'lib/stripe/services/credit_note_service.rb', line 265

def initialize(
  amount: nil,
  description: nil,
  invoice_line_item: nil,
  quantity: nil,
  tax_amounts: nil,
  tax_rates: nil,
  type: nil,
  unit_amount: nil,
  unit_amount_decimal: nil
)
  @amount = amount
  @description = description
  @invoice_line_item = invoice_line_item
  @quantity = quantity
  @tax_amounts = tax_amounts
  @tax_rates = tax_rates
  @type = type
  @unit_amount = unit_amount
  @unit_amount_decimal = unit_amount_decimal
end

Instance Attribute Details

#amountObject

The line item amount to credit. Only valid when ‘type` is `invoice_line_item`. If invoice is set up with `automatic_tax=true`, this amount is tax exclusive



247
248
249
# File 'lib/stripe/services/credit_note_service.rb', line 247

def amount
  @amount
end

#descriptionObject

The description of the credit note line item. Only valid when the ‘type` is `custom_line_item`.



249
250
251
# File 'lib/stripe/services/credit_note_service.rb', line 249

def description
  @description
end

#invoice_line_itemObject

The invoice line item to credit. Only valid when the ‘type` is `invoice_line_item`.



251
252
253
# File 'lib/stripe/services/credit_note_service.rb', line 251

def invoice_line_item
  @invoice_line_item
end

#quantityObject

The line item quantity to credit.



253
254
255
# File 'lib/stripe/services/credit_note_service.rb', line 253

def quantity
  @quantity
end

#tax_amountsObject

A list of up to 10 tax amounts for the credit note line item. Cannot be mixed with ‘tax_rates`.



255
256
257
# File 'lib/stripe/services/credit_note_service.rb', line 255

def tax_amounts
  @tax_amounts
end

#tax_ratesObject

The tax rates which apply to the credit note line item. Only valid when the ‘type` is `custom_line_item` and cannot be mixed with `tax_amounts`.



257
258
259
# File 'lib/stripe/services/credit_note_service.rb', line 257

def tax_rates
  @tax_rates
end

#typeObject

Type of the credit note line item, one of ‘invoice_line_item` or `custom_line_item`



259
260
261
# File 'lib/stripe/services/credit_note_service.rb', line 259

def type
  @type
end

#unit_amountObject

The integer unit amount in cents (or local equivalent) of the credit note line item. This ‘unit_amount` will be multiplied by the quantity to get the full amount to credit for this line item. Only valid when `type` is `custom_line_item`.



261
262
263
# File 'lib/stripe/services/credit_note_service.rb', line 261

def unit_amount
  @unit_amount
end

#unit_amount_decimalObject

Same as ‘unit_amount`, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places. Only one of `unit_amount` and `unit_amount_decimal` can be set.



263
264
265
# File 'lib/stripe/services/credit_note_service.rb', line 263

def unit_amount_decimal
  @unit_amount_decimal
end