Class: Stripe::CreditNoteService::PreviewParams::Line::TaxAmount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/credit_note_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, tax_rate: nil, taxable_amount: nil) ⇒ TaxAmount

Returns a new instance of TaxAmount.



240
241
242
243
244
# File 'lib/stripe/services/credit_note_service.rb', line 240

def initialize(amount: nil, tax_rate: nil, taxable_amount: nil)
  @amount = amount
  @tax_rate = tax_rate
  @taxable_amount = taxable_amount
end

Instance Attribute Details

#amountObject

The amount, in cents (or local equivalent), of the tax.



234
235
236
# File 'lib/stripe/services/credit_note_service.rb', line 234

def amount
  @amount
end

#tax_rateObject

The id of the tax rate for this tax amount. The tax rate must have been automatically created by Stripe.



236
237
238
# File 'lib/stripe/services/credit_note_service.rb', line 236

def tax_rate
  @tax_rate
end

#taxable_amountObject

The amount on which tax is calculated, in cents (or local equivalent).



238
239
240
# File 'lib/stripe/services/credit_note_service.rb', line 238

def taxable_amount
  @taxable_amount
end