Class: Stripe::Crypto::Customer

Inherits:
APIResource show all
Extended by:
APIOperations::NestedResource
Defined in:
lib/stripe/resources/crypto/customer.rb

Overview

This object represents a crypto onramp customer. Use it to get their kyc status and payment methods.

Defined Under Namespace

Classes: KycTier, Verification

Constant Summary collapse

OBJECT_NAME =
"crypto.customer"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods included from APIOperations::NestedResource

nested_resource_class_methods

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#idObject (readonly)

Unique identifier for the object.



52
53
54
# File 'lib/stripe/resources/crypto/customer.rb', line 52

def id
  @id
end

#kyc_regionObject (readonly)

The KYC region determined by the customer's address country.



54
55
56
# File 'lib/stripe/resources/crypto/customer.rb', line 54

def kyc_region
  @kyc_region
end

#kyc_tiersObject (readonly)

List of KYC tiers and their verification status.



56
57
58
# File 'lib/stripe/resources/crypto/customer.rb', line 56

def kyc_tiers
  @kyc_tiers
end

#objectObject (readonly)

String representing the object's type. Objects of the same type share the same value.



58
59
60
# File 'lib/stripe/resources/crypto/customer.rb', line 58

def object
  @object
end

#provided_fieldsObject (readonly)

The set of KYC Fields provided for this customers.



60
61
62
# File 'lib/stripe/resources/crypto/customer.rb', line 60

def provided_fields
  @provided_fields
end

#verificationsObject (readonly)

List of verifications and their outcome.



62
63
64
# File 'lib/stripe/resources/crypto/customer.rb', line 62

def verifications
  @verifications
end

Class Method Details

.field_remappingsObject



68
69
70
# File 'lib/stripe/resources/crypto/customer.rb', line 68

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



64
65
66
# File 'lib/stripe/resources/crypto/customer.rb', line 64

def self.inner_class_types
  @inner_class_types = { kyc_tiers: KycTier, verifications: Verification }
end

.object_nameObject



11
12
13
# File 'lib/stripe/resources/crypto/customer.rb', line 11

def self.object_name
  "crypto.customer"
end