Class: Stripe::Crypto::CustomerConsumerWallet

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/crypto/customer_consumer_wallet.rb

Overview

A consumer wallet represents a cryptocurrency wallet address associated with a Crypto Customer.

Constant Summary collapse

OBJECT_NAME =
"crypto.consumer_wallet"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#idObject (readonly)

Unique identifier for the object.



14
15
16
# File 'lib/stripe/resources/crypto/customer_consumer_wallet.rb', line 14

def id
  @id
end

#livemodeObject (readonly)

If the object exists in live mode, the value is true. If the object exists in test mode, the value is false.



16
17
18
# File 'lib/stripe/resources/crypto/customer_consumer_wallet.rb', line 16

def livemode
  @livemode
end

#networkObject (readonly)

The blockchain network for this wallet



18
19
20
# File 'lib/stripe/resources/crypto/customer_consumer_wallet.rb', line 18

def network
  @network
end

#objectObject (readonly)

String representing the object's type. Objects of the same type share the same value.



20
21
22
# File 'lib/stripe/resources/crypto/customer_consumer_wallet.rb', line 20

def object
  @object
end

#verified_ownershipObject (readonly)

Whether ownership of this wallet has been verified



22
23
24
# File 'lib/stripe/resources/crypto/customer_consumer_wallet.rb', line 22

def verified_ownership
  @verified_ownership
end

#wallet_addressObject (readonly)

The wallet address



24
25
26
# File 'lib/stripe/resources/crypto/customer_consumer_wallet.rb', line 24

def wallet_address
  @wallet_address
end

Class Method Details

.field_remappingsObject



30
31
32
# File 'lib/stripe/resources/crypto/customer_consumer_wallet.rb', line 30

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



26
27
28
# File 'lib/stripe/resources/crypto/customer_consumer_wallet.rb', line 26

def self.inner_class_types
  @inner_class_types = {}
end

.object_nameObject



9
10
11
# File 'lib/stripe/resources/crypto/customer_consumer_wallet.rb', line 9

def self.object_name
  "crypto.consumer_wallet"
end