Class: Stripe::Crypto::CustomerPaymentToken::Card
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Crypto::CustomerPaymentToken::Card
- Defined in:
- lib/stripe/resources/crypto/customer_payment_token.rb
Defined Under Namespace
Classes: Wallet
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#brand ⇒ Object
readonly
Card brand.
-
#exp_month ⇒ Object
readonly
Two-digit number representing the card’s expiration month.
-
#exp_year ⇒ Object
readonly
Four-digit number representing the card’s expiration year.
-
#funding ⇒ Object
readonly
Card funding type.
-
#last4 ⇒ Object
readonly
The last four digits of the card.
-
#wallet ⇒ Object
readonly
If this Card is part of a card wallet, this contains the details of the card wallet.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#brand ⇒ Object (readonly)
Card brand. Can be amex, cartes_bancaires, diners, discover, eftpos_au, jcb, link, mastercard, unionpay, visa or unknown.
27 28 29 |
# File 'lib/stripe/resources/crypto/customer_payment_token.rb', line 27 def brand @brand end |
#exp_month ⇒ Object (readonly)
Two-digit number representing the card’s expiration month.
29 30 31 |
# File 'lib/stripe/resources/crypto/customer_payment_token.rb', line 29 def exp_month @exp_month end |
#exp_year ⇒ Object (readonly)
Four-digit number representing the card’s expiration year.
31 32 33 |
# File 'lib/stripe/resources/crypto/customer_payment_token.rb', line 31 def exp_year @exp_year end |
#funding ⇒ Object (readonly)
Card funding type. Can be credit, debit, prepaid, or unknown.
33 34 35 |
# File 'lib/stripe/resources/crypto/customer_payment_token.rb', line 33 def funding @funding end |
#last4 ⇒ Object (readonly)
The last four digits of the card.
35 36 37 |
# File 'lib/stripe/resources/crypto/customer_payment_token.rb', line 35 def last4 @last4 end |
#wallet ⇒ Object (readonly)
If this Card is part of a card wallet, this contains the details of the card wallet.
37 38 39 |
# File 'lib/stripe/resources/crypto/customer_payment_token.rb', line 37 def wallet @wallet end |
Class Method Details
.field_remappings ⇒ Object
43 44 45 |
# File 'lib/stripe/resources/crypto/customer_payment_token.rb', line 43 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
39 40 41 |
# File 'lib/stripe/resources/crypto/customer_payment_token.rb', line 39 def self.inner_class_types @inner_class_types = { wallet: Wallet } end |