Class: Stripe::Crypto::DepositAddressCreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/crypto/deposit_address_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(customer: nil, expand: nil, metadata: nil, network: nil) ⇒ DepositAddressCreateParams

Returns a new instance of DepositAddressCreateParams.



16
17
18
19
20
21
# File 'lib/stripe/params/crypto/deposit_address_create_params.rb', line 16

def initialize(customer: nil, expand: nil, metadata: nil, network: nil)
  @customer = customer
  @expand = expand
  @metadata = 
  @network = network
end

Instance Attribute Details

#customerObject

If set, this deposit address is scoped to a Customer and can only receive funds from that customer. Otherwise, this deposit address can receive funds from any customer.



8
9
10
# File 'lib/stripe/params/crypto/deposit_address_create_params.rb', line 8

def customer
  @customer
end

#expandObject

Specifies which fields in the response should be expanded.



10
11
12
# File 'lib/stripe/params/crypto/deposit_address_create_params.rb', line 10

def expand
  @expand
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



12
13
14
# File 'lib/stripe/params/crypto/deposit_address_create_params.rb', line 12

def 
  @metadata
end

#networkObject

The blockchain network to generate a deposit address for.



14
15
16
# File 'lib/stripe/params/crypto/deposit_address_create_params.rb', line 14

def network
  @network
end