Class: Stripe::Crypto::DepositAddressListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/crypto/deposit_address_list_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(address: nil, customer: nil, customer_account: nil, ending_before: nil, expand: nil, limit: nil, network: nil, starting_after: nil) ⇒ DepositAddressListParams

Returns a new instance of DepositAddressListParams.



24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
# File 'lib/stripe/params/crypto/deposit_address_list_params.rb', line 24

def initialize(
  address: nil,
  customer: nil,
  customer_account: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  network: nil,
  starting_after: nil
)
  @address = address
  @customer = customer
  @customer_account = 
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @network = network
  @starting_after = starting_after
end

Instance Attribute Details

#addressObject

Only return the deposit address matching this on-chain address.



8
9
10
# File 'lib/stripe/params/crypto/deposit_address_list_params.rb', line 8

def address
  @address
end

#customerObject

Only return deposit addresses scoped to this Customer.



10
11
12
# File 'lib/stripe/params/crypto/deposit_address_list_params.rb', line 10

def customer
  @customer
end

#customer_accountObject

Only return deposit addresses belonging to this customer account.



12
13
14
# File 'lib/stripe/params/crypto/deposit_address_list_params.rb', line 12

def 
  @customer_account
end

#ending_beforeObject

A cursor for use in pagination. ending_before is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with obj_bar, your subsequent call can include ending_before=obj_bar in order to fetch the previous page of the list.



14
15
16
# File 'lib/stripe/params/crypto/deposit_address_list_params.rb', line 14

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



16
17
18
# File 'lib/stripe/params/crypto/deposit_address_list_params.rb', line 16

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



18
19
20
# File 'lib/stripe/params/crypto/deposit_address_list_params.rb', line 18

def limit
  @limit
end

#networkObject

Only return deposit addresses for this blockchain network.



20
21
22
# File 'lib/stripe/params/crypto/deposit_address_list_params.rb', line 20

def network
  @network
end

#starting_afterObject

A cursor for use in pagination. starting_after is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with obj_foo, your subsequent call can include starting_after=obj_foo in order to fetch the next page of the list.



22
23
24
# File 'lib/stripe/params/crypto/deposit_address_list_params.rb', line 22

def starting_after
  @starting_after
end