Class: Stripe::Crypto::OnrampSession::TransactionDetails

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/crypto/onramp_session.rb

Defined Under Namespace

Classes: Fees, WalletAddresses

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#destination_amountObject (readonly)

The amount of crypto the customer will get deposited into their wallet



85
86
87
# File 'lib/stripe/resources/crypto/onramp_session.rb', line 85

def destination_amount
  @destination_amount
end

#destination_currenciesObject (readonly)

If a platform wants to lock the currencies an session will support, they can add supported currencies to this array. If left null, the experience will allow selection of all supported destination currencies.



87
88
89
# File 'lib/stripe/resources/crypto/onramp_session.rb', line 87

def destination_currencies
  @destination_currencies
end

#destination_currencyObject (readonly)

The selected destination_currency to convert the source to. This should be a crypto currency code. If destination_currencies is set, it must be a value in that array.



89
90
91
# File 'lib/stripe/resources/crypto/onramp_session.rb', line 89

def destination_currency
  @destination_currency
end

#destination_networkObject (readonly)

The specific crypto network the destination_currency is settled on. If destination_networks is set, it must be a value in that array.



91
92
93
# File 'lib/stripe/resources/crypto/onramp_session.rb', line 91

def destination_network
  @destination_network
end

#destination_networksObject (readonly)

If a platform wants to lock the supported networks, they can do so through this array. If left null, the experience will allow selection of all supported networks.



93
94
95
# File 'lib/stripe/resources/crypto/onramp_session.rb', line 93

def destination_networks
  @destination_networks
end

#feesObject (readonly)

Details about the fees associated with this transaction



95
96
97
# File 'lib/stripe/resources/crypto/onramp_session.rb', line 95

def fees
  @fees
end

#lock_wallet_addressObject (readonly)

Whether or not to lock the suggested wallet address.



97
98
99
# File 'lib/stripe/resources/crypto/onramp_session.rb', line 97

def lock_wallet_address
  @lock_wallet_address
end

#settlement_speedObject (readonly)

Speed at which the cryptocurrency is delivered to the wallet One of: instant (default): crypto is delivered when payment is confirmed standard: crypto is delivered when payment settles



102
103
104
# File 'lib/stripe/resources/crypto/onramp_session.rb', line 102

def settlement_speed
  @settlement_speed
end

#source_amountObject (readonly)

The amount of fiat we intend to onramp - excluding fees



104
105
106
# File 'lib/stripe/resources/crypto/onramp_session.rb', line 104

def source_amount
  @source_amount
end

#source_currencyObject (readonly)

A fiat currency code



106
107
108
# File 'lib/stripe/resources/crypto/onramp_session.rb', line 106

def source_currency
  @source_currency
end

#transaction_idObject (readonly)

The on-chain transaction hash (also referred to as transaction ID or tx_hash) of the transaction that was sent to the customer's wallet. The format varies by chain (e.g. 0xc257...1a95 on Ethereum, 5UB1...v3xZ on Solana, or a1b2...bf00 on Bitcoin). This will only be set if the session reaches status=fulfillment_complete and we've transferred the crypto successfully to the external wallet.



108
109
110
# File 'lib/stripe/resources/crypto/onramp_session.rb', line 108

def transaction_id
  @transaction_id
end

#wallet_addressObject (readonly)

The consumer's wallet address (where crypto will be sent to)



110
111
112
# File 'lib/stripe/resources/crypto/onramp_session.rb', line 110

def wallet_address
  @wallet_address
end

#wallet_addressesObject (readonly)

The end customer's crypto wallet address (for each network) to use for this transaction.



112
113
114
# File 'lib/stripe/resources/crypto/onramp_session.rb', line 112

def wallet_addresses
  @wallet_addresses
end

Class Method Details

.field_remappingsObject



118
119
120
# File 'lib/stripe/resources/crypto/onramp_session.rb', line 118

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



114
115
116
# File 'lib/stripe/resources/crypto/onramp_session.rb', line 114

def self.inner_class_types
  @inner_class_types = { fees: Fees, wallet_addresses: WalletAddresses }
end