Class: Stripe::Crypto::OnrampSession::TransactionDetails::Fees
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Crypto::OnrampSession::TransactionDetails::Fees
- Defined in:
- lib/stripe/resources/crypto/onramp_session.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#network_fee_amount ⇒ Object
readonly
The cost associated with moving crypto from Stripe to the end consumer's wallet.
-
#transaction_fee_amount ⇒ Object
readonly
Fee for processing the transaction.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#network_fee_amount ⇒ Object (readonly)
The cost associated with moving crypto from Stripe to the end consumer's wallet. e.g: for ETH, this is called 'gas fee', for BTC this is a 'miner's fee'.
23 24 25 |
# File 'lib/stripe/resources/crypto/onramp_session.rb', line 23 def network_fee_amount @network_fee_amount end |
#transaction_fee_amount ⇒ Object (readonly)
Fee for processing the transaction.
25 26 27 |
# File 'lib/stripe/resources/crypto/onramp_session.rb', line 25 def transaction_fee_amount @transaction_fee_amount end |
Class Method Details
.field_remappings ⇒ Object
31 32 33 |
# File 'lib/stripe/resources/crypto/onramp_session.rb', line 31 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
27 28 29 |
# File 'lib/stripe/resources/crypto/onramp_session.rb', line 27 def self.inner_class_types @inner_class_types = {} end |