Class: Stripe::Crypto::OnrampSessionCheckoutParams::MandateData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Crypto::OnrampSessionCheckoutParams::MandateData
- Defined in:
- lib/stripe/params/crypto/onramp_session_checkout_params.rb
Defined Under Namespace
Classes: CustomerAcceptance
Instance Attribute Summary collapse
-
#customer_acceptance ⇒ Object
This hash contains details about the customer acceptance of the Mandate.
Instance Method Summary collapse
-
#initialize(customer_acceptance: nil) ⇒ MandateData
constructor
A new instance of MandateData.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(customer_acceptance: nil) ⇒ MandateData
Returns a new instance of MandateData.
41 42 43 |
# File 'lib/stripe/params/crypto/onramp_session_checkout_params.rb', line 41 def initialize(customer_acceptance: nil) @customer_acceptance = customer_acceptance end |
Instance Attribute Details
#customer_acceptance ⇒ Object
This hash contains details about the customer acceptance of the Mandate.
39 40 41 |
# File 'lib/stripe/params/crypto/onramp_session_checkout_params.rb', line 39 def customer_acceptance @customer_acceptance end |