Class: Stripe::Crypto::OnrampSessionCheckoutParams::MandateData::CustomerAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/crypto/onramp_session_checkout_params.rb

Defined Under Namespace

Classes: Offline, Online

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(accepted_at: nil, offline: nil, online: nil, type: nil) ⇒ CustomerAcceptance

Returns a new instance of CustomerAcceptance.



31
32
33
34
35
36
# File 'lib/stripe/params/crypto/onramp_session_checkout_params.rb', line 31

def initialize(accepted_at: nil, offline: nil, online: nil, type: nil)
  @accepted_at = accepted_at
  @offline = offline
  @online = online
  @type = type
end

Instance Attribute Details

#accepted_atObject

The time at which the customer accepted the Mandate.



23
24
25
# File 'lib/stripe/params/crypto/onramp_session_checkout_params.rb', line 23

def accepted_at
  @accepted_at
end

#offlineObject

If this is a Mandate accepted offline, this hash contains details about the offline acceptance.



25
26
27
# File 'lib/stripe/params/crypto/onramp_session_checkout_params.rb', line 25

def offline
  @offline
end

#onlineObject

If this is a Mandate accepted online, this hash contains details about the online acceptance.



27
28
29
# File 'lib/stripe/params/crypto/onramp_session_checkout_params.rb', line 27

def online
  @online
end

#typeObject

The type of customer acceptance information included with the Mandate. One of online or offline.



29
30
31
# File 'lib/stripe/params/crypto/onramp_session_checkout_params.rb', line 29

def type
  @type
end