Class: Stripe::Crypto::OnrampSessionCheckoutParams::MandateData::CustomerAcceptance::Online

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/crypto/onramp_session_checkout_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(ip_address: nil, user_agent: nil) ⇒ Online

Returns a new instance of Online.



17
18
19
20
# File 'lib/stripe/params/crypto/onramp_session_checkout_params.rb', line 17

def initialize(ip_address: nil, user_agent: nil)
  @ip_address = ip_address
  @user_agent = user_agent
end

Instance Attribute Details

#ip_addressObject

The IP address from which the Mandate was accepted by the customer.



13
14
15
# File 'lib/stripe/params/crypto/onramp_session_checkout_params.rb', line 13

def ip_address
  @ip_address
end

#user_agentObject

The user agent of the browser from which the Mandate was accepted by the customer.



15
16
17
# File 'lib/stripe/params/crypto/onramp_session_checkout_params.rb', line 15

def user_agent
  @user_agent
end