Class: Stripe::Crypto::OnrampTransactionLimits

Inherits:
SingletonAPIResource show all
Defined in:
lib/stripe/resources/crypto/onramp_transaction_limits.rb

Overview

This object represents the limit for the remaining amount that the crypto customer can onramp.

Constant Summary collapse

OBJECT_NAME =
"crypto.onramp_transaction_limits"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from SingletonAPIResource

resource_url, #resource_url, retrieve

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#crypto_customer_idObject (readonly)

The ID of the crypto customer.



14
15
16
# File 'lib/stripe/resources/crypto/onramp_transaction_limits.rb', line 14

def crypto_customer_id
  @crypto_customer_id
end

#limitsObject (readonly)

The remaining onramp limit for the crypto customer, separated by currency, payment method, and settlement speed.

Limits are shown for currencies that correspond to the regions where the customer previously transacted. If the customer has no prior transactions, we return limits for all supported currencies.



18
19
20
# File 'lib/stripe/resources/crypto/onramp_transaction_limits.rb', line 18

def limits
  @limits
end

#livemodeObject (readonly)

If the object exists in live mode, the value is true. If the object exists in test mode, the value is false.



20
21
22
# File 'lib/stripe/resources/crypto/onramp_transaction_limits.rb', line 20

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object's type. Objects of the same type share the same value.



22
23
24
# File 'lib/stripe/resources/crypto/onramp_transaction_limits.rb', line 22

def object
  @object
end

Class Method Details

.field_remappingsObject



28
29
30
# File 'lib/stripe/resources/crypto/onramp_transaction_limits.rb', line 28

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



24
25
26
# File 'lib/stripe/resources/crypto/onramp_transaction_limits.rb', line 24

def self.inner_class_types
  @inner_class_types = {}
end

.object_nameObject



9
10
11
# File 'lib/stripe/resources/crypto/onramp_transaction_limits.rb', line 9

def self.object_name
  "crypto.onramp_transaction_limits"
end