Class: Stripe::Crypto::OnrampTransactionLimitsRetrieveParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Crypto::OnrampTransactionLimitsRetrieveParams
- Defined in:
- lib/stripe/params/crypto/onramp_transaction_limits_retrieve_params.rb
Instance Attribute Summary collapse
-
#customer_ip_address ⇒ Object
The IP address of the customer requesting transaction limits.
-
#destination_network ⇒ Object
The destination blockchain network to use for limit calculations.
-
#destination_tag ⇒ Object
The destination tag for the wallet address, if applicable for the network.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#wallet_address ⇒ Object
The wallet address to use for destination-specific limit calculations.
Instance Method Summary collapse
-
#initialize(customer_ip_address: nil, destination_network: nil, destination_tag: nil, expand: nil, wallet_address: nil) ⇒ OnrampTransactionLimitsRetrieveParams
constructor
A new instance of OnrampTransactionLimitsRetrieveParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(customer_ip_address: nil, destination_network: nil, destination_tag: nil, expand: nil, wallet_address: nil) ⇒ OnrampTransactionLimitsRetrieveParams
Returns a new instance of OnrampTransactionLimitsRetrieveParams.
18 19 20 21 22 23 24 25 26 27 28 29 30 |
# File 'lib/stripe/params/crypto/onramp_transaction_limits_retrieve_params.rb', line 18 def initialize( customer_ip_address: nil, destination_network: nil, destination_tag: nil, expand: nil, wallet_address: nil ) @customer_ip_address = customer_ip_address @destination_network = destination_network @destination_tag = destination_tag @expand = @wallet_address = wallet_address end |
Instance Attribute Details
#customer_ip_address ⇒ Object
The IP address of the customer requesting transaction limits. We support IPv4 and IPv6 addresses.
8 9 10 |
# File 'lib/stripe/params/crypto/onramp_transaction_limits_retrieve_params.rb', line 8 def customer_ip_address @customer_ip_address end |
#destination_network ⇒ Object
The destination blockchain network to use for limit calculations.
10 11 12 |
# File 'lib/stripe/params/crypto/onramp_transaction_limits_retrieve_params.rb', line 10 def destination_network @destination_network end |
#destination_tag ⇒ Object
The destination tag for the wallet address, if applicable for the network.
12 13 14 |
# File 'lib/stripe/params/crypto/onramp_transaction_limits_retrieve_params.rb', line 12 def destination_tag @destination_tag end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
14 15 16 |
# File 'lib/stripe/params/crypto/onramp_transaction_limits_retrieve_params.rb', line 14 def @expand end |
#wallet_address ⇒ Object
The wallet address to use for destination-specific limit calculations.
16 17 18 |
# File 'lib/stripe/params/crypto/onramp_transaction_limits_retrieve_params.rb', line 16 def wallet_address @wallet_address end |