Class: Stripe::Customer::FundCashBalanceParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/customer.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, currency: nil, expand: nil, reference: nil) ⇒ FundCashBalanceParams

Returns a new instance of FundCashBalanceParams.



793
794
795
796
797
798
# File 'lib/stripe/resources/customer.rb', line 793

def initialize(amount: nil, currency: nil, expand: nil, reference: nil)
  @amount = amount
  @currency = currency
  @expand = expand
  @reference = reference
end

Instance Attribute Details

#amountObject

Amount to be used for this test cash balance transaction. A positive integer representing how much to fund in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal) (e.g., 100 cents to fund $1.00 or 100 to fund ¥100, a zero-decimal currency).



785
786
787
# File 'lib/stripe/resources/customer.rb', line 785

def amount
  @amount
end

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



787
788
789
# File 'lib/stripe/resources/customer.rb', line 787

def currency
  @currency
end

#expandObject

Specifies which fields in the response should be expanded.



789
790
791
# File 'lib/stripe/resources/customer.rb', line 789

def expand
  @expand
end

#referenceObject

A description of the test funding. This simulates free-text references supplied by customers when making bank transfers to their cash balance. You can use this to test how Stripe’s [reconciliation algorithm](stripe.com/docs/payments/customer-balance/reconciliation) applies to different user inputs.



791
792
793
# File 'lib/stripe/resources/customer.rb', line 791

def reference
  @reference
end