Class: Stripe::Customer::InvoiceSettings

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/customer.rb

Defined Under Namespace

Classes: CustomField, RenderingOptions

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#custom_fieldsObject (readonly)

Default custom fields to be displayed on invoices for this customer.



62
63
64
# File 'lib/stripe/resources/customer.rb', line 62

def custom_fields
  @custom_fields
end

#default_payment_methodObject (readonly)

ID of a payment method that’s attached to the customer, to be used as the customer’s default payment method for subscriptions and invoices.



65
66
67
# File 'lib/stripe/resources/customer.rb', line 65

def default_payment_method
  @default_payment_method
end

Default footer to be displayed on invoices for this customer.



68
69
70
# File 'lib/stripe/resources/customer.rb', line 68

def footer
  @footer
end

#rendering_optionsObject (readonly)

Default options for invoice PDF rendering for this customer.



71
72
73
# File 'lib/stripe/resources/customer.rb', line 71

def rendering_options
  @rendering_options
end