Class: Stripe::Customer::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Customer::ListParams
- Defined in:
- lib/stripe/resources/customer.rb
Defined Under Namespace
Classes: Created
Instance Attribute Summary collapse
-
#created ⇒ Object
Only return customers that were created during the given date interval.
-
#email ⇒ Object
A case-sensitive filter on the list based on the customer’s ‘email` field.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#starting_after ⇒ Object
A cursor for use in pagination.
-
#test_clock ⇒ Object
Provides a list of customers that are associated with the specified test clock.
Instance Method Summary collapse
-
#initialize(created: nil, email: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, test_clock: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(created: nil, email: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, test_clock: nil) ⇒ ListParams
Returns a new instance of ListParams.
447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 |
# File 'lib/stripe/resources/customer.rb', line 447 def initialize( created: nil, email: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, test_clock: nil ) @created = created @email = email @ending_before = ending_before @expand = @limit = limit @starting_after = starting_after @test_clock = test_clock end |
Instance Attribute Details
#created ⇒ Object
Only return customers that were created during the given date interval.
433 434 435 |
# File 'lib/stripe/resources/customer.rb', line 433 def created @created end |
#email ⇒ Object
A case-sensitive filter on the list based on the customer’s ‘email` field. The value must be a string.
435 436 437 |
# File 'lib/stripe/resources/customer.rb', line 435 def email @email end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
437 438 439 |
# File 'lib/stripe/resources/customer.rb', line 437 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
439 440 441 |
# File 'lib/stripe/resources/customer.rb', line 439 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
441 442 443 |
# File 'lib/stripe/resources/customer.rb', line 441 def limit @limit end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
443 444 445 |
# File 'lib/stripe/resources/customer.rb', line 443 def starting_after @starting_after end |
#test_clock ⇒ Object
Provides a list of customers that are associated with the specified test clock. The response will not include customers with test clocks if this parameter is not set.
445 446 447 |
# File 'lib/stripe/resources/customer.rb', line 445 def test_clock @test_clock end |