Class: Stripe::Customer::ListPaymentMethodsParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/customer.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(allow_redisplay: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, type: nil) ⇒ ListPaymentMethodsParams

Returns a new instance of ListPaymentMethodsParams.



734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
# File 'lib/stripe/resources/customer.rb', line 734

def initialize(
  allow_redisplay: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  starting_after: nil,
  type: nil
)
  @allow_redisplay = allow_redisplay
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
  @type = type
end

Instance Attribute Details

#allow_redisplayObject

This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow.



722
723
724
# File 'lib/stripe/resources/customer.rb', line 722

def allow_redisplay
  @allow_redisplay
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



724
725
726
# File 'lib/stripe/resources/customer.rb', line 724

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



726
727
728
# File 'lib/stripe/resources/customer.rb', line 726

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



728
729
730
# File 'lib/stripe/resources/customer.rb', line 728

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



730
731
732
# File 'lib/stripe/resources/customer.rb', line 730

def starting_after
  @starting_after
end

#typeObject

An optional filter on the list, based on the object ‘type` field. Without the filter, the list includes all current and future payment method types. If your integration expects only one type of payment method in the response, make sure to provide a type value in the request.



732
733
734
# File 'lib/stripe/resources/customer.rb', line 732

def type
  @type
end