Class: Stripe::Customer::RetrievePaymentMethodParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Customer::RetrievePaymentMethodParams
- Defined in:
- lib/stripe/resources/customer.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ RetrievePaymentMethodParams
constructor
A new instance of RetrievePaymentMethodParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ RetrievePaymentMethodParams
Returns a new instance of RetrievePaymentMethodParams.
718 719 720 |
# File 'lib/stripe/resources/customer.rb', line 718 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
716 717 718 |
# File 'lib/stripe/resources/customer.rb', line 716 def @expand end |