Class: Stripe::Customer::SearchParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Customer::SearchParams
- Defined in:
- lib/stripe/resources/customer.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#page ⇒ Object
A cursor for pagination across multiple pages of results.
-
#query ⇒ Object
The search query string.
Instance Method Summary collapse
-
#initialize(expand: nil, limit: nil, page: nil, query: nil) ⇒ SearchParams
constructor
A new instance of SearchParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, limit: nil, page: nil, query: nil) ⇒ SearchParams
Returns a new instance of SearchParams.
708 709 710 711 712 713 |
# File 'lib/stripe/resources/customer.rb', line 708 def initialize(expand: nil, limit: nil, page: nil, query: nil) @expand = @limit = limit @page = page @query = query end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
700 701 702 |
# File 'lib/stripe/resources/customer.rb', line 700 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
702 703 704 |
# File 'lib/stripe/resources/customer.rb', line 702 def limit @limit end |
#page ⇒ Object
A cursor for pagination across multiple pages of results. Don’t include this parameter on the first call. Use the next_page value returned in a previous response to request subsequent results.
704 705 706 |
# File 'lib/stripe/resources/customer.rb', line 704 def page @page end |
#query ⇒ Object
The search query string. See [search query language](stripe.com/docs/search#search-query-language) and the list of supported [query fields for customers](stripe.com/docs/search#query-fields-for-customers).
706 707 708 |
# File 'lib/stripe/resources/customer.rb', line 706 def query @query end |