Class: Stripe::Customer::Tax

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/customer.rb

Defined Under Namespace

Classes: Location

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#automatic_taxObject (readonly)

Surfaces if automatic tax computation is possible given the current customer location information.



101
102
103
# File 'lib/stripe/resources/customer.rb', line 101

def automatic_tax
  @automatic_tax
end

#ip_addressObject (readonly)

A recent IP address of the customer used for tax reporting and tax location inference.



103
104
105
# File 'lib/stripe/resources/customer.rb', line 103

def ip_address
  @ip_address
end

#locationObject (readonly)

The identified tax location of the customer.



105
106
107
# File 'lib/stripe/resources/customer.rb', line 105

def location
  @location
end