Class: Stripe::Customer::UpdateParams::InvoiceSettings

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/customer.rb

Defined Under Namespace

Classes: CustomField, RenderingOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(custom_fields: nil, default_payment_method: nil, footer: nil, rendering_options: nil) ⇒ InvoiceSettings

Returns a new instance of InvoiceSettings.



193
194
195
196
197
198
199
200
201
202
203
# File 'lib/stripe/resources/customer.rb', line 193

def initialize(
  custom_fields: nil,
  default_payment_method: nil,
  footer: nil,
  rendering_options: nil
)
  @custom_fields = custom_fields
  @default_payment_method = default_payment_method
  @footer = footer
  @rendering_options = rendering_options
end

Instance Attribute Details

#custom_fieldsObject

The list of up to 4 default custom fields to be displayed on invoices for this customer. When updating, pass an empty string to remove previously-defined fields.



185
186
187
# File 'lib/stripe/resources/customer.rb', line 185

def custom_fields
  @custom_fields
end

#default_payment_methodObject

ID of a payment method that’s attached to the customer, to be used as the customer’s default payment method for subscriptions and invoices.



187
188
189
# File 'lib/stripe/resources/customer.rb', line 187

def default_payment_method
  @default_payment_method
end

Default footer to be displayed on invoices for this customer.



189
190
191
# File 'lib/stripe/resources/customer.rb', line 189

def footer
  @footer
end

#rendering_optionsObject

Default options for invoice PDF rendering for this customer.



191
192
193
# File 'lib/stripe/resources/customer.rb', line 191

def rendering_options
  @rendering_options
end