Class: Stripe::Customer::UpdateParams::Tax

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/customer.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(ip_address: nil, validate_location: nil) ⇒ Tax

Returns a new instance of Tax.



267
268
269
270
# File 'lib/stripe/resources/customer.rb', line 267

def initialize(ip_address: nil, validate_location: nil)
  @ip_address = ip_address
  @validate_location = validate_location
end

Instance Attribute Details

#ip_addressObject

A recent IP address of the customer used for tax reporting and tax location inference. Stripe recommends updating the IP address when a new PaymentMethod is attached or the address field on the customer is updated. We recommend against updating this field more frequently since it could result in unexpected tax location/reporting outcomes.



263
264
265
# File 'lib/stripe/resources/customer.rb', line 263

def ip_address
  @ip_address
end

#validate_locationObject

A flag that indicates when Stripe should validate the customer tax location. Defaults to ‘auto`.



265
266
267
# File 'lib/stripe/resources/customer.rb', line 265

def validate_location
  @validate_location
end