Class: Stripe::CustomerBalanceTransactionCreateParams::AppliedToInvoice
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::CustomerBalanceTransactionCreateParams::AppliedToInvoice
- Defined in:
- lib/stripe/params/customer_balance_transaction_create_params.rb
Instance Attribute Summary collapse
-
#invoice ⇒ Object
The ID of the open invoice to apply the customer's balance credit to.
Instance Method Summary collapse
-
#initialize(invoice: nil) ⇒ AppliedToInvoice
constructor
A new instance of AppliedToInvoice.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(invoice: nil) ⇒ AppliedToInvoice
Returns a new instance of AppliedToInvoice.
10 11 12 |
# File 'lib/stripe/params/customer_balance_transaction_create_params.rb', line 10 def initialize(invoice: nil) @invoice = invoice end |
Instance Attribute Details
#invoice ⇒ Object
The ID of the open invoice to apply the customer's balance credit to.
8 9 10 |
# File 'lib/stripe/params/customer_balance_transaction_create_params.rb', line 8 def invoice @invoice end |