Class: Stripe::CustomerBalanceTransactionService::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/customer_balance_transaction_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, expand: nil, metadata: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



62
63
64
65
66
# File 'lib/stripe/services/customer_balance_transaction_service.rb', line 62

def initialize(description: nil, expand: nil, metadata: nil)
  @description = description
  @expand = expand
  @metadata = 
end

Instance Attribute Details

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



56
57
58
# File 'lib/stripe/services/customer_balance_transaction_service.rb', line 56

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



58
59
60
# File 'lib/stripe/services/customer_balance_transaction_service.rb', line 58

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



60
61
62
# File 'lib/stripe/services/customer_balance_transaction_service.rb', line 60

def 
  @metadata
end