Class: Stripe::CustomerCashBalanceTransaction::Funded::BankTransfer::JpBankTransfer
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::CustomerCashBalanceTransaction::Funded::BankTransfer::JpBankTransfer
- Defined in:
- lib/stripe/resources/customer_cash_balance_transaction.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#sender_bank ⇒ Object
readonly
The name of the bank of the sender of the funding.
-
#sender_branch ⇒ Object
readonly
The name of the bank branch of the sender of the funding.
-
#sender_name ⇒ Object
readonly
The full name of the sender, as supplied by the sending bank.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#sender_bank ⇒ Object (readonly)
The name of the bank of the sender of the funding.
54 55 56 |
# File 'lib/stripe/resources/customer_cash_balance_transaction.rb', line 54 def sender_bank @sender_bank end |
#sender_branch ⇒ Object (readonly)
The name of the bank branch of the sender of the funding.
57 58 59 |
# File 'lib/stripe/resources/customer_cash_balance_transaction.rb', line 57 def sender_branch @sender_branch end |
#sender_name ⇒ Object (readonly)
The full name of the sender, as supplied by the sending bank.
60 61 62 |
# File 'lib/stripe/resources/customer_cash_balance_transaction.rb', line 60 def sender_name @sender_name end |