Class: Stripe::CustomerCashBalanceTransaction::Funded::BankTransfer::UsBankTransfer
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::CustomerCashBalanceTransaction::Funded::BankTransfer::UsBankTransfer
- Defined in:
- lib/stripe/resources/customer_cash_balance_transaction.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#network ⇒ Object
readonly
The banking network used for this funding.
-
#sender_name ⇒ Object
readonly
The full name of the sender, as supplied by the sending bank.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#network ⇒ Object (readonly)
The banking network used for this funding.
65 66 67 |
# File 'lib/stripe/resources/customer_cash_balance_transaction.rb', line 65 def network @network end |
#sender_name ⇒ Object (readonly)
The full name of the sender, as supplied by the sending bank.
68 69 70 |
# File 'lib/stripe/resources/customer_cash_balance_transaction.rb', line 68 def sender_name @sender_name end |