Class: Stripe::CustomerCashBalanceTransactionService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::CustomerCashBalanceTransactionService
- Defined in:
- lib/stripe/services/customer_cash_balance_transaction_service.rb
Defined Under Namespace
Classes: ListParams, RetrieveParams
Instance Method Summary collapse
-
#list(customer, params = {}, opts = {}) ⇒ Object
Returns a list of transactions that modified the customer’s [cash balance](docs.stripe.com/docs/payments/customer-balance).
-
#retrieve(customer, transaction, params = {}, opts = {}) ⇒ Object
Retrieves a specific cash balance transaction, which updated the customer’s [cash balance](docs.stripe.com/docs/payments/customer-balance).
Methods inherited from StripeService
#initialize, #request, #request_stream
Constructor Details
This class inherits a constructor from Stripe::StripeService
Instance Method Details
#list(customer, params = {}, opts = {}) ⇒ Object
Returns a list of transactions that modified the customer’s [cash balance](docs.stripe.com/docs/payments/customer-balance).
34 35 36 37 38 39 40 41 42 |
# File 'lib/stripe/services/customer_cash_balance_transaction_service.rb', line 34 def list(customer, params = {}, opts = {}) request( method: :get, path: format("/v1/customers/%<customer>s/cash_balance_transactions", { customer: CGI.escape(customer) }), params: params, opts: opts, base_address: :api ) end |
#retrieve(customer, transaction, params = {}, opts = {}) ⇒ Object
Retrieves a specific cash balance transaction, which updated the customer’s [cash balance](docs.stripe.com/docs/payments/customer-balance).
45 46 47 48 49 50 51 52 53 |
# File 'lib/stripe/services/customer_cash_balance_transaction_service.rb', line 45 def retrieve(customer, transaction, params = {}, opts = {}) request( method: :get, path: format("/v1/customers/%<customer>s/cash_balance_transactions/%<transaction>s", { customer: CGI.escape(customer), transaction: CGI.escape(transaction) }), params: params, opts: opts, base_address: :api ) end |