Class: Stripe::CustomerPaymentSourceService::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/customer_payment_source_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, metadata: nil, source: nil, validate: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



37
38
39
40
41
42
# File 'lib/stripe/services/customer_payment_source_service.rb', line 37

def initialize(expand: nil, metadata: nil, source: nil, validate: nil)
  @expand = expand
  @metadata = 
  @source = source
  @validate = validate
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



29
30
31
# File 'lib/stripe/services/customer_payment_source_service.rb', line 29

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



31
32
33
# File 'lib/stripe/services/customer_payment_source_service.rb', line 31

def 
  @metadata
end

#sourceObject

Please refer to full [documentation](stripe.com/docs/api) instead.



33
34
35
# File 'lib/stripe/services/customer_payment_source_service.rb', line 33

def source
  @source
end

#validateObject

Attribute for param field validate



35
36
37
# File 'lib/stripe/services/customer_payment_source_service.rb', line 35

def validate
  @validate
end