Class: Stripe::CustomerPaymentSourceService::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/customer_payment_source_service.rb

Defined Under Namespace

Classes: Owner

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_holder_type: nil, address_city: nil, address_country: nil, address_line1: nil, address_line2: nil, address_state: nil, address_zip: nil, exp_month: nil, exp_year: nil, expand: nil, metadata: nil, name: nil, owner: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/stripe/services/customer_payment_source_service.rb', line 159

def initialize(
  account_holder_name: nil,
  account_holder_type: nil,
  address_city: nil,
  address_country: nil,
  address_line1: nil,
  address_line2: nil,
  address_state: nil,
  address_zip: nil,
  exp_month: nil,
  exp_year: nil,
  expand: nil,
  metadata: nil,
  name: nil,
  owner: nil
)
  @account_holder_name = 
  @account_holder_type = 
  @address_city = address_city
  @address_country = address_country
  @address_line1 = address_line1
  @address_line2 = address_line2
  @address_state = address_state
  @address_zip = address_zip
  @exp_month = exp_month
  @exp_year = exp_year
  @expand = expand
  @metadata = 
  @name = name
  @owner = owner
end

Instance Attribute Details

#account_holder_nameObject

The name of the person or business that owns the bank account.



118
119
120
# File 'lib/stripe/services/customer_payment_source_service.rb', line 118

def 
  @account_holder_name
end

#account_holder_typeObject

The type of entity that holds the account. This can be either ‘individual` or `company`.



121
122
123
# File 'lib/stripe/services/customer_payment_source_service.rb', line 121

def 
  @account_holder_type
end

#address_cityObject

City/District/Suburb/Town/Village.



124
125
126
# File 'lib/stripe/services/customer_payment_source_service.rb', line 124

def address_city
  @address_city
end

#address_countryObject

Billing address country, if provided when creating card.



127
128
129
# File 'lib/stripe/services/customer_payment_source_service.rb', line 127

def address_country
  @address_country
end

#address_line1Object

Address line 1 (Street address/PO Box/Company name).



130
131
132
# File 'lib/stripe/services/customer_payment_source_service.rb', line 130

def address_line1
  @address_line1
end

#address_line2Object

Address line 2 (Apartment/Suite/Unit/Building).



133
134
135
# File 'lib/stripe/services/customer_payment_source_service.rb', line 133

def address_line2
  @address_line2
end

#address_stateObject

State/County/Province/Region.



136
137
138
# File 'lib/stripe/services/customer_payment_source_service.rb', line 136

def address_state
  @address_state
end

#address_zipObject

ZIP or postal code.



139
140
141
# File 'lib/stripe/services/customer_payment_source_service.rb', line 139

def address_zip
  @address_zip
end

#exp_monthObject

Two digit number representing the card’s expiration month.



142
143
144
# File 'lib/stripe/services/customer_payment_source_service.rb', line 142

def exp_month
  @exp_month
end

#exp_yearObject

Four digit number representing the card’s expiration year.



145
146
147
# File 'lib/stripe/services/customer_payment_source_service.rb', line 145

def exp_year
  @exp_year
end

#expandObject

Specifies which fields in the response should be expanded.



148
149
150
# File 'lib/stripe/services/customer_payment_source_service.rb', line 148

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



151
152
153
# File 'lib/stripe/services/customer_payment_source_service.rb', line 151

def 
  @metadata
end

#nameObject

Cardholder name.



154
155
156
# File 'lib/stripe/services/customer_payment_source_service.rb', line 154

def name
  @name
end

#ownerObject

Attribute for param field owner



157
158
159
# File 'lib/stripe/services/customer_payment_source_service.rb', line 157

def owner
  @owner
end