Class: Stripe::CustomerPaymentSourceService::VerifyParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/customer_payment_source_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amounts: nil, expand: nil) ⇒ VerifyParams

Returns a new instance of VerifyParams.



179
180
181
182
# File 'lib/stripe/services/customer_payment_source_service.rb', line 179

def initialize(amounts: nil, expand: nil)
  @amounts = amounts
  @expand = expand
end

Instance Attribute Details

#amountsObject

Two positive integers, in cents, equal to the values of the microdeposits sent to the bank account.



175
176
177
# File 'lib/stripe/services/customer_payment_source_service.rb', line 175

def amounts
  @amounts
end

#expandObject

Specifies which fields in the response should be expanded.



177
178
179
# File 'lib/stripe/services/customer_payment_source_service.rb', line 177

def expand
  @expand
end