Class: Stripe::CustomerService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::CustomerService::CreateParams
- Defined in:
- lib/stripe/services/customer_service.rb
Defined Under Namespace
Classes: Address, CashBalance, InvoiceSettings, Shipping, Tax, TaxIdDatum
Instance Attribute Summary collapse
-
#address ⇒ Object
The customer’s address.
-
#balance ⇒ Object
An integer amount in cents (or local equivalent) that represents the customer’s current balance, which affect the customer’s future invoices.
-
#cash_balance ⇒ Object
Balance information and default balance settings for this customer.
-
#description ⇒ Object
An arbitrary string that you can attach to a customer object.
-
#email ⇒ Object
Customer’s email address.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#invoice_prefix ⇒ Object
The prefix for the customer used to generate unique invoice numbers.
-
#invoice_settings ⇒ Object
Default invoice settings for this customer.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#name ⇒ Object
The customer’s full name or business name.
-
#next_invoice_sequence ⇒ Object
The sequence to be used on the customer’s next invoice.
-
#payment_method ⇒ Object
Attribute for param field payment_method.
-
#phone ⇒ Object
The customer’s phone number.
-
#preferred_locales ⇒ Object
Customer’s preferred languages, ordered by preference.
-
#shipping ⇒ Object
The customer’s shipping information.
-
#source ⇒ Object
Attribute for param field source.
-
#tax ⇒ Object
Tax details about the customer.
-
#tax_exempt ⇒ Object
The customer’s tax exemption.
-
#tax_id_data ⇒ Object
The customer’s tax IDs.
-
#test_clock ⇒ Object
ID of the test clock to attach to the customer.
-
#validate ⇒ Object
Attribute for param field validate.
Instance Method Summary collapse
-
#initialize(address: nil, balance: nil, cash_balance: nil, description: nil, email: nil, expand: nil, invoice_prefix: nil, invoice_settings: nil, metadata: nil, name: nil, next_invoice_sequence: nil, payment_method: nil, phone: nil, preferred_locales: nil, shipping: nil, source: nil, tax: nil, tax_exempt: nil, tax_id_data: nil, test_clock: nil, validate: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, balance: nil, cash_balance: nil, description: nil, email: nil, expand: nil, invoice_prefix: nil, invoice_settings: nil, metadata: nil, name: nil, next_invoice_sequence: nil, payment_method: nil, phone: nil, preferred_locales: nil, shipping: nil, source: nil, tax: nil, tax_exempt: nil, tax_id_data: nil, test_clock: nil, validate: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 |
# File 'lib/stripe/services/customer_service.rb', line 529 def initialize( address: nil, balance: nil, cash_balance: nil, description: nil, email: nil, expand: nil, invoice_prefix: nil, invoice_settings: nil, metadata: nil, name: nil, next_invoice_sequence: nil, payment_method: nil, phone: nil, preferred_locales: nil, shipping: nil, source: nil, tax: nil, tax_exempt: nil, tax_id_data: nil, test_clock: nil, validate: nil ) @address = address @balance = balance @cash_balance = cash_balance @description = description @email = email @expand = @invoice_prefix = invoice_prefix @invoice_settings = invoice_settings @metadata = @name = name @next_invoice_sequence = next_invoice_sequence @payment_method = payment_method @phone = phone @preferred_locales = preferred_locales @shipping = shipping @source = source @tax = tax @tax_exempt = tax_exempt @tax_id_data = tax_id_data @test_clock = test_clock @validate = validate end |
Instance Attribute Details
#address ⇒ Object
The customer’s address.
487 488 489 |
# File 'lib/stripe/services/customer_service.rb', line 487 def address @address end |
#balance ⇒ Object
An integer amount in cents (or local equivalent) that represents the customer’s current balance, which affect the customer’s future invoices. A negative amount represents a credit that decreases the amount due on an invoice; a positive amount increases the amount due on an invoice.
489 490 491 |
# File 'lib/stripe/services/customer_service.rb', line 489 def balance @balance end |
#cash_balance ⇒ Object
Balance information and default balance settings for this customer.
491 492 493 |
# File 'lib/stripe/services/customer_service.rb', line 491 def cash_balance @cash_balance end |
#description ⇒ Object
An arbitrary string that you can attach to a customer object. It is displayed alongside the customer in the dashboard.
493 494 495 |
# File 'lib/stripe/services/customer_service.rb', line 493 def description @description end |
#email ⇒ Object
Customer’s email address. It’s displayed alongside the customer in your dashboard and can be useful for searching and tracking. This may be up to *512 characters*.
495 496 497 |
# File 'lib/stripe/services/customer_service.rb', line 495 def email @email end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
497 498 499 |
# File 'lib/stripe/services/customer_service.rb', line 497 def @expand end |
#invoice_prefix ⇒ Object
The prefix for the customer used to generate unique invoice numbers. Must be 3–12 uppercase letters or numbers.
499 500 501 |
# File 'lib/stripe/services/customer_service.rb', line 499 def invoice_prefix @invoice_prefix end |
#invoice_settings ⇒ Object
Default invoice settings for this customer.
501 502 503 |
# File 'lib/stripe/services/customer_service.rb', line 501 def invoice_settings @invoice_settings end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
503 504 505 |
# File 'lib/stripe/services/customer_service.rb', line 503 def @metadata end |
#name ⇒ Object
The customer’s full name or business name.
505 506 507 |
# File 'lib/stripe/services/customer_service.rb', line 505 def name @name end |
#next_invoice_sequence ⇒ Object
The sequence to be used on the customer’s next invoice. Defaults to 1.
507 508 509 |
# File 'lib/stripe/services/customer_service.rb', line 507 def next_invoice_sequence @next_invoice_sequence end |
#payment_method ⇒ Object
Attribute for param field payment_method
509 510 511 |
# File 'lib/stripe/services/customer_service.rb', line 509 def payment_method @payment_method end |
#phone ⇒ Object
The customer’s phone number.
511 512 513 |
# File 'lib/stripe/services/customer_service.rb', line 511 def phone @phone end |
#preferred_locales ⇒ Object
Customer’s preferred languages, ordered by preference.
513 514 515 |
# File 'lib/stripe/services/customer_service.rb', line 513 def preferred_locales @preferred_locales end |
#shipping ⇒ Object
The customer’s shipping information. Appears on invoices emailed to this customer.
515 516 517 |
# File 'lib/stripe/services/customer_service.rb', line 515 def shipping @shipping end |
#source ⇒ Object
Attribute for param field source
517 518 519 |
# File 'lib/stripe/services/customer_service.rb', line 517 def source @source end |
#tax ⇒ Object
Tax details about the customer.
519 520 521 |
# File 'lib/stripe/services/customer_service.rb', line 519 def tax @tax end |
#tax_exempt ⇒ Object
The customer’s tax exemption. One of ‘none`, `exempt`, or `reverse`.
521 522 523 |
# File 'lib/stripe/services/customer_service.rb', line 521 def tax_exempt @tax_exempt end |
#tax_id_data ⇒ Object
The customer’s tax IDs.
523 524 525 |
# File 'lib/stripe/services/customer_service.rb', line 523 def tax_id_data @tax_id_data end |
#test_clock ⇒ Object
ID of the test clock to attach to the customer.
525 526 527 |
# File 'lib/stripe/services/customer_service.rb', line 525 def test_clock @test_clock end |
#validate ⇒ Object
Attribute for param field validate
527 528 529 |
# File 'lib/stripe/services/customer_service.rb', line 527 def validate @validate end |