Class: Stripe::CustomerService::CreateParams::CashBalance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::CustomerService::CreateParams::CashBalance
- Defined in:
- lib/stripe/services/customer_service.rb
Defined Under Namespace
Classes: Settings
Instance Attribute Summary collapse
-
#settings ⇒ Object
Settings controlling the behavior of the customer’s cash balance, such as reconciliation of funds received.
Instance Method Summary collapse
-
#initialize(settings: nil) ⇒ CashBalance
constructor
A new instance of CashBalance.
Methods inherited from RequestParams
Constructor Details
#initialize(settings: nil) ⇒ CashBalance
Returns a new instance of CashBalance.
367 368 369 |
# File 'lib/stripe/services/customer_service.rb', line 367 def initialize(settings: nil) @settings = settings end |
Instance Attribute Details
#settings ⇒ Object
Settings controlling the behavior of the customer’s cash balance, such as reconciliation of funds received.
365 366 367 |
# File 'lib/stripe/services/customer_service.rb', line 365 def settings @settings end |