Class: Stripe::CustomerService::CreateParams::Tax

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/customer_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(ip_address: nil, validate_location: nil) ⇒ Tax

Returns a new instance of Tax.



479
480
481
482
# File 'lib/stripe/services/customer_service.rb', line 479

def initialize(ip_address: nil, validate_location: nil)
  @ip_address = ip_address
  @validate_location = validate_location
end

Instance Attribute Details

#ip_addressObject

A recent IP address of the customer used for tax reporting and tax location inference. Stripe recommends updating the IP address when a new PaymentMethod is attached or the address field on the customer is updated. We recommend against updating this field more frequently since it could result in unexpected tax location/reporting outcomes.



475
476
477
# File 'lib/stripe/services/customer_service.rb', line 475

def ip_address
  @ip_address
end

#validate_locationObject

A flag that indicates when Stripe should validate the customer tax location. Defaults to ‘deferred`.



477
478
479
# File 'lib/stripe/services/customer_service.rb', line 477

def validate_location
  @validate_location
end