Class: Stripe::CustomerService::SearchParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/customer_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, limit: nil, page: nil, query: nil) ⇒ SearchParams

Returns a new instance of SearchParams.



695
696
697
698
699
700
# File 'lib/stripe/services/customer_service.rb', line 695

def initialize(expand: nil, limit: nil, page: nil, query: nil)
  @expand = expand
  @limit = limit
  @page = page
  @query = query
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



684
685
686
# File 'lib/stripe/services/customer_service.rb', line 684

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



687
688
689
# File 'lib/stripe/services/customer_service.rb', line 687

def limit
  @limit
end

#pageObject

A cursor for pagination across multiple pages of results. Don’t include this parameter on the first call. Use the next_page value returned in a previous response to request subsequent results.



690
691
692
# File 'lib/stripe/services/customer_service.rb', line 690

def page
  @page
end

#queryObject

The search query string. See [search query language](stripe.com/docs/search#search-query-language) and the list of supported [query fields for customers](stripe.com/docs/search#query-fields-for-customers).



693
694
695
# File 'lib/stripe/services/customer_service.rb', line 693

def query
  @query
end