Class: Stripe::CustomerService::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::CustomerService::UpdateParams
- Defined in:
- lib/stripe/services/customer_service.rb
Defined Under Namespace
Classes: Address, CashBalance, InvoiceSettings, Shipping, Tax
Instance Attribute Summary collapse
-
#address ⇒ Object
The customer’s address.
-
#balance ⇒ Object
An integer amount in cents (or local equivalent) that represents the customer’s current balance, which affect the customer’s future invoices.
-
#cash_balance ⇒ Object
Balance information and default balance settings for this customer.
-
#default_source ⇒ Object
If you are using payment methods created via the PaymentMethods API, see the [invoice_settings.default_payment_method](stripe.com/docs/api/customers/update#update_customer-invoice_settings-default_payment_method) parameter.
-
#description ⇒ Object
An arbitrary string that you can attach to a customer object.
-
#email ⇒ Object
Customer’s email address.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#invoice_prefix ⇒ Object
The prefix for the customer used to generate unique invoice numbers.
-
#invoice_settings ⇒ Object
Default invoice settings for this customer.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#name ⇒ Object
The customer’s full name or business name.
-
#next_invoice_sequence ⇒ Object
The sequence to be used on the customer’s next invoice.
-
#phone ⇒ Object
The customer’s phone number.
-
#preferred_locales ⇒ Object
Customer’s preferred languages, ordered by preference.
-
#shipping ⇒ Object
The customer’s shipping information.
-
#source ⇒ Object
Attribute for param field source.
-
#tax ⇒ Object
Tax details about the customer.
-
#tax_exempt ⇒ Object
The customer’s tax exemption.
-
#validate ⇒ Object
Attribute for param field validate.
Instance Method Summary collapse
-
#initialize(address: nil, balance: nil, cash_balance: nil, default_source: nil, description: nil, email: nil, expand: nil, invoice_prefix: nil, invoice_settings: nil, metadata: nil, name: nil, next_invoice_sequence: nil, phone: nil, preferred_locales: nil, shipping: nil, source: nil, tax: nil, tax_exempt: nil, validate: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, balance: nil, cash_balance: nil, default_source: nil, description: nil, email: nil, expand: nil, invoice_prefix: nil, invoice_settings: nil, metadata: nil, name: nil, next_invoice_sequence: nil, phone: nil, preferred_locales: nil, shipping: nil, source: nil, tax: nil, tax_exempt: nil, validate: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 |
# File 'lib/stripe/services/customer_service.rb', line 226 def initialize( address: nil, balance: nil, cash_balance: nil, default_source: nil, description: nil, email: nil, expand: nil, invoice_prefix: nil, invoice_settings: nil, metadata: nil, name: nil, next_invoice_sequence: nil, phone: nil, preferred_locales: nil, shipping: nil, source: nil, tax: nil, tax_exempt: nil, validate: nil ) @address = address @balance = balance @cash_balance = cash_balance @default_source = default_source @description = description @email = email @expand = @invoice_prefix = invoice_prefix @invoice_settings = invoice_settings @metadata = @name = name @next_invoice_sequence = next_invoice_sequence @phone = phone @preferred_locales = preferred_locales @shipping = shipping @source = source @tax = tax @tax_exempt = tax_exempt @validate = validate end |
Instance Attribute Details
#address ⇒ Object
The customer’s address.
184 185 186 |
# File 'lib/stripe/services/customer_service.rb', line 184 def address @address end |
#balance ⇒ Object
An integer amount in cents (or local equivalent) that represents the customer’s current balance, which affect the customer’s future invoices. A negative amount represents a credit that decreases the amount due on an invoice; a positive amount increases the amount due on an invoice.
186 187 188 |
# File 'lib/stripe/services/customer_service.rb', line 186 def balance @balance end |
#cash_balance ⇒ Object
Balance information and default balance settings for this customer.
188 189 190 |
# File 'lib/stripe/services/customer_service.rb', line 188 def cash_balance @cash_balance end |
#default_source ⇒ Object
If you are using payment methods created via the PaymentMethods API, see the [invoice_settings.default_payment_method](stripe.com/docs/api/customers/update#update_customer-invoice_settings-default_payment_method) parameter.
Provide the ID of a payment source already attached to this customer to make it this customer’s default payment source.
If you want to add a new payment source and make it the default, see the [source](stripe.com/docs/api/customers/update#update_customer-source) property.
194 195 196 |
# File 'lib/stripe/services/customer_service.rb', line 194 def default_source @default_source end |
#description ⇒ Object
An arbitrary string that you can attach to a customer object. It is displayed alongside the customer in the dashboard.
196 197 198 |
# File 'lib/stripe/services/customer_service.rb', line 196 def description @description end |
#email ⇒ Object
Customer’s email address. It’s displayed alongside the customer in your dashboard and can be useful for searching and tracking. This may be up to *512 characters*.
198 199 200 |
# File 'lib/stripe/services/customer_service.rb', line 198 def email @email end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
200 201 202 |
# File 'lib/stripe/services/customer_service.rb', line 200 def @expand end |
#invoice_prefix ⇒ Object
The prefix for the customer used to generate unique invoice numbers. Must be 3–12 uppercase letters or numbers.
202 203 204 |
# File 'lib/stripe/services/customer_service.rb', line 202 def invoice_prefix @invoice_prefix end |
#invoice_settings ⇒ Object
Default invoice settings for this customer.
204 205 206 |
# File 'lib/stripe/services/customer_service.rb', line 204 def invoice_settings @invoice_settings end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
206 207 208 |
# File 'lib/stripe/services/customer_service.rb', line 206 def @metadata end |
#name ⇒ Object
The customer’s full name or business name.
208 209 210 |
# File 'lib/stripe/services/customer_service.rb', line 208 def name @name end |
#next_invoice_sequence ⇒ Object
The sequence to be used on the customer’s next invoice. Defaults to 1.
210 211 212 |
# File 'lib/stripe/services/customer_service.rb', line 210 def next_invoice_sequence @next_invoice_sequence end |
#phone ⇒ Object
The customer’s phone number.
212 213 214 |
# File 'lib/stripe/services/customer_service.rb', line 212 def phone @phone end |
#preferred_locales ⇒ Object
Customer’s preferred languages, ordered by preference.
214 215 216 |
# File 'lib/stripe/services/customer_service.rb', line 214 def preferred_locales @preferred_locales end |
#shipping ⇒ Object
The customer’s shipping information. Appears on invoices emailed to this customer.
216 217 218 |
# File 'lib/stripe/services/customer_service.rb', line 216 def shipping @shipping end |
#source ⇒ Object
Attribute for param field source
218 219 220 |
# File 'lib/stripe/services/customer_service.rb', line 218 def source @source end |
#tax ⇒ Object
Tax details about the customer.
220 221 222 |
# File 'lib/stripe/services/customer_service.rb', line 220 def tax @tax end |
#tax_exempt ⇒ Object
The customer’s tax exemption. One of ‘none`, `exempt`, or `reverse`.
222 223 224 |
# File 'lib/stripe/services/customer_service.rb', line 222 def tax_exempt @tax_exempt end |
#validate ⇒ Object
Attribute for param field validate
224 225 226 |
# File 'lib/stripe/services/customer_service.rb', line 224 def validate @validate end |