Class: Stripe::CustomerSession::Components

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/customer_session.rb

Defined Under Namespace

Classes: ActiveEntitlements, BuyButton, CustomerPortal, CustomerSheet, MobilePaymentElement, PaymentElement, PricingTable, TaxIdElement

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#active_entitlementsObject (readonly)

This hash contains whether the active entitlements is enabled.



226
227
228
# File 'lib/stripe/resources/customer_session.rb', line 226

def active_entitlements
  @active_entitlements
end

#buy_buttonObject (readonly)

This hash contains whether the buy button is enabled.



228
229
230
# File 'lib/stripe/resources/customer_session.rb', line 228

def buy_button
  @buy_button
end

#customer_portalObject (readonly)

This hash contains whether the customer portal is enabled.



230
231
232
# File 'lib/stripe/resources/customer_session.rb', line 230

def customer_portal
  @customer_portal
end

#customer_sheetObject (readonly)

This hash contains whether the customer sheet is enabled and the features it supports.



232
233
234
# File 'lib/stripe/resources/customer_session.rb', line 232

def customer_sheet
  @customer_sheet
end

#mobile_payment_elementObject (readonly)

This hash contains whether the mobile payment element is enabled and the features it supports.



234
235
236
# File 'lib/stripe/resources/customer_session.rb', line 234

def mobile_payment_element
  @mobile_payment_element
end

#payment_elementObject (readonly)

This hash contains whether the Payment Element is enabled and the features it supports.



236
237
238
# File 'lib/stripe/resources/customer_session.rb', line 236

def payment_element
  @payment_element
end

#pricing_tableObject (readonly)

This hash contains whether the pricing table is enabled.



238
239
240
# File 'lib/stripe/resources/customer_session.rb', line 238

def pricing_table
  @pricing_table
end

#tax_id_elementObject (readonly)

This hash contains whether the Tax ID Element is enabled and the features it supports.



240
241
242
# File 'lib/stripe/resources/customer_session.rb', line 240

def tax_id_element
  @tax_id_element
end

Class Method Details

.field_remappingsObject



255
256
257
# File 'lib/stripe/resources/customer_session.rb', line 255

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



242
243
244
245
246
247
248
249
250
251
252
253
# File 'lib/stripe/resources/customer_session.rb', line 242

def self.inner_class_types
  @inner_class_types = {
    active_entitlements: ActiveEntitlements,
    buy_button: BuyButton,
    customer_portal: CustomerPortal,
    customer_sheet: CustomerSheet,
    mobile_payment_element: MobilePaymentElement,
    payment_element: PaymentElement,
    pricing_table: PricingTable,
    tax_id_element: TaxIdElement,
  }
end