Class: Stripe::CustomerSession::CreateParams::Components::PaymentElement
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::CustomerSession::CreateParams::Components::PaymentElement
- Defined in:
- lib/stripe/resources/customer_session.rb
Defined Under Namespace
Classes: Features
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Whether the Payment Element is enabled.
-
#features ⇒ Object
This hash defines whether the Payment Element supports certain features.
Instance Method Summary collapse
-
#initialize(enabled: nil, features: nil) ⇒ PaymentElement
constructor
A new instance of PaymentElement.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, features: nil) ⇒ PaymentElement
Returns a new instance of PaymentElement.
135 136 137 138 |
# File 'lib/stripe/resources/customer_session.rb', line 135 def initialize(enabled: nil, features: nil) @enabled = enabled @features = features end |
Instance Attribute Details
#enabled ⇒ Object
Whether the Payment Element is enabled.
130 131 132 |
# File 'lib/stripe/resources/customer_session.rb', line 130 def enabled @enabled end |
#features ⇒ Object
This hash defines whether the Payment Element supports certain features.
133 134 135 |
# File 'lib/stripe/resources/customer_session.rb', line 133 def features @features end |