Class: Stripe::CustomerSessionCreateParams::Components::MobilePaymentElement
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::CustomerSessionCreateParams::Components::MobilePaymentElement
- Defined in:
- lib/stripe/params/customer_session_create_params.rb
Defined Under Namespace
Classes: Features
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Whether the mobile payment element is enabled.
-
#features ⇒ Object
This hash defines whether the mobile payment element supports certain features.
Instance Method Summary collapse
-
#initialize(enabled: nil, features: nil) ⇒ MobilePaymentElement
constructor
A new instance of MobilePaymentElement.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(enabled: nil, features: nil) ⇒ MobilePaymentElement
Returns a new instance of MobilePaymentElement.
101 102 103 104 |
# File 'lib/stripe/params/customer_session_create_params.rb', line 101 def initialize(enabled: nil, features: nil) @enabled = enabled @features = features end |
Instance Attribute Details
#enabled ⇒ Object
Whether the mobile payment element is enabled.
97 98 99 |
# File 'lib/stripe/params/customer_session_create_params.rb', line 97 def enabled @enabled end |
#features ⇒ Object
This hash defines whether the mobile payment element supports certain features.
99 100 101 |
# File 'lib/stripe/params/customer_session_create_params.rb', line 99 def features @features end |