Class: Stripe::CustomerSessionService::CreateParams::Components::PaymentElement
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::CustomerSessionService::CreateParams::Components::PaymentElement
- Defined in:
- lib/stripe/services/customer_session_service.rb
Defined Under Namespace
Classes: Features
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Whether the Payment Element is enabled.
-
#features ⇒ Object
This hash defines whether the Payment Element supports certain features.
Instance Method Summary collapse
-
#initialize(enabled: nil, features: nil) ⇒ PaymentElement
constructor
A new instance of PaymentElement.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, features: nil) ⇒ PaymentElement
Returns a new instance of PaymentElement.
61 62 63 64 |
# File 'lib/stripe/services/customer_session_service.rb', line 61 def initialize(enabled: nil, features: nil) @enabled = enabled @features = features end |
Instance Attribute Details
#enabled ⇒ Object
Whether the Payment Element is enabled.
57 58 59 |
# File 'lib/stripe/services/customer_session_service.rb', line 57 def enabled @enabled end |
#features ⇒ Object
This hash defines whether the Payment Element supports certain features.
59 60 61 |
# File 'lib/stripe/services/customer_session_service.rb', line 59 def features @features end |