Class: Stripe::CustomerSessionService::CreateParams::Components::PaymentElement::Features
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::CustomerSessionService::CreateParams::Components::PaymentElement::Features
- Defined in:
- lib/stripe/services/customer_session_service.rb
Instance Attribute Summary collapse
-
#payment_method_allow_redisplay_filters ⇒ Object
A list of [‘allow_redisplay`](docs.stripe.com/api/payment_methods/object#payment_method_object-allow_redisplay) values that controls which saved payment methods the Payment Element displays by filtering to only show payment methods with an `allow_redisplay` value that is present in this list.
-
#payment_method_redisplay ⇒ Object
Controls whether or not the Payment Element shows saved payment methods.
-
#payment_method_redisplay_limit ⇒ Object
Determines the max number of saved payment methods for the Payment Element to display.
-
#payment_method_remove ⇒ Object
Controls whether the Payment Element displays the option to remove a saved payment method.
-
#payment_method_save ⇒ Object
Controls whether the Payment Element displays a checkbox offering to save a new payment method.
-
#payment_method_save_usage ⇒ Object
When using PaymentIntents and the customer checks the save checkbox, this field determines the [‘setup_future_usage`](docs.stripe.com/api/payment_intents/object#payment_intent_object-setup_future_usage) value used to confirm the PaymentIntent.
Instance Method Summary collapse
-
#initialize(payment_method_allow_redisplay_filters: nil, payment_method_redisplay: nil, payment_method_redisplay_limit: nil, payment_method_remove: nil, payment_method_save: nil, payment_method_save_usage: nil) ⇒ Features
constructor
A new instance of Features.
Methods inherited from RequestParams
Constructor Details
#initialize(payment_method_allow_redisplay_filters: nil, payment_method_redisplay: nil, payment_method_redisplay_limit: nil, payment_method_remove: nil, payment_method_save: nil, payment_method_save_usage: nil) ⇒ Features
Returns a new instance of Features.
45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/stripe/services/customer_session_service.rb', line 45 def initialize( payment_method_allow_redisplay_filters: nil, payment_method_redisplay: nil, payment_method_redisplay_limit: nil, payment_method_remove: nil, payment_method_save: nil, payment_method_save_usage: nil ) @payment_method_allow_redisplay_filters = payment_method_allow_redisplay_filters @payment_method_redisplay = payment_method_redisplay @payment_method_redisplay_limit = payment_method_redisplay_limit @payment_method_remove = payment_method_remove @payment_method_save = payment_method_save @payment_method_save_usage = payment_method_save_usage end |
Instance Attribute Details
#payment_method_allow_redisplay_filters ⇒ Object
A list of [‘allow_redisplay`](docs.stripe.com/api/payment_methods/object#payment_method_object-allow_redisplay) values that controls which saved payment methods the Payment Element displays by filtering to only show payment methods with an `allow_redisplay` value that is present in this list.
If not specified, defaults to [“always”]. In order to display all saved payment methods, specify [“always”, “limited”, “unspecified”].
22 23 24 |
# File 'lib/stripe/services/customer_session_service.rb', line 22 def payment_method_allow_redisplay_filters @payment_method_allow_redisplay_filters end |
#payment_method_redisplay ⇒ Object
Controls whether or not the Payment Element shows saved payment methods. This parameter defaults to ‘disabled`.
25 26 27 |
# File 'lib/stripe/services/customer_session_service.rb', line 25 def payment_method_redisplay @payment_method_redisplay end |
#payment_method_redisplay_limit ⇒ Object
Determines the max number of saved payment methods for the Payment Element to display. This parameter defaults to ‘3`.
28 29 30 |
# File 'lib/stripe/services/customer_session_service.rb', line 28 def payment_method_redisplay_limit @payment_method_redisplay_limit end |
#payment_method_remove ⇒ Object
Controls whether the Payment Element displays the option to remove a saved payment method. This parameter defaults to ‘disabled`.
Allowing buyers to remove their saved payment methods impacts subscriptions that depend on that payment method. Removing the payment method detaches the [‘customer` object](docs.stripe.com/api/payment_methods/object#payment_method_object-customer) from that [PaymentMethod](docs.stripe.com/api/payment_methods).
33 34 35 |
# File 'lib/stripe/services/customer_session_service.rb', line 33 def payment_method_remove @payment_method_remove end |
#payment_method_save ⇒ Object
Controls whether the Payment Element displays a checkbox offering to save a new payment method. This parameter defaults to ‘disabled`.
If a customer checks the box, the [‘allow_redisplay`](docs.stripe.com/api/payment_methods/object#payment_method_object-allow_redisplay) value on the PaymentMethod is set to `’always’‘ at confirmation time. For PaymentIntents, the [`setup_future_usage`](docs.stripe.com/api/payment_intents/object#payment_intent_object-setup_future_usage) value is also set to the value defined in `payment_method_save_usage`.
38 39 40 |
# File 'lib/stripe/services/customer_session_service.rb', line 38 def payment_method_save @payment_method_save end |
#payment_method_save_usage ⇒ Object
When using PaymentIntents and the customer checks the save checkbox, this field determines the [‘setup_future_usage`](docs.stripe.com/api/payment_intents/object#payment_intent_object-setup_future_usage) value used to confirm the PaymentIntent.
When using SetupIntents, directly configure the [‘usage`](docs.stripe.com/api/setup_intents/object#setup_intent_object-usage) value on SetupIntent creation.
43 44 45 |
# File 'lib/stripe/services/customer_session_service.rb', line 43 def payment_method_save_usage @payment_method_save_usage end |