Class: Stripe::DelegatedCheckout::RequestedSession::AffiliateAttribution
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::DelegatedCheckout::RequestedSession::AffiliateAttribution
- Defined in:
- lib/stripe/resources/delegated_checkout/requested_session.rb
Defined Under Namespace
Classes: Source
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#campaign_id ⇒ Object
readonly
Agent-scoped campaign identifier.
-
#creative_id ⇒ Object
readonly
Agent-scoped creative identifier.
-
#expires_at ⇒ Object
readonly
Timestamp when the attribution token expires.
-
#identification_token ⇒ Object
readonly
Agent-issued secret to validate the legitimacy of the source of this data.
-
#issued_at ⇒ Object
readonly
Timestamp for when the attribution token was issued.
-
#provider ⇒ Object
readonly
Identifier for the attribution agent / affiliate network namespace.
-
#publisher_id ⇒ Object
readonly
Agent-scoped affiliate/publisher identifier.
-
#shared_metadata ⇒ Object
readonly
Freeform key/value pairs for additional non-sensitive per-agent data.
-
#source ⇒ Object
readonly
Context about where the attribution originated.
-
#sub_id ⇒ Object
readonly
Agent-scoped sub-tracking identifier.
-
#touchpoint ⇒ Object
readonly
Whether this is the first or last touchpoint.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#campaign_id ⇒ Object (readonly)
Agent-scoped campaign identifier.
34 35 36 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 34 def campaign_id @campaign_id end |
#creative_id ⇒ Object (readonly)
Agent-scoped creative identifier.
36 37 38 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 36 def creative_id @creative_id end |
#expires_at ⇒ Object (readonly)
Timestamp when the attribution token expires.
38 39 40 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 38 def expires_at @expires_at end |
#identification_token ⇒ Object (readonly)
Agent-issued secret to validate the legitimacy of the source of this data.
40 41 42 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 40 def identification_token @identification_token end |
#issued_at ⇒ Object (readonly)
Timestamp for when the attribution token was issued.
42 43 44 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 42 def issued_at @issued_at end |
#provider ⇒ Object (readonly)
Identifier for the attribution agent / affiliate network namespace.
44 45 46 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 44 def provider @provider end |
#publisher_id ⇒ Object (readonly)
Agent-scoped affiliate/publisher identifier.
46 47 48 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 46 def publisher_id @publisher_id end |
#shared_metadata ⇒ Object (readonly)
Freeform key/value pairs for additional non-sensitive per-agent data.
48 49 50 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 48 def @shared_metadata end |
#source ⇒ Object (readonly)
Context about where the attribution originated.
50 51 52 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 50 def source @source end |
#sub_id ⇒ Object (readonly)
Agent-scoped sub-tracking identifier.
52 53 54 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 52 def sub_id @sub_id end |
#touchpoint ⇒ Object (readonly)
Whether this is the first or last touchpoint.
54 55 56 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 54 def touchpoint @touchpoint end |
Class Method Details
.field_remappings ⇒ Object
60 61 62 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 60 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
56 57 58 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 56 def self.inner_class_types @inner_class_types = { source: Source } end |