Class: Stripe::DelegatedCheckout::RequestedSession::Discounts
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::DelegatedCheckout::RequestedSession::Discounts
- Defined in:
- lib/stripe/resources/delegated_checkout/requested_session.rb
Defined Under Namespace
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#applied ⇒ Object
readonly
The list of successfully applied discounts.
-
#invalid ⇒ Object
readonly
The list of discount codes that could not be applied.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#applied ⇒ Object (readonly)
The list of successfully applied discounts.
164 165 166 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 164 def applied @applied end |
#invalid ⇒ Object (readonly)
The list of discount codes that could not be applied.
166 167 168 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 166 def invalid @invalid end |
Class Method Details
.field_remappings ⇒ Object
172 173 174 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 172 def self.field_remappings @field_remappings = {} end |