Class: Stripe::DelegatedCheckout::RequestedSession::FulfillmentDetails::FulfillmentOption::Digital::DigitalOption
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::DelegatedCheckout::RequestedSession::FulfillmentDetails::FulfillmentOption::Digital::DigitalOption
- Defined in:
- lib/stripe/resources/delegated_checkout/requested_session.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#description ⇒ Object
readonly
The description of the digital fulfillment option.
-
#digital_amount ⇒ Object
readonly
The digital amount of the digital fulfillment option.
-
#display_name ⇒ Object
readonly
The display name of the digital fulfillment option.
-
#key ⇒ Object
readonly
The key of the digital fulfillment option.
-
#line_item_keys ⇒ Object
readonly
The line item keys associated with this digital fulfillment option.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#description ⇒ Object (readonly)
The description of the digital fulfillment option.
205 206 207 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 205 def description @description end |
#digital_amount ⇒ Object (readonly)
The digital amount of the digital fulfillment option.
207 208 209 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 207 def digital_amount @digital_amount end |
#display_name ⇒ Object (readonly)
The display name of the digital fulfillment option.
209 210 211 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 209 def display_name @display_name end |
#key ⇒ Object (readonly)
The key of the digital fulfillment option.
211 212 213 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 211 def key @key end |
#line_item_keys ⇒ Object (readonly)
The line item keys associated with this digital fulfillment option.
213 214 215 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 213 def line_item_keys @line_item_keys end |
Class Method Details
.field_remappings ⇒ Object
219 220 221 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 219 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
215 216 217 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 215 def self.inner_class_types @inner_class_types = {} end |