Class: Stripe::DelegatedCheckout::RequestedSession::RiskDetails::ClientDeviceMetadataDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::DelegatedCheckout::RequestedSession::RiskDetails::ClientDeviceMetadataDetails
- Defined in:
- lib/stripe/resources/delegated_checkout/requested_session.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#radar_session ⇒ Object
readonly
The radar session for the client device.
-
#referrer ⇒ Object
readonly
The referrer of the client device.
-
#remote_ip ⇒ Object
readonly
The remote IP address of the client device.
-
#time_on_page_ms ⇒ Object
readonly
The time spent on the page by the client device.
-
#user_agent ⇒ Object
readonly
The user agent of the client device.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#radar_session ⇒ Object (readonly)
The radar session for the client device.
490 491 492 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 490 def radar_session @radar_session end |
#referrer ⇒ Object (readonly)
The referrer of the client device.
492 493 494 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 492 def referrer @referrer end |
#remote_ip ⇒ Object (readonly)
The remote IP address of the client device.
494 495 496 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 494 def remote_ip @remote_ip end |
#time_on_page_ms ⇒ Object (readonly)
The time spent on the page by the client device.
496 497 498 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 496 def time_on_page_ms @time_on_page_ms end |
#user_agent ⇒ Object (readonly)
The user agent of the client device.
498 499 500 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 498 def user_agent @user_agent end |
Class Method Details
.field_remappings ⇒ Object
504 505 506 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 504 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
500 501 502 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 500 def self.inner_class_types @inner_class_types = {} end |