Class: Stripe::DelegatedCheckout::RequestedSession::TotalDetails::Breakdown::Discount
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::DelegatedCheckout::RequestedSession::TotalDetails::Breakdown::Discount
- Defined in:
- lib/stripe/resources/delegated_checkout/requested_session.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The amount this discount contributed to the total discount.
-
#key ⇒ Object
readonly
The key of the applied discount.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The amount this discount contributed to the total discount.
691 692 693 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 691 def amount @amount end |
#key ⇒ Object (readonly)
The key of the applied discount.
693 694 695 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 693 def key @key end |
Class Method Details
.field_remappings ⇒ Object
699 700 701 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 699 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
695 696 697 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 695 def self.inner_class_types @inner_class_types = {} end |