Class: Stripe::DelegatedCheckout::RequestedSessionConfirmParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/delegated_checkout/requested_session_confirm_params.rb

Defined Under Namespace

Classes: AffiliateAttribution, BuyerConsents, RiskDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(affiliate_attribution: nil, buyer_consents: nil, expand: nil, metadata: nil, payment_method: nil, return_url: nil, risk_details: nil) ⇒ RequestedSessionConfirmParams

Returns a new instance of RequestedSessionConfirmParams.



149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/stripe/params/delegated_checkout/requested_session_confirm_params.rb', line 149

def initialize(
  affiliate_attribution: nil,
  buyer_consents: nil,
  expand: nil,
  metadata: nil,
  payment_method: nil,
  return_url: nil,
  risk_details: nil
)
  @affiliate_attribution = affiliate_attribution
  @buyer_consents = buyer_consents
  @expand = expand
  @metadata = 
  @payment_method = payment_method
  @return_url = return_url
  @risk_details = risk_details
end

Instance Attribute Details

#affiliate_attributionObject

Affiliate attribution data associated with this requested session.



135
136
137
# File 'lib/stripe/params/delegated_checkout/requested_session_confirm_params.rb', line 135

def affiliate_attribution
  @affiliate_attribution
end

#buyer_consentsObject

The buyer’s consent choices for marketing communications.



137
138
139
# File 'lib/stripe/params/delegated_checkout/requested_session_confirm_params.rb', line 137

def buyer_consents
  @buyer_consents
end

#expandObject

Specifies which fields in the response should be expanded.



139
140
141
# File 'lib/stripe/params/delegated_checkout/requested_session_confirm_params.rb', line 139

def expand
  @expand
end

#metadataObject

The metadata for this requested session.



141
142
143
# File 'lib/stripe/params/delegated_checkout/requested_session_confirm_params.rb', line 141

def 
  @metadata
end

#payment_methodObject

The PaymentMethod to use with the requested session.



143
144
145
# File 'lib/stripe/params/delegated_checkout/requested_session_confirm_params.rb', line 143

def payment_method
  @payment_method
end

#return_urlObject

The URL to redirect your customer back to after they authenticate or complete a payment action. Required for redirect-based payment methods such as Affirm or Klarna.



145
146
147
# File 'lib/stripe/params/delegated_checkout/requested_session_confirm_params.rb', line 145

def return_url
  @return_url
end

#risk_detailsObject

Risk details/signals associated with the requested session



147
148
149
# File 'lib/stripe/params/delegated_checkout/requested_session_confirm_params.rb', line 147

def risk_details
  @risk_details
end