Class: Stripe::DelegatedCheckout::RequestedSessionCreateParams::AffiliateAttribution
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::DelegatedCheckout::RequestedSessionCreateParams::AffiliateAttribution
- Defined in:
- lib/stripe/params/delegated_checkout/requested_session_create_params.rb
Defined Under Namespace
Classes: Source
Instance Attribute Summary collapse
-
#campaign_id ⇒ Object
Agent-scoped campaign identifier.
-
#creative_id ⇒ Object
Agent-scoped creative identifier.
-
#expires_at ⇒ Object
Timestamp when the attribution token expires.
-
#identification_token ⇒ Object
Agent-issued secret to validate the legitimacy of the source of this data.
-
#issued_at ⇒ Object
Timestamp for when the attribution token was issued.
-
#provider ⇒ Object
Identifier for the attribution agent / affiliate network namespace.
-
#publisher_id ⇒ Object
Agent-scoped affiliate/publisher identifier.
-
#shared_metadata ⇒ Object
Freeform key/value pairs for additional non-sensitive per-agent data.
-
#source ⇒ Object
Context about where the attribution originated.
-
#sub_id ⇒ Object
Agent-scoped sub-tracking identifier.
-
#touchpoint ⇒ Object
Whether this is the first or last touchpoint.
Instance Method Summary collapse
-
#initialize(campaign_id: nil, creative_id: nil, expires_at: nil, identification_token: nil, issued_at: nil, provider: nil, publisher_id: nil, shared_metadata: nil, source: nil, sub_id: nil, touchpoint: nil) ⇒ AffiliateAttribution
constructor
A new instance of AffiliateAttribution.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(campaign_id: nil, creative_id: nil, expires_at: nil, identification_token: nil, issued_at: nil, provider: nil, publisher_id: nil, shared_metadata: nil, source: nil, sub_id: nil, touchpoint: nil) ⇒ AffiliateAttribution
Returns a new instance of AffiliateAttribution.
45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 45 def initialize( campaign_id: nil, creative_id: nil, expires_at: nil, identification_token: nil, issued_at: nil, provider: nil, publisher_id: nil, shared_metadata: nil, source: nil, sub_id: nil, touchpoint: nil ) @campaign_id = campaign_id @creative_id = creative_id @expires_at = expires_at @identification_token = identification_token @issued_at = issued_at @provider = provider @publisher_id = publisher_id @shared_metadata = @source = source @sub_id = sub_id @touchpoint = touchpoint end |
Instance Attribute Details
#campaign_id ⇒ Object
Agent-scoped campaign identifier.
23 24 25 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 23 def campaign_id @campaign_id end |
#creative_id ⇒ Object
Agent-scoped creative identifier.
25 26 27 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 25 def creative_id @creative_id end |
#expires_at ⇒ Object
Timestamp when the attribution token expires.
27 28 29 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 27 def expires_at @expires_at end |
#identification_token ⇒ Object
Agent-issued secret to validate the legitimacy of the source of this data.
29 30 31 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 29 def identification_token @identification_token end |
#issued_at ⇒ Object
Timestamp for when the attribution token was issued.
31 32 33 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 31 def issued_at @issued_at end |
#provider ⇒ Object
Identifier for the attribution agent / affiliate network namespace.
33 34 35 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 33 def provider @provider end |
#publisher_id ⇒ Object
Agent-scoped affiliate/publisher identifier.
35 36 37 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 35 def publisher_id @publisher_id end |
#shared_metadata ⇒ Object
Freeform key/value pairs for additional non-sensitive per-agent data.
37 38 39 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 37 def @shared_metadata end |
#source ⇒ Object
Context about where the attribution originated.
39 40 41 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 39 def source @source end |
#sub_id ⇒ Object
Agent-scoped sub-tracking identifier.
41 42 43 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 41 def sub_id @sub_id end |
#touchpoint ⇒ Object
Whether this is the first or last touchpoint.
43 44 45 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 43 def touchpoint @touchpoint end |