Class: Stripe::DelegatedCheckout::RequestedSessionUpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/delegated_checkout/requested_session_update_params.rb

Defined Under Namespace

Classes: Discounts, FulfillmentDetails, LineItemDetail, PaymentMethodOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(discounts: nil, expand: nil, fulfillment_details: nil, line_item_details: nil, metadata: nil, payment_method: nil, payment_method_options: nil, shared_metadata: nil) ⇒ RequestedSessionUpdateParams

Returns a new instance of RequestedSessionUpdateParams.



195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
# File 'lib/stripe/params/delegated_checkout/requested_session_update_params.rb', line 195

def initialize(
  discounts: nil,
  expand: nil,
  fulfillment_details: nil,
  line_item_details: nil,
  metadata: nil,
  payment_method: nil,
  payment_method_options: nil,
  shared_metadata: nil
)
  @discounts = discounts
  @expand = expand
  @fulfillment_details = fulfillment_details
  @line_item_details = line_item_details
  @metadata = 
  @payment_method = payment_method
  @payment_method_options = payment_method_options
  @shared_metadata = 
end

Instance Attribute Details

#discountsObject

The discount codes to apply to this requested session.



179
180
181
# File 'lib/stripe/params/delegated_checkout/requested_session_update_params.rb', line 179

def discounts
  @discounts
end

#expandObject

Specifies which fields in the response should be expanded.



181
182
183
# File 'lib/stripe/params/delegated_checkout/requested_session_update_params.rb', line 181

def expand
  @expand
end

#fulfillment_detailsObject

The details of the fulfillment.



183
184
185
# File 'lib/stripe/params/delegated_checkout/requested_session_update_params.rb', line 183

def fulfillment_details
  @fulfillment_details
end

#line_item_detailsObject

The details of the line items.



185
186
187
# File 'lib/stripe/params/delegated_checkout/requested_session_update_params.rb', line 185

def line_item_details
  @line_item_details
end

#metadataObject

The metadata for this requested session.



187
188
189
# File 'lib/stripe/params/delegated_checkout/requested_session_update_params.rb', line 187

def 
  @metadata
end

#payment_methodObject

The payment method for this requested session.



189
190
191
# File 'lib/stripe/params/delegated_checkout/requested_session_update_params.rb', line 189

def payment_method
  @payment_method
end

#payment_method_optionsObject

The payment method options for this requested session.



191
192
193
# File 'lib/stripe/params/delegated_checkout/requested_session_update_params.rb', line 191

def payment_method_options
  @payment_method_options
end

#shared_metadataObject

The shared metadata for this requested session.



193
194
195
# File 'lib/stripe/params/delegated_checkout/requested_session_update_params.rb', line 193

def 
  @shared_metadata
end