Class: Stripe::Dispute::CloseParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Dispute::CloseParams
- Defined in:
- lib/stripe/resources/dispute.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ CloseParams
constructor
A new instance of CloseParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ CloseParams
Returns a new instance of CloseParams.
590 591 592 |
# File 'lib/stripe/resources/dispute.rb', line 590 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
588 589 590 |
# File 'lib/stripe/resources/dispute.rb', line 588 def @expand end |