Class: Stripe::Dispute::Evidence

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/dispute.rb

Defined Under Namespace

Classes: EnhancedEvidence

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#access_activity_logObject (readonly)

Any server or activity logs showing proof that the customer accessed or downloaded the purchased digital product. This information should include IP addresses, corresponding timestamps, and any detailed recorded activity.



181
182
183
# File 'lib/stripe/resources/dispute.rb', line 181

def access_activity_log
  @access_activity_log
end

#billing_addressObject (readonly)

The billing address provided by the customer.



183
184
185
# File 'lib/stripe/resources/dispute.rb', line 183

def billing_address
  @billing_address
end

#cancellation_policyObject (readonly)

(ID of a [file upload](stripe.com/docs/guides/file-upload)) Your subscription cancellation policy, as shown to the customer.



185
186
187
# File 'lib/stripe/resources/dispute.rb', line 185

def cancellation_policy
  @cancellation_policy
end

#cancellation_policy_disclosureObject (readonly)

An explanation of how and when the customer was shown your refund policy prior to purchase.



187
188
189
# File 'lib/stripe/resources/dispute.rb', line 187

def cancellation_policy_disclosure
  @cancellation_policy_disclosure
end

#cancellation_rebuttalObject (readonly)

A justification for why the customer’s subscription was not canceled.



189
190
191
# File 'lib/stripe/resources/dispute.rb', line 189

def cancellation_rebuttal
  @cancellation_rebuttal
end

#customer_communicationObject (readonly)

(ID of a [file upload](stripe.com/docs/guides/file-upload)) Any communication with the customer that you feel is relevant to your case. Examples include emails proving that the customer received the product or service, or demonstrating their use of or satisfaction with the product or service.



191
192
193
# File 'lib/stripe/resources/dispute.rb', line 191

def customer_communication
  @customer_communication
end

#customer_email_addressObject (readonly)

The email address of the customer.



193
194
195
# File 'lib/stripe/resources/dispute.rb', line 193

def customer_email_address
  @customer_email_address
end

#customer_nameObject (readonly)

The name of the customer.



195
196
197
# File 'lib/stripe/resources/dispute.rb', line 195

def customer_name
  @customer_name
end

#customer_purchase_ipObject (readonly)

The IP address that the customer used when making the purchase.



197
198
199
# File 'lib/stripe/resources/dispute.rb', line 197

def customer_purchase_ip
  @customer_purchase_ip
end

#customer_signatureObject (readonly)

(ID of a [file upload](stripe.com/docs/guides/file-upload)) A relevant document or contract showing the customer’s signature.



199
200
201
# File 'lib/stripe/resources/dispute.rb', line 199

def customer_signature
  @customer_signature
end

#duplicate_charge_documentationObject (readonly)

(ID of a [file upload](stripe.com/docs/guides/file-upload)) Documentation for the prior charge that can uniquely identify the charge, such as a receipt, shipping label, work order, etc. This document should be paired with a similar document from the disputed payment that proves the two payments are separate.



201
202
203
# File 'lib/stripe/resources/dispute.rb', line 201

def duplicate_charge_documentation
  @duplicate_charge_documentation
end

#duplicate_charge_explanationObject (readonly)

An explanation of the difference between the disputed charge versus the prior charge that appears to be a duplicate.



203
204
205
# File 'lib/stripe/resources/dispute.rb', line 203

def duplicate_charge_explanation
  @duplicate_charge_explanation
end

#duplicate_charge_idObject (readonly)

The Stripe ID for the prior charge which appears to be a duplicate of the disputed charge.



205
206
207
# File 'lib/stripe/resources/dispute.rb', line 205

def duplicate_charge_id
  @duplicate_charge_id
end

#enhanced_evidenceObject (readonly)

Attribute for field enhanced_evidence



207
208
209
# File 'lib/stripe/resources/dispute.rb', line 207

def enhanced_evidence
  @enhanced_evidence
end

#product_descriptionObject (readonly)

A description of the product or service that was sold.



209
210
211
# File 'lib/stripe/resources/dispute.rb', line 209

def product_description
  @product_description
end

#receiptObject (readonly)

(ID of a [file upload](stripe.com/docs/guides/file-upload)) Any receipt or message sent to the customer notifying them of the charge.



211
212
213
# File 'lib/stripe/resources/dispute.rb', line 211

def receipt
  @receipt
end

#refund_policyObject (readonly)

(ID of a [file upload](stripe.com/docs/guides/file-upload)) Your refund policy, as shown to the customer.



213
214
215
# File 'lib/stripe/resources/dispute.rb', line 213

def refund_policy
  @refund_policy
end

#refund_policy_disclosureObject (readonly)

Documentation demonstrating that the customer was shown your refund policy prior to purchase.



215
216
217
# File 'lib/stripe/resources/dispute.rb', line 215

def refund_policy_disclosure
  @refund_policy_disclosure
end

#refund_refusal_explanationObject (readonly)

A justification for why the customer is not entitled to a refund.



217
218
219
# File 'lib/stripe/resources/dispute.rb', line 217

def refund_refusal_explanation
  @refund_refusal_explanation
end

#service_dateObject (readonly)

The date on which the customer received or began receiving the purchased service, in a clear human-readable format.



219
220
221
# File 'lib/stripe/resources/dispute.rb', line 219

def service_date
  @service_date
end

#service_documentationObject (readonly)

(ID of a [file upload](stripe.com/docs/guides/file-upload)) Documentation showing proof that a service was provided to the customer. This could include a copy of a signed contract, work order, or other form of written agreement.



221
222
223
# File 'lib/stripe/resources/dispute.rb', line 221

def service_documentation
  @service_documentation
end

#shipping_addressObject (readonly)

The address to which a physical product was shipped. You should try to include as complete address information as possible.



223
224
225
# File 'lib/stripe/resources/dispute.rb', line 223

def shipping_address
  @shipping_address
end

#shipping_carrierObject (readonly)

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc. If multiple carriers were used for this purchase, please separate them with commas.



225
226
227
# File 'lib/stripe/resources/dispute.rb', line 225

def shipping_carrier
  @shipping_carrier
end

#shipping_dateObject (readonly)

The date on which a physical product began its route to the shipping address, in a clear human-readable format.



227
228
229
# File 'lib/stripe/resources/dispute.rb', line 227

def shipping_date
  @shipping_date
end

#shipping_documentationObject (readonly)

(ID of a [file upload](stripe.com/docs/guides/file-upload)) Documentation showing proof that a product was shipped to the customer at the same address the customer provided to you. This could include a copy of the shipment receipt, shipping label, etc. It should show the customer’s full shipping address, if possible.



229
230
231
# File 'lib/stripe/resources/dispute.rb', line 229

def shipping_documentation
  @shipping_documentation
end

#shipping_tracking_numberObject (readonly)

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



231
232
233
# File 'lib/stripe/resources/dispute.rb', line 231

def shipping_tracking_number
  @shipping_tracking_number
end

#uncategorized_fileObject (readonly)

(ID of a [file upload](stripe.com/docs/guides/file-upload)) Any additional evidence or statements.



233
234
235
# File 'lib/stripe/resources/dispute.rb', line 233

def uncategorized_file
  @uncategorized_file
end

#uncategorized_textObject (readonly)

Any additional evidence or statements.



235
236
237
# File 'lib/stripe/resources/dispute.rb', line 235

def uncategorized_text
  @uncategorized_text
end

Class Method Details

.field_remappingsObject



241
242
243
# File 'lib/stripe/resources/dispute.rb', line 241

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



237
238
239
# File 'lib/stripe/resources/dispute.rb', line 237

def self.inner_class_types
  @inner_class_types = { enhanced_evidence: EnhancedEvidence }
end