Class: Stripe::Dispute::Evidence::EnhancedEvidence::VisaCompellingEvidence3::PriorUndisputedTransaction

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/dispute.rb

Defined Under Namespace

Classes: ShippingAddress

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#chargeObject (readonly)

Stripe charge ID for the Visa Compelling Evidence 3.0 eligible prior charge.



88
89
90
# File 'lib/stripe/resources/dispute.rb', line 88

def charge
  @charge
end

#customer_account_idObject (readonly)

User Account ID used to log into business platform. Must be recognizable by the user.



91
92
93
# File 'lib/stripe/resources/dispute.rb', line 91

def 
  @customer_account_id
end

#customer_device_fingerprintObject (readonly)

Unique identifier of the cardholder’s device derived from a combination of at least two hardware and software attributes. Must be at least 20 characters.



94
95
96
# File 'lib/stripe/resources/dispute.rb', line 94

def customer_device_fingerprint
  @customer_device_fingerprint
end

#customer_device_idObject (readonly)

Unique identifier of the cardholder’s device such as a device serial number (e.g., International Mobile Equipment Identity [IMEI]). Must be at least 15 characters.



97
98
99
# File 'lib/stripe/resources/dispute.rb', line 97

def customer_device_id
  @customer_device_id
end

#customer_email_addressObject (readonly)

The email address of the customer.



100
101
102
# File 'lib/stripe/resources/dispute.rb', line 100

def customer_email_address
  @customer_email_address
end

#customer_purchase_ipObject (readonly)

The IP address that the customer used when making the purchase.



103
104
105
# File 'lib/stripe/resources/dispute.rb', line 103

def customer_purchase_ip
  @customer_purchase_ip
end

#product_descriptionObject (readonly)

A description of the product or service that was sold.



106
107
108
# File 'lib/stripe/resources/dispute.rb', line 106

def product_description
  @product_description
end

#shipping_addressObject (readonly)

The address to which a physical product was shipped. All fields are required for Visa Compelling Evidence 3.0 evidence submission.



109
110
111
# File 'lib/stripe/resources/dispute.rb', line 109

def shipping_address
  @shipping_address
end