Class: Stripe::Dispute::Evidence::EnhancedEvidence::VisaCompliance

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/dispute.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#fee_acknowledgedObject (readonly)

A field acknowledging the fee incurred when countering a Visa compliance dispute. If this field is set to true, evidence can be submitted for the compliance dispute. Stripe collects a 500 USD (or local equivalent) amount to cover the network costs associated with resolving compliance disputes. Stripe refunds the 500 USD network fee if you win the dispute.



151
152
153
# File 'lib/stripe/resources/dispute.rb', line 151

def fee_acknowledged
  @fee_acknowledged
end

Class Method Details

.field_remappingsObject



157
158
159
# File 'lib/stripe/resources/dispute.rb', line 157

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



153
154
155
# File 'lib/stripe/resources/dispute.rb', line 153

def self.inner_class_types
  @inner_class_types = {}
end