Class: Stripe::Dispute::EvidenceDetails

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/dispute.rb

Defined Under Namespace

Classes: EnhancedEligibility

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#due_byObject (readonly)

Date by which evidence must be submitted in order to successfully challenge dispute. Will be 0 if the customer's bank or credit card company doesn't allow a response for this particular dispute.



308
309
310
# File 'lib/stripe/resources/dispute.rb', line 308

def due_by
  @due_by
end

#enhanced_eligibilityObject (readonly)

Attribute for field enhanced_eligibility



310
311
312
# File 'lib/stripe/resources/dispute.rb', line 310

def enhanced_eligibility
  @enhanced_eligibility
end

#has_evidenceObject (readonly)

Whether evidence has been staged for this dispute.



312
313
314
# File 'lib/stripe/resources/dispute.rb', line 312

def has_evidence
  @has_evidence
end

#past_dueObject (readonly)

Whether the last evidence submission was submitted past the due date. Defaults to false if no evidence submissions have occurred. If true, then delivery of the latest evidence is not guaranteed.



314
315
316
# File 'lib/stripe/resources/dispute.rb', line 314

def past_due
  @past_due
end

#submission_countObject (readonly)

The number of times evidence has been submitted. Typically, you may only submit evidence once.



316
317
318
# File 'lib/stripe/resources/dispute.rb', line 316

def submission_count
  @submission_count
end

#submission_methodObject (readonly)

Whether the dispute was submitted manually, with Smart Disputes, or not submitted.



318
319
320
# File 'lib/stripe/resources/dispute.rb', line 318

def submission_method
  @submission_method
end

Class Method Details

.field_remappingsObject



324
325
326
# File 'lib/stripe/resources/dispute.rb', line 324

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



320
321
322
# File 'lib/stripe/resources/dispute.rb', line 320

def self.inner_class_types
  @inner_class_types = { enhanced_eligibility: EnhancedEligibility }
end