Class: Stripe::Dispute::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/dispute.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(charge: nil, created: nil, ending_before: nil, expand: nil, limit: nil, payment_intent: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
# File 'lib/stripe/resources/dispute.rb', line 423

def initialize(
  charge: nil,
  created: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  payment_intent: nil,
  starting_after: nil
)
  @charge = charge
  @created = created
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @payment_intent = payment_intent
  @starting_after = starting_after
end

Instance Attribute Details

#chargeObject

Only return disputes associated to the charge specified by this charge ID.



409
410
411
# File 'lib/stripe/resources/dispute.rb', line 409

def charge
  @charge
end

#createdObject

Only return disputes that were created during the given date interval.



411
412
413
# File 'lib/stripe/resources/dispute.rb', line 411

def created
  @created
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



413
414
415
# File 'lib/stripe/resources/dispute.rb', line 413

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



415
416
417
# File 'lib/stripe/resources/dispute.rb', line 415

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



417
418
419
# File 'lib/stripe/resources/dispute.rb', line 417

def limit
  @limit
end

#payment_intentObject

Only return disputes associated to the PaymentIntent specified by this PaymentIntent ID.



419
420
421
# File 'lib/stripe/resources/dispute.rb', line 419

def payment_intent
  @payment_intent
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



421
422
423
# File 'lib/stripe/resources/dispute.rb', line 421

def starting_after
  @starting_after
end