Class: Stripe::Dispute::PaymentMethodDetails::Card

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/dispute.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#brandObject (readonly)

Card brand. Can be amex, cartes_bancaires, diners, discover, eftpos_au, jcb, link, mastercard, unionpay, visa or unknown.



345
346
347
# File 'lib/stripe/resources/dispute.rb', line 345

def brand
  @brand
end

#case_typeObject (readonly)

The type of dispute opened. Different case types may have varying fees and financial impact.



347
348
349
# File 'lib/stripe/resources/dispute.rb', line 347

def case_type
  @case_type
end

#networkObject (readonly)

Identifies which network this charge was processed on. Can be amex, cartes_bancaires, diners, discover, eftpos_au, interac, jcb, link, mastercard, unionpay, visa, or unknown.



349
350
351
# File 'lib/stripe/resources/dispute.rb', line 349

def network
  @network
end

#network_reason_codeObject (readonly)

The card network's specific dispute reason code, which maps to one of Stripe's primary dispute categories to simplify response guidance. The Network code map lists all available dispute reason codes by network.



351
352
353
# File 'lib/stripe/resources/dispute.rb', line 351

def network_reason_code
  @network_reason_code
end

Class Method Details

.field_remappingsObject



357
358
359
# File 'lib/stripe/resources/dispute.rb', line 357

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



353
354
355
# File 'lib/stripe/resources/dispute.rb', line 353

def self.inner_class_types
  @inner_class_types = {}
end