Class: Stripe::Dispute::SmartDisputes
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Dispute::SmartDisputes
- Defined in:
- lib/stripe/resources/dispute.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#recommended_evidence ⇒ Object
readonly
Evidence that could be provided to improve the SmartDisputes packet.
-
#status ⇒ Object
readonly
Smart Disputes auto representment packet availability status.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#recommended_evidence ⇒ Object (readonly)
Evidence that could be provided to improve the SmartDisputes packet
379 380 381 |
# File 'lib/stripe/resources/dispute.rb', line 379 def recommended_evidence @recommended_evidence end |
#status ⇒ Object (readonly)
Smart Disputes auto representment packet availability status.
381 382 383 |
# File 'lib/stripe/resources/dispute.rb', line 381 def status @status end |
Class Method Details
.field_remappings ⇒ Object
387 388 389 |
# File 'lib/stripe/resources/dispute.rb', line 387 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
383 384 385 |
# File 'lib/stripe/resources/dispute.rb', line 383 def self.inner_class_types @inner_class_types = {} end |