Class: Stripe::Dispute::UpdateParams::Evidence::EnhancedEvidence::VisaCompellingEvidence3::DisputedTransaction
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Dispute::UpdateParams::Evidence::EnhancedEvidence::VisaCompellingEvidence3::DisputedTransaction
- Defined in:
- lib/stripe/resources/dispute.rb
Defined Under Namespace
Classes: ShippingAddress
Instance Attribute Summary collapse
-
#customer_account_id ⇒ Object
User Account ID used to log into business platform.
-
#customer_device_fingerprint ⇒ Object
Unique identifier of the cardholder’s device derived from a combination of at least two hardware and software attributes.
-
#customer_device_id ⇒ Object
Unique identifier of the cardholder’s device such as a device serial number (e.g., International Mobile Equipment Identity [IMEI]).
-
#customer_email_address ⇒ Object
The email address of the customer.
-
#customer_purchase_ip ⇒ Object
The IP address that the customer used when making the purchase.
-
#merchandise_or_services ⇒ Object
Categorization of disputed payment.
-
#product_description ⇒ Object
A description of the product or service that was sold.
-
#shipping_address ⇒ Object
The address to which a physical product was shipped.
Instance Method Summary collapse
-
#initialize(customer_account_id: nil, customer_device_fingerprint: nil, customer_device_id: nil, customer_email_address: nil, customer_purchase_ip: nil, merchandise_or_services: nil, product_description: nil, shipping_address: nil) ⇒ DisputedTransaction
constructor
A new instance of DisputedTransaction.
Methods inherited from RequestParams
Constructor Details
#initialize(customer_account_id: nil, customer_device_fingerprint: nil, customer_device_id: nil, customer_email_address: nil, customer_purchase_ip: nil, merchandise_or_services: nil, product_description: nil, shipping_address: nil) ⇒ DisputedTransaction
Returns a new instance of DisputedTransaction.
428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 |
# File 'lib/stripe/resources/dispute.rb', line 428 def initialize( customer_account_id: nil, customer_device_fingerprint: nil, customer_device_id: nil, customer_email_address: nil, customer_purchase_ip: nil, merchandise_or_services: nil, product_description: nil, shipping_address: nil ) @customer_account_id = customer_account_id @customer_device_fingerprint = customer_device_fingerprint @customer_device_id = customer_device_id @customer_email_address = customer_email_address @customer_purchase_ip = customer_purchase_ip @merchandise_or_services = merchandise_or_services @product_description = product_description @shipping_address = shipping_address end |
Instance Attribute Details
#customer_account_id ⇒ Object
User Account ID used to log into business platform. Must be recognizable by the user.
405 406 407 |
# File 'lib/stripe/resources/dispute.rb', line 405 def customer_account_id @customer_account_id end |
#customer_device_fingerprint ⇒ Object
Unique identifier of the cardholder’s device derived from a combination of at least two hardware and software attributes. Must be at least 20 characters.
408 409 410 |
# File 'lib/stripe/resources/dispute.rb', line 408 def customer_device_fingerprint @customer_device_fingerprint end |
#customer_device_id ⇒ Object
Unique identifier of the cardholder’s device such as a device serial number (e.g., International Mobile Equipment Identity [IMEI]). Must be at least 15 characters.
411 412 413 |
# File 'lib/stripe/resources/dispute.rb', line 411 def customer_device_id @customer_device_id end |
#customer_email_address ⇒ Object
The email address of the customer.
414 415 416 |
# File 'lib/stripe/resources/dispute.rb', line 414 def customer_email_address @customer_email_address end |
#customer_purchase_ip ⇒ Object
The IP address that the customer used when making the purchase.
417 418 419 |
# File 'lib/stripe/resources/dispute.rb', line 417 def customer_purchase_ip @customer_purchase_ip end |
#merchandise_or_services ⇒ Object
Categorization of disputed payment.
420 421 422 |
# File 'lib/stripe/resources/dispute.rb', line 420 def merchandise_or_services @merchandise_or_services end |
#product_description ⇒ Object
A description of the product or service that was sold.
423 424 425 |
# File 'lib/stripe/resources/dispute.rb', line 423 def product_description @product_description end |
#shipping_address ⇒ Object
The address to which a physical product was shipped. All fields are required for Visa Compelling Evidence 3.0 evidence submission.
426 427 428 |
# File 'lib/stripe/resources/dispute.rb', line 426 def shipping_address @shipping_address end |