Class: Stripe::Dispute::UpdateParams::Evidence::EnhancedEvidence::VisaCompellingEvidence3::PriorUndisputedTransaction
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Dispute::UpdateParams::Evidence::EnhancedEvidence::VisaCompellingEvidence3::PriorUndisputedTransaction
- Defined in:
- lib/stripe/resources/dispute.rb
Defined Under Namespace
Classes: ShippingAddress
Instance Attribute Summary collapse
-
#charge ⇒ Object
Stripe charge ID for the Visa Compelling Evidence 3.0 eligible prior charge.
-
#customer_account_id ⇒ Object
User Account ID used to log into business platform.
-
#customer_device_fingerprint ⇒ Object
Unique identifier of the cardholder’s device derived from a combination of at least two hardware and software attributes.
-
#customer_device_id ⇒ Object
Unique identifier of the cardholder’s device such as a device serial number (e.g., International Mobile Equipment Identity [IMEI]).
-
#customer_email_address ⇒ Object
The email address of the customer.
-
#customer_purchase_ip ⇒ Object
The IP address that the customer used when making the purchase.
-
#product_description ⇒ Object
A description of the product or service that was sold.
-
#shipping_address ⇒ Object
The address to which a physical product was shipped.
Instance Method Summary collapse
-
#initialize(charge: nil, customer_account_id: nil, customer_device_fingerprint: nil, customer_device_id: nil, customer_email_address: nil, customer_purchase_ip: nil, product_description: nil, shipping_address: nil) ⇒ PriorUndisputedTransaction
constructor
A new instance of PriorUndisputedTransaction.
Methods inherited from RequestParams
Constructor Details
#initialize(charge: nil, customer_account_id: nil, customer_device_fingerprint: nil, customer_device_id: nil, customer_email_address: nil, customer_purchase_ip: nil, product_description: nil, shipping_address: nil) ⇒ PriorUndisputedTransaction
Returns a new instance of PriorUndisputedTransaction.
563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 |
# File 'lib/stripe/resources/dispute.rb', line 563 def initialize( charge: nil, customer_account_id: nil, customer_device_fingerprint: nil, customer_device_id: nil, customer_email_address: nil, customer_purchase_ip: nil, product_description: nil, shipping_address: nil ) @charge = charge @customer_account_id = customer_account_id @customer_device_fingerprint = customer_device_fingerprint @customer_device_id = customer_device_id @customer_email_address = customer_email_address @customer_purchase_ip = customer_purchase_ip @product_description = product_description @shipping_address = shipping_address end |
Instance Attribute Details
#charge ⇒ Object
Stripe charge ID for the Visa Compelling Evidence 3.0 eligible prior charge.
547 548 549 |
# File 'lib/stripe/resources/dispute.rb', line 547 def charge @charge end |
#customer_account_id ⇒ Object
User Account ID used to log into business platform. Must be recognizable by the user.
549 550 551 |
# File 'lib/stripe/resources/dispute.rb', line 549 def customer_account_id @customer_account_id end |
#customer_device_fingerprint ⇒ Object
Unique identifier of the cardholder’s device derived from a combination of at least two hardware and software attributes. Must be at least 20 characters.
551 552 553 |
# File 'lib/stripe/resources/dispute.rb', line 551 def customer_device_fingerprint @customer_device_fingerprint end |
#customer_device_id ⇒ Object
Unique identifier of the cardholder’s device such as a device serial number (e.g., International Mobile Equipment Identity [IMEI]). Must be at least 15 characters.
553 554 555 |
# File 'lib/stripe/resources/dispute.rb', line 553 def customer_device_id @customer_device_id end |
#customer_email_address ⇒ Object
The email address of the customer.
555 556 557 |
# File 'lib/stripe/resources/dispute.rb', line 555 def customer_email_address @customer_email_address end |
#customer_purchase_ip ⇒ Object
The IP address that the customer used when making the purchase.
557 558 559 |
# File 'lib/stripe/resources/dispute.rb', line 557 def customer_purchase_ip @customer_purchase_ip end |
#product_description ⇒ Object
A description of the product or service that was sold.
559 560 561 |
# File 'lib/stripe/resources/dispute.rb', line 559 def product_description @product_description end |
#shipping_address ⇒ Object
The address to which a physical product was shipped. All fields are required for Visa Compelling Evidence 3.0 evidence submission.
561 562 563 |
# File 'lib/stripe/resources/dispute.rb', line 561 def shipping_address @shipping_address end |