Class: Stripe::Dispute::UpdateParams::Evidence::EnhancedEvidence::VisaCompliance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/dispute.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(fee_acknowledged: nil) ⇒ VisaCompliance

Returns a new instance of VisaCompliance.



438
439
440
# File 'lib/stripe/resources/dispute.rb', line 438

def initialize(fee_acknowledged: nil)
  @fee_acknowledged = fee_acknowledged
end

Instance Attribute Details

#fee_acknowledgedObject

A field acknowledging the fee incurred when countering a Visa compliance dispute. If this field is set to true, evidence can be submitted for the compliance dispute. Stripe collects a 500 USD (or local equivalent) amount to cover the network costs associated with resolving compliance disputes. Stripe refunds the 500 USD network fee if you win the dispute.



436
437
438
# File 'lib/stripe/resources/dispute.rb', line 436

def fee_acknowledged
  @fee_acknowledged
end