Class: Stripe::DisputeService::CloseParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::DisputeService::CloseParams
- Defined in:
- lib/stripe/services/dispute_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ CloseParams
constructor
A new instance of CloseParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ CloseParams
Returns a new instance of CloseParams.
440 441 442 |
# File 'lib/stripe/services/dispute_service.rb', line 440 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
438 439 440 |
# File 'lib/stripe/services/dispute_service.rb', line 438 def @expand end |