Class: Stripe::DisputeService::UpdateParams::Evidence

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/dispute_service.rb

Defined Under Namespace

Classes: EnhancedEvidence

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(access_activity_log: nil, billing_address: nil, cancellation_policy: nil, cancellation_policy_disclosure: nil, cancellation_rebuttal: nil, customer_communication: nil, customer_email_address: nil, customer_name: nil, customer_purchase_ip: nil, customer_signature: nil, duplicate_charge_documentation: nil, duplicate_charge_explanation: nil, duplicate_charge_id: nil, enhanced_evidence: nil, product_description: nil, receipt: nil, refund_policy: nil, refund_policy_disclosure: nil, refund_refusal_explanation: nil, service_date: nil, service_documentation: nil, shipping_address: nil, shipping_carrier: nil, shipping_date: nil, shipping_documentation: nil, shipping_tracking_number: nil, uncategorized_file: nil, uncategorized_text: nil) ⇒ Evidence

Returns a new instance of Evidence.



356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
# File 'lib/stripe/services/dispute_service.rb', line 356

def initialize(
  access_activity_log: nil,
  billing_address: nil,
  cancellation_policy: nil,
  cancellation_policy_disclosure: nil,
  cancellation_rebuttal: nil,
  customer_communication: nil,
  customer_email_address: nil,
  customer_name: nil,
  customer_purchase_ip: nil,
  customer_signature: nil,
  duplicate_charge_documentation: nil,
  duplicate_charge_explanation: nil,
  duplicate_charge_id: nil,
  enhanced_evidence: nil,
  product_description: nil,
  receipt: nil,
  refund_policy: nil,
  refund_policy_disclosure: nil,
  refund_refusal_explanation: nil,
  service_date: nil,
  service_documentation: nil,
  shipping_address: nil,
  shipping_carrier: nil,
  shipping_date: nil,
  shipping_documentation: nil,
  shipping_tracking_number: nil,
  uncategorized_file: nil,
  uncategorized_text: nil
)
  @access_activity_log = access_activity_log
  @billing_address = billing_address
  @cancellation_policy = cancellation_policy
  @cancellation_policy_disclosure = cancellation_policy_disclosure
  @cancellation_rebuttal = cancellation_rebuttal
  @customer_communication = customer_communication
  @customer_email_address = customer_email_address
  @customer_name = customer_name
  @customer_purchase_ip = customer_purchase_ip
  @customer_signature = customer_signature
  @duplicate_charge_documentation = duplicate_charge_documentation
  @duplicate_charge_explanation = duplicate_charge_explanation
  @duplicate_charge_id = duplicate_charge_id
  @enhanced_evidence = enhanced_evidence
  @product_description = product_description
  @receipt = receipt
  @refund_policy = refund_policy
  @refund_policy_disclosure = refund_policy_disclosure
  @refund_refusal_explanation = refund_refusal_explanation
  @service_date = service_date
  @service_documentation = service_documentation
  @shipping_address = shipping_address
  @shipping_carrier = shipping_carrier
  @shipping_date = shipping_date
  @shipping_documentation = shipping_documentation
  @shipping_tracking_number = shipping_tracking_number
  @uncategorized_file = uncategorized_file
  @uncategorized_text = uncategorized_text
end

Instance Attribute Details

#access_activity_logObject

Any server or activity logs showing proof that the customer accessed or downloaded the purchased digital product. This information should include IP addresses, corresponding timestamps, and any detailed recorded activity. Has a maximum character count of 20,000.



273
274
275
# File 'lib/stripe/services/dispute_service.rb', line 273

def access_activity_log
  @access_activity_log
end

#billing_addressObject

The billing address provided by the customer.



276
277
278
# File 'lib/stripe/services/dispute_service.rb', line 276

def billing_address
  @billing_address
end

#cancellation_policyObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) Your subscription cancellation policy, as shown to the customer.



279
280
281
# File 'lib/stripe/services/dispute_service.rb', line 279

def cancellation_policy
  @cancellation_policy
end

#cancellation_policy_disclosureObject

An explanation of how and when the customer was shown your refund policy prior to purchase. Has a maximum character count of 20,000.



282
283
284
# File 'lib/stripe/services/dispute_service.rb', line 282

def cancellation_policy_disclosure
  @cancellation_policy_disclosure
end

#cancellation_rebuttalObject

A justification for why the customer’s subscription was not canceled. Has a maximum character count of 20,000.



285
286
287
# File 'lib/stripe/services/dispute_service.rb', line 285

def cancellation_rebuttal
  @cancellation_rebuttal
end

#customer_communicationObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) Any communication with the customer that you feel is relevant to your case. Examples include emails proving that the customer received the product or service, or demonstrating their use of or satisfaction with the product or service.



288
289
290
# File 'lib/stripe/services/dispute_service.rb', line 288

def customer_communication
  @customer_communication
end

#customer_email_addressObject

The email address of the customer.



291
292
293
# File 'lib/stripe/services/dispute_service.rb', line 291

def customer_email_address
  @customer_email_address
end

#customer_nameObject

The name of the customer.



294
295
296
# File 'lib/stripe/services/dispute_service.rb', line 294

def customer_name
  @customer_name
end

#customer_purchase_ipObject

The IP address that the customer used when making the purchase.



297
298
299
# File 'lib/stripe/services/dispute_service.rb', line 297

def customer_purchase_ip
  @customer_purchase_ip
end

#customer_signatureObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) A relevant document or contract showing the customer’s signature.



300
301
302
# File 'lib/stripe/services/dispute_service.rb', line 300

def customer_signature
  @customer_signature
end

#duplicate_charge_documentationObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) Documentation for the prior charge that can uniquely identify the charge, such as a receipt, shipping label, work order, etc. This document should be paired with a similar document from the disputed payment that proves the two payments are separate.



303
304
305
# File 'lib/stripe/services/dispute_service.rb', line 303

def duplicate_charge_documentation
  @duplicate_charge_documentation
end

#duplicate_charge_explanationObject

An explanation of the difference between the disputed charge versus the prior charge that appears to be a duplicate. Has a maximum character count of 20,000.



306
307
308
# File 'lib/stripe/services/dispute_service.rb', line 306

def duplicate_charge_explanation
  @duplicate_charge_explanation
end

#duplicate_charge_idObject

The Stripe ID for the prior charge which appears to be a duplicate of the disputed charge.



309
310
311
# File 'lib/stripe/services/dispute_service.rb', line 309

def duplicate_charge_id
  @duplicate_charge_id
end

#enhanced_evidenceObject

Additional evidence for qualifying evidence programs.



312
313
314
# File 'lib/stripe/services/dispute_service.rb', line 312

def enhanced_evidence
  @enhanced_evidence
end

#product_descriptionObject

A description of the product or service that was sold. Has a maximum character count of 20,000.



315
316
317
# File 'lib/stripe/services/dispute_service.rb', line 315

def product_description
  @product_description
end

#receiptObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) Any receipt or message sent to the customer notifying them of the charge.



318
319
320
# File 'lib/stripe/services/dispute_service.rb', line 318

def receipt
  @receipt
end

#refund_policyObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) Your refund policy, as shown to the customer.



321
322
323
# File 'lib/stripe/services/dispute_service.rb', line 321

def refund_policy
  @refund_policy
end

#refund_policy_disclosureObject

Documentation demonstrating that the customer was shown your refund policy prior to purchase. Has a maximum character count of 20,000.



324
325
326
# File 'lib/stripe/services/dispute_service.rb', line 324

def refund_policy_disclosure
  @refund_policy_disclosure
end

#refund_refusal_explanationObject

A justification for why the customer is not entitled to a refund. Has a maximum character count of 20,000.



327
328
329
# File 'lib/stripe/services/dispute_service.rb', line 327

def refund_refusal_explanation
  @refund_refusal_explanation
end

#service_dateObject

The date on which the customer received or began receiving the purchased service, in a clear human-readable format.



330
331
332
# File 'lib/stripe/services/dispute_service.rb', line 330

def service_date
  @service_date
end

#service_documentationObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) Documentation showing proof that a service was provided to the customer. This could include a copy of a signed contract, work order, or other form of written agreement.



333
334
335
# File 'lib/stripe/services/dispute_service.rb', line 333

def service_documentation
  @service_documentation
end

#shipping_addressObject

The address to which a physical product was shipped. You should try to include as complete address information as possible.



336
337
338
# File 'lib/stripe/services/dispute_service.rb', line 336

def shipping_address
  @shipping_address
end

#shipping_carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc. If multiple carriers were used for this purchase, please separate them with commas.



339
340
341
# File 'lib/stripe/services/dispute_service.rb', line 339

def shipping_carrier
  @shipping_carrier
end

#shipping_dateObject

The date on which a physical product began its route to the shipping address, in a clear human-readable format.



342
343
344
# File 'lib/stripe/services/dispute_service.rb', line 342

def shipping_date
  @shipping_date
end

#shipping_documentationObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) Documentation showing proof that a product was shipped to the customer at the same address the customer provided to you. This could include a copy of the shipment receipt, shipping label, etc. It should show the customer’s full shipping address, if possible.



345
346
347
# File 'lib/stripe/services/dispute_service.rb', line 345

def shipping_documentation
  @shipping_documentation
end

#shipping_tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



348
349
350
# File 'lib/stripe/services/dispute_service.rb', line 348

def shipping_tracking_number
  @shipping_tracking_number
end

#uncategorized_fileObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) Any additional evidence or statements.



351
352
353
# File 'lib/stripe/services/dispute_service.rb', line 351

def uncategorized_file
  @uncategorized_file
end

#uncategorized_textObject

Any additional evidence or statements. Has a maximum character count of 20,000.



354
355
356
# File 'lib/stripe/services/dispute_service.rb', line 354

def uncategorized_text
  @uncategorized_text
end