Class: Stripe::DisputeUpdateParams::Evidence::EnhancedEvidence::VisaCompellingEvidence3::PriorUndisputedTransaction

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/dispute_update_params.rb

Defined Under Namespace

Classes: ShippingAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(charge: nil, customer_account_id: nil, customer_device_fingerprint: nil, customer_device_id: nil, customer_email_address: nil, customer_purchase_ip: nil, product_description: nil, shipping_address: nil) ⇒ PriorUndisputedTransaction

Returns a new instance of PriorUndisputedTransaction.



135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
# File 'lib/stripe/params/dispute_update_params.rb', line 135

def initialize(
  charge: nil,
  customer_account_id: nil,
  customer_device_fingerprint: nil,
  customer_device_id: nil,
  customer_email_address: nil,
  customer_purchase_ip: nil,
  product_description: nil,
  shipping_address: nil
)
  @charge = charge
  @customer_account_id = 
  @customer_device_fingerprint = customer_device_fingerprint
  @customer_device_id = customer_device_id
  @customer_email_address = customer_email_address
  @customer_purchase_ip = customer_purchase_ip
  @product_description = product_description
  @shipping_address = shipping_address
end

Instance Attribute Details

#chargeObject

Stripe charge ID for the Visa Compelling Evidence 3.0 eligible prior charge.



119
120
121
# File 'lib/stripe/params/dispute_update_params.rb', line 119

def charge
  @charge
end

#customer_account_idObject

User Account ID used to log into business platform. Must be recognizable by the user.



121
122
123
# File 'lib/stripe/params/dispute_update_params.rb', line 121

def 
  @customer_account_id
end

#customer_device_fingerprintObject

Unique identifier of the cardholder’s device derived from a combination of at least two hardware and software attributes. Must be at least 20 characters.



123
124
125
# File 'lib/stripe/params/dispute_update_params.rb', line 123

def customer_device_fingerprint
  @customer_device_fingerprint
end

#customer_device_idObject

Unique identifier of the cardholder’s device such as a device serial number (e.g., International Mobile Equipment Identity [IMEI]). Must be at least 15 characters.



125
126
127
# File 'lib/stripe/params/dispute_update_params.rb', line 125

def customer_device_id
  @customer_device_id
end

#customer_email_addressObject

The email address of the customer.



127
128
129
# File 'lib/stripe/params/dispute_update_params.rb', line 127

def customer_email_address
  @customer_email_address
end

#customer_purchase_ipObject

The IP address that the customer used when making the purchase.



129
130
131
# File 'lib/stripe/params/dispute_update_params.rb', line 129

def customer_purchase_ip
  @customer_purchase_ip
end

#product_descriptionObject

A description of the product or service that was sold.



131
132
133
# File 'lib/stripe/params/dispute_update_params.rb', line 131

def product_description
  @product_description
end

#shipping_addressObject

The address to which a physical product was shipped. All fields are required for Visa Compelling Evidence 3.0 evidence submission.



133
134
135
# File 'lib/stripe/params/dispute_update_params.rb', line 133

def shipping_address
  @shipping_address
end