Class: Stripe::Entitlements::ActiveEntitlementSummary

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/entitlements/active_entitlement_summary.rb

Overview

A summary of a customer’s active entitlements.

Constant Summary collapse

OBJECT_NAME =
"entitlements.active_entitlement_summary"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#customerObject (readonly)

The customer that is entitled to this feature.



14
15
16
# File 'lib/stripe/resources/entitlements/active_entitlement_summary.rb', line 14

def customer
  @customer
end

#entitlementsObject (readonly)

The list of entitlements this customer has.



17
18
19
# File 'lib/stripe/resources/entitlements/active_entitlement_summary.rb', line 17

def entitlements
  @entitlements
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



20
21
22
# File 'lib/stripe/resources/entitlements/active_entitlement_summary.rb', line 20

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



23
24
25
# File 'lib/stripe/resources/entitlements/active_entitlement_summary.rb', line 23

def object
  @object
end

Class Method Details

.object_nameObject



9
10
11
# File 'lib/stripe/resources/entitlements/active_entitlement_summary.rb', line 9

def self.object_name
  "entitlements.active_entitlement_summary"
end