Class: Stripe::Entitlements::Feature
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Entitlements::Feature
- Extended by:
- APIOperations::Create, APIOperations::List
- Includes:
- APIOperations::Save
- Defined in:
- lib/stripe/resources/entitlements/feature.rb
Overview
A feature represents a monetizable ability or functionality in your system. Features can be assigned to products, and when those products are purchased, Stripe will create an entitlement to the feature for the purchasing customer.
Defined Under Namespace
Classes: CreateParams, ListParams, RetrieveParams, UpdateParams
Constant Summary collapse
- OBJECT_NAME =
"entitlements.feature"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#active ⇒ Object
readonly
Inactive features cannot be attached to new products and will not be returned from the features list endpoint.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#lookup_key ⇒ Object
readonly
A unique key you provide as your own system identifier.
-
#metadata ⇒ Object
readonly
Set of key-value pairs that you can attach to an object.
-
#name ⇒ Object
readonly
The feature’s name, for your own purpose, not meant to be displayable to the customer.
-
#object ⇒ Object
readonly
String representing the object’s type.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.create(params = {}, opts = {}) ⇒ Object
Creates a feature.
-
.list(params = {}, opts = {}) ⇒ Object
Retrieve a list of features.
- .object_name ⇒ Object
-
.update(id, params = {}, opts = {}) ⇒ Object
Update a feature’s metadata or permanently deactivate it.
Methods included from APIOperations::Create
Methods included from APIOperations::List
Methods included from APIOperations::Save
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#active ⇒ Object (readonly)
Inactive features cannot be attached to new products and will not be returned from the features list endpoint.
94 95 96 |
# File 'lib/stripe/resources/entitlements/feature.rb', line 94 def active @active end |
#id ⇒ Object (readonly)
Unique identifier for the object.
96 97 98 |
# File 'lib/stripe/resources/entitlements/feature.rb', line 96 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
98 99 100 |
# File 'lib/stripe/resources/entitlements/feature.rb', line 98 def livemode @livemode end |
#lookup_key ⇒ Object (readonly)
A unique key you provide as your own system identifier. This may be up to 80 characters.
100 101 102 |
# File 'lib/stripe/resources/entitlements/feature.rb', line 100 def lookup_key @lookup_key end |
#metadata ⇒ Object (readonly)
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
102 103 104 |
# File 'lib/stripe/resources/entitlements/feature.rb', line 102 def @metadata end |
#name ⇒ Object (readonly)
The feature’s name, for your own purpose, not meant to be displayable to the customer.
104 105 106 |
# File 'lib/stripe/resources/entitlements/feature.rb', line 104 def name @name end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
106 107 108 |
# File 'lib/stripe/resources/entitlements/feature.rb', line 106 def object @object end |
Class Method Details
.create(params = {}, opts = {}) ⇒ Object
Creates a feature
109 110 111 112 113 114 115 116 |
# File 'lib/stripe/resources/entitlements/feature.rb', line 109 def self.create(params = {}, opts = {}) request_stripe_object( method: :post, path: "/v1/entitlements/features", params: params, opts: opts ) end |
.list(params = {}, opts = {}) ⇒ Object
Retrieve a list of features
119 120 121 122 123 124 125 126 |
# File 'lib/stripe/resources/entitlements/feature.rb', line 119 def self.list(params = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/entitlements/features", params: params, opts: opts ) end |
.object_name ⇒ Object
14 15 16 |
# File 'lib/stripe/resources/entitlements/feature.rb', line 14 def self.object_name "entitlements.feature" end |
.update(id, params = {}, opts = {}) ⇒ Object
Update a feature’s metadata or permanently deactivate it.
129 130 131 132 133 134 135 136 |
# File 'lib/stripe/resources/entitlements/feature.rb', line 129 def self.update(id, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/entitlements/features/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts ) end |