Class: Stripe::Entitlements::Feature::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/entitlements/feature.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, lookup_key: nil, metadata: nil, name: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



59
60
61
62
63
64
# File 'lib/stripe/resources/entitlements/feature.rb', line 59

def initialize(expand: nil, lookup_key: nil, metadata: nil, name: nil)
  @expand = expand
  @lookup_key = lookup_key
  @metadata = 
  @name = name
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



51
52
53
# File 'lib/stripe/resources/entitlements/feature.rb', line 51

def expand
  @expand
end

#lookup_keyObject

A unique key you provide as your own system identifier. This may be up to 80 characters.



53
54
55
# File 'lib/stripe/resources/entitlements/feature.rb', line 53

def lookup_key
  @lookup_key
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



55
56
57
# File 'lib/stripe/resources/entitlements/feature.rb', line 55

def 
  @metadata
end

#nameObject

The feature’s name, for your own purpose, not meant to be displayable to the customer.



57
58
59
# File 'lib/stripe/resources/entitlements/feature.rb', line 57

def name
  @name
end