Class: Stripe::Entitlements::Feature::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/entitlements/feature.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(active: nil, expand: nil, metadata: nil, name: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



86
87
88
89
90
91
# File 'lib/stripe/resources/entitlements/feature.rb', line 86

def initialize(active: nil, expand: nil, metadata: nil, name: nil)
  @active = active
  @expand = expand
  @metadata = 
  @name = name
end

Instance Attribute Details

#activeObject

Inactive features cannot be attached to new products and will not be returned from the features list endpoint.



78
79
80
# File 'lib/stripe/resources/entitlements/feature.rb', line 78

def active
  @active
end

#expandObject

Specifies which fields in the response should be expanded.



80
81
82
# File 'lib/stripe/resources/entitlements/feature.rb', line 80

def expand
  @expand
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



82
83
84
# File 'lib/stripe/resources/entitlements/feature.rb', line 82

def 
  @metadata
end

#nameObject

The feature’s name, for your own purpose, not meant to be displayable to the customer.



84
85
86
# File 'lib/stripe/resources/entitlements/feature.rb', line 84

def name
  @name
end