Class: Stripe::Entitlements::FeatureService::RetrieveParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Entitlements::FeatureService::RetrieveParams
- Defined in:
- lib/stripe/services/entitlements/feature_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ RetrieveParams
constructor
A new instance of RetrieveParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ RetrieveParams
Returns a new instance of RetrieveParams.
68 69 70 |
# File 'lib/stripe/services/entitlements/feature_service.rb', line 68 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
66 67 68 |
# File 'lib/stripe/services/entitlements/feature_service.rb', line 66 def @expand end |