Class: Stripe::EphemeralKey::DeleteParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::EphemeralKey::DeleteParams
- Defined in:
- lib/stripe/resources/ephemeral_key.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ DeleteParams
constructor
A new instance of DeleteParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ DeleteParams
Returns a new instance of DeleteParams.
18 19 20 |
# File 'lib/stripe/resources/ephemeral_key.rb', line 18 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
16 17 18 |
# File 'lib/stripe/resources/ephemeral_key.rb', line 16 def @expand end |