Class: Stripe::EphemeralKeyService::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/ephemeral_key_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(customer: nil, expand: nil, issuing_card: nil, nonce: nil, verification_session: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



27
28
29
30
31
32
33
34
35
36
37
38
39
# File 'lib/stripe/services/ephemeral_key_service.rb', line 27

def initialize(
  customer: nil,
  expand: nil,
  issuing_card: nil,
  nonce: nil,
  verification_session: nil
)
  @customer = customer
  @expand = expand
  @issuing_card = issuing_card
  @nonce = nonce
  @verification_session = verification_session
end

Instance Attribute Details

#customerObject

The ID of the Customer you’d like to modify using the resulting ephemeral key.



17
18
19
# File 'lib/stripe/services/ephemeral_key_service.rb', line 17

def customer
  @customer
end

#expandObject

Specifies which fields in the response should be expanded.



19
20
21
# File 'lib/stripe/services/ephemeral_key_service.rb', line 19

def expand
  @expand
end

#issuing_cardObject

The ID of the Issuing Card you’d like to access using the resulting ephemeral key.



21
22
23
# File 'lib/stripe/services/ephemeral_key_service.rb', line 21

def issuing_card
  @issuing_card
end

#nonceObject

A single-use token, created by Stripe.js, used for creating ephemeral keys for Issuing Cards without exchanging sensitive information.



23
24
25
# File 'lib/stripe/services/ephemeral_key_service.rb', line 23

def nonce
  @nonce
end

#verification_sessionObject

The ID of the Identity VerificationSession you’d like to access using the resulting ephemeral key



25
26
27
# File 'lib/stripe/services/ephemeral_key_service.rb', line 25

def verification_session
  @verification_session
end