Class: Stripe::Event::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/event.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(created: nil, delivery_success: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, type: nil, types: nil) ⇒ ListParams

Returns a new instance of ListParams.



157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/stripe/resources/event.rb', line 157

def initialize(
  created: nil,
  delivery_success: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  starting_after: nil,
  type: nil,
  types: nil
)
  @created = created
  @delivery_success = delivery_success
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
  @type = type
  @types = types
end

Instance Attribute Details

#createdObject

Only return events that were created during the given date interval.



141
142
143
# File 'lib/stripe/resources/event.rb', line 141

def created
  @created
end

#delivery_successObject

Filter events by whether all webhooks were successfully delivered. If false, events which are still pending or have failed all delivery attempts to a webhook endpoint will be returned.



143
144
145
# File 'lib/stripe/resources/event.rb', line 143

def delivery_success
  @delivery_success
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



145
146
147
# File 'lib/stripe/resources/event.rb', line 145

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



147
148
149
# File 'lib/stripe/resources/event.rb', line 147

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



149
150
151
# File 'lib/stripe/resources/event.rb', line 149

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



151
152
153
# File 'lib/stripe/resources/event.rb', line 151

def starting_after
  @starting_after
end

#typeObject

A string containing a specific event name, or group of events using * as a wildcard. The list will be filtered to include only events with a matching event property.



153
154
155
# File 'lib/stripe/resources/event.rb', line 153

def type
  @type
end

#typesObject

An array of up to 20 strings containing specific event names. The list will be filtered to include only events with a matching event property. You may pass either ‘type` or `types`, but not both.



155
156
157
# File 'lib/stripe/resources/event.rb', line 155

def types
  @types
end