Class: Stripe::Event::Reason::AutomationAction
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Event::Reason::AutomationAction
- Defined in:
- lib/stripe/resources/event.rb
Defined Under Namespace
Classes: StripeSendWebhookCustomEvent
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#stripe_send_webhook_custom_event ⇒ Object
readonly
Attribute for field stripe_send_webhook_custom_event.
-
#trigger ⇒ Object
readonly
The trigger name of the automation that triggered this action.
-
#type ⇒ Object
readonly
The type of the ‘automation_action`.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#stripe_send_webhook_custom_event ⇒ Object (readonly)
Attribute for field stripe_send_webhook_custom_event
61 62 63 |
# File 'lib/stripe/resources/event.rb', line 61 def stripe_send_webhook_custom_event @stripe_send_webhook_custom_event end |
#trigger ⇒ Object (readonly)
The trigger name of the automation that triggered this action.
Please visit [Revenue and retention automations](https://docs.stripe.com/billing/automations#choose-a-trigger) for all possible trigger names.
64 65 66 |
# File 'lib/stripe/resources/event.rb', line 64 def trigger @trigger end |
#type ⇒ Object (readonly)
The type of the ‘automation_action`.
66 67 68 |
# File 'lib/stripe/resources/event.rb', line 66 def type @type end |
Class Method Details
.field_remappings ⇒ Object
72 73 74 |
# File 'lib/stripe/resources/event.rb', line 72 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
68 69 70 |
# File 'lib/stripe/resources/event.rb', line 68 def self.inner_class_types @inner_class_types = { stripe_send_webhook_custom_event: StripeSendWebhookCustomEvent } end |