Class: Stripe::Event::Reason::AutomationAction::StripeSendWebhookCustomEvent
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Event::Reason::AutomationAction::StripeSendWebhookCustomEvent
- Defined in:
- lib/stripe/resources/event.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#custom_data ⇒ Object
readonly
Set of key-value pairs attached to the action when creating an Automation.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#custom_data ⇒ Object (readonly)
Set of key-value pairs attached to the action when creating an Automation.
54 55 56 |
# File 'lib/stripe/resources/event.rb', line 54 def custom_data @custom_data end |