Class: Stripe::Event::Request

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/event.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#idObject (readonly)

ID of the API request that caused the event. If null, the event was automatic (e.g., Stripe's automatic subscription handling). Request logs are available in the dashboard, but currently not in the API.



109
110
111
# File 'lib/stripe/resources/event.rb', line 109

def id
  @id
end

#idempotency_keyObject (readonly)

The idempotency key transmitted during the request, if any. Note: This property is populated only for events on or after May 23, 2017.



111
112
113
# File 'lib/stripe/resources/event.rb', line 111

def idempotency_key
  @idempotency_key
end

Class Method Details

.field_remappingsObject



117
118
119
# File 'lib/stripe/resources/event.rb', line 117

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



113
114
115
# File 'lib/stripe/resources/event.rb', line 113

def self.inner_class_types
  @inner_class_types = {}
end