Module: Stripe::EventTypes

Defined in:
lib/stripe/event_types.rb

Class Method Summary collapse

Class Method Details

.event_notification_types_to_classesObject



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/stripe/event_types.rb', line 51

def self.event_notification_types_to_classes
  {
    # event notification types: The beginning of the section generated from our OpenAPI spec
    Events::V1BillingMeterErrorReportTriggeredEventNotification.lookup_type =>
    Events::V1BillingMeterErrorReportTriggeredEventNotification,
    Events::V1BillingMeterNoMeterFoundEventNotification.lookup_type =>
    Events::V1BillingMeterNoMeterFoundEventNotification,
    Events::V2CommerceProductCatalogImportsFailedEventNotification.lookup_type =>
    Events::V2CommerceProductCatalogImportsFailedEventNotification,
    Events::V2CommerceProductCatalogImportsProcessingEventNotification.lookup_type =>
    Events::V2CommerceProductCatalogImportsProcessingEventNotification,
    Events::V2CommerceProductCatalogImportsSucceededEventNotification.lookup_type =>
    Events::V2CommerceProductCatalogImportsSucceededEventNotification,
    Events::V2CommerceProductCatalogImportsSucceededWithErrorsEventNotification.lookup_type =>
    Events::V2CommerceProductCatalogImportsSucceededWithErrorsEventNotification,
    Events::V2CoreAccountClosedEventNotification.lookup_type =>
    Events::V2CoreAccountClosedEventNotification,
    Events::V2CoreAccountCreatedEventNotification.lookup_type =>
    Events::V2CoreAccountCreatedEventNotification,
    Events::V2CoreAccountIncludingConfigurationCustomerCapabilityStatusUpdatedEventNotification.lookup_type =>
    Events::V2CoreAccountIncludingConfigurationCustomerCapabilityStatusUpdatedEventNotification,
    Events::V2CoreAccountIncludingConfigurationCustomerUpdatedEventNotification.lookup_type =>
    Events::V2CoreAccountIncludingConfigurationCustomerUpdatedEventNotification,
    Events::V2CoreAccountIncludingConfigurationMerchantCapabilityStatusUpdatedEventNotification.lookup_type =>
    Events::V2CoreAccountIncludingConfigurationMerchantCapabilityStatusUpdatedEventNotification,
    Events::V2CoreAccountIncludingConfigurationMerchantUpdatedEventNotification.lookup_type =>
    Events::V2CoreAccountIncludingConfigurationMerchantUpdatedEventNotification,
    Events::V2CoreAccountIncludingConfigurationRecipientCapabilityStatusUpdatedEventNotification.lookup_type =>
    Events::V2CoreAccountIncludingConfigurationRecipientCapabilityStatusUpdatedEventNotification,
    Events::V2CoreAccountIncludingConfigurationRecipientUpdatedEventNotification.lookup_type =>
    Events::V2CoreAccountIncludingConfigurationRecipientUpdatedEventNotification,
    Events::V2CoreAccountIncludingDefaultsUpdatedEventNotification.lookup_type =>
    Events::V2CoreAccountIncludingDefaultsUpdatedEventNotification,
    Events::V2CoreAccountIncludingFutureRequirementsUpdatedEventNotification.lookup_type =>
    Events::V2CoreAccountIncludingFutureRequirementsUpdatedEventNotification,
    Events::V2CoreAccountIncludingIdentityUpdatedEventNotification.lookup_type =>
    Events::V2CoreAccountIncludingIdentityUpdatedEventNotification,
    Events::V2CoreAccountIncludingRequirementsUpdatedEventNotification.lookup_type =>
    Events::V2CoreAccountIncludingRequirementsUpdatedEventNotification,
    Events::V2CoreAccountLinkReturnedEventNotification.lookup_type =>
    Events::V2CoreAccountLinkReturnedEventNotification,
    Events::V2CoreAccountPersonCreatedEventNotification.lookup_type =>
    Events::V2CoreAccountPersonCreatedEventNotification,
    Events::V2CoreAccountPersonDeletedEventNotification.lookup_type =>
    Events::V2CoreAccountPersonDeletedEventNotification,
    Events::V2CoreAccountPersonUpdatedEventNotification.lookup_type =>
    Events::V2CoreAccountPersonUpdatedEventNotification,
    Events::V2CoreAccountUpdatedEventNotification.lookup_type =>
    Events::V2CoreAccountUpdatedEventNotification,
    Events::V2CoreEventDestinationPingEventNotification.lookup_type =>
    Events::V2CoreEventDestinationPingEventNotification,
    # event notification types: The end of the section generated from our OpenAPI spec
  }
end

.v2_event_types_to_classesObject



5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
# File 'lib/stripe/event_types.rb', line 5

def self.v2_event_types_to_classes
  {
    # v2 event types: The beginning of the section generated from our OpenAPI spec
    Events::V1BillingMeterErrorReportTriggeredEvent.lookup_type =>
    Events::V1BillingMeterErrorReportTriggeredEvent,
    Events::V1BillingMeterNoMeterFoundEvent.lookup_type => Events::V1BillingMeterNoMeterFoundEvent,
    Events::V2CommerceProductCatalogImportsFailedEvent.lookup_type =>
    Events::V2CommerceProductCatalogImportsFailedEvent,
    Events::V2CommerceProductCatalogImportsProcessingEvent.lookup_type =>
    Events::V2CommerceProductCatalogImportsProcessingEvent,
    Events::V2CommerceProductCatalogImportsSucceededEvent.lookup_type =>
    Events::V2CommerceProductCatalogImportsSucceededEvent,
    Events::V2CommerceProductCatalogImportsSucceededWithErrorsEvent.lookup_type =>
    Events::V2CommerceProductCatalogImportsSucceededWithErrorsEvent,
    Events::V2CoreAccountClosedEvent.lookup_type => Events::V2CoreAccountClosedEvent,
    Events::V2CoreAccountCreatedEvent.lookup_type => Events::V2CoreAccountCreatedEvent,
    Events::V2CoreAccountIncludingConfigurationCustomerCapabilityStatusUpdatedEvent.lookup_type =>
    Events::V2CoreAccountIncludingConfigurationCustomerCapabilityStatusUpdatedEvent,
    Events::V2CoreAccountIncludingConfigurationCustomerUpdatedEvent.lookup_type =>
    Events::V2CoreAccountIncludingConfigurationCustomerUpdatedEvent,
    Events::V2CoreAccountIncludingConfigurationMerchantCapabilityStatusUpdatedEvent.lookup_type =>
    Events::V2CoreAccountIncludingConfigurationMerchantCapabilityStatusUpdatedEvent,
    Events::V2CoreAccountIncludingConfigurationMerchantUpdatedEvent.lookup_type =>
    Events::V2CoreAccountIncludingConfigurationMerchantUpdatedEvent,
    Events::V2CoreAccountIncludingConfigurationRecipientCapabilityStatusUpdatedEvent.lookup_type =>
    Events::V2CoreAccountIncludingConfigurationRecipientCapabilityStatusUpdatedEvent,
    Events::V2CoreAccountIncludingConfigurationRecipientUpdatedEvent.lookup_type =>
    Events::V2CoreAccountIncludingConfigurationRecipientUpdatedEvent,
    Events::V2CoreAccountIncludingDefaultsUpdatedEvent.lookup_type =>
    Events::V2CoreAccountIncludingDefaultsUpdatedEvent,
    Events::V2CoreAccountIncludingFutureRequirementsUpdatedEvent.lookup_type =>
    Events::V2CoreAccountIncludingFutureRequirementsUpdatedEvent,
    Events::V2CoreAccountIncludingIdentityUpdatedEvent.lookup_type =>
    Events::V2CoreAccountIncludingIdentityUpdatedEvent,
    Events::V2CoreAccountIncludingRequirementsUpdatedEvent.lookup_type =>
    Events::V2CoreAccountIncludingRequirementsUpdatedEvent,
    Events::V2CoreAccountLinkReturnedEvent.lookup_type => Events::V2CoreAccountLinkReturnedEvent,
    Events::V2CoreAccountPersonCreatedEvent.lookup_type => Events::V2CoreAccountPersonCreatedEvent,
    Events::V2CoreAccountPersonDeletedEvent.lookup_type => Events::V2CoreAccountPersonDeletedEvent,
    Events::V2CoreAccountPersonUpdatedEvent.lookup_type => Events::V2CoreAccountPersonUpdatedEvent,
    Events::V2CoreAccountUpdatedEvent.lookup_type => Events::V2CoreAccountUpdatedEvent,
    Events::V2CoreEventDestinationPingEvent.lookup_type => Events::V2CoreEventDestinationPingEvent,
    # v2 event types: The end of the section generated from our OpenAPI spec
  }
end