Class: Stripe::Events::V1CashBalanceFundsAvailableEvent

Inherits:
V2::Core::Event show all
Defined in:
lib/stripe/events/v1_cash_balance_funds_available_event.rb

Overview

Occurs whenever there is a positive remaining cash balance after Stripe automatically reconciles new funds into the cash balance. If you enabled manual reconciliation, this webhook will fire whenever there are new funds into the cash balance.

Constant Summary

Constants inherited from V2::Core::Event

V2::Core::Event::OBJECT_NAME

Constants inherited from APIResource

APIResource::OBJECT_NAME

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from V2::Core::Event

#changes, #context, #created, #id, #livemode, #object, #reason, #snapshot_event, #type

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from V2::Core::Event

field_remappings, inner_class_types, object_name

Methods inherited from APIResource

class_name, custom_method, object_name, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, field_remappings, #hash, #initialize, inner_class_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

Returns the value of attribute related_object.



21
22
23
# File 'lib/stripe/events/v1_cash_balance_funds_available_event.rb', line 21

def related_object
  @related_object
end

Class Method Details

.lookup_typeObject



8
9
10
# File 'lib/stripe/events/v1_cash_balance_funds_available_event.rb', line 8

def self.lookup_type
  "v1.cash_balance.funds_available"
end

Instance Method Details

Retrieves the related object from the API. Makes an API request on every call.



13
14
15
16
17
18
19
20
# File 'lib/stripe/events/v1_cash_balance_funds_available_event.rb', line 13

def fetch_related_object
  _request(
    method: :get,
    path: related_object.url,
    base_address: :api,
    opts: { stripe_context: context, "Stripe-Request-Trigger": "event=#{id}" }
  )
end