Class: Stripe::Events::V1CashBalanceFundsAvailableEventNotification
- Inherits:
-
V2::Core::EventNotification
- Object
- V2::Core::EventNotification
- Stripe::Events::V1CashBalanceFundsAvailableEventNotification
- Defined in:
- lib/stripe/events/v1_cash_balance_funds_available_event.rb
Overview
Occurs whenever there is a positive remaining cash balance after Stripe automatically reconciles new funds into the cash balance. If you enabled manual reconciliation, this webhook will fire whenever there are new funds into the cash balance.
Instance Attribute Summary collapse
-
#related_object ⇒ Object
readonly
Returns the value of attribute related_object.
Attributes inherited from V2::Core::EventNotification
#context, #created, #id, #livemode, #reason, #type
Class Method Summary collapse
Instance Method Summary collapse
-
#fetch_related_object ⇒ Object
Retrieves the CashBalance related to this EventNotification from the Stripe API.
Methods inherited from V2::Core::EventNotification
Constructor Details
This class inherits a constructor from Stripe::V2::Core::EventNotification
Instance Attribute Details
#related_object ⇒ Object (readonly)
Returns the value of attribute related_object.
30 31 32 |
# File 'lib/stripe/events/v1_cash_balance_funds_available_event.rb', line 30 def @related_object end |
Class Method Details
.lookup_type ⇒ Object
26 27 28 |
# File 'lib/stripe/events/v1_cash_balance_funds_available_event.rb', line 26 def self.lookup_type "v1.cash_balance.funds_available" end |
Instance Method Details
#fetch_related_object ⇒ Object
Retrieves the CashBalance related to this EventNotification from the Stripe API. Makes an API request on every call.
33 34 35 36 37 38 39 40 41 |
# File 'lib/stripe/events/v1_cash_balance_funds_available_event.rb', line 33 def resp = @client.raw_request( :get, .url, opts: { stripe_context: context, "Stripe-Request-Trigger": "event=#{id}" }, usage: ["fetch_related_object"] ) @client.deserialize(resp.http_body, api_mode: Util.get_api_mode(.url)) end |