Class: Stripe::Events::V2BillingRateCardCustomPricingUnitOverageRateCreatedEvent::V2BillingRateCardCustomPricingUnitOverageRateCreatedEventData

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/events/v2_billing_rate_card_custom_pricing_unit_overage_rate_created_event.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#createdObject (readonly)

Timestamp of when the object was created.



14
15
16
# File 'lib/stripe/events/v2_billing_rate_card_custom_pricing_unit_overage_rate_created_event.rb', line 14

def created
  @created
end

#custom_pricing_unitObject (readonly)

The ID of the custom pricing unit this overage rate applies to.



16
17
18
# File 'lib/stripe/events/v2_billing_rate_card_custom_pricing_unit_overage_rate_created_event.rb', line 16

def custom_pricing_unit
  @custom_pricing_unit
end

#rate_cardObject (readonly)

The ID of the RateCard which this custom pricing unit overage rate belongs to.



18
19
20
# File 'lib/stripe/events/v2_billing_rate_card_custom_pricing_unit_overage_rate_created_event.rb', line 18

def rate_card
  @rate_card
end

#rate_card_versionObject (readonly)

The ID of the RateCard Version when the custom pricing unit overage rate was created.



20
21
22
# File 'lib/stripe/events/v2_billing_rate_card_custom_pricing_unit_overage_rate_created_event.rb', line 20

def rate_card_version
  @rate_card_version
end

Class Method Details

.field_remappingsObject



26
27
28
# File 'lib/stripe/events/v2_billing_rate_card_custom_pricing_unit_overage_rate_created_event.rb', line 26

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



22
23
24
# File 'lib/stripe/events/v2_billing_rate_card_custom_pricing_unit_overage_rate_created_event.rb', line 22

def self.inner_class_types
  @inner_class_types = {}
end