Class: Stripe::Events::V2CoreAccountSignalsFraudulentWebsiteReadyEvent::V2CoreAccountSignalsFraudulentWebsiteReadyEventData

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/events/v2_core_account_signals_fraudulent_website_ready_event.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#accountObject (readonly)

The account for which the signals belong to. Empty if this was an entityless request.



14
15
16
# File 'lib/stripe/events/v2_core_account_signals_fraudulent_website_ready_event.rb', line 14

def 
  @account
end

#detailsObject (readonly)

Human readable description of concerns found in the website, produced by LLM. If risk_level is unknown, this explains why evaluation could not run.



16
17
18
# File 'lib/stripe/events/v2_core_account_signals_fraudulent_website_ready_event.rb', line 16

def details
  @details
end

#evaluated_atObject (readonly)

Time at which the signal was evaluated.



18
19
20
# File 'lib/stripe/events/v2_core_account_signals_fraudulent_website_ready_event.rb', line 18

def evaluated_at
  @evaluated_at
end

#evaluation_idObject (readonly)

Unique identifier for the fraudulent website evaluation request.



20
21
22
# File 'lib/stripe/events/v2_core_account_signals_fraudulent_website_ready_event.rb', line 20

def evaluation_id
  @evaluation_id
end

#risk_levelObject (readonly)

Risk level for the fraudulent website signal. If evaluation could not run (like invalid website), we return unknown.



22
23
24
# File 'lib/stripe/events/v2_core_account_signals_fraudulent_website_ready_event.rb', line 22

def risk_level
  @risk_level
end

#signal_idObject (readonly)

Unique identifier for the fraudulent website signal.



24
25
26
# File 'lib/stripe/events/v2_core_account_signals_fraudulent_website_ready_event.rb', line 24

def signal_id
  @signal_id
end

Class Method Details

.field_remappingsObject



30
31
32
# File 'lib/stripe/events/v2_core_account_signals_fraudulent_website_ready_event.rb', line 30

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



26
27
28
# File 'lib/stripe/events/v2_core_account_signals_fraudulent_website_ready_event.rb', line 26

def self.inner_class_types
  @inner_class_types = {}
end