Class: Stripe::Events::V2CoreClaimableSandboxSandboxDetailsOwnerAccountUpdatedEventNotification

Inherits:
V2::Core::EventNotification show all
Defined in:
lib/stripe/events/v2_core_claimable_sandbox_sandbox_details_owner_account_updated_event.rb

Overview

Occurs when a claimable sandbox is activated by the user with the intention to go live and your Stripe app is installed on the live account.

Instance Attribute Summary collapse

Attributes inherited from V2::Core::EventNotification

#context, #created, #id, #livemode, #reason, #type

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from V2::Core::EventNotification

#fetch_event, #initialize

Constructor Details

This class inherits a constructor from Stripe::V2::Core::EventNotification

Instance Attribute Details

Returns the value of attribute related_object.



30
31
32
# File 'lib/stripe/events/v2_core_claimable_sandbox_sandbox_details_owner_account_updated_event.rb', line 30

def related_object
  @related_object
end

Class Method Details

.lookup_typeObject



26
27
28
# File 'lib/stripe/events/v2_core_claimable_sandbox_sandbox_details_owner_account_updated_event.rb', line 26

def self.lookup_type
  "v2.core.claimable_sandbox.sandbox_details_owner_account_updated"
end

Instance Method Details

Retrieves the ClaimableSandbox related to this EventNotification from the Stripe API. Makes an API request on every call.



33
34
35
36
37
38
39
40
41
# File 'lib/stripe/events/v2_core_claimable_sandbox_sandbox_details_owner_account_updated_event.rb', line 33

def fetch_related_object
  resp = @client.raw_request(
    :get,
    related_object.url,
    opts: { stripe_context: context, "Stripe-Request-Trigger": "event=#{id}" },
    usage: ["fetch_related_object"]
  )
  @client.deserialize(resp.http_body, api_mode: Util.get_api_mode(related_object.url))
end