Class: Stripe::Events::V2CoreHealthApiErrorResolvedEvent::V2CoreHealthApiErrorResolvedEventData

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/events/v2_core_health_api_error_resolved_event.rb

Defined Under Namespace

Classes: Impact

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#alert_idObject (readonly)

The alert ID.



68
69
70
# File 'lib/stripe/events/v2_core_health_api_error_resolved_event.rb', line 68

def alert_id
  @alert_id
end

#grouping_keyObject (readonly)

The grouping key for the alert.



70
71
72
# File 'lib/stripe/events/v2_core_health_api_error_resolved_event.rb', line 70

def grouping_key
  @grouping_key
end

#impactObject (readonly)

The user impact.



72
73
74
# File 'lib/stripe/events/v2_core_health_api_error_resolved_event.rb', line 72

def impact
  @impact
end

#resolved_atObject (readonly)

The time when the user experience has returned to expected levels.



74
75
76
# File 'lib/stripe/events/v2_core_health_api_error_resolved_event.rb', line 74

def resolved_at
  @resolved_at
end

#started_atObject (readonly)

The time when impact on the user experience was first detected.



76
77
78
# File 'lib/stripe/events/v2_core_health_api_error_resolved_event.rb', line 76

def started_at
  @started_at
end

#summaryObject (readonly)

A short description of the alert.



78
79
80
# File 'lib/stripe/events/v2_core_health_api_error_resolved_event.rb', line 78

def summary
  @summary
end

Class Method Details

.field_encodingsObject



88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/stripe/events/v2_core_health_api_error_resolved_event.rb', line 88

def self.field_encodings
  @field_encodings = {
    impact: {
      kind: :object,
      fields: {
        impacted_requests_percentage: :decimal_string,
        top_impacted_accounts: {
          kind: :array,
          element: { kind: :object, fields: { impacted_requests_percentage: :decimal_string } },
        },
      },
    },
  }
end

.field_remappingsObject



84
85
86
# File 'lib/stripe/events/v2_core_health_api_error_resolved_event.rb', line 84

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



80
81
82
# File 'lib/stripe/events/v2_core_health_api_error_resolved_event.rb', line 80

def self.inner_class_types
  @inner_class_types = { impact: Impact }
end