Class: Stripe::Events::V2CoreHealthAuthorizationRateDropFiringEvent::V2CoreHealthAuthorizationRateDropFiringEventData
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Events::V2CoreHealthAuthorizationRateDropFiringEvent::V2CoreHealthAuthorizationRateDropFiringEventData
- Defined in:
- lib/stripe/events/v2_core_health_authorization_rate_drop_firing_event.rb
Defined Under Namespace
Classes: Impact
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#alert_id ⇒ Object
readonly
The alert ID.
-
#grouping_key ⇒ Object
readonly
The grouping key for the alert.
-
#impact ⇒ Object
readonly
The user impact.
-
#started_at ⇒ Object
readonly
The time when impact on the user experience was first detected.
-
#summary ⇒ Object
readonly
A short description of the alert.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#alert_id ⇒ Object (readonly)
The alert ID.
55 56 57 |
# File 'lib/stripe/events/v2_core_health_authorization_rate_drop_firing_event.rb', line 55 def alert_id @alert_id end |
#grouping_key ⇒ Object (readonly)
The grouping key for the alert.
57 58 59 |
# File 'lib/stripe/events/v2_core_health_authorization_rate_drop_firing_event.rb', line 57 def grouping_key @grouping_key end |
#impact ⇒ Object (readonly)
The user impact.
59 60 61 |
# File 'lib/stripe/events/v2_core_health_authorization_rate_drop_firing_event.rb', line 59 def impact @impact end |
#started_at ⇒ Object (readonly)
The time when impact on the user experience was first detected.
61 62 63 |
# File 'lib/stripe/events/v2_core_health_authorization_rate_drop_firing_event.rb', line 61 def started_at @started_at end |
#summary ⇒ Object (readonly)
A short description of the alert.
63 64 65 |
# File 'lib/stripe/events/v2_core_health_authorization_rate_drop_firing_event.rb', line 63 def summary @summary end |
Class Method Details
.field_encodings ⇒ Object
73 74 75 76 77 78 79 80 |
# File 'lib/stripe/events/v2_core_health_authorization_rate_drop_firing_event.rb', line 73 def self.field_encodings @field_encodings = { impact: { kind: :object, fields: { current_percentage: :decimal_string, previous_percentage: :decimal_string }, }, } end |
.field_remappings ⇒ Object
69 70 71 |
# File 'lib/stripe/events/v2_core_health_authorization_rate_drop_firing_event.rb', line 69 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
65 66 67 |
# File 'lib/stripe/events/v2_core_health_authorization_rate_drop_firing_event.rb', line 65 def self.inner_class_types @inner_class_types = { impact: Impact } end |