Class: Stripe::Events::V2CoreHealthAuthorizationRateDropFiringEvent::V2CoreHealthAuthorizationRateDropFiringEventData::Impact
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Events::V2CoreHealthAuthorizationRateDropFiringEvent::V2CoreHealthAuthorizationRateDropFiringEventData::Impact
- Defined in:
- lib/stripe/events/v2_core_health_authorization_rate_drop_firing_event.rb
Defined Under Namespace
Classes: Dimension
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#charge_type ⇒ Object
readonly
The type of the charge.
-
#current_percentage ⇒ Object
readonly
The current authorization rate percentage.
-
#dimensions ⇒ Object
readonly
Dimensions that describe what subset of payments are impacted.
-
#payment_method_type ⇒ Object
readonly
The type of the payment method.
-
#previous_percentage ⇒ Object
readonly
The previous authorization rate percentage.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#charge_type ⇒ Object (readonly)
The type of the charge.
29 30 31 |
# File 'lib/stripe/events/v2_core_health_authorization_rate_drop_firing_event.rb', line 29 def charge_type @charge_type end |
#current_percentage ⇒ Object (readonly)
The current authorization rate percentage.
31 32 33 |
# File 'lib/stripe/events/v2_core_health_authorization_rate_drop_firing_event.rb', line 31 def current_percentage @current_percentage end |
#dimensions ⇒ Object (readonly)
Dimensions that describe what subset of payments are impacted.
33 34 35 |
# File 'lib/stripe/events/v2_core_health_authorization_rate_drop_firing_event.rb', line 33 def dimensions @dimensions end |
#payment_method_type ⇒ Object (readonly)
The type of the payment method.
35 36 37 |
# File 'lib/stripe/events/v2_core_health_authorization_rate_drop_firing_event.rb', line 35 def payment_method_type @payment_method_type end |
#previous_percentage ⇒ Object (readonly)
The previous authorization rate percentage.
37 38 39 |
# File 'lib/stripe/events/v2_core_health_authorization_rate_drop_firing_event.rb', line 37 def previous_percentage @previous_percentage end |
Class Method Details
.field_encodings ⇒ Object
47 48 49 50 51 52 |
# File 'lib/stripe/events/v2_core_health_authorization_rate_drop_firing_event.rb', line 47 def self.field_encodings @field_encodings = { current_percentage: :decimal_string, previous_percentage: :decimal_string, } end |
.field_remappings ⇒ Object
43 44 45 |
# File 'lib/stripe/events/v2_core_health_authorization_rate_drop_firing_event.rb', line 43 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
39 40 41 |
# File 'lib/stripe/events/v2_core_health_authorization_rate_drop_firing_event.rb', line 39 def self.inner_class_types @inner_class_types = { dimensions: Dimension } end |