Class: Stripe::Events::V2CoreHealthAuthorizationRateDropResolvedEvent::V2CoreHealthAuthorizationRateDropResolvedEventData

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/events/v2_core_health_authorization_rate_drop_resolved_event.rb

Defined Under Namespace

Classes: Impact

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#alert_idObject (readonly)

The alert ID.



55
56
57
# File 'lib/stripe/events/v2_core_health_authorization_rate_drop_resolved_event.rb', line 55

def alert_id
  @alert_id
end

#grouping_keyObject (readonly)

The grouping key for the alert.



57
58
59
# File 'lib/stripe/events/v2_core_health_authorization_rate_drop_resolved_event.rb', line 57

def grouping_key
  @grouping_key
end

#impactObject (readonly)

The user impact.



59
60
61
# File 'lib/stripe/events/v2_core_health_authorization_rate_drop_resolved_event.rb', line 59

def impact
  @impact
end

#resolved_atObject (readonly)

The time when the user experience has returned to expected levels.



61
62
63
# File 'lib/stripe/events/v2_core_health_authorization_rate_drop_resolved_event.rb', line 61

def resolved_at
  @resolved_at
end

#started_atObject (readonly)

The time when impact on the user experience was first detected.



63
64
65
# File 'lib/stripe/events/v2_core_health_authorization_rate_drop_resolved_event.rb', line 63

def started_at
  @started_at
end

#summaryObject (readonly)

A short description of the alert.



65
66
67
# File 'lib/stripe/events/v2_core_health_authorization_rate_drop_resolved_event.rb', line 65

def summary
  @summary
end

Class Method Details

.field_encodingsObject



75
76
77
78
79
80
81
82
# File 'lib/stripe/events/v2_core_health_authorization_rate_drop_resolved_event.rb', line 75

def self.field_encodings
  @field_encodings = {
    impact: {
      kind: :object,
      fields: { current_percentage: :decimal_string, previous_percentage: :decimal_string },
    },
  }
end

.field_remappingsObject



71
72
73
# File 'lib/stripe/events/v2_core_health_authorization_rate_drop_resolved_event.rb', line 71

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



67
68
69
# File 'lib/stripe/events/v2_core_health_authorization_rate_drop_resolved_event.rb', line 67

def self.inner_class_types
  @inner_class_types = { impact: Impact }
end