Class: Stripe::Events::V2CoreHealthEventGenerationFailureResolvedEvent::V2CoreHealthEventGenerationFailureResolvedEventData
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Events::V2CoreHealthEventGenerationFailureResolvedEvent::V2CoreHealthEventGenerationFailureResolvedEventData
- Defined in:
- lib/stripe/events/v2_core_health_event_generation_failure_resolved_event.rb
Defined Under Namespace
Classes: Impact
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#alert_id ⇒ Object
readonly
The alert ID.
-
#grouping_key ⇒ Object
readonly
The grouping key for the alert.
-
#impact ⇒ Object
readonly
The user impact.
-
#resolved_at ⇒ Object
readonly
The time when the user experience has returned to expected levels.
-
#summary ⇒ Object
readonly
A short description of the alert.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#alert_id ⇒ Object (readonly)
The alert ID.
46 47 48 |
# File 'lib/stripe/events/v2_core_health_event_generation_failure_resolved_event.rb', line 46 def alert_id @alert_id end |
#grouping_key ⇒ Object (readonly)
The grouping key for the alert.
48 49 50 |
# File 'lib/stripe/events/v2_core_health_event_generation_failure_resolved_event.rb', line 48 def grouping_key @grouping_key end |
#impact ⇒ Object (readonly)
The user impact.
50 51 52 |
# File 'lib/stripe/events/v2_core_health_event_generation_failure_resolved_event.rb', line 50 def impact @impact end |
#resolved_at ⇒ Object (readonly)
The time when the user experience has returned to expected levels.
52 53 54 |
# File 'lib/stripe/events/v2_core_health_event_generation_failure_resolved_event.rb', line 52 def resolved_at @resolved_at end |
#summary ⇒ Object (readonly)
A short description of the alert.
54 55 56 |
# File 'lib/stripe/events/v2_core_health_event_generation_failure_resolved_event.rb', line 54 def summary @summary end |
Class Method Details
.field_remappings ⇒ Object
60 61 62 |
# File 'lib/stripe/events/v2_core_health_event_generation_failure_resolved_event.rb', line 60 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
56 57 58 |
# File 'lib/stripe/events/v2_core_health_event_generation_failure_resolved_event.rb', line 56 def self.inner_class_types @inner_class_types = { impact: Impact } end |