Class: Stripe::Events::V2CoreHealthEventGenerationFailureResolvedEvent::V2CoreHealthEventGenerationFailureResolvedEventData::Impact
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Events::V2CoreHealthEventGenerationFailureResolvedEvent::V2CoreHealthEventGenerationFailureResolvedEventData::Impact
- Defined in:
- lib/stripe/events/v2_core_health_event_generation_failure_resolved_event.rb
Defined Under Namespace
Classes: RelatedObject
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#context ⇒ Object
readonly
The context the event should have been generated for.
-
#event_type ⇒ Object
readonly
The type of event that Stripe failed to generate.
-
#related_object ⇒ Object
readonly
The related object details.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#context ⇒ Object (readonly)
The context the event should have been generated for. Only present when the account is a connected account.
31 32 33 |
# File 'lib/stripe/events/v2_core_health_event_generation_failure_resolved_event.rb', line 31 def context @context end |
#event_type ⇒ Object (readonly)
The type of event that Stripe failed to generate.
33 34 35 |
# File 'lib/stripe/events/v2_core_health_event_generation_failure_resolved_event.rb', line 33 def event_type @event_type end |
#related_object ⇒ Object (readonly)
The related object details.
35 36 37 |
# File 'lib/stripe/events/v2_core_health_event_generation_failure_resolved_event.rb', line 35 def @related_object end |
Class Method Details
.field_remappings ⇒ Object
41 42 43 |
# File 'lib/stripe/events/v2_core_health_event_generation_failure_resolved_event.rb', line 41 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
37 38 39 |
# File 'lib/stripe/events/v2_core_health_event_generation_failure_resolved_event.rb', line 37 def self.inner_class_types @inner_class_types = { related_object: RelatedObject } end |