Class: Stripe::Events::V2CoreHealthInvoiceCountDroppedResolvedEvent::V2CoreHealthInvoiceCountDroppedResolvedEventData::Impact
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Events::V2CoreHealthInvoiceCountDroppedResolvedEvent::V2CoreHealthInvoiceCountDroppedResolvedEventData::Impact
- Defined in:
- lib/stripe/events/v2_core_health_invoice_count_dropped_resolved_event.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#observed_count ⇒ Object
readonly
The observed number of invoices within the time window.
-
#threshold_count ⇒ Object
readonly
The expected threshold number of invoices within the time window.
-
#time_window ⇒ Object
readonly
The size of the observation time window.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#observed_count ⇒ Object (readonly)
The observed number of invoices within the time window.
15 16 17 |
# File 'lib/stripe/events/v2_core_health_invoice_count_dropped_resolved_event.rb', line 15 def observed_count @observed_count end |
#threshold_count ⇒ Object (readonly)
The expected threshold number of invoices within the time window.
17 18 19 |
# File 'lib/stripe/events/v2_core_health_invoice_count_dropped_resolved_event.rb', line 17 def threshold_count @threshold_count end |
#time_window ⇒ Object (readonly)
The size of the observation time window.
19 20 21 |
# File 'lib/stripe/events/v2_core_health_invoice_count_dropped_resolved_event.rb', line 19 def time_window @time_window end |
Class Method Details
.field_encodings ⇒ Object
29 30 31 |
# File 'lib/stripe/events/v2_core_health_invoice_count_dropped_resolved_event.rb', line 29 def self.field_encodings @field_encodings = { observed_count: :decimal_string, threshold_count: :decimal_string } end |
.field_remappings ⇒ Object
25 26 27 |
# File 'lib/stripe/events/v2_core_health_invoice_count_dropped_resolved_event.rb', line 25 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
21 22 23 |
# File 'lib/stripe/events/v2_core_health_invoice_count_dropped_resolved_event.rb', line 21 def self.inner_class_types @inner_class_types = {} end |