Class: Stripe::Events::V2CoreHealthWebhookLatencyFiringEvent::V2CoreHealthWebhookLatencyFiringEventData
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Events::V2CoreHealthWebhookLatencyFiringEvent::V2CoreHealthWebhookLatencyFiringEventData
- Defined in:
- lib/stripe/events/v2_core_health_webhook_latency_firing_event.rb
Defined Under Namespace
Classes: Impact
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#alert_id ⇒ Object
readonly
The alert ID.
-
#grouping_key ⇒ Object
readonly
The grouping key for the alert.
-
#impact ⇒ Object
readonly
The user impact.
-
#started_at ⇒ Object
readonly
The time when impact on the user experience was first detected.
-
#summary ⇒ Object
readonly
A short description of the alert.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#alert_id ⇒ Object (readonly)
The alert ID.
26 27 28 |
# File 'lib/stripe/events/v2_core_health_webhook_latency_firing_event.rb', line 26 def alert_id @alert_id end |
#grouping_key ⇒ Object (readonly)
The grouping key for the alert.
28 29 30 |
# File 'lib/stripe/events/v2_core_health_webhook_latency_firing_event.rb', line 28 def grouping_key @grouping_key end |
#impact ⇒ Object (readonly)
The user impact.
30 31 32 |
# File 'lib/stripe/events/v2_core_health_webhook_latency_firing_event.rb', line 30 def impact @impact end |
#started_at ⇒ Object (readonly)
The time when impact on the user experience was first detected.
32 33 34 |
# File 'lib/stripe/events/v2_core_health_webhook_latency_firing_event.rb', line 32 def started_at @started_at end |
#summary ⇒ Object (readonly)
A short description of the alert.
34 35 36 |
# File 'lib/stripe/events/v2_core_health_webhook_latency_firing_event.rb', line 34 def summary @summary end |
Class Method Details
.field_remappings ⇒ Object
40 41 42 |
# File 'lib/stripe/events/v2_core_health_webhook_latency_firing_event.rb', line 40 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
36 37 38 |
# File 'lib/stripe/events/v2_core_health_webhook_latency_firing_event.rb', line 36 def self.inner_class_types @inner_class_types = { impact: Impact } end |