Class: Stripe::Events::V2ExtendWorkflowRunFailedEvent::V2ExtendWorkflowRunFailedEventData
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Events::V2ExtendWorkflowRunFailedEvent::V2ExtendWorkflowRunFailedEventData
- Defined in:
- lib/stripe/events/v2_extend_workflow_run_failed_event.rb
Defined Under Namespace
Classes: FailureDetails
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#dashboard_url ⇒ Object
readonly
A Stripe dashboard URL with more information about the Workflow Run failure.
-
#failure_details ⇒ Object
readonly
Details about the Workflow Run’s transition into the FAILED state.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#dashboard_url ⇒ Object (readonly)
A Stripe dashboard URL with more information about the Workflow Run failure.
26 27 28 |
# File 'lib/stripe/events/v2_extend_workflow_run_failed_event.rb', line 26 def dashboard_url @dashboard_url end |
#failure_details ⇒ Object (readonly)
Details about the Workflow Run’s transition into the FAILED state.
28 29 30 |
# File 'lib/stripe/events/v2_extend_workflow_run_failed_event.rb', line 28 def failure_details @failure_details end |
Class Method Details
.field_remappings ⇒ Object
34 35 36 |
# File 'lib/stripe/events/v2_extend_workflow_run_failed_event.rb', line 34 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
30 31 32 |
# File 'lib/stripe/events/v2_extend_workflow_run_failed_event.rb', line 30 def self.inner_class_types @inner_class_types = { failure_details: FailureDetails } end |