Class: Stripe::Events::V2OrchestratedCommerceAgreementConfirmedEvent::V2OrchestratedCommerceAgreementConfirmedEventData
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Events::V2OrchestratedCommerceAgreementConfirmedEvent::V2OrchestratedCommerceAgreementConfirmedEventData
- Defined in:
- lib/stripe/events/v2_orchestrated_commerce_agreement_confirmed_event.rb
Defined Under Namespace
Classes: OrchestratorDetails, SellerDetails
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#orchestrator_confirmed_at ⇒ Object
readonly
The time at which the orchestrator confirmed the agreement.
-
#orchestrator_details ⇒ Object
readonly
Details about the orchestrator.
-
#seller_confirmed_at ⇒ Object
readonly
The time at which the seller confirmed the agreement.
-
#seller_details ⇒ Object
readonly
Details about the seller.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#orchestrator_confirmed_at ⇒ Object (readonly)
The time at which the orchestrator confirmed the agreement.
41 42 43 |
# File 'lib/stripe/events/v2_orchestrated_commerce_agreement_confirmed_event.rb', line 41 def orchestrator_confirmed_at @orchestrator_confirmed_at end |
#orchestrator_details ⇒ Object (readonly)
Details about the orchestrator.
43 44 45 |
# File 'lib/stripe/events/v2_orchestrated_commerce_agreement_confirmed_event.rb', line 43 def orchestrator_details @orchestrator_details end |
#seller_confirmed_at ⇒ Object (readonly)
The time at which the seller confirmed the agreement.
45 46 47 |
# File 'lib/stripe/events/v2_orchestrated_commerce_agreement_confirmed_event.rb', line 45 def seller_confirmed_at @seller_confirmed_at end |
#seller_details ⇒ Object (readonly)
Details about the seller.
47 48 49 |
# File 'lib/stripe/events/v2_orchestrated_commerce_agreement_confirmed_event.rb', line 47 def seller_details @seller_details end |
Class Method Details
.field_remappings ⇒ Object
56 57 58 |
# File 'lib/stripe/events/v2_orchestrated_commerce_agreement_confirmed_event.rb', line 56 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
49 50 51 52 53 54 |
# File 'lib/stripe/events/v2_orchestrated_commerce_agreement_confirmed_event.rb', line 49 def self.inner_class_types @inner_class_types = { orchestrator_details: OrchestratorDetails, seller_details: SellerDetails, } end |