Class: Stripe::Events::V2PaymentsOffSessionPaymentAuthorizationAttemptFailedEventNotification

Inherits:
V2::Core::EventNotification show all
Defined in:
lib/stripe/events/v2_payments_off_session_payment_authorization_attempt_failed_event.rb

Overview

Sent after a failed authorization if there are still retries available on the OffSessionPayment. This event has been renamed this to attempt_failed, but we are keeping this around for backwards compatibility.

Instance Attribute Summary collapse

Attributes inherited from V2::Core::EventNotification

#context, #created, #id, #livemode, #reason, #type

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from V2::Core::EventNotification

#fetch_event, #initialize

Constructor Details

This class inherits a constructor from Stripe::V2::Core::EventNotification

Instance Attribute Details

Returns the value of attribute related_object.



32
33
34
# File 'lib/stripe/events/v2_payments_off_session_payment_authorization_attempt_failed_event.rb', line 32

def related_object
  @related_object
end

Class Method Details

.lookup_typeObject



28
29
30
# File 'lib/stripe/events/v2_payments_off_session_payment_authorization_attempt_failed_event.rb', line 28

def self.lookup_type
  "v2.payments.off_session_payment.authorization_attempt_failed"
end

Instance Method Details

Retrieves the OffSessionPayment related to this EventNotification from the Stripe API. Makes an API request on every call.



35
36
37
38
39
40
41
42
43
# File 'lib/stripe/events/v2_payments_off_session_payment_authorization_attempt_failed_event.rb', line 35

def fetch_related_object
  resp = @client.raw_request(
    :get,
    related_object.url,
    opts: { stripe_context: context },
    usage: ["fetch_related_object"]
  )
  @client.deserialize(resp.http_body, api_mode: Util.get_api_mode(related_object.url))
end