Class: Stripe::Events::V2PaymentsSettlementAllocationIntentErroredEvent::V2PaymentsSettlementAllocationIntentErroredEventData
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Events::V2PaymentsSettlementAllocationIntentErroredEvent::V2PaymentsSettlementAllocationIntentErroredEventData
- Defined in:
- lib/stripe/events/v2_payments_settlement_allocation_intent_errored_event.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#doc_url ⇒ Object
readonly
Stripe doc link to debug the issue.
-
#message ⇒ Object
readonly
User Message detailing the reason code and possible resolution .
-
#reason_code ⇒ Object
readonly
Open Enum.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#doc_url ⇒ Object (readonly)
Stripe doc link to debug the issue.
14 15 16 |
# File 'lib/stripe/events/v2_payments_settlement_allocation_intent_errored_event.rb', line 14 def doc_url @doc_url end |
#message ⇒ Object (readonly)
User Message detailing the reason code and possible resolution .
16 17 18 |
# File 'lib/stripe/events/v2_payments_settlement_allocation_intent_errored_event.rb', line 16 def @message end |
#reason_code ⇒ Object (readonly)
Open Enum. The ‘errored` status reason.
18 19 20 |
# File 'lib/stripe/events/v2_payments_settlement_allocation_intent_errored_event.rb', line 18 def reason_code @reason_code end |
Class Method Details
.field_remappings ⇒ Object
24 25 26 |
# File 'lib/stripe/events/v2_payments_settlement_allocation_intent_errored_event.rb', line 24 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
20 21 22 |
# File 'lib/stripe/events/v2_payments_settlement_allocation_intent_errored_event.rb', line 20 def self.inner_class_types @inner_class_types = {} end |