Class: Stripe::Events::V2SignalsAccountSignalFraudulentMerchantReadyEvent::V2SignalsAccountSignalFraudulentMerchantReadyEventData::FraudulentMerchant

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/events/v2_signals_account_signal_fraudulent_merchant_ready_event.rb

Defined Under Namespace

Classes: Indicator

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#indicatorsObject (readonly)

Array of objects representing individual factors that contributed to the calculated probability. Maximum of 3.



31
32
33
# File 'lib/stripe/events/v2_signals_account_signal_fraudulent_merchant_ready_event.rb', line 31

def indicators
  @indicators
end

#probabilityObject (readonly)

The probability of the merchant being fraudulent. Can be between 0.00 and 100.00. May be empty if the risk_level is UNKNOWN or NOT_ASSESSED.



33
34
35
# File 'lib/stripe/events/v2_signals_account_signal_fraudulent_merchant_ready_event.rb', line 33

def probability
  @probability
end

#risk_levelObject (readonly)

Categorical assessment of the fraudulent merchant risk based on probability.



35
36
37
# File 'lib/stripe/events/v2_signals_account_signal_fraudulent_merchant_ready_event.rb', line 35

def risk_level
  @risk_level
end

Class Method Details

.field_encodingsObject



45
46
47
# File 'lib/stripe/events/v2_signals_account_signal_fraudulent_merchant_ready_event.rb', line 45

def self.field_encodings
  @field_encodings = { probability: :decimal_string }
end

.field_remappingsObject



41
42
43
# File 'lib/stripe/events/v2_signals_account_signal_fraudulent_merchant_ready_event.rb', line 41

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



37
38
39
# File 'lib/stripe/events/v2_signals_account_signal_fraudulent_merchant_ready_event.rb', line 37

def self.inner_class_types
  @inner_class_types = { indicators: Indicator }
end