Class: Stripe::Events::V2SignalsAccountSignalFraudulentMerchantReadyEvent::V2SignalsAccountSignalFraudulentMerchantReadyEventData::FraudulentMerchant::Indicator
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Events::V2SignalsAccountSignalFraudulentMerchantReadyEvent::V2SignalsAccountSignalFraudulentMerchantReadyEventData::FraudulentMerchant::Indicator
- Defined in:
- lib/stripe/events/v2_signals_account_signal_fraudulent_merchant_ready_event.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#description ⇒ Object
readonly
A brief explanation of how this indicator contributed to the fraudulent merchant probability.
-
#impact ⇒ Object
readonly
The effect this indicator had on the overall risk level.
-
#indicator ⇒ Object
readonly
The name of the specific indicator used in the risk assessment.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#description ⇒ Object (readonly)
A brief explanation of how this indicator contributed to the fraudulent merchant probability.
16 17 18 |
# File 'lib/stripe/events/v2_signals_account_signal_fraudulent_merchant_ready_event.rb', line 16 def description @description end |
#impact ⇒ Object (readonly)
The effect this indicator had on the overall risk level.
18 19 20 |
# File 'lib/stripe/events/v2_signals_account_signal_fraudulent_merchant_ready_event.rb', line 18 def impact @impact end |
#indicator ⇒ Object (readonly)
The name of the specific indicator used in the risk assessment.
20 21 22 |
# File 'lib/stripe/events/v2_signals_account_signal_fraudulent_merchant_ready_event.rb', line 20 def indicator @indicator end |
Class Method Details
.field_remappings ⇒ Object
26 27 28 |
# File 'lib/stripe/events/v2_signals_account_signal_fraudulent_merchant_ready_event.rb', line 26 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
22 23 24 |
# File 'lib/stripe/events/v2_signals_account_signal_fraudulent_merchant_ready_event.rb', line 22 def self.inner_class_types @inner_class_types = {} end |