Class: Stripe::ExternalAccountService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::ExternalAccountService
- Defined in:
- lib/stripe/services/external_account_service.rb
Instance Method Summary collapse
-
#create(params = {}, opts = {}) ⇒ Object
Create an external account for a given connected account.
-
#delete(id, params = {}, opts = {}) ⇒ Object
Delete a specified external account for a given account.
-
#list(params = {}, opts = {}) ⇒ Object
List external accounts for an account.
-
#retrieve(id, params = {}, opts = {}) ⇒ Object
Retrieve a specified external account for a given account.
-
#update(id, params = {}, opts = {}) ⇒ Object
Updates the metadata, account holder name, account holder type of a bank account belonging to a connected account and optionally sets it as the default for its currency.
Methods inherited from StripeService
#initialize, #request, #request_stream
Constructor Details
This class inherits a constructor from Stripe::StripeService
Instance Method Details
#create(params = {}, opts = {}) ⇒ Object
Create an external account for a given connected account.
7 8 9 10 11 12 13 14 15 |
# File 'lib/stripe/services/external_account_service.rb', line 7 def create(params = {}, opts = {}) request( method: :post, path: "/v1/external_accounts", params: params, opts: opts, base_address: :api ) end |
#delete(id, params = {}, opts = {}) ⇒ Object
Delete a specified external account for a given account.
18 19 20 21 22 23 24 25 26 |
# File 'lib/stripe/services/external_account_service.rb', line 18 def delete(id, params = {}, opts = {}) request( method: :delete, path: format("/v1/external_accounts/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |
#list(params = {}, opts = {}) ⇒ Object
List external accounts for an account.
29 30 31 32 33 34 35 36 37 |
# File 'lib/stripe/services/external_account_service.rb', line 29 def list(params = {}, opts = {}) request( method: :get, path: "/v1/external_accounts", params: params, opts: opts, base_address: :api ) end |
#retrieve(id, params = {}, opts = {}) ⇒ Object
Retrieve a specified external account for a given account.
40 41 42 43 44 45 46 47 48 |
# File 'lib/stripe/services/external_account_service.rb', line 40 def retrieve(id, params = {}, opts = {}) request( method: :get, path: format("/v1/external_accounts/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |
#update(id, params = {}, opts = {}) ⇒ Object
Updates the metadata, account holder name, account holder type of a bank account belonging to a connected account and optionally sets it as the default for its currency. Other bank account details are not editable by design.
You can only update bank accounts when [account.controller.requirement_collection is application, which includes <a href=“/connect/custom-accounts”>Custom accounts](docs.stripe.com/api/accounts/object#account_object-controller-requirement_collection).
You can re-enable a disabled bank account by performing an update call without providing any arguments or changes.
58 59 60 61 62 63 64 65 66 |
# File 'lib/stripe/services/external_account_service.rb', line 58 def update(id, params = {}, opts = {}) request( method: :post, path: format("/v1/external_accounts/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |