Class: Stripe::ExternalAccountService::CreateParams::BankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/external_account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(object: nil, account_holder_name: nil, account_holder_type: nil, account_number: nil, country: nil, currency: nil, routing_number: nil) ⇒ BankAccount

Returns a new instance of BankAccount.



142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/stripe/services/external_account_service.rb', line 142

def initialize(
  object: nil,
  account_holder_name: nil,
  account_holder_type: nil,
  account_number: nil,
  country: nil,
  currency: nil,
  routing_number: nil
)
  @object = object
  @account_holder_name = 
  @account_holder_type = 
  @account_number = 
  @country = country
  @currency = currency
  @routing_number = routing_number
end

Instance Attribute Details

#account_holder_nameObject

The name of the person or business that owns the bank account.This field is required when attaching the bank account to a ‘Customer` object.



130
131
132
# File 'lib/stripe/services/external_account_service.rb', line 130

def 
  @account_holder_name
end

#account_holder_typeObject

The type of entity that holds the account. It can be ‘company` or `individual`. This field is required when attaching the bank account to a `Customer` object.



132
133
134
# File 'lib/stripe/services/external_account_service.rb', line 132

def 
  @account_holder_type
end

#account_numberObject

The account number for the bank account, in string form. Must be a checking account.



134
135
136
# File 'lib/stripe/services/external_account_service.rb', line 134

def 
  @account_number
end

#countryObject

The country in which the bank account is located.



136
137
138
# File 'lib/stripe/services/external_account_service.rb', line 136

def country
  @country
end

#currencyObject

The currency the bank account is in. This must be a country/currency pairing that [Stripe supports.](docs/payouts)



138
139
140
# File 'lib/stripe/services/external_account_service.rb', line 138

def currency
  @currency
end

#objectObject

Attribute for param field object



128
129
130
# File 'lib/stripe/services/external_account_service.rb', line 128

def object
  @object
end

#routing_numberObject

The routing number, sort code, or other country-appropriate institution number for the bank account. For US bank accounts, this is required and should be the ACH routing number, not the wire routing number. If you are providing an IBAN for ‘account_number`, this field is not required.



140
141
142
# File 'lib/stripe/services/external_account_service.rb', line 140

def routing_number
  @routing_number
end