Class: Stripe::ExternalAccountService::ListParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/external_account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(ending_before: nil, expand: nil, limit: nil, object: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



116
117
118
119
120
121
122
# File 'lib/stripe/services/external_account_service.rb', line 116

def initialize(ending_before: nil, expand: nil, limit: nil, object: nil, starting_after: nil)
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @object = object
  @starting_after = starting_after
end

Instance Attribute Details

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



106
107
108
# File 'lib/stripe/services/external_account_service.rb', line 106

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



108
109
110
# File 'lib/stripe/services/external_account_service.rb', line 108

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



110
111
112
# File 'lib/stripe/services/external_account_service.rb', line 110

def limit
  @limit
end

#objectObject

Filter external accounts according to a particular object type.



112
113
114
# File 'lib/stripe/services/external_account_service.rb', line 112

def object
  @object
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



114
115
116
# File 'lib/stripe/services/external_account_service.rb', line 114

def starting_after
  @starting_after
end