Class: Stripe::ExternalAccountService::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/external_account_service.rb

Defined Under Namespace

Classes: Documents

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_holder_type: nil, account_type: nil, address_city: nil, address_country: nil, address_line1: nil, address_line2: nil, address_state: nil, address_zip: nil, default_for_currency: nil, documents: nil, exp_month: nil, exp_year: nil, expand: nil, metadata: nil, name: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/stripe/services/external_account_service.rb', line 67

def initialize(
  account_holder_name: nil,
  account_holder_type: nil,
  account_type: nil,
  address_city: nil,
  address_country: nil,
  address_line1: nil,
  address_line2: nil,
  address_state: nil,
  address_zip: nil,
  default_for_currency: nil,
  documents: nil,
  exp_month: nil,
  exp_year: nil,
  expand: nil,
  metadata: nil,
  name: nil
)
  @account_holder_name = 
  @account_holder_type = 
  @account_type = 
  @address_city = address_city
  @address_country = address_country
  @address_line1 = address_line1
  @address_line2 = address_line2
  @address_state = address_state
  @address_zip = address_zip
  @default_for_currency = default_for_currency
  @documents = documents
  @exp_month = exp_month
  @exp_year = exp_year
  @expand = expand
  @metadata = 
  @name = name
end

Instance Attribute Details

#account_holder_nameObject

The name of the person or business that owns the bank account.



35
36
37
# File 'lib/stripe/services/external_account_service.rb', line 35

def 
  @account_holder_name
end

#account_holder_typeObject

The type of entity that holds the account. This can be either ‘individual` or `company`.



37
38
39
# File 'lib/stripe/services/external_account_service.rb', line 37

def 
  @account_holder_type
end

#account_typeObject

The bank account type. This can only be ‘checking` or `savings` in most countries. In Japan, this can only be `futsu` or `toza`.



39
40
41
# File 'lib/stripe/services/external_account_service.rb', line 39

def 
  @account_type
end

#address_cityObject

City/District/Suburb/Town/Village.



41
42
43
# File 'lib/stripe/services/external_account_service.rb', line 41

def address_city
  @address_city
end

#address_countryObject

Billing address country, if provided when creating card.



43
44
45
# File 'lib/stripe/services/external_account_service.rb', line 43

def address_country
  @address_country
end

#address_line1Object

Address line 1 (Street address/PO Box/Company name).



45
46
47
# File 'lib/stripe/services/external_account_service.rb', line 45

def address_line1
  @address_line1
end

#address_line2Object

Address line 2 (Apartment/Suite/Unit/Building).



47
48
49
# File 'lib/stripe/services/external_account_service.rb', line 47

def address_line2
  @address_line2
end

#address_stateObject

State/County/Province/Region.



49
50
51
# File 'lib/stripe/services/external_account_service.rb', line 49

def address_state
  @address_state
end

#address_zipObject

ZIP or postal code.



51
52
53
# File 'lib/stripe/services/external_account_service.rb', line 51

def address_zip
  @address_zip
end

#default_for_currencyObject

When set to true, this becomes the default external account for its currency.



53
54
55
# File 'lib/stripe/services/external_account_service.rb', line 53

def default_for_currency
  @default_for_currency
end

#documentsObject

Documents that may be submitted to satisfy various informational requests.



55
56
57
# File 'lib/stripe/services/external_account_service.rb', line 55

def documents
  @documents
end

#exp_monthObject

Two digit number representing the card’s expiration month.



57
58
59
# File 'lib/stripe/services/external_account_service.rb', line 57

def exp_month
  @exp_month
end

#exp_yearObject

Four digit number representing the card’s expiration year.



59
60
61
# File 'lib/stripe/services/external_account_service.rb', line 59

def exp_year
  @exp_year
end

#expandObject

Specifies which fields in the response should be expanded.



61
62
63
# File 'lib/stripe/services/external_account_service.rb', line 61

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



63
64
65
# File 'lib/stripe/services/external_account_service.rb', line 63

def 
  @metadata
end

#nameObject

Cardholder name.



65
66
67
# File 'lib/stripe/services/external_account_service.rb', line 65

def name
  @name
end