Class: Stripe::File::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/file.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(created: nil, ending_before: nil, expand: nil, limit: nil, purpose: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/stripe/resources/file.rb', line 52

def initialize(
  created: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  purpose: nil,
  starting_after: nil
)
  @created = created
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @purpose = purpose
  @starting_after = starting_after
end

Instance Attribute Details

#createdObject

Only return files that were created during the given date interval.



40
41
42
# File 'lib/stripe/resources/file.rb', line 40

def created
  @created
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



42
43
44
# File 'lib/stripe/resources/file.rb', line 42

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



44
45
46
# File 'lib/stripe/resources/file.rb', line 44

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



46
47
48
# File 'lib/stripe/resources/file.rb', line 46

def limit
  @limit
end

#purposeObject

Filter queries by the file purpose. If you don’t provide a purpose, the queries return unfiltered files.



48
49
50
# File 'lib/stripe/resources/file.rb', line 48

def purpose
  @purpose
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



50
51
52
# File 'lib/stripe/resources/file.rb', line 50

def starting_after
  @starting_after
end