Class: Stripe::FileLink

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List
Includes:
APIOperations::Save
Defined in:
lib/stripe/resources/file_link.rb

Overview

To share the contents of a ‘File` object with non-Stripe users, you can create a `FileLink`. `FileLink`s contain a URL that you can use to retrieve the contents of the file without authentication.

Defined Under Namespace

Classes: CreateParams, ListParams, RetrieveParams, UpdateParams

Constant Summary collapse

OBJECT_NAME =
"file_link"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods included from APIOperations::Save

included, #save

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



126
127
128
# File 'lib/stripe/resources/file_link.rb', line 126

def created
  @created
end

#expiredObject (readonly)

Returns if the link is already expired.



129
130
131
# File 'lib/stripe/resources/file_link.rb', line 129

def expired
  @expired
end

#expires_atObject (readonly)

Time that the link expires.



132
133
134
# File 'lib/stripe/resources/file_link.rb', line 132

def expires_at
  @expires_at
end

#fileObject (readonly)

The file object this link points to.



135
136
137
# File 'lib/stripe/resources/file_link.rb', line 135

def file
  @file
end

#idObject (readonly)

Unique identifier for the object.



138
139
140
# File 'lib/stripe/resources/file_link.rb', line 138

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



141
142
143
# File 'lib/stripe/resources/file_link.rb', line 141

def livemode
  @livemode
end

#metadataObject (readonly)

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



144
145
146
# File 'lib/stripe/resources/file_link.rb', line 144

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



147
148
149
# File 'lib/stripe/resources/file_link.rb', line 147

def object
  @object
end

#urlObject (readonly)

The publicly accessible URL to download the file.



150
151
152
# File 'lib/stripe/resources/file_link.rb', line 150

def url
  @url
end

Class Method Details

.create(params = {}, opts = {}) ⇒ Object

Creates a new file link object.



153
154
155
# File 'lib/stripe/resources/file_link.rb', line 153

def self.create(params = {}, opts = {})
  request_stripe_object(method: :post, path: "/v1/file_links", params: params, opts: opts)
end

.list(params = {}, opts = {}) ⇒ Object

Returns a list of file links.



158
159
160
# File 'lib/stripe/resources/file_link.rb', line 158

def self.list(params = {}, opts = {})
  request_stripe_object(method: :get, path: "/v1/file_links", params: params, opts: opts)
end

.object_nameObject



14
15
16
# File 'lib/stripe/resources/file_link.rb', line 14

def self.object_name
  "file_link"
end

.update(id, params = {}, opts = {}) ⇒ Object

Updates an existing file link object. Expired links can no longer be updated.



163
164
165
166
167
168
169
170
# File 'lib/stripe/resources/file_link.rb', line 163

def self.update(id, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/file_links/%<id>s", { id: CGI.escape(id) }),
    params: params,
    opts: opts
  )
end