Class: Stripe::FileLink::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/file_link.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, expires_at: nil, file: nil, metadata: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



92
93
94
95
96
97
# File 'lib/stripe/resources/file_link.rb', line 92

def initialize(expand: nil, expires_at: nil, file: nil, metadata: nil)
  @expand = expand
  @expires_at = expires_at
  @file = file
  @metadata = 
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



81
82
83
# File 'lib/stripe/resources/file_link.rb', line 81

def expand
  @expand
end

#expires_atObject

The link isn’t usable after this future timestamp.



84
85
86
# File 'lib/stripe/resources/file_link.rb', line 84

def expires_at
  @expires_at
end

#fileObject

The ID of the file. The file’s ‘purpose` must be one of the following: `business_icon`, `business_logo`, `customer_signature`, `dispute_evidence`, `finance_report_run`, `financial_account_statement`, `identity_document_downloadable`, `issuing_regulatory_reporting`, `pci_document`, `selfie`, `sigma_scheduled_query`, `tax_document_user_upload`, or `terminal_reader_splashscreen`.



87
88
89
# File 'lib/stripe/resources/file_link.rb', line 87

def file
  @file
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



90
91
92
# File 'lib/stripe/resources/file_link.rb', line 90

def 
  @metadata
end