Class: Stripe::FileLinkService::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/file_link_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, expires_at: nil, metadata: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



107
108
109
110
111
# File 'lib/stripe/services/file_link_service.rb', line 107

def initialize(expand: nil, expires_at: nil, metadata: nil)
  @expand = expand
  @expires_at = expires_at
  @metadata = 
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



99
100
101
# File 'lib/stripe/services/file_link_service.rb', line 99

def expand
  @expand
end

#expires_atObject

A future timestamp after which the link will no longer be usable, or ‘now` to expire the link immediately.



102
103
104
# File 'lib/stripe/services/file_link_service.rb', line 102

def expires_at
  @expires_at
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



105
106
107
# File 'lib/stripe/services/file_link_service.rb', line 105

def 
  @metadata
end