Class: Stripe::FinancialConnections::Account

Inherits:
APIResource show all
Extended by:
APIOperations::List, APIOperations::NestedResource
Defined in:
lib/stripe/resources/financial_connections/account.rb

Overview

A Financial Connections Account represents an account that exists outside of Stripe, to which you have been granted some degree of access.

Defined Under Namespace

Classes: AccountHolder, AccountNumber, Balance, BalanceRefresh, ClassificationState, EnrichmentState, InferredBalancesRefresh, OwnershipRefresh, StatusDetails, TransactionRefresh

Constant Summary collapse

OBJECT_NAME =
"financial_connections.account"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::List

list

Methods included from APIOperations::NestedResource

nested_resource_class_methods

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_holderObject (readonly)

The account holder that this account belongs to.



268
269
270
# File 'lib/stripe/resources/financial_connections/account.rb', line 268

def 
  @account_holder
end

#account_numbersObject (readonly)

Details about the account numbers.



270
271
272
# File 'lib/stripe/resources/financial_connections/account.rb', line 270

def 
  @account_numbers
end

#authorizationObject (readonly)

The ID of the Financial Connections Authorization this account belongs to.



272
273
274
# File 'lib/stripe/resources/financial_connections/account.rb', line 272

def authorization
  @authorization
end

#balanceObject (readonly)

The most recent information about the account's balance.



274
275
276
# File 'lib/stripe/resources/financial_connections/account.rb', line 274

def balance
  @balance
end

#balance_refreshObject (readonly)

The state of the most recent attempt to refresh the account balance.



276
277
278
# File 'lib/stripe/resources/financial_connections/account.rb', line 276

def balance_refresh
  @balance_refresh
end

#categoryObject (readonly)

The type of the account. Account category is further divided in subcategory.



278
279
280
# File 'lib/stripe/resources/financial_connections/account.rb', line 278

def category
  @category
end

#classification_stateObject (readonly)

Per-taxonomy processing state for this account. One entry per subscribed taxonomy.



280
281
282
# File 'lib/stripe/resources/financial_connections/account.rb', line 280

def classification_state
  @classification_state
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



282
283
284
# File 'lib/stripe/resources/financial_connections/account.rb', line 282

def created
  @created
end

#display_nameObject (readonly)

A human-readable name that has been assigned to this account, either by the account holder or by the institution.



284
285
286
# File 'lib/stripe/resources/financial_connections/account.rb', line 284

def display_name
  @display_name
end

#enrichment_stateObject (readonly)

The state of merchant name enrichment for this account.



286
287
288
# File 'lib/stripe/resources/financial_connections/account.rb', line 286

def enrichment_state
  @enrichment_state
end

#idObject (readonly)

Unique identifier for the object.



288
289
290
# File 'lib/stripe/resources/financial_connections/account.rb', line 288

def id
  @id
end

#inferred_balances_refreshObject (readonly)

The state of the most recent attempt to refresh the account's inferred balance history.



290
291
292
# File 'lib/stripe/resources/financial_connections/account.rb', line 290

def inferred_balances_refresh
  @inferred_balances_refresh
end

#institutionObject (readonly)

The ID of the Financial Connections Institution this account belongs to. Note that this relationship may sometimes change in rare circumstances (e.g. institution mergers).



292
293
294
# File 'lib/stripe/resources/financial_connections/account.rb', line 292

def institution
  @institution
end

#institution_nameObject (readonly)

The name of the institution that holds this account.



294
295
296
# File 'lib/stripe/resources/financial_connections/account.rb', line 294

def institution_name
  @institution_name
end

#last4Object (readonly)

The last 4 digits of the account number. If present, this will be 4 numeric characters.



296
297
298
# File 'lib/stripe/resources/financial_connections/account.rb', line 296

def last4
  @last4
end

#livemodeObject (readonly)

If the object exists in live mode, the value is true. If the object exists in test mode, the value is false.



298
299
300
# File 'lib/stripe/resources/financial_connections/account.rb', line 298

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object's type. Objects of the same type share the same value.



300
301
302
# File 'lib/stripe/resources/financial_connections/account.rb', line 300

def object
  @object
end

#ownershipObject (readonly)

The most recent information about the account's owners.



302
303
304
# File 'lib/stripe/resources/financial_connections/account.rb', line 302

def ownership
  @ownership
end

#ownership_refreshObject (readonly)

The state of the most recent attempt to refresh the account owners.



304
305
306
# File 'lib/stripe/resources/financial_connections/account.rb', line 304

def ownership_refresh
  @ownership_refresh
end

#permissionsObject (readonly)

The list of permissions granted by this account.



306
307
308
# File 'lib/stripe/resources/financial_connections/account.rb', line 306

def permissions
  @permissions
end

#statusObject (readonly)

The status of the link to the account.



308
309
310
# File 'lib/stripe/resources/financial_connections/account.rb', line 308

def status
  @status
end

#status_detailsObject (readonly)

Attribute for field status_details



310
311
312
# File 'lib/stripe/resources/financial_connections/account.rb', line 310

def status_details
  @status_details
end

#subcategoryObject (readonly)

If category is cash, one of:

  • checking
  • savings
  • other

If category is credit, one of:

  • mortgage
  • line_of_credit
  • credit_card
  • other

If category is investment or other, this will be other.



325
326
327
# File 'lib/stripe/resources/financial_connections/account.rb', line 325

def subcategory
  @subcategory
end

#subscriptionsObject (readonly)

The list of data refresh subscriptions requested on this account.



327
328
329
# File 'lib/stripe/resources/financial_connections/account.rb', line 327

def subscriptions
  @subscriptions
end

#supported_payment_method_typesObject (readonly)

The PaymentMethod type(s) that can be created from this account.



329
330
331
# File 'lib/stripe/resources/financial_connections/account.rb', line 329

def supported_payment_method_types
  @supported_payment_method_types
end

#transaction_refreshObject (readonly)

The state of the most recent attempt to refresh the account transactions.



331
332
333
# File 'lib/stripe/resources/financial_connections/account.rb', line 331

def transaction_refresh
  @transaction_refresh
end

Class Method Details

.disconnect(account, params = {}, opts = {}) ⇒ Object

Disables your access to a Financial Connections Account. You will no longer be able to access data associated with the account (e.g. balances, transactions).



344
345
346
347
348
349
350
351
# File 'lib/stripe/resources/financial_connections/account.rb', line 344

def self.disconnect(, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/financial_connections/accounts/%<account>s/disconnect", { account: CGI.escape() }),
    params: params,
    opts: opts
  )
end

.field_remappingsObject



458
459
460
# File 'lib/stripe/resources/financial_connections/account.rb', line 458

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



443
444
445
446
447
448
449
450
451
452
453
454
455
456
# File 'lib/stripe/resources/financial_connections/account.rb', line 443

def self.inner_class_types
  @inner_class_types = {
    account_holder: AccountHolder,
    account_numbers: AccountNumber,
    balance: Balance,
    balance_refresh: BalanceRefresh,
    classification_state: ClassificationState,
    enrichment_state: EnrichmentState,
    inferred_balances_refresh: InferredBalancesRefresh,
    ownership_refresh: OwnershipRefresh,
    status_details: StatusDetails,
    transaction_refresh: TransactionRefresh,
  }
end

.list(params = {}, opts = {}) ⇒ Object

Returns a list of Financial Connections Account objects.



354
355
356
357
358
359
360
361
# File 'lib/stripe/resources/financial_connections/account.rb', line 354

def self.list(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/financial_connections/accounts",
    params: params,
    opts: opts
  )
end

.list_owners(account, params = {}, opts = {}) ⇒ Object

Lists all owners for a given Account



374
375
376
377
378
379
380
381
# File 'lib/stripe/resources/financial_connections/account.rb', line 374

def self.list_owners(, params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: format("/v1/financial_connections/accounts/%<account>s/owners", { account: CGI.escape() }),
    params: params,
    opts: opts
  )
end

.object_nameObject



12
13
14
# File 'lib/stripe/resources/financial_connections/account.rb', line 12

def self.object_name
  "financial_connections.account"
end

.refresh_account(account, params = {}, opts = {}) ⇒ Object

Refreshes the data associated with a Financial Connections Account.



394
395
396
397
398
399
400
401
# File 'lib/stripe/resources/financial_connections/account.rb', line 394

def self.(, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/financial_connections/accounts/%<account>s/refresh", { account: CGI.escape() }),
    params: params,
    opts: opts
  )
end

.subscribe(account, params = {}, opts = {}) ⇒ Object

Subscribes to periodic refreshes of data associated with a Financial Connections Account. When the account status is active, data is typically refreshed once a day.



414
415
416
417
418
419
420
421
# File 'lib/stripe/resources/financial_connections/account.rb', line 414

def self.subscribe(, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/financial_connections/accounts/%<account>s/subscribe", { account: CGI.escape() }),
    params: params,
    opts: opts
  )
end

.unsubscribe(account, params = {}, opts = {}) ⇒ Object

Unsubscribes from periodic refreshes of data associated with a Financial Connections Account.



434
435
436
437
438
439
440
441
# File 'lib/stripe/resources/financial_connections/account.rb', line 434

def self.unsubscribe(, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/financial_connections/accounts/%<account>s/unsubscribe", { account: CGI.escape() }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#disconnect(params = {}, opts = {}) ⇒ Object

Disables your access to a Financial Connections Account. You will no longer be able to access data associated with the account (e.g. balances, transactions).



334
335
336
337
338
339
340
341
# File 'lib/stripe/resources/financial_connections/account.rb', line 334

def disconnect(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/financial_connections/accounts/%<account>s/disconnect", { account: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#list_owners(params = {}, opts = {}) ⇒ Object

Lists all owners for a given Account



364
365
366
367
368
369
370
371
# File 'lib/stripe/resources/financial_connections/account.rb', line 364

def list_owners(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: format("/v1/financial_connections/accounts/%<account>s/owners", { account: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#refresh_account(params = {}, opts = {}) ⇒ Object

Refreshes the data associated with a Financial Connections Account.



384
385
386
387
388
389
390
391
# File 'lib/stripe/resources/financial_connections/account.rb', line 384

def (params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/financial_connections/accounts/%<account>s/refresh", { account: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#subscribe(params = {}, opts = {}) ⇒ Object

Subscribes to periodic refreshes of data associated with a Financial Connections Account. When the account status is active, data is typically refreshed once a day.



404
405
406
407
408
409
410
411
# File 'lib/stripe/resources/financial_connections/account.rb', line 404

def subscribe(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/financial_connections/accounts/%<account>s/subscribe", { account: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#unsubscribe(params = {}, opts = {}) ⇒ Object

Unsubscribes from periodic refreshes of data associated with a Financial Connections Account.



424
425
426
427
428
429
430
431
# File 'lib/stripe/resources/financial_connections/account.rb', line 424

def unsubscribe(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/financial_connections/accounts/%<account>s/unsubscribe", { account: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end