Class: Stripe::FinancialConnections::Account::AccountNumber
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::FinancialConnections::Account::AccountNumber
- Defined in:
- lib/stripe/resources/financial_connections/account.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#expected_expiry_date ⇒ Object
readonly
When the account number is expected to expire, if applicable.
-
#identifier_type ⇒ Object
readonly
The type of account number associated with the account.
-
#status ⇒ Object
readonly
Whether the account number is currently active and usable for transactions.
-
#supported_networks ⇒ Object
readonly
The payment networks that the account number can be used for.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#expected_expiry_date ⇒ Object (readonly)
When the account number is expected to expire, if applicable.
39 40 41 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 39 def expected_expiry_date @expected_expiry_date end |
#identifier_type ⇒ Object (readonly)
The type of account number associated with the account.
41 42 43 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 41 def identifier_type @identifier_type end |
#status ⇒ Object (readonly)
Whether the account number is currently active and usable for transactions.
43 44 45 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 43 def status @status end |
#supported_networks ⇒ Object (readonly)
The payment networks that the account number can be used for.
45 46 47 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 45 def supported_networks @supported_networks end |
Class Method Details
.field_remappings ⇒ Object
51 52 53 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 51 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
47 48 49 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 47 def self.inner_class_types @inner_class_types = {} end |