Class: Stripe::FinancialConnections::Account::DisconnectParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::FinancialConnections::Account::DisconnectParams
- Defined in:
- lib/stripe/resources/financial_connections/account.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ DisconnectParams
constructor
A new instance of DisconnectParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ DisconnectParams
Returns a new instance of DisconnectParams.
177 178 179 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 177 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
175 176 177 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 175 def @expand end |