Class: Stripe::FinancialConnections::Account::ListParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/financial_connections/account.rb

Defined Under Namespace

Classes: AccountHolder

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder: nil, ending_before: nil, expand: nil, limit: nil, session: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/stripe/resources/financial_connections/account.rb', line 129

def initialize(
  account_holder: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  session: nil,
  starting_after: nil
)
  @account_holder = 
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @session = session
  @starting_after = starting_after
end

Instance Attribute Details

#account_holderObject

If present, only return accounts that belong to the specified account holder. ‘account_holder` and `account_holder` are mutually exclusive.



117
118
119
# File 'lib/stripe/resources/financial_connections/account.rb', line 117

def 
  @account_holder
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



119
120
121
# File 'lib/stripe/resources/financial_connections/account.rb', line 119

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



121
122
123
# File 'lib/stripe/resources/financial_connections/account.rb', line 121

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



123
124
125
# File 'lib/stripe/resources/financial_connections/account.rb', line 123

def limit
  @limit
end

#sessionObject

If present, only return accounts that were collected as part of the given session.



125
126
127
# File 'lib/stripe/resources/financial_connections/account.rb', line 125

def session
  @session
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



127
128
129
# File 'lib/stripe/resources/financial_connections/account.rb', line 127

def starting_after
  @starting_after
end