Class: Stripe::FinancialConnections::Account::ListParams::AccountHolder

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/financial_connections/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account: nil, customer: nil, customer_account: nil) ⇒ AccountHolder

Returns a new instance of AccountHolder.



174
175
176
177
178
# File 'lib/stripe/resources/financial_connections/account.rb', line 174

def initialize(account: nil, customer: nil, customer_account: nil)
  @account = 
  @customer = customer
  @customer_account = 
end

Instance Attribute Details

#accountObject

The ID of the Stripe account whose accounts will be retrieved.



168
169
170
# File 'lib/stripe/resources/financial_connections/account.rb', line 168

def 
  @account
end

#customerObject

The ID of the Stripe customer whose accounts will be retrieved.



170
171
172
# File 'lib/stripe/resources/financial_connections/account.rb', line 170

def customer
  @customer
end

#customer_accountObject

The Account ID of the Stripe customer whose accounts will be retrieved.



172
173
174
# File 'lib/stripe/resources/financial_connections/account.rb', line 172

def 
  @customer_account
end