Class: Stripe::FinancialConnections::Account::RefreshAccountParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/financial_connections/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, features: nil) ⇒ RefreshAccountParams

Returns a new instance of RefreshAccountParams.



252
253
254
255
# File 'lib/stripe/resources/financial_connections/account.rb', line 252

def initialize(expand: nil, features: nil)
  @expand = expand
  @features = features
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



248
249
250
# File 'lib/stripe/resources/financial_connections/account.rb', line 248

def expand
  @expand
end

#featuresObject

The list of account features that you would like to refresh.



250
251
252
# File 'lib/stripe/resources/financial_connections/account.rb', line 250

def features
  @features
end