Class: Stripe::FinancialConnections::Account::SubscribeParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/financial_connections/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, features: nil) ⇒ SubscribeParams

Returns a new instance of SubscribeParams.



264
265
266
267
# File 'lib/stripe/resources/financial_connections/account.rb', line 264

def initialize(expand: nil, features: nil)
  @expand = expand
  @features = features
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



260
261
262
# File 'lib/stripe/resources/financial_connections/account.rb', line 260

def expand
  @expand
end

#featuresObject

The list of account features to which you would like to subscribe.



262
263
264
# File 'lib/stripe/resources/financial_connections/account.rb', line 262

def features
  @features
end