Class: Stripe::FinancialConnections::Account::UnsubscribeParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/financial_connections/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, features: nil) ⇒ UnsubscribeParams

Returns a new instance of UnsubscribeParams.



195
196
197
198
# File 'lib/stripe/resources/financial_connections/account.rb', line 195

def initialize(expand: nil, features: nil)
  @expand = expand
  @features = features
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



191
192
193
# File 'lib/stripe/resources/financial_connections/account.rb', line 191

def expand
  @expand
end

#featuresObject

The list of account features from which you would like to unsubscribe.



193
194
195
# File 'lib/stripe/resources/financial_connections/account.rb', line 193

def features
  @features
end