Class: Stripe::FinancialConnections::AccountListParams::AccountHolder

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/financial_connections/account_list_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(account: nil, customer: nil, customer_account: nil) ⇒ AccountHolder

Returns a new instance of AccountHolder.



15
16
17
18
19
# File 'lib/stripe/params/financial_connections/account_list_params.rb', line 15

def initialize(account: nil, customer: nil, customer_account: nil)
  @account = 
  @customer = customer
  @customer_account = 
end

Instance Attribute Details

#accountObject

The ID of the Stripe account whose accounts you will retrieve.



9
10
11
# File 'lib/stripe/params/financial_connections/account_list_params.rb', line 9

def 
  @account
end

#customerObject

The ID of the Stripe customer whose accounts you will retrieve.



11
12
13
# File 'lib/stripe/params/financial_connections/account_list_params.rb', line 11

def customer
  @customer
end

#customer_accountObject

The ID of the Account representing a customer whose accounts you will retrieve.



13
14
15
# File 'lib/stripe/params/financial_connections/account_list_params.rb', line 13

def 
  @customer_account
end