Class: Stripe::FinancialConnections::AccountService::DisconnectParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::FinancialConnections::AccountService::DisconnectParams
- Defined in:
- lib/stripe/services/financial_connections/account_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ DisconnectParams
constructor
A new instance of DisconnectParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ DisconnectParams
Returns a new instance of DisconnectParams.
74 75 76 |
# File 'lib/stripe/services/financial_connections/account_service.rb', line 74 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
72 73 74 |
# File 'lib/stripe/services/financial_connections/account_service.rb', line 72 def @expand end |