Class: Stripe::FinancialConnections::AccountService::ListParams::AccountHolder
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::FinancialConnections::AccountService::ListParams::AccountHolder
- Defined in:
- lib/stripe/services/financial_connections/account_service.rb
Instance Attribute Summary collapse
-
#account ⇒ Object
The ID of the Stripe account whose accounts will be retrieved.
-
#customer ⇒ Object
The ID of the Stripe customer whose accounts will be retrieved.
-
#customer_account ⇒ Object
The Account ID of the Stripe customer whose accounts will be retrieved.
Instance Method Summary collapse
-
#initialize(account: nil, customer: nil, customer_account: nil) ⇒ AccountHolder
constructor
A new instance of AccountHolder.
Methods inherited from RequestParams
Constructor Details
#initialize(account: nil, customer: nil, customer_account: nil) ⇒ AccountHolder
Returns a new instance of AccountHolder.
25 26 27 28 29 |
# File 'lib/stripe/services/financial_connections/account_service.rb', line 25 def initialize(account: nil, customer: nil, customer_account: nil) @account = account @customer = customer @customer_account = customer_account end |
Instance Attribute Details
#account ⇒ Object
The ID of the Stripe account whose accounts will be retrieved.
19 20 21 |
# File 'lib/stripe/services/financial_connections/account_service.rb', line 19 def account @account end |
#customer ⇒ Object
The ID of the Stripe customer whose accounts will be retrieved.
21 22 23 |
# File 'lib/stripe/services/financial_connections/account_service.rb', line 21 def customer @customer end |
#customer_account ⇒ Object
The Account ID of the Stripe customer whose accounts will be retrieved.
23 24 25 |
# File 'lib/stripe/services/financial_connections/account_service.rb', line 23 def customer_account @customer_account end |