Class: Stripe::FinancialConnections::AccountService::RefreshParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::FinancialConnections::AccountService::RefreshParams
- Defined in:
- lib/stripe/services/financial_connections/account_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#features ⇒ Object
The list of account features that you would like to refresh.
Instance Method Summary collapse
-
#initialize(expand: nil, features: nil) ⇒ RefreshParams
constructor
A new instance of RefreshParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, features: nil) ⇒ RefreshParams
Returns a new instance of RefreshParams.
80 81 82 83 |
# File 'lib/stripe/services/financial_connections/account_service.rb', line 80 def initialize(expand: nil, features: nil) @expand = @features = features end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
76 77 78 |
# File 'lib/stripe/services/financial_connections/account_service.rb', line 76 def @expand end |
#features ⇒ Object
The list of account features that you would like to refresh.
78 79 80 |
# File 'lib/stripe/services/financial_connections/account_service.rb', line 78 def features @features end |