Class: Stripe::FinancialConnections::AccountService::SubscribeParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/financial_connections/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, features: nil) ⇒ SubscribeParams

Returns a new instance of SubscribeParams.



97
98
99
100
# File 'lib/stripe/services/financial_connections/account_service.rb', line 97

def initialize(expand: nil, features: nil)
  @expand = expand
  @features = features
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



93
94
95
# File 'lib/stripe/services/financial_connections/account_service.rb', line 93

def expand
  @expand
end

#featuresObject

The list of account features to which you would like to subscribe.



95
96
97
# File 'lib/stripe/services/financial_connections/account_service.rb', line 95

def features
  @features
end