Class: Stripe::FinancialConnections::Authorization

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/financial_connections/authorization.rb

Overview

An Authorization represents the set of credentials used to connect a group of Financial Connections Accounts.

Defined Under Namespace

Classes: StatusDetails

Constant Summary collapse

OBJECT_NAME =
"financial_connections.authorization"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#idObject (readonly)

Unique identifier for the object.



55
56
57
# File 'lib/stripe/resources/financial_connections/authorization.rb', line 55

def id
  @id
end

#institution_nameObject (readonly)

The name of the institution that this authorization belongs to.



57
58
59
# File 'lib/stripe/resources/financial_connections/authorization.rb', line 57

def institution_name
  @institution_name
end

#livemodeObject (readonly)

If the object exists in live mode, the value is true. If the object exists in test mode, the value is false.



59
60
61
# File 'lib/stripe/resources/financial_connections/authorization.rb', line 59

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object's type. Objects of the same type share the same value.



61
62
63
# File 'lib/stripe/resources/financial_connections/authorization.rb', line 61

def object
  @object
end

#statusObject (readonly)

The status of the connection to the Authorization.



63
64
65
# File 'lib/stripe/resources/financial_connections/authorization.rb', line 63

def status
  @status
end

#status_detailsObject (readonly)

Attribute for field status_details



65
66
67
# File 'lib/stripe/resources/financial_connections/authorization.rb', line 65

def status_details
  @status_details
end

Class Method Details

.field_remappingsObject



71
72
73
# File 'lib/stripe/resources/financial_connections/authorization.rb', line 71

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



67
68
69
# File 'lib/stripe/resources/financial_connections/authorization.rb', line 67

def self.inner_class_types
  @inner_class_types = { status_details: StatusDetails }
end

.object_nameObject



9
10
11
# File 'lib/stripe/resources/financial_connections/authorization.rb', line 9

def self.object_name
  "financial_connections.authorization"
end