Class: Stripe::FinancialConnections::Institution

Inherits:
APIResource show all
Extended by:
APIOperations::List
Defined in:
lib/stripe/resources/financial_connections/institution.rb

Overview

An institution represents a financial institution to which an end user can connect using the Financial Connections authentication flow.

Defined Under Namespace

Classes: Features

Constant Summary collapse

OBJECT_NAME =
"financial_connections.institution"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods included from APIOperations::List

list

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#countriesObject (readonly)

The list of countries supported by this institution, formatted as ISO country codes.



90
91
92
# File 'lib/stripe/resources/financial_connections/institution.rb', line 90

def countries
  @countries
end

#featuresObject (readonly)

Attribute for field features



92
93
94
# File 'lib/stripe/resources/financial_connections/institution.rb', line 92

def features
  @features
end

#idObject (readonly)

Unique identifier for the object.



94
95
96
# File 'lib/stripe/resources/financial_connections/institution.rb', line 94

def id
  @id
end

#livemodeObject (readonly)

If the object exists in live mode, the value is ‘true`. If the object exists in test mode, the value is `false`.



96
97
98
# File 'lib/stripe/resources/financial_connections/institution.rb', line 96

def livemode
  @livemode
end

#nameObject (readonly)

The name of this institution.



98
99
100
# File 'lib/stripe/resources/financial_connections/institution.rb', line 98

def name
  @name
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



100
101
102
# File 'lib/stripe/resources/financial_connections/institution.rb', line 100

def object
  @object
end

#routing_numbersObject (readonly)

A list of routing numbers which are known to correspond to this institution. Due to the many to many relationship between institutions and routing numbers, this list may not be comprehensive and routing numbers may also be shared between institutions.



102
103
104
# File 'lib/stripe/resources/financial_connections/institution.rb', line 102

def routing_numbers
  @routing_numbers
end

#statusObject (readonly)

The status of this institution in the Financial Connections authentication flow.



104
105
106
# File 'lib/stripe/resources/financial_connections/institution.rb', line 104

def status
  @status
end

#urlObject (readonly)

A URL corresponding to this institution. This URL is also displayed in the authentication flow to help end users confirm that they are authenticating with the right institution.



106
107
108
# File 'lib/stripe/resources/financial_connections/institution.rb', line 106

def url
  @url
end

Class Method Details

.field_remappingsObject



122
123
124
# File 'lib/stripe/resources/financial_connections/institution.rb', line 122

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



118
119
120
# File 'lib/stripe/resources/financial_connections/institution.rb', line 118

def self.inner_class_types
  @inner_class_types = { features: Features }
end

.list(params = {}, opts = {}) ⇒ Object

Returns a list of Financial Connections Institution objects.



109
110
111
112
113
114
115
116
# File 'lib/stripe/resources/financial_connections/institution.rb', line 109

def self.list(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/financial_connections/institutions",
    params: params,
    opts: opts
  )
end

.object_nameObject



11
12
13
# File 'lib/stripe/resources/financial_connections/institution.rb', line 11

def self.object_name
  "financial_connections.institution"
end