Class: Stripe::FinancialConnections::Session::AccountHolder
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::FinancialConnections::Session::AccountHolder
- Defined in:
- lib/stripe/resources/financial_connections/session.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account ⇒ Object
readonly
The ID of the Stripe account that this account belongs to.
-
#customer ⇒ Object
readonly
The ID for an Account representing a customer that this account belongs to.
-
#customer_account ⇒ Object
readonly
Attribute for field customer_account.
-
#type ⇒ Object
readonly
Type of account holder that this account belongs to.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account ⇒ Object (readonly)
The ID of the Stripe account that this account belongs to. Only available when ‘account_holder.type` is `account`.
17 18 19 |
# File 'lib/stripe/resources/financial_connections/session.rb', line 17 def account @account end |
#customer ⇒ Object (readonly)
The ID for an Account representing a customer that this account belongs to. Only available when ‘account_holder.type` is `customer`.
19 20 21 |
# File 'lib/stripe/resources/financial_connections/session.rb', line 19 def customer @customer end |
#customer_account ⇒ Object (readonly)
Attribute for field customer_account
21 22 23 |
# File 'lib/stripe/resources/financial_connections/session.rb', line 21 def customer_account @customer_account end |
#type ⇒ Object (readonly)
Type of account holder that this account belongs to.
23 24 25 |
# File 'lib/stripe/resources/financial_connections/session.rb', line 23 def type @type end |
Class Method Details
.field_remappings ⇒ Object
29 30 31 |
# File 'lib/stripe/resources/financial_connections/session.rb', line 29 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
25 26 27 |
# File 'lib/stripe/resources/financial_connections/session.rb', line 25 def self.inner_class_types @inner_class_types = {} end |