Class: Stripe::FinancialConnections::Session::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::FinancialConnections::Session::CreateParams
- Defined in:
- lib/stripe/resources/financial_connections/session.rb
Defined Under Namespace
Classes: AccountHolder, Filters, Limits, ManualEntry
Instance Attribute Summary collapse
-
#account_holder ⇒ Object
The account holder to link accounts for.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#filters ⇒ Object
Filters to restrict the kinds of accounts to collect.
-
#limits ⇒ Object
Settings for configuring Session-specific limits.
-
#manual_entry ⇒ Object
Customize manual entry behavior.
-
#permissions ⇒ Object
List of data features that you would like to request access to.
-
#prefetch ⇒ Object
List of data features that you would like to retrieve upon account creation.
-
#return_url ⇒ Object
For webview integrations only.
Instance Method Summary collapse
-
#initialize(account_holder: nil, expand: nil, filters: nil, limits: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder: nil, expand: nil, filters: nil, limits: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/stripe/resources/financial_connections/session.rb', line 169 def initialize( account_holder: nil, expand: nil, filters: nil, limits: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil ) @account_holder = account_holder @expand = @filters = filters @limits = limits @manual_entry = manual_entry @permissions = @prefetch = prefetch @return_url = return_url end |
Instance Attribute Details
#account_holder ⇒ Object
The account holder to link accounts for.
151 152 153 |
# File 'lib/stripe/resources/financial_connections/session.rb', line 151 def account_holder @account_holder end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
153 154 155 |
# File 'lib/stripe/resources/financial_connections/session.rb', line 153 def @expand end |
#filters ⇒ Object
Filters to restrict the kinds of accounts to collect.
155 156 157 |
# File 'lib/stripe/resources/financial_connections/session.rb', line 155 def filters @filters end |
#limits ⇒ Object
Settings for configuring Session-specific limits.
157 158 159 |
# File 'lib/stripe/resources/financial_connections/session.rb', line 157 def limits @limits end |
#manual_entry ⇒ Object
Customize manual entry behavior
159 160 161 |
# File 'lib/stripe/resources/financial_connections/session.rb', line 159 def manual_entry @manual_entry end |
#permissions ⇒ Object
List of data features that you would like to request access to.
Possible values are ‘balances`, `transactions`, `ownership`, and `payment_method`.
163 164 165 |
# File 'lib/stripe/resources/financial_connections/session.rb', line 163 def @permissions end |
#prefetch ⇒ Object
List of data features that you would like to retrieve upon account creation.
165 166 167 |
# File 'lib/stripe/resources/financial_connections/session.rb', line 165 def prefetch @prefetch end |
#return_url ⇒ Object
For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.
167 168 169 |
# File 'lib/stripe/resources/financial_connections/session.rb', line 167 def return_url @return_url end |