Class: Stripe::FinancialConnections::Session::CreateParams::AccountHolder

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/financial_connections/session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account: nil, customer: nil, customer_account: nil, type: nil) ⇒ AccountHolder

Returns a new instance of AccountHolder.



110
111
112
113
114
115
# File 'lib/stripe/resources/financial_connections/session.rb', line 110

def initialize(account: nil, customer: nil, customer_account: nil, type: nil)
  @account = 
  @customer = customer
  @customer_account = 
  @type = type
end

Instance Attribute Details

#accountObject

The ID of the Stripe account whose accounts will be retrieved. Should only be present if ‘type` is `account`.



102
103
104
# File 'lib/stripe/resources/financial_connections/session.rb', line 102

def 
  @account
end

#customerObject

The ID of the Stripe customer whose accounts will be retrieved. Should only be present if ‘type` is `customer`.



104
105
106
# File 'lib/stripe/resources/financial_connections/session.rb', line 104

def customer
  @customer
end

#customer_accountObject

The ID of the Stripe customer Account whose accounts will be retrieved. Should only be present if ‘type` is `customer`.



106
107
108
# File 'lib/stripe/resources/financial_connections/session.rb', line 106

def 
  @customer_account
end

#typeObject

Type of account holder to collect accounts for.



108
109
110
# File 'lib/stripe/resources/financial_connections/session.rb', line 108

def type
  @type
end