Class: Stripe::FinancialConnections::Session::Filters

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/financial_connections/session.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_subcategoriesObject (readonly)

Restricts the Session to subcategories of accounts that can be linked. Valid subcategories are: ‘checking`, `savings`, `mortgage`, `line_of_credit`, `credit_card`.



26
27
28
# File 'lib/stripe/resources/financial_connections/session.rb', line 26

def 
  @account_subcategories
end

#countriesObject (readonly)

List of countries from which to filter accounts.



28
29
30
# File 'lib/stripe/resources/financial_connections/session.rb', line 28

def countries
  @countries
end

#institutionObject (readonly)

Stripe ID of the institution with which the customer should be directed to log in.



30
31
32
# File 'lib/stripe/resources/financial_connections/session.rb', line 30

def institution
  @institution
end