Class: Stripe::FinancialConnections::SessionCreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/financial_connections/session_create_params.rb

Defined Under Namespace

Classes: AccountHolder, Filters, Hosted, Limits, ManualEntry, RelinkOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(account_holder: nil, expand: nil, filters: nil, hosted: nil, limits: nil, manual_entry: nil, permissions: nil, prefetch: nil, relink_options: nil, return_url: nil, ui_mode: nil) ⇒ SessionCreateParams

Returns a new instance of SessionCreateParams.



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'lib/stripe/params/financial_connections/session_create_params.rb', line 103

def initialize(
  account_holder: nil,
  expand: nil,
  filters: nil,
  hosted: nil,
  limits: nil,
  manual_entry: nil,
  permissions: nil,
  prefetch: nil,
  relink_options: nil,
  return_url: nil,
  ui_mode: nil
)
  @account_holder = 
  @expand = expand
  @filters = filters
  @hosted = hosted
  @limits = limits
  @manual_entry = manual_entry
  @permissions = permissions
  @prefetch = prefetch
  @relink_options = relink_options
  @return_url = return_url
  @ui_mode = ui_mode
end

Instance Attribute Details

#account_holderObject

The account holder to link accounts for.



79
80
81
# File 'lib/stripe/params/financial_connections/session_create_params.rb', line 79

def 
  @account_holder
end

#expandObject

Specifies which fields in the response should be expanded.



81
82
83
# File 'lib/stripe/params/financial_connections/session_create_params.rb', line 81

def expand
  @expand
end

#filtersObject

Filters to restrict the kinds of accounts to collect.



83
84
85
# File 'lib/stripe/params/financial_connections/session_create_params.rb', line 83

def filters
  @filters
end

#hostedObject

Settings for hosted Sessions. Required if ‘ui_mode` is `hosted`.



85
86
87
# File 'lib/stripe/params/financial_connections/session_create_params.rb', line 85

def hosted
  @hosted
end

#limitsObject

Settings for configuring Session-specific limits.



87
88
89
# File 'lib/stripe/params/financial_connections/session_create_params.rb', line 87

def limits
  @limits
end

#manual_entryObject

Customize manual entry behavior



89
90
91
# File 'lib/stripe/params/financial_connections/session_create_params.rb', line 89

def manual_entry
  @manual_entry
end

#permissionsObject

List of data features that you would like to request access to.

Possible values are ‘balances`, `transactions`, `ownership`, and `payment_method`.



93
94
95
# File 'lib/stripe/params/financial_connections/session_create_params.rb', line 93

def permissions
  @permissions
end

#prefetchObject

List of data features that you would like to retrieve upon account creation.



95
96
97
# File 'lib/stripe/params/financial_connections/session_create_params.rb', line 95

def prefetch
  @prefetch
end

Options for specifying a Session targeted to relinking an authorization.



97
98
99
# File 'lib/stripe/params/financial_connections/session_create_params.rb', line 97

def relink_options
  @relink_options
end

#return_urlObject

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



99
100
101
# File 'lib/stripe/params/financial_connections/session_create_params.rb', line 99

def return_url
  @return_url
end

#ui_modeObject

The UI mode of the Session. Defaults to ‘modal`.



101
102
103
# File 'lib/stripe/params/financial_connections/session_create_params.rb', line 101

def ui_mode
  @ui_mode
end