Class: Stripe::FinancialConnections::SessionCreateParams::Limits

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/financial_connections/session_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(accounts: nil) ⇒ Limits

Returns a new instance of Limits.



61
62
63
# File 'lib/stripe/params/financial_connections/session_create_params.rb', line 61

def initialize(accounts: nil)
  @accounts = accounts
end

Instance Attribute Details

#accountsObject

The number of accounts that can be linked in this Session. Pass an empty value to allow any number of accounts.



59
60
61
# File 'lib/stripe/params/financial_connections/session_create_params.rb', line 59

def accounts
  @accounts
end