Class: Stripe::FinancialConnections::SessionService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::FinancialConnections::SessionService
- Defined in:
- lib/stripe/services/financial_connections/session_service.rb
Defined Under Namespace
Classes: CreateParams, RetrieveParams
Instance Method Summary collapse
-
#create(params = {}, opts = {}) ⇒ Object
To launch the Financial Connections authorization flow, create a Session.
-
#retrieve(session, params = {}, opts = {}) ⇒ Object
Retrieves the details of a Financial Connections Session.
Methods inherited from StripeService
#initialize, #request, #request_stream
Constructor Details
This class inherits a constructor from Stripe::StripeService
Instance Method Details
#create(params = {}, opts = {}) ⇒ Object
To launch the Financial Connections authorization flow, create a Session. The session’s client_secret can be used to launch the flow using Stripe.js.
108 109 110 111 112 113 114 115 116 |
# File 'lib/stripe/services/financial_connections/session_service.rb', line 108 def create(params = {}, opts = {}) request( method: :post, path: "/v1/financial_connections/sessions", params: params, opts: opts, base_address: :api ) end |
#retrieve(session, params = {}, opts = {}) ⇒ Object
Retrieves the details of a Financial Connections Session
119 120 121 122 123 124 125 126 127 |
# File 'lib/stripe/services/financial_connections/session_service.rb', line 119 def retrieve(session, params = {}, opts = {}) request( method: :get, path: format("/v1/financial_connections/sessions/%<session>s", { session: CGI.escape(session) }), params: params, opts: opts, base_address: :api ) end |