Class: Stripe::FinancialConnections::SessionService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::FinancialConnections::SessionService::CreateParams
- Defined in:
- lib/stripe/services/financial_connections/session_service.rb
Defined Under Namespace
Classes: AccountHolder, Filters, Limits, ManualEntry
Instance Attribute Summary collapse
-
#account_holder ⇒ Object
The account holder to link accounts for.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#filters ⇒ Object
Filters to restrict the kinds of accounts to collect.
-
#limits ⇒ Object
Settings for configuring Session-specific limits.
-
#manual_entry ⇒ Object
Settings for configuring manual entry of account details for this Session.
-
#permissions ⇒ Object
List of data features that you would like to request access to.
-
#prefetch ⇒ Object
List of data features that you would like to retrieve upon account creation.
-
#return_url ⇒ Object
For webview integrations only.
Instance Method Summary collapse
-
#initialize(account_holder: nil, expand: nil, filters: nil, limits: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder: nil, expand: nil, filters: nil, limits: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/stripe/services/financial_connections/session_service.rb', line 94 def initialize( account_holder: nil, expand: nil, filters: nil, limits: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil ) @account_holder = account_holder @expand = @filters = filters @limits = limits @manual_entry = manual_entry @permissions = @prefetch = prefetch @return_url = return_url end |
Instance Attribute Details
#account_holder ⇒ Object
The account holder to link accounts for.
69 70 71 |
# File 'lib/stripe/services/financial_connections/session_service.rb', line 69 def account_holder @account_holder end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
72 73 74 |
# File 'lib/stripe/services/financial_connections/session_service.rb', line 72 def @expand end |
#filters ⇒ Object
Filters to restrict the kinds of accounts to collect.
75 76 77 |
# File 'lib/stripe/services/financial_connections/session_service.rb', line 75 def filters @filters end |
#limits ⇒ Object
Settings for configuring Session-specific limits.
78 79 80 |
# File 'lib/stripe/services/financial_connections/session_service.rb', line 78 def limits @limits end |
#manual_entry ⇒ Object
Settings for configuring manual entry of account details for this Session.
81 82 83 |
# File 'lib/stripe/services/financial_connections/session_service.rb', line 81 def manual_entry @manual_entry end |
#permissions ⇒ Object
List of data features that you would like to request access to.
Possible values are ‘balances`, `transactions`, `ownership`, and `payment_method`.
86 87 88 |
# File 'lib/stripe/services/financial_connections/session_service.rb', line 86 def @permissions end |
#prefetch ⇒ Object
List of data features that you would like to retrieve upon account creation.
89 90 91 |
# File 'lib/stripe/services/financial_connections/session_service.rb', line 89 def prefetch @prefetch end |
#return_url ⇒ Object
For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.
92 93 94 |
# File 'lib/stripe/services/financial_connections/session_service.rb', line 92 def return_url @return_url end |