Class: Stripe::FinancialConnections::SessionService::CreateParams::AccountHolder

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/financial_connections/session_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account: nil, customer: nil, type: nil) ⇒ AccountHolder

Returns a new instance of AccountHolder.



27
28
29
30
31
# File 'lib/stripe/services/financial_connections/session_service.rb', line 27

def initialize(account: nil, customer: nil, type: nil)
  @account = 
  @customer = customer
  @type = type
end

Instance Attribute Details

#accountObject

The ID of the Stripe account whose accounts will be retrieved. Should only be present if ‘type` is `account`.



19
20
21
# File 'lib/stripe/services/financial_connections/session_service.rb', line 19

def 
  @account
end

#customerObject

The ID of the Stripe customer whose accounts will be retrieved. Should only be present if ‘type` is `customer`.



22
23
24
# File 'lib/stripe/services/financial_connections/session_service.rb', line 22

def customer
  @customer
end

#typeObject

Type of account holder to collect accounts for.



25
26
27
# File 'lib/stripe/services/financial_connections/session_service.rb', line 25

def type
  @type
end