Class: Stripe::FinancialConnections::Transaction
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::FinancialConnections::Transaction
- Extended by:
- APIOperations::List
- Defined in:
- lib/stripe/resources/financial_connections/transaction.rb
Overview
A Transaction represents a real transaction that affects a Financial Connections Account balance.
Defined Under Namespace
Classes: Classification, Enrichments, StatusTransitions
Constant Summary collapse
- OBJECT_NAME =
"financial_connections.transaction"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account ⇒ Object
readonly
The ID of the Financial Connections Account this transaction belongs to.
-
#amount ⇒ Object
readonly
The amount of this transaction, in cents (or local equivalent).
-
#classifications ⇒ Object
readonly
Classification labels for this transaction, one entry per subscribed use case.
-
#currency ⇒ Object
readonly
Three-letter ISO currency code, in lowercase.
-
#description ⇒ Object
readonly
The description of this transaction.
-
#enrichments ⇒ Object
readonly
Enriched merchant information for this transaction.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
If the object exists in live mode, the value is
true. -
#object ⇒ Object
readonly
String representing the object's type.
-
#status ⇒ Object
readonly
The status of the transaction.
-
#status_transitions ⇒ Object
readonly
Attribute for field status_transitions.
-
#transacted_at ⇒ Object
readonly
Time at which the transaction was transacted.
-
#transaction_refresh ⇒ Object
readonly
The token of the transaction refresh that last updated or created this transaction.
-
#updated ⇒ Object
readonly
Time at which the object was last updated.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
-
.list(params = {}, opts = {}) ⇒ Object
Returns a list of Financial Connections Transaction objects.
- .object_name ⇒ Object
Methods included from APIOperations::List
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account ⇒ Object (readonly)
The ID of the Financial Connections Account this transaction belongs to.
107 108 109 |
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 107 def account @account end |
#amount ⇒ Object (readonly)
The amount of this transaction, in cents (or local equivalent).
109 110 111 |
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 109 def amount @amount end |
#classifications ⇒ Object (readonly)
Classification labels for this transaction, one entry per subscribed use case.
111 112 113 |
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 111 def classifications @classifications end |
#currency ⇒ Object (readonly)
Three-letter ISO currency code, in lowercase. Must be a supported currency.
113 114 115 |
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 113 def currency @currency end |
#description ⇒ Object (readonly)
The description of this transaction.
115 116 117 |
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 115 def description @description end |
#enrichments ⇒ Object (readonly)
Enriched merchant information for this transaction.
117 118 119 |
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 117 def enrichments @enrichments end |
#id ⇒ Object (readonly)
Unique identifier for the object.
119 120 121 |
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 119 def id @id end |
#livemode ⇒ Object (readonly)
If the object exists in live mode, the value is true. If the object exists in test mode, the value is false.
121 122 123 |
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 121 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object's type. Objects of the same type share the same value.
123 124 125 |
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 123 def object @object end |
#status ⇒ Object (readonly)
The status of the transaction.
125 126 127 |
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 125 def status @status end |
#status_transitions ⇒ Object (readonly)
Attribute for field status_transitions
127 128 129 |
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 127 def status_transitions @status_transitions end |
#transacted_at ⇒ Object (readonly)
Time at which the transaction was transacted. Measured in seconds since the Unix epoch.
129 130 131 |
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 129 def transacted_at @transacted_at end |
#transaction_refresh ⇒ Object (readonly)
The token of the transaction refresh that last updated or created this transaction.
131 132 133 |
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 131 def transaction_refresh @transaction_refresh end |
#updated ⇒ Object (readonly)
Time at which the object was last updated. Measured in seconds since the Unix epoch.
133 134 135 |
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 133 def updated @updated end |
Class Method Details
.field_remappings ⇒ Object
153 154 155 |
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 153 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
145 146 147 148 149 150 151 |
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 145 def self.inner_class_types @inner_class_types = { classifications: Classification, enrichments: Enrichments, status_transitions: StatusTransitions, } end |
.list(params = {}, opts = {}) ⇒ Object
Returns a list of Financial Connections Transaction objects.
136 137 138 139 140 141 142 143 |
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 136 def self.list(params = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/financial_connections/transactions", params: params, opts: opts ) end |
.object_name ⇒ Object
11 12 13 |
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 11 def self.object_name "financial_connections.transaction" end |