Class: Stripe::FinancialConnections::Transaction::ListParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/financial_connections/transaction.rb

Defined Under Namespace

Classes: TransactedAt, TransactionRefresh

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, transacted_at: nil, transaction_refresh: nil) ⇒ ListParams

Returns a new instance of ListParams.



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 72

def initialize(
  account: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  starting_after: nil,
  transacted_at: nil,
  transaction_refresh: nil
)
  @account = 
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
  @transacted_at = transacted_at
  @transaction_refresh = transaction_refresh
end

Instance Attribute Details

#accountObject

The ID of the Financial Connections Account whose transactions will be retrieved.



58
59
60
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 58

def 
  @account
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



60
61
62
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 60

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



62
63
64
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 62

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



64
65
66
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 64

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



66
67
68
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 66

def starting_after
  @starting_after
end

#transacted_atObject

A filter on the list based on the object ‘transacted_at` field. The value can be a string with an integer Unix timestamp, or it can be a dictionary with the following options:



68
69
70
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 68

def transacted_at
  @transacted_at
end

#transaction_refreshObject

A filter on the list based on the object ‘transaction_refresh` field. The value can be a dictionary with the following options:



70
71
72
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 70

def transaction_refresh
  @transaction_refresh
end