Class: Stripe::FinancialConnections::Transaction::ListParams::TransactionRefresh

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/financial_connections/transaction.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(after: nil) ⇒ TransactionRefresh

Returns a new instance of TransactionRefresh.



53
54
55
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 53

def initialize(after: nil)
  @after = after
end

Instance Attribute Details

#afterObject

Return results where the transactions were created or updated by a refresh that took place after this refresh (non-inclusive).



51
52
53
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 51

def after
  @after
end