Class: Stripe::FinancialConnections::TransactionService::ListParams::TransactionRefresh

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/financial_connections/transaction_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(after: nil) ⇒ TransactionRefresh

Returns a new instance of TransactionRefresh.



33
34
35
# File 'lib/stripe/services/financial_connections/transaction_service.rb', line 33

def initialize(after: nil)
  @after = after
end

Instance Attribute Details

#afterObject

Return results where the transactions were created or updated by a refresh that took place after this refresh (non-inclusive).



31
32
33
# File 'lib/stripe/services/financial_connections/transaction_service.rb', line 31

def after
  @after
end