Class: Stripe::Forwarding::Request::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/forwarding/request.rb

Defined Under Namespace

Classes: Request

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, metadata: nil, payment_method: nil, replacements: nil, request: nil, url: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/stripe/resources/forwarding/request.rb', line 188

def initialize(
  expand: nil,
  metadata: nil,
  payment_method: nil,
  replacements: nil,
  request: nil,
  url: nil
)
  @expand = expand
  @metadata = 
  @payment_method = payment_method
  @replacements = replacements
  @request = request
  @url = url
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



176
177
178
# File 'lib/stripe/resources/forwarding/request.rb', line 176

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



178
179
180
# File 'lib/stripe/resources/forwarding/request.rb', line 178

def 
  @metadata
end

#payment_methodObject

The PaymentMethod to insert into the forwarded request. Forwarding previously consumed PaymentMethods is allowed.



180
181
182
# File 'lib/stripe/resources/forwarding/request.rb', line 180

def payment_method
  @payment_method
end

#replacementsObject

The field kinds to be replaced in the forwarded request.



182
183
184
# File 'lib/stripe/resources/forwarding/request.rb', line 182

def replacements
  @replacements
end

#requestObject

The request body and headers to be sent to the destination endpoint.



184
185
186
# File 'lib/stripe/resources/forwarding/request.rb', line 184

def request
  @request
end

#urlObject

The destination URL for the forwarded request. Must be supported by the config.



186
187
188
# File 'lib/stripe/resources/forwarding/request.rb', line 186

def url
  @url
end