Class: Stripe::Forwarding::Request::CreateParams::Request
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Forwarding::Request::CreateParams::Request
- Defined in:
- lib/stripe/resources/forwarding/request.rb
Defined Under Namespace
Classes: Header
Instance Attribute Summary collapse
-
#body ⇒ Object
The body payload to send to the destination endpoint.
-
#headers ⇒ Object
The headers to include in the forwarded request.
Instance Method Summary collapse
-
#initialize(body: nil, headers: nil) ⇒ Request
constructor
A new instance of Request.
Methods inherited from RequestParams
Constructor Details
#initialize(body: nil, headers: nil) ⇒ Request
Returns a new instance of Request.
170 171 172 173 |
# File 'lib/stripe/resources/forwarding/request.rb', line 170 def initialize(body: nil, headers: nil) @body = body @headers = headers end |
Instance Attribute Details
#body ⇒ Object
The body payload to send to the destination endpoint.
166 167 168 |
# File 'lib/stripe/resources/forwarding/request.rb', line 166 def body @body end |
#headers ⇒ Object
The headers to include in the forwarded request. Can be omitted if no additional headers (excluding Stripe-generated ones such as the Content-Type header) should be included.
168 169 170 |
# File 'lib/stripe/resources/forwarding/request.rb', line 168 def headers @headers end |