Class: Stripe::Forwarding::Request::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/forwarding/request.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/stripe/resources/forwarding/request.rb', line 137

def initialize(
  created: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  starting_after: nil
)
  @created = created
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
end

Instance Attribute Details

#createdObject

Similar to other List endpoints, filters results based on created timestamp. You can pass gt, gte, lt, and lte timestamp values.



127
128
129
# File 'lib/stripe/resources/forwarding/request.rb', line 127

def created
  @created
end

#ending_beforeObject

A pagination cursor to fetch the previous page of the list. The value must be a ForwardingRequest ID.



129
130
131
# File 'lib/stripe/resources/forwarding/request.rb', line 129

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



131
132
133
# File 'lib/stripe/resources/forwarding/request.rb', line 131

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



133
134
135
# File 'lib/stripe/resources/forwarding/request.rb', line 133

def limit
  @limit
end

#starting_afterObject

A pagination cursor to fetch the next page of the list. The value must be a ForwardingRequest ID.



135
136
137
# File 'lib/stripe/resources/forwarding/request.rb', line 135

def starting_after
  @starting_after
end