Class: Stripe::Forwarding::Request::ListParams::Created
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Forwarding::Request::ListParams::Created
- Defined in:
- lib/stripe/resources/forwarding/request.rb
Instance Attribute Summary collapse
-
#gt ⇒ Object
Return results where the ‘created` field is greater than this value.
-
#gte ⇒ Object
Return results where the ‘created` field is greater than or equal to this value.
-
#lt ⇒ Object
Return results where the ‘created` field is less than this value.
-
#lte ⇒ Object
Return results where the ‘created` field is less than or equal to this value.
Instance Method Summary collapse
-
#initialize(gt: nil, gte: nil, lt: nil, lte: nil) ⇒ Created
constructor
A new instance of Created.
Methods inherited from RequestParams
Constructor Details
#initialize(gt: nil, gte: nil, lt: nil, lte: nil) ⇒ Created
Returns a new instance of Created.
119 120 121 122 123 124 |
# File 'lib/stripe/resources/forwarding/request.rb', line 119 def initialize(gt: nil, gte: nil, lt: nil, lte: nil) @gt = gt @gte = gte @lt = lt @lte = lte end |
Instance Attribute Details
#gt ⇒ Object
Return results where the ‘created` field is greater than this value.
111 112 113 |
# File 'lib/stripe/resources/forwarding/request.rb', line 111 def gt @gt end |
#gte ⇒ Object
Return results where the ‘created` field is greater than or equal to this value.
113 114 115 |
# File 'lib/stripe/resources/forwarding/request.rb', line 113 def gte @gte end |
#lt ⇒ Object
Return results where the ‘created` field is less than this value.
115 116 117 |
# File 'lib/stripe/resources/forwarding/request.rb', line 115 def lt @lt end |
#lte ⇒ Object
Return results where the ‘created` field is less than or equal to this value.
117 118 119 |
# File 'lib/stripe/resources/forwarding/request.rb', line 117 def lte @lte end |