Class: Stripe::Forwarding::Request::ResponseDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Forwarding::Request::ResponseDetails
- Defined in:
- lib/stripe/resources/forwarding/request.rb
Defined Under Namespace
Classes: Header
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#body ⇒ Object
readonly
The response body from the destination endpoint to Stripe.
-
#headers ⇒ Object
readonly
HTTP headers that the destination endpoint returned.
-
#status ⇒ Object
readonly
The HTTP status code that the destination endpoint returned.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#body ⇒ Object (readonly)
The response body from the destination endpoint to Stripe.
61 62 63 |
# File 'lib/stripe/resources/forwarding/request.rb', line 61 def body @body end |
#headers ⇒ Object (readonly)
HTTP headers that the destination endpoint returned.
63 64 65 |
# File 'lib/stripe/resources/forwarding/request.rb', line 63 def headers @headers end |
#status ⇒ Object (readonly)
The HTTP status code that the destination endpoint returned.
65 66 67 |
# File 'lib/stripe/resources/forwarding/request.rb', line 65 def status @status end |