Class: Stripe::Forwarding::Request::RetrieveParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Forwarding::Request::RetrieveParams
- Defined in:
- lib/stripe/resources/forwarding/request.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ RetrieveParams
constructor
A new instance of RetrieveParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ RetrieveParams
Returns a new instance of RetrieveParams.
169 170 171 |
# File 'lib/stripe/resources/forwarding/request.rb', line 169 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
167 168 169 |
# File 'lib/stripe/resources/forwarding/request.rb', line 167 def @expand end |