Class: Stripe::Forwarding::RequestService::ListParams::Created
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Forwarding::RequestService::ListParams::Created
- Defined in:
- lib/stripe/services/forwarding/request_service.rb
Instance Attribute Summary collapse
-
#gt ⇒ Object
Return results where the ‘created` field is greater than this value.
-
#gte ⇒ Object
Return results where the ‘created` field is greater than or equal to this value.
-
#lt ⇒ Object
Return results where the ‘created` field is less than this value.
-
#lte ⇒ Object
Return results where the ‘created` field is less than or equal to this value.
Instance Method Summary collapse
-
#initialize(gt: nil, gte: nil, lt: nil, lte: nil) ⇒ Created
constructor
A new instance of Created.
Methods inherited from RequestParams
Constructor Details
#initialize(gt: nil, gte: nil, lt: nil, lte: nil) ⇒ Created
Returns a new instance of Created.
18 19 20 21 22 23 |
# File 'lib/stripe/services/forwarding/request_service.rb', line 18 def initialize(gt: nil, gte: nil, lt: nil, lte: nil) @gt = gt @gte = gte @lt = lt @lte = lte end |
Instance Attribute Details
#gt ⇒ Object
Return results where the ‘created` field is greater than this value.
10 11 12 |
# File 'lib/stripe/services/forwarding/request_service.rb', line 10 def gt @gt end |
#gte ⇒ Object
Return results where the ‘created` field is greater than or equal to this value.
12 13 14 |
# File 'lib/stripe/services/forwarding/request_service.rb', line 12 def gte @gte end |
#lt ⇒ Object
Return results where the ‘created` field is less than this value.
14 15 16 |
# File 'lib/stripe/services/forwarding/request_service.rb', line 14 def lt @lt end |
#lte ⇒ Object
Return results where the ‘created` field is less than or equal to this value.
16 17 18 |
# File 'lib/stripe/services/forwarding/request_service.rb', line 16 def lte @lte end |