Class: Stripe::FrMealVouchersOnboardingCreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/fr_meal_vouchers_onboarding_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(expand: nil, metadata: nil, name: nil, postal_code: nil, siret: nil) ⇒ FrMealVouchersOnboardingCreateParams

Returns a new instance of FrMealVouchersOnboardingCreateParams.



17
18
19
20
21
22
23
# File 'lib/stripe/params/fr_meal_vouchers_onboarding_create_params.rb', line 17

def initialize(expand: nil, metadata: nil, name: nil, postal_code: nil, siret: nil)
  @expand = expand
  @metadata = 
  @name = name
  @postal_code = postal_code
  @siret = siret
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



7
8
9
# File 'lib/stripe/params/fr_meal_vouchers_onboarding_create_params.rb', line 7

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`. This cannot be changed after creation of this object.



9
10
11
# File 'lib/stripe/params/fr_meal_vouchers_onboarding_create_params.rb', line 9

def 
  @metadata
end

#nameObject

Name of the restaurant. This cannot be changed after creation of this object.



11
12
13
# File 'lib/stripe/params/fr_meal_vouchers_onboarding_create_params.rb', line 11

def name
  @name
end

#postal_codeObject

Postal code of the restaurant.



13
14
15
# File 'lib/stripe/params/fr_meal_vouchers_onboarding_create_params.rb', line 13

def postal_code
  @postal_code
end

#siretObject

SIRET number associated with the restaurant. This cannot be changed after creation of this object.



15
16
17
# File 'lib/stripe/params/fr_meal_vouchers_onboarding_create_params.rb', line 15

def siret
  @siret
end