Class: Stripe::FundingInstructions::BankTransfer::FinancialAddress::SortCode
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::FundingInstructions::BankTransfer::FinancialAddress::SortCode
- Defined in:
- lib/stripe/resources/funding_instructions.rb
Defined Under Namespace
Classes: AccountHolderAddress, BankAddress
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_holder_address ⇒ Object
readonly
Attribute for field account_holder_address.
-
#account_holder_name ⇒ Object
readonly
The name of the person or business that owns the bank account.
-
#account_number ⇒ Object
readonly
The account number.
-
#bank_address ⇒ Object
readonly
Attribute for field bank_address.
-
#sort_code ⇒ Object
readonly
The six-digit sort code.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_holder_address ⇒ Object (readonly)
Attribute for field account_holder_address
139 140 141 |
# File 'lib/stripe/resources/funding_instructions.rb', line 139 def account_holder_address @account_holder_address end |
#account_holder_name ⇒ Object (readonly)
The name of the person or business that owns the bank account
141 142 143 |
# File 'lib/stripe/resources/funding_instructions.rb', line 141 def account_holder_name @account_holder_name end |
#account_number ⇒ Object (readonly)
The account number
143 144 145 |
# File 'lib/stripe/resources/funding_instructions.rb', line 143 def account_number @account_number end |
#bank_address ⇒ Object (readonly)
Attribute for field bank_address
145 146 147 |
# File 'lib/stripe/resources/funding_instructions.rb', line 145 def bank_address @bank_address end |
#sort_code ⇒ Object (readonly)
The six-digit sort code
147 148 149 |
# File 'lib/stripe/resources/funding_instructions.rb', line 147 def sort_code @sort_code end |