Class: Stripe::FxQuote::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/fx_quote.rb

Defined Under Namespace

Classes: Usage

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, from_currencies: nil, lock_duration: nil, to_currency: nil, usage: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



179
180
181
182
183
184
185
186
187
188
189
190
191
# File 'lib/stripe/resources/fx_quote.rb', line 179

def initialize(
  expand: nil,
  from_currencies: nil,
  lock_duration: nil,
  to_currency: nil,
  usage: nil
)
  @expand = expand
  @from_currencies = from_currencies
  @lock_duration = lock_duration
  @to_currency = to_currency
  @usage = usage
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



169
170
171
# File 'lib/stripe/resources/fx_quote.rb', line 169

def expand
  @expand
end

#from_currenciesObject

A list of three letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be [supported currencies](stripe.com/docs/currencies).



171
172
173
# File 'lib/stripe/resources/fx_quote.rb', line 171

def from_currencies
  @from_currencies
end

#lock_durationObject

The duration that you wish the quote to be locked for. The quote will be usable for the duration specified. The default is ‘none`. The maximum is 1 day.



173
174
175
# File 'lib/stripe/resources/fx_quote.rb', line 173

def lock_duration
  @lock_duration
end

#to_currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



175
176
177
# File 'lib/stripe/resources/fx_quote.rb', line 175

def to_currency
  @to_currency
end

#usageObject

The usage specific information for the quote.



177
178
179
# File 'lib/stripe/resources/fx_quote.rb', line 177

def usage
  @usage
end