Class: Stripe::FxQuote::CreateParams::Usage

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/fx_quote.rb

Defined Under Namespace

Classes: Payment, Transfer

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(payment: nil, transfer: nil, type: nil) ⇒ Usage

Returns a new instance of Usage.



162
163
164
165
166
# File 'lib/stripe/resources/fx_quote.rb', line 162

def initialize(payment: nil, transfer: nil, type: nil)
  @payment = payment
  @transfer = transfer
  @type = type
end

Instance Attribute Details

#paymentObject

The payment transaction details that are intended for the FX Quote.



154
155
156
# File 'lib/stripe/resources/fx_quote.rb', line 154

def payment
  @payment
end

#transferObject

The transfer transaction details that are intended for the FX Quote.



156
157
158
# File 'lib/stripe/resources/fx_quote.rb', line 156

def transfer
  @transfer
end

#typeObject

Which transaction the FX Quote will be used for

Can be “payment” | “transfer”



160
161
162
# File 'lib/stripe/resources/fx_quote.rb', line 160

def type
  @type
end