Class: Stripe::FxQuote::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/fx_quote.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



75
76
77
78
79
80
# File 'lib/stripe/resources/fx_quote.rb', line 75

def initialize(ending_before: nil, expand: nil, limit: nil, starting_after: nil)
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
end

Instance Attribute Details

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



67
68
69
# File 'lib/stripe/resources/fx_quote.rb', line 67

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



69
70
71
# File 'lib/stripe/resources/fx_quote.rb', line 69

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



71
72
73
# File 'lib/stripe/resources/fx_quote.rb', line 71

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



73
74
75
# File 'lib/stripe/resources/fx_quote.rb', line 73

def starting_after
  @starting_after
end