Class: Stripe::FxQuote::Rates::RateDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::FxQuote::Rates::RateDetails
- Defined in:
- lib/stripe/resources/fx_quote.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#base_rate ⇒ Object
readonly
The rate for the currency pair.
-
#duration_premium ⇒ Object
readonly
The fee for locking the conversion rates.
-
#fx_fee_rate ⇒ Object
readonly
The FX fee for the currency pair.
-
#reference_rate ⇒ Object
readonly
A reference rate for the currency pair provided by the reference rate provider.
-
#reference_rate_provider ⇒ Object
readonly
The reference rate provider.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#base_rate ⇒ Object (readonly)
The rate for the currency pair.
23 24 25 |
# File 'lib/stripe/resources/fx_quote.rb', line 23 def base_rate @base_rate end |
#duration_premium ⇒ Object (readonly)
The fee for locking the conversion rates.
25 26 27 |
# File 'lib/stripe/resources/fx_quote.rb', line 25 def duration_premium @duration_premium end |
#fx_fee_rate ⇒ Object (readonly)
The FX fee for the currency pair.
27 28 29 |
# File 'lib/stripe/resources/fx_quote.rb', line 27 def fx_fee_rate @fx_fee_rate end |
#reference_rate ⇒ Object (readonly)
A reference rate for the currency pair provided by the reference rate provider.
29 30 31 |
# File 'lib/stripe/resources/fx_quote.rb', line 29 def reference_rate @reference_rate end |
#reference_rate_provider ⇒ Object (readonly)
The reference rate provider.
31 32 33 |
# File 'lib/stripe/resources/fx_quote.rb', line 31 def reference_rate_provider @reference_rate_provider end |
Class Method Details
.field_remappings ⇒ Object
37 38 39 |
# File 'lib/stripe/resources/fx_quote.rb', line 37 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
33 34 35 |
# File 'lib/stripe/resources/fx_quote.rb', line 33 def self.inner_class_types @inner_class_types = {} end |