Class: Stripe::FxQuoteCreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/fx_quote_create_params.rb

Defined Under Namespace

Classes: Usage

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(expand: nil, from_currencies: nil, lock_duration: nil, to_currency: nil, usage: nil) ⇒ FxQuoteCreateParams

Returns a new instance of FxQuoteCreateParams.



59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/stripe/params/fx_quote_create_params.rb', line 59

def initialize(
  expand: nil,
  from_currencies: nil,
  lock_duration: nil,
  to_currency: nil,
  usage: nil
)
  @expand = expand
  @from_currencies = from_currencies
  @lock_duration = lock_duration
  @to_currency = to_currency
  @usage = usage
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



49
50
51
# File 'lib/stripe/params/fx_quote_create_params.rb', line 49

def expand
  @expand
end

#from_currenciesObject

A list of three letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be [supported currencies](stripe.com/docs/currencies).



51
52
53
# File 'lib/stripe/params/fx_quote_create_params.rb', line 51

def from_currencies
  @from_currencies
end

#lock_durationObject

The duration that you wish the quote to be locked for. The quote will be usable for the duration specified. The default is ‘none`. The maximum is 1 day.



53
54
55
# File 'lib/stripe/params/fx_quote_create_params.rb', line 53

def lock_duration
  @lock_duration
end

#to_currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



55
56
57
# File 'lib/stripe/params/fx_quote_create_params.rb', line 55

def to_currency
  @to_currency
end

#usageObject

The usage specific information for the quote.



57
58
59
# File 'lib/stripe/params/fx_quote_create_params.rb', line 57

def usage
  @usage
end