Class: Stripe::FxQuoteCreateParams::Usage

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/fx_quote_create_params.rb

Defined Under Namespace

Classes: Payment, Transfer

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(payment: nil, transfer: nil, type: nil) ⇒ Usage

Returns a new instance of Usage.



42
43
44
45
46
# File 'lib/stripe/params/fx_quote_create_params.rb', line 42

def initialize(payment: nil, transfer: nil, type: nil)
  @payment = payment
  @transfer = transfer
  @type = type
end

Instance Attribute Details

#paymentObject

The payment transaction details that are intended for the FX Quote.



34
35
36
# File 'lib/stripe/params/fx_quote_create_params.rb', line 34

def payment
  @payment
end

#transferObject

The transfer transaction details that are intended for the FX Quote.



36
37
38
# File 'lib/stripe/params/fx_quote_create_params.rb', line 36

def transfer
  @transfer
end

#typeObject

Which transaction the FX Quote will be used for

Can be “payment” | “transfer”



40
41
42
# File 'lib/stripe/params/fx_quote_create_params.rb', line 40

def type
  @type
end