Class: Stripe::FxQuoteService::CreateParams::Usage
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::FxQuoteService::CreateParams::Usage
- Defined in:
- lib/stripe/services/fx_quote_service.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#payment ⇒ Object
The payment transaction details that are intended for the FX Quote.
-
#transfer ⇒ Object
The transfer transaction details that are intended for the FX Quote.
-
#type ⇒ Object
Which transaction the FX Quote will be used for.
Instance Method Summary collapse
-
#initialize(payment: nil, transfer: nil, type: nil) ⇒ Usage
constructor
A new instance of Usage.
Methods inherited from RequestParams
Constructor Details
#initialize(payment: nil, transfer: nil, type: nil) ⇒ Usage
Returns a new instance of Usage.
61 62 63 64 65 |
# File 'lib/stripe/services/fx_quote_service.rb', line 61 def initialize(payment: nil, transfer: nil, type: nil) @payment = payment @transfer = transfer @type = type end |
Instance Attribute Details
#payment ⇒ Object
The payment transaction details that are intended for the FX Quote.
53 54 55 |
# File 'lib/stripe/services/fx_quote_service.rb', line 53 def payment @payment end |
#transfer ⇒ Object
The transfer transaction details that are intended for the FX Quote.
55 56 57 |
# File 'lib/stripe/services/fx_quote_service.rb', line 55 def transfer @transfer end |
#type ⇒ Object
Which transaction the FX Quote will be used for
Can be “payment” | “transfer”
59 60 61 |
# File 'lib/stripe/services/fx_quote_service.rb', line 59 def type @type end |