Class: Stripe::GiftCardActivateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/gift_card_activate_params.rb

Defined Under Namespace

Classes: Balance

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(balance: nil, expand: nil, on_behalf_of: nil) ⇒ GiftCardActivateParams

Returns a new instance of GiftCardActivateParams.



24
25
26
27
28
# File 'lib/stripe/params/gift_card_activate_params.rb', line 24

def initialize(balance: nil, expand: nil, on_behalf_of: nil)
  @balance = balance
  @expand = expand
  @on_behalf_of = on_behalf_of
end

Instance Attribute Details

#balanceObject

The initial balance to set on the gift card.



18
19
20
# File 'lib/stripe/params/gift_card_activate_params.rb', line 18

def balance
  @balance
end

#expandObject

Specifies which fields in the response should be expanded.



20
21
22
# File 'lib/stripe/params/gift_card_activate_params.rb', line 20

def expand
  @expand
end

#on_behalf_ofObject

The Stripe account ID to process the gift card operation on behalf of.



22
23
24
# File 'lib/stripe/params/gift_card_activate_params.rb', line 22

def on_behalf_of
  @on_behalf_of
end