Class: Stripe::GiftCardCheckBalanceParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::GiftCardCheckBalanceParams
- Defined in:
- lib/stripe/params/gift_card_check_balance_params.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#on_behalf_of ⇒ Object
The Stripe account ID to process the gift card operation on behalf of.
Instance Method Summary collapse
-
#initialize(expand: nil, on_behalf_of: nil) ⇒ GiftCardCheckBalanceParams
constructor
A new instance of GiftCardCheckBalanceParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(expand: nil, on_behalf_of: nil) ⇒ GiftCardCheckBalanceParams
Returns a new instance of GiftCardCheckBalanceParams.
11 12 13 14 |
# File 'lib/stripe/params/gift_card_check_balance_params.rb', line 11 def initialize(expand: nil, on_behalf_of: nil) @expand = @on_behalf_of = on_behalf_of end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
7 8 9 |
# File 'lib/stripe/params/gift_card_check_balance_params.rb', line 7 def @expand end |
#on_behalf_of ⇒ Object
The Stripe account ID to process the gift card operation on behalf of.
9 10 11 |
# File 'lib/stripe/params/gift_card_check_balance_params.rb', line 9 def on_behalf_of @on_behalf_of end |