Class: Stripe::GiftCardCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::GiftCardCreateParams
- Defined in:
- lib/stripe/params/gift_card_create_params.rb
Instance Attribute Summary collapse
-
#brand ⇒ Object
The brand of the gift card.
-
#exp_month ⇒ Object
Two-digit number representing the gift card's expiration month.
-
#exp_year ⇒ Object
Four-digit number representing the gift card's expiration year.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#number ⇒ Object
The gift card number.
-
#pin ⇒ Object
The gift card PIN.
Instance Method Summary collapse
-
#initialize(brand: nil, exp_month: nil, exp_year: nil, expand: nil, number: nil, pin: nil) ⇒ GiftCardCreateParams
constructor
A new instance of GiftCardCreateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(brand: nil, exp_month: nil, exp_year: nil, expand: nil, number: nil, pin: nil) ⇒ GiftCardCreateParams
Returns a new instance of GiftCardCreateParams.
19 20 21 22 23 24 25 26 |
# File 'lib/stripe/params/gift_card_create_params.rb', line 19 def initialize(brand: nil, exp_month: nil, exp_year: nil, expand: nil, number: nil, pin: nil) @brand = brand @exp_month = exp_month @exp_year = exp_year @expand = @number = number @pin = pin end |
Instance Attribute Details
#brand ⇒ Object
The brand of the gift card.
7 8 9 |
# File 'lib/stripe/params/gift_card_create_params.rb', line 7 def brand @brand end |
#exp_month ⇒ Object
Two-digit number representing the gift card's expiration month.
9 10 11 |
# File 'lib/stripe/params/gift_card_create_params.rb', line 9 def exp_month @exp_month end |
#exp_year ⇒ Object
Four-digit number representing the gift card's expiration year.
11 12 13 |
# File 'lib/stripe/params/gift_card_create_params.rb', line 11 def exp_year @exp_year end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
13 14 15 |
# File 'lib/stripe/params/gift_card_create_params.rb', line 13 def @expand end |
#number ⇒ Object
The gift card number.
15 16 17 |
# File 'lib/stripe/params/gift_card_create_params.rb', line 15 def number @number end |
#pin ⇒ Object
The gift card PIN.
17 18 19 |
# File 'lib/stripe/params/gift_card_create_params.rb', line 17 def pin @pin end |