Class: Stripe::GiftCardOperation::CashoutVoid
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::GiftCardOperation::CashoutVoid
- Defined in:
- lib/stripe/resources/gift_card_operation.rb
Defined Under Namespace
Classes: Balance
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#balance ⇒ Object
readonly
The balance amount of a gift card, including currency and amount.
-
#voided_operation ⇒ Object
readonly
The operation that was voided.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#balance ⇒ Object (readonly)
The balance amount of a gift card, including currency and amount.
140 141 142 |
# File 'lib/stripe/resources/gift_card_operation.rb', line 140 def balance @balance end |
#voided_operation ⇒ Object (readonly)
The operation that was voided.
142 143 144 |
# File 'lib/stripe/resources/gift_card_operation.rb', line 142 def voided_operation @voided_operation end |
Class Method Details
.field_remappings ⇒ Object
148 149 150 |
# File 'lib/stripe/resources/gift_card_operation.rb', line 148 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
144 145 146 |
# File 'lib/stripe/resources/gift_card_operation.rb', line 144 def self.inner_class_types @inner_class_types = { balance: Balance } end |