Class: Stripe::GiftCardVoidOperationParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::GiftCardVoidOperationParams
- Defined in:
- lib/stripe/params/gift_card_void_operation_params.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#on_behalf_of ⇒ Object
The Stripe account ID to process the gift card operation on behalf of.
-
#operation ⇒ Object
The ID of the gift card operation to void.
Instance Method Summary collapse
-
#initialize(expand: nil, on_behalf_of: nil, operation: nil) ⇒ GiftCardVoidOperationParams
constructor
A new instance of GiftCardVoidOperationParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(expand: nil, on_behalf_of: nil, operation: nil) ⇒ GiftCardVoidOperationParams
Returns a new instance of GiftCardVoidOperationParams.
13 14 15 16 17 |
# File 'lib/stripe/params/gift_card_void_operation_params.rb', line 13 def initialize(expand: nil, on_behalf_of: nil, operation: nil) @expand = @on_behalf_of = on_behalf_of @operation = operation end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
7 8 9 |
# File 'lib/stripe/params/gift_card_void_operation_params.rb', line 7 def @expand end |
#on_behalf_of ⇒ Object
The Stripe account ID to process the gift card operation on behalf of.
9 10 11 |
# File 'lib/stripe/params/gift_card_void_operation_params.rb', line 9 def on_behalf_of @on_behalf_of end |
#operation ⇒ Object
The ID of the gift card operation to void.
11 12 13 |
# File 'lib/stripe/params/gift_card_void_operation_params.rb', line 11 def operation @operation end |