Class: Stripe::GiftCards::Card::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/gift_cards/card.rb

Defined Under Namespace

Classes: CreatedBy

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(active: nil, created_by: nil, currency: nil, expand: nil, initial_amount: nil, metadata: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/stripe/resources/gift_cards/card.rb', line 98

def initialize(
  active: nil,
  created_by: nil,
  currency: nil,
  expand: nil,
  initial_amount: nil,
  metadata: nil
)
  @active = active
  @created_by = created_by
  @currency = currency
  @expand = expand
  @initial_amount = initial_amount
  @metadata = 
end

Instance Attribute Details

#activeObject

The active state for the new gift card, defaults to false. The active state can be updated after creation.



86
87
88
# File 'lib/stripe/resources/gift_cards/card.rb', line 86

def active
  @active
end

#created_byObject

Related objects which created this gift card.



88
89
90
# File 'lib/stripe/resources/gift_cards/card.rb', line 88

def created_by
  @created_by
end

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



90
91
92
# File 'lib/stripe/resources/gift_cards/card.rb', line 90

def currency
  @currency
end

#expandObject

Specifies which fields in the response should be expanded.



92
93
94
# File 'lib/stripe/resources/gift_cards/card.rb', line 92

def expand
  @expand
end

#initial_amountObject

The initial amount to load onto the new gift card, defaults to 0.



94
95
96
# File 'lib/stripe/resources/gift_cards/card.rb', line 94

def initial_amount
  @initial_amount
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



96
97
98
# File 'lib/stripe/resources/gift_cards/card.rb', line 96

def 
  @metadata
end