Class: Stripe::GiftCards::Card::CreateParams::CreatedBy
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::GiftCards::Card::CreateParams::CreatedBy
- Defined in:
- lib/stripe/resources/gift_cards/card.rb
Defined Under Namespace
Classes: Payment
Instance Attribute Summary collapse
-
#payment ⇒ Object
The details for the payment that created this object.
-
#type ⇒ Object
The type of event that created this object.
Instance Method Summary collapse
-
#initialize(payment: nil, type: nil) ⇒ CreatedBy
constructor
A new instance of CreatedBy.
Methods inherited from RequestParams
Constructor Details
#initialize(payment: nil, type: nil) ⇒ CreatedBy
Returns a new instance of CreatedBy.
89 90 91 92 |
# File 'lib/stripe/resources/gift_cards/card.rb', line 89 def initialize(payment: nil, type: nil) @payment = payment @type = type end |
Instance Attribute Details
#payment ⇒ Object
The details for the payment that created this object.
84 85 86 |
# File 'lib/stripe/resources/gift_cards/card.rb', line 84 def payment @payment end |
#type ⇒ Object
The type of event that created this object.
87 88 89 |
# File 'lib/stripe/resources/gift_cards/card.rb', line 87 def type @type end |