Class: Stripe::GiftCards::Card::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/gift_cards/card.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



65
66
67
68
69
70
# File 'lib/stripe/resources/gift_cards/card.rb', line 65

def initialize(ending_before: nil, expand: nil, limit: nil, starting_after: nil)
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
end

Instance Attribute Details

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



54
55
56
# File 'lib/stripe/resources/gift_cards/card.rb', line 54

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



57
58
59
# File 'lib/stripe/resources/gift_cards/card.rb', line 57

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



60
61
62
# File 'lib/stripe/resources/gift_cards/card.rb', line 60

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



63
64
65
# File 'lib/stripe/resources/gift_cards/card.rb', line 63

def starting_after
  @starting_after
end