Class: Stripe::GiftCards::CardService::CreateParams::CreatedBy
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::GiftCards::CardService::CreateParams::CreatedBy
- Defined in:
- lib/stripe/services/gift_cards/card_service.rb
Defined Under Namespace
Classes: Payment
Instance Attribute Summary collapse
-
#payment ⇒ Object
The details for the payment that created this object.
-
#type ⇒ Object
The type of event that created this object.
Instance Method Summary collapse
-
#initialize(payment: nil, type: nil) ⇒ CreatedBy
constructor
A new instance of CreatedBy.
Methods inherited from RequestParams
Constructor Details
#initialize(payment: nil, type: nil) ⇒ CreatedBy
Returns a new instance of CreatedBy.
44 45 46 47 |
# File 'lib/stripe/services/gift_cards/card_service.rb', line 44 def initialize(payment: nil, type: nil) @payment = payment @type = type end |
Instance Attribute Details
#payment ⇒ Object
The details for the payment that created this object.
39 40 41 |
# File 'lib/stripe/services/gift_cards/card_service.rb', line 39 def payment @payment end |
#type ⇒ Object
The type of event that created this object.
42 43 44 |
# File 'lib/stripe/services/gift_cards/card_service.rb', line 42 def type @type end |