Class: Stripe::GiftCards::CardService::ValidateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::GiftCards::CardService::ValidateParams
- Defined in:
- lib/stripe/services/gift_cards/card_service.rb
Instance Attribute Summary collapse
-
#code ⇒ Object
The gift card code to be validated.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#giftcard_pin ⇒ Object
The pin associated with the gift card.
Instance Method Summary collapse
-
#initialize(code: nil, expand: nil, giftcard_pin: nil) ⇒ ValidateParams
constructor
A new instance of ValidateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(code: nil, expand: nil, giftcard_pin: nil) ⇒ ValidateParams
Returns a new instance of ValidateParams.
120 121 122 123 124 |
# File 'lib/stripe/services/gift_cards/card_service.rb', line 120 def initialize(code: nil, expand: nil, giftcard_pin: nil) @code = code @expand = @giftcard_pin = giftcard_pin end |
Instance Attribute Details
#code ⇒ Object
The gift card code to be validated.
112 113 114 |
# File 'lib/stripe/services/gift_cards/card_service.rb', line 112 def code @code end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
115 116 117 |
# File 'lib/stripe/services/gift_cards/card_service.rb', line 115 def @expand end |
#giftcard_pin ⇒ Object
The pin associated with the gift card. Not all gift cards have pins.
118 119 120 |
# File 'lib/stripe/services/gift_cards/card_service.rb', line 118 def giftcard_pin @giftcard_pin end |