Class: Stripe::GiftCards::Transaction::CancelParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::GiftCards::Transaction::CancelParams
- Defined in:
- lib/stripe/resources/gift_cards/transaction.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ CancelParams
constructor
A new instance of CancelParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ CancelParams
Returns a new instance of CancelParams.
193 194 195 |
# File 'lib/stripe/resources/gift_cards/transaction.rb', line 193 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
191 192 193 |
# File 'lib/stripe/resources/gift_cards/transaction.rb', line 191 def @expand end |