Class: Stripe::GiftCards::Transaction::ConfirmParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::GiftCards::Transaction::ConfirmParams
- Defined in:
- lib/stripe/resources/gift_cards/transaction.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ ConfirmParams
constructor
A new instance of ConfirmParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ ConfirmParams
Returns a new instance of ConfirmParams.
181 182 183 |
# File 'lib/stripe/resources/gift_cards/transaction.rb', line 181 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
179 180 181 |
# File 'lib/stripe/resources/gift_cards/transaction.rb', line 179 def @expand end |