Class: Stripe::GiftCards::Transaction::CreateParams::CreatedBy
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::GiftCards::Transaction::CreateParams::CreatedBy
- Defined in:
- lib/stripe/resources/gift_cards/transaction.rb
Defined Under Namespace
Classes: Payment
Instance Attribute Summary collapse
-
#payment ⇒ Object
The details for the payment that created this object.
-
#type ⇒ Object
The type of event that created this object.
Instance Method Summary collapse
-
#initialize(payment: nil, type: nil) ⇒ CreatedBy
constructor
A new instance of CreatedBy.
Methods inherited from RequestParams
Constructor Details
#initialize(payment: nil, type: nil) ⇒ CreatedBy
Returns a new instance of CreatedBy.
108 109 110 111 |
# File 'lib/stripe/resources/gift_cards/transaction.rb', line 108 def initialize(payment: nil, type: nil) @payment = payment @type = type end |
Instance Attribute Details
#payment ⇒ Object
The details for the payment that created this object.
103 104 105 |
# File 'lib/stripe/resources/gift_cards/transaction.rb', line 103 def payment @payment end |
#type ⇒ Object
The type of event that created this object.
106 107 108 |
# File 'lib/stripe/resources/gift_cards/transaction.rb', line 106 def type @type end |