Class: Stripe::GiftCards::Transaction::ListParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/gift_cards/transaction.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(ending_before: nil, expand: nil, gift_card: nil, limit: nil, starting_after: nil, transfer_group: nil) ⇒ ListParams

Returns a new instance of ListParams.



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/stripe/resources/gift_cards/transaction.rb', line 65

def initialize(
  ending_before: nil,
  expand: nil,
  gift_card: nil,
  limit: nil,
  starting_after: nil,
  transfer_group: nil
)
  @ending_before = ending_before
  @expand = expand
  @gift_card = gift_card
  @limit = limit
  @starting_after = starting_after
  @transfer_group = transfer_group
end

Instance Attribute Details

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



53
54
55
# File 'lib/stripe/resources/gift_cards/transaction.rb', line 53

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



55
56
57
# File 'lib/stripe/resources/gift_cards/transaction.rb', line 55

def expand
  @expand
end

#gift_cardObject

The gift card to list transactions for.



57
58
59
# File 'lib/stripe/resources/gift_cards/transaction.rb', line 57

def gift_card
  @gift_card
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



59
60
61
# File 'lib/stripe/resources/gift_cards/transaction.rb', line 59

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



61
62
63
# File 'lib/stripe/resources/gift_cards/transaction.rb', line 61

def starting_after
  @starting_after
end

#transfer_groupObject

A string that identifies this transaction as part of a group. See the [Connect documentation](stripe.com/docs/connect/separate-charges-and-transfers) for details.



63
64
65
# File 'lib/stripe/resources/gift_cards/transaction.rb', line 63

def transfer_group
  @transfer_group
end