Class: Stripe::GiftCards::Transaction::RetrieveParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::GiftCards::Transaction::RetrieveParams
- Defined in:
- lib/stripe/resources/gift_cards/transaction.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ RetrieveParams
constructor
A new instance of RetrieveParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ RetrieveParams
Returns a new instance of RetrieveParams.
167 168 169 |
# File 'lib/stripe/resources/gift_cards/transaction.rb', line 167 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
165 166 167 |
# File 'lib/stripe/resources/gift_cards/transaction.rb', line 165 def @expand end |