Class: Stripe::GiftCards::Transaction::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/gift_cards/transaction.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, expand: nil, metadata: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



161
162
163
164
165
# File 'lib/stripe/resources/gift_cards/transaction.rb', line 161

def initialize(description: nil, expand: nil, metadata: nil)
  @description = description
  @expand = expand
  @metadata = 
end

Instance Attribute Details

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



155
156
157
# File 'lib/stripe/resources/gift_cards/transaction.rb', line 155

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



157
158
159
# File 'lib/stripe/resources/gift_cards/transaction.rb', line 157

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



159
160
161
# File 'lib/stripe/resources/gift_cards/transaction.rb', line 159

def 
  @metadata
end