Class: Stripe::GiftCards::TransactionService::ConfirmParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::GiftCards::TransactionService::ConfirmParams
- Defined in:
- lib/stripe/services/gift_cards/transaction_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ ConfirmParams
constructor
A new instance of ConfirmParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ ConfirmParams
Returns a new instance of ConfirmParams.
137 138 139 |
# File 'lib/stripe/services/gift_cards/transaction_service.rb', line 137 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
135 136 137 |
# File 'lib/stripe/services/gift_cards/transaction_service.rb', line 135 def @expand end |