Class: Stripe::GiftCards::TransactionService::CreateParams::CreatedBy
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::GiftCards::TransactionService::CreateParams::CreatedBy
- Defined in:
- lib/stripe/services/gift_cards/transaction_service.rb
Defined Under Namespace
Classes: Payment
Instance Attribute Summary collapse
-
#payment ⇒ Object
The details for the payment that created this object.
-
#type ⇒ Object
The type of event that created this object.
Instance Method Summary collapse
-
#initialize(payment: nil, type: nil) ⇒ CreatedBy
constructor
A new instance of CreatedBy.
Methods inherited from RequestParams
Constructor Details
#initialize(payment: nil, type: nil) ⇒ CreatedBy
Returns a new instance of CreatedBy.
53 54 55 56 |
# File 'lib/stripe/services/gift_cards/transaction_service.rb', line 53 def initialize(payment: nil, type: nil) @payment = payment @type = type end |
Instance Attribute Details
#payment ⇒ Object
The details for the payment that created this object.
49 50 51 |
# File 'lib/stripe/services/gift_cards/transaction_service.rb', line 49 def payment @payment end |
#type ⇒ Object
The type of event that created this object.
51 52 53 |
# File 'lib/stripe/services/gift_cards/transaction_service.rb', line 51 def type @type end |