Class: Stripe::GiftCards::TransactionService::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::GiftCards::TransactionService::ListParams
- Defined in:
- lib/stripe/services/gift_cards/transaction_service.rb
Instance Attribute Summary collapse
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#gift_card ⇒ Object
The gift card to list transactions for.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#starting_after ⇒ Object
A cursor for use in pagination.
-
#transfer_group ⇒ Object
A string that identifies this transaction as part of a group.
Instance Method Summary collapse
-
#initialize(ending_before: nil, expand: nil, gift_card: nil, limit: nil, starting_after: nil, transfer_group: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(ending_before: nil, expand: nil, gift_card: nil, limit: nil, starting_after: nil, transfer_group: nil) ⇒ ListParams
Returns a new instance of ListParams.
26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 |
# File 'lib/stripe/services/gift_cards/transaction_service.rb', line 26 def initialize( ending_before: nil, expand: nil, gift_card: nil, limit: nil, starting_after: nil, transfer_group: nil ) @ending_before = ending_before @expand = @gift_card = gift_card @limit = limit @starting_after = starting_after @transfer_group = transfer_group end |
Instance Attribute Details
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
9 10 11 |
# File 'lib/stripe/services/gift_cards/transaction_service.rb', line 9 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
12 13 14 |
# File 'lib/stripe/services/gift_cards/transaction_service.rb', line 12 def @expand end |
#gift_card ⇒ Object
The gift card to list transactions for.
15 16 17 |
# File 'lib/stripe/services/gift_cards/transaction_service.rb', line 15 def gift_card @gift_card end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
18 19 20 |
# File 'lib/stripe/services/gift_cards/transaction_service.rb', line 18 def limit @limit end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
21 22 23 |
# File 'lib/stripe/services/gift_cards/transaction_service.rb', line 21 def starting_after @starting_after end |
#transfer_group ⇒ Object
A string that identifies this transaction as part of a group. See the [Connect documentation](stripe.com/docs/connect/separate-charges-and-transfers) for details.
24 25 26 |
# File 'lib/stripe/services/gift_cards/transaction_service.rb', line 24 def transfer_group @transfer_group end |