Class: Stripe::GiftCards::TransactionService::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/gift_cards/transaction_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, expand: nil, metadata: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



117
118
119
120
121
# File 'lib/stripe/services/gift_cards/transaction_service.rb', line 117

def initialize(description: nil, expand: nil, metadata: nil)
  @description = description
  @expand = expand
  @metadata = 
end

Instance Attribute Details

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



111
112
113
# File 'lib/stripe/services/gift_cards/transaction_service.rb', line 111

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



113
114
115
# File 'lib/stripe/services/gift_cards/transaction_service.rb', line 113

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



115
116
117
# File 'lib/stripe/services/gift_cards/transaction_service.rb', line 115

def 
  @metadata
end