Class: Stripe::Identity::BlocklistEntry

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List
Defined in:
lib/stripe/resources/identity/blocklist_entry.rb

Overview

A BlocklistEntry represents an entry in our identity verification blocklist. It helps prevent fraudulent users from repeatedly attempting verification with similar information. When you create a BlocklistEntry, we store data from a specified VerificationReport, such as document details or facial biometrics. This allows us to compare future verification attempts against these entries. If a match is found, we categorize the new verification as unverified.

To learn more, see [Identity Verification Blocklist](docs.stripe.com/identity/review-tools#block-list)

Constant Summary collapse

OBJECT_NAME =
"identity.blocklist_entry"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



24
25
26
# File 'lib/stripe/resources/identity/blocklist_entry.rb', line 24

def created
  @created
end

#disabled_atObject (readonly)

Time at which you disabled the BlocklistEntry. Measured in seconds since the Unix epoch.



26
27
28
# File 'lib/stripe/resources/identity/blocklist_entry.rb', line 26

def disabled_at
  @disabled_at
end

#expires_atObject (readonly)

Time at which the BlocklistEntry expires. Measured in seconds since the Unix epoch.



28
29
30
# File 'lib/stripe/resources/identity/blocklist_entry.rb', line 28

def expires_at
  @expires_at
end

#idObject (readonly)

Unique identifier for the object.



30
31
32
# File 'lib/stripe/resources/identity/blocklist_entry.rb', line 30

def id
  @id
end

#livemodeObject (readonly)

If the object exists in live mode, the value is ‘true`. If the object exists in test mode, the value is `false`.



32
33
34
# File 'lib/stripe/resources/identity/blocklist_entry.rb', line 32

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



34
35
36
# File 'lib/stripe/resources/identity/blocklist_entry.rb', line 34

def object
  @object
end

#statusObject (readonly)

The current status of the BlocklistEntry.



36
37
38
# File 'lib/stripe/resources/identity/blocklist_entry.rb', line 36

def status
  @status
end

#typeObject (readonly)

The type of BlocklistEntry.



38
39
40
# File 'lib/stripe/resources/identity/blocklist_entry.rb', line 38

def type
  @type
end

#verification_reportObject (readonly)

The verification report the BlocklistEntry was created from.



40
41
42
# File 'lib/stripe/resources/identity/blocklist_entry.rb', line 40

def verification_report
  @verification_report
end

#verification_sessionObject (readonly)

The verification session the BlocklistEntry was created from.



42
43
44
# File 'lib/stripe/resources/identity/blocklist_entry.rb', line 42

def verification_session
  @verification_session
end

Class Method Details

.create(params = {}, opts = {}) ⇒ Object

Creates a BlocklistEntry object from a verification report.

A blocklist entry prevents future identity verifications that match the same identity information. You can create blocklist entries from verification reports that contain document extracted data or a selfie.

Related guide: [Identity Verification Blocklist](docs.stripe.com/docs/identity/review-tools#add-a-blocklist-entry)



51
52
53
54
55
56
57
58
# File 'lib/stripe/resources/identity/blocklist_entry.rb', line 51

def self.create(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/identity/blocklist_entries",
    params: params,
    opts: opts
  )
end

.disable(id, params = {}, opts = {}) ⇒ Object

Disables a BlocklistEntry object.

After a BlocklistEntry is disabled, it will no longer block future verifications that match the same information. This action is irreversible. To re-enable it, a new BlocklistEntry must be created using the same verification report.

Related guide: [Identity Verification Blocklist](docs.stripe.com/docs/identity/review-tools#disable-a-blocklist-entry)



83
84
85
86
87
88
89
90
# File 'lib/stripe/resources/identity/blocklist_entry.rb', line 83

def self.disable(id, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/identity/blocklist_entries/%<id>s/disable", { id: CGI.escape(id) }),
    params: params,
    opts: opts
  )
end

.field_remappingsObject



111
112
113
# File 'lib/stripe/resources/identity/blocklist_entry.rb', line 111

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



107
108
109
# File 'lib/stripe/resources/identity/blocklist_entry.rb', line 107

def self.inner_class_types
  @inner_class_types = {}
end

.list(params = {}, opts = {}) ⇒ Object

Returns a list of BlocklistEntry objects associated with your account.

The blocklist entries are returned sorted by creation date, with the most recently created entries appearing first.

Related guide: [Identity Verification Blocklist](docs.stripe.com/docs/identity/review-tools#block-list)



98
99
100
101
102
103
104
105
# File 'lib/stripe/resources/identity/blocklist_entry.rb', line 98

def self.list(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/identity/blocklist_entries",
    params: params,
    opts: opts
  )
end

.object_nameObject



19
20
21
# File 'lib/stripe/resources/identity/blocklist_entry.rb', line 19

def self.object_name
  "identity.blocklist_entry"
end

Instance Method Details

#disable(params = {}, opts = {}) ⇒ Object

Disables a BlocklistEntry object.

After a BlocklistEntry is disabled, it will no longer block future verifications that match the same information. This action is irreversible. To re-enable it, a new BlocklistEntry must be created using the same verification report.

Related guide: [Identity Verification Blocklist](docs.stripe.com/docs/identity/review-tools#disable-a-blocklist-entry)



67
68
69
70
71
72
73
74
# File 'lib/stripe/resources/identity/blocklist_entry.rb', line 67

def disable(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/identity/blocklist_entries/%<id>s/disable", { id: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end