Class: Stripe::Identity::BlocklistEntryCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Identity::BlocklistEntryCreateParams
- Defined in:
- lib/stripe/params/identity/blocklist_entry_create_params.rb
Instance Attribute Summary collapse
-
#check_existing_verifications ⇒ Object
When true, the created BlocklistEntry will be used to retroactively unverify matching verifications.
-
#entry_type ⇒ Object
The type of blocklist entry to be created.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#verification_report ⇒ Object
The identifier of the VerificationReport to create the BlocklistEntry from.
Instance Method Summary collapse
-
#initialize(check_existing_verifications: nil, entry_type: nil, expand: nil, verification_report: nil) ⇒ BlocklistEntryCreateParams
constructor
A new instance of BlocklistEntryCreateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(check_existing_verifications: nil, entry_type: nil, expand: nil, verification_report: nil) ⇒ BlocklistEntryCreateParams
Returns a new instance of BlocklistEntryCreateParams.
16 17 18 19 20 21 22 23 24 25 26 |
# File 'lib/stripe/params/identity/blocklist_entry_create_params.rb', line 16 def initialize( check_existing_verifications: nil, entry_type: nil, expand: nil, verification_report: nil ) @check_existing_verifications = check_existing_verifications @entry_type = entry_type @expand = @verification_report = verification_report end |
Instance Attribute Details
#check_existing_verifications ⇒ Object
When true, the created BlocklistEntry will be used to retroactively unverify matching verifications.
8 9 10 |
# File 'lib/stripe/params/identity/blocklist_entry_create_params.rb', line 8 def check_existing_verifications @check_existing_verifications end |
#entry_type ⇒ Object
The type of blocklist entry to be created.
10 11 12 |
# File 'lib/stripe/params/identity/blocklist_entry_create_params.rb', line 10 def entry_type @entry_type end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
12 13 14 |
# File 'lib/stripe/params/identity/blocklist_entry_create_params.rb', line 12 def @expand end |
#verification_report ⇒ Object
The identifier of the VerificationReport to create the BlocklistEntry from.
14 15 16 |
# File 'lib/stripe/params/identity/blocklist_entry_create_params.rb', line 14 def verification_report @verification_report end |