Class: Stripe::Identity::BlocklistEntryService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::Identity::BlocklistEntryService
- Defined in:
- lib/stripe/services/identity/blocklist_entry_service.rb
Instance Method Summary collapse
-
#create(params = {}, opts = {}) ⇒ Object
Creates a BlocklistEntry object from a verification report.
-
#disable(id, params = {}, opts = {}) ⇒ Object
Disables a BlocklistEntry object.
-
#list(params = {}, opts = {}) ⇒ Object
Returns a list of BlocklistEntry objects associated with your account.
-
#retrieve(id, params = {}, opts = {}) ⇒ Object
Retrieves a BlocklistEntry object by its identifier.
Methods inherited from StripeService
#initialize, #request, #request_stream
Constructor Details
This class inherits a constructor from Stripe::StripeService
Instance Method Details
#create(params = {}, opts = {}) ⇒ Object
Creates a BlocklistEntry object from a verification report.
A blocklist entry prevents future identity verifications that match the same identity information. You can create blocklist entries from verification reports that contain document extracted data or a selfie.
Related guide: [Identity Verification Blocklist](docs.stripe.com/docs/identity/review-tools#add-a-blocklist-entry)
14 15 16 17 18 19 20 21 22 |
# File 'lib/stripe/services/identity/blocklist_entry_service.rb', line 14 def create(params = {}, opts = {}) request( method: :post, path: "/v1/identity/blocklist_entries", params: params, opts: opts, base_address: :api ) end |
#disable(id, params = {}, opts = {}) ⇒ Object
Disables a BlocklistEntry object.
After a BlocklistEntry is disabled, it will no longer block future verifications that match the same information. This action is irreversible. To re-enable it, a new BlocklistEntry must be created using the same verification report.
Related guide: [Identity Verification Blocklist](docs.stripe.com/docs/identity/review-tools#disable-a-blocklist-entry)
31 32 33 34 35 36 37 38 39 |
# File 'lib/stripe/services/identity/blocklist_entry_service.rb', line 31 def disable(id, params = {}, opts = {}) request( method: :post, path: format("/v1/identity/blocklist_entries/%<id>s/disable", { id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |
#list(params = {}, opts = {}) ⇒ Object
Returns a list of BlocklistEntry objects associated with your account.
The blocklist entries are returned sorted by creation date, with the most recently created entries appearing first.
Related guide: [Identity Verification Blocklist](docs.stripe.com/docs/identity/review-tools#block-list)
47 48 49 50 51 52 53 54 55 |
# File 'lib/stripe/services/identity/blocklist_entry_service.rb', line 47 def list(params = {}, opts = {}) request( method: :get, path: "/v1/identity/blocklist_entries", params: params, opts: opts, base_address: :api ) end |
#retrieve(id, params = {}, opts = {}) ⇒ Object
Retrieves a BlocklistEntry object by its identifier.
Related guide: [Identity Verification Blocklist](docs.stripe.com/docs/identity/review-tools#block-list)
60 61 62 63 64 65 66 67 68 |
# File 'lib/stripe/services/identity/blocklist_entry_service.rb', line 60 def retrieve(id, params = {}, opts = {}) request( method: :get, path: format("/v1/identity/blocklist_entries/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |