Class: Stripe::Identity::VerificationReport

Inherits:
APIResource show all
Extended by:
APIOperations::List
Defined in:
lib/stripe/resources/identity/verification_report.rb

Overview

A VerificationReport is the result of an attempt to collect and verify data from a user. The collection of verification checks performed is determined from the type and options parameters used. You can find the result of each verification check performed in the appropriate sub-resource: document, id_number, selfie.

Each VerificationReport contains a copy of any data collected by the user as well as reference IDs which can be used to access collected images through the FileUpload API. To configure and create VerificationReports, use the VerificationSession API.

Related guide: Accessing verification results.

Defined Under Namespace

Classes: Document, Email, IdNumber, Options, Phone, Selfie

Constant Summary collapse

OBJECT_NAME =
"identity.verification_report"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods included from APIOperations::List

list

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#client_reference_idObject (readonly)

A string to reference this user. This can be a customer ID, a session ID, or similar, and can be used to reconcile this verification with your internal systems.



377
378
379
# File 'lib/stripe/resources/identity/verification_report.rb', line 377

def client_reference_id
  @client_reference_id
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



379
380
381
# File 'lib/stripe/resources/identity/verification_report.rb', line 379

def created
  @created
end

#documentObject (readonly)

Result from a document check



381
382
383
# File 'lib/stripe/resources/identity/verification_report.rb', line 381

def document
  @document
end

#emailObject (readonly)

Result from a email check



383
384
385
# File 'lib/stripe/resources/identity/verification_report.rb', line 383

def email
  @email
end

#idObject (readonly)

Unique identifier for the object.



385
386
387
# File 'lib/stripe/resources/identity/verification_report.rb', line 385

def id
  @id
end

#id_numberObject (readonly)

Result from an id_number check



387
388
389
# File 'lib/stripe/resources/identity/verification_report.rb', line 387

def id_number
  @id_number
end

#livemodeObject (readonly)

If the object exists in live mode, the value is true. If the object exists in test mode, the value is false.



389
390
391
# File 'lib/stripe/resources/identity/verification_report.rb', line 389

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object's type. Objects of the same type share the same value.



391
392
393
# File 'lib/stripe/resources/identity/verification_report.rb', line 391

def object
  @object
end

#optionsObject (readonly)

Attribute for field options



393
394
395
# File 'lib/stripe/resources/identity/verification_report.rb', line 393

def options
  @options
end

#phoneObject (readonly)

Result from a phone check



395
396
397
# File 'lib/stripe/resources/identity/verification_report.rb', line 395

def phone
  @phone
end

#selfieObject (readonly)

Result from a selfie check



397
398
399
# File 'lib/stripe/resources/identity/verification_report.rb', line 397

def selfie
  @selfie
end

#typeObject (readonly)

Type of report.



399
400
401
# File 'lib/stripe/resources/identity/verification_report.rb', line 399

def type
  @type
end

#verification_flowObject (readonly)

The configuration token of a verification flow from the dashboard.



401
402
403
# File 'lib/stripe/resources/identity/verification_report.rb', line 401

def verification_flow
  @verification_flow
end

#verification_sessionObject (readonly)

ID of the VerificationSession that created this report.



403
404
405
# File 'lib/stripe/resources/identity/verification_report.rb', line 403

def verification_session
  @verification_session
end

Class Method Details

.field_remappingsObject



426
427
428
# File 'lib/stripe/resources/identity/verification_report.rb', line 426

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



415
416
417
418
419
420
421
422
423
424
# File 'lib/stripe/resources/identity/verification_report.rb', line 415

def self.inner_class_types
  @inner_class_types = {
    document: Document,
    email: Email,
    id_number: IdNumber,
    options: Options,
    phone: Phone,
    selfie: Selfie,
  }
end

.list(params = {}, opts = {}) ⇒ Object

List all verification reports.



406
407
408
409
410
411
412
413
# File 'lib/stripe/resources/identity/verification_report.rb', line 406

def self.list(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/identity/verification_reports",
    params: params,
    opts: opts
  )
end

.object_nameObject



21
22
23
# File 'lib/stripe/resources/identity/verification_report.rb', line 21

def self.object_name
  "identity.verification_report"
end