Class: Stripe::Identity::VerificationReport::Email::Details
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Identity::VerificationReport::Email::Details
- Defined in:
- lib/stripe/resources/identity/verification_report.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#days_since_domain_creation ⇒ Object
readonly
Number of days from the time when the email domain was first observed to the time of verification.
-
#days_since_ownership_started ⇒ Object
readonly
Number of days from the time when the email address was first observed to the time of verification.
-
#domain_country ⇒ Object
readonly
Two-letter ISO 3166-1 alpha-2 country code of the email domain’s country.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#days_since_domain_creation ⇒ Object (readonly)
Number of days from the time when the email domain was first observed to the time of verification.
165 166 167 |
# File 'lib/stripe/resources/identity/verification_report.rb', line 165 def days_since_domain_creation @days_since_domain_creation end |
#days_since_ownership_started ⇒ Object (readonly)
Number of days from the time when the email address was first observed to the time of verification.
167 168 169 |
# File 'lib/stripe/resources/identity/verification_report.rb', line 167 def days_since_ownership_started @days_since_ownership_started end |
#domain_country ⇒ Object (readonly)
Two-letter ISO 3166-1 alpha-2 country code of the email domain’s country.
169 170 171 |
# File 'lib/stripe/resources/identity/verification_report.rb', line 169 def domain_country @domain_country end |
Class Method Details
.field_remappings ⇒ Object
175 176 177 |
# File 'lib/stripe/resources/identity/verification_report.rb', line 175 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
171 172 173 |
# File 'lib/stripe/resources/identity/verification_report.rb', line 171 def self.inner_class_types @inner_class_types = {} end |