Class: Stripe::Identity::VerificationReport::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Identity::VerificationReport::ListParams
- Defined in:
- lib/stripe/resources/identity/verification_report.rb
Defined Under Namespace
Classes: Created
Instance Attribute Summary collapse
-
#client_reference_id ⇒ Object
A string to reference this user.
-
#created ⇒ Object
Only return VerificationReports that were created during the given date interval.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#starting_after ⇒ Object
A cursor for use in pagination.
-
#type ⇒ Object
Only return VerificationReports of this type.
-
#verification_session ⇒ Object
Only return VerificationReports created by this VerificationSession ID.
Instance Method Summary collapse
-
#initialize(client_reference_id: nil, created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, type: nil, verification_session: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(client_reference_id: nil, created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, type: nil, verification_session: nil) ⇒ ListParams
Returns a new instance of ListParams.
389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 |
# File 'lib/stripe/resources/identity/verification_report.rb', line 389 def initialize( client_reference_id: nil, created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, type: nil, verification_session: nil ) @client_reference_id = client_reference_id @created = created @ending_before = ending_before @expand = @limit = limit @starting_after = starting_after @type = type @verification_session = verification_session end |
Instance Attribute Details
#client_reference_id ⇒ Object
A string to reference this user. This can be a customer ID, a session ID, or similar, and can be used to reconcile this verification with your internal systems.
373 374 375 |
# File 'lib/stripe/resources/identity/verification_report.rb', line 373 def client_reference_id @client_reference_id end |
#created ⇒ Object
Only return VerificationReports that were created during the given date interval.
375 376 377 |
# File 'lib/stripe/resources/identity/verification_report.rb', line 375 def created @created end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
377 378 379 |
# File 'lib/stripe/resources/identity/verification_report.rb', line 377 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
379 380 381 |
# File 'lib/stripe/resources/identity/verification_report.rb', line 379 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
381 382 383 |
# File 'lib/stripe/resources/identity/verification_report.rb', line 381 def limit @limit end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
383 384 385 |
# File 'lib/stripe/resources/identity/verification_report.rb', line 383 def starting_after @starting_after end |
#type ⇒ Object
Only return VerificationReports of this type
385 386 387 |
# File 'lib/stripe/resources/identity/verification_report.rb', line 385 def type @type end |
#verification_session ⇒ Object
Only return VerificationReports created by this VerificationSession ID. It is allowed to provide a VerificationIntent ID.
387 388 389 |
# File 'lib/stripe/resources/identity/verification_report.rb', line 387 def verification_session @verification_session end |