Class: Stripe::Identity::VerificationReport::Options::Document

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/identity/verification_report.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#allowed_typesObject (readonly)

Array of strings of allowed identity document types. If the provided identity document isn’t one of the allowed types, the verification check will fail with a document_type_not_allowed error code.



156
157
158
# File 'lib/stripe/resources/identity/verification_report.rb', line 156

def allowed_types
  @allowed_types
end

#require_id_numberObject (readonly)

Collect an ID number and perform an [ID number check](stripe.com/docs/identity/verification-checks?type=id-number) with the document’s extracted name and date of birth.



158
159
160
# File 'lib/stripe/resources/identity/verification_report.rb', line 158

def require_id_number
  @require_id_number
end

#require_live_captureObject (readonly)

Disable image uploads, identity document images have to be captured using the device’s camera.



160
161
162
# File 'lib/stripe/resources/identity/verification_report.rb', line 160

def require_live_capture
  @require_live_capture
end

#require_matching_selfieObject (readonly)

Capture a face image and perform a [selfie check](stripe.com/docs/identity/verification-checks?type=selfie) comparing a photo ID and a picture of your user’s face. [Learn more](stripe.com/docs/identity/selfie).



162
163
164
# File 'lib/stripe/resources/identity/verification_report.rb', line 162

def require_matching_selfie
  @require_matching_selfie
end