Class: Stripe::Identity::VerificationReport::Selfie

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/identity/verification_report.rb

Defined Under Namespace

Classes: Error

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#blocked_by_entryObject (readonly)

If selfie was not verified due to being on the blocklist, this is the token of the BlocklistEntry that blocked it



358
359
360
# File 'lib/stripe/resources/identity/verification_report.rb', line 358

def blocked_by_entry
  @blocked_by_entry
end

#documentObject (readonly)

ID of the [File](docs.stripe.com/api/files) holding the image of the identity document used in this check.



360
361
362
# File 'lib/stripe/resources/identity/verification_report.rb', line 360

def document
  @document
end

#errorObject (readonly)

Details on the verification error. Present when status is ‘unverified`.



362
363
364
# File 'lib/stripe/resources/identity/verification_report.rb', line 362

def error
  @error
end

#selfieObject (readonly)

ID of the [File](docs.stripe.com/api/files) holding the image of the selfie used in this check.



364
365
366
# File 'lib/stripe/resources/identity/verification_report.rb', line 364

def selfie
  @selfie
end

#statusObject (readonly)

Status of this ‘selfie` check.



366
367
368
# File 'lib/stripe/resources/identity/verification_report.rb', line 366

def status
  @status
end

Class Method Details

.field_remappingsObject



372
373
374
# File 'lib/stripe/resources/identity/verification_report.rb', line 372

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



368
369
370
# File 'lib/stripe/resources/identity/verification_report.rb', line 368

def self.inner_class_types
  @inner_class_types = { error: Error }
end