Class: Stripe::Identity::VerificationSession::CancelParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Identity::VerificationSession::CancelParams
- Defined in:
- lib/stripe/resources/identity/verification_session.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ CancelParams
constructor
A new instance of CancelParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ CancelParams
Returns a new instance of CancelParams.
338 339 340 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 338 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
336 337 338 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 336 def @expand end |