Class: Stripe::Identity::VerificationSession::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/identity/verification_session.rb

Defined Under Namespace

Classes: Options, ProvidedDetails, RelatedPerson

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(client_reference_id: nil, expand: nil, metadata: nil, options: nil, provided_details: nil, related_customer: nil, related_customer_account: nil, related_person: nil, return_url: nil, type: nil, verification_flow: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
# File 'lib/stripe/resources/identity/verification_session.rb', line 391

def initialize(
  client_reference_id: nil,
  expand: nil,
  metadata: nil,
  options: nil,
  provided_details: nil,
  related_customer: nil,
  related_customer_account: nil,
  related_person: nil,
  return_url: nil,
  type: nil,
  verification_flow: nil
)
  @client_reference_id = client_reference_id
  @expand = expand
  @metadata = 
  @options = options
  @provided_details = provided_details
  @related_customer = related_customer
  @related_customer_account = 
  @related_person = related_person
  @return_url = return_url
  @type = type
  @verification_flow = verification_flow
end

Instance Attribute Details

#client_reference_idObject

A string to reference this user. This can be a customer ID, a session ID, or similar, and can be used to reconcile this verification with your internal systems.



369
370
371
# File 'lib/stripe/resources/identity/verification_session.rb', line 369

def client_reference_id
  @client_reference_id
end

#expandObject

Specifies which fields in the response should be expanded.



371
372
373
# File 'lib/stripe/resources/identity/verification_session.rb', line 371

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



373
374
375
# File 'lib/stripe/resources/identity/verification_session.rb', line 373

def 
  @metadata
end

#optionsObject

A set of options for the session’s verification checks.



375
376
377
# File 'lib/stripe/resources/identity/verification_session.rb', line 375

def options
  @options
end

#provided_detailsObject

Details provided about the user being verified. These details may be shown to the user.



377
378
379
# File 'lib/stripe/resources/identity/verification_session.rb', line 377

def provided_details
  @provided_details
end

Customer ID



379
380
381
# File 'lib/stripe/resources/identity/verification_session.rb', line 379

def related_customer
  @related_customer
end

Token referencing a Customer Account resource.



381
382
383
# File 'lib/stripe/resources/identity/verification_session.rb', line 381

def 
  @related_customer_account
end

Tokens referencing a Person resource and it’s associated account.



383
384
385
# File 'lib/stripe/resources/identity/verification_session.rb', line 383

def related_person
  @related_person
end

#return_urlObject

The URL that the user will be redirected to upon completing the verification flow.



385
386
387
# File 'lib/stripe/resources/identity/verification_session.rb', line 385

def return_url
  @return_url
end

#typeObject

The type of [verification check](stripe.com/docs/identity/verification-checks) to be performed. You must provide a ‘type` if not passing `verification_flow`.



387
388
389
# File 'lib/stripe/resources/identity/verification_session.rb', line 387

def type
  @type
end

#verification_flowObject

The ID of a verification flow from the Dashboard. See docs.stripe.com/identity/verification-flows.



389
390
391
# File 'lib/stripe/resources/identity/verification_session.rb', line 389

def verification_flow
  @verification_flow
end