Class: Stripe::Identity::VerificationSession::CreateParams::RelatedPerson
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Identity::VerificationSession::CreateParams::RelatedPerson
- Defined in:
- lib/stripe/resources/identity/verification_session.rb
Instance Attribute Summary collapse
-
#account ⇒ Object
A token representing a connected account.
-
#person ⇒ Object
A token referencing a Person resource that this verification is being used to verify.
Instance Method Summary collapse
-
#initialize(account: nil, person: nil) ⇒ RelatedPerson
constructor
A new instance of RelatedPerson.
Methods inherited from RequestParams
Constructor Details
#initialize(account: nil, person: nil) ⇒ RelatedPerson
Returns a new instance of RelatedPerson.
363 364 365 366 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 363 def initialize(account: nil, person: nil) @account = account @person = person end |
Instance Attribute Details
#account ⇒ Object
A token representing a connected account. If provided, the person parameter is also required and must be associated with the account.
359 360 361 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 359 def account @account end |
#person ⇒ Object
A token referencing a Person resource that this verification is being used to verify.
361 362 363 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 361 def person @person end |