Class: Stripe::Identity::VerificationSession::LastError
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Identity::VerificationSession::LastError
- Defined in:
- lib/stripe/resources/identity/verification_session.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#code ⇒ Object
readonly
A short machine-readable string giving the reason for the verification or user-session failure.
-
#reason ⇒ Object
readonly
A message that explains the reason for verification or user-session failure.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#code ⇒ Object (readonly)
A short machine-readable string giving the reason for the verification or user-session failure.
29 30 31 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 29 def code @code end |
#reason ⇒ Object (readonly)
A message that explains the reason for verification or user-session failure.
31 32 33 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 31 def reason @reason end |