Class: Stripe::Identity::VerificationSession::ListParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/identity/verification_session.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(client_reference_id: nil, created: nil, ending_before: nil, expand: nil, limit: nil, related_customer: nil, related_customer_account: nil, starting_after: nil, status: nil) ⇒ ListParams

Returns a new instance of ListParams.



290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
# File 'lib/stripe/resources/identity/verification_session.rb', line 290

def initialize(
  client_reference_id: nil,
  created: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  related_customer: nil,
  related_customer_account: nil,
  starting_after: nil,
  status: nil
)
  @client_reference_id = client_reference_id
  @created = created
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @related_customer = related_customer
  @related_customer_account = 
  @starting_after = starting_after
  @status = status
end

Instance Attribute Details

#client_reference_idObject

A string to reference this user. This can be a customer ID, a session ID, or similar, and can be used to reconcile this verification with your internal systems.



272
273
274
# File 'lib/stripe/resources/identity/verification_session.rb', line 272

def client_reference_id
  @client_reference_id
end

#createdObject

Only return VerificationSessions that were created during the given date interval.



274
275
276
# File 'lib/stripe/resources/identity/verification_session.rb', line 274

def created
  @created
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



276
277
278
# File 'lib/stripe/resources/identity/verification_session.rb', line 276

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



278
279
280
# File 'lib/stripe/resources/identity/verification_session.rb', line 278

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



280
281
282
# File 'lib/stripe/resources/identity/verification_session.rb', line 280

def limit
  @limit
end

Attribute for param field related_customer



282
283
284
# File 'lib/stripe/resources/identity/verification_session.rb', line 282

def related_customer
  @related_customer
end

Attribute for param field related_customer_account



284
285
286
# File 'lib/stripe/resources/identity/verification_session.rb', line 284

def 
  @related_customer_account
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



286
287
288
# File 'lib/stripe/resources/identity/verification_session.rb', line 286

def starting_after
  @starting_after
end

#statusObject

Only return VerificationSessions with this status. [Learn more about the lifecycle of sessions](stripe.com/docs/identity/how-sessions-work).



288
289
290
# File 'lib/stripe/resources/identity/verification_session.rb', line 288

def status
  @status
end