Class: Stripe::Identity::VerificationSession::RetrieveParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Identity::VerificationSession::RetrieveParams
- Defined in:
- lib/stripe/resources/identity/verification_session.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ RetrieveParams
constructor
A new instance of RetrieveParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ RetrieveParams
Returns a new instance of RetrieveParams.
266 267 268 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 266 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
264 265 266 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 264 def @expand end |