Class: Stripe::Identity::VerificationSession::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Identity::VerificationSession::UpdateParams
- Defined in:
- lib/stripe/resources/identity/verification_session.rb
Defined Under Namespace
Classes: Options, ProvidedDetails
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#options ⇒ Object
A set of options for the session’s verification checks.
-
#provided_details ⇒ Object
Details provided about the user being verified.
-
#type ⇒ Object
The type of [verification check](stripe.com/docs/identity/verification-checks) to be performed.
Instance Method Summary collapse
-
#initialize(expand: nil, metadata: nil, options: nil, provided_details: nil, type: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, metadata: nil, options: nil, provided_details: nil, type: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
324 325 326 327 328 329 330 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 324 def initialize(expand: nil, metadata: nil, options: nil, provided_details: nil, type: nil) @expand = @metadata = @options = @provided_details = provided_details @type = type end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
314 315 316 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 314 def @expand end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
316 317 318 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 316 def @metadata end |
#options ⇒ Object
A set of options for the session’s verification checks.
318 319 320 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 318 def @options end |
#provided_details ⇒ Object
Details provided about the user being verified. These details may be shown to the user.
320 321 322 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 320 def provided_details @provided_details end |
#type ⇒ Object
The type of [verification check](stripe.com/docs/identity/verification-checks) to be performed.
322 323 324 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 322 def type @type end |