Class: Stripe::Identity::VerificationSessionService::CancelParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Identity::VerificationSessionService::CancelParams
- Defined in:
- lib/stripe/services/identity/verification_session_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ CancelParams
constructor
A new instance of CancelParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ CancelParams
Returns a new instance of CancelParams.
232 233 234 |
# File 'lib/stripe/services/identity/verification_session_service.rb', line 232 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
230 231 232 |
# File 'lib/stripe/services/identity/verification_session_service.rb', line 230 def @expand end |