Class: Stripe::Identity::VerificationSessionService::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/identity/verification_session_service.rb

Defined Under Namespace

Classes: Options, ProvidedDetails, RelatedPerson

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(client_reference_id: nil, expand: nil, metadata: nil, options: nil, provided_details: nil, related_customer: nil, related_customer_account: nil, related_person: nil, return_url: nil, type: nil, verification_flow: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
# File 'lib/stripe/services/identity/verification_session_service.rb', line 145

def initialize(
  client_reference_id: nil,
  expand: nil,
  metadata: nil,
  options: nil,
  provided_details: nil,
  related_customer: nil,
  related_customer_account: nil,
  related_person: nil,
  return_url: nil,
  type: nil,
  verification_flow: nil
)
  @client_reference_id = client_reference_id
  @expand = expand
  @metadata = 
  @options = options
  @provided_details = provided_details
  @related_customer = related_customer
  @related_customer_account = 
  @related_person = related_person
  @return_url = return_url
  @type = type
  @verification_flow = verification_flow
end

Instance Attribute Details

#client_reference_idObject

A string to reference this user. This can be a customer ID, a session ID, or similar, and can be used to reconcile this verification with your internal systems.



123
124
125
# File 'lib/stripe/services/identity/verification_session_service.rb', line 123

def client_reference_id
  @client_reference_id
end

#expandObject

Specifies which fields in the response should be expanded.



125
126
127
# File 'lib/stripe/services/identity/verification_session_service.rb', line 125

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



127
128
129
# File 'lib/stripe/services/identity/verification_session_service.rb', line 127

def 
  @metadata
end

#optionsObject

A set of options for the session’s verification checks.



129
130
131
# File 'lib/stripe/services/identity/verification_session_service.rb', line 129

def options
  @options
end

#provided_detailsObject

Details provided about the user being verified. These details may be shown to the user.



131
132
133
# File 'lib/stripe/services/identity/verification_session_service.rb', line 131

def provided_details
  @provided_details
end

Customer ID



133
134
135
# File 'lib/stripe/services/identity/verification_session_service.rb', line 133

def related_customer
  @related_customer
end

Token referencing a Customer Account resource.



135
136
137
# File 'lib/stripe/services/identity/verification_session_service.rb', line 135

def 
  @related_customer_account
end

Tokens referencing a Person resource and it’s associated account.



137
138
139
# File 'lib/stripe/services/identity/verification_session_service.rb', line 137

def related_person
  @related_person
end

#return_urlObject

The URL that the user will be redirected to upon completing the verification flow.



139
140
141
# File 'lib/stripe/services/identity/verification_session_service.rb', line 139

def return_url
  @return_url
end

#typeObject

The type of [verification check](stripe.com/docs/identity/verification-checks) to be performed. You must provide a ‘type` if not passing `verification_flow`.



141
142
143
# File 'lib/stripe/services/identity/verification_session_service.rb', line 141

def type
  @type
end

#verification_flowObject

The ID of a verification flow from the Dashboard. See docs.stripe.com/identity/verification-flows.



143
144
145
# File 'lib/stripe/services/identity/verification_session_service.rb', line 143

def verification_flow
  @verification_flow
end