Class: Stripe::Identity::VerificationSessionService::ListParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/identity/verification_session_service.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(client_reference_id: nil, created: nil, ending_before: nil, expand: nil, limit: nil, related_customer: nil, starting_after: nil, status: nil) ⇒ ListParams

Returns a new instance of ListParams.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/stripe/services/identity/verification_session_service.rb', line 52

def initialize(
  client_reference_id: nil,
  created: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  related_customer: nil,
  starting_after: nil,
  status: nil
)
  @client_reference_id = client_reference_id
  @created = created
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @related_customer = related_customer
  @starting_after = starting_after
  @status = status
end

Instance Attribute Details

#client_reference_idObject

A string to reference this user. This can be a customer ID, a session ID, or similar, and can be used to reconcile this verification with your internal systems.



29
30
31
# File 'lib/stripe/services/identity/verification_session_service.rb', line 29

def client_reference_id
  @client_reference_id
end

#createdObject

Only return VerificationSessions that were created during the given date interval.



32
33
34
# File 'lib/stripe/services/identity/verification_session_service.rb', line 32

def created
  @created
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



35
36
37
# File 'lib/stripe/services/identity/verification_session_service.rb', line 35

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



38
39
40
# File 'lib/stripe/services/identity/verification_session_service.rb', line 38

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



41
42
43
# File 'lib/stripe/services/identity/verification_session_service.rb', line 41

def limit
  @limit
end

Attribute for param field related_customer



44
45
46
# File 'lib/stripe/services/identity/verification_session_service.rb', line 44

def related_customer
  @related_customer
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



47
48
49
# File 'lib/stripe/services/identity/verification_session_service.rb', line 47

def starting_after
  @starting_after
end

#statusObject

Only return VerificationSessions with this status. [Learn more about the lifecycle of sessions](stripe.com/docs/identity/how-sessions-work).



50
51
52
# File 'lib/stripe/services/identity/verification_session_service.rb', line 50

def status
  @status
end