Class: Stripe::Identity::VerificationSessionService::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/identity/verification_session_service.rb

Defined Under Namespace

Classes: Options, ProvidedDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, metadata: nil, options: nil, provided_details: nil, type: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



235
236
237
238
239
240
241
# File 'lib/stripe/services/identity/verification_session_service.rb', line 235

def initialize(expand: nil, metadata: nil, options: nil, provided_details: nil, type: nil)
  @expand = expand
  @metadata = 
  @options = options
  @provided_details = provided_details
  @type = type
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



225
226
227
# File 'lib/stripe/services/identity/verification_session_service.rb', line 225

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



227
228
229
# File 'lib/stripe/services/identity/verification_session_service.rb', line 227

def 
  @metadata
end

#optionsObject

A set of options for the session’s verification checks.



229
230
231
# File 'lib/stripe/services/identity/verification_session_service.rb', line 229

def options
  @options
end

#provided_detailsObject

Details provided about the user being verified. These details may be shown to the user.



231
232
233
# File 'lib/stripe/services/identity/verification_session_service.rb', line 231

def provided_details
  @provided_details
end

#typeObject

The type of [verification check](stripe.com/docs/identity/verification-checks) to be performed.



233
234
235
# File 'lib/stripe/services/identity/verification_session_service.rb', line 233

def type
  @type
end