Class: Stripe::Identity::VerificationSessionUpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/identity/verification_session_update_params.rb

Defined Under Namespace

Classes: Options, ProvidedDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(confirm: nil, expand: nil, metadata: nil, options: nil, provided_details: nil, type: nil) ⇒ VerificationSessionUpdateParams

Returns a new instance of VerificationSessionUpdateParams.



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/stripe/params/identity/verification_session_update_params.rb', line 62

def initialize(
  confirm: nil,
  expand: nil,
  metadata: nil,
  options: nil,
  provided_details: nil,
  type: nil
)
  @confirm = confirm
  @expand = expand
  @metadata = 
  @options = options
  @provided_details = provided_details
  @type = type
end

Instance Attribute Details

#confirmObject

Confirm and submit the provided details for verification.



50
51
52
# File 'lib/stripe/params/identity/verification_session_update_params.rb', line 50

def confirm
  @confirm
end

#expandObject

Specifies which fields in the response should be expanded.



52
53
54
# File 'lib/stripe/params/identity/verification_session_update_params.rb', line 52

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



54
55
56
# File 'lib/stripe/params/identity/verification_session_update_params.rb', line 54

def 
  @metadata
end

#optionsObject

A set of options for the session’s verification checks.



56
57
58
# File 'lib/stripe/params/identity/verification_session_update_params.rb', line 56

def options
  @options
end

#provided_detailsObject

Details provided about the user being verified. These details may be shown to the user.



58
59
60
# File 'lib/stripe/params/identity/verification_session_update_params.rb', line 58

def provided_details
  @provided_details
end

#typeObject

The type of [verification check](docs.stripe.com/identity/verification-checks) to be performed.



60
61
62
# File 'lib/stripe/params/identity/verification_session_update_params.rb', line 60

def type
  @type
end