Class: Stripe::Invoice

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List, APIOperations::NestedResource, APIOperations::Search
Includes:
APIOperations::Delete, APIOperations::Save
Defined in:
lib/stripe/resources/invoice.rb

Overview

Invoices are statements of amounts owed by a customer, and are either generated one-off, or generated periodically from a subscription.

They contain invoice items, and proration adjustments that may be caused by subscription upgrades/downgrades (if necessary).

If your invoice is configured to be billed through automatic charges, Stripe automatically finalizes your invoice and attempts payment. Note that finalizing the invoice, when automatic, does not happen immediately as the invoice is created. Stripe waits until one hour after the last webhook was successfully sent (or the last webhook timed out after failing). If you (and the platforms you may have connected to) have no webhooks configured, Stripe waits one hour after creation to finalize the invoice.

If your invoice is configured to be billed by sending an email, then based on your email settings, Stripe will email the invoice to your customer and await payment. These emails can contain a link to a hosted page to pay the invoice.

Stripe applies any customer credit on the account before determining the amount due for the invoice (i.e., the amount that will be actually charged). If the amount due for the invoice is less than Stripe's minimum allowed charge per currency, the invoice is automatically marked paid, and we add the amount due to the customer's credit balance which is applied to the next invoice.

More details on the customer's credit balance are here.

Related guide: Send invoices to customers

Defined Under Namespace

Classes: AmountsDue, AutomaticTax, ConfirmationSecret, CustomField, CustomerAddress, CustomerShipping, CustomerTaxId, FromInvoice, Issuer, LastFinalizationError, Parent, PaymentSettings, Rendering, ShippingCost, ShippingDetails, StatusTransitions, ThresholdReason, TotalDiscountAmount, TotalMarginAmount, TotalPretaxCreditAmount, TotalTax

Constant Summary collapse

OBJECT_NAME =
"invoice"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods included from APIOperations::NestedResource

nested_resource_class_methods

Methods included from APIOperations::Search

_search

Methods included from APIOperations::Save

included, #save

Methods included from APIOperations::Delete

included

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_countryObject (readonly)

The country of the business associated with this invoice, most often the business creating the invoice.



991
992
993
# File 'lib/stripe/resources/invoice.rb', line 991

def 
  @account_country
end

#account_nameObject (readonly)

The public name of the business associated with this invoice, most often the business creating the invoice.



993
994
995
# File 'lib/stripe/resources/invoice.rb', line 993

def 
  @account_name
end

#account_tax_idsObject (readonly)

The account tax IDs associated with the invoice. Only editable when the invoice is a draft.



995
996
997
# File 'lib/stripe/resources/invoice.rb', line 995

def 
  @account_tax_ids
end

#amount_dueObject (readonly)

Final amount due at this time for this invoice. If the invoice's total is smaller than the minimum charge amount, for example, or if there is account credit that can be applied to the invoice, the amount_due may be 0. If there is a positive starting_balance for the invoice (the customer owes money), the amount_due will also take that into account. The charge that gets generated for the invoice will be for the amount specified in amount_due.



997
998
999
# File 'lib/stripe/resources/invoice.rb', line 997

def amount_due
  @amount_due
end

#amount_overpaidObject (readonly)

Amount that was overpaid on the invoice. The amount overpaid is credited to the customer's credit balance.



999
1000
1001
# File 'lib/stripe/resources/invoice.rb', line 999

def amount_overpaid
  @amount_overpaid
end

#amount_paidObject (readonly)

The amount, in cents (or local equivalent), that was paid.



1001
1002
1003
# File 'lib/stripe/resources/invoice.rb', line 1001

def amount_paid
  @amount_paid
end

#amount_paid_off_stripeObject (readonly)

Amount, in cents (or local equivalent), that was paid on the invoice outside of Stripe.



1003
1004
1005
# File 'lib/stripe/resources/invoice.rb', line 1003

def amount_paid_off_stripe
  @amount_paid_off_stripe
end

#amount_remainingObject (readonly)

The difference between amount_due and amount_paid, in cents (or local equivalent).



1005
1006
1007
# File 'lib/stripe/resources/invoice.rb', line 1005

def amount_remaining
  @amount_remaining
end

#amount_shippingObject (readonly)

This is the sum of all the shipping amounts.



1007
1008
1009
# File 'lib/stripe/resources/invoice.rb', line 1007

def amount_shipping
  @amount_shipping
end

#amounts_dueObject (readonly)

List of expected payments and corresponding due dates. This value will be null for invoices where collection_method=charge_automatically.



1009
1010
1011
# File 'lib/stripe/resources/invoice.rb', line 1009

def amounts_due
  @amounts_due
end

#applicationObject (readonly)

ID of the Connect Application that created the invoice.



1011
1012
1013
# File 'lib/stripe/resources/invoice.rb', line 1011

def application
  @application
end

#attempt_countObject (readonly)

Number of payment attempts made for this invoice, from the perspective of the payment retry schedule. Any payment attempt counts as the first attempt, and subsequently only automatic retries increment the attempt count. In other words, manual payment attempts after the first attempt do not affect the retry schedule. If a failure is returned with a non-retryable return code, the invoice can no longer be retried unless a new payment method is obtained. Retries will continue to be scheduled, and attempt_count will continue to increment, but retries will only be executed if a new payment method is obtained.



1013
1014
1015
# File 'lib/stripe/resources/invoice.rb', line 1013

def attempt_count
  @attempt_count
end

#attemptedObject (readonly)

Whether an attempt has been made to pay the invoice. An invoice is not attempted until 1 hour after the invoice.created webhook, for example, so you might not want to display that invoice as unpaid to your users.



1015
1016
1017
# File 'lib/stripe/resources/invoice.rb', line 1015

def attempted
  @attempted
end

#auto_advanceObject (readonly)

Controls whether Stripe performs automatic collection of the invoice. If false, the invoice's state doesn't automatically advance without an explicit action.



1017
1018
1019
# File 'lib/stripe/resources/invoice.rb', line 1017

def auto_advance
  @auto_advance
end

#automatic_taxObject (readonly)

Attribute for field automatic_tax



1019
1020
1021
# File 'lib/stripe/resources/invoice.rb', line 1019

def automatic_tax
  @automatic_tax
end

#automatically_finalizes_atObject (readonly)

The time when this invoice is currently scheduled to be automatically finalized. The field will be null if the invoice is not scheduled to finalize in the future. If the invoice is not in the draft state, this field will always be null - see finalized_at for the time when an already-finalized invoice was finalized.



1021
1022
1023
# File 'lib/stripe/resources/invoice.rb', line 1021

def automatically_finalizes_at
  @automatically_finalizes_at
end

#billing_reasonObject (readonly)

Indicates the reason why the invoice was created.

  • manual: Unrelated to a subscription, for example, created via the invoice editor.
  • subscription: No longer in use. Applies to subscriptions from before May 2018 where no distinction was made between updates, cycles, and thresholds.
  • subscription_create: A new subscription was created.
  • subscription_cycle: A subscription advanced into a new period.
  • subscription_threshold: A subscription reached a billing threshold.
  • subscription_update: A subscription was updated.
  • upcoming: Reserved for upcoming invoices created through the Create Preview Invoice API or when an invoice.upcoming event is generated for an upcoming invoice on a subscription.


1031
1032
1033
# File 'lib/stripe/resources/invoice.rb', line 1031

def billing_reason
  @billing_reason
end

#collection_methodObject (readonly)

Either charge_automatically, or send_invoice. When charging automatically, Stripe will attempt to pay this invoice using the default source attached to the customer. When sending an invoice, Stripe will email this invoice to the customer with payment instructions.



1033
1034
1035
# File 'lib/stripe/resources/invoice.rb', line 1033

def collection_method
  @collection_method
end

#confirmation_secretObject (readonly)

The confirmation secret associated with this invoice. Currently, this contains the client_secret of the PaymentIntent that Stripe creates during invoice finalization.



1035
1036
1037
# File 'lib/stripe/resources/invoice.rb', line 1035

def confirmation_secret
  @confirmation_secret
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



1037
1038
1039
# File 'lib/stripe/resources/invoice.rb', line 1037

def created
  @created
end

#currencyObject (readonly)

Three-letter ISO currency code, in lowercase. Must be a supported currency.



1039
1040
1041
# File 'lib/stripe/resources/invoice.rb', line 1039

def currency
  @currency
end

#custom_fieldsObject (readonly)

Custom fields displayed on the invoice.



1041
1042
1043
# File 'lib/stripe/resources/invoice.rb', line 1041

def custom_fields
  @custom_fields
end

#customerObject (readonly)

The ID of the customer to bill.



1043
1044
1045
# File 'lib/stripe/resources/invoice.rb', line 1043

def customer
  @customer
end

#customer_accountObject (readonly)

The ID of the account representing the customer to bill.



1045
1046
1047
# File 'lib/stripe/resources/invoice.rb', line 1045

def 
  @customer_account
end

#customer_addressObject (readonly)

The customer's address. Until the invoice is finalized, this field will equal customer.address. Once the invoice is finalized, this field will no longer be updated.



1047
1048
1049
# File 'lib/stripe/resources/invoice.rb', line 1047

def customer_address
  @customer_address
end

#customer_emailObject (readonly)

The customer's email. Until the invoice is finalized, this field will equal customer.email. Once the invoice is finalized, this field will no longer be updated.



1049
1050
1051
# File 'lib/stripe/resources/invoice.rb', line 1049

def customer_email
  @customer_email
end

#customer_nameObject (readonly)

The customer's name. Until the invoice is finalized, this field will equal customer.name. Once the invoice is finalized, this field will no longer be updated.



1051
1052
1053
# File 'lib/stripe/resources/invoice.rb', line 1051

def customer_name
  @customer_name
end

#customer_phoneObject (readonly)

The customer's phone number. Until the invoice is finalized, this field will equal customer.phone. Once the invoice is finalized, this field will no longer be updated.



1053
1054
1055
# File 'lib/stripe/resources/invoice.rb', line 1053

def customer_phone
  @customer_phone
end

#customer_shippingObject (readonly)

The customer's shipping information. Until the invoice is finalized, this field will equal customer.shipping. Once the invoice is finalized, this field will no longer be updated.



1055
1056
1057
# File 'lib/stripe/resources/invoice.rb', line 1055

def customer_shipping
  @customer_shipping
end

#customer_tax_exemptObject (readonly)

The customer's tax exempt status. Until the invoice is finalized, this field will equal customer.tax_exempt. Once the invoice is finalized, this field will no longer be updated.



1057
1058
1059
# File 'lib/stripe/resources/invoice.rb', line 1057

def customer_tax_exempt
  @customer_tax_exempt
end

#customer_tax_idsObject (readonly)

The customer's tax IDs. Until the invoice is finalized, this field will contain the same tax IDs as customer.tax_ids. Once the invoice is finalized, this field will no longer be updated.



1059
1060
1061
# File 'lib/stripe/resources/invoice.rb', line 1059

def customer_tax_ids
  @customer_tax_ids
end

#default_marginsObject (readonly)

The margins applied to the invoice. Can be overridden by line item margins. Use expand[]=default_margins to expand each margin.



1061
1062
1063
# File 'lib/stripe/resources/invoice.rb', line 1061

def default_margins
  @default_margins
end

#default_payment_methodObject (readonly)

ID of the default payment method for the invoice. It must belong to the customer associated with the invoice. If not set, defaults to the subscription's default payment method, if any, or to the default payment method in the customer's invoice settings.



1063
1064
1065
# File 'lib/stripe/resources/invoice.rb', line 1063

def default_payment_method
  @default_payment_method
end

#default_sourceObject (readonly)

ID of the default payment source for the invoice. It must belong to the customer associated with the invoice and be in a chargeable state. If not set, defaults to the subscription's default source, if any, or to the customer's default source.



1065
1066
1067
# File 'lib/stripe/resources/invoice.rb', line 1065

def default_source
  @default_source
end

#default_tax_ratesObject (readonly)

The tax rates applied to this invoice, if any.



1067
1068
1069
# File 'lib/stripe/resources/invoice.rb', line 1067

def default_tax_rates
  @default_tax_rates
end

#deletedObject (readonly)

Always true for a deleted object



1069
1070
1071
# File 'lib/stripe/resources/invoice.rb', line 1069

def deleted
  @deleted
end

#descriptionObject (readonly)

An arbitrary string attached to the object. Often useful for displaying to users. Referenced as 'memo' in the Dashboard.



1071
1072
1073
# File 'lib/stripe/resources/invoice.rb', line 1071

def description
  @description
end

#discountsObject (readonly)

The discounts applied to the invoice. Line item discounts are applied before invoice discounts. Use expand[]=discounts to expand each discount.



1073
1074
1075
# File 'lib/stripe/resources/invoice.rb', line 1073

def discounts
  @discounts
end

#due_dateObject (readonly)

The date on which payment for this invoice is due. This value will be null for invoices where collection_method=charge_automatically.



1075
1076
1077
# File 'lib/stripe/resources/invoice.rb', line 1075

def due_date
  @due_date
end

#effective_atObject (readonly)

The date when this invoice is in effect. Same as finalized_at unless overwritten. When defined, this value replaces the system-generated 'Date of issue' printed on the invoice PDF and receipt.



1077
1078
1079
# File 'lib/stripe/resources/invoice.rb', line 1077

def effective_at
  @effective_at
end

#ending_balanceObject (readonly)

Ending customer balance after the invoice is finalized. Invoices are finalized approximately an hour after successful webhook delivery or when payment collection is attempted for the invoice. If the invoice has not been finalized yet, this will be null.



1079
1080
1081
# File 'lib/stripe/resources/invoice.rb', line 1079

def ending_balance
  @ending_balance
end

Footer displayed on the invoice.



1081
1082
1083
# File 'lib/stripe/resources/invoice.rb', line 1081

def footer
  @footer
end

#from_invoiceObject (readonly)

Details of the invoice that was cloned. See the revision documentation for more details.



1083
1084
1085
# File 'lib/stripe/resources/invoice.rb', line 1083

def from_invoice
  @from_invoice
end

#hosted_invoice_urlObject (readonly)

The URL for the hosted invoice page, which allows customers to view and pay an invoice. If the invoice has not been finalized yet, this will be null.



1085
1086
1087
# File 'lib/stripe/resources/invoice.rb', line 1085

def hosted_invoice_url
  @hosted_invoice_url
end

#idObject (readonly)

Unique identifier for the object. For preview invoices created using the create preview endpoint, this id will be prefixed with upcoming_in.



1087
1088
1089
# File 'lib/stripe/resources/invoice.rb', line 1087

def id
  @id
end

#invoice_pdfObject (readonly)

The link to download the PDF for the invoice. If the invoice has not been finalized yet, this will be null.



1089
1090
1091
# File 'lib/stripe/resources/invoice.rb', line 1089

def invoice_pdf
  @invoice_pdf
end

#issuerObject (readonly)

Attribute for field issuer



1091
1092
1093
# File 'lib/stripe/resources/invoice.rb', line 1091

def issuer
  @issuer
end

#last_finalization_errorObject (readonly)

The error encountered during the previous attempt to finalize the invoice. This field is cleared when the invoice is successfully finalized.



1093
1094
1095
# File 'lib/stripe/resources/invoice.rb', line 1093

def last_finalization_error
  @last_finalization_error
end

#latest_revisionObject (readonly)

The ID of the most recent non-draft revision of this invoice



1095
1096
1097
# File 'lib/stripe/resources/invoice.rb', line 1095

def latest_revision
  @latest_revision
end

#linesObject (readonly)

The individual line items that make up the invoice. lines is sorted as follows: (1) pending invoice items (including prorations) in reverse chronological order, (2) subscription items in reverse chronological order, and (3) invoice items added after invoice creation in chronological order.



1097
1098
1099
# File 'lib/stripe/resources/invoice.rb', line 1097

def lines
  @lines
end

#livemodeObject (readonly)

If the object exists in live mode, the value is true. If the object exists in test mode, the value is false.



1099
1100
1101
# File 'lib/stripe/resources/invoice.rb', line 1099

def livemode
  @livemode
end

#metadataObject (readonly)

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



1101
1102
1103
# File 'lib/stripe/resources/invoice.rb', line 1101

def 
  @metadata
end

#next_payment_attemptObject (readonly)

The time at which payment will next be attempted. This value will be null for invoices where collection_method=send_invoice.



1103
1104
1105
# File 'lib/stripe/resources/invoice.rb', line 1103

def next_payment_attempt
  @next_payment_attempt
end

#numberObject (readonly)

A unique, identifying string that appears on emails sent to the customer for this invoice. This starts with the customer's unique invoice_prefix if it is specified.



1105
1106
1107
# File 'lib/stripe/resources/invoice.rb', line 1105

def number
  @number
end

#objectObject (readonly)

String representing the object's type. Objects of the same type share the same value.



1107
1108
1109
# File 'lib/stripe/resources/invoice.rb', line 1107

def object
  @object
end

#on_behalf_ofObject (readonly)

The account (if any) for which the funds of the invoice payment are intended. If set, the invoice will be presented with the branding and support information of the specified account. See the Invoices with Connect documentation for details.



1109
1110
1111
# File 'lib/stripe/resources/invoice.rb', line 1109

def on_behalf_of
  @on_behalf_of
end

#parentObject (readonly)

The parent that generated this invoice



1111
1112
1113
# File 'lib/stripe/resources/invoice.rb', line 1111

def parent
  @parent
end

#payment_settingsObject (readonly)

Attribute for field payment_settings



1113
1114
1115
# File 'lib/stripe/resources/invoice.rb', line 1113

def payment_settings
  @payment_settings
end

#paymentsObject (readonly)

Payments for this invoice. Use invoice payment to get more details.



1115
1116
1117
# File 'lib/stripe/resources/invoice.rb', line 1115

def payments
  @payments
end

#period_endObject (readonly)

The latest timestamp at which invoice items can be associated with this invoice. Use the line item period to get the service period for each price.



1117
1118
1119
# File 'lib/stripe/resources/invoice.rb', line 1117

def period_end
  @period_end
end

#period_startObject (readonly)

The earliest timestamp at which invoice items can be associated with this invoice. Use the line item period to get the service period for each price.



1119
1120
1121
# File 'lib/stripe/resources/invoice.rb', line 1119

def period_start
  @period_start
end

#post_payment_credit_notes_amountObject (readonly)

Total amount of all post-payment credit notes issued for this invoice.



1121
1122
1123
# File 'lib/stripe/resources/invoice.rb', line 1121

def post_payment_credit_notes_amount
  @post_payment_credit_notes_amount
end

#pre_payment_credit_notes_amountObject (readonly)

Total amount of all pre-payment credit notes issued for this invoice.



1123
1124
1125
# File 'lib/stripe/resources/invoice.rb', line 1123

def pre_payment_credit_notes_amount
  @pre_payment_credit_notes_amount
end

#receipt_numberObject (readonly)

This is the transaction number that appears on email receipts sent for this invoice.



1125
1126
1127
# File 'lib/stripe/resources/invoice.rb', line 1125

def receipt_number
  @receipt_number
end

#renderingObject (readonly)

The rendering-related settings that control how the invoice is displayed on customer-facing surfaces such as PDF and Hosted Invoice Page.



1127
1128
1129
# File 'lib/stripe/resources/invoice.rb', line 1127

def rendering
  @rendering
end

#shipping_costObject (readonly)

The details of the cost of shipping, including the ShippingRate applied on the invoice.



1129
1130
1131
# File 'lib/stripe/resources/invoice.rb', line 1129

def shipping_cost
  @shipping_cost
end

#shipping_detailsObject (readonly)

Shipping details for the invoice. The Invoice PDF will use the shipping_details value if it is set, otherwise the PDF will render the shipping address from the customer.



1131
1132
1133
# File 'lib/stripe/resources/invoice.rb', line 1131

def shipping_details
  @shipping_details
end

#starting_balanceObject (readonly)

Starting customer balance before the invoice is finalized. If the invoice has not been finalized yet, this will be the current customer balance. For revision invoices, this also includes any customer balance that was applied to the original invoice.



1133
1134
1135
# File 'lib/stripe/resources/invoice.rb', line 1133

def starting_balance
  @starting_balance
end

#statement_descriptorObject (readonly)

Extra information about an invoice for the customer's credit card statement.



1135
1136
1137
# File 'lib/stripe/resources/invoice.rb', line 1135

def statement_descriptor
  @statement_descriptor
end

#statusObject (readonly)

The status of the invoice, one of draft, open, paid, uncollectible, or void. Learn more



1137
1138
1139
# File 'lib/stripe/resources/invoice.rb', line 1137

def status
  @status
end

#status_transitionsObject (readonly)

Attribute for field status_transitions



1139
1140
1141
# File 'lib/stripe/resources/invoice.rb', line 1139

def status_transitions
  @status_transitions
end

#subtotalObject (readonly)

Total of all subscriptions, invoice items, and prorations on the invoice before any invoice level discount or exclusive tax is applied. Item discounts are already incorporated



1141
1142
1143
# File 'lib/stripe/resources/invoice.rb', line 1141

def subtotal
  @subtotal
end

#subtotal_excluding_taxObject (readonly)

The integer amount in cents (or local equivalent) representing the subtotal of the invoice before any invoice level discount or tax is applied. Item discounts are already incorporated



1143
1144
1145
# File 'lib/stripe/resources/invoice.rb', line 1143

def subtotal_excluding_tax
  @subtotal_excluding_tax
end

#test_clockObject (readonly)

ID of the test clock this invoice belongs to.



1145
1146
1147
# File 'lib/stripe/resources/invoice.rb', line 1145

def test_clock
  @test_clock
end

#threshold_reasonObject (readonly)

Attribute for field threshold_reason



1147
1148
1149
# File 'lib/stripe/resources/invoice.rb', line 1147

def threshold_reason
  @threshold_reason
end

#totalObject (readonly)

Total after discounts and taxes.



1149
1150
1151
# File 'lib/stripe/resources/invoice.rb', line 1149

def total
  @total
end

#total_discount_amountsObject (readonly)

The aggregate amounts calculated per discount across all line items.



1151
1152
1153
# File 'lib/stripe/resources/invoice.rb', line 1151

def total_discount_amounts
  @total_discount_amounts
end

#total_excluding_taxObject (readonly)

The integer amount in cents (or local equivalent) representing the total amount of the invoice including all discounts but excluding all tax.



1153
1154
1155
# File 'lib/stripe/resources/invoice.rb', line 1153

def total_excluding_tax
  @total_excluding_tax
end

#total_margin_amountsObject (readonly)

The aggregate amounts calculated per margin across all line items.



1155
1156
1157
# File 'lib/stripe/resources/invoice.rb', line 1155

def total_margin_amounts
  @total_margin_amounts
end

#total_pretax_credit_amountsObject (readonly)

Contains pretax credit amounts (ex: discount, credit grants, etc) that apply to this invoice. This is a combined list of total_pretax_credit_amounts across all invoice line items.



1157
1158
1159
# File 'lib/stripe/resources/invoice.rb', line 1157

def total_pretax_credit_amounts
  @total_pretax_credit_amounts
end

#total_taxesObject (readonly)

The aggregate tax information of all line items.



1159
1160
1161
# File 'lib/stripe/resources/invoice.rb', line 1159

def total_taxes
  @total_taxes
end

#webhooks_delivered_atObject (readonly)

Invoices are automatically paid or sent 1 hour after webhooks are delivered, or until all webhook delivery attempts have been exhausted. This field tracks the time when webhooks for this invoice were successfully delivered. If the invoice had no webhooks to deliver, this will be set while the invoice is being created.



1161
1162
1163
# File 'lib/stripe/resources/invoice.rb', line 1161

def webhooks_delivered_at
  @webhooks_delivered_at
end

Class Method Details

.add_lines(invoice, params = {}, opts = {}) ⇒ Object

Adds multiple line items to an invoice. This is only possible when an invoice is still a draft.



1174
1175
1176
1177
1178
1179
1180
1181
# File 'lib/stripe/resources/invoice.rb', line 1174

def self.add_lines(invoice, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/invoices/%<invoice>s/add_lines", { invoice: CGI.escape(invoice) }),
    params: params,
    opts: opts
  )
end

.attach_payment(invoice, params = {}, opts = {}) ⇒ Object

Attaches a PaymentIntent or an Out of Band Payment to the invoice, adding it to the list of payments.

For the PaymentIntent, when the PaymentIntent's status changes to succeeded, the payment is credited to the invoice, increasing its amount_paid. When the invoice is fully paid, the invoice's status becomes paid.

If the PaymentIntent's status is already succeeded when it's attached, it's credited to the invoice immediately.

See: Partial payments to learn more.



1212
1213
1214
1215
1216
1217
1218
1219
# File 'lib/stripe/resources/invoice.rb', line 1212

def self.attach_payment(invoice, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/invoices/%<invoice>s/attach_payment", { invoice: CGI.escape(invoice) }),
    params: params,
    opts: opts
  )
end

.create(params = {}, opts = {}) ⇒ Object

This endpoint creates a draft invoice for a given customer. The invoice remains a draft until you [finalize the invoice, which allows you to pay or send](https://docs.stripe.com/api/invoices/finalize) the invoice to your customers.



1222
1223
1224
# File 'lib/stripe/resources/invoice.rb', line 1222

def self.create(params = {}, opts = {})
  request_stripe_object(method: :post, path: "/v1/invoices", params: params, opts: opts)
end

.create_preview(params = {}, opts = {}) ⇒ Object

At any time, you can preview the upcoming invoice for a subscription or subscription schedule. This will show you all the charges that are pending, including subscription renewal charges, invoice item charges, etc. It will also show you any discounts that are applicable to the invoice.

You can also preview the effects of creating or updating a subscription or subscription schedule, including a preview of any prorations that will take place. To ensure that the actual proration is calculated exactly the same as the previewed proration, you should pass the subscription_details.proration_date parameter when doing the actual subscription update.

The recommended way to get only the prorations being previewed on the invoice is to consider line items where parent.subscription_item_details.proration is true.

Note that when you are viewing an upcoming invoice, you are simply viewing a preview – the invoice has not yet been created. As such, the upcoming invoice will not show up in invoice listing calls, and you cannot use the API to pay or edit the invoice. If you want to change the amount that your customer will be billed, you can add, remove, or update pending invoice items, or update the customer's discount.

Note: Currency conversion calculations use the latest exchange rates. Exchange rates may vary between the time of the preview and the time of the actual invoice creation. Learn more



1235
1236
1237
1238
1239
1240
1241
1242
# File 'lib/stripe/resources/invoice.rb', line 1235

def self.create_preview(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/invoices/create_preview",
    params: params,
    opts: opts
  )
end

.delete(invoice, params = {}, opts = {}) ⇒ Object

Permanently deletes a one-off invoice draft. This cannot be undone. Attempts to delete invoices that are no longer in a draft state will fail; once an invoice has been finalized or if an invoice is for a subscription, it must be voided.



1245
1246
1247
1248
1249
1250
1251
1252
# File 'lib/stripe/resources/invoice.rb', line 1245

def self.delete(invoice, params = {}, opts = {})
  request_stripe_object(
    method: :delete,
    path: format("/v1/invoices/%<invoice>s", { invoice: CGI.escape(invoice) }),
    params: params,
    opts: opts
  )
end

.detach_payment(invoice, params = {}, opts = {}) ⇒ Object

Detaches a payment from the invoice, removing it from the list of payments



1275
1276
1277
1278
1279
1280
1281
1282
# File 'lib/stripe/resources/invoice.rb', line 1275

def self.detach_payment(invoice, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/invoices/%<invoice>s/detach_payment", { invoice: CGI.escape(invoice) }),
    params: params,
    opts: opts
  )
end

.field_remappingsObject



1486
1487
1488
# File 'lib/stripe/resources/invoice.rb', line 1486

def self.field_remappings
  @field_remappings = {}
end

.finalize_invoice(invoice, params = {}, opts = {}) ⇒ Object

Stripe automatically finalizes drafts before sending and attempting payment on invoices. However, if you'd like to finalize a draft invoice manually, you can do so using this method.



1295
1296
1297
1298
1299
1300
1301
1302
# File 'lib/stripe/resources/invoice.rb', line 1295

def self.finalize_invoice(invoice, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/invoices/%<invoice>s/finalize", { invoice: CGI.escape(invoice) }),
    params: params,
    opts: opts
  )
end

.inner_class_typesObject



1460
1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
1481
1482
1483
1484
# File 'lib/stripe/resources/invoice.rb', line 1460

def self.inner_class_types
  @inner_class_types = {
    amounts_due: AmountsDue,
    automatic_tax: AutomaticTax,
    confirmation_secret: ConfirmationSecret,
    custom_fields: CustomField,
    customer_address: CustomerAddress,
    customer_shipping: CustomerShipping,
    customer_tax_ids: CustomerTaxId,
    from_invoice: FromInvoice,
    issuer: Issuer,
    last_finalization_error: LastFinalizationError,
    parent: Parent,
    payment_settings: PaymentSettings,
    rendering: Rendering,
    shipping_cost: ShippingCost,
    shipping_details: ShippingDetails,
    status_transitions: StatusTransitions,
    threshold_reason: ThresholdReason,
    total_discount_amounts: TotalDiscountAmount,
    total_margin_amounts: TotalMarginAmount,
    total_pretax_credit_amounts: TotalPretaxCreditAmount,
    total_taxes: TotalTax,
  }
end

.list(params = {}, opts = {}) ⇒ Object

You can list all invoices, or list the invoices for a specific customer. The invoices are returned sorted by creation date, with the most recently created invoices appearing first.



1305
1306
1307
# File 'lib/stripe/resources/invoice.rb', line 1305

def self.list(params = {}, opts = {})
  request_stripe_object(method: :get, path: "/v1/invoices", params: params, opts: opts)
end

.mark_uncollectible(invoice, params = {}, opts = {}) ⇒ Object

Marking an invoice as uncollectible is useful for keeping track of bad debts that can be written off for accounting purposes.



1320
1321
1322
1323
1324
1325
1326
1327
# File 'lib/stripe/resources/invoice.rb', line 1320

def self.mark_uncollectible(invoice, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/invoices/%<invoice>s/mark_uncollectible", { invoice: CGI.escape(invoice) }),
    params: params,
    opts: opts
  )
end

.object_nameObject



46
47
48
# File 'lib/stripe/resources/invoice.rb', line 46

def self.object_name
  "invoice"
end

.pay(invoice, params = {}, opts = {}) ⇒ Object

Stripe automatically creates and then attempts to collect payment on invoices for customers on subscriptions according to your subscriptions settings. However, if you'd like to attempt payment on an invoice out of the normal collection schedule or for some other reason, you can do so.



1340
1341
1342
1343
1344
1345
1346
1347
# File 'lib/stripe/resources/invoice.rb', line 1340

def self.pay(invoice, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/invoices/%<invoice>s/pay", { invoice: CGI.escape(invoice) }),
    params: params,
    opts: opts
  )
end

.remove_lines(invoice, params = {}, opts = {}) ⇒ Object

Removes multiple line items from an invoice. This is only possible when an invoice is still a draft.



1360
1361
1362
1363
1364
1365
1366
1367
# File 'lib/stripe/resources/invoice.rb', line 1360

def self.remove_lines(invoice, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/invoices/%<invoice>s/remove_lines", { invoice: CGI.escape(invoice) }),
    params: params,
    opts: opts
  )
end

.search(params = {}, opts = {}) ⇒ Object



1369
1370
1371
# File 'lib/stripe/resources/invoice.rb', line 1369

def self.search(params = {}, opts = {})
  request_stripe_object(method: :get, path: "/v1/invoices/search", params: params, opts: opts)
end

.search_auto_paging_each(params = {}, opts = {}, &blk) ⇒ Object



1373
1374
1375
# File 'lib/stripe/resources/invoice.rb', line 1373

def self.search_auto_paging_each(params = {}, opts = {}, &blk)
  search(params, opts).auto_paging_each(&blk)
end

.send_invoice(invoice, params = {}, opts = {}) ⇒ Object

Stripe will automatically send invoices to customers according to your subscriptions settings. However, if you'd like to manually send an invoice to your customer out of the normal schedule, you can do so. When sending invoices that have already been paid, there will be no reference to the payment in the email.

Requests made in test-mode result in no emails being sent, despite sending an invoice.sent event.



1392
1393
1394
1395
1396
1397
1398
1399
# File 'lib/stripe/resources/invoice.rb', line 1392

def self.send_invoice(invoice, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/invoices/%<invoice>s/send", { invoice: CGI.escape(invoice) }),
    params: params,
    opts: opts
  )
end

.update(invoice, params = {}, opts = {}) ⇒ Object

Draft invoices are fully editable. Once an invoice is finalized, monetary values, as well as collection_method, become uneditable.

If you would like to stop the Stripe Billing engine from automatically finalizing, reattempting payments on, sending reminders for, or automatically reconciling invoices, pass auto_advance=false.



1407
1408
1409
1410
1411
1412
1413
1414
# File 'lib/stripe/resources/invoice.rb', line 1407

def self.update(invoice, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/invoices/%<invoice>s", { invoice: CGI.escape(invoice) }),
    params: params,
    opts: opts
  )
end

.update_lines(invoice, params = {}, opts = {}) ⇒ Object

Updates multiple line items on an invoice. This is only possible when an invoice is still a draft.



1427
1428
1429
1430
1431
1432
1433
1434
# File 'lib/stripe/resources/invoice.rb', line 1427

def self.update_lines(invoice, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/invoices/%<invoice>s/update_lines", { invoice: CGI.escape(invoice) }),
    params: params,
    opts: opts
  )
end

.void_invoice(invoice, params = {}, opts = {}) ⇒ Object

Mark a finalized invoice as void. This cannot be undone. Voiding an invoice is similar to deletion, however it only applies to finalized invoices and maintains a papertrail where the invoice can still be found.

Consult with local regulations to determine whether and how an invoice might be amended, canceled, or voided in the jurisdiction you're doing business in. You might need to [issue another invoice or credit note](https://docs.stripe.com/api/invoices/create) instead. Stripe recommends that you consult with your legal counsel for advice specific to your business.



1451
1452
1453
1454
1455
1456
1457
1458
# File 'lib/stripe/resources/invoice.rb', line 1451

def self.void_invoice(invoice, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/invoices/%<invoice>s/void", { invoice: CGI.escape(invoice) }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#add_lines(params = {}, opts = {}) ⇒ Object

Adds multiple line items to an invoice. This is only possible when an invoice is still a draft.



1164
1165
1166
1167
1168
1169
1170
1171
# File 'lib/stripe/resources/invoice.rb', line 1164

def add_lines(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/invoices/%<invoice>s/add_lines", { invoice: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#attach_payment(params = {}, opts = {}) ⇒ Object

Attaches a PaymentIntent or an Out of Band Payment to the invoice, adding it to the list of payments.

For the PaymentIntent, when the PaymentIntent's status changes to succeeded, the payment is credited to the invoice, increasing its amount_paid. When the invoice is fully paid, the invoice's status becomes paid.

If the PaymentIntent's status is already succeeded when it's attached, it's credited to the invoice immediately.

See: Partial payments to learn more.



1193
1194
1195
1196
1197
1198
1199
1200
# File 'lib/stripe/resources/invoice.rb', line 1193

def attach_payment(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/invoices/%<invoice>s/attach_payment", { invoice: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#delete(params = {}, opts = {}) ⇒ Object

Permanently deletes a one-off invoice draft. This cannot be undone. Attempts to delete invoices that are no longer in a draft state will fail; once an invoice has been finalized or if an invoice is for a subscription, it must be voided.



1255
1256
1257
1258
1259
1260
1261
1262
# File 'lib/stripe/resources/invoice.rb', line 1255

def delete(params = {}, opts = {})
  request_stripe_object(
    method: :delete,
    path: format("/v1/invoices/%<invoice>s", { invoice: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#detach_payment(params = {}, opts = {}) ⇒ Object

Detaches a payment from the invoice, removing it from the list of payments



1265
1266
1267
1268
1269
1270
1271
1272
# File 'lib/stripe/resources/invoice.rb', line 1265

def detach_payment(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/invoices/%<invoice>s/detach_payment", { invoice: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#finalize_invoice(params = {}, opts = {}) ⇒ Object

Stripe automatically finalizes drafts before sending and attempting payment on invoices. However, if you'd like to finalize a draft invoice manually, you can do so using this method.



1285
1286
1287
1288
1289
1290
1291
1292
# File 'lib/stripe/resources/invoice.rb', line 1285

def finalize_invoice(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/invoices/%<invoice>s/finalize", { invoice: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#mark_uncollectible(params = {}, opts = {}) ⇒ Object

Marking an invoice as uncollectible is useful for keeping track of bad debts that can be written off for accounting purposes.



1310
1311
1312
1313
1314
1315
1316
1317
# File 'lib/stripe/resources/invoice.rb', line 1310

def mark_uncollectible(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/invoices/%<invoice>s/mark_uncollectible", { invoice: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#pay(params = {}, opts = {}) ⇒ Object

Stripe automatically creates and then attempts to collect payment on invoices for customers on subscriptions according to your subscriptions settings. However, if you'd like to attempt payment on an invoice out of the normal collection schedule or for some other reason, you can do so.



1330
1331
1332
1333
1334
1335
1336
1337
# File 'lib/stripe/resources/invoice.rb', line 1330

def pay(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/invoices/%<invoice>s/pay", { invoice: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#remove_lines(params = {}, opts = {}) ⇒ Object

Removes multiple line items from an invoice. This is only possible when an invoice is still a draft.



1350
1351
1352
1353
1354
1355
1356
1357
# File 'lib/stripe/resources/invoice.rb', line 1350

def remove_lines(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/invoices/%<invoice>s/remove_lines", { invoice: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#send_invoice(params = {}, opts = {}) ⇒ Object

Stripe will automatically send invoices to customers according to your subscriptions settings. However, if you'd like to manually send an invoice to your customer out of the normal schedule, you can do so. When sending invoices that have already been paid, there will be no reference to the payment in the email.

Requests made in test-mode result in no emails being sent, despite sending an invoice.sent event.



1380
1381
1382
1383
1384
1385
1386
1387
# File 'lib/stripe/resources/invoice.rb', line 1380

def send_invoice(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/invoices/%<invoice>s/send", { invoice: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#update_lines(params = {}, opts = {}) ⇒ Object

Updates multiple line items on an invoice. This is only possible when an invoice is still a draft.



1417
1418
1419
1420
1421
1422
1423
1424
# File 'lib/stripe/resources/invoice.rb', line 1417

def update_lines(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/invoices/%<invoice>s/update_lines", { invoice: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#void_invoice(params = {}, opts = {}) ⇒ Object

Mark a finalized invoice as void. This cannot be undone. Voiding an invoice is similar to deletion, however it only applies to finalized invoices and maintains a papertrail where the invoice can still be found.

Consult with local regulations to determine whether and how an invoice might be amended, canceled, or voided in the jurisdiction you're doing business in. You might need to [issue another invoice or credit note](https://docs.stripe.com/api/invoices/create) instead. Stripe recommends that you consult with your legal counsel for advice specific to your business.



1439
1440
1441
1442
1443
1444
1445
1446
# File 'lib/stripe/resources/invoice.rb', line 1439

def void_invoice(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/invoices/%<invoice>s/void", { invoice: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end