Class: Stripe::Invoice::AddLinesParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Line

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, invoice_metadata: nil, lines: nil) ⇒ AddLinesParams

Returns a new instance of AddLinesParams.



2610
2611
2612
2613
2614
# File 'lib/stripe/resources/invoice.rb', line 2610

def initialize(expand: nil, invoice_metadata: nil, lines: nil)
  @expand = expand
  @invoice_metadata = 
  @lines = lines
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



2604
2605
2606
# File 'lib/stripe/resources/invoice.rb', line 2604

def expand
  @expand
end

#invoice_metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2606
2607
2608
# File 'lib/stripe/resources/invoice.rb', line 2606

def 
  @invoice_metadata
end

#linesObject

The line items to add.



2608
2609
2610
# File 'lib/stripe/resources/invoice.rb', line 2608

def lines
  @lines
end