Class: Stripe::Invoice::AddLinesParams::Line::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1992
1993
1994
1995
1996
1997
# File 'lib/stripe/resources/invoice.rb', line 1992

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1984
1985
1986
# File 'lib/stripe/resources/invoice.rb', line 1984

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1986
1987
1988
# File 'lib/stripe/resources/invoice.rb', line 1986

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1988
1989
1990
# File 'lib/stripe/resources/invoice.rb', line 1988

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1990
1991
1992
# File 'lib/stripe/resources/invoice.rb', line 1990

def promotion_code
  @promotion_code
end