Class: Stripe::Invoice::AddLinesParams::Line::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::AddLinesParams::Line::Discount::DiscountEnd
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
1977 1978 1979 1980 1981 |
# File 'lib/stripe/resources/invoice.rb', line 1977 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
1971 1972 1973 |
# File 'lib/stripe/resources/invoice.rb', line 1971 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
1973 1974 1975 |
# File 'lib/stripe/resources/invoice.rb', line 1973 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
1975 1976 1977 |
# File 'lib/stripe/resources/invoice.rb', line 1975 def type @type end |