Class: Stripe::Invoice::AddLinesParams::Line::Discount::DiscountEnd::Duration
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::AddLinesParams::Line::Discount::DiscountEnd::Duration
- Defined in:
- lib/stripe/resources/invoice.rb
Instance Attribute Summary collapse
-
#interval ⇒ Object
Specifies a type of interval unit.
-
#interval_count ⇒ Object
The number of intervals, as an whole number greater than 0.
Instance Method Summary collapse
-
#initialize(interval: nil, interval_count: nil) ⇒ Duration
constructor
A new instance of Duration.
Methods inherited from RequestParams
Constructor Details
#initialize(interval: nil, interval_count: nil) ⇒ Duration
Returns a new instance of Duration.
2373 2374 2375 2376 |
# File 'lib/stripe/resources/invoice.rb', line 2373 def initialize(interval: nil, interval_count: nil) @interval = interval @interval_count = interval_count end |
Instance Attribute Details
#interval ⇒ Object
Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.
2369 2370 2371 |
# File 'lib/stripe/resources/invoice.rb', line 2369 def interval @interval end |
#interval_count ⇒ Object
The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.
2371 2372 2373 |
# File 'lib/stripe/resources/invoice.rb', line 2371 def interval_count @interval_count end |