Class: Stripe::Invoice::AddLinesParams::Line::Period
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::AddLinesParams::Line::Period
- Defined in:
- lib/stripe/resources/invoice.rb
Instance Attribute Summary collapse
-
#end ⇒ Object
The end of the period, which must be greater than or equal to the start.
-
#start ⇒ Object
The start of the period.
Instance Method Summary collapse
-
#initialize(end_: nil, start: nil) ⇒ Period
constructor
A new instance of Period.
Methods inherited from RequestParams
Constructor Details
#initialize(end_: nil, start: nil) ⇒ Period
Returns a new instance of Period.
1999 2000 2001 2002 |
# File 'lib/stripe/resources/invoice.rb', line 1999 def initialize(end_: nil, start: nil) @end = end_ @start = start end |
Instance Attribute Details
#end ⇒ Object
The end of the period, which must be greater than or equal to the start. This value is inclusive.
1995 1996 1997 |
# File 'lib/stripe/resources/invoice.rb', line 1995 def end @end end |
#start ⇒ Object
The start of the period. This value is inclusive.
1997 1998 1999 |
# File 'lib/stripe/resources/invoice.rb', line 1997 def start @start end |