Class: Stripe::Invoice::AddLinesParams::Line::PriceData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::AddLinesParams::Line::PriceData
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: ProductData
Instance Attribute Summary collapse
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#product ⇒ Object
The ID of the product that this price will belong to.
-
#product_data ⇒ Object
Data used to generate a new product object inline.
-
#tax_behavior ⇒ Object
Only required if a [default tax behavior](stripe.com/docs/tax/products-prices-tax-categories-tax-behavior#setting-a-default-tax-behavior-(recommended)) was not provided in the Stripe Tax settings.
-
#unit_amount ⇒ Object
A non-negative integer in cents (or local equivalent) representing how much to charge.
-
#unit_amount_decimal ⇒ Object
Same as ‘unit_amount`, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places.
Instance Method Summary collapse
-
#initialize(currency: nil, product: nil, product_data: nil, tax_behavior: nil, unit_amount: nil, unit_amount_decimal: nil) ⇒ PriceData
constructor
A new instance of PriceData.
Methods inherited from RequestParams
Constructor Details
#initialize(currency: nil, product: nil, product_data: nil, tax_behavior: nil, unit_amount: nil, unit_amount_decimal: nil) ⇒ PriceData
Returns a new instance of PriceData.
5666 5667 5668 5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 |
# File 'lib/stripe/resources/invoice.rb', line 5666 def initialize( currency: nil, product: nil, product_data: nil, tax_behavior: nil, unit_amount: nil, unit_amount_decimal: nil ) @currency = currency @product = product @product_data = product_data @tax_behavior = tax_behavior @unit_amount = unit_amount @unit_amount_decimal = unit_amount_decimal end |
Instance Attribute Details
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
5654 5655 5656 |
# File 'lib/stripe/resources/invoice.rb', line 5654 def currency @currency end |
#product ⇒ Object
The ID of the product that this price will belong to. One of ‘product` or `product_data` is required.
5656 5657 5658 |
# File 'lib/stripe/resources/invoice.rb', line 5656 def product @product end |
#product_data ⇒ Object
Data used to generate a new product object inline. One of ‘product` or `product_data` is required.
5658 5659 5660 |
# File 'lib/stripe/resources/invoice.rb', line 5658 def product_data @product_data end |
#tax_behavior ⇒ Object
Only required if a [default tax behavior](stripe.com/docs/tax/products-prices-tax-categories-tax-behavior#setting-a-default-tax-behavior-(recommended)) was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`. Once specified as either `inclusive` or `exclusive`, it cannot be changed.
5660 5661 5662 |
# File 'lib/stripe/resources/invoice.rb', line 5660 def tax_behavior @tax_behavior end |
#unit_amount ⇒ Object
A non-negative integer in cents (or local equivalent) representing how much to charge. One of ‘unit_amount` or `unit_amount_decimal` is required.
5662 5663 5664 |
# File 'lib/stripe/resources/invoice.rb', line 5662 def unit_amount @unit_amount end |
#unit_amount_decimal ⇒ Object
Same as ‘unit_amount`, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places. Only one of `unit_amount` and `unit_amount_decimal` can be set.
5664 5665 5666 |
# File 'lib/stripe/resources/invoice.rb', line 5664 def unit_amount_decimal @unit_amount_decimal end |