Class: Stripe::Invoice::AddLinesParams::Line::PriceData::ProductData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil) ⇒ ProductData

Returns a new instance of ProductData.



2025
2026
2027
2028
2029
2030
2031
# File 'lib/stripe/resources/invoice.rb', line 2025

def initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil)
  @description = description
  @images = images
  @metadata = 
  @name = name
  @tax_code = tax_code
end

Instance Attribute Details

#descriptionObject

The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.



2015
2016
2017
# File 'lib/stripe/resources/invoice.rb', line 2015

def description
  @description
end

#imagesObject

A list of up to 8 URLs of images for this product, meant to be displayable to the customer.



2017
2018
2019
# File 'lib/stripe/resources/invoice.rb', line 2017

def images
  @images
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2019
2020
2021
# File 'lib/stripe/resources/invoice.rb', line 2019

def 
  @metadata
end

#nameObject

The product’s name, meant to be displayable to the customer.



2021
2022
2023
# File 'lib/stripe/resources/invoice.rb', line 2021

def name
  @name
end

#tax_codeObject



2023
2024
2025
# File 'lib/stripe/resources/invoice.rb', line 2023

def tax_code
  @tax_code
end