Class: Stripe::Invoice::AmountsDue

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/invoice.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Incremental amount due for this payment in cents (or local equivalent).



54
55
56
# File 'lib/stripe/resources/invoice.rb', line 54

def amount
  @amount
end

#amount_paidObject (readonly)

The amount in cents (or local equivalent) that was paid for this payment.



56
57
58
# File 'lib/stripe/resources/invoice.rb', line 56

def amount_paid
  @amount_paid
end

#amount_remainingObject (readonly)

The difference between the payment’s amount and amount_paid, in cents (or local equivalent).



58
59
60
# File 'lib/stripe/resources/invoice.rb', line 58

def amount_remaining
  @amount_remaining
end

#days_until_dueObject (readonly)

Number of days from when invoice is finalized until the payment is due.



60
61
62
# File 'lib/stripe/resources/invoice.rb', line 60

def days_until_due
  @days_until_due
end

#descriptionObject (readonly)

An arbitrary string attached to the object. Often useful for displaying to users.



62
63
64
# File 'lib/stripe/resources/invoice.rb', line 62

def description
  @description
end

#due_dateObject (readonly)

Date on which a payment plan’s payment is due.



64
65
66
# File 'lib/stripe/resources/invoice.rb', line 64

def due_date
  @due_date
end

Timestamp when the payment was paid.



66
67
68
# File 'lib/stripe/resources/invoice.rb', line 66

def paid_at
  @paid_at
end

#statusObject (readonly)

The status of the payment, one of ‘open`, `paid`, or `past_due`



68
69
70
# File 'lib/stripe/resources/invoice.rb', line 68

def status
  @status
end

Class Method Details

.field_remappingsObject



74
75
76
# File 'lib/stripe/resources/invoice.rb', line 74

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



70
71
72
# File 'lib/stripe/resources/invoice.rb', line 70

def self.inner_class_types
  @inner_class_types = {}
end