Class: Stripe::Invoice::AttachPaymentIntentParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::AttachPaymentIntentParams
- Defined in:
- lib/stripe/resources/invoice.rb
Instance Attribute Summary collapse
-
#amount_requested ⇒ Object
The portion of the PaymentIntent’s ‘amount` that should be applied to thisinvoice.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#payment_intent ⇒ Object
The ID of the PaymentIntent to attach to the invoice.
Instance Method Summary collapse
-
#initialize(amount_requested: nil, expand: nil, payment_intent: nil) ⇒ AttachPaymentIntentParams
constructor
A new instance of AttachPaymentIntentParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount_requested: nil, expand: nil, payment_intent: nil) ⇒ AttachPaymentIntentParams
Returns a new instance of AttachPaymentIntentParams.
2202 2203 2204 2205 2206 |
# File 'lib/stripe/resources/invoice.rb', line 2202 def initialize(amount_requested: nil, expand: nil, payment_intent: nil) @amount_requested = amount_requested @expand = @payment_intent = payment_intent end |
Instance Attribute Details
#amount_requested ⇒ Object
The portion of the PaymentIntent’s ‘amount` that should be applied to thisinvoice. Defaults to the entire amount.
2196 2197 2198 |
# File 'lib/stripe/resources/invoice.rb', line 2196 def amount_requested @amount_requested end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2198 2199 2200 |
# File 'lib/stripe/resources/invoice.rb', line 2198 def @expand end |
#payment_intent ⇒ Object
The ID of the PaymentIntent to attach to the invoice.
2200 2201 2202 |
# File 'lib/stripe/resources/invoice.rb', line 2200 def payment_intent @payment_intent end |