Class: Stripe::Invoice::AttachPaymentParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: PaymentRecordData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_requested: nil, expand: nil, payment_intent: nil, payment_record: nil, payment_record_data: nil) ⇒ AttachPaymentParams

Returns a new instance of AttachPaymentParams.



2659
2660
2661
2662
2663
2664
2665
2666
2667
2668
2669
2670
2671
# File 'lib/stripe/resources/invoice.rb', line 2659

def initialize(
  amount_requested: nil,
  expand: nil,
  payment_intent: nil,
  payment_record: nil,
  payment_record_data: nil
)
  @amount_requested = amount_requested
  @expand = expand
  @payment_intent = payment_intent
  @payment_record = payment_record
  @payment_record_data = payment_record_data
end

Instance Attribute Details

#amount_requestedObject

The portion of the ‘amount` on the PaymentIntent or out of band payment to apply to this invoice. It defaults to the entire amount.



2649
2650
2651
# File 'lib/stripe/resources/invoice.rb', line 2649

def amount_requested
  @amount_requested
end

#expandObject

Specifies which fields in the response should be expanded.



2651
2652
2653
# File 'lib/stripe/resources/invoice.rb', line 2651

def expand
  @expand
end

#payment_intentObject

The ID of the PaymentIntent to attach to the invoice.



2653
2654
2655
# File 'lib/stripe/resources/invoice.rb', line 2653

def payment_intent
  @payment_intent
end

#payment_recordObject

The ID of the PaymentRecord to attach to the invoice.



2655
2656
2657
# File 'lib/stripe/resources/invoice.rb', line 2655

def payment_record
  @payment_record
end

#payment_record_dataObject

The PaymentRecord data for attaching an out of band payment to the invoice.



2657
2658
2659
# File 'lib/stripe/resources/invoice.rb', line 2657

def payment_record_data
  @payment_record_data
end