Class: Stripe::Invoice::AttachPaymentParams::PaymentRecordData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, currency: nil, metadata: nil, money_movement_type: nil, paid_at: nil, payment_reference: nil) ⇒ PaymentRecordData

Returns a new instance of PaymentRecordData.



2632
2633
2634
2635
2636
2637
2638
2639
2640
2641
2642
2643
2644
2645
2646
# File 'lib/stripe/resources/invoice.rb', line 2632

def initialize(
  amount: nil,
  currency: nil,
  metadata: nil,
  money_movement_type: nil,
  paid_at: nil,
  payment_reference: nil
)
  @amount = amount
  @currency = currency
  @metadata = 
  @money_movement_type = money_movement_type
  @paid_at = paid_at
  @payment_reference = payment_reference
end

Instance Attribute Details

#amountObject

The amount that was paid out of band.



2620
2621
2622
# File 'lib/stripe/resources/invoice.rb', line 2620

def amount
  @amount
end

#currencyObject

The currency that was paid out of band.



2622
2623
2624
# File 'lib/stripe/resources/invoice.rb', line 2622

def currency
  @currency
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2624
2625
2626
# File 'lib/stripe/resources/invoice.rb', line 2624

def 
  @metadata
end

#money_movement_typeObject

The type of money movement for this out of band payment record.



2626
2627
2628
# File 'lib/stripe/resources/invoice.rb', line 2626

def money_movement_type
  @money_movement_type
end

The timestamp when this out of band payment was paid.



2628
2629
2630
# File 'lib/stripe/resources/invoice.rb', line 2628

def paid_at
  @paid_at
end

#payment_referenceObject

The reference for this out of band payment record.



2630
2631
2632
# File 'lib/stripe/resources/invoice.rb', line 2630

def payment_reference
  @payment_reference
end