Class: Stripe::Invoice::AutomaticTax
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Invoice::AutomaticTax
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: Liability
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#disabled_reason ⇒ Object
readonly
If Stripe disabled automatic tax, this enum describes why.
-
#enabled ⇒ Object
readonly
Whether Stripe automatically computes tax on this invoice.
-
#liability ⇒ Object
readonly
The account that’s liable for tax.
-
#provider ⇒ Object
readonly
The tax provider powering automatic tax.
-
#status ⇒ Object
readonly
The status of the most recent automated tax calculation for this invoice.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#disabled_reason ⇒ Object (readonly)
If Stripe disabled automatic tax, this enum describes why.
95 96 97 |
# File 'lib/stripe/resources/invoice.rb', line 95 def disabled_reason @disabled_reason end |
#enabled ⇒ Object (readonly)
Whether Stripe automatically computes tax on this invoice. Note that incompatible invoice items (invoice items with manually specified [tax rates](docs.stripe.com/api/tax_rates), negative amounts, or ‘tax_behavior=unspecified`) cannot be added to automatic tax invoices.
97 98 99 |
# File 'lib/stripe/resources/invoice.rb', line 97 def enabled @enabled end |
#liability ⇒ Object (readonly)
The account that’s liable for tax. If set, the business address and tax registrations required to perform the tax calculation are loaded from this account. The tax transaction is returned in the report of the connected account.
99 100 101 |
# File 'lib/stripe/resources/invoice.rb', line 99 def liability @liability end |
#provider ⇒ Object (readonly)
The tax provider powering automatic tax.
101 102 103 |
# File 'lib/stripe/resources/invoice.rb', line 101 def provider @provider end |
#status ⇒ Object (readonly)
The status of the most recent automated tax calculation for this invoice.
103 104 105 |
# File 'lib/stripe/resources/invoice.rb', line 103 def status @status end |
Class Method Details
.field_remappings ⇒ Object
109 110 111 |
# File 'lib/stripe/resources/invoice.rb', line 109 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
105 106 107 |
# File 'lib/stripe/resources/invoice.rb', line 105 def self.inner_class_types @inner_class_types = { liability: Liability } end |