Class: Stripe::Invoice::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: AmountsDue, AutomaticTax, CustomField, Discount, FromInvoice, Issuer, PaymentSettings, Rendering, ShippingCost, ShippingDetails, TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_tax_ids: nil, amounts_due: nil, application_fee_amount: nil, auto_advance: nil, automatic_tax: nil, automatically_finalizes_at: nil, collection_method: nil, currency: nil, custom_fields: nil, customer: nil, customer_account: nil, days_until_due: nil, default_margins: nil, default_payment_method: nil, default_source: nil, default_tax_rates: nil, description: nil, discounts: nil, due_date: nil, effective_at: nil, expand: nil, footer: nil, from_invoice: nil, issuer: nil, metadata: nil, number: nil, on_behalf_of: nil, payment_settings: nil, pending_invoice_items_behavior: nil, rendering: nil, shipping_cost: nil, shipping_details: nil, statement_descriptor: nil, subscription: nil, transfer_data: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
1916
1917
1918
1919
1920
1921
1922
1923
1924
1925
1926
1927
1928
1929
1930
1931
1932
1933
1934
# File 'lib/stripe/resources/invoice.rb', line 1862

def initialize(
  account_tax_ids: nil,
  amounts_due: nil,
  application_fee_amount: nil,
  auto_advance: nil,
  automatic_tax: nil,
  automatically_finalizes_at: nil,
  collection_method: nil,
  currency: nil,
  custom_fields: nil,
  customer: nil,
  customer_account: nil,
  days_until_due: nil,
  default_margins: nil,
  default_payment_method: nil,
  default_source: nil,
  default_tax_rates: nil,
  description: nil,
  discounts: nil,
  due_date: nil,
  effective_at: nil,
  expand: nil,
  footer: nil,
  from_invoice: nil,
  issuer: nil,
  metadata: nil,
  number: nil,
  on_behalf_of: nil,
  payment_settings: nil,
  pending_invoice_items_behavior: nil,
  rendering: nil,
  shipping_cost: nil,
  shipping_details: nil,
  statement_descriptor: nil,
  subscription: nil,
  transfer_data: nil
)
  @account_tax_ids = 
  @amounts_due = amounts_due
  @application_fee_amount = application_fee_amount
  @auto_advance = auto_advance
  @automatic_tax = automatic_tax
  @automatically_finalizes_at = automatically_finalizes_at
  @collection_method = collection_method
  @currency = currency
  @custom_fields = custom_fields
  @customer = customer
  @customer_account = 
  @days_until_due = days_until_due
  @default_margins = default_margins
  @default_payment_method = default_payment_method
  @default_source = default_source
  @default_tax_rates = default_tax_rates
  @description = description
  @discounts = discounts
  @due_date = due_date
  @effective_at = effective_at
  @expand = expand
  @footer = footer
  @from_invoice = from_invoice
  @issuer = issuer
  @metadata = 
  @number = number
  @on_behalf_of = on_behalf_of
  @payment_settings = payment_settings
  @pending_invoice_items_behavior = pending_invoice_items_behavior
  @rendering = rendering
  @shipping_cost = shipping_cost
  @shipping_details = shipping_details
  @statement_descriptor = statement_descriptor
  @subscription = subscription
  @transfer_data = transfer_data
end

Instance Attribute Details

#account_tax_idsObject

The account tax IDs associated with the invoice. Only editable when the invoice is a draft.



1792
1793
1794
# File 'lib/stripe/resources/invoice.rb', line 1792

def 
  @account_tax_ids
end

#amounts_dueObject

List of expected payments and corresponding due dates. Valid only for invoices where ‘collection_method=send_invoice`.



1794
1795
1796
# File 'lib/stripe/resources/invoice.rb', line 1794

def amounts_due
  @amounts_due
end

#application_fee_amountObject

A fee in cents (or local equivalent) that will be applied to the invoice and transferred to the application owner’s Stripe account. The request must be made with an OAuth key or the Stripe-Account header in order to take an application fee. For more information, see the application fees [documentation](stripe.com/docs/billing/invoices/connect#collecting-fees).



1796
1797
1798
# File 'lib/stripe/resources/invoice.rb', line 1796

def application_fee_amount
  @application_fee_amount
end

#auto_advanceObject

Controls whether Stripe performs [automatic collection](stripe.com/docs/invoicing/integration/automatic-advancement-collection) of the invoice. If ‘false`, the invoice’s state doesn’t automatically advance without an explicit action. Defaults to false.



1798
1799
1800
# File 'lib/stripe/resources/invoice.rb', line 1798

def auto_advance
  @auto_advance
end

#automatic_taxObject

Settings for automatic tax lookup for this invoice.



1800
1801
1802
# File 'lib/stripe/resources/invoice.rb', line 1800

def automatic_tax
  @automatic_tax
end

#automatically_finalizes_atObject

The time when this invoice should be scheduled to finalize (up to 5 years in the future). The invoice is finalized at this time if it’s still in draft state.



1802
1803
1804
# File 'lib/stripe/resources/invoice.rb', line 1802

def automatically_finalizes_at
  @automatically_finalizes_at
end

#collection_methodObject

Either ‘charge_automatically`, or `send_invoice`. When charging automatically, Stripe will attempt to pay this invoice using the default source attached to the customer. When sending an invoice, Stripe will email this invoice to the customer with payment instructions. Defaults to `charge_automatically`.



1804
1805
1806
# File 'lib/stripe/resources/invoice.rb', line 1804

def collection_method
  @collection_method
end

#currencyObject

The currency to create this invoice in. Defaults to that of ‘customer` if not specified.



1806
1807
1808
# File 'lib/stripe/resources/invoice.rb', line 1806

def currency
  @currency
end

#custom_fieldsObject

A list of up to 4 custom fields to be displayed on the invoice.



1808
1809
1810
# File 'lib/stripe/resources/invoice.rb', line 1808

def custom_fields
  @custom_fields
end

#customerObject

The ID of the customer who will be billed.



1810
1811
1812
# File 'lib/stripe/resources/invoice.rb', line 1810

def customer
  @customer
end

#customer_accountObject

The ID of the account who will be billed.



1812
1813
1814
# File 'lib/stripe/resources/invoice.rb', line 1812

def 
  @customer_account
end

#days_until_dueObject

The number of days from when the invoice is created until it is due. Valid only for invoices where ‘collection_method=send_invoice`.



1814
1815
1816
# File 'lib/stripe/resources/invoice.rb', line 1814

def days_until_due
  @days_until_due
end

#default_marginsObject

The ids of the margins to apply to the invoice. Can be overridden by line item ‘margins`.



1816
1817
1818
# File 'lib/stripe/resources/invoice.rb', line 1816

def default_margins
  @default_margins
end

#default_payment_methodObject

ID of the default payment method for the invoice. It must belong to the customer associated with the invoice. If not set, defaults to the subscription’s default payment method, if any, or to the default payment method in the customer’s invoice settings.



1818
1819
1820
# File 'lib/stripe/resources/invoice.rb', line 1818

def default_payment_method
  @default_payment_method
end

#default_sourceObject

ID of the default payment source for the invoice. It must belong to the customer associated with the invoice and be in a chargeable state. If not set, defaults to the subscription’s default source, if any, or to the customer’s default source.



1820
1821
1822
# File 'lib/stripe/resources/invoice.rb', line 1820

def default_source
  @default_source
end

#default_tax_ratesObject

The tax rates that will apply to any line item that does not have ‘tax_rates` set.



1822
1823
1824
# File 'lib/stripe/resources/invoice.rb', line 1822

def default_tax_rates
  @default_tax_rates
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users. Referenced as ‘memo’ in the Dashboard.



1824
1825
1826
# File 'lib/stripe/resources/invoice.rb', line 1824

def description
  @description
end

#discountsObject

The coupons and promotion codes to redeem into discounts for the invoice. If not specified, inherits the discount from the invoice’s customer. Pass an empty string to avoid inheriting any discounts.



1826
1827
1828
# File 'lib/stripe/resources/invoice.rb', line 1826

def discounts
  @discounts
end

#due_dateObject

The date on which payment for this invoice is due. Valid only for invoices where ‘collection_method=send_invoice`.



1828
1829
1830
# File 'lib/stripe/resources/invoice.rb', line 1828

def due_date
  @due_date
end

#effective_atObject

The date when this invoice is in effect. Same as ‘finalized_at` unless overwritten. When defined, this value replaces the system-generated ’Date of issue’ printed on the invoice PDF and receipt.



1830
1831
1832
# File 'lib/stripe/resources/invoice.rb', line 1830

def effective_at
  @effective_at
end

#expandObject

Specifies which fields in the response should be expanded.



1832
1833
1834
# File 'lib/stripe/resources/invoice.rb', line 1832

def expand
  @expand
end

Footer to be displayed on the invoice.



1834
1835
1836
# File 'lib/stripe/resources/invoice.rb', line 1834

def footer
  @footer
end

#from_invoiceObject

Revise an existing invoice. The new invoice will be created in ‘status=draft`. See the [revision documentation](stripe.com/docs/invoicing/invoice-revisions) for more details.



1836
1837
1838
# File 'lib/stripe/resources/invoice.rb', line 1836

def from_invoice
  @from_invoice
end

#issuerObject

The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.



1838
1839
1840
# File 'lib/stripe/resources/invoice.rb', line 1838

def issuer
  @issuer
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1840
1841
1842
# File 'lib/stripe/resources/invoice.rb', line 1840

def 
  @metadata
end

#numberObject

Set the number for this invoice. If no number is present then a number will be assigned automatically when the invoice is finalized. In many markets, regulations require invoices to be unique, sequential and / or gapless. You are responsible for ensuring this is true across all your different invoicing systems in the event that you edit the invoice number using our API. If you use only Stripe for your invoices and do not change invoice numbers, Stripe handles this aspect of compliance for you automatically.



1842
1843
1844
# File 'lib/stripe/resources/invoice.rb', line 1842

def number
  @number
end

#on_behalf_ofObject

The account (if any) for which the funds of the invoice payment are intended. If set, the invoice will be presented with the branding and support information of the specified account. See the [Invoices with Connect](stripe.com/docs/billing/invoices/connect) documentation for details.



1844
1845
1846
# File 'lib/stripe/resources/invoice.rb', line 1844

def on_behalf_of
  @on_behalf_of
end

#payment_settingsObject

Configuration settings for the PaymentIntent that is generated when the invoice is finalized.



1846
1847
1848
# File 'lib/stripe/resources/invoice.rb', line 1846

def payment_settings
  @payment_settings
end

#pending_invoice_items_behaviorObject

How to handle pending invoice items on invoice creation. Defaults to ‘exclude` if the parameter is omitted.



1848
1849
1850
# File 'lib/stripe/resources/invoice.rb', line 1848

def pending_invoice_items_behavior
  @pending_invoice_items_behavior
end

#renderingObject

The rendering-related settings that control how the invoice is displayed on customer-facing surfaces such as PDF and Hosted Invoice Page.



1850
1851
1852
# File 'lib/stripe/resources/invoice.rb', line 1850

def rendering
  @rendering
end

#shipping_costObject

Settings for the cost of shipping for this invoice.



1852
1853
1854
# File 'lib/stripe/resources/invoice.rb', line 1852

def shipping_cost
  @shipping_cost
end

#shipping_detailsObject

Shipping details for the invoice. The Invoice PDF will use the ‘shipping_details` value if it is set, otherwise the PDF will render the shipping address from the customer.



1854
1855
1856
# File 'lib/stripe/resources/invoice.rb', line 1854

def shipping_details
  @shipping_details
end

#statement_descriptorObject

Extra information about a charge for the customer’s credit card statement. It must contain at least one letter. If not specified and this invoice is part of a subscription, the default ‘statement_descriptor` will be set to the first subscription item’s product’s ‘statement_descriptor`.



1856
1857
1858
# File 'lib/stripe/resources/invoice.rb', line 1856

def statement_descriptor
  @statement_descriptor
end

#subscriptionObject

The ID of the subscription to invoice, if any. If set, the created invoice will only include pending invoice items for that subscription. The subscription’s billing cycle and regular subscription events won’t be affected.



1858
1859
1860
# File 'lib/stripe/resources/invoice.rb', line 1858

def subscription
  @subscription
end

#transfer_dataObject

If specified, the funds from the invoice will be transferred to the destination and the ID of the resulting transfer will be found on the invoice’s charge.



1860
1861
1862
# File 'lib/stripe/resources/invoice.rb', line 1860

def transfer_data
  @transfer_data
end