Class: Stripe::Invoice::CreateParams::AmountsDue
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreateParams::AmountsDue
- Defined in:
- lib/stripe/resources/invoice.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount in cents (or local equivalent).
-
#days_until_due ⇒ Object
Number of days from when invoice is finalized until the payment is due.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#due_date ⇒ Object
Date on which a payment plan’s payment is due.
Instance Method Summary collapse
-
#initialize(amount: nil, days_until_due: nil, description: nil, due_date: nil) ⇒ AmountsDue
constructor
A new instance of AmountsDue.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, days_until_due: nil, description: nil, due_date: nil) ⇒ AmountsDue
Returns a new instance of AmountsDue.
1260 1261 1262 1263 1264 1265 |
# File 'lib/stripe/resources/invoice.rb', line 1260 def initialize(amount: nil, days_until_due: nil, description: nil, due_date: nil) @amount = amount @days_until_due = days_until_due @description = description @due_date = due_date end |
Instance Attribute Details
#amount ⇒ Object
The amount in cents (or local equivalent).
1252 1253 1254 |
# File 'lib/stripe/resources/invoice.rb', line 1252 def amount @amount end |
#days_until_due ⇒ Object
Number of days from when invoice is finalized until the payment is due.
1254 1255 1256 |
# File 'lib/stripe/resources/invoice.rb', line 1254 def days_until_due @days_until_due end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
1256 1257 1258 |
# File 'lib/stripe/resources/invoice.rb', line 1256 def description @description end |
#due_date ⇒ Object
Date on which a payment plan’s payment is due.
1258 1259 1260 |
# File 'lib/stripe/resources/invoice.rb', line 1258 def due_date @due_date end |