Class: Stripe::Invoice::CreateParams::Discount

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1345
1346
1347
1348
1349
1350
# File 'lib/stripe/resources/invoice.rb', line 1345

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1337
1338
1339
# File 'lib/stripe/resources/invoice.rb', line 1337

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1339
1340
1341
# File 'lib/stripe/resources/invoice.rb', line 1339

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1341
1342
1343
# File 'lib/stripe/resources/invoice.rb', line 1341

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1343
1344
1345
# File 'lib/stripe/resources/invoice.rb', line 1343

def promotion_code
  @promotion_code
end