Class: Stripe::Invoice::CreateParams::FromInvoice
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreateParams::FromInvoice
- Defined in:
- lib/stripe/resources/invoice.rb
Instance Attribute Summary collapse
-
#action ⇒ Object
The relation between the new invoice and the original invoice.
-
#invoice ⇒ Object
The ‘id` of the invoice that will be cloned.
Instance Method Summary collapse
-
#initialize(action: nil, invoice: nil) ⇒ FromInvoice
constructor
A new instance of FromInvoice.
Methods inherited from RequestParams
Constructor Details
#initialize(action: nil, invoice: nil) ⇒ FromInvoice
Returns a new instance of FromInvoice.
1359 1360 1361 1362 |
# File 'lib/stripe/resources/invoice.rb', line 1359 def initialize(action: nil, invoice: nil) @action = action @invoice = invoice end |
Instance Attribute Details
#action ⇒ Object
The relation between the new invoice and the original invoice. Currently, only ‘revision’ is permitted
1355 1356 1357 |
# File 'lib/stripe/resources/invoice.rb', line 1355 def action @action end |
#invoice ⇒ Object
The ‘id` of the invoice that will be cloned.
1357 1358 1359 |
# File 'lib/stripe/resources/invoice.rb', line 1357 def invoice @invoice end |