Class: Stripe::Invoice::CreateParams::PaymentSettings::PaymentMethodOptions::Card::Installments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Plan

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(enabled: nil, plan: nil) ⇒ Installments

Returns a new instance of Installments.



1431
1432
1433
1434
# File 'lib/stripe/resources/invoice.rb', line 1431

def initialize(enabled: nil, plan: nil)
  @enabled = enabled
  @plan = plan
end

Instance Attribute Details

#enabledObject

Setting to true enables installments for this invoice. Setting to false will prevent any selected plan from applying to a payment.



1427
1428
1429
# File 'lib/stripe/resources/invoice.rb', line 1427

def enabled
  @enabled
end

#planObject

The selected installment plan to use for this invoice.



1429
1430
1431
# File 'lib/stripe/resources/invoice.rb', line 1429

def plan
  @plan
end