Class: Stripe::Invoice::CreateParams::PaymentSettings::PaymentMethodOptions::Card::Installments::Plan
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreateParams::PaymentSettings::PaymentMethodOptions::Card::Installments::Plan
- Defined in:
- lib/stripe/resources/invoice.rb
Instance Attribute Summary collapse
-
#count ⇒ Object
For ‘fixed_count` installment plans, this is required.
-
#interval ⇒ Object
For ‘fixed_count` installment plans, this is required.
-
#type ⇒ Object
Type of installment plan, one of ‘fixed_count`.
Instance Method Summary collapse
-
#initialize(count: nil, interval: nil, type: nil) ⇒ Plan
constructor
A new instance of Plan.
Methods inherited from RequestParams
Constructor Details
#initialize(count: nil, interval: nil, type: nil) ⇒ Plan
Returns a new instance of Plan.
1212 1213 1214 1215 1216 |
# File 'lib/stripe/resources/invoice.rb', line 1212 def initialize(count: nil, interval: nil, type: nil) @count = count @interval = interval @type = type end |
Instance Attribute Details
#count ⇒ Object
For ‘fixed_count` installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.
1205 1206 1207 |
# File 'lib/stripe/resources/invoice.rb', line 1205 def count @count end |
#interval ⇒ Object
For ‘fixed_count` installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of `month`.
1208 1209 1210 |
# File 'lib/stripe/resources/invoice.rb', line 1208 def interval @interval end |
#type ⇒ Object
Type of installment plan, one of ‘fixed_count`.
1210 1211 1212 |
# File 'lib/stripe/resources/invoice.rb', line 1210 def type @type end |