Class: Stripe::Invoice::CreateParams::PaymentSettings::PaymentMethodOptions::CustomerBalance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: BankTransfer

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bank_transfer: nil, funding_type: nil) ⇒ CustomerBalance

Returns a new instance of CustomerBalance.



1882
1883
1884
1885
# File 'lib/stripe/resources/invoice.rb', line 1882

def initialize(bank_transfer: nil, funding_type: nil)
  @bank_transfer = bank_transfer
  @funding_type = funding_type
end

Instance Attribute Details

#bank_transferObject

Configuration for the bank transfer funding type, if the ‘funding_type` is set to `bank_transfer`.



1878
1879
1880
# File 'lib/stripe/resources/invoice.rb', line 1878

def bank_transfer
  @bank_transfer
end

#funding_typeObject

The funding method type to be used when there are not enough funds in the customer balance. Permitted values include: ‘bank_transfer`.



1880
1881
1882
# File 'lib/stripe/resources/invoice.rb', line 1880

def funding_type
  @funding_type
end