Class: Stripe::Invoice::CreateParams::PaymentSettings::PaymentMethodOptions::UsBankAccount::FinancialConnections
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreateParams::PaymentSettings::PaymentMethodOptions::UsBankAccount::FinancialConnections
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: Filters
Instance Attribute Summary collapse
-
#filters ⇒ Object
Provide filters for the linked accounts that the customer can select for the payment method.
-
#permissions ⇒ Object
The list of permissions to request.
-
#prefetch ⇒ Object
List of data features that you would like to retrieve upon account creation.
Instance Method Summary collapse
-
#initialize(filters: nil, permissions: nil, prefetch: nil) ⇒ FinancialConnections
constructor
A new instance of FinancialConnections.
Methods inherited from RequestParams
Constructor Details
#initialize(filters: nil, permissions: nil, prefetch: nil) ⇒ FinancialConnections
Returns a new instance of FinancialConnections.
1661 1662 1663 1664 1665 |
# File 'lib/stripe/resources/invoice.rb', line 1661 def initialize(filters: nil, permissions: nil, prefetch: nil) @filters = filters @permissions = @prefetch = prefetch end |
Instance Attribute Details
#filters ⇒ Object
Provide filters for the linked accounts that the customer can select for the payment method.
1653 1654 1655 |
# File 'lib/stripe/resources/invoice.rb', line 1653 def filters @filters end |
#permissions ⇒ Object
The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.
1656 1657 1658 |
# File 'lib/stripe/resources/invoice.rb', line 1656 def @permissions end |
#prefetch ⇒ Object
List of data features that you would like to retrieve upon account creation.
1659 1660 1661 |
# File 'lib/stripe/resources/invoice.rb', line 1659 def prefetch @prefetch end |