Class: Stripe::Invoice::CreateParams::Rendering

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Pdf

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_tax_display: nil, pdf: nil, template: nil, template_version: nil) ⇒ Rendering

Returns a new instance of Rendering.



1621
1622
1623
1624
1625
1626
# File 'lib/stripe/resources/invoice.rb', line 1621

def initialize(amount_tax_display: nil, pdf: nil, template: nil, template_version: nil)
  @amount_tax_display = amount_tax_display
  @pdf = pdf
  @template = template
  @template_version = template_version
end

Instance Attribute Details

#amount_tax_displayObject

How line-item prices and amounts will be displayed with respect to tax on invoice PDFs. One of ‘exclude_tax` or `include_inclusive_tax`. `include_inclusive_tax` will include inclusive tax (and exclude exclusive tax) in invoice PDF amounts. `exclude_tax` will exclude all tax (inclusive and exclusive alike) from invoice PDF amounts.



1613
1614
1615
# File 'lib/stripe/resources/invoice.rb', line 1613

def amount_tax_display
  @amount_tax_display
end

#pdfObject

Invoice pdf rendering options



1615
1616
1617
# File 'lib/stripe/resources/invoice.rb', line 1615

def pdf
  @pdf
end

#templateObject

ID of the invoice rendering template to use for this invoice.



1617
1618
1619
# File 'lib/stripe/resources/invoice.rb', line 1617

def template
  @template
end

#template_versionObject

The specific version of invoice rendering template to use for this invoice.



1619
1620
1621
# File 'lib/stripe/resources/invoice.rb', line 1619

def template_version
  @template_version
end