Class: Stripe::Invoice::CreateParams::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



1786
1787
1788
1789
# File 'lib/stripe/resources/invoice.rb', line 1786

def initialize(amount: nil, destination: nil)
  @amount = amount
  @destination = destination
end

Instance Attribute Details

#amountObject

The amount that will be transferred automatically when the invoice is paid. If no amount is set, the full amount is transferred.



1782
1783
1784
# File 'lib/stripe/resources/invoice.rb', line 1782

def amount
  @amount
end

#destinationObject

ID of an existing, connected Stripe account.



1784
1785
1786
# File 'lib/stripe/resources/invoice.rb', line 1784

def destination
  @destination
end