Class: Stripe::Invoice::CreatePreviewParams::AutomaticTax

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Liability

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(enabled: nil, liability: nil) ⇒ AutomaticTax

Returns a new instance of AutomaticTax.



3048
3049
3050
3051
# File 'lib/stripe/resources/invoice.rb', line 3048

def initialize(enabled: nil, liability: nil)
  @enabled = enabled
  @liability = liability
end

Instance Attribute Details

#enabledObject

Whether Stripe automatically computes tax on this invoice. Note that incompatible invoice items (invoice items with manually specified [tax rates](stripe.com/docs/api/tax_rates), negative amounts, or ‘tax_behavior=unspecified`) cannot be added to automatic tax invoices.



3044
3045
3046
# File 'lib/stripe/resources/invoice.rb', line 3044

def enabled
  @enabled
end

#liabilityObject

The account that’s liable for tax. If set, the business address and tax registrations required to perform the tax calculation are loaded from this account. The tax transaction is returned in the report of the connected account.



3046
3047
3048
# File 'lib/stripe/resources/invoice.rb', line 3046

def liability
  @liability
end