Class: Stripe::Invoice::CreatePreviewParams::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



2798
2799
2800
2801
2802
2803
# File 'lib/stripe/resources/invoice.rb', line 2798

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



2790
2791
2792
# File 'lib/stripe/resources/invoice.rb', line 2790

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



2792
2793
2794
# File 'lib/stripe/resources/invoice.rb', line 2792

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



2794
2795
2796
# File 'lib/stripe/resources/invoice.rb', line 2794

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



2796
2797
2798
# File 'lib/stripe/resources/invoice.rb', line 2796

def promotion_code
  @promotion_code
end