Class: Stripe::Invoice::CreatePreviewParams::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



3191
3192
3193
3194
3195
# File 'lib/stripe/resources/invoice.rb', line 3191

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



3185
3186
3187
# File 'lib/stripe/resources/invoice.rb', line 3185

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



3187
3188
3189
# File 'lib/stripe/resources/invoice.rb', line 3187

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



3189
3190
3191
# File 'lib/stripe/resources/invoice.rb', line 3189

def type
  @type
end