Class: Stripe::Invoice::CreatePreviewParams::Discount::DiscountEnd::Duration
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreatePreviewParams::Discount::DiscountEnd::Duration
- Defined in:
- lib/stripe/resources/invoice.rb
Instance Attribute Summary collapse
-
#interval ⇒ Object
Specifies a type of interval unit.
-
#interval_count ⇒ Object
The number of intervals, as an whole number greater than 0.
Instance Method Summary collapse
-
#initialize(interval: nil, interval_count: nil) ⇒ Duration
constructor
A new instance of Duration.
Methods inherited from RequestParams
Constructor Details
#initialize(interval: nil, interval_count: nil) ⇒ Duration
Returns a new instance of Duration.
2698 2699 2700 2701 |
# File 'lib/stripe/resources/invoice.rb', line 2698 def initialize(interval: nil, interval_count: nil) @interval = interval @interval_count = interval_count end |
Instance Attribute Details
#interval ⇒ Object
Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.
2694 2695 2696 |
# File 'lib/stripe/resources/invoice.rb', line 2694 def interval @interval end |
#interval_count ⇒ Object
The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.
2696 2697 2698 |
# File 'lib/stripe/resources/invoice.rb', line 2696 def interval_count @interval_count end |