Class: Stripe::Invoice::CreatePreviewParams::InvoiceItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



2827
2828
2829
2830
2831
# File 'lib/stripe/resources/invoice.rb', line 2827

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



2821
2822
2823
# File 'lib/stripe/resources/invoice.rb', line 2821

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



2823
2824
2825
# File 'lib/stripe/resources/invoice.rb', line 2823

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



2825
2826
2827
# File 'lib/stripe/resources/invoice.rb', line 2825

def type
  @type
end