Class: Stripe::Invoice::CreatePreviewParams::InvoiceItem::Period
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreatePreviewParams::InvoiceItem::Period
- Defined in:
- lib/stripe/resources/invoice.rb
Instance Attribute Summary collapse
-
#end ⇒ Object
The end of the period, which must be greater than or equal to the start.
-
#start ⇒ Object
The start of the period.
Instance Method Summary collapse
-
#initialize(end_: nil, start: nil) ⇒ Period
constructor
A new instance of Period.
Methods inherited from RequestParams
Constructor Details
#initialize(end_: nil, start: nil) ⇒ Period
Returns a new instance of Period.
2849 2850 2851 2852 |
# File 'lib/stripe/resources/invoice.rb', line 2849 def initialize(end_: nil, start: nil) @end = end_ @start = start end |
Instance Attribute Details
#end ⇒ Object
The end of the period, which must be greater than or equal to the start. This value is inclusive.
2845 2846 2847 |
# File 'lib/stripe/resources/invoice.rb', line 2845 def end @end end |
#start ⇒ Object
The start of the period. This value is inclusive.
2847 2848 2849 |
# File 'lib/stripe/resources/invoice.rb', line 2847 def start @start end |