Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: AmendmentEnd, AmendmentStart, DiscountAction, ItemAction, MetadataAction, SetPauseCollection, TrialSettings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendment_end: nil, amendment_start: nil, billing_cycle_anchor: nil, discount_actions: nil, item_actions: nil, metadata_actions: nil, proration_behavior: nil, set_pause_collection: nil, set_schedule_end: nil, trial_settings: nil) ⇒ Amendment

Returns a new instance of Amendment.



3806
3807
3808
3809
3810
3811
3812
3813
3814
3815
3816
3817
3818
3819
3820
3821
3822
3823
3824
3825
3826
3827
3828
# File 'lib/stripe/resources/invoice.rb', line 3806

def initialize(
  amendment_end: nil,
  amendment_start: nil,
  billing_cycle_anchor: nil,
  discount_actions: nil,
  item_actions: nil,
  metadata_actions: nil,
  proration_behavior: nil,
  set_pause_collection: nil,
  set_schedule_end: nil,
  trial_settings: nil
)
  @amendment_end = amendment_end
  @amendment_start = amendment_start
  @billing_cycle_anchor = billing_cycle_anchor
  @discount_actions = discount_actions
  @item_actions = item_actions
  @metadata_actions = 
  @proration_behavior = proration_behavior
  @set_pause_collection = set_pause_collection
  @set_schedule_end = set_schedule_end
  @trial_settings = trial_settings
end

Instance Attribute Details

#amendment_endObject

Details to identify the end of the time range modified by the proposed change. If not supplied, the amendment is considered a point-in-time operation that only affects the exact timestamp at ‘amendment_start`, and a restricted set of attributes is supported on the amendment.



3786
3787
3788
# File 'lib/stripe/resources/invoice.rb', line 3786

def amendment_end
  @amendment_end
end

#amendment_startObject

Details to identify the earliest timestamp where the proposed change should take effect.



3788
3789
3790
# File 'lib/stripe/resources/invoice.rb', line 3788

def amendment_start
  @amendment_start
end

#billing_cycle_anchorObject

For point-in-time amendments (having no ‘amendment_end`), this attribute lets you set or remove whether the subscription’s billing cycle anchor is reset at the ‘amendment_start` timestamp.For time-span based amendments (having both `amendment_start` and `amendment_end`), the only value valid is `automatic`, which removes any previously configured billing cycle anchor resets scheduled to occur during the window of time spanned by the amendment.



3790
3791
3792
# File 'lib/stripe/resources/invoice.rb', line 3790

def billing_cycle_anchor
  @billing_cycle_anchor
end

#discount_actionsObject

Changes to the coupons being redeemed or discounts being applied during the amendment time span.



3792
3793
3794
# File 'lib/stripe/resources/invoice.rb', line 3792

def discount_actions
  @discount_actions
end

#item_actionsObject

Changes to the subscription items during the amendment time span.



3794
3795
3796
# File 'lib/stripe/resources/invoice.rb', line 3794

def item_actions
  @item_actions
end

#metadata_actionsObject

Instructions for how to modify phase metadata



3796
3797
3798
# File 'lib/stripe/resources/invoice.rb', line 3796

def 
  @metadata_actions
end

#proration_behaviorObject

Changes to how Stripe handles prorations during the amendment time span. Affects if and how prorations are created when a future phase starts. In cases where the amendment changes the currently active phase, it is used to determine whether or how to prorate now, at the time of the request. Also supported as a point-in-time operation when ‘amendment_end` is `null`.



3798
3799
3800
# File 'lib/stripe/resources/invoice.rb', line 3798

def proration_behavior
  @proration_behavior
end

#set_pause_collectionObject

Defines how to pause collection for the underlying subscription throughout the duration of the amendment.



3800
3801
3802
# File 'lib/stripe/resources/invoice.rb', line 3800

def set_pause_collection
  @set_pause_collection
end

#set_schedule_endObject

Ends the subscription schedule early as dictated by either the accompanying amendment’s start or end.



3802
3803
3804
# File 'lib/stripe/resources/invoice.rb', line 3802

def set_schedule_end
  @set_schedule_end
end

#trial_settingsObject

Settings related to subscription trials.



3804
3805
3806
# File 'lib/stripe/resources/invoice.rb', line 3804

def trial_settings
  @trial_settings
end