Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::AmendmentEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd, Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ AmendmentEnd

Returns a new instance of AmendmentEnd.



3002
3003
3004
3005
3006
3007
# File 'lib/stripe/resources/invoice.rb', line 3002

def initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil)
  @discount_end = discount_end
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#discount_endObject

Use the ‘end` time of a given discount.



2994
2995
2996
# File 'lib/stripe/resources/invoice.rb', line 2994

def discount_end
  @discount_end
end

#durationObject

Time span for the amendment starting from the ‘amendment_start`.



2996
2997
2998
# File 'lib/stripe/resources/invoice.rb', line 2996

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the amendment to end. Must be after the ‘amendment_start`.



2998
2999
3000
# File 'lib/stripe/resources/invoice.rb', line 2998

def timestamp
  @timestamp
end

#typeObject

Select one of three ways to pass the ‘amendment_end`.



3000
3001
3002
# File 'lib/stripe/resources/invoice.rb', line 3000

def type
  @type
end