Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::AmendmentStart

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: AmendmentEnd, DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendment_end: nil, discount_end: nil, timestamp: nil, type: nil) ⇒ AmendmentStart

Returns a new instance of AmendmentStart.



3445
3446
3447
3448
3449
3450
# File 'lib/stripe/resources/invoice.rb', line 3445

def initialize(amendment_end: nil, discount_end: nil, timestamp: nil, type: nil)
  @amendment_end = amendment_end
  @discount_end = discount_end
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#amendment_endObject

Details of another amendment in the same array, immediately after which this amendment should begin.



3437
3438
3439
# File 'lib/stripe/resources/invoice.rb', line 3437

def amendment_end
  @amendment_end
end

#discount_endObject

Use the ‘end` time of a given discount.



3439
3440
3441
# File 'lib/stripe/resources/invoice.rb', line 3439

def discount_end
  @discount_end
end

#timestampObject

A precise Unix timestamp for the amendment to start.



3441
3442
3443
# File 'lib/stripe/resources/invoice.rb', line 3441

def timestamp
  @timestamp
end

#typeObject

Select one of three ways to pass the ‘amendment_start`.



3443
3444
3445
# File 'lib/stripe/resources/invoice.rb', line 3443

def type
  @type
end