Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::AmendmentStart::AmendmentEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::AmendmentStart::AmendmentEnd
- Defined in:
- lib/stripe/resources/invoice.rb
Instance Attribute Summary collapse
-
#index ⇒ Object
The position of the previous amendment in the ‘amendments` array after which this amendment should begin.
Instance Method Summary collapse
-
#initialize(index: nil) ⇒ AmendmentEnd
constructor
A new instance of AmendmentEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(index: nil) ⇒ AmendmentEnd
Returns a new instance of AmendmentEnd.
3423 3424 3425 |
# File 'lib/stripe/resources/invoice.rb', line 3423 def initialize(index: nil) @index = index end |
Instance Attribute Details
#index ⇒ Object
The position of the previous amendment in the ‘amendments` array after which this amendment should begin. Indexes start from 0 and must be less than the index of the current amendment in the array.
3421 3422 3423 |
# File 'lib/stripe/resources/invoice.rb', line 3421 def index @index end |