Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::DiscountAction
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::DiscountAction
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#add ⇒ Object
Details of the discount to add.
-
#remove ⇒ Object
Details of the discount to remove.
-
#set ⇒ Object
Details of the discount to replace the existing discounts with.
-
#type ⇒ Object
Determines the type of discount action.
Instance Method Summary collapse
-
#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ DiscountAction
constructor
A new instance of DiscountAction.
Methods inherited from RequestParams
Constructor Details
#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ DiscountAction
Returns a new instance of DiscountAction.
3527 3528 3529 3530 3531 3532 |
# File 'lib/stripe/resources/invoice.rb', line 3527 def initialize(add: nil, remove: nil, set: nil, type: nil) @add = add @remove = remove @set = set @type = type end |
Instance Attribute Details
#add ⇒ Object
Details of the discount to add.
3519 3520 3521 |
# File 'lib/stripe/resources/invoice.rb', line 3519 def add @add end |
#remove ⇒ Object
Details of the discount to remove.
3521 3522 3523 |
# File 'lib/stripe/resources/invoice.rb', line 3521 def remove @remove end |
#set ⇒ Object
Details of the discount to replace the existing discounts with.
3523 3524 3525 |
# File 'lib/stripe/resources/invoice.rb', line 3523 def set @set end |
#type ⇒ Object
Determines the type of discount action.
3525 3526 3527 |
# File 'lib/stripe/resources/invoice.rb', line 3525 def type @type end |