Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::DiscountAction::Add

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ Add

Returns a new instance of Add.



3066
3067
3068
3069
3070
3071
3072
3073
3074
3075
3076
3077
3078
# File 'lib/stripe/resources/invoice.rb', line 3066

def initialize(
  coupon: nil,
  discount: nil,
  discount_end: nil,
  index: nil,
  promotion_code: nil
)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @index = index
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to redeem.



3056
3057
3058
# File 'lib/stripe/resources/invoice.rb', line 3056

def coupon
  @coupon
end

#discountObject

An ID of an existing discount for a coupon that was already redeemed.



3058
3059
3060
# File 'lib/stripe/resources/invoice.rb', line 3058

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



3060
3061
3062
# File 'lib/stripe/resources/invoice.rb', line 3060

def discount_end
  @discount_end
end

#indexObject

The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the ‘discounts` array.



3062
3063
3064
# File 'lib/stripe/resources/invoice.rb', line 3062

def index
  @index
end

#promotion_codeObject

The promotion code to redeem.



3064
3065
3066
# File 'lib/stripe/resources/invoice.rb', line 3064

def promotion_code
  @promotion_code
end