Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::DiscountAction::Add::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::DiscountAction::Add::DiscountEnd
- Defined in:
- lib/stripe/resources/invoice.rb
Instance Attribute Summary collapse
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
2994 2995 2996 |
# File 'lib/stripe/resources/invoice.rb', line 2994 def initialize(type: nil) @type = type end |
Instance Attribute Details
#type ⇒ Object
The type of calculation made to determine when the discount ends.
2992 2993 2994 |
# File 'lib/stripe/resources/invoice.rb', line 2992 def type @type end |