Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::DiscountAction::Remove

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Remove

Returns a new instance of Remove.



3497
3498
3499
3500
3501
# File 'lib/stripe/resources/invoice.rb', line 3497

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to remove from the ‘discounts` array.



3491
3492
3493
# File 'lib/stripe/resources/invoice.rb', line 3491

def coupon
  @coupon
end

#discountObject

The ID of a discount to remove from the ‘discounts` array.



3493
3494
3495
# File 'lib/stripe/resources/invoice.rb', line 3493

def discount
  @discount
end

#promotion_codeObject

The ID of a promotion code to remove from the ‘discounts` array.



3495
3496
3497
# File 'lib/stripe/resources/invoice.rb', line 3495

def promotion_code
  @promotion_code
end