Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::DiscountAction::Set

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Set

Returns a new instance of Set.



3104
3105
3106
3107
3108
# File 'lib/stripe/resources/invoice.rb', line 3104

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to replace the ‘discounts` array with.



3098
3099
3100
# File 'lib/stripe/resources/invoice.rb', line 3098

def coupon
  @coupon
end

#discountObject

An ID of an existing discount to replace the ‘discounts` array with.



3100
3101
3102
# File 'lib/stripe/resources/invoice.rb', line 3100

def discount
  @discount
end

#promotion_codeObject

An ID of an existing promotion code to replace the ‘discounts` array with.



3102
3103
3104
# File 'lib/stripe/resources/invoice.rb', line 3102

def promotion_code
  @promotion_code
end