Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::ItemAction

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Add, Remove, Set

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ ItemAction

Returns a new instance of ItemAction.



3315
3316
3317
3318
3319
3320
# File 'lib/stripe/resources/invoice.rb', line 3315

def initialize(add: nil, remove: nil, set: nil, type: nil)
  @add = add
  @remove = remove
  @set = set
  @type = type
end

Instance Attribute Details

#addObject

Details of the subscription item to add. If an item with the same ‘price` exists, it will be replaced by this new item. Otherwise, it adds the new item.



3307
3308
3309
# File 'lib/stripe/resources/invoice.rb', line 3307

def add
  @add
end

#removeObject

Details of the subscription item to remove.



3309
3310
3311
# File 'lib/stripe/resources/invoice.rb', line 3309

def remove
  @remove
end

#setObject

Details of the subscription item to replace the existing items with. If an item with the ‘set` already exists, the `items` array is not cleared. Instead, all of the other `set` properties that are passed in this request will replace the existing values for the configuration item.



3311
3312
3313
# File 'lib/stripe/resources/invoice.rb', line 3311

def set
  @set
end

#typeObject

Determines the type of item action.



3313
3314
3315
# File 'lib/stripe/resources/invoice.rb', line 3313

def type
  @type
end