Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Add

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Discount, Trial

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Add

Returns a new instance of Add.



3196
3197
3198
3199
3200
3201
3202
3203
3204
3205
3206
3207
3208
3209
3210
# File 'lib/stripe/resources/invoice.rb', line 3196

def initialize(
  discounts: nil,
  metadata: nil,
  price: nil,
  quantity: nil,
  tax_rates: nil,
  trial: nil
)
  @discounts = discounts
  @metadata = 
  @price = price
  @quantity = quantity
  @tax_rates = tax_rates
  @trial = trial
end

Instance Attribute Details

#discountsObject

The discounts applied to the item. Subscription item discounts are applied before subscription discounts.



3184
3185
3186
# File 'lib/stripe/resources/invoice.rb', line 3184

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



3186
3187
3188
# File 'lib/stripe/resources/invoice.rb', line 3186

def 
  @metadata
end

#priceObject

The ID of the price object.



3188
3189
3190
# File 'lib/stripe/resources/invoice.rb', line 3188

def price
  @price
end

#quantityObject

Quantity for this item.



3190
3191
3192
# File 'lib/stripe/resources/invoice.rb', line 3190

def quantity
  @quantity
end

#tax_ratesObject

The tax rates that apply to this subscription item. When set, the ‘default_tax_rates` on the subscription do not apply to this `subscription_item`.



3192
3193
3194
# File 'lib/stripe/resources/invoice.rb', line 3192

def tax_rates
  @tax_rates
end

#trialObject

Options that configure the trial on the subscription item.



3194
3195
3196
# File 'lib/stripe/resources/invoice.rb', line 3194

def trial
  @trial
end