Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Add::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



3557
3558
3559
3560
3561
# File 'lib/stripe/resources/invoice.rb', line 3557

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



3551
3552
3553
# File 'lib/stripe/resources/invoice.rb', line 3551

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



3553
3554
3555
# File 'lib/stripe/resources/invoice.rb', line 3553

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



3555
3556
3557
# File 'lib/stripe/resources/invoice.rb', line 3555

def type
  @type
end