Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Set::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



3651
3652
3653
3654
3655
# File 'lib/stripe/resources/invoice.rb', line 3651

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



3645
3646
3647
# File 'lib/stripe/resources/invoice.rb', line 3645

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



3647
3648
3649
# File 'lib/stripe/resources/invoice.rb', line 3647

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



3649
3650
3651
# File 'lib/stripe/resources/invoice.rb', line 3649

def type
  @type
end