Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::SetPauseCollection::Set
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::SetPauseCollection::Set
- Defined in:
- lib/stripe/resources/invoice.rb
Instance Attribute Summary collapse
-
#behavior ⇒ Object
The payment collection behavior for this subscription while paused.
Instance Method Summary collapse
-
#initialize(behavior: nil) ⇒ Set
constructor
A new instance of Set.
Methods inherited from RequestParams
Constructor Details
#initialize(behavior: nil) ⇒ Set
Returns a new instance of Set.
3289 3290 3291 |
# File 'lib/stripe/resources/invoice.rb', line 3289 def initialize(behavior: nil) @behavior = behavior end |
Instance Attribute Details
#behavior ⇒ Object
The payment collection behavior for this subscription while paused. One of ‘keep_as_draft`, `mark_uncollectible`, or `void`.
3287 3288 3289 |
# File 'lib/stripe/resources/invoice.rb', line 3287 def behavior @behavior end |