Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::BillingMode
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreatePreviewParams::ScheduleDetails::BillingMode
- Defined in:
- lib/stripe/resources/invoice.rb
Instance Attribute Summary collapse
-
#type ⇒ Object
Controls the calculation and orchestration of prorations and invoices for subscriptions.
Instance Method Summary collapse
-
#initialize(type: nil) ⇒ BillingMode
constructor
A new instance of BillingMode.
Methods inherited from RequestParams
Constructor Details
#initialize(type: nil) ⇒ BillingMode
Returns a new instance of BillingMode.
3420 3421 3422 |
# File 'lib/stripe/resources/invoice.rb', line 3420 def initialize(type: nil) @type = type end |
Instance Attribute Details
#type ⇒ Object
Controls the calculation and orchestration of prorations and invoices for subscriptions.
3418 3419 3420 |
# File 'lib/stripe/resources/invoice.rb', line 3418 def type @type end |