Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Phase::AddInvoiceItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Discount, Period, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discounts: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ AddInvoiceItem

Returns a new instance of AddInvoiceItem.



3961
3962
3963
3964
3965
3966
3967
3968
3969
3970
3971
3972
3973
3974
3975
3976
3977
# File 'lib/stripe/resources/invoice.rb', line 3961

def initialize(
  discounts: nil,
  metadata: nil,
  period: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @discounts = discounts
  @metadata = 
  @period = period
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#discountsObject

The coupons to redeem into discounts for the item.



3947
3948
3949
# File 'lib/stripe/resources/invoice.rb', line 3947

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



3949
3950
3951
# File 'lib/stripe/resources/invoice.rb', line 3949

def 
  @metadata
end

#periodObject

The period associated with this invoice item. Defaults to the period of the underlying subscription that surrounds the start of the phase.



3951
3952
3953
# File 'lib/stripe/resources/invoice.rb', line 3951

def period
  @period
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required.



3953
3954
3955
# File 'lib/stripe/resources/invoice.rb', line 3953

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.



3955
3956
3957
# File 'lib/stripe/resources/invoice.rb', line 3955

def price_data
  @price_data
end

#quantityObject

Quantity for this item. Defaults to 1.



3957
3958
3959
# File 'lib/stripe/resources/invoice.rb', line 3957

def quantity
  @quantity
end

#tax_ratesObject

The tax rates which apply to the item. When set, the ‘default_tax_rates` do not apply to this item.



3959
3960
3961
# File 'lib/stripe/resources/invoice.rb', line 3959

def tax_rates
  @tax_rates
end