Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Phase::AddInvoiceItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



3877
3878
3879
3880
3881
3882
# File 'lib/stripe/resources/invoice.rb', line 3877

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



3869
3870
3871
# File 'lib/stripe/resources/invoice.rb', line 3869

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



3871
3872
3873
# File 'lib/stripe/resources/invoice.rb', line 3871

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



3873
3874
3875
# File 'lib/stripe/resources/invoice.rb', line 3873

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



3875
3876
3877
# File 'lib/stripe/resources/invoice.rb', line 3875

def promotion_code
  @promotion_code
end