Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Phase::AddInvoiceItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



3454
3455
3456
3457
3458
# File 'lib/stripe/resources/invoice.rb', line 3454

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



3448
3449
3450
# File 'lib/stripe/resources/invoice.rb', line 3448

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



3450
3451
3452
# File 'lib/stripe/resources/invoice.rb', line 3450

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



3452
3453
3454
# File 'lib/stripe/resources/invoice.rb', line 3452

def type
  @type
end