Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Phase::AddInvoiceItem::Period::End

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(timestamp: nil, type: nil) ⇒ End

Returns a new instance of End.



3484
3485
3486
3487
# File 'lib/stripe/resources/invoice.rb', line 3484

def initialize(timestamp: nil, type: nil)
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#timestampObject

A precise Unix timestamp for the end of the invoice item period. Must be greater than or equal to ‘period.start`.



3480
3481
3482
# File 'lib/stripe/resources/invoice.rb', line 3480

def timestamp
  @timestamp
end

#typeObject

Select how to calculate the end of the invoice item period.



3482
3483
3484
# File 'lib/stripe/resources/invoice.rb', line 3482

def type
  @type
end