Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Phase::AddInvoiceItem::Period::Start
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Phase::AddInvoiceItem::Period::Start
- Defined in:
- lib/stripe/resources/invoice.rb
Instance Attribute Summary collapse
-
#timestamp ⇒ Object
A precise Unix timestamp for the start of the invoice item period.
-
#type ⇒ Object
Select how to calculate the start of the invoice item period.
Instance Method Summary collapse
-
#initialize(timestamp: nil, type: nil) ⇒ Start
constructor
A new instance of Start.
Methods inherited from RequestParams
Constructor Details
#initialize(timestamp: nil, type: nil) ⇒ Start
Returns a new instance of Start.
3496 3497 3498 3499 |
# File 'lib/stripe/resources/invoice.rb', line 3496 def initialize(timestamp: nil, type: nil) @timestamp = @type = type end |
Instance Attribute Details
#timestamp ⇒ Object
A precise Unix timestamp for the start of the invoice item period. Must be less than or equal to ‘period.end`.
3492 3493 3494 |
# File 'lib/stripe/resources/invoice.rb', line 3492 def @timestamp end |
#type ⇒ Object
Select how to calculate the start of the invoice item period.
3494 3495 3496 |
# File 'lib/stripe/resources/invoice.rb', line 3494 def type @type end |