Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Phase::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



4050
4051
4052
4053
4054
4055
# File 'lib/stripe/resources/invoice.rb', line 4050

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



4042
4043
4044
# File 'lib/stripe/resources/invoice.rb', line 4042

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



4044
4045
4046
# File 'lib/stripe/resources/invoice.rb', line 4044

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



4046
4047
4048
# File 'lib/stripe/resources/invoice.rb', line 4046

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



4048
4049
4050
# File 'lib/stripe/resources/invoice.rb', line 4048

def promotion_code
  @promotion_code
end