Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Phase::Item

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: BillingThresholds, Discount, PriceData, Trial

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_thresholds: nil, discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Item

Returns a new instance of Item.



3813
3814
3815
3816
3817
3818
3819
3820
3821
3822
3823
3824
3825
3826
3827
3828
3829
3830
3831
3832
3833
# File 'lib/stripe/resources/invoice.rb', line 3813

def initialize(
  billing_thresholds: nil,
  discounts: nil,
  metadata: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil,
  trial: nil
)
  @billing_thresholds = billing_thresholds
  @discounts = discounts
  @metadata = 
  @plan = plan
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
  @trial = trial
end

Instance Attribute Details

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.



3795
3796
3797
# File 'lib/stripe/resources/invoice.rb', line 3795

def billing_thresholds
  @billing_thresholds
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



3797
3798
3799
# File 'lib/stripe/resources/invoice.rb', line 3797

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to a configuration item. Metadata on a configuration item will update the underlying subscription item’s ‘metadata` when the phase is entered, adding new keys and replacing existing keys. Individual keys in the subscription item’s ‘metadata` can be unset by posting an empty value to them in the configuration item’s ‘metadata`. To unset all keys in the subscription item’s ‘metadata`, update the subscription item directly or unset every key individually from the configuration item’s ‘metadata`.



3799
3800
3801
# File 'lib/stripe/resources/invoice.rb', line 3799

def 
  @metadata
end

#planObject

The plan ID to subscribe to. You may specify the same ID in ‘plan` and `price`.



3801
3802
3803
# File 'lib/stripe/resources/invoice.rb', line 3801

def plan
  @plan
end

#priceObject

The ID of the price object.



3803
3804
3805
# File 'lib/stripe/resources/invoice.rb', line 3803

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.



3805
3806
3807
# File 'lib/stripe/resources/invoice.rb', line 3805

def price_data
  @price_data
end

#quantityObject

Quantity for the given price. Can be set only if the price’s ‘usage_type` is `licensed` and not `metered`.



3807
3808
3809
# File 'lib/stripe/resources/invoice.rb', line 3807

def quantity
  @quantity
end

#tax_ratesObject

A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



3809
3810
3811
# File 'lib/stripe/resources/invoice.rb', line 3809

def tax_rates
  @tax_rates
end

#trialObject

Options that configure the trial on the subscription item.



3811
3812
3813
# File 'lib/stripe/resources/invoice.rb', line 3811

def trial
  @trial
end