Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Phase::Item::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Phase::Item::Discount
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
3733 3734 3735 3736 3737 3738 |
# File 'lib/stripe/resources/invoice.rb', line 3733 def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
3725 3726 3727 |
# File 'lib/stripe/resources/invoice.rb', line 3725 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
3727 3728 3729 |
# File 'lib/stripe/resources/invoice.rb', line 3727 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
3729 3730 3731 |
# File 'lib/stripe/resources/invoice.rb', line 3729 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
3731 3732 3733 |
# File 'lib/stripe/resources/invoice.rb', line 3731 def promotion_code @promotion_code end |