Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Phase::Item::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



3718
3719
3720
3721
3722
# File 'lib/stripe/resources/invoice.rb', line 3718

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



3712
3713
3714
# File 'lib/stripe/resources/invoice.rb', line 3712

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



3714
3715
3716
# File 'lib/stripe/resources/invoice.rb', line 3714

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



3716
3717
3718
# File 'lib/stripe/resources/invoice.rb', line 3716

def type
  @type
end