Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Prebilling::BillUntil

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: AmendmentEnd, Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ BillUntil

Returns a new instance of BillUntil.



4422
4423
4424
4425
4426
4427
# File 'lib/stripe/resources/invoice.rb', line 4422

def initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil)
  @amendment_end = amendment_end
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#amendment_endObject

End the prebilled period when a specified amendment ends.



4414
4415
4416
# File 'lib/stripe/resources/invoice.rb', line 4414

def amendment_end
  @amendment_end
end

#durationObject

Time span for prebilling, starting from ‘bill_from`.



4416
4417
4418
# File 'lib/stripe/resources/invoice.rb', line 4416

def duration
  @duration
end

#timestampObject

End the prebilled period at a precise integer timestamp, starting from the Unix epoch.



4418
4419
4420
# File 'lib/stripe/resources/invoice.rb', line 4418

def timestamp
  @timestamp
end

#typeObject

Select one of several ways to pass the ‘bill_until` value.



4420
4421
4422
# File 'lib/stripe/resources/invoice.rb', line 4420

def type
  @type
end