Class: Stripe::Invoice::CreatePreviewParams::SubscriptionDetails::BillingMode
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreatePreviewParams::SubscriptionDetails::BillingMode
- Defined in:
- lib/stripe/resources/invoice.rb
Instance Attribute Summary collapse
-
#type ⇒ Object
Controls the calculation and orchestration of prorations and invoices for subscriptions.
Instance Method Summary collapse
-
#initialize(type: nil) ⇒ BillingMode
constructor
A new instance of BillingMode.
Methods inherited from RequestParams
Constructor Details
#initialize(type: nil) ⇒ BillingMode
Returns a new instance of BillingMode.
4070 4071 4072 |
# File 'lib/stripe/resources/invoice.rb', line 4070 def initialize(type: nil) @type = type end |
Instance Attribute Details
#type ⇒ Object
Controls the calculation and orchestration of prorations and invoices for subscriptions.
4068 4069 4070 |
# File 'lib/stripe/resources/invoice.rb', line 4068 def type @type end |