Class: Stripe::Invoice::CreatePreviewParams::SubscriptionDetails::Item::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



4513
4514
4515
4516
4517
# File 'lib/stripe/resources/invoice.rb', line 4513

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



4507
4508
4509
# File 'lib/stripe/resources/invoice.rb', line 4507

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



4509
4510
4511
# File 'lib/stripe/resources/invoice.rb', line 4509

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



4511
4512
4513
# File 'lib/stripe/resources/invoice.rb', line 4511

def type
  @type
end