Class: Stripe::Invoice::FinalizeInvoiceParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::FinalizeInvoiceParams
- Defined in:
- lib/stripe/resources/invoice.rb
Instance Attribute Summary collapse
-
#auto_advance ⇒ Object
Controls whether Stripe performs [automatic collection](stripe.com/docs/invoicing/integration/automatic-advancement-collection) of the invoice.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(auto_advance: nil, expand: nil) ⇒ FinalizeInvoiceParams
constructor
A new instance of FinalizeInvoiceParams.
Methods inherited from RequestParams
Constructor Details
#initialize(auto_advance: nil, expand: nil) ⇒ FinalizeInvoiceParams
Returns a new instance of FinalizeInvoiceParams.
2199 2200 2201 2202 |
# File 'lib/stripe/resources/invoice.rb', line 2199 def initialize(auto_advance: nil, expand: nil) @auto_advance = auto_advance @expand = end |
Instance Attribute Details
#auto_advance ⇒ Object
Controls whether Stripe performs [automatic collection](stripe.com/docs/invoicing/integration/automatic-advancement-collection) of the invoice. If ‘false`, the invoice’s state doesn’t automatically advance without an explicit action.
2195 2196 2197 |
# File 'lib/stripe/resources/invoice.rb', line 2195 def auto_advance @auto_advance end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2197 2198 2199 |
# File 'lib/stripe/resources/invoice.rb', line 2197 def @expand end |