Class: Stripe::Invoice::LastFinalizationError

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#advice_codeObject (readonly)

For card errors resulting from a card issuer decline, a short string indicating how to proceed with an error if they provide one.



274
275
276
# File 'lib/stripe/resources/invoice.rb', line 274

def advice_code
  @advice_code
end

#chargeObject (readonly)

For card errors, the ID of the failed charge.



276
277
278
# File 'lib/stripe/resources/invoice.rb', line 276

def charge
  @charge
end

#codeObject (readonly)

For some errors that could be handled programmatically, a short string indicating the error code reported.



278
279
280
# File 'lib/stripe/resources/invoice.rb', line 278

def code
  @code
end

#decline_codeObject (readonly)

For card errors resulting from a card issuer decline, a short string indicating the card issuer's reason for the decline if they provide one.



280
281
282
# File 'lib/stripe/resources/invoice.rb', line 280

def decline_code
  @decline_code
end

#doc_urlObject (readonly)

A URL to more information about the error code reported.



282
283
284
# File 'lib/stripe/resources/invoice.rb', line 282

def doc_url
  @doc_url
end

#gift_card_operationObject (readonly)

A GiftCardOperation represents an operation performed on a third-party gift card, such as activation, reload, cashout, balance check, or void.



285
286
287
# File 'lib/stripe/resources/invoice.rb', line 285

def gift_card_operation
  @gift_card_operation
end

#messageObject (readonly)

A human-readable message providing more details about the error. For card errors, these messages can be shown to your users.



287
288
289
# File 'lib/stripe/resources/invoice.rb', line 287

def message
  @message
end

#network_advice_codeObject (readonly)

For card errors resulting from a card issuer decline, a 2 digit code which indicates the advice given to merchant by the card network on how to proceed with an error.



289
290
291
# File 'lib/stripe/resources/invoice.rb', line 289

def network_advice_code
  @network_advice_code
end

#network_decline_codeObject (readonly)

For payments declined by the network, an alphanumeric code which indicates the reason the payment failed.



291
292
293
# File 'lib/stripe/resources/invoice.rb', line 291

def network_decline_code
  @network_decline_code
end

#paramObject (readonly)

If the error is parameter-specific, the parameter related to the error. For example, you can use this to display a message near the correct form field.



293
294
295
# File 'lib/stripe/resources/invoice.rb', line 293

def param
  @param
end

#payment_intentObject (readonly)

A PaymentIntent guides you through the process of collecting a payment from your customer. We recommend that you create exactly one PaymentIntent for each order or customer session in your system. You can reference the PaymentIntent later to see the history of payment attempts for a particular session.

A PaymentIntent transitions through multiple statuses throughout its lifetime as it interfaces with Stripe.js to perform authentication flows and ultimately creates at most one successful charge.

Related guide: Payment Intents API



305
306
307
# File 'lib/stripe/resources/invoice.rb', line 305

def payment_intent
  @payment_intent
end

#payment_methodObject (readonly)

PaymentMethod objects represent your customer's payment instruments. You can use them with PaymentIntents to collect payments or save them to Customer objects to store instrument details for future payments.

Related guides: Payment Methods and More Payment Scenarios.



311
312
313
# File 'lib/stripe/resources/invoice.rb', line 311

def payment_method
  @payment_method
end

#payment_method_typeObject (readonly)

If the error is specific to the type of payment method, the payment method type that had a problem. This field is only populated for invoice-related errors.



313
314
315
# File 'lib/stripe/resources/invoice.rb', line 313

def payment_method_type
  @payment_method_type
end

#request_log_urlObject (readonly)

A URL to the request log entry in your dashboard.



315
316
317
# File 'lib/stripe/resources/invoice.rb', line 315

def request_log_url
  @request_log_url
end

#setup_intentObject (readonly)

A SetupIntent guides you through the process of setting up and saving a customer's payment credentials for future payments. For example, you can use a SetupIntent to set up and save your customer's card without immediately collecting a payment. Later, you can use PaymentIntents to drive the payment flow.

Create a SetupIntent when you're ready to collect your customer's payment credentials. Don't maintain long-lived, unconfirmed SetupIntents because they might not be valid. The SetupIntent transitions through multiple statuses as it guides you through the setup process.

Successful SetupIntents result in payment credentials that are optimized for future payments. For example, cardholders in certain regions might need to be run through Strong Customer Authentication during payment method collection to streamline later off-session payments. If you use the SetupIntent with a Customer, it automatically attaches the resulting payment method to that Customer after successful setup. We recommend using SetupIntents or setup_future_usage on PaymentIntents to save payment methods to prevent saving invalid or unoptimized payment methods.

By using SetupIntents, you can reduce friction for your customers, even as regulations change over time.

Related guide: Setup Intents API



337
338
339
# File 'lib/stripe/resources/invoice.rb', line 337

def setup_intent
  @setup_intent
end

#sourceObject (readonly)

Attribute for field source



339
340
341
# File 'lib/stripe/resources/invoice.rb', line 339

def source
  @source
end

#typeObject (readonly)

The type of error returned. One of api_error, card_error, idempotency_error, or invalid_request_error



341
342
343
# File 'lib/stripe/resources/invoice.rb', line 341

def type
  @type
end

Class Method Details

.field_remappingsObject



347
348
349
# File 'lib/stripe/resources/invoice.rb', line 347

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



343
344
345
# File 'lib/stripe/resources/invoice.rb', line 343

def self.inner_class_types
  @inner_class_types = {}
end