Class: Stripe::Invoice::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Created, DueDate

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(collection_method: nil, created: nil, customer: nil, customer_account: nil, due_date: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, status: nil, subscription: nil) ⇒ ListParams

Returns a new instance of ListParams.



1229
1230
1231
1232
1233
1234
1235
1236
1237
1238
1239
1240
1241
1242
1243
1244
1245
1246
1247
1248
1249
1250
1251
1252
1253
# File 'lib/stripe/resources/invoice.rb', line 1229

def initialize(
  collection_method: nil,
  created: nil,
  customer: nil,
  customer_account: nil,
  due_date: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  starting_after: nil,
  status: nil,
  subscription: nil
)
  @collection_method = collection_method
  @created = created
  @customer = customer
  @customer_account = 
  @due_date = due_date
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
  @status = status
  @subscription = subscription
end

Instance Attribute Details

#collection_methodObject

The collection method of the invoice to retrieve. Either ‘charge_automatically` or `send_invoice`.



1207
1208
1209
# File 'lib/stripe/resources/invoice.rb', line 1207

def collection_method
  @collection_method
end

#createdObject

Only return invoices that were created during the given date interval.



1209
1210
1211
# File 'lib/stripe/resources/invoice.rb', line 1209

def created
  @created
end

#customerObject

Only return invoices for the customer specified by this customer ID.



1211
1212
1213
# File 'lib/stripe/resources/invoice.rb', line 1211

def customer
  @customer
end

#customer_accountObject

Only return invoices for the account specified by this account ID.



1213
1214
1215
# File 'lib/stripe/resources/invoice.rb', line 1213

def 
  @customer_account
end

#due_dateObject

Attribute for param field due_date



1215
1216
1217
# File 'lib/stripe/resources/invoice.rb', line 1215

def due_date
  @due_date
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



1217
1218
1219
# File 'lib/stripe/resources/invoice.rb', line 1217

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



1219
1220
1221
# File 'lib/stripe/resources/invoice.rb', line 1219

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



1221
1222
1223
# File 'lib/stripe/resources/invoice.rb', line 1221

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



1223
1224
1225
# File 'lib/stripe/resources/invoice.rb', line 1223

def starting_after
  @starting_after
end

#statusObject

The status of the invoice, one of ‘draft`, `open`, `paid`, `uncollectible`, or `void`. [Learn more](stripe.com/docs/billing/invoices/workflow#workflow-overview)



1225
1226
1227
# File 'lib/stripe/resources/invoice.rb', line 1225

def status
  @status
end

#subscriptionObject

Only return invoices for the subscription specified by this subscription ID.



1227
1228
1229
# File 'lib/stripe/resources/invoice.rb', line 1227

def subscription
  @subscription
end