Class: Stripe::Invoice::ListUpcomingLineItemsParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::ListUpcomingLineItemsParams
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: AutomaticTax, CustomerDetails, Discount, InvoiceItem, Issuer, ScheduleDetails, SubscriptionDetails, SubscriptionItem, SubscriptionPrebilling
Instance Attribute Summary collapse
-
#automatic_tax ⇒ Object
Settings for automatic tax lookup for this invoice preview.
-
#coupon ⇒ Object
The ID of the coupon to apply to this phase of the subscription schedule.
-
#currency ⇒ Object
The currency to preview this invoice in.
-
#customer ⇒ Object
The identifier of the customer whose upcoming invoice you’d like to retrieve.
-
#customer_details ⇒ Object
Details about the customer you want to invoice or overrides for an existing customer.
-
#discounts ⇒ Object
The coupons to redeem into discounts for the invoice preview.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#invoice_items ⇒ Object
List of invoice items to add or update in the upcoming invoice preview (up to 250).
-
#issuer ⇒ Object
The connected account that issues the invoice.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#on_behalf_of ⇒ Object
The account (if any) for which the funds of the invoice payment are intended.
-
#preview_mode ⇒ Object
Customizes the types of values to include when calculating the invoice.
-
#schedule ⇒ Object
The identifier of the schedule whose upcoming invoice you’d like to retrieve.
-
#schedule_details ⇒ Object
The schedule creation or modification params to apply as a preview.
-
#starting_after ⇒ Object
A cursor for use in pagination.
-
#subscription ⇒ Object
The identifier of the subscription for which you’d like to retrieve the upcoming invoice.
-
#subscription_billing_cycle_anchor ⇒ Object
For new subscriptions, a future timestamp to anchor the subscription’s [billing cycle](stripe.com/docs/subscriptions/billing-cycle).
-
#subscription_cancel_at ⇒ Object
A timestamp at which the subscription should cancel.
-
#subscription_cancel_at_period_end ⇒ Object
Indicate whether this subscription should cancel at the end of the current period (‘current_period_end`).
-
#subscription_cancel_now ⇒ Object
This simulates the subscription being canceled or expired immediately.
-
#subscription_default_tax_rates ⇒ Object
If provided, the invoice returned will preview updating or creating a subscription with these default tax rates.
-
#subscription_details ⇒ Object
The subscription creation or modification params to apply as a preview.
-
#subscription_items ⇒ Object
A list of up to 20 subscription items, each with an attached price.
-
#subscription_prebilling ⇒ Object
The pre-billing to apply to the subscription as a preview.
-
#subscription_proration_behavior ⇒ Object
Determines how to handle [prorations](stripe.com/docs/billing/subscriptions/prorations) when the billing cycle changes (e.g., when switching plans, resetting ‘billing_cycle_anchor=now`, or starting a trial), or if an item’s ‘quantity` changes.
-
#subscription_proration_date ⇒ Object
If previewing an update to a subscription, and doing proration, ‘subscription_proration_date` forces the proration to be calculated as though the update was done at the specified time.
-
#subscription_resume_at ⇒ Object
For paused subscriptions, setting ‘subscription_resume_at` to `now` will preview the invoice that will be generated if the subscription is resumed.
-
#subscription_start_date ⇒ Object
Date a subscription is intended to start (can be future or past).
-
#subscription_trial_end ⇒ Object
If provided, the invoice returned will preview updating or creating a subscription with that trial end.
-
#subscription_trial_from_plan ⇒ Object
Indicates if a plan’s ‘trial_period_days` should be applied to the subscription.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(automatic_tax: nil, coupon: nil, currency: nil, customer: nil, customer_details: nil, discounts: nil, ending_before: nil, expand: nil, invoice_items: nil, issuer: nil, limit: nil, on_behalf_of: nil, preview_mode: nil, schedule: nil, schedule_details: nil, starting_after: nil, subscription: nil, subscription_billing_cycle_anchor: nil, subscription_cancel_at: nil, subscription_cancel_at_period_end: nil, subscription_cancel_now: nil, subscription_default_tax_rates: nil, subscription_details: nil, subscription_items: nil, subscription_prebilling: nil, subscription_proration_behavior: nil, subscription_proration_date: nil, subscription_resume_at: nil, subscription_start_date: nil, subscription_trial_end: nil, subscription_trial_from_plan: nil) ⇒ ListUpcomingLineItemsParams
Returns a new instance of ListUpcomingLineItemsParams.
5508 5509 5510 5511 5512 5513 5514 5515 5516 5517 5518 5519 5520 5521 5522 5523 5524 5525 5526 5527 5528 5529 5530 5531 5532 5533 5534 5535 5536 5537 5538 5539 5540 5541 5542 5543 5544 5545 5546 5547 5548 5549 5550 5551 5552 5553 5554 5555 5556 5557 5558 5559 5560 5561 5562 5563 5564 5565 5566 5567 5568 5569 5570 5571 5572 |
# File 'lib/stripe/resources/invoice.rb', line 5508 def initialize( automatic_tax: nil, coupon: nil, currency: nil, customer: nil, customer_details: nil, discounts: nil, ending_before: nil, expand: nil, invoice_items: nil, issuer: nil, limit: nil, on_behalf_of: nil, preview_mode: nil, schedule: nil, schedule_details: nil, starting_after: nil, subscription: nil, subscription_billing_cycle_anchor: nil, subscription_cancel_at: nil, subscription_cancel_at_period_end: nil, subscription_cancel_now: nil, subscription_default_tax_rates: nil, subscription_details: nil, subscription_items: nil, subscription_prebilling: nil, subscription_proration_behavior: nil, subscription_proration_date: nil, subscription_resume_at: nil, subscription_start_date: nil, subscription_trial_end: nil, subscription_trial_from_plan: nil ) @automatic_tax = automatic_tax @coupon = coupon @currency = currency @customer = customer @customer_details = customer_details @discounts = discounts @ending_before = ending_before @expand = @invoice_items = invoice_items @issuer = issuer @limit = limit @on_behalf_of = on_behalf_of @preview_mode = preview_mode @schedule = schedule @schedule_details = schedule_details @starting_after = starting_after @subscription = subscription @subscription_billing_cycle_anchor = subscription_billing_cycle_anchor @subscription_cancel_at = subscription_cancel_at @subscription_cancel_at_period_end = subscription_cancel_at_period_end @subscription_cancel_now = subscription_cancel_now @subscription_default_tax_rates = subscription_default_tax_rates @subscription_details = subscription_details @subscription_items = subscription_items @subscription_prebilling = subscription_prebilling @subscription_proration_behavior = subscription_proration_behavior @subscription_proration_date = subscription_proration_date @subscription_resume_at = subscription_resume_at @subscription_start_date = subscription_start_date @subscription_trial_end = subscription_trial_end @subscription_trial_from_plan = subscription_trial_from_plan end |
Instance Attribute Details
#automatic_tax ⇒ Object
Settings for automatic tax lookup for this invoice preview.
5446 5447 5448 |
# File 'lib/stripe/resources/invoice.rb', line 5446 def automatic_tax @automatic_tax end |
#coupon ⇒ Object
The ID of the coupon to apply to this phase of the subscription schedule. This field has been deprecated and will be removed in a future API version. Use ‘discounts` instead.
5448 5449 5450 |
# File 'lib/stripe/resources/invoice.rb', line 5448 def coupon @coupon end |
#currency ⇒ Object
The currency to preview this invoice in. Defaults to that of ‘customer` if not specified.
5450 5451 5452 |
# File 'lib/stripe/resources/invoice.rb', line 5450 def currency @currency end |
#customer ⇒ Object
The identifier of the customer whose upcoming invoice you’d like to retrieve. If ‘automatic_tax` is enabled then one of `customer`, `customer_details`, `subscription`, or `schedule` must be set.
5452 5453 5454 |
# File 'lib/stripe/resources/invoice.rb', line 5452 def customer @customer end |
#customer_details ⇒ Object
Details about the customer you want to invoice or overrides for an existing customer. If ‘automatic_tax` is enabled then one of `customer`, `customer_details`, `subscription`, or `schedule` must be set.
5454 5455 5456 |
# File 'lib/stripe/resources/invoice.rb', line 5454 def customer_details @customer_details end |
#discounts ⇒ Object
The coupons to redeem into discounts for the invoice preview. If not specified, inherits the discount from the subscription or customer. This works for both coupons directly applied to an invoice and coupons applied to a subscription. Pass an empty string to avoid inheriting any discounts.
5456 5457 5458 |
# File 'lib/stripe/resources/invoice.rb', line 5456 def discounts @discounts end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
5458 5459 5460 |
# File 'lib/stripe/resources/invoice.rb', line 5458 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
5460 5461 5462 |
# File 'lib/stripe/resources/invoice.rb', line 5460 def @expand end |
#invoice_items ⇒ Object
List of invoice items to add or update in the upcoming invoice preview (up to 250).
5462 5463 5464 |
# File 'lib/stripe/resources/invoice.rb', line 5462 def invoice_items @invoice_items end |
#issuer ⇒ Object
The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.
5464 5465 5466 |
# File 'lib/stripe/resources/invoice.rb', line 5464 def issuer @issuer end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
5466 5467 5468 |
# File 'lib/stripe/resources/invoice.rb', line 5466 def limit @limit end |
#on_behalf_of ⇒ Object
The account (if any) for which the funds of the invoice payment are intended. If set, the invoice will be presented with the branding and support information of the specified account. See the [Invoices with Connect](stripe.com/docs/billing/invoices/connect) documentation for details.
5468 5469 5470 |
# File 'lib/stripe/resources/invoice.rb', line 5468 def on_behalf_of @on_behalf_of end |
#preview_mode ⇒ Object
Customizes the types of values to include when calculating the invoice. Defaults to ‘next` if unspecified.
5470 5471 5472 |
# File 'lib/stripe/resources/invoice.rb', line 5470 def preview_mode @preview_mode end |
#schedule ⇒ Object
The identifier of the schedule whose upcoming invoice you’d like to retrieve. Cannot be used with subscription or subscription fields.
5472 5473 5474 |
# File 'lib/stripe/resources/invoice.rb', line 5472 def schedule @schedule end |
#schedule_details ⇒ Object
The schedule creation or modification params to apply as a preview. Cannot be used with ‘subscription` or `subscription_` prefixed fields.
5474 5475 5476 |
# File 'lib/stripe/resources/invoice.rb', line 5474 def schedule_details @schedule_details end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
5476 5477 5478 |
# File 'lib/stripe/resources/invoice.rb', line 5476 def starting_after @starting_after end |
#subscription ⇒ Object
The identifier of the subscription for which you’d like to retrieve the upcoming invoice. If not provided, but a ‘subscription_details.items` is provided, you will preview creating a subscription with those items. If neither `subscription` nor `subscription_details.items` is provided, you will retrieve the next upcoming invoice from among the customer’s subscriptions.
5478 5479 5480 |
# File 'lib/stripe/resources/invoice.rb', line 5478 def subscription @subscription end |
#subscription_billing_cycle_anchor ⇒ Object
For new subscriptions, a future timestamp to anchor the subscription’s [billing cycle](stripe.com/docs/subscriptions/billing-cycle). This is used to determine the date of the first full invoice, and, for plans with ‘month` or `year` intervals, the day of the month for subsequent invoices. For existing subscriptions, the value can only be set to `now` or `unchanged`. This field has been deprecated and will be removed in a future API version. Use `subscription_details.billing_cycle_anchor` instead.
5480 5481 5482 |
# File 'lib/stripe/resources/invoice.rb', line 5480 def subscription_billing_cycle_anchor @subscription_billing_cycle_anchor end |
#subscription_cancel_at ⇒ Object
A timestamp at which the subscription should cancel. If set to a date before the current period ends, this will cause a proration if prorations have been enabled using ‘proration_behavior`. If set during a future period, this will always cause a proration for that period. This field has been deprecated and will be removed in a future API version. Use `subscription_details.cancel_at` instead.
5482 5483 5484 |
# File 'lib/stripe/resources/invoice.rb', line 5482 def subscription_cancel_at @subscription_cancel_at end |
#subscription_cancel_at_period_end ⇒ Object
Indicate whether this subscription should cancel at the end of the current period (‘current_period_end`). Defaults to `false`. This field has been deprecated and will be removed in a future API version. Use `subscription_details.cancel_at_period_end` instead.
5484 5485 5486 |
# File 'lib/stripe/resources/invoice.rb', line 5484 def subscription_cancel_at_period_end @subscription_cancel_at_period_end end |
#subscription_cancel_now ⇒ Object
This simulates the subscription being canceled or expired immediately. This field has been deprecated and will be removed in a future API version. Use ‘subscription_details.cancel_now` instead.
5486 5487 5488 |
# File 'lib/stripe/resources/invoice.rb', line 5486 def subscription_cancel_now @subscription_cancel_now end |
#subscription_default_tax_rates ⇒ Object
If provided, the invoice returned will preview updating or creating a subscription with these default tax rates. The default tax rates will apply to any line item that does not have ‘tax_rates` set. This field has been deprecated and will be removed in a future API version. Use `subscription_details.default_tax_rates` instead.
5488 5489 5490 |
# File 'lib/stripe/resources/invoice.rb', line 5488 def subscription_default_tax_rates @subscription_default_tax_rates end |
#subscription_details ⇒ Object
The subscription creation or modification params to apply as a preview. Cannot be used with ‘schedule` or `schedule_details` fields.
5490 5491 5492 |
# File 'lib/stripe/resources/invoice.rb', line 5490 def subscription_details @subscription_details end |
#subscription_items ⇒ Object
A list of up to 20 subscription items, each with an attached price. This field has been deprecated and will be removed in a future API version. Use ‘subscription_details.items` instead.
5492 5493 5494 |
# File 'lib/stripe/resources/invoice.rb', line 5492 def subscription_items @subscription_items end |
#subscription_prebilling ⇒ Object
The pre-billing to apply to the subscription as a preview. This field has been deprecated and will be removed in a future API version. Use ‘subscription_details.prebilling` instead.
5494 5495 5496 |
# File 'lib/stripe/resources/invoice.rb', line 5494 def subscription_prebilling @subscription_prebilling end |
#subscription_proration_behavior ⇒ Object
Determines how to handle [prorations](stripe.com/docs/billing/subscriptions/prorations) when the billing cycle changes (e.g., when switching plans, resetting ‘billing_cycle_anchor=now`, or starting a trial), or if an item’s ‘quantity` changes. The default value is `create_prorations`. This field has been deprecated and will be removed in a future API version. Use `subscription_details.proration_behavior` instead.
5496 5497 5498 |
# File 'lib/stripe/resources/invoice.rb', line 5496 def subscription_proration_behavior @subscription_proration_behavior end |
#subscription_proration_date ⇒ Object
If previewing an update to a subscription, and doing proration, ‘subscription_proration_date` forces the proration to be calculated as though the update was done at the specified time. The time given must be within the current subscription period and within the current phase of the schedule backing this subscription, if the schedule exists. If set, `subscription`, and one of `subscription_items`, or `subscription_trial_end` are required. Also, `subscription_proration_behavior` cannot be set to ’none’. This field has been deprecated and will be removed in a future API version. Use ‘subscription_details.proration_date` instead.
5498 5499 5500 |
# File 'lib/stripe/resources/invoice.rb', line 5498 def subscription_proration_date @subscription_proration_date end |
#subscription_resume_at ⇒ Object
For paused subscriptions, setting ‘subscription_resume_at` to `now` will preview the invoice that will be generated if the subscription is resumed. This field has been deprecated and will be removed in a future API version. Use `subscription_details.resume_at` instead.
5500 5501 5502 |
# File 'lib/stripe/resources/invoice.rb', line 5500 def subscription_resume_at @subscription_resume_at end |
#subscription_start_date ⇒ Object
Date a subscription is intended to start (can be future or past). This field has been deprecated and will be removed in a future API version. Use ‘subscription_details.start_date` instead.
5502 5503 5504 |
# File 'lib/stripe/resources/invoice.rb', line 5502 def subscription_start_date @subscription_start_date end |
#subscription_trial_end ⇒ Object
If provided, the invoice returned will preview updating or creating a subscription with that trial end. If set, one of ‘subscription_items` or `subscription` is required. This field has been deprecated and will be removed in a future API version. Use `subscription_details.trial_end` instead.
5504 5505 5506 |
# File 'lib/stripe/resources/invoice.rb', line 5504 def subscription_trial_end @subscription_trial_end end |
#subscription_trial_from_plan ⇒ Object
Indicates if a plan’s ‘trial_period_days` should be applied to the subscription. Setting `subscription_trial_end` per subscription is preferred, and this defaults to `false`. Setting this flag to `true` together with `subscription_trial_end` is not allowed. See [Using trial periods on subscriptions](stripe.com/docs/billing/subscriptions/trials) to learn more.
5506 5507 5508 |
# File 'lib/stripe/resources/invoice.rb', line 5506 def subscription_trial_from_plan @subscription_trial_from_plan end |