Class: Stripe::Invoice::ListUpcomingLineItemsParams::AutomaticTax
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::ListUpcomingLineItemsParams::AutomaticTax
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: Liability
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Whether Stripe automatically computes tax on this invoice.
-
#liability ⇒ Object
The account that’s liable for tax.
Instance Method Summary collapse
-
#initialize(enabled: nil, liability: nil) ⇒ AutomaticTax
constructor
A new instance of AutomaticTax.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, liability: nil) ⇒ AutomaticTax
Returns a new instance of AutomaticTax.
3729 3730 3731 3732 |
# File 'lib/stripe/resources/invoice.rb', line 3729 def initialize(enabled: nil, liability: nil) @enabled = enabled @liability = liability end |
Instance Attribute Details
#enabled ⇒ Object
Whether Stripe automatically computes tax on this invoice. Note that incompatible invoice items (invoice items with manually specified [tax rates](stripe.com/docs/api/tax_rates), negative amounts, or ‘tax_behavior=unspecified`) cannot be added to automatic tax invoices.
3725 3726 3727 |
# File 'lib/stripe/resources/invoice.rb', line 3725 def enabled @enabled end |
#liability ⇒ Object
The account that’s liable for tax. If set, the business address and tax registrations required to perform the tax calculation are loaded from this account. The tax transaction is returned in the report of the connected account.
3727 3728 3729 |
# File 'lib/stripe/resources/invoice.rb', line 3727 def liability @liability end |