Class: Stripe::Invoice::ListUpcomingLineItemsParams::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::ListUpcomingLineItemsParams::Discount
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
3887 3888 3889 3890 3891 3892 |
# File 'lib/stripe/resources/invoice.rb', line 3887 def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
3879 3880 3881 |
# File 'lib/stripe/resources/invoice.rb', line 3879 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
3881 3882 3883 |
# File 'lib/stripe/resources/invoice.rb', line 3881 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
3883 3884 3885 |
# File 'lib/stripe/resources/invoice.rb', line 3883 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
3885 3886 3887 |
# File 'lib/stripe/resources/invoice.rb', line 3885 def promotion_code @promotion_code end |