Class: Stripe::Invoice::ListUpcomingLineItemsParams::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



3872
3873
3874
3875
3876
# File 'lib/stripe/resources/invoice.rb', line 3872

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



3866
3867
3868
# File 'lib/stripe/resources/invoice.rb', line 3866

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



3868
3869
3870
# File 'lib/stripe/resources/invoice.rb', line 3868

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



3870
3871
3872
# File 'lib/stripe/resources/invoice.rb', line 3870

def type
  @type
end