Class: Stripe::Invoice::ListUpcomingLineItemsParams::InvoiceItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



4526
4527
4528
4529
4530
4531
# File 'lib/stripe/resources/invoice.rb', line 4526

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



4515
4516
4517
# File 'lib/stripe/resources/invoice.rb', line 4515

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



4518
4519
4520
# File 'lib/stripe/resources/invoice.rb', line 4518

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



4521
4522
4523
# File 'lib/stripe/resources/invoice.rb', line 4521

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



4524
4525
4526
# File 'lib/stripe/resources/invoice.rb', line 4524

def promotion_code
  @promotion_code
end