Class: Stripe::Invoice::ListUpcomingLineItemsParams::ScheduleDetails::Amendment::AmendmentEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd, Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ AmendmentEnd

Returns a new instance of AmendmentEnd.



4091
4092
4093
4094
4095
4096
# File 'lib/stripe/resources/invoice.rb', line 4091

def initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil)
  @discount_end = discount_end
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#discount_endObject

Use the ‘end` time of a given discount.



4083
4084
4085
# File 'lib/stripe/resources/invoice.rb', line 4083

def discount_end
  @discount_end
end

#durationObject

Time span for the amendment starting from the ‘amendment_start`.



4085
4086
4087
# File 'lib/stripe/resources/invoice.rb', line 4085

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the amendment to end. Must be after the ‘amendment_start`.



4087
4088
4089
# File 'lib/stripe/resources/invoice.rb', line 4087

def timestamp
  @timestamp
end

#typeObject

Select one of three ways to pass the ‘amendment_end`.



4089
4090
4091
# File 'lib/stripe/resources/invoice.rb', line 4089

def type
  @type
end