Class: Stripe::Invoice::ListUpcomingLineItemsParams::ScheduleDetails::Amendment::AmendmentEnd::Duration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(interval: nil, interval_count: nil) ⇒ Duration

Returns a new instance of Duration.



4694
4695
4696
4697
# File 'lib/stripe/resources/invoice.rb', line 4694

def initialize(interval: nil, interval_count: nil)
  @interval = interval
  @interval_count = interval_count
end

Instance Attribute Details

#intervalObject

Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.



4689
4690
4691
# File 'lib/stripe/resources/invoice.rb', line 4689

def interval
  @interval
end

#interval_countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



4692
4693
4694
# File 'lib/stripe/resources/invoice.rb', line 4692

def interval_count
  @interval_count
end