Class: Stripe::Invoice::ListUpcomingLineItemsParams::ScheduleDetails::Amendment::AmendmentStart

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: AmendmentEnd, DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendment_end: nil, discount_end: nil, timestamp: nil, type: nil) ⇒ AmendmentStart

Returns a new instance of AmendmentStart.



4749
4750
4751
4752
4753
4754
# File 'lib/stripe/resources/invoice.rb', line 4749

def initialize(amendment_end: nil, discount_end: nil, timestamp: nil, type: nil)
  @amendment_end = amendment_end
  @discount_end = discount_end
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#amendment_endObject

Details of another amendment in the same array, immediately after which this amendment should begin.



4738
4739
4740
# File 'lib/stripe/resources/invoice.rb', line 4738

def amendment_end
  @amendment_end
end

#discount_endObject

Use the ‘end` time of a given discount.



4741
4742
4743
# File 'lib/stripe/resources/invoice.rb', line 4741

def discount_end
  @discount_end
end

#timestampObject

A precise Unix timestamp for the amendment to start.



4744
4745
4746
# File 'lib/stripe/resources/invoice.rb', line 4744

def timestamp
  @timestamp
end

#typeObject

Select one of three ways to pass the ‘amendment_start`.



4747
4748
4749
# File 'lib/stripe/resources/invoice.rb', line 4747

def type
  @type
end