Class: Stripe::Invoice::ListUpcomingLineItemsParams::ScheduleDetails::Amendment::DiscountAction
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::ListUpcomingLineItemsParams::ScheduleDetails::Amendment::DiscountAction
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#add ⇒ Object
Details of the discount to add.
-
#remove ⇒ Object
Details of the discount to remove.
-
#set ⇒ Object
Details of the discount to replace the existing discounts with.
-
#type ⇒ Object
Determines the type of discount action.
Instance Method Summary collapse
-
#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ DiscountAction
constructor
A new instance of DiscountAction.
Methods inherited from RequestParams
Constructor Details
#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ DiscountAction
Returns a new instance of DiscountAction.
4208 4209 4210 4211 4212 4213 |
# File 'lib/stripe/resources/invoice.rb', line 4208 def initialize(add: nil, remove: nil, set: nil, type: nil) @add = add @remove = remove @set = set @type = type end |
Instance Attribute Details
#add ⇒ Object
Details of the discount to add.
4200 4201 4202 |
# File 'lib/stripe/resources/invoice.rb', line 4200 def add @add end |
#remove ⇒ Object
Details of the discount to remove.
4202 4203 4204 |
# File 'lib/stripe/resources/invoice.rb', line 4202 def remove @remove end |
#set ⇒ Object
Details of the discount to replace the existing discounts with.
4204 4205 4206 |
# File 'lib/stripe/resources/invoice.rb', line 4204 def set @set end |
#type ⇒ Object
Determines the type of discount action.
4206 4207 4208 |
# File 'lib/stripe/resources/invoice.rb', line 4206 def type @type end |