Class: Stripe::Invoice::ListUpcomingLineItemsParams::ScheduleDetails::Amendment::DiscountAction::Set

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Set

Returns a new instance of Set.



4193
4194
4195
4196
4197
# File 'lib/stripe/resources/invoice.rb', line 4193

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to replace the ‘discounts` array with.



4187
4188
4189
# File 'lib/stripe/resources/invoice.rb', line 4187

def coupon
  @coupon
end

#discountObject

An ID of an existing discount to replace the ‘discounts` array with.



4189
4190
4191
# File 'lib/stripe/resources/invoice.rb', line 4189

def discount
  @discount
end

#promotion_codeObject

An ID of an existing promotion code to replace the ‘discounts` array with.



4191
4192
4193
# File 'lib/stripe/resources/invoice.rb', line 4191

def promotion_code
  @promotion_code
end