Class: Stripe::Invoice::ListUpcomingLineItemsParams::ScheduleDetails::Amendment::ItemAction

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Add, Remove, Set

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ ItemAction

Returns a new instance of ItemAction.



4404
4405
4406
4407
4408
4409
# File 'lib/stripe/resources/invoice.rb', line 4404

def initialize(add: nil, remove: nil, set: nil, type: nil)
  @add = add
  @remove = remove
  @set = set
  @type = type
end

Instance Attribute Details

#addObject

Details of the subscription item to add. If an item with the same ‘price` exists, it will be replaced by this new item. Otherwise, it adds the new item.



4396
4397
4398
# File 'lib/stripe/resources/invoice.rb', line 4396

def add
  @add
end

#removeObject

Details of the subscription item to remove.



4398
4399
4400
# File 'lib/stripe/resources/invoice.rb', line 4398

def remove
  @remove
end

#setObject

Details of the subscription item to replace the existing items with. If an item with the ‘set` already exists, the `items` array is not cleared. Instead, all of the other `set` properties that are passed in this request will replace the existing values for the configuration item.



4400
4401
4402
# File 'lib/stripe/resources/invoice.rb', line 4400

def set
  @set
end

#typeObject

Determines the type of item action.



4402
4403
4404
# File 'lib/stripe/resources/invoice.rb', line 4402

def type
  @type
end