Class: Stripe::Invoice::ListUpcomingLineItemsParams::ScheduleDetails::Amendment::ItemAction::Add

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Discount, Trial

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Add

Returns a new instance of Add.



4285
4286
4287
4288
4289
4290
4291
4292
4293
4294
4295
4296
4297
4298
4299
# File 'lib/stripe/resources/invoice.rb', line 4285

def initialize(
  discounts: nil,
  metadata: nil,
  price: nil,
  quantity: nil,
  tax_rates: nil,
  trial: nil
)
  @discounts = discounts
  @metadata = 
  @price = price
  @quantity = quantity
  @tax_rates = tax_rates
  @trial = trial
end

Instance Attribute Details

#discountsObject

The discounts applied to the item. Subscription item discounts are applied before subscription discounts.



4273
4274
4275
# File 'lib/stripe/resources/invoice.rb', line 4273

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



4275
4276
4277
# File 'lib/stripe/resources/invoice.rb', line 4275

def 
  @metadata
end

#priceObject

The ID of the price object.



4277
4278
4279
# File 'lib/stripe/resources/invoice.rb', line 4277

def price
  @price
end

#quantityObject

Quantity for this item.



4279
4280
4281
# File 'lib/stripe/resources/invoice.rb', line 4279

def quantity
  @quantity
end

#tax_ratesObject

The tax rates that apply to this subscription item. When set, the ‘default_tax_rates` on the subscription do not apply to this `subscription_item`.



4281
4282
4283
# File 'lib/stripe/resources/invoice.rb', line 4281

def tax_rates
  @tax_rates
end

#trialObject

Options that configure the trial on the subscription item.



4283
4284
4285
# File 'lib/stripe/resources/invoice.rb', line 4283

def trial
  @trial
end