Class: Stripe::Invoice::ListUpcomingLineItemsParams::ScheduleDetails::Amendment::ItemAction::Add::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



4893
4894
4895
4896
4897
4898
# File 'lib/stripe/resources/invoice.rb', line 4893

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



4882
4883
4884
# File 'lib/stripe/resources/invoice.rb', line 4882

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



4885
4886
4887
# File 'lib/stripe/resources/invoice.rb', line 4885

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



4888
4889
4890
# File 'lib/stripe/resources/invoice.rb', line 4888

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



4891
4892
4893
# File 'lib/stripe/resources/invoice.rb', line 4891

def promotion_code
  @promotion_code
end