Class: Stripe::Invoice::ListUpcomingLineItemsParams::ScheduleDetails::Amendment::ItemAction::Set::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



4347
4348
4349
4350
4351
4352
# File 'lib/stripe/resources/invoice.rb', line 4347

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



4339
4340
4341
# File 'lib/stripe/resources/invoice.rb', line 4339

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



4341
4342
4343
# File 'lib/stripe/resources/invoice.rb', line 4341

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



4343
4344
4345
# File 'lib/stripe/resources/invoice.rb', line 4343

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



4345
4346
4347
# File 'lib/stripe/resources/invoice.rb', line 4345

def promotion_code
  @promotion_code
end