Class: Stripe::Invoice::ListUpcomingLineItemsParams::ScheduleDetails::Phase::AddInvoiceItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::ListUpcomingLineItemsParams::ScheduleDetails::Phase::AddInvoiceItem
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#discounts ⇒ Object
The coupons to redeem into discounts for the item.
-
#price ⇒ Object
The ID of the price object.
-
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.
-
#quantity ⇒ Object
Quantity for this item.
-
#tax_rates ⇒ Object
The tax rates which apply to the item.
Instance Method Summary collapse
-
#initialize(discounts: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ AddInvoiceItem
constructor
A new instance of AddInvoiceItem.
Methods inherited from RequestParams
Constructor Details
#initialize(discounts: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ AddInvoiceItem
Returns a new instance of AddInvoiceItem.
4594 4595 4596 4597 4598 4599 4600 4601 4602 4603 4604 4605 4606 |
# File 'lib/stripe/resources/invoice.rb', line 4594 def initialize( discounts: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil ) @discounts = discounts @price = price @price_data = price_data @quantity = quantity @tax_rates = tax_rates end |
Instance Attribute Details
#discounts ⇒ Object
The coupons to redeem into discounts for the item.
4584 4585 4586 |
# File 'lib/stripe/resources/invoice.rb', line 4584 def discounts @discounts end |
#price ⇒ Object
The ID of the price object. One of ‘price` or `price_data` is required.
4586 4587 4588 |
# File 'lib/stripe/resources/invoice.rb', line 4586 def price @price end |
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.
4588 4589 4590 |
# File 'lib/stripe/resources/invoice.rb', line 4588 def price_data @price_data end |
#quantity ⇒ Object
Quantity for this item. Defaults to 1.
4590 4591 4592 |
# File 'lib/stripe/resources/invoice.rb', line 4590 def quantity @quantity end |
#tax_rates ⇒ Object
The tax rates which apply to the item. When set, the ‘default_tax_rates` do not apply to this item.
4592 4593 4594 |
# File 'lib/stripe/resources/invoice.rb', line 4592 def tax_rates @tax_rates end |