Class: Stripe::Invoice::ListUpcomingLineItemsParams::ScheduleDetails::Phase::AddInvoiceItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



5211
5212
5213
5214
5215
# File 'lib/stripe/resources/invoice.rb', line 5211

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



5203
5204
5205
# File 'lib/stripe/resources/invoice.rb', line 5203

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



5206
5207
5208
# File 'lib/stripe/resources/invoice.rb', line 5206

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



5209
5210
5211
# File 'lib/stripe/resources/invoice.rb', line 5209

def type
  @type
end