Class: Stripe::Invoice::ListUpcomingLineItemsParams::ScheduleDetails::Phase::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



4664
4665
4666
4667
4668
# File 'lib/stripe/resources/invoice.rb', line 4664

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



4658
4659
4660
# File 'lib/stripe/resources/invoice.rb', line 4658

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



4660
4661
4662
# File 'lib/stripe/resources/invoice.rb', line 4660

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



4662
4663
4664
# File 'lib/stripe/resources/invoice.rb', line 4662

def type
  @type
end