Class: Stripe::Invoice::ListUpcomingLineItemsParams::ScheduleDetails::Phase::Item::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::ListUpcomingLineItemsParams::ScheduleDetails::Phase::Item::Discount::DiscountEnd
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
4743 4744 4745 4746 4747 |
# File 'lib/stripe/resources/invoice.rb', line 4743 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
4737 4738 4739 |
# File 'lib/stripe/resources/invoice.rb', line 4737 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
4739 4740 4741 |
# File 'lib/stripe/resources/invoice.rb', line 4739 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
4741 4742 4743 |
# File 'lib/stripe/resources/invoice.rb', line 4741 def type @type end |