Class: Stripe::Invoice::ListUpcomingLineItemsParams::ScheduleDetails::Phase::PauseCollection
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::ListUpcomingLineItemsParams::ScheduleDetails::Phase::PauseCollection
- Defined in:
- lib/stripe/resources/invoice.rb
Instance Attribute Summary collapse
-
#behavior ⇒ Object
The payment collection behavior for this subscription while paused.
Instance Method Summary collapse
-
#initialize(behavior: nil) ⇒ PauseCollection
constructor
A new instance of PauseCollection.
Methods inherited from RequestParams
Constructor Details
#initialize(behavior: nil) ⇒ PauseCollection
Returns a new instance of PauseCollection.
5586 5587 5588 |
# File 'lib/stripe/resources/invoice.rb', line 5586 def initialize(behavior: nil) @behavior = behavior end |
Instance Attribute Details
#behavior ⇒ Object
The payment collection behavior for this subscription while paused. One of ‘keep_as_draft`, `mark_uncollectible`, or `void`.
5584 5585 5586 |
# File 'lib/stripe/resources/invoice.rb', line 5584 def behavior @behavior end |