Class: Stripe::Invoice::ListUpcomingLineItemsParams::ScheduleDetails::Prebilling::BillUntil
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::ListUpcomingLineItemsParams::ScheduleDetails::Prebilling::BillUntil
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: AmendmentEnd, Duration
Instance Attribute Summary collapse
-
#amendment_end ⇒ Object
End the prebilled period when a specified amendment ends.
-
#duration ⇒ Object
Time span for prebilling, starting from ‘bill_from`.
-
#timestamp ⇒ Object
End the prebilled period at a precise integer timestamp, starting from the Unix epoch.
-
#type ⇒ Object
Select one of several ways to pass the ‘bill_until` value.
Instance Method Summary collapse
-
#initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ BillUntil
constructor
A new instance of BillUntil.
Methods inherited from RequestParams
Constructor Details
#initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ BillUntil
Returns a new instance of BillUntil.
5039 5040 5041 5042 5043 5044 |
# File 'lib/stripe/resources/invoice.rb', line 5039 def initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil) @amendment_end = amendment_end @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#amendment_end ⇒ Object
End the prebilled period when a specified amendment ends.
5031 5032 5033 |
# File 'lib/stripe/resources/invoice.rb', line 5031 def amendment_end @amendment_end end |
#duration ⇒ Object
Time span for prebilling, starting from ‘bill_from`.
5033 5034 5035 |
# File 'lib/stripe/resources/invoice.rb', line 5033 def duration @duration end |
#timestamp ⇒ Object
End the prebilled period at a precise integer timestamp, starting from the Unix epoch.
5035 5036 5037 |
# File 'lib/stripe/resources/invoice.rb', line 5035 def @timestamp end |
#type ⇒ Object
Select one of several ways to pass the ‘bill_until` value.
5037 5038 5039 |
# File 'lib/stripe/resources/invoice.rb', line 5037 def type @type end |