Class: Stripe::Invoice::ListUpcomingLineItemsParams::SubscriptionDetails::Item

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: BillingThresholds, Discount, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_thresholds: nil, clear_usage: nil, deleted: nil, discounts: nil, id: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ Item

Returns a new instance of Item.



5983
5984
5985
5986
5987
5988
5989
5990
5991
5992
5993
5994
5995
5996
5997
5998
5999
6000
6001
6002
6003
6004
6005
6006
6007
# File 'lib/stripe/resources/invoice.rb', line 5983

def initialize(
  billing_thresholds: nil,
  clear_usage: nil,
  deleted: nil,
  discounts: nil,
  id: nil,
  metadata: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @billing_thresholds = billing_thresholds
  @clear_usage = clear_usage
  @deleted = deleted
  @discounts = discounts
  @id = id
  @metadata = 
  @plan = plan
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. When updating, pass an empty string to remove previously-defined thresholds.



5951
5952
5953
# File 'lib/stripe/resources/invoice.rb', line 5951

def billing_thresholds
  @billing_thresholds
end

#clear_usageObject

Delete all usage for a given subscription item. You must pass this when deleting a usage records subscription item. ‘clear_usage` has no effect if the plan has a billing meter attached.



5954
5955
5956
# File 'lib/stripe/resources/invoice.rb', line 5954

def clear_usage
  @clear_usage
end

#deletedObject

A flag that, if set to ‘true`, will delete the specified item.



5957
5958
5959
# File 'lib/stripe/resources/invoice.rb', line 5957

def deleted
  @deleted
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



5960
5961
5962
# File 'lib/stripe/resources/invoice.rb', line 5960

def discounts
  @discounts
end

#idObject

Subscription item to update.



5963
5964
5965
# File 'lib/stripe/resources/invoice.rb', line 5963

def id
  @id
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



5966
5967
5968
# File 'lib/stripe/resources/invoice.rb', line 5966

def 
  @metadata
end

#planObject

Plan ID for this item, as a string.



5969
5970
5971
# File 'lib/stripe/resources/invoice.rb', line 5969

def plan
  @plan
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required. When changing a subscription item’s price, ‘quantity` is set to 1 unless a `quantity` parameter is provided.



5972
5973
5974
# File 'lib/stripe/resources/invoice.rb', line 5972

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.



5975
5976
5977
# File 'lib/stripe/resources/invoice.rb', line 5975

def price_data
  @price_data
end

#quantityObject

Quantity for this item.



5978
5979
5980
# File 'lib/stripe/resources/invoice.rb', line 5978

def quantity
  @quantity
end

#tax_ratesObject

A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



5981
5982
5983
# File 'lib/stripe/resources/invoice.rb', line 5981

def tax_rates
  @tax_rates
end