Class: Stripe::Invoice::ListUpcomingLineItemsParams::SubscriptionDetails::Item::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



5132
5133
5134
5135
5136
5137
# File 'lib/stripe/resources/invoice.rb', line 5132

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



5124
5125
5126
# File 'lib/stripe/resources/invoice.rb', line 5124

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



5126
5127
5128
# File 'lib/stripe/resources/invoice.rb', line 5126

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



5128
5129
5130
# File 'lib/stripe/resources/invoice.rb', line 5128

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



5130
5131
5132
# File 'lib/stripe/resources/invoice.rb', line 5130

def promotion_code
  @promotion_code
end