Class: Stripe::Invoice::ListUpcomingLineItemsParams::SubscriptionDetails::Item::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



5877
5878
5879
5880
5881
# File 'lib/stripe/resources/invoice.rb', line 5877

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



5869
5870
5871
# File 'lib/stripe/resources/invoice.rb', line 5869

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



5872
5873
5874
# File 'lib/stripe/resources/invoice.rb', line 5872

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



5875
5876
5877
# File 'lib/stripe/resources/invoice.rb', line 5875

def type
  @type
end