Class: Stripe::Invoice::ListUpcomingLineItemsParams::SubscriptionItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: BillingThresholds, Discount, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_thresholds: nil, clear_usage: nil, deleted: nil, discounts: nil, id: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ SubscriptionItem

Returns a new instance of SubscriptionItem.



6222
6223
6224
6225
6226
6227
6228
6229
6230
6231
6232
6233
6234
6235
6236
6237
6238
6239
6240
6241
6242
6243
6244
6245
6246
# File 'lib/stripe/resources/invoice.rb', line 6222

def initialize(
  billing_thresholds: nil,
  clear_usage: nil,
  deleted: nil,
  discounts: nil,
  id: nil,
  metadata: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @billing_thresholds = billing_thresholds
  @clear_usage = clear_usage
  @deleted = deleted
  @discounts = discounts
  @id = id
  @metadata = 
  @plan = plan
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. When updating, pass an empty string to remove previously-defined thresholds.



6190
6191
6192
# File 'lib/stripe/resources/invoice.rb', line 6190

def billing_thresholds
  @billing_thresholds
end

#clear_usageObject

Delete all usage for a given subscription item. You must pass this when deleting a usage records subscription item. ‘clear_usage` has no effect if the plan has a billing meter attached.



6193
6194
6195
# File 'lib/stripe/resources/invoice.rb', line 6193

def clear_usage
  @clear_usage
end

#deletedObject

A flag that, if set to ‘true`, will delete the specified item.



6196
6197
6198
# File 'lib/stripe/resources/invoice.rb', line 6196

def deleted
  @deleted
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



6199
6200
6201
# File 'lib/stripe/resources/invoice.rb', line 6199

def discounts
  @discounts
end

#idObject

Subscription item to update.



6202
6203
6204
# File 'lib/stripe/resources/invoice.rb', line 6202

def id
  @id
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



6205
6206
6207
# File 'lib/stripe/resources/invoice.rb', line 6205

def 
  @metadata
end

#planObject

Plan ID for this item, as a string.



6208
6209
6210
# File 'lib/stripe/resources/invoice.rb', line 6208

def plan
  @plan
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required. When changing a subscription item’s price, ‘quantity` is set to 1 unless a `quantity` parameter is provided.



6211
6212
6213
# File 'lib/stripe/resources/invoice.rb', line 6211

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.



6214
6215
6216
# File 'lib/stripe/resources/invoice.rb', line 6214

def price_data
  @price_data
end

#quantityObject

Quantity for this item.



6217
6218
6219
# File 'lib/stripe/resources/invoice.rb', line 6217

def quantity
  @quantity
end

#tax_ratesObject

A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



6220
6221
6222
# File 'lib/stripe/resources/invoice.rb', line 6220

def tax_rates
  @tax_rates
end