Class: Stripe::Invoice::ListUpcomingLineItemsParams::SubscriptionItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



5338
5339
5340
5341
5342
5343
# File 'lib/stripe/resources/invoice.rb', line 5338

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



5330
5331
5332
# File 'lib/stripe/resources/invoice.rb', line 5330

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



5332
5333
5334
# File 'lib/stripe/resources/invoice.rb', line 5332

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



5334
5335
5336
# File 'lib/stripe/resources/invoice.rb', line 5334

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



5336
5337
5338
# File 'lib/stripe/resources/invoice.rb', line 5336

def promotion_code
  @promotion_code
end