Class: Stripe::Invoice::ListUpcomingLineItemsParams::SubscriptionItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



5323
5324
5325
5326
5327
# File 'lib/stripe/resources/invoice.rb', line 5323

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



5317
5318
5319
# File 'lib/stripe/resources/invoice.rb', line 5317

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



5319
5320
5321
# File 'lib/stripe/resources/invoice.rb', line 5319

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



5321
5322
5323
# File 'lib/stripe/resources/invoice.rb', line 5321

def type
  @type
end