Class: Stripe::Invoice::MarkUncollectibleParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::MarkUncollectibleParams
- Defined in:
- lib/stripe/resources/invoice.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ MarkUncollectibleParams
constructor
A new instance of MarkUncollectibleParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ MarkUncollectibleParams
Returns a new instance of MarkUncollectibleParams.
2690 2691 2692 |
# File 'lib/stripe/resources/invoice.rb', line 2690 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2688 2689 2690 |
# File 'lib/stripe/resources/invoice.rb', line 2688 def @expand end |