Class: Stripe::Invoice::Parent
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Invoice::Parent
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: BillingCadenceDetails, QuoteDetails, ScheduleDetails, SubscriptionDetails
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#billing_cadence_details ⇒ Object
readonly
Details about the billing cadence that generated this invoice.
-
#quote_details ⇒ Object
readonly
Details about the quote that generated this invoice.
-
#schedule_details ⇒ Object
readonly
Details about the schedule that generated this invoice.
-
#subscription_details ⇒ Object
readonly
Details about the subscription that generated this invoice.
-
#type ⇒ Object
readonly
The type of parent that generated this invoice.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#billing_cadence_details ⇒ Object (readonly)
Details about the billing cadence that generated this invoice
406 407 408 |
# File 'lib/stripe/resources/invoice.rb', line 406 def billing_cadence_details @billing_cadence_details end |
#quote_details ⇒ Object (readonly)
Details about the quote that generated this invoice
408 409 410 |
# File 'lib/stripe/resources/invoice.rb', line 408 def quote_details @quote_details end |
#schedule_details ⇒ Object (readonly)
Details about the schedule that generated this invoice
414 415 416 |
# File 'lib/stripe/resources/invoice.rb', line 414 def schedule_details @schedule_details end |
#subscription_details ⇒ Object (readonly)
Details about the subscription that generated this invoice
410 411 412 |
# File 'lib/stripe/resources/invoice.rb', line 410 def subscription_details @subscription_details end |
#type ⇒ Object (readonly)
The type of parent that generated this invoice
412 413 414 |
# File 'lib/stripe/resources/invoice.rb', line 412 def type @type end |
Class Method Details
.field_remappings ⇒ Object
425 426 427 |
# File 'lib/stripe/resources/invoice.rb', line 425 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
416 417 418 419 420 421 422 423 |
# File 'lib/stripe/resources/invoice.rb', line 416 def self.inner_class_types @inner_class_types = { billing_cadence_details: BillingCadenceDetails, quote_details: QuoteDetails, subscription_details: SubscriptionDetails, schedule_details: ScheduleDetails, } end |