Class: Stripe::Invoice::Parent::SubscriptionDetails

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: PauseCollection

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#metadataObject (readonly)

Set of key-value pairs defined as subscription metadata when an invoice is created. Becomes an immutable snapshot of the subscription metadata at the time of invoice finalization. Note: This attribute is populated only for invoices created on or after June 29, 2023.



424
425
426
# File 'lib/stripe/resources/invoice.rb', line 424

def 
  @metadata
end

#pause_collectionObject (readonly)

If specified, payment collection for this subscription will be paused. Note that the subscription status will be unchanged and will not be updated to paused. Learn more about pausing collection.



426
427
428
# File 'lib/stripe/resources/invoice.rb', line 426

def pause_collection
  @pause_collection
end

#subscriptionObject (readonly)

The subscription that generated this invoice



428
429
430
# File 'lib/stripe/resources/invoice.rb', line 428

def subscription
  @subscription
end

#subscription_proration_dateObject (readonly)

Only set for upcoming invoices that preview prorations. The time used to calculate prorations.



430
431
432
# File 'lib/stripe/resources/invoice.rb', line 430

def subscription_proration_date
  @subscription_proration_date
end

Class Method Details

.field_remappingsObject



436
437
438
# File 'lib/stripe/resources/invoice.rb', line 436

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



432
433
434
# File 'lib/stripe/resources/invoice.rb', line 432

def self.inner_class_types
  @inner_class_types = { pause_collection: PauseCollection }
end