Class: Stripe::Invoice::Parent::SubscriptionDetails::PauseCollection
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Invoice::Parent::SubscriptionDetails::PauseCollection
- Defined in:
- lib/stripe/resources/invoice.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#behavior ⇒ Object
readonly
The payment collection behavior for this subscription while paused.
-
#resumes_at ⇒ Object
readonly
The time after which the subscription will resume collecting payments.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#behavior ⇒ Object (readonly)
The payment collection behavior for this subscription while paused. One of ‘keep_as_draft`, `mark_uncollectible`, or `void`.
362 363 364 |
# File 'lib/stripe/resources/invoice.rb', line 362 def behavior @behavior end |
#resumes_at ⇒ Object (readonly)
The time after which the subscription will resume collecting payments.
364 365 366 |
# File 'lib/stripe/resources/invoice.rb', line 364 def resumes_at @resumes_at end |
Class Method Details
.field_remappings ⇒ Object
370 371 372 |
# File 'lib/stripe/resources/invoice.rb', line 370 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
366 367 368 |
# File 'lib/stripe/resources/invoice.rb', line 366 def self.inner_class_types @inner_class_types = {} end |