Class: Stripe::Invoice::PaymentSettings::PaymentMethodOptions

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: AcssDebit, Bancontact, Billie, Card, CustomerBalance, Konbini, Payto, Pix, SepaDebit, Upi, UsBankAccount

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#acss_debitObject (readonly)

If paying by acss_debit, this sub-hash contains details about the Canadian pre-authorized debit payment method options to pass to the invoice’s PaymentIntent.



613
614
615
# File 'lib/stripe/resources/invoice.rb', line 613

def acss_debit
  @acss_debit
end

#bancontactObject (readonly)

If paying by bancontact, this sub-hash contains details about the Bancontact payment method options to pass to the invoice’s PaymentIntent.



615
616
617
# File 'lib/stripe/resources/invoice.rb', line 615

def bancontact
  @bancontact
end

#billieObject (readonly)

If paying by billie, this sub-hash contains details about the Billie payment method options to pass to the invoice’s PaymentIntent.



617
618
619
# File 'lib/stripe/resources/invoice.rb', line 617

def billie
  @billie
end

#cardObject (readonly)

If paying by card, this sub-hash contains details about the Card payment method options to pass to the invoice’s PaymentIntent.



619
620
621
# File 'lib/stripe/resources/invoice.rb', line 619

def card
  @card
end

#customer_balanceObject (readonly)

If paying by customer_balance, this sub-hash contains details about the Bank transfer payment method options to pass to the invoice’s PaymentIntent.



621
622
623
# File 'lib/stripe/resources/invoice.rb', line 621

def customer_balance
  @customer_balance
end

#konbiniObject (readonly)

If paying by konbini, this sub-hash contains details about the Konbini payment method options to pass to the invoice’s PaymentIntent.



623
624
625
# File 'lib/stripe/resources/invoice.rb', line 623

def konbini
  @konbini
end

#paytoObject (readonly)

If paying by payto, this sub-hash contains details about the PayTo payment method options to pass to the invoice’s PaymentIntent.



625
626
627
# File 'lib/stripe/resources/invoice.rb', line 625

def payto
  @payto
end

#pixObject (readonly)

If paying by pix, this sub-hash contains details about the Pix payment method options to pass to the invoice’s PaymentIntent.



627
628
629
# File 'lib/stripe/resources/invoice.rb', line 627

def pix
  @pix
end

#sepa_debitObject (readonly)

If paying by sepa_debit, this sub-hash contains details about the SEPA Direct Debit payment method options to pass to the invoice’s PaymentIntent.



629
630
631
# File 'lib/stripe/resources/invoice.rb', line 629

def sepa_debit
  @sepa_debit
end

#upiObject (readonly)

If paying by upi, this sub-hash contains details about the UPI payment method options to pass to the invoice’s PaymentIntent.



631
632
633
# File 'lib/stripe/resources/invoice.rb', line 631

def upi
  @upi
end

#us_bank_accountObject (readonly)

If paying by us_bank_account, this sub-hash contains details about the ACH direct debit payment method options to pass to the invoice’s PaymentIntent.



633
634
635
# File 'lib/stripe/resources/invoice.rb', line 633

def 
  @us_bank_account
end

Class Method Details

.field_remappingsObject



651
652
653
# File 'lib/stripe/resources/invoice.rb', line 651

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
# File 'lib/stripe/resources/invoice.rb', line 635

def self.inner_class_types
  @inner_class_types = {
    acss_debit: AcssDebit,
    bancontact: Bancontact,
    billie: Billie,
    card: Card,
    customer_balance: CustomerBalance,
    konbini: Konbini,
    payto: Payto,
    pix: Pix,
    sepa_debit: SepaDebit,
    upi: Upi,
    us_bank_account: UsBankAccount,
  }
end