Class: Stripe::Invoice::PaymentSettings::PaymentMethodOptions::WechatPay
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Invoice::PaymentSettings::PaymentMethodOptions::WechatPay
- Defined in:
- lib/stripe/resources/invoice.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#app_id ⇒ Object
readonly
The app ID registered with WeChat Pay.
-
#client ⇒ Object
readonly
The client type that the end customer will pay from.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#app_id ⇒ Object (readonly)
The app ID registered with WeChat Pay. Only required when client is ‘ios` or `android`.
724 725 726 |
# File 'lib/stripe/resources/invoice.rb', line 724 def app_id @app_id end |
#client ⇒ Object (readonly)
The client type that the end customer will pay from.
726 727 728 |
# File 'lib/stripe/resources/invoice.rb', line 726 def client @client end |
Class Method Details
.field_remappings ⇒ Object
732 733 734 |
# File 'lib/stripe/resources/invoice.rb', line 732 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
728 729 730 |
# File 'lib/stripe/resources/invoice.rb', line 728 def self.inner_class_types @inner_class_types = {} end |