Class: Stripe::Invoice::RemoveLinesParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Line

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, invoice_metadata: nil, lines: nil) ⇒ RemoveLinesParams

Returns a new instance of RemoveLinesParams.



2343
2344
2345
2346
2347
# File 'lib/stripe/resources/invoice.rb', line 2343

def initialize(expand: nil, invoice_metadata: nil, lines: nil)
  @expand = expand
  @invoice_metadata = 
  @lines = lines
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



2337
2338
2339
# File 'lib/stripe/resources/invoice.rb', line 2337

def expand
  @expand
end

#invoice_metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2339
2340
2341
# File 'lib/stripe/resources/invoice.rb', line 2339

def 
  @invoice_metadata
end

#linesObject

The line items to remove.



2341
2342
2343
# File 'lib/stripe/resources/invoice.rb', line 2341

def lines
  @lines
end