Class: Stripe::Invoice::RemoveLinesParams::Line

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(behavior: nil, id: nil) ⇒ Line

Returns a new instance of Line.



2331
2332
2333
2334
# File 'lib/stripe/resources/invoice.rb', line 2331

def initialize(behavior: nil, id: nil)
  @behavior = behavior
  @id = id
end

Instance Attribute Details

#behaviorObject

Either ‘delete` or `unassign`. Deleted line items are permanently deleted. Unassigned line items can be reassigned to an invoice.



2327
2328
2329
# File 'lib/stripe/resources/invoice.rb', line 2327

def behavior
  @behavior
end

#idObject

ID of an existing line item to remove from this invoice.



2329
2330
2331
# File 'lib/stripe/resources/invoice.rb', line 2329

def id
  @id
end