Class: Stripe::Invoice::Rendering

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Pdf

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amount_tax_displayObject (readonly)

How line-item prices and amounts will be displayed with respect to tax on invoice PDFs.



743
744
745
# File 'lib/stripe/resources/invoice.rb', line 743

def amount_tax_display
  @amount_tax_display
end

#pdfObject (readonly)

Invoice pdf rendering options



745
746
747
# File 'lib/stripe/resources/invoice.rb', line 745

def pdf
  @pdf
end

#templateObject (readonly)

ID of the rendering template that the invoice is formatted by.



747
748
749
# File 'lib/stripe/resources/invoice.rb', line 747

def template
  @template
end

#template_versionObject (readonly)

Version of the rendering template that the invoice is using.



749
750
751
# File 'lib/stripe/resources/invoice.rb', line 749

def template_version
  @template_version
end

Class Method Details

.field_remappingsObject



755
756
757
# File 'lib/stripe/resources/invoice.rb', line 755

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



751
752
753
# File 'lib/stripe/resources/invoice.rb', line 751

def self.inner_class_types
  @inner_class_types = { pdf: Pdf }
end