Class: Stripe::Invoice::SendInvoiceParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::SendInvoiceParams
- Defined in:
- lib/stripe/resources/invoice.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ SendInvoiceParams
constructor
A new instance of SendInvoiceParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ SendInvoiceParams
Returns a new instance of SendInvoiceParams.
2281 2282 2283 |
# File 'lib/stripe/resources/invoice.rb', line 2281 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2279 2280 2281 |
# File 'lib/stripe/resources/invoice.rb', line 2279 def @expand end |