Class: Stripe::Invoice::SubscriptionDetails::PauseCollection

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#behaviorObject (readonly)

The payment collection behavior for this subscription while paused. One of ‘keep_as_draft`, `mark_uncollectible`, or `void`.



404
405
406
# File 'lib/stripe/resources/invoice.rb', line 404

def behavior
  @behavior
end

#resumes_atObject (readonly)

The time after which the subscription will resume collecting payments.



406
407
408
# File 'lib/stripe/resources/invoice.rb', line 406

def resumes_at
  @resumes_at
end