Class: Stripe::Invoice::TotalPretaxCreditAmount
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Invoice::TotalPretaxCreditAmount
- Defined in:
- lib/stripe/resources/invoice.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The amount, in cents (or local equivalent), of the pretax credit amount.
-
#credit_balance_transaction ⇒ Object
readonly
The credit balance transaction that was applied to get this pretax credit amount.
-
#discount ⇒ Object
readonly
The discount that was applied to get this pretax credit amount.
-
#margin ⇒ Object
readonly
The margin that was applied to get this pretax credit amount.
-
#type ⇒ Object
readonly
Type of the pretax credit amount referenced.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The amount, in cents (or local equivalent), of the pretax credit amount.
996 997 998 |
# File 'lib/stripe/resources/invoice.rb', line 996 def amount @amount end |
#credit_balance_transaction ⇒ Object (readonly)
The credit balance transaction that was applied to get this pretax credit amount.
998 999 1000 |
# File 'lib/stripe/resources/invoice.rb', line 998 def credit_balance_transaction @credit_balance_transaction end |
#discount ⇒ Object (readonly)
The discount that was applied to get this pretax credit amount.
1000 1001 1002 |
# File 'lib/stripe/resources/invoice.rb', line 1000 def discount @discount end |
#margin ⇒ Object (readonly)
The margin that was applied to get this pretax credit amount.
1002 1003 1004 |
# File 'lib/stripe/resources/invoice.rb', line 1002 def margin @margin end |
#type ⇒ Object (readonly)
Type of the pretax credit amount referenced.
1004 1005 1006 |
# File 'lib/stripe/resources/invoice.rb', line 1004 def type @type end |
Class Method Details
.field_remappings ⇒ Object
1010 1011 1012 |
# File 'lib/stripe/resources/invoice.rb', line 1010 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1006 1007 1008 |
# File 'lib/stripe/resources/invoice.rb', line 1006 def self.inner_class_types @inner_class_types = {} end |