Class: Stripe::Invoice::TotalTaxAmount

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/invoice.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

The amount, in cents (or local equivalent), of the tax.



457
458
459
# File 'lib/stripe/resources/invoice.rb', line 457

def amount
  @amount
end

#inclusiveObject (readonly)

Whether this tax amount is inclusive or exclusive.



459
460
461
# File 'lib/stripe/resources/invoice.rb', line 459

def inclusive
  @inclusive
end

#tax_rateObject (readonly)

The tax rate that was applied to get this tax amount.



461
462
463
# File 'lib/stripe/resources/invoice.rb', line 461

def tax_rate
  @tax_rate
end

#taxability_reasonObject (readonly)

The reasoning behind this tax, for example, if the product is tax exempt. The possible values for this field may be extended as new tax rules are supported.



463
464
465
# File 'lib/stripe/resources/invoice.rb', line 463

def taxability_reason
  @taxability_reason
end

#taxable_amountObject (readonly)

The amount on which tax is calculated, in cents (or local equivalent).



465
466
467
# File 'lib/stripe/resources/invoice.rb', line 465

def taxable_amount
  @taxable_amount
end