Class: Stripe::Invoice::UpcomingParams::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



2020
2021
2022
2023
2024
# File 'lib/stripe/resources/invoice.rb', line 2020

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



2014
2015
2016
# File 'lib/stripe/resources/invoice.rb', line 2014

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



2016
2017
2018
# File 'lib/stripe/resources/invoice.rb', line 2016

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



2018
2019
2020
# File 'lib/stripe/resources/invoice.rb', line 2018

def type
  @type
end