Class: Stripe::Invoice::UpcomingParams::InvoiceItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



2064
2065
2066
2067
2068
# File 'lib/stripe/resources/invoice.rb', line 2064

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



2058
2059
2060
# File 'lib/stripe/resources/invoice.rb', line 2058

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



2060
2061
2062
# File 'lib/stripe/resources/invoice.rb', line 2060

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



2062
2063
2064
# File 'lib/stripe/resources/invoice.rb', line 2062

def type
  @type
end