Class: Stripe::Invoice::UpcomingParams::ScheduleDetails::Amendment::AmendmentEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd, Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ AmendmentEnd

Returns a new instance of AmendmentEnd.



2584
2585
2586
2587
2588
2589
# File 'lib/stripe/resources/invoice.rb', line 2584

def initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil)
  @discount_end = discount_end
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#discount_endObject

Use the ‘end` time of a given discount.



2573
2574
2575
# File 'lib/stripe/resources/invoice.rb', line 2573

def discount_end
  @discount_end
end

#durationObject

Time span for the amendment starting from the ‘amendment_start`.



2576
2577
2578
# File 'lib/stripe/resources/invoice.rb', line 2576

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the amendment to end. Must be after the ‘amendment_start`.



2579
2580
2581
# File 'lib/stripe/resources/invoice.rb', line 2579

def timestamp
  @timestamp
end

#typeObject

Select one of three ways to pass the ‘amendment_end`.



2582
2583
2584
# File 'lib/stripe/resources/invoice.rb', line 2582

def type
  @type
end