Class: Stripe::Invoice::UpcomingParams::ScheduleDetails::Amendment::AmendmentStart

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: AmendmentEnd, DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendment_end: nil, discount_end: nil, timestamp: nil, type: nil) ⇒ AmendmentStart

Returns a new instance of AmendmentStart.



2622
2623
2624
2625
2626
2627
# File 'lib/stripe/resources/invoice.rb', line 2622

def initialize(amendment_end: nil, discount_end: nil, timestamp: nil, type: nil)
  @amendment_end = amendment_end
  @discount_end = discount_end
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#amendment_endObject

Details of another amendment in the same array, immediately after which this amendment should begin.



2611
2612
2613
# File 'lib/stripe/resources/invoice.rb', line 2611

def amendment_end
  @amendment_end
end

#discount_endObject

Use the ‘end` time of a given discount.



2614
2615
2616
# File 'lib/stripe/resources/invoice.rb', line 2614

def discount_end
  @discount_end
end

#timestampObject

A precise Unix timestamp for the amendment to start.



2617
2618
2619
# File 'lib/stripe/resources/invoice.rb', line 2617

def timestamp
  @timestamp
end

#typeObject

Select one of three ways to pass the ‘amendment_start`.



2620
2621
2622
# File 'lib/stripe/resources/invoice.rb', line 2620

def type
  @type
end