Class: Stripe::Invoice::UpcomingParams::ScheduleDetails::Amendment::DiscountAction
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::UpcomingParams::ScheduleDetails::Amendment::DiscountAction
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#add ⇒ Object
Details of the discount to add.
-
#remove ⇒ Object
Details of the discount to remove.
-
#set ⇒ Object
Details of the discount to replace the existing discounts with.
-
#type ⇒ Object
Determines the type of discount action.
Instance Method Summary collapse
-
#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ DiscountAction
constructor
A new instance of DiscountAction.
Methods inherited from RequestParams
Constructor Details
#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ DiscountAction
Returns a new instance of DiscountAction.
2356 2357 2358 2359 2360 2361 |
# File 'lib/stripe/resources/invoice.rb', line 2356 def initialize(add: nil, remove: nil, set: nil, type: nil) @add = add @remove = remove @set = set @type = type end |
Instance Attribute Details
#add ⇒ Object
Details of the discount to add.
2348 2349 2350 |
# File 'lib/stripe/resources/invoice.rb', line 2348 def add @add end |
#remove ⇒ Object
Details of the discount to remove.
2350 2351 2352 |
# File 'lib/stripe/resources/invoice.rb', line 2350 def remove @remove end |
#set ⇒ Object
Details of the discount to replace the existing discounts with.
2352 2353 2354 |
# File 'lib/stripe/resources/invoice.rb', line 2352 def set @set end |
#type ⇒ Object
Determines the type of discount action.
2354 2355 2356 |
# File 'lib/stripe/resources/invoice.rb', line 2354 def type @type end |