Class: Stripe::Invoice::UpcomingParams::ScheduleDetails::Amendment::DiscountAction::Add

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ Add

Returns a new instance of Add.



2303
2304
2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
# File 'lib/stripe/resources/invoice.rb', line 2303

def initialize(
  coupon: nil,
  discount: nil,
  discount_end: nil,
  index: nil,
  promotion_code: nil
)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @index = index
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to redeem.



2293
2294
2295
# File 'lib/stripe/resources/invoice.rb', line 2293

def coupon
  @coupon
end

#discountObject

An ID of an existing discount for a coupon that was already redeemed.



2295
2296
2297
# File 'lib/stripe/resources/invoice.rb', line 2295

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



2297
2298
2299
# File 'lib/stripe/resources/invoice.rb', line 2297

def discount_end
  @discount_end
end

#indexObject

The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the ‘discounts` array.



2299
2300
2301
# File 'lib/stripe/resources/invoice.rb', line 2299

def index
  @index
end

#promotion_codeObject

The promotion code to redeem.



2301
2302
2303
# File 'lib/stripe/resources/invoice.rb', line 2301

def promotion_code
  @promotion_code
end