Class: Stripe::Invoice::UpcomingParams::ScheduleDetails::Amendment::DiscountAction::Add::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::UpcomingParams::ScheduleDetails::Amendment::DiscountAction::Add::DiscountEnd
- Defined in:
- lib/stripe/resources/invoice.rb
Instance Attribute Summary collapse
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
2636 2637 2638 |
# File 'lib/stripe/resources/invoice.rb', line 2636 def initialize(type: nil) @type = type end |
Instance Attribute Details
#type ⇒ Object
The type of calculation made to determine when the discount ends.
2634 2635 2636 |
# File 'lib/stripe/resources/invoice.rb', line 2634 def type @type end |