Class: Stripe::Invoice::UpcomingParams::ScheduleDetails::Amendment::DiscountAction::Remove

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Remove

Returns a new instance of Remove.



2680
2681
2682
2683
2684
# File 'lib/stripe/resources/invoice.rb', line 2680

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to remove from the ‘discounts` array.



2672
2673
2674
# File 'lib/stripe/resources/invoice.rb', line 2672

def coupon
  @coupon
end

#discountObject

The ID of a discount to remove from the ‘discounts` array.



2675
2676
2677
# File 'lib/stripe/resources/invoice.rb', line 2675

def discount
  @discount
end

#promotion_codeObject

The ID of a promotion code to remove from the ‘discounts` array.



2678
2679
2680
# File 'lib/stripe/resources/invoice.rb', line 2678

def promotion_code
  @promotion_code
end