Class: Stripe::Invoice::UpcomingParams::ScheduleDetails::Amendment::DiscountAction::Set

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Set

Returns a new instance of Set.



2697
2698
2699
2700
2701
# File 'lib/stripe/resources/invoice.rb', line 2697

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to replace the ‘discounts` array with.



2689
2690
2691
# File 'lib/stripe/resources/invoice.rb', line 2689

def coupon
  @coupon
end

#discountObject

An ID of an existing discount to replace the ‘discounts` array with.



2692
2693
2694
# File 'lib/stripe/resources/invoice.rb', line 2692

def discount
  @discount
end

#promotion_codeObject

An ID of an existing promotion code to replace the ‘discounts` array with.



2695
2696
2697
# File 'lib/stripe/resources/invoice.rb', line 2695

def promotion_code
  @promotion_code
end