Class: Stripe::Invoice::UpcomingParams::ScheduleDetails::Amendment::ItemAction::Add
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::UpcomingParams::ScheduleDetails::Amendment::ItemAction::Add
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#discounts ⇒ Object
The discounts applied to the item.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#price ⇒ Object
The ID of the price object.
-
#quantity ⇒ Object
Quantity for this item.
-
#tax_rates ⇒ Object
The tax rates that apply to this subscription item.
-
#trial ⇒ Object
Options that configure the trial on the subscription item.
Instance Method Summary collapse
-
#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Add
constructor
A new instance of Add.
Methods inherited from RequestParams
Constructor Details
#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Add
Returns a new instance of Add.
2804 2805 2806 2807 2808 2809 2810 2811 2812 2813 2814 2815 2816 2817 2818 |
# File 'lib/stripe/resources/invoice.rb', line 2804 def initialize( discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil ) @discounts = discounts @metadata = @price = price @quantity = quantity @tax_rates = tax_rates @trial = trial end |
Instance Attribute Details
#discounts ⇒ Object
The discounts applied to the item. Subscription item discounts are applied before subscription discounts.
2787 2788 2789 |
# File 'lib/stripe/resources/invoice.rb', line 2787 def discounts @discounts end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
2790 2791 2792 |
# File 'lib/stripe/resources/invoice.rb', line 2790 def @metadata end |
#price ⇒ Object
The ID of the price object.
2793 2794 2795 |
# File 'lib/stripe/resources/invoice.rb', line 2793 def price @price end |
#quantity ⇒ Object
Quantity for this item.
2796 2797 2798 |
# File 'lib/stripe/resources/invoice.rb', line 2796 def quantity @quantity end |
#tax_rates ⇒ Object
The tax rates that apply to this subscription item. When set, the ‘default_tax_rates` on the subscription do not apply to this `subscription_item`.
2799 2800 2801 |
# File 'lib/stripe/resources/invoice.rb', line 2799 def tax_rates @tax_rates end |
#trial ⇒ Object
Options that configure the trial on the subscription item.
2802 2803 2804 |
# File 'lib/stripe/resources/invoice.rb', line 2802 def trial @trial end |