Class: Stripe::Invoice::UpcomingParams::ScheduleDetails::Amendment::ItemAction::Add::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



2386
2387
2388
2389
2390
# File 'lib/stripe/resources/invoice.rb', line 2386

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



2380
2381
2382
# File 'lib/stripe/resources/invoice.rb', line 2380

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



2382
2383
2384
# File 'lib/stripe/resources/invoice.rb', line 2382

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



2384
2385
2386
# File 'lib/stripe/resources/invoice.rb', line 2384

def type
  @type
end