Class: Stripe::Invoice::UpcomingParams::ScheduleDetails::Amendment::ItemAction::Set::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



2495
2496
2497
2498
2499
2500
# File 'lib/stripe/resources/invoice.rb', line 2495

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



2487
2488
2489
# File 'lib/stripe/resources/invoice.rb', line 2487

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



2489
2490
2491
# File 'lib/stripe/resources/invoice.rb', line 2489

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



2491
2492
2493
# File 'lib/stripe/resources/invoice.rb', line 2491

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



2493
2494
2495
# File 'lib/stripe/resources/invoice.rb', line 2493

def promotion_code
  @promotion_code
end