Class: Stripe::Invoice::UpcomingParams::ScheduleDetails::Amendment::ItemAction::Set::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



2480
2481
2482
2483
2484
# File 'lib/stripe/resources/invoice.rb', line 2480

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



2474
2475
2476
# File 'lib/stripe/resources/invoice.rb', line 2474

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



2476
2477
2478
# File 'lib/stripe/resources/invoice.rb', line 2476

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



2478
2479
2480
# File 'lib/stripe/resources/invoice.rb', line 2478

def type
  @type
end