Class: Stripe::Invoice::UpcomingParams::ScheduleDetails::Amendment::ItemAction::Set::Discount::DiscountEnd::Duration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(interval: nil, interval_count: nil) ⇒ Duration

Returns a new instance of Duration.



2468
2469
2470
2471
# File 'lib/stripe/resources/invoice.rb', line 2468

def initialize(interval: nil, interval_count: nil)
  @interval = interval
  @interval_count = interval_count
end

Instance Attribute Details

#intervalObject

Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.



2464
2465
2466
# File 'lib/stripe/resources/invoice.rb', line 2464

def interval
  @interval
end

#interval_countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



2466
2467
2468
# File 'lib/stripe/resources/invoice.rb', line 2466

def interval_count
  @interval_count
end