Class: Stripe::Invoice::UpcomingParams::ScheduleDetails::Amendment::ItemAction::Set::Trial
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::UpcomingParams::ScheduleDetails::Amendment::ItemAction::Set::Trial
- Defined in:
- lib/stripe/resources/invoice.rb
Instance Attribute Summary collapse
-
#converts_to ⇒ Object
List of price IDs which, if present on the subscription following a paid trial, constitute opting-in to the paid trial.
-
#type ⇒ Object
Determines the type of trial for this item.
Instance Method Summary collapse
-
#initialize(converts_to: nil, type: nil) ⇒ Trial
constructor
A new instance of Trial.
Methods inherited from RequestParams
Constructor Details
#initialize(converts_to: nil, type: nil) ⇒ Trial
Returns a new instance of Trial.
2887 2888 2889 2890 |
# File 'lib/stripe/resources/invoice.rb', line 2887 def initialize(converts_to: nil, type: nil) @converts_to = converts_to @type = type end |
Instance Attribute Details
#converts_to ⇒ Object
List of price IDs which, if present on the subscription following a paid trial, constitute opting-in to the paid trial. Currently only supports at most 1 price ID.
2882 2883 2884 |
# File 'lib/stripe/resources/invoice.rb', line 2882 def converts_to @converts_to end |
#type ⇒ Object
Determines the type of trial for this item.
2885 2886 2887 |
# File 'lib/stripe/resources/invoice.rb', line 2885 def type @type end |