Class: Stripe::Invoice::UpcomingParams::ScheduleDetails::Phase::AddInvoiceItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



3102
3103
3104
3105
3106
3107
# File 'lib/stripe/resources/invoice.rb', line 3102

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



3091
3092
3093
# File 'lib/stripe/resources/invoice.rb', line 3091

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



3094
3095
3096
# File 'lib/stripe/resources/invoice.rb', line 3094

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



3097
3098
3099
# File 'lib/stripe/resources/invoice.rb', line 3097

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



3100
3101
3102
# File 'lib/stripe/resources/invoice.rb', line 3100

def promotion_code
  @promotion_code
end