Class: Stripe::Invoice::UpcomingParams::ScheduleDetails::Phase::AddInvoiceItem::PriceData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::UpcomingParams::ScheduleDetails::Phase::AddInvoiceItem::PriceData
- Defined in:
- lib/stripe/resources/invoice.rb
Instance Attribute Summary collapse
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#product ⇒ Object
The ID of the product that this price will belong to.
-
#tax_behavior ⇒ Object
Only required if a [default tax behavior](stripe.com/docs/tax/products-prices-tax-categories-tax-behavior#setting-a-default-tax-behavior-(recommended)) was not provided in the Stripe Tax settings.
-
#unit_amount ⇒ Object
A positive integer in cents (or local equivalent) (or 0 for a free price) representing how much to charge or a negative integer representing the amount to credit to the customer.
-
#unit_amount_decimal ⇒ Object
Same as ‘unit_amount`, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places.
Instance Method Summary collapse
-
#initialize(currency: nil, product: nil, tax_behavior: nil, unit_amount: nil, unit_amount_decimal: nil) ⇒ PriceData
constructor
A new instance of PriceData.
Methods inherited from RequestParams
Constructor Details
#initialize(currency: nil, product: nil, tax_behavior: nil, unit_amount: nil, unit_amount_decimal: nil) ⇒ PriceData
Returns a new instance of PriceData.
2717 2718 2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 |
# File 'lib/stripe/resources/invoice.rb', line 2717 def initialize( currency: nil, product: nil, tax_behavior: nil, unit_amount: nil, unit_amount_decimal: nil ) @currency = currency @product = product @tax_behavior = tax_behavior @unit_amount = unit_amount @unit_amount_decimal = unit_amount_decimal end |
Instance Attribute Details
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
2707 2708 2709 |
# File 'lib/stripe/resources/invoice.rb', line 2707 def currency @currency end |
#product ⇒ Object
The ID of the product that this price will belong to.
2709 2710 2711 |
# File 'lib/stripe/resources/invoice.rb', line 2709 def product @product end |
#tax_behavior ⇒ Object
Only required if a [default tax behavior](stripe.com/docs/tax/products-prices-tax-categories-tax-behavior#setting-a-default-tax-behavior-(recommended)) was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`. Once specified as either `inclusive` or `exclusive`, it cannot be changed.
2711 2712 2713 |
# File 'lib/stripe/resources/invoice.rb', line 2711 def tax_behavior @tax_behavior end |
#unit_amount ⇒ Object
A positive integer in cents (or local equivalent) (or 0 for a free price) representing how much to charge or a negative integer representing the amount to credit to the customer.
2713 2714 2715 |
# File 'lib/stripe/resources/invoice.rb', line 2713 def unit_amount @unit_amount end |
#unit_amount_decimal ⇒ Object
Same as ‘unit_amount`, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places. Only one of `unit_amount` and `unit_amount_decimal` can be set.
2715 2716 2717 |
# File 'lib/stripe/resources/invoice.rb', line 2715 def unit_amount_decimal @unit_amount_decimal end |