Class: Stripe::Invoice::UpcomingParams::ScheduleDetails::Phase::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



2827
2828
2829
2830
2831
2832
# File 'lib/stripe/resources/invoice.rb', line 2827

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



2819
2820
2821
# File 'lib/stripe/resources/invoice.rb', line 2819

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



2821
2822
2823
# File 'lib/stripe/resources/invoice.rb', line 2821

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



2823
2824
2825
# File 'lib/stripe/resources/invoice.rb', line 2823

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



2825
2826
2827
# File 'lib/stripe/resources/invoice.rb', line 2825

def promotion_code
  @promotion_code
end