Class: Stripe::Invoice::UpcomingParams::ScheduleDetails::Phase::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



2812
2813
2814
2815
2816
# File 'lib/stripe/resources/invoice.rb', line 2812

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



2806
2807
2808
# File 'lib/stripe/resources/invoice.rb', line 2806

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



2808
2809
2810
# File 'lib/stripe/resources/invoice.rb', line 2808

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



2810
2811
2812
# File 'lib/stripe/resources/invoice.rb', line 2810

def type
  @type
end