Class: Stripe::Invoice::UpcomingParams::ScheduleDetails::Phase::Item::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



3337
3338
3339
3340
3341
3342
# File 'lib/stripe/resources/invoice.rb', line 3337

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



3326
3327
3328
# File 'lib/stripe/resources/invoice.rb', line 3326

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



3329
3330
3331
# File 'lib/stripe/resources/invoice.rb', line 3329

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



3332
3333
3334
# File 'lib/stripe/resources/invoice.rb', line 3332

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



3335
3336
3337
# File 'lib/stripe/resources/invoice.rb', line 3335

def promotion_code
  @promotion_code
end