Class: Stripe::Invoice::UpcomingParams::ScheduleDetails::Phase::Item::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



3319
3320
3321
3322
3323
# File 'lib/stripe/resources/invoice.rb', line 3319

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



3311
3312
3313
# File 'lib/stripe/resources/invoice.rb', line 3311

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



3314
3315
3316
# File 'lib/stripe/resources/invoice.rb', line 3314

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



3317
3318
3319
# File 'lib/stripe/resources/invoice.rb', line 3317

def type
  @type
end