Class: Stripe::Invoice::UpcomingParams::ScheduleDetails::Prebilling::BillUntil

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: AmendmentEnd, Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ BillUntil

Returns a new instance of BillUntil.



3187
3188
3189
3190
3191
3192
# File 'lib/stripe/resources/invoice.rb', line 3187

def initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil)
  @amendment_end = amendment_end
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#amendment_endObject

End the prebilled period when a specified amendment ends.



3179
3180
3181
# File 'lib/stripe/resources/invoice.rb', line 3179

def amendment_end
  @amendment_end
end

#durationObject

Time span for prebilling, starting from ‘bill_from`.



3181
3182
3183
# File 'lib/stripe/resources/invoice.rb', line 3181

def duration
  @duration
end

#timestampObject

End the prebilled period at a precise integer timestamp, starting from the Unix epoch.



3183
3184
3185
# File 'lib/stripe/resources/invoice.rb', line 3183

def timestamp
  @timestamp
end

#typeObject

Select one of several ways to pass the ‘bill_until` value.



3185
3186
3187
# File 'lib/stripe/resources/invoice.rb', line 3185

def type
  @type
end