Class: Stripe::Invoice::UpcomingParams::SubscriptionDetails::Item::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



3768
3769
3770
3771
3772
3773
# File 'lib/stripe/resources/invoice.rb', line 3768

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



3757
3758
3759
# File 'lib/stripe/resources/invoice.rb', line 3757

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



3760
3761
3762
# File 'lib/stripe/resources/invoice.rb', line 3760

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



3763
3764
3765
# File 'lib/stripe/resources/invoice.rb', line 3763

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



3766
3767
3768
# File 'lib/stripe/resources/invoice.rb', line 3766

def promotion_code
  @promotion_code
end