Class: Stripe::Invoice::UpcomingParams::SubscriptionDetails::Item::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::UpcomingParams::SubscriptionDetails::Item::Discount::DiscountEnd
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
3265 3266 3267 3268 3269 |
# File 'lib/stripe/resources/invoice.rb', line 3265 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
3259 3260 3261 |
# File 'lib/stripe/resources/invoice.rb', line 3259 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
3261 3262 3263 |
# File 'lib/stripe/resources/invoice.rb', line 3261 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
3263 3264 3265 |
# File 'lib/stripe/resources/invoice.rb', line 3263 def type @type end |