Class: Stripe::Invoice::UpcomingParams::SubscriptionItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: BillingThresholds, Discount, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_thresholds: nil, clear_usage: nil, deleted: nil, discounts: nil, id: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ SubscriptionItem

Returns a new instance of SubscriptionItem.



4095
4096
4097
4098
4099
4100
4101
4102
4103
4104
4105
4106
4107
4108
4109
4110
4111
4112
4113
4114
4115
4116
4117
4118
4119
# File 'lib/stripe/resources/invoice.rb', line 4095

def initialize(
  billing_thresholds: nil,
  clear_usage: nil,
  deleted: nil,
  discounts: nil,
  id: nil,
  metadata: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @billing_thresholds = billing_thresholds
  @clear_usage = clear_usage
  @deleted = deleted
  @discounts = discounts
  @id = id
  @metadata = 
  @plan = plan
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. When updating, pass an empty string to remove previously-defined thresholds.



4063
4064
4065
# File 'lib/stripe/resources/invoice.rb', line 4063

def billing_thresholds
  @billing_thresholds
end

#clear_usageObject

Delete all usage for a given subscription item. You must pass this when deleting a usage records subscription item. ‘clear_usage` has no effect if the plan has a billing meter attached.



4066
4067
4068
# File 'lib/stripe/resources/invoice.rb', line 4066

def clear_usage
  @clear_usage
end

#deletedObject

A flag that, if set to ‘true`, will delete the specified item.



4069
4070
4071
# File 'lib/stripe/resources/invoice.rb', line 4069

def deleted
  @deleted
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



4072
4073
4074
# File 'lib/stripe/resources/invoice.rb', line 4072

def discounts
  @discounts
end

#idObject

Subscription item to update.



4075
4076
4077
# File 'lib/stripe/resources/invoice.rb', line 4075

def id
  @id
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



4078
4079
4080
# File 'lib/stripe/resources/invoice.rb', line 4078

def 
  @metadata
end

#planObject

Plan ID for this item, as a string.



4081
4082
4083
# File 'lib/stripe/resources/invoice.rb', line 4081

def plan
  @plan
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required. When changing a subscription item’s price, ‘quantity` is set to 1 unless a `quantity` parameter is provided.



4084
4085
4086
# File 'lib/stripe/resources/invoice.rb', line 4084

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.



4087
4088
4089
# File 'lib/stripe/resources/invoice.rb', line 4087

def price_data
  @price_data
end

#quantityObject

Quantity for this item.



4090
4091
4092
# File 'lib/stripe/resources/invoice.rb', line 4090

def quantity
  @quantity
end

#tax_ratesObject

A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



4093
4094
4095
# File 'lib/stripe/resources/invoice.rb', line 4093

def tax_rates
  @tax_rates
end