Class: Stripe::Invoice::UpcomingParams::SubscriptionItem::BillingThresholds

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(usage_gte: nil) ⇒ BillingThresholds

Returns a new instance of BillingThresholds.



3446
3447
3448
# File 'lib/stripe/resources/invoice.rb', line 3446

def initialize(usage_gte: nil)
  @usage_gte = usage_gte
end

Instance Attribute Details

#usage_gteObject

Number of units that meets the billing threshold to advance the subscription to a new billing period (e.g., it takes 10 $5 units to meet a $50 [monetary threshold](stripe.com/docs/api/subscriptions/update#update_subscription-billing_thresholds-amount_gte))



3444
3445
3446
# File 'lib/stripe/resources/invoice.rb', line 3444

def usage_gte
  @usage_gte
end