Class: Stripe::Invoice::UpcomingParams::SubscriptionItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



3486
3487
3488
3489
3490
3491
# File 'lib/stripe/resources/invoice.rb', line 3486

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



3478
3479
3480
# File 'lib/stripe/resources/invoice.rb', line 3478

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



3480
3481
3482
# File 'lib/stripe/resources/invoice.rb', line 3480

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



3482
3483
3484
# File 'lib/stripe/resources/invoice.rb', line 3482

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



3484
3485
3486
# File 'lib/stripe/resources/invoice.rb', line 3484

def promotion_code
  @promotion_code
end