Class: Stripe::Invoice::UpcomingParams::SubscriptionItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



3989
3990
3991
3992
3993
# File 'lib/stripe/resources/invoice.rb', line 3989

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



3981
3982
3983
# File 'lib/stripe/resources/invoice.rb', line 3981

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



3984
3985
3986
# File 'lib/stripe/resources/invoice.rb', line 3984

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



3987
3988
3989
# File 'lib/stripe/resources/invoice.rb', line 3987

def type
  @type
end