Class: Stripe::Invoice::UpcomingParams::SubscriptionPrebilling
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::UpcomingParams::SubscriptionPrebilling
- Defined in:
- lib/stripe/resources/invoice.rb
Instance Attribute Summary collapse
-
#iterations ⇒ Object
This is used to determine the number of billing cycles to prebill.
Instance Method Summary collapse
-
#initialize(iterations: nil) ⇒ SubscriptionPrebilling
constructor
A new instance of SubscriptionPrebilling.
Methods inherited from RequestParams
Constructor Details
#initialize(iterations: nil) ⇒ SubscriptionPrebilling
Returns a new instance of SubscriptionPrebilling.
4126 4127 4128 |
# File 'lib/stripe/resources/invoice.rb', line 4126 def initialize(iterations: nil) @iterations = iterations end |
Instance Attribute Details
#iterations ⇒ Object
This is used to determine the number of billing cycles to prebill.
4124 4125 4126 |
# File 'lib/stripe/resources/invoice.rb', line 4124 def iterations @iterations end |