Class: Stripe::Invoice::UpdateLinesParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Line

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, invoice_metadata: nil, lines: nil) ⇒ UpdateLinesParams

Returns a new instance of UpdateLinesParams.



3014
3015
3016
3017
3018
# File 'lib/stripe/resources/invoice.rb', line 3014

def initialize(expand: nil, invoice_metadata: nil, lines: nil)
  @expand = expand
  @invoice_metadata = 
  @lines = lines
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



3008
3009
3010
# File 'lib/stripe/resources/invoice.rb', line 3008

def expand
  @expand
end

#invoice_metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`. For [type=subscription](stripe.com/docs/api/invoices/line_item#invoice_line_item_object-type) line items, the incoming metadata specified on the request is directly used to set this value, in contrast to [type=invoiceitem](api/invoices/line_item#invoice_line_item_object-type) line items, where any existing metadata on the invoice line is merged with the incoming data.



3010
3011
3012
# File 'lib/stripe/resources/invoice.rb', line 3010

def 
  @invoice_metadata
end

#linesObject

The line items to update.



3012
3013
3014
# File 'lib/stripe/resources/invoice.rb', line 3012

def lines
  @lines
end