Class: Stripe::Invoice::UpdateLinesParams::Line

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Discount, Period, PriceData, Pricing, TaxAmount

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, description: nil, discountable: nil, discounts: nil, id: nil, margins: nil, metadata: nil, period: nil, price_data: nil, pricing: nil, quantity: nil, tax_amounts: nil, tax_rates: nil) ⇒ Line

Returns a new instance of Line.



2569
2570
2571
2572
2573
2574
2575
2576
2577
2578
2579
2580
2581
2582
2583
2584
2585
2586
2587
2588
2589
2590
2591
2592
2593
2594
2595
2596
2597
# File 'lib/stripe/resources/invoice.rb', line 2569

def initialize(
  amount: nil,
  description: nil,
  discountable: nil,
  discounts: nil,
  id: nil,
  margins: nil,
  metadata: nil,
  period: nil,
  price_data: nil,
  pricing: nil,
  quantity: nil,
  tax_amounts: nil,
  tax_rates: nil
)
  @amount = amount
  @description = description
  @discountable = discountable
  @discounts = discounts
  @id = id
  @margins = margins
  @metadata = 
  @period = period
  @price_data = price_data
  @pricing = pricing
  @quantity = quantity
  @tax_amounts = tax_amounts
  @tax_rates = tax_rates
end

Instance Attribute Details

#amountObject

The integer amount in cents (or local equivalent) of the charge to be applied to the upcoming invoice. If you want to apply a credit to the customer’s account, pass a negative amount.



2543
2544
2545
# File 'lib/stripe/resources/invoice.rb', line 2543

def amount
  @amount
end

#descriptionObject

An arbitrary string which you can attach to the invoice item. The description is displayed in the invoice for easy tracking.



2545
2546
2547
# File 'lib/stripe/resources/invoice.rb', line 2545

def description
  @description
end

#discountableObject

Controls whether discounts apply to this line item. Defaults to false for prorations or negative line items, and true for all other line items. Cannot be set to true for prorations.



2547
2548
2549
# File 'lib/stripe/resources/invoice.rb', line 2547

def discountable
  @discountable
end

#discountsObject

The coupons, promotion codes & existing discounts which apply to the line item. Item discounts are applied before invoice discounts. Pass an empty string to remove previously-defined discounts.



2549
2550
2551
# File 'lib/stripe/resources/invoice.rb', line 2549

def discounts
  @discounts
end

#idObject

ID of an existing line item on the invoice.



2551
2552
2553
# File 'lib/stripe/resources/invoice.rb', line 2551

def id
  @id
end

#marginsObject

The IDs of the margins to apply to the line item. When set, the ‘default_margins` on the invoice do not apply to this line item.



2553
2554
2555
# File 'lib/stripe/resources/invoice.rb', line 2553

def margins
  @margins
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`. For [type=subscription](stripe.com/docs/api/invoices/line_item#invoice_line_item_object-type) line items, the incoming metadata specified on the request is directly used to set this value, in contrast to [type=invoiceitem](api/invoices/line_item#invoice_line_item_object-type) line items, where any existing metadata on the invoice line is merged with the incoming data.



2555
2556
2557
# File 'lib/stripe/resources/invoice.rb', line 2555

def 
  @metadata
end

#periodObject

The period associated with this invoice item. When set to different values, the period will be rendered on the invoice. If you have [Stripe Revenue Recognition](stripe.com/docs/revenue-recognition) enabled, the period will be used to recognize and defer revenue. See the [Revenue Recognition documentation](stripe.com/docs/revenue-recognition/methodology/subscriptions-and-invoicing) for details.



2557
2558
2559
# File 'lib/stripe/resources/invoice.rb', line 2557

def period
  @period
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.



2559
2560
2561
# File 'lib/stripe/resources/invoice.rb', line 2559

def price_data
  @price_data
end

#pricingObject

The pricing information for the invoice item.



2561
2562
2563
# File 'lib/stripe/resources/invoice.rb', line 2561

def pricing
  @pricing
end

#quantityObject

Non-negative integer. The quantity of units for the line item.



2563
2564
2565
# File 'lib/stripe/resources/invoice.rb', line 2563

def quantity
  @quantity
end

#tax_amountsObject

A list of up to 10 tax amounts for this line item. This can be useful if you calculate taxes on your own or use a third-party to calculate them. You cannot set tax amounts if any line item has [tax_rates](stripe.com/docs/api/invoices/line_item#invoice_line_item_object-tax_rates) or if the invoice has [default_tax_rates](stripe.com/docs/api/invoices/object#invoice_object-default_tax_rates) or uses [automatic tax](stripe.com/docs/tax/invoicing). Pass an empty string to remove previously defined tax amounts.



2565
2566
2567
# File 'lib/stripe/resources/invoice.rb', line 2565

def tax_amounts
  @tax_amounts
end

#tax_ratesObject

The tax rates which apply to the line item. When set, the ‘default_tax_rates` on the invoice do not apply to this line item. Pass an empty string to remove previously-defined tax rates.



2567
2568
2569
# File 'lib/stripe/resources/invoice.rb', line 2567

def tax_rates
  @tax_rates
end