Class: Stripe::Invoice::UpdateLinesParams::Line::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::UpdateLinesParams::Line::Discount
- Defined in:
- lib/stripe/resources/invoice.rb
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
2035 2036 2037 2038 2039 |
# File 'lib/stripe/resources/invoice.rb', line 2035 def initialize(coupon: nil, discount: nil, promotion_code: nil) @coupon = coupon @discount = discount @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
2029 2030 2031 |
# File 'lib/stripe/resources/invoice.rb', line 2029 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
2031 2032 2033 |
# File 'lib/stripe/resources/invoice.rb', line 2031 def discount @discount end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
2033 2034 2035 |
# File 'lib/stripe/resources/invoice.rb', line 2033 def promotion_code @promotion_code end |