Class: Stripe::Invoice::UpdateLinesParams::Line::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



2789
2790
2791
2792
2793
# File 'lib/stripe/resources/invoice.rb', line 2789

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



2783
2784
2785
# File 'lib/stripe/resources/invoice.rb', line 2783

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



2785
2786
2787
# File 'lib/stripe/resources/invoice.rb', line 2785

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



2787
2788
2789
# File 'lib/stripe/resources/invoice.rb', line 2787

def type
  @type
end