Class: Stripe::Invoice::UpdateLinesParams::Line::Period
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::UpdateLinesParams::Line::Period
- Defined in:
- lib/stripe/resources/invoice.rb
Instance Attribute Summary collapse
-
#end ⇒ Object
The end of the period, which must be greater than or equal to the start.
-
#start ⇒ Object
The start of the period.
Instance Method Summary collapse
-
#initialize(end_: nil, start: nil) ⇒ Period
constructor
A new instance of Period.
Methods inherited from RequestParams
Constructor Details
#initialize(end_: nil, start: nil) ⇒ Period
Returns a new instance of Period.
2818 2819 2820 2821 |
# File 'lib/stripe/resources/invoice.rb', line 2818 def initialize(end_: nil, start: nil) @end = end_ @start = start end |
Instance Attribute Details
#end ⇒ Object
The end of the period, which must be greater than or equal to the start. This value is inclusive.
2814 2815 2816 |
# File 'lib/stripe/resources/invoice.rb', line 2814 def end @end end |
#start ⇒ Object
The start of the period. This value is inclusive.
2816 2817 2818 |
# File 'lib/stripe/resources/invoice.rb', line 2816 def start @start end |