Class: Stripe::Invoice::UpdateLinesParams::Line::PriceData::ProductData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil) ⇒ ProductData

Returns a new instance of ProductData.



2837
2838
2839
2840
2841
2842
2843
# File 'lib/stripe/resources/invoice.rb', line 2837

def initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil)
  @description = description
  @images = images
  @metadata = 
  @name = name
  @tax_code = tax_code
end

Instance Attribute Details

#descriptionObject

The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.



2827
2828
2829
# File 'lib/stripe/resources/invoice.rb', line 2827

def description
  @description
end

#imagesObject

A list of up to 8 URLs of images for this product, meant to be displayable to the customer.



2829
2830
2831
# File 'lib/stripe/resources/invoice.rb', line 2829

def images
  @images
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2831
2832
2833
# File 'lib/stripe/resources/invoice.rb', line 2831

def 
  @metadata
end

#nameObject

The product’s name, meant to be displayable to the customer.



2833
2834
2835
# File 'lib/stripe/resources/invoice.rb', line 2833

def name
  @name
end

#tax_codeObject



2835
2836
2837
# File 'lib/stripe/resources/invoice.rb', line 2835

def tax_code
  @tax_code
end