Class: Stripe::Invoice::UpdateLinesParams::Line::TaxAmount::TaxRateData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(country: nil, description: nil, display_name: nil, inclusive: nil, jurisdiction: nil, jurisdiction_level: nil, percentage: nil, state: nil, tax_type: nil) ⇒ TaxRateData

Returns a new instance of TaxRateData.



2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
2917
2918
2919
2920
2921
2922
2923
2924
2925
# File 'lib/stripe/resources/invoice.rb', line 2905

def initialize(
  country: nil,
  description: nil,
  display_name: nil,
  inclusive: nil,
  jurisdiction: nil,
  jurisdiction_level: nil,
  percentage: nil,
  state: nil,
  tax_type: nil
)
  @country = country
  @description = description
  @display_name = display_name
  @inclusive = inclusive
  @jurisdiction = jurisdiction
  @jurisdiction_level = jurisdiction_level
  @percentage = percentage
  @state = state
  @tax_type = tax_type
end

Instance Attribute Details

#countryObject

Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).



2887
2888
2889
# File 'lib/stripe/resources/invoice.rb', line 2887

def country
  @country
end

#descriptionObject

An arbitrary string attached to the tax rate for your internal use only. It will not be visible to your customers.



2889
2890
2891
# File 'lib/stripe/resources/invoice.rb', line 2889

def description
  @description
end

#display_nameObject

The display name of the tax rate, which will be shown to users.



2891
2892
2893
# File 'lib/stripe/resources/invoice.rb', line 2891

def display_name
  @display_name
end

#inclusiveObject

This specifies if the tax rate is inclusive or exclusive.



2893
2894
2895
# File 'lib/stripe/resources/invoice.rb', line 2893

def inclusive
  @inclusive
end

#jurisdictionObject

The jurisdiction for the tax rate. You can use this label field for tax reporting purposes. It also appears on your customer’s invoice.



2895
2896
2897
# File 'lib/stripe/resources/invoice.rb', line 2895

def jurisdiction
  @jurisdiction
end

#jurisdiction_levelObject

The level of the jurisdiction that imposes this tax rate.



2897
2898
2899
# File 'lib/stripe/resources/invoice.rb', line 2897

def jurisdiction_level
  @jurisdiction_level
end

#percentageObject

The statutory tax rate percent. This field accepts decimal values between 0 and 100 inclusive with at most 4 decimal places. To accommodate fixed-amount taxes, set the percentage to zero. Stripe will not display zero percentages on the invoice unless the ‘amount` of the tax is also zero.



2899
2900
2901
# File 'lib/stripe/resources/invoice.rb', line 2899

def percentage
  @percentage
end

#stateObject

[ISO 3166-2 subdivision code](en.wikipedia.org/wiki/ISO_3166-2:US), without country prefix. For example, “NY” for New York, United States.



2901
2902
2903
# File 'lib/stripe/resources/invoice.rb', line 2901

def state
  @state
end

#tax_typeObject

The high-level tax type, such as ‘vat` or `sales_tax`.



2903
2904
2905
# File 'lib/stripe/resources/invoice.rb', line 2903

def tax_type
  @tax_type
end