Class: Stripe::Invoice::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: AmountsDue, AutomaticTax, CustomField, Discount, Issuer, PaymentSettings, Rendering, ShippingCost, ShippingDetails, TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_tax_ids: nil, amounts_due: nil, application_fee_amount: nil, auto_advance: nil, automatic_tax: nil, automatically_finalizes_at: nil, collection_method: nil, custom_fields: nil, days_until_due: nil, default_margins: nil, default_payment_method: nil, default_source: nil, default_tax_rates: nil, description: nil, discounts: nil, due_date: nil, effective_at: nil, expand: nil, footer: nil, issuer: nil, metadata: nil, number: nil, on_behalf_of: nil, payment_settings: nil, rendering: nil, shipping_cost: nil, shipping_details: nil, statement_descriptor: nil, transfer_data: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
1538
1539
1540
1541
1542
1543
1544
1545
1546
1547
1548
1549
1550
1551
1552
1553
1554
1555
1556
1557
1558
1559
1560
1561
1562
1563
1564
1565
1566
1567
1568
1569
1570
1571
1572
1573
1574
1575
# File 'lib/stripe/resources/invoice.rb', line 1515

def initialize(
  account_tax_ids: nil,
  amounts_due: nil,
  application_fee_amount: nil,
  auto_advance: nil,
  automatic_tax: nil,
  automatically_finalizes_at: nil,
  collection_method: nil,
  custom_fields: nil,
  days_until_due: nil,
  default_margins: nil,
  default_payment_method: nil,
  default_source: nil,
  default_tax_rates: nil,
  description: nil,
  discounts: nil,
  due_date: nil,
  effective_at: nil,
  expand: nil,
  footer: nil,
  issuer: nil,
  metadata: nil,
  number: nil,
  on_behalf_of: nil,
  payment_settings: nil,
  rendering: nil,
  shipping_cost: nil,
  shipping_details: nil,
  statement_descriptor: nil,
  transfer_data: nil
)
  @account_tax_ids = 
  @amounts_due = amounts_due
  @application_fee_amount = application_fee_amount
  @auto_advance = auto_advance
  @automatic_tax = automatic_tax
  @automatically_finalizes_at = automatically_finalizes_at
  @collection_method = collection_method
  @custom_fields = custom_fields
  @days_until_due = days_until_due
  @default_margins = default_margins
  @default_payment_method = default_payment_method
  @default_source = default_source
  @default_tax_rates = default_tax_rates
  @description = description
  @discounts = discounts
  @due_date = due_date
  @effective_at = effective_at
  @expand = expand
  @footer = footer
  @issuer = issuer
  @metadata = 
  @number = number
  @on_behalf_of = on_behalf_of
  @payment_settings = payment_settings
  @rendering = rendering
  @shipping_cost = shipping_cost
  @shipping_details = shipping_details
  @statement_descriptor = statement_descriptor
  @transfer_data = transfer_data
end

Instance Attribute Details

#account_tax_idsObject

The account tax IDs associated with the invoice. Only editable when the invoice is a draft.



1457
1458
1459
# File 'lib/stripe/resources/invoice.rb', line 1457

def 
  @account_tax_ids
end

#amounts_dueObject

List of expected payments and corresponding due dates. Valid only for invoices where ‘collection_method=send_invoice`.



1459
1460
1461
# File 'lib/stripe/resources/invoice.rb', line 1459

def amounts_due
  @amounts_due
end

#application_fee_amountObject

A fee in cents (or local equivalent) that will be applied to the invoice and transferred to the application owner’s Stripe account. The request must be made with an OAuth key or the Stripe-Account header in order to take an application fee. For more information, see the application fees [documentation](stripe.com/docs/billing/invoices/connect#collecting-fees).



1461
1462
1463
# File 'lib/stripe/resources/invoice.rb', line 1461

def application_fee_amount
  @application_fee_amount
end

#auto_advanceObject

Controls whether Stripe performs [automatic collection](stripe.com/docs/invoicing/integration/automatic-advancement-collection) of the invoice.



1463
1464
1465
# File 'lib/stripe/resources/invoice.rb', line 1463

def auto_advance
  @auto_advance
end

#automatic_taxObject

Settings for automatic tax lookup for this invoice.



1465
1466
1467
# File 'lib/stripe/resources/invoice.rb', line 1465

def automatic_tax
  @automatic_tax
end

#automatically_finalizes_atObject

The time when this invoice should be scheduled to finalize (up to 5 years in the future). The invoice is finalized at this time if it’s still in draft state. To turn off automatic finalization, set ‘auto_advance` to false.



1467
1468
1469
# File 'lib/stripe/resources/invoice.rb', line 1467

def automatically_finalizes_at
  @automatically_finalizes_at
end

#collection_methodObject

Either ‘charge_automatically` or `send_invoice`. This field can be updated only on `draft` invoices.



1469
1470
1471
# File 'lib/stripe/resources/invoice.rb', line 1469

def collection_method
  @collection_method
end

#custom_fieldsObject

A list of up to 4 custom fields to be displayed on the invoice. If a value for ‘custom_fields` is specified, the list specified will replace the existing custom field list on this invoice. Pass an empty string to remove previously-defined fields.



1471
1472
1473
# File 'lib/stripe/resources/invoice.rb', line 1471

def custom_fields
  @custom_fields
end

#days_until_dueObject

The number of days from which the invoice is created until it is due. Only valid for invoices where ‘collection_method=send_invoice`. This field can only be updated on `draft` invoices.



1473
1474
1475
# File 'lib/stripe/resources/invoice.rb', line 1473

def days_until_due
  @days_until_due
end

#default_marginsObject

The ids of the margins to apply to the invoice. Can be overridden by line item ‘margins`.



1475
1476
1477
# File 'lib/stripe/resources/invoice.rb', line 1475

def default_margins
  @default_margins
end

#default_payment_methodObject

ID of the default payment method for the invoice. It must belong to the customer associated with the invoice. If not set, defaults to the subscription’s default payment method, if any, or to the default payment method in the customer’s invoice settings.



1477
1478
1479
# File 'lib/stripe/resources/invoice.rb', line 1477

def default_payment_method
  @default_payment_method
end

#default_sourceObject

ID of the default payment source for the invoice. It must belong to the customer associated with the invoice and be in a chargeable state. If not set, defaults to the subscription’s default source, if any, or to the customer’s default source.



1479
1480
1481
# File 'lib/stripe/resources/invoice.rb', line 1479

def default_source
  @default_source
end

#default_tax_ratesObject

The tax rates that will apply to any line item that does not have ‘tax_rates` set. Pass an empty string to remove previously-defined tax rates.



1481
1482
1483
# File 'lib/stripe/resources/invoice.rb', line 1481

def default_tax_rates
  @default_tax_rates
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users. Referenced as ‘memo’ in the Dashboard.



1483
1484
1485
# File 'lib/stripe/resources/invoice.rb', line 1483

def description
  @description
end

#discountsObject

The discounts that will apply to the invoice. Pass an empty string to remove previously-defined discounts.



1485
1486
1487
# File 'lib/stripe/resources/invoice.rb', line 1485

def discounts
  @discounts
end

#due_dateObject

The date on which payment for this invoice is due. Only valid for invoices where ‘collection_method=send_invoice`. This field can only be updated on `draft` invoices.



1487
1488
1489
# File 'lib/stripe/resources/invoice.rb', line 1487

def due_date
  @due_date
end

#effective_atObject

The date when this invoice is in effect. Same as ‘finalized_at` unless overwritten. When defined, this value replaces the system-generated ’Date of issue’ printed on the invoice PDF and receipt.



1489
1490
1491
# File 'lib/stripe/resources/invoice.rb', line 1489

def effective_at
  @effective_at
end

#expandObject

Specifies which fields in the response should be expanded.



1491
1492
1493
# File 'lib/stripe/resources/invoice.rb', line 1491

def expand
  @expand
end

Footer to be displayed on the invoice.



1493
1494
1495
# File 'lib/stripe/resources/invoice.rb', line 1493

def footer
  @footer
end

#issuerObject

The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.



1495
1496
1497
# File 'lib/stripe/resources/invoice.rb', line 1495

def issuer
  @issuer
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1497
1498
1499
# File 'lib/stripe/resources/invoice.rb', line 1497

def 
  @metadata
end

#numberObject

Set the number for this invoice. If no number is present then a number will be assigned automatically when the invoice is finalized. In many markets, regulations require invoices to be unique, sequential and / or gapless. You are responsible for ensuring this is true across all your different invoicing systems in the event that you edit the invoice number using our API. If you use only Stripe for your invoices and do not change invoice numbers, Stripe handles this aspect of compliance for you automatically.



1499
1500
1501
# File 'lib/stripe/resources/invoice.rb', line 1499

def number
  @number
end

#on_behalf_ofObject

The account (if any) for which the funds of the invoice payment are intended. If set, the invoice will be presented with the branding and support information of the specified account. See the [Invoices with Connect](stripe.com/docs/billing/invoices/connect) documentation for details.



1501
1502
1503
# File 'lib/stripe/resources/invoice.rb', line 1501

def on_behalf_of
  @on_behalf_of
end

#payment_settingsObject

Configuration settings for the PaymentIntent that is generated when the invoice is finalized.



1503
1504
1505
# File 'lib/stripe/resources/invoice.rb', line 1503

def payment_settings
  @payment_settings
end

#renderingObject

The rendering-related settings that control how the invoice is displayed on customer-facing surfaces such as PDF and Hosted Invoice Page.



1505
1506
1507
# File 'lib/stripe/resources/invoice.rb', line 1505

def rendering
  @rendering
end

#shipping_costObject

Settings for the cost of shipping for this invoice.



1507
1508
1509
# File 'lib/stripe/resources/invoice.rb', line 1507

def shipping_cost
  @shipping_cost
end

#shipping_detailsObject

Shipping details for the invoice. The Invoice PDF will use the ‘shipping_details` value if it is set, otherwise the PDF will render the shipping address from the customer.



1509
1510
1511
# File 'lib/stripe/resources/invoice.rb', line 1509

def shipping_details
  @shipping_details
end

#statement_descriptorObject

Extra information about a charge for the customer’s credit card statement. It must contain at least one letter. If not specified and this invoice is part of a subscription, the default ‘statement_descriptor` will be set to the first subscription item’s product’s ‘statement_descriptor`.



1511
1512
1513
# File 'lib/stripe/resources/invoice.rb', line 1511

def statement_descriptor
  @statement_descriptor
end

#transfer_dataObject

If specified, the funds from the invoice will be transferred to the destination and the ID of the resulting transfer will be found on the invoice’s charge. This will be unset if you POST an empty value.



1513
1514
1515
# File 'lib/stripe/resources/invoice.rb', line 1513

def transfer_data
  @transfer_data
end