Class: Stripe::Invoice::UpdateParams::AmountsDue
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::UpdateParams::AmountsDue
- Defined in:
- lib/stripe/resources/invoice.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount in cents (or local equivalent).
-
#days_until_due ⇒ Object
Number of days from when invoice is finalized until the payment is due.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#due_date ⇒ Object
Date on which a payment plan’s payment is due.
Instance Method Summary collapse
-
#initialize(amount: nil, days_until_due: nil, description: nil, due_date: nil) ⇒ AmountsDue
constructor
A new instance of AmountsDue.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, days_until_due: nil, description: nil, due_date: nil) ⇒ AmountsDue
Returns a new instance of AmountsDue.
944 945 946 947 948 949 |
# File 'lib/stripe/resources/invoice.rb', line 944 def initialize(amount: nil, days_until_due: nil, description: nil, due_date: nil) @amount = amount @days_until_due = days_until_due @description = description @due_date = due_date end |
Instance Attribute Details
#amount ⇒ Object
The amount in cents (or local equivalent).
936 937 938 |
# File 'lib/stripe/resources/invoice.rb', line 936 def amount @amount end |
#days_until_due ⇒ Object
Number of days from when invoice is finalized until the payment is due.
938 939 940 |
# File 'lib/stripe/resources/invoice.rb', line 938 def days_until_due @days_until_due end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
940 941 942 |
# File 'lib/stripe/resources/invoice.rb', line 940 def description @description end |
#due_date ⇒ Object
Date on which a payment plan’s payment is due.
942 943 944 |
# File 'lib/stripe/resources/invoice.rb', line 942 def due_date @due_date end |