Class: Stripe::Invoice::UpdateParams::AutomaticTax

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Liability

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(enabled: nil, liability: nil) ⇒ AutomaticTax

Returns a new instance of AutomaticTax.



554
555
556
557
# File 'lib/stripe/resources/invoice.rb', line 554

def initialize(enabled: nil, liability: nil)
  @enabled = enabled
  @liability = liability
end

Instance Attribute Details

#enabledObject

Whether Stripe automatically computes tax on this invoice. Note that incompatible invoice items (invoice items with manually specified [tax rates](stripe.com/docs/api/tax_rates), negative amounts, or ‘tax_behavior=unspecified`) cannot be added to automatic tax invoices.



550
551
552
# File 'lib/stripe/resources/invoice.rb', line 550

def enabled
  @enabled
end

#liabilityObject

The account that’s liable for tax. If set, the business address and tax registrations required to perform the tax calculation are loaded from this account. The tax transaction is returned in the report of the connected account.



552
553
554
# File 'lib/stripe/resources/invoice.rb', line 552

def liability
  @liability
end