Class: Stripe::Invoice::UpdateParams::Discount

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1022
1023
1024
1025
1026
1027
# File 'lib/stripe/resources/invoice.rb', line 1022

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1014
1015
1016
# File 'lib/stripe/resources/invoice.rb', line 1014

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1016
1017
1018
# File 'lib/stripe/resources/invoice.rb', line 1016

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1018
1019
1020
# File 'lib/stripe/resources/invoice.rb', line 1018

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1020
1021
1022
# File 'lib/stripe/resources/invoice.rb', line 1020

def promotion_code
  @promotion_code
end