Class: Stripe::Invoice::UpdateParams::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



1007
1008
1009
1010
1011
# File 'lib/stripe/resources/invoice.rb', line 1007

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



1001
1002
1003
# File 'lib/stripe/resources/invoice.rb', line 1001

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



1003
1004
1005
# File 'lib/stripe/resources/invoice.rb', line 1003

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



1005
1006
1007
# File 'lib/stripe/resources/invoice.rb', line 1005

def type
  @type
end