Class: Stripe::Invoice::UpdateParams::PaymentSettings

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: PaymentMethodOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(default_mandate: nil, payment_method_options: nil, payment_method_types: nil) ⇒ PaymentSettings

Returns a new instance of PaymentSettings.



844
845
846
847
848
# File 'lib/stripe/resources/invoice.rb', line 844

def initialize(default_mandate: nil, payment_method_options: nil, payment_method_types: nil)
  @default_mandate = default_mandate
  @payment_method_options = payment_method_options
  @payment_method_types = payment_method_types
end

Instance Attribute Details

#default_mandateObject

ID of the mandate to be used for this invoice. It must correspond to the payment method used to pay the invoice, including the invoice’s default_payment_method or default_source, if set.



838
839
840
# File 'lib/stripe/resources/invoice.rb', line 838

def default_mandate
  @default_mandate
end

#payment_method_optionsObject

Payment-method-specific configuration to provide to the invoice’s PaymentIntent.



840
841
842
# File 'lib/stripe/resources/invoice.rb', line 840

def payment_method_options
  @payment_method_options
end

#payment_method_typesObject

The list of payment method types (e.g. card) to provide to the invoice’s PaymentIntent. If not set, Stripe attempts to automatically determine the types to use by looking at the invoice’s default payment method, the subscription’s default payment method, the customer’s default payment method, and your [invoice template settings](dashboard.stripe.com/settings/billing/invoice). Should not be specified with payment_method_configuration



842
843
844
# File 'lib/stripe/resources/invoice.rb', line 842

def payment_method_types
  @payment_method_types
end