Class: Stripe::Invoice::UpdateParams::PaymentSettings::PaymentMethodOptions::Upi::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



1160
1161
1162
1163
1164
1165
# File 'lib/stripe/resources/invoice.rb', line 1160

def initialize(amount: nil, amount_type: nil, description: nil, end_date: nil)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



1152
1153
1154
# File 'lib/stripe/resources/invoice.rb', line 1152

def amount
  @amount
end

#amount_typeObject

One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.



1154
1155
1156
# File 'lib/stripe/resources/invoice.rb', line 1154

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



1156
1157
1158
# File 'lib/stripe/resources/invoice.rb', line 1156

def description
  @description
end

#end_dateObject

End date of the mandate or subscription. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.



1158
1159
1160
# File 'lib/stripe/resources/invoice.rb', line 1158

def end_date
  @end_date
end