Class: Stripe::Invoice::UpdateParams::ShippingCost::ShippingRateData::FixedAmount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::UpdateParams::ShippingCost::ShippingRateData::FixedAmount
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: CurrencyOptions
Instance Attribute Summary collapse
-
#amount ⇒ Object
A non-negative integer in cents representing how much to charge.
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#currency_options ⇒ Object
Shipping rates defined in each available currency option.
Instance Method Summary collapse
-
#initialize(amount: nil, currency: nil, currency_options: nil) ⇒ FixedAmount
constructor
A new instance of FixedAmount.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, currency: nil, currency_options: nil) ⇒ FixedAmount
Returns a new instance of FixedAmount.
1350 1351 1352 1353 1354 |
# File 'lib/stripe/resources/invoice.rb', line 1350 def initialize(amount: nil, currency: nil, currency_options: nil) @amount = amount @currency = currency @currency_options = end |
Instance Attribute Details
#amount ⇒ Object
A non-negative integer in cents representing how much to charge.
1344 1345 1346 |
# File 'lib/stripe/resources/invoice.rb', line 1344 def amount @amount end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
1346 1347 1348 |
# File 'lib/stripe/resources/invoice.rb', line 1346 def currency @currency end |
#currency_options ⇒ Object
Shipping rates defined in each available currency option. Each key must be a three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html) and a [supported currency](stripe.com/docs/currencies).
1348 1349 1350 |
# File 'lib/stripe/resources/invoice.rb', line 1348 def @currency_options end |