Class: Stripe::Invoice::UpdateParams::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



1036
1037
1038
1039
# File 'lib/stripe/resources/invoice.rb', line 1036

def initialize(amount: nil, destination: nil)
  @amount = amount
  @destination = destination
end

Instance Attribute Details

#amountObject

The amount that will be transferred automatically when the invoice is paid. If no amount is set, the full amount is transferred.



1032
1033
1034
# File 'lib/stripe/resources/invoice.rb', line 1032

def amount
  @amount
end

#destinationObject

ID of an existing, connected Stripe account.



1034
1035
1036
# File 'lib/stripe/resources/invoice.rb', line 1034

def destination
  @destination
end