Class: Stripe::InvoiceAddLinesParams::Line

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/invoice_add_lines_params.rb

Defined Under Namespace

Classes: Discount, Period, PriceData, Pricing, TaxAmount

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(amount: nil, description: nil, discountable: nil, discounts: nil, invoice_item: nil, metadata: nil, period: nil, price_data: nil, pricing: nil, quantity: nil, quantity_decimal: nil, tax_amounts: nil, tax_rates: nil) ⇒ Line

Returns a new instance of Line.



196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'lib/stripe/params/invoice_add_lines_params.rb', line 196

def initialize(
  amount: nil,
  description: nil,
  discountable: nil,
  discounts: nil,
  invoice_item: nil,
  metadata: nil,
  period: nil,
  price_data: nil,
  pricing: nil,
  quantity: nil,
  quantity_decimal: nil,
  tax_amounts: nil,
  tax_rates: nil
)
  @amount = amount
  @description = description
  @discountable = discountable
  @discounts = discounts
  @invoice_item = invoice_item
   = 
  @period = period
  @price_data = price_data
  @pricing = pricing
  @quantity = quantity
  @quantity_decimal = quantity_decimal
  @tax_amounts = tax_amounts
  @tax_rates = tax_rates
end

Instance Attribute Details

#amountObject

The integer amount in cents (or local equivalent) of the charge to be applied to the upcoming invoice. If you want to apply a credit to the customer’s account, pass a negative amount.



170
171
172
# File 'lib/stripe/params/invoice_add_lines_params.rb', line 170

def amount
  @amount
end

#descriptionObject

An arbitrary string which you can attach to the invoice item. The description is displayed in the invoice for easy tracking.



172
173
174
# File 'lib/stripe/params/invoice_add_lines_params.rb', line 172

def description
  @description
end

#discountableObject

Controls whether discounts apply to this line item. Defaults to false for prorations or negative line items, and true for all other line items. Cannot be set to true for prorations.



174
175
176
# File 'lib/stripe/params/invoice_add_lines_params.rb', line 174

def discountable
  @discountable
end

#discountsObject

The coupons, promotion codes & existing discounts which apply to the line item. Item discounts are applied before invoice discounts. Pass an empty string to remove previously-defined discounts.



176
177
178
# File 'lib/stripe/params/invoice_add_lines_params.rb', line 176

def discounts
  @discounts
end

#invoice_itemObject

ID of an unassigned invoice item to assign to this invoice. If not provided, a new item will be created.



178
179
180
# File 'lib/stripe/params/invoice_add_lines_params.rb', line 178

def invoice_item
  @invoice_item
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.



180
181
182
# File 'lib/stripe/params/invoice_add_lines_params.rb', line 180

def 
  
end

#periodObject

The period associated with this invoice item. When set to different values, the period will be rendered on the invoice. If you have [Stripe Revenue Recognition](docs.stripe.com/revenue-recognition) enabled, the period will be used to recognize and defer revenue. See the [Revenue Recognition documentation](docs.stripe.com/revenue-recognition/methodology/subscriptions-and-invoicing) for details.



182
183
184
# File 'lib/stripe/params/invoice_add_lines_params.rb', line 182

def period
  @period
end

#price_dataObject

Data used to generate a new [Price](docs.stripe.com/api/prices) object inline.



184
185
186
# File 'lib/stripe/params/invoice_add_lines_params.rb', line 184

def price_data
  @price_data
end

#pricingObject

The pricing information for the invoice item.



186
187
188
# File 'lib/stripe/params/invoice_add_lines_params.rb', line 186

def pricing
  @pricing
end

#quantityObject

Non-negative integer. The quantity of units for the line item. Use quantity_decimal instead to provide decimal precision. This field will be deprecated in favor of quantity_decimal in a future version.



188
189
190
# File 'lib/stripe/params/invoice_add_lines_params.rb', line 188

def quantity
  @quantity
end

#quantity_decimalObject

Non-negative decimal with at most 12 decimal places. The quantity of units for the line item.



190
191
192
# File 'lib/stripe/params/invoice_add_lines_params.rb', line 190

def quantity_decimal
  @quantity_decimal
end

#tax_amountsObject

A list of up to 10 tax amounts for this line item. This can be useful if you calculate taxes on your own or use a third-party to calculate them. You cannot set tax amounts if any line item has [tax_rates](docs.stripe.com/api/invoices/line_item#invoice_line_item_object-tax_rates) or if the invoice has [default_tax_rates](docs.stripe.com/api/invoices/object#invoice_object-default_tax_rates) or uses [automatic tax](docs.stripe.com/tax/invoicing). Pass an empty string to remove previously defined tax amounts.



192
193
194
# File 'lib/stripe/params/invoice_add_lines_params.rb', line 192

def tax_amounts
  @tax_amounts
end

#tax_ratesObject

The tax rates which apply to the line item. When set, the default_tax_rates on the invoice do not apply to this line item. Pass an empty string to remove previously-defined tax rates.



194
195
196
# File 'lib/stripe/params/invoice_add_lines_params.rb', line 194

def tax_rates
  @tax_rates
end

Class Method Details

.field_encodingsObject



226
227
228
229
230
231
# File 'lib/stripe/params/invoice_add_lines_params.rb', line 226

def self.field_encodings
  @field_encodings = {
    price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } },
    quantity_decimal: :decimal_string,
  }
end