Class: Stripe::InvoiceAddLinesParams::Line::PriceData::ProductData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_add_lines_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil, unit_label: nil) ⇒ ProductData

Returns a new instance of ProductData.



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/stripe/params/invoice_add_lines_params.rb', line 77

def initialize(
  description: nil,
  images: nil,
  metadata: nil,
  name: nil,
  tax_code: nil,
  unit_label: nil
)
  @description = description
  @images = images
  @metadata = 
  @name = name
  @tax_code = tax_code
  @unit_label = unit_label
end

Instance Attribute Details

#descriptionObject

The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.



65
66
67
# File 'lib/stripe/params/invoice_add_lines_params.rb', line 65

def description
  @description
end

#imagesObject

A list of up to 8 URLs of images for this product, meant to be displayable to the customer.



67
68
69
# File 'lib/stripe/params/invoice_add_lines_params.rb', line 67

def images
  @images
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



69
70
71
# File 'lib/stripe/params/invoice_add_lines_params.rb', line 69

def 
  @metadata
end

#nameObject

The product’s name, meant to be displayable to the customer.



71
72
73
# File 'lib/stripe/params/invoice_add_lines_params.rb', line 71

def name
  @name
end

#tax_codeObject



73
74
75
# File 'lib/stripe/params/invoice_add_lines_params.rb', line 73

def tax_code
  @tax_code
end

#unit_labelObject

A label that represents units of this product. When set, this will be included in customers’ receipts, invoices, Checkout, and the customer portal.



75
76
77
# File 'lib/stripe/params/invoice_add_lines_params.rb', line 75

def unit_label
  @unit_label
end