Class: Stripe::InvoiceCreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/invoice_create_params.rb

Defined Under Namespace

Classes: AmountsDue, AutomaticTax, CustomField, Discount, FromInvoice, Issuer, PaymentSettings, Rendering, ShippingCost, ShippingDetails, TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(account_tax_ids: nil, amounts_due: nil, application_fee_amount: nil, auto_advance: nil, automatic_tax: nil, automatically_finalizes_at: nil, collection_method: nil, currency: nil, custom_fields: nil, customer: nil, customer_account: nil, days_until_due: nil, default_margins: nil, default_payment_method: nil, default_source: nil, default_tax_rates: nil, description: nil, discounts: nil, due_date: nil, effective_at: nil, expand: nil, footer: nil, from_invoice: nil, issuer: nil, metadata: nil, number: nil, on_behalf_of: nil, payment_settings: nil, pending_invoice_items_behavior: nil, rendering: nil, shipping_cost: nil, shipping_details: nil, statement_descriptor: nil, subscription: nil, transfer_data: nil) ⇒ InvoiceCreateParams

Returns a new instance of InvoiceCreateParams.



685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
# File 'lib/stripe/params/invoice_create_params.rb', line 685

def initialize(
  account_tax_ids: nil,
  amounts_due: nil,
  application_fee_amount: nil,
  auto_advance: nil,
  automatic_tax: nil,
  automatically_finalizes_at: nil,
  collection_method: nil,
  currency: nil,
  custom_fields: nil,
  customer: nil,
  customer_account: nil,
  days_until_due: nil,
  default_margins: nil,
  default_payment_method: nil,
  default_source: nil,
  default_tax_rates: nil,
  description: nil,
  discounts: nil,
  due_date: nil,
  effective_at: nil,
  expand: nil,
  footer: nil,
  from_invoice: nil,
  issuer: nil,
  metadata: nil,
  number: nil,
  on_behalf_of: nil,
  payment_settings: nil,
  pending_invoice_items_behavior: nil,
  rendering: nil,
  shipping_cost: nil,
  shipping_details: nil,
  statement_descriptor: nil,
  subscription: nil,
  transfer_data: nil
)
  @account_tax_ids = 
  @amounts_due = amounts_due
  @application_fee_amount = application_fee_amount
  @auto_advance = auto_advance
  @automatic_tax = automatic_tax
  @automatically_finalizes_at = automatically_finalizes_at
  @collection_method = collection_method
  @currency = currency
  @custom_fields = custom_fields
  @customer = customer
  @customer_account = 
  @days_until_due = days_until_due
  @default_margins = default_margins
  @default_payment_method = default_payment_method
  @default_source = default_source
  @default_tax_rates = default_tax_rates
  @description = description
  @discounts = discounts
  @due_date = due_date
  @effective_at = effective_at
  @expand = expand
  @footer = footer
  @from_invoice = from_invoice
  @issuer = issuer
  @metadata = 
  @number = number
  @on_behalf_of = on_behalf_of
  @payment_settings = payment_settings
  @pending_invoice_items_behavior = pending_invoice_items_behavior
  @rendering = rendering
  @shipping_cost = shipping_cost
  @shipping_details = shipping_details
  @statement_descriptor = statement_descriptor
  @subscription = subscription
  @transfer_data = transfer_data
end

Instance Attribute Details

#account_tax_idsObject

The account tax IDs associated with the invoice. Only editable when the invoice is a draft.



615
616
617
# File 'lib/stripe/params/invoice_create_params.rb', line 615

def 
  @account_tax_ids
end

#amounts_dueObject

List of expected payments and corresponding due dates. Valid only for invoices where ‘collection_method=send_invoice`.



617
618
619
# File 'lib/stripe/params/invoice_create_params.rb', line 617

def amounts_due
  @amounts_due
end

#application_fee_amountObject

A fee in cents (or local equivalent) that will be applied to the invoice and transferred to the application owner’s Stripe account. The request must be made with an OAuth key or the Stripe-Account header in order to take an application fee. For more information, see the application fees [documentation](docs.stripe.com/billing/invoices/connect#collecting-fees).



619
620
621
# File 'lib/stripe/params/invoice_create_params.rb', line 619

def application_fee_amount
  @application_fee_amount
end

#auto_advanceObject

Controls whether Stripe performs [automatic collection](docs.stripe.com/invoicing/integration/automatic-advancement-collection) of the invoice. If ‘false`, the invoice’s state doesn’t automatically advance without an explicit action. Defaults to false.



621
622
623
# File 'lib/stripe/params/invoice_create_params.rb', line 621

def auto_advance
  @auto_advance
end

#automatic_taxObject

Settings for automatic tax lookup for this invoice.



623
624
625
# File 'lib/stripe/params/invoice_create_params.rb', line 623

def automatic_tax
  @automatic_tax
end

#automatically_finalizes_atObject

The time when this invoice should be scheduled to finalize (up to 5 years in the future). The invoice is finalized at this time if it’s still in draft state.



625
626
627
# File 'lib/stripe/params/invoice_create_params.rb', line 625

def automatically_finalizes_at
  @automatically_finalizes_at
end

#collection_methodObject

Either ‘charge_automatically`, or `send_invoice`. When charging automatically, Stripe will attempt to pay this invoice using the default source attached to the customer. When sending an invoice, Stripe will email this invoice to the customer with payment instructions. Defaults to `charge_automatically`.



627
628
629
# File 'lib/stripe/params/invoice_create_params.rb', line 627

def collection_method
  @collection_method
end

#currencyObject

The currency to create this invoice in. Defaults to that of ‘customer` if not specified.



629
630
631
# File 'lib/stripe/params/invoice_create_params.rb', line 629

def currency
  @currency
end

#custom_fieldsObject

A list of up to 4 custom fields to be displayed on the invoice.



631
632
633
# File 'lib/stripe/params/invoice_create_params.rb', line 631

def custom_fields
  @custom_fields
end

#customerObject

The ID of the customer to bill.



633
634
635
# File 'lib/stripe/params/invoice_create_params.rb', line 633

def customer
  @customer
end

#customer_accountObject

The ID of the account to bill.



635
636
637
# File 'lib/stripe/params/invoice_create_params.rb', line 635

def 
  @customer_account
end

#days_until_dueObject

The number of days from when the invoice is created until it is due. Valid only for invoices where ‘collection_method=send_invoice`.



637
638
639
# File 'lib/stripe/params/invoice_create_params.rb', line 637

def days_until_due
  @days_until_due
end

#default_marginsObject

The ids of the margins to apply to the invoice. Can be overridden by line item ‘margins`.



639
640
641
# File 'lib/stripe/params/invoice_create_params.rb', line 639

def default_margins
  @default_margins
end

#default_payment_methodObject

ID of the default payment method for the invoice. It must belong to the customer associated with the invoice. If not set, defaults to the subscription’s default payment method, if any, or to the default payment method in the customer’s invoice settings.



641
642
643
# File 'lib/stripe/params/invoice_create_params.rb', line 641

def default_payment_method
  @default_payment_method
end

#default_sourceObject

ID of the default payment source for the invoice. It must belong to the customer associated with the invoice and be in a chargeable state. If not set, defaults to the subscription’s default source, if any, or to the customer’s default source.



643
644
645
# File 'lib/stripe/params/invoice_create_params.rb', line 643

def default_source
  @default_source
end

#default_tax_ratesObject

The tax rates that will apply to any line item that does not have ‘tax_rates` set.



645
646
647
# File 'lib/stripe/params/invoice_create_params.rb', line 645

def default_tax_rates
  @default_tax_rates
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users. Referenced as ‘memo’ in the Dashboard.



647
648
649
# File 'lib/stripe/params/invoice_create_params.rb', line 647

def description
  @description
end

#discountsObject

The coupons and promotion codes to redeem into discounts for the invoice. If not specified, inherits the discount from the invoice’s customer. Pass an empty string to avoid inheriting any discounts.



649
650
651
# File 'lib/stripe/params/invoice_create_params.rb', line 649

def discounts
  @discounts
end

#due_dateObject

The date on which payment for this invoice is due. Valid only for invoices where ‘collection_method=send_invoice`.



651
652
653
# File 'lib/stripe/params/invoice_create_params.rb', line 651

def due_date
  @due_date
end

#effective_atObject

The date when this invoice is in effect. Same as ‘finalized_at` unless overwritten. When defined, this value replaces the system-generated ’Date of issue’ printed on the invoice PDF and receipt.



653
654
655
# File 'lib/stripe/params/invoice_create_params.rb', line 653

def effective_at
  @effective_at
end

#expandObject

Specifies which fields in the response should be expanded.



655
656
657
# File 'lib/stripe/params/invoice_create_params.rb', line 655

def expand
  @expand
end

Footer to be displayed on the invoice.



657
658
659
# File 'lib/stripe/params/invoice_create_params.rb', line 657

def footer
  @footer
end

#from_invoiceObject

Revise an existing invoice. The new invoice will be created in ‘status=draft`. See the [revision documentation](docs.stripe.com/invoicing/invoice-revisions) for more details.



659
660
661
# File 'lib/stripe/params/invoice_create_params.rb', line 659

def from_invoice
  @from_invoice
end

#issuerObject

The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.



661
662
663
# File 'lib/stripe/params/invoice_create_params.rb', line 661

def issuer
  @issuer
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



663
664
665
# File 'lib/stripe/params/invoice_create_params.rb', line 663

def 
  @metadata
end

#numberObject

Set the number for this invoice. If no number is present then a number will be assigned automatically when the invoice is finalized. In many markets, regulations require invoices to be unique, sequential and / or gapless. You are responsible for ensuring this is true across all your different invoicing systems in the event that you edit the invoice number using our API. If you use only Stripe for your invoices and do not change invoice numbers, Stripe handles this aspect of compliance for you automatically.



665
666
667
# File 'lib/stripe/params/invoice_create_params.rb', line 665

def number
  @number
end

#on_behalf_ofObject

The account (if any) for which the funds of the invoice payment are intended. If set, the invoice will be presented with the branding and support information of the specified account. See the [Invoices with Connect](docs.stripe.com/billing/invoices/connect) documentation for details.



667
668
669
# File 'lib/stripe/params/invoice_create_params.rb', line 667

def on_behalf_of
  @on_behalf_of
end

#payment_settingsObject

Configuration settings for the PaymentIntent that is generated when the invoice is finalized.



669
670
671
# File 'lib/stripe/params/invoice_create_params.rb', line 669

def payment_settings
  @payment_settings
end

#pending_invoice_items_behaviorObject

How to handle pending invoice items on invoice creation. Defaults to ‘exclude` if the parameter is omitted.



671
672
673
# File 'lib/stripe/params/invoice_create_params.rb', line 671

def pending_invoice_items_behavior
  @pending_invoice_items_behavior
end

#renderingObject

The rendering-related settings that control how the invoice is displayed on customer-facing surfaces such as PDF and Hosted Invoice Page.



673
674
675
# File 'lib/stripe/params/invoice_create_params.rb', line 673

def rendering
  @rendering
end

#shipping_costObject

Settings for the cost of shipping for this invoice.



675
676
677
# File 'lib/stripe/params/invoice_create_params.rb', line 675

def shipping_cost
  @shipping_cost
end

#shipping_detailsObject

Shipping details for the invoice. The Invoice PDF will use the ‘shipping_details` value if it is set, otherwise the PDF will render the shipping address from the customer.



677
678
679
# File 'lib/stripe/params/invoice_create_params.rb', line 677

def shipping_details
  @shipping_details
end

#statement_descriptorObject

Extra information about a charge for the customer’s credit card statement. It must contain at least one letter. If not specified and this invoice is part of a subscription, the default ‘statement_descriptor` will be set to the first subscription item’s product’s ‘statement_descriptor`.



679
680
681
# File 'lib/stripe/params/invoice_create_params.rb', line 679

def statement_descriptor
  @statement_descriptor
end

#subscriptionObject

The ID of the subscription to invoice, if any. If set, the created invoice will only include pending invoice items for that subscription. The subscription’s billing cycle and regular subscription events won’t be affected.



681
682
683
# File 'lib/stripe/params/invoice_create_params.rb', line 681

def subscription
  @subscription
end

#transfer_dataObject

If specified, the funds from the invoice will be transferred to the destination and the ID of the resulting transfer will be found on the invoice’s charge.



683
684
685
# File 'lib/stripe/params/invoice_create_params.rb', line 683

def transfer_data
  @transfer_data
end