Class: Stripe::InvoiceCreateParams::AmountsDue
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreateParams::AmountsDue
- Defined in:
- lib/stripe/params/invoice_create_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount in cents (or local equivalent).
-
#days_until_due ⇒ Object
Number of days from when invoice is finalized until the payment is due.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#due_date ⇒ Object
Date on which a payment plan’s payment is due.
Instance Method Summary collapse
-
#initialize(amount: nil, days_until_due: nil, description: nil, due_date: nil) ⇒ AmountsDue
constructor
A new instance of AmountsDue.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, days_until_due: nil, description: nil, due_date: nil) ⇒ AmountsDue
Returns a new instance of AmountsDue.
16 17 18 19 20 21 |
# File 'lib/stripe/params/invoice_create_params.rb', line 16 def initialize(amount: nil, days_until_due: nil, description: nil, due_date: nil) @amount = amount @days_until_due = days_until_due @description = description @due_date = due_date end |
Instance Attribute Details
#amount ⇒ Object
The amount in cents (or local equivalent).
8 9 10 |
# File 'lib/stripe/params/invoice_create_params.rb', line 8 def amount @amount end |
#days_until_due ⇒ Object
Number of days from when invoice is finalized until the payment is due.
10 11 12 |
# File 'lib/stripe/params/invoice_create_params.rb', line 10 def days_until_due @days_until_due end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
12 13 14 |
# File 'lib/stripe/params/invoice_create_params.rb', line 12 def description @description end |
#due_date ⇒ Object
Date on which a payment plan’s payment is due.
14 15 16 |
# File 'lib/stripe/params/invoice_create_params.rb', line 14 def due_date @due_date end |