Class: Stripe::InvoiceCreateParams::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_params.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



79
80
81
82
83
# File 'lib/stripe/params/invoice_create_params.rb', line 79

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



73
74
75
# File 'lib/stripe/params/invoice_create_params.rb', line 73

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



75
76
77
# File 'lib/stripe/params/invoice_create_params.rb', line 75

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



77
78
79
# File 'lib/stripe/params/invoice_create_params.rb', line 77

def type
  @type
end