Class: Stripe::InvoiceCreateParams::FromInvoice
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreateParams::FromInvoice
- Defined in:
- lib/stripe/params/invoice_create_params.rb
Instance Attribute Summary collapse
-
#action ⇒ Object
The relation between the new invoice and the original invoice.
-
#invoice ⇒ Object
The ‘id` of the invoice that will be cloned.
Instance Method Summary collapse
-
#initialize(action: nil, invoice: nil) ⇒ FromInvoice
constructor
A new instance of FromInvoice.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(action: nil, invoice: nil) ⇒ FromInvoice
Returns a new instance of FromInvoice.
108 109 110 111 |
# File 'lib/stripe/params/invoice_create_params.rb', line 108 def initialize(action: nil, invoice: nil) @action = action @invoice = invoice end |
Instance Attribute Details
#action ⇒ Object
The relation between the new invoice and the original invoice. Currently, only ‘revision’ is permitted
104 105 106 |
# File 'lib/stripe/params/invoice_create_params.rb', line 104 def action @action end |
#invoice ⇒ Object
The ‘id` of the invoice that will be cloned.
106 107 108 |
# File 'lib/stripe/params/invoice_create_params.rb', line 106 def invoice @invoice end |