Class: Stripe::InvoiceCreateParams::PaymentSettings::PaymentMethodOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreateParams::PaymentSettings::PaymentMethodOptions
- Defined in:
- lib/stripe/params/invoice_create_params.rb
Defined Under Namespace
Classes: AcssDebit, Bancontact, Bizum, Blik, Card, CheckScan, CustomerBalance, IdBankTransfer, Konbini, Payto, Pix, SepaDebit, Upi, UsBankAccount, WechatPay
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
If paying by
acss_debit, this sub-hash contains details about the Canadian pre-authorized debit payment method options to pass to the invoice’s PaymentIntent. -
#bancontact ⇒ Object
If paying by
bancontact, this sub-hash contains details about the Bancontact payment method options to pass to the invoice’s PaymentIntent. -
#bizum ⇒ Object
If paying by
bizum, this sub-hash contains details about the Bizum payment method options to pass to the invoice’s PaymentIntent. -
#blik ⇒ Object
If paying by
blik, this sub-hash contains details about the Blik payment method options to pass to the invoice’s PaymentIntent. -
#card ⇒ Object
If paying by
card, this sub-hash contains details about the Card payment method options to pass to the invoice’s PaymentIntent. -
#check_scan ⇒ Object
If paying by
check_scan, this sub-hash contains details about the Check Scan payment method options to pass to the invoice’s PaymentIntent. -
#customer_balance ⇒ Object
If paying by
customer_balance, this sub-hash contains details about the Bank transfer payment method options to pass to the invoice’s PaymentIntent. -
#id_bank_transfer ⇒ Object
If paying by
id_bank_transfer, this sub-hash contains details about the Indonesia bank transfer payment method options to pass to the invoice’s PaymentIntent. -
#konbini ⇒ Object
If paying by
konbini, this sub-hash contains details about the Konbini payment method options to pass to the invoice’s PaymentIntent. -
#payto ⇒ Object
If paying by
payto, this sub-hash contains details about the PayTo payment method options to pass to the invoice’s PaymentIntent. -
#pix ⇒ Object
If paying by
pix, this sub-hash contains details about the Pix payment method options to pass to the invoice’s PaymentIntent. -
#sepa_debit ⇒ Object
If paying by
sepa_debit, this sub-hash contains details about the SEPA Direct Debit payment method options to pass to the invoice’s PaymentIntent. -
#upi ⇒ Object
If paying by
upi, this sub-hash contains details about the UPI payment method options to pass to the invoice’s PaymentIntent. -
#us_bank_account ⇒ Object
If paying by
us_bank_account, this sub-hash contains details about the ACH direct debit payment method options to pass to the invoice’s PaymentIntent. -
#wechat_pay ⇒ Object
If paying by
wechat_pay, this sub-hash contains details about the WeChat Pay payment method options to pass to the invoice’s PaymentIntent.
Instance Method Summary collapse
-
#initialize(acss_debit: nil, bancontact: nil, bizum: nil, blik: nil, card: nil, check_scan: nil, customer_balance: nil, id_bank_transfer: nil, konbini: nil, payto: nil, pix: nil, sepa_debit: nil, upi: nil, us_bank_account: nil, wechat_pay: nil) ⇒ PaymentMethodOptions
constructor
A new instance of PaymentMethodOptions.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(acss_debit: nil, bancontact: nil, bizum: nil, blik: nil, card: nil, check_scan: nil, customer_balance: nil, id_bank_transfer: nil, konbini: nil, payto: nil, pix: nil, sepa_debit: nil, upi: nil, us_bank_account: nil, wechat_pay: nil) ⇒ PaymentMethodOptions
Returns a new instance of PaymentMethodOptions.
385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 |
# File 'lib/stripe/params/invoice_create_params.rb', line 385 def initialize( acss_debit: nil, bancontact: nil, bizum: nil, blik: nil, card: nil, check_scan: nil, customer_balance: nil, id_bank_transfer: nil, konbini: nil, payto: nil, pix: nil, sepa_debit: nil, upi: nil, us_bank_account: nil, wechat_pay: nil ) @acss_debit = acss_debit @bancontact = bancontact @bizum = bizum @blik = blik @card = card @check_scan = check_scan @customer_balance = customer_balance @id_bank_transfer = id_bank_transfer @konbini = konbini @payto = payto @pix = pix @sepa_debit = sepa_debit @upi = upi @us_bank_account = us_bank_account @wechat_pay = wechat_pay end |
Instance Attribute Details
#acss_debit ⇒ Object
If paying by acss_debit, this sub-hash contains details about the Canadian pre-authorized debit payment method options to pass to the invoice’s PaymentIntent.
355 356 357 |
# File 'lib/stripe/params/invoice_create_params.rb', line 355 def acss_debit @acss_debit end |
#bancontact ⇒ Object
If paying by bancontact, this sub-hash contains details about the Bancontact payment method options to pass to the invoice’s PaymentIntent.
357 358 359 |
# File 'lib/stripe/params/invoice_create_params.rb', line 357 def bancontact @bancontact end |
#bizum ⇒ Object
If paying by bizum, this sub-hash contains details about the Bizum payment method options to pass to the invoice’s PaymentIntent.
359 360 361 |
# File 'lib/stripe/params/invoice_create_params.rb', line 359 def bizum @bizum end |
#blik ⇒ Object
If paying by blik, this sub-hash contains details about the Blik payment method options to pass to the invoice’s PaymentIntent.
361 362 363 |
# File 'lib/stripe/params/invoice_create_params.rb', line 361 def blik @blik end |
#card ⇒ Object
If paying by card, this sub-hash contains details about the Card payment method options to pass to the invoice’s PaymentIntent.
363 364 365 |
# File 'lib/stripe/params/invoice_create_params.rb', line 363 def card @card end |
#check_scan ⇒ Object
If paying by check_scan, this sub-hash contains details about the Check Scan payment method options to pass to the invoice’s PaymentIntent.
365 366 367 |
# File 'lib/stripe/params/invoice_create_params.rb', line 365 def check_scan @check_scan end |
#customer_balance ⇒ Object
If paying by customer_balance, this sub-hash contains details about the Bank transfer payment method options to pass to the invoice’s PaymentIntent.
367 368 369 |
# File 'lib/stripe/params/invoice_create_params.rb', line 367 def customer_balance @customer_balance end |
#id_bank_transfer ⇒ Object
If paying by id_bank_transfer, this sub-hash contains details about the Indonesia bank transfer payment method options to pass to the invoice’s PaymentIntent.
369 370 371 |
# File 'lib/stripe/params/invoice_create_params.rb', line 369 def id_bank_transfer @id_bank_transfer end |
#konbini ⇒ Object
If paying by konbini, this sub-hash contains details about the Konbini payment method options to pass to the invoice’s PaymentIntent.
371 372 373 |
# File 'lib/stripe/params/invoice_create_params.rb', line 371 def konbini @konbini end |
#payto ⇒ Object
If paying by payto, this sub-hash contains details about the PayTo payment method options to pass to the invoice’s PaymentIntent.
373 374 375 |
# File 'lib/stripe/params/invoice_create_params.rb', line 373 def payto @payto end |
#pix ⇒ Object
If paying by pix, this sub-hash contains details about the Pix payment method options to pass to the invoice’s PaymentIntent.
375 376 377 |
# File 'lib/stripe/params/invoice_create_params.rb', line 375 def pix @pix end |
#sepa_debit ⇒ Object
If paying by sepa_debit, this sub-hash contains details about the SEPA Direct Debit payment method options to pass to the invoice’s PaymentIntent.
377 378 379 |
# File 'lib/stripe/params/invoice_create_params.rb', line 377 def sepa_debit @sepa_debit end |
#upi ⇒ Object
If paying by upi, this sub-hash contains details about the UPI payment method options to pass to the invoice’s PaymentIntent.
379 380 381 |
# File 'lib/stripe/params/invoice_create_params.rb', line 379 def upi @upi end |
#us_bank_account ⇒ Object
If paying by us_bank_account, this sub-hash contains details about the ACH direct debit payment method options to pass to the invoice’s PaymentIntent.
381 382 383 |
# File 'lib/stripe/params/invoice_create_params.rb', line 381 def us_bank_account @us_bank_account end |
#wechat_pay ⇒ Object
If paying by wechat_pay, this sub-hash contains details about the WeChat Pay payment method options to pass to the invoice’s PaymentIntent.
383 384 385 |
# File 'lib/stripe/params/invoice_create_params.rb', line 383 def wechat_pay @wechat_pay end |