Class: Stripe::InvoiceCreateParams::PaymentSettings::PaymentMethodOptions::Billie::CompanyDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_params.rb

Defined Under Namespace

Classes: RegisteredAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h

Constructor Details

#initialize(registered_address: nil, registered_name: nil, registration_number: nil, registration_type: nil, vat: nil) ⇒ CompanyDetails

Returns a new instance of CompanyDetails.



154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'lib/stripe/params/invoice_create_params.rb', line 154

def initialize(
  registered_address: nil,
  registered_name: nil,
  registration_number: nil,
  registration_type: nil,
  vat: nil
)
  @registered_address = registered_address
  @registered_name = registered_name
  @registration_number = registration_number
  @registration_type = registration_type
  @vat = vat
end

Instance Attribute Details

#registered_address ⇒ Object

The address the company or entity is registered with.



144
145
146
# File 'lib/stripe/params/invoice_create_params.rb', line 144

def registered_address
  @registered_address
end

#registered_name ⇒ Object

Company or entity name.



146
147
148
# File 'lib/stripe/params/invoice_create_params.rb', line 146

def registered_name
  @registered_name
end

#registration_number ⇒ Object

The official registration number for the given registration type.



148
149
150
# File 'lib/stripe/params/invoice_create_params.rb', line 148

def registration_number
  @registration_number
end

#registration_type ⇒ Object

Type of registration the company or entity holds in their registered country.



150
151
152
# File 'lib/stripe/params/invoice_create_params.rb', line 150

def registration_type
  @registration_type
end

#vat ⇒ Object

VAT ID number.



152
153
154
# File 'lib/stripe/params/invoice_create_params.rb', line 152

def vat
  @vat
end