Class: Stripe::InvoiceCreateParams::PaymentSettings::PaymentMethodOptions::Card
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreateParams::PaymentSettings::PaymentMethodOptions::Card
- Defined in:
- lib/stripe/params/invoice_create_params.rb
Defined Under Namespace
Classes: Installments
Instance Attribute Summary collapse
-
#installments ⇒ Object
Installment configuration for payments attempted on this invoice.
-
#request_three_d_secure ⇒ Object
We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and other requirements.
Instance Method Summary collapse
-
#initialize(installments: nil, request_three_d_secure: nil) ⇒ Card
constructor
A new instance of Card.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(installments: nil, request_three_d_secure: nil) ⇒ Card
Returns a new instance of Card.
204 205 206 207 |
# File 'lib/stripe/params/invoice_create_params.rb', line 204 def initialize(installments: nil, request_three_d_secure: nil) @installments = installments @request_three_d_secure = request_three_d_secure end |
Instance Attribute Details
#installments ⇒ Object
Installment configuration for payments attempted on this invoice.
For more information, see the installments integration guide.
200 201 202 |
# File 'lib/stripe/params/invoice_create_params.rb', line 200 def installments @installments end |
#request_three_d_secure ⇒ Object
We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and other requirements. However, if you wish to request 3D Secure based on logic from your own fraud engine, provide this option. Read our guide on manually requesting 3D Secure for more information on how this configuration interacts with Radar and our SCA Engine.
202 203 204 |
# File 'lib/stripe/params/invoice_create_params.rb', line 202 def request_three_d_secure @request_three_d_secure end |