Class: Stripe::InvoiceCreateParams::PaymentSettings::PaymentMethodOptions::Card::Installments::Plan

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(count: nil, interval: nil, type: nil) ⇒ Plan

Returns a new instance of Plan.



171
172
173
174
175
# File 'lib/stripe/params/invoice_create_params.rb', line 171

def initialize(count: nil, interval: nil, type: nil)
  @count = count
  @interval = interval
  @type = type
end

Instance Attribute Details

#countObject

For ‘fixed_count` installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.



164
165
166
# File 'lib/stripe/params/invoice_create_params.rb', line 164

def count
  @count
end

#intervalObject

For ‘fixed_count` installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of `month`.



167
168
169
# File 'lib/stripe/params/invoice_create_params.rb', line 167

def interval
  @interval
end

#typeObject

Type of installment plan, one of ‘fixed_count`, `bonus`, or `revolving`.



169
170
171
# File 'lib/stripe/params/invoice_create_params.rb', line 169

def type
  @type
end