Class: Stripe::InvoiceCreateParams::PaymentSettings::PaymentMethodOptions::Payto::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, purpose: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



262
263
264
265
# File 'lib/stripe/params/invoice_create_params.rb', line 262

def initialize(amount: nil, purpose: nil)
  @amount = amount
  @purpose = purpose
end

Instance Attribute Details

#amount ⇒ Object

The maximum amount that can be collected in a single invoice. If you don't specify a maximum, then there is no limit.



258
259
260
# File 'lib/stripe/params/invoice_create_params.rb', line 258

def amount
  @amount
end

#purpose ⇒ Object

The purpose for which payments are made. Has a default value based on your merchant category code.



260
261
262
# File 'lib/stripe/params/invoice_create_params.rb', line 260

def purpose
  @purpose
end