Class: Stripe::InvoiceCreateParams::PaymentSettings::PaymentMethodOptions::Upi::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



291
292
293
294
295
296
# File 'lib/stripe/params/invoice_create_params.rb', line 291

def initialize(amount: nil, amount_type: nil, description: nil, end_date: nil)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



283
284
285
# File 'lib/stripe/params/invoice_create_params.rb', line 283

def amount
  @amount
end

#amount_typeObject

One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.



285
286
287
# File 'lib/stripe/params/invoice_create_params.rb', line 285

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



287
288
289
# File 'lib/stripe/params/invoice_create_params.rb', line 287

def description
  @description
end

#end_dateObject

End date of the mandate or subscription.



289
290
291
# File 'lib/stripe/params/invoice_create_params.rb', line 289

def end_date
  @end_date
end