Class: Stripe::InvoiceCreateParams::Rendering

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/invoice_create_params.rb

Defined Under Namespace

Classes: Pdf

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount_tax_display: nil, pdf: nil, template: nil, template_version: nil) ⇒ Rendering

Returns a new instance of Rendering.



417
418
419
420
421
422
# File 'lib/stripe/params/invoice_create_params.rb', line 417

def initialize(amount_tax_display: nil, pdf: nil, template: nil, template_version: nil)
  @amount_tax_display = amount_tax_display
  @pdf = pdf
  @template = template
  @template_version = template_version
end

Instance Attribute Details

#amount_tax_displayObject

How line-item prices and amounts will be displayed with respect to tax on invoice PDFs. One of ‘exclude_tax` or `include_inclusive_tax`. `include_inclusive_tax` will include inclusive tax (and exclude exclusive tax) in invoice PDF amounts. `exclude_tax` will exclude all tax (inclusive and exclusive alike) from invoice PDF amounts.



409
410
411
# File 'lib/stripe/params/invoice_create_params.rb', line 409

def amount_tax_display
  @amount_tax_display
end

#pdfObject

Invoice pdf rendering options



411
412
413
# File 'lib/stripe/params/invoice_create_params.rb', line 411

def pdf
  @pdf
end

#templateObject

ID of the invoice rendering template to use for this invoice.



413
414
415
# File 'lib/stripe/params/invoice_create_params.rb', line 413

def template
  @template
end

#template_versionObject

The specific version of invoice rendering template to use for this invoice.



415
416
417
# File 'lib/stripe/params/invoice_create_params.rb', line 415

def template_version
  @template_version
end