Class: Stripe::InvoiceCreateParams::ShippingCost::ShippingRateData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_params.rb

Defined Under Namespace

Classes: DeliveryEstimate, FixedAmount

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(delivery_estimate: nil, display_name: nil, fixed_amount: nil, metadata: nil, tax_behavior: nil, tax_code: nil, type: nil) ⇒ ShippingRateData

Returns a new instance of ShippingRateData.



502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
# File 'lib/stripe/params/invoice_create_params.rb', line 502

def initialize(
  delivery_estimate: nil,
  display_name: nil,
  fixed_amount: nil,
  metadata: nil,
  tax_behavior: nil,
  tax_code: nil,
  type: nil
)
  @delivery_estimate = delivery_estimate
  @display_name = display_name
  @fixed_amount = fixed_amount
  @metadata = 
  @tax_behavior = tax_behavior
  @tax_code = tax_code
  @type = type
end

Instance Attribute Details

#delivery_estimateObject

The estimated range for how long shipping will take, meant to be displayable to the customer. This will appear on CheckoutSessions.



488
489
490
# File 'lib/stripe/params/invoice_create_params.rb', line 488

def delivery_estimate
  @delivery_estimate
end

#display_nameObject

The name of the shipping rate, meant to be displayable to the customer. This will appear on CheckoutSessions.



490
491
492
# File 'lib/stripe/params/invoice_create_params.rb', line 490

def display_name
  @display_name
end

#fixed_amountObject

Describes a fixed amount to charge for shipping. Must be present if type is ‘fixed_amount`.



492
493
494
# File 'lib/stripe/params/invoice_create_params.rb', line 492

def fixed_amount
  @fixed_amount
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



494
495
496
# File 'lib/stripe/params/invoice_create_params.rb', line 494

def 
  @metadata
end

#tax_behaviorObject

Specifies whether the rate is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`.



496
497
498
# File 'lib/stripe/params/invoice_create_params.rb', line 496

def tax_behavior
  @tax_behavior
end

#tax_codeObject

A [tax code](docs.stripe.com/tax/tax-categories) ID. The Shipping tax code is ‘txcd_92010001`.



498
499
500
# File 'lib/stripe/params/invoice_create_params.rb', line 498

def tax_code
  @tax_code
end

#typeObject

The type of calculation to use on the shipping rate.



500
501
502
# File 'lib/stripe/params/invoice_create_params.rb', line 500

def type
  @type
end