Class: Stripe::InvoiceCreateParams::ShippingCost::ShippingRateData::FixedAmount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreateParams::ShippingCost::ShippingRateData::FixedAmount
- Defined in:
- lib/stripe/params/invoice_create_params.rb
Defined Under Namespace
Classes: CurrencyOptions
Instance Attribute Summary collapse
-
#amount ⇒ Object
A non-negative integer in cents representing how much to charge.
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#currency_options ⇒ Object
Shipping rates defined in each available currency option.
Instance Method Summary collapse
-
#initialize(amount: nil, currency: nil, currency_options: nil) ⇒ FixedAmount
constructor
A new instance of FixedAmount.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, currency: nil, currency_options: nil) ⇒ FixedAmount
Returns a new instance of FixedAmount.
448 449 450 451 452 |
# File 'lib/stripe/params/invoice_create_params.rb', line 448 def initialize(amount: nil, currency: nil, currency_options: nil) @amount = amount @currency = currency @currency_options = end |
Instance Attribute Details
#amount ⇒ Object
A non-negative integer in cents representing how much to charge.
442 443 444 |
# File 'lib/stripe/params/invoice_create_params.rb', line 442 def amount @amount end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
444 445 446 |
# File 'lib/stripe/params/invoice_create_params.rb', line 444 def currency @currency end |
#currency_options ⇒ Object
Shipping rates defined in each available currency option. Each key must be a three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html) and a [supported currency](stripe.com/docs/currencies).
446 447 448 |
# File 'lib/stripe/params/invoice_create_params.rb', line 446 def @currency_options end |