Class: Stripe::InvoiceCreateParams::TransferData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreateParams::TransferData
- Defined in:
- lib/stripe/params/invoice_create_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount that will be transferred automatically when the invoice is paid.
-
#destination ⇒ Object
ID of an existing, connected Stripe account.
Instance Method Summary collapse
-
#initialize(amount: nil, destination: nil) ⇒ TransferData
constructor
A new instance of TransferData.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, destination: nil) ⇒ TransferData
Returns a new instance of TransferData.
587 588 589 590 |
# File 'lib/stripe/params/invoice_create_params.rb', line 587 def initialize(amount: nil, destination: nil) @amount = amount @destination = destination end |
Instance Attribute Details
#amount ⇒ Object
The amount that will be transferred automatically when the invoice is paid. If no amount is set, the full amount is transferred.
583 584 585 |
# File 'lib/stripe/params/invoice_create_params.rb', line 583 def amount @amount end |
#destination ⇒ Object
ID of an existing, connected Stripe account.
585 586 587 |
# File 'lib/stripe/params/invoice_create_params.rb', line 585 def destination @destination end |