Class: Stripe::InvoiceCreatePreviewParams::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



181
182
183
184
185
186
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 181

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



173
174
175
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 173

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



175
176
177
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 175

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



177
178
179
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 177

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



179
180
181
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 179

def promotion_code
  @promotion_code
end