Class: Stripe::InvoiceCreatePreviewParams::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



166
167
168
169
170
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 166

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



160
161
162
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 160

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



162
163
164
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 162

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



164
165
166
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 164

def type
  @type
end