Class: Stripe::InvoiceCreatePreviewParams::Discount::Settings::ServicePeriodAnchorConfig::Custom
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::Discount::Settings::ServicePeriodAnchorConfig::Custom
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Instance Attribute Summary collapse
-
#day_of_month ⇒ Object
The day of the month the anchor should be.
-
#hour ⇒ Object
The hour of the day the anchor should be.
-
#minute ⇒ Object
The minute of the hour the anchor should be.
-
#month ⇒ Object
The month to start full cycle periods.
-
#second ⇒ Object
The second of the minute the anchor should be.
Instance Method Summary collapse
-
#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom
constructor
A new instance of Custom.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom
Returns a new instance of Custom.
187 188 189 190 191 192 193 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 187 def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) @day_of_month = day_of_month @hour = hour @minute = minute @month = month @second = second end |
Instance Attribute Details
#day_of_month ⇒ Object
The day of the month the anchor should be. Ranges from 1 to 31.
177 178 179 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 177 def day_of_month @day_of_month end |
#hour ⇒ Object
The hour of the day the anchor should be. Ranges from 0 to 23.
179 180 181 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 179 def hour @hour end |
#minute ⇒ Object
The minute of the hour the anchor should be. Ranges from 0 to 59.
181 182 183 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 181 def minute @minute end |
#month ⇒ Object
The month to start full cycle periods. Ranges from 1 to 12.
183 184 185 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 183 def month @month end |
#second ⇒ Object
The second of the minute the anchor should be. Ranges from 0 to 59.
185 186 187 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 185 def second @second end |