Class: Stripe::InvoiceCreatePreviewParams::InvoiceItem::Period
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::InvoiceItem::Period
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Instance Attribute Summary collapse
-
#end ⇒ Object
The end of the period, which must be greater than or equal to the start.
-
#start ⇒ Object
The start of the period.
Instance Method Summary collapse
-
#initialize(end_: nil, start: nil) ⇒ Period
constructor
A new instance of Period.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(end_: nil, start: nil) ⇒ Period
Returns a new instance of Period.
239 240 241 242 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 239 def initialize(end_: nil, start: nil) @end = end_ @start = start end |
Instance Attribute Details
#end ⇒ Object
The end of the period, which must be greater than or equal to the start. This value is inclusive.
235 236 237 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 235 def end @end end |
#start ⇒ Object
The start of the period. This value is inclusive.
237 238 239 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 237 def start @start end |