Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: AmendmentEnd, AmendmentStart, BillingSchedulesAction, DiscountAction, ItemAction, MetadataAction, SetPauseCollection, TrialSettings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amendment_end: nil, amendment_start: nil, billing_cycle_anchor: nil, billing_schedules_actions: nil, discount_actions: nil, effective_at: nil, item_actions: nil, metadata_actions: nil, proration_behavior: nil, set_pause_collection: nil, set_schedule_end: nil, trial_settings: nil) ⇒ Amendment

Returns a new instance of Amendment.



1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
1109
1110
1111
1112
1113
1114
1115
1116
1117
1118
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1092

def initialize(
  amendment_end: nil,
  amendment_start: nil,
  billing_cycle_anchor: nil,
  billing_schedules_actions: nil,
  discount_actions: nil,
  effective_at: nil,
  item_actions: nil,
  metadata_actions: nil,
  proration_behavior: nil,
  set_pause_collection: nil,
  set_schedule_end: nil,
  trial_settings: nil
)
  @amendment_end = amendment_end
  @amendment_start = amendment_start
  @billing_cycle_anchor = billing_cycle_anchor
  @billing_schedules_actions = billing_schedules_actions
  @discount_actions = discount_actions
  @effective_at = effective_at
  @item_actions = item_actions
  @metadata_actions = 
  @proration_behavior = proration_behavior
  @set_pause_collection = set_pause_collection
  @set_schedule_end = set_schedule_end
  @trial_settings = trial_settings
end

Instance Attribute Details

#amendment_endObject

Details to identify the end of the time range modified by the proposed change. If not supplied, the amendment is considered a point-in-time operation that only affects the exact timestamp at ‘amendment_start`, and a restricted set of attributes is supported on the amendment.



1068
1069
1070
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1068

def amendment_end
  @amendment_end
end

#amendment_startObject

Details to identify the earliest timestamp where the proposed change should take effect.



1070
1071
1072
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1070

def amendment_start
  @amendment_start
end

#billing_cycle_anchorObject

For point-in-time amendments (having no ‘amendment_end`), this attribute lets you set or remove whether the subscription’s billing cycle anchor is reset at the ‘amendment_start` timestamp.For time-span based amendments (having both `amendment_start` and `amendment_end`), the only value valid is `automatic`, which removes any previously configured billing cycle anchor resets scheduled to occur during the window of time spanned by the amendment.



1072
1073
1074
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1072

def billing_cycle_anchor
  @billing_cycle_anchor
end

#billing_schedules_actionsObject

Actions to apply to the billing schedules.



1074
1075
1076
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1074

def billing_schedules_actions
  @billing_schedules_actions
end

#discount_actionsObject

Changes to the coupons being redeemed or discounts being applied during the amendment time span.



1076
1077
1078
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1076

def discount_actions
  @discount_actions
end

#effective_atObject

Configures how the subscription schedule handles billing for phase transitions.



1078
1079
1080
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1078

def effective_at
  @effective_at
end

#item_actionsObject

Changes to the subscription items during the amendment time span.



1080
1081
1082
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1080

def item_actions
  @item_actions
end

#metadata_actionsObject

Instructions for how to modify phase metadata



1082
1083
1084
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1082

def 
  @metadata_actions
end

#proration_behaviorObject

Changes to how Stripe handles prorations during the amendment time span. Affects if and how prorations are created when a future phase starts. In cases where the amendment changes the currently active phase, it is used to determine whether or how to prorate now, at the time of the request. Also supported as a point-in-time operation when ‘amendment_end` is `null`.



1084
1085
1086
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1084

def proration_behavior
  @proration_behavior
end

#set_pause_collectionObject

Defines how to pause collection for the underlying subscription throughout the duration of the amendment.



1086
1087
1088
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1086

def set_pause_collection
  @set_pause_collection
end

#set_schedule_endObject

Ends the subscription schedule early as dictated by either the accompanying amendment’s start or end.



1088
1089
1090
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1088

def set_schedule_end
  @set_schedule_end
end

#trial_settingsObject

Settings related to subscription trials.



1090
1091
1092
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1090

def trial_settings
  @trial_settings
end