Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::AmendmentEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: DiscountEnd, Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ AmendmentEnd

Returns a new instance of AmendmentEnd.



401
402
403
404
405
406
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 401

def initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil)
  @discount_end = discount_end
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#discount_endObject

Use the end time of a given discount.



393
394
395
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 393

def discount_end
  @discount_end
end

#durationObject

Time span for the amendment starting from the amendment_start.



395
396
397
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 395

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the amendment to end. Must be after the amendment_start.



397
398
399
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 397

def timestamp
  @timestamp
end

#typeObject

Select one of three ways to pass the amendment_end.



399
400
401
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 399

def type
  @type
end