Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::AmendmentStart

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: AmendmentEnd, DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amendment_end: nil, discount_end: nil, timestamp: nil, type: nil) ⇒ AmendmentStart

Returns a new instance of AmendmentStart.



488
489
490
491
492
493
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 488

def initialize(amendment_end: nil, discount_end: nil, timestamp: nil, type: nil)
  @amendment_end = amendment_end
  @discount_end = discount_end
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#amendment_endObject

Details of another amendment in the same array, immediately after which this amendment should begin.



480
481
482
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 480

def amendment_end
  @amendment_end
end

#discount_endObject

Use the ‘end` time of a given discount.



482
483
484
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 482

def discount_end
  @discount_end
end

#timestampObject

A precise Unix timestamp for the amendment to start.



484
485
486
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 484

def timestamp
  @timestamp
end

#typeObject

Select one of three ways to pass the ‘amendment_start`.



486
487
488
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 486

def type
  @type
end