Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::BillingSchedulesAction
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::BillingSchedulesAction
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Defined Under Namespace
Classes: AppliesTo
Instance Attribute Summary collapse
-
#applies_to ⇒ Object
Specify which subscription items the billing schedule applies to.
-
#type ⇒ Object
Select the action.
Instance Method Summary collapse
-
#initialize(applies_to: nil, type: nil) ⇒ BillingSchedulesAction
constructor
A new instance of BillingSchedulesAction.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(applies_to: nil, type: nil) ⇒ BillingSchedulesAction
Returns a new instance of BillingSchedulesAction.
513 514 515 516 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 513 def initialize(applies_to: nil, type: nil) @applies_to = applies_to @type = type end |
Instance Attribute Details
#applies_to ⇒ Object
Specify which subscription items the billing schedule applies to.
509 510 511 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 509 def applies_to @applies_to end |
#type ⇒ Object
Select the action.
511 512 513 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 511 def type @type end |