Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::BillingSchedulesAction::AppliesTo
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::BillingSchedulesAction::AppliesTo
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Instance Attribute Summary collapse
-
#price ⇒ Object
The ID of the price object.
-
#type ⇒ Object
Controls which subscription items the billing schedule applies to.
Instance Method Summary collapse
-
#initialize(price: nil, type: nil) ⇒ AppliesTo
constructor
A new instance of AppliesTo.
Methods inherited from RequestParams
Constructor Details
#initialize(price: nil, type: nil) ⇒ AppliesTo
Returns a new instance of AppliesTo.
487 488 489 490 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 487 def initialize(price: nil, type: nil) @price = price @type = type end |
Instance Attribute Details
#price ⇒ Object
The ID of the price object.
483 484 485 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 483 def price @price end |
#type ⇒ Object
Controls which subscription items the billing schedule applies to.
485 486 487 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 485 def type @type end |