Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::DiscountAction
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::DiscountAction
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#add ⇒ Object
Details of the discount to add.
-
#remove ⇒ Object
Details of the discount to remove.
-
#set ⇒ Object
Details of the discount to replace the existing discounts with.
-
#type ⇒ Object
Determines the type of discount action.
Instance Method Summary collapse
-
#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ DiscountAction
constructor
A new instance of DiscountAction.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ DiscountAction
Returns a new instance of DiscountAction.
518 519 520 521 522 523 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 518 def initialize(add: nil, remove: nil, set: nil, type: nil) @add = add @remove = remove @set = set @type = type end |
Instance Attribute Details
#add ⇒ Object
Details of the discount to add.
510 511 512 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 510 def add @add end |
#remove ⇒ Object
Details of the discount to remove.
512 513 514 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 512 def remove @remove end |
#set ⇒ Object
Details of the discount to replace the existing discounts with.
514 515 516 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 514 def set @set end |
#type ⇒ Object
Determines the type of discount action.
516 517 518 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 516 def type @type end |