Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::DiscountAction::Add::Settings::ServicePeriodAnchorConfig::Custom

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom

Returns a new instance of Custom.



528
529
530
531
532
533
534
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 528

def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil)
  @day_of_month = day_of_month
  @hour = hour
  @minute = minute
  @month = month
  @second = second
end

Instance Attribute Details

#day_of_monthObject

The day of the month the anchor should be. Ranges from 1 to 31.



518
519
520
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 518

def day_of_month
  @day_of_month
end

#hourObject

The hour of the day the anchor should be. Ranges from 0 to 23.



520
521
522
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 520

def hour
  @hour
end

#minuteObject

The minute of the hour the anchor should be. Ranges from 0 to 59.



522
523
524
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 522

def minute
  @minute
end

#monthObject

The month to start full cycle periods. Ranges from 1 to 12.



524
525
526
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 524

def month
  @month
end

#secondObject

The second of the minute the anchor should be. Ranges from 0 to 59.



526
527
528
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 526

def second
  @second
end