Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::DiscountAction::Set

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Set

Returns a new instance of Set.



503
504
505
506
507
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 503

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to replace the ‘discounts` array with.



497
498
499
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 497

def coupon
  @coupon
end

#discountObject

An ID of an existing discount to replace the ‘discounts` array with.



499
500
501
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 499

def discount
  @discount
end

#promotion_codeObject

An ID of an existing promotion code to replace the ‘discounts` array with.



501
502
503
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 501

def promotion_code
  @promotion_code
end