Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::DiscountAction::Set::Settings::ServicePeriodAnchorConfig::Custom

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom

Returns a new instance of Custom.



632
633
634
635
636
637
638
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 632

def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil)
  @day_of_month = day_of_month
  @hour = hour
  @minute = minute
  @month = month
  @second = second
end

Instance Attribute Details

#day_of_monthObject

The day of the month the anchor should be. Ranges from 1 to 31.



622
623
624
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 622

def day_of_month
  @day_of_month
end

#hourObject

The hour of the day the anchor should be. Ranges from 0 to 23.



624
625
626
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 624

def hour
  @hour
end

#minuteObject

The minute of the hour the anchor should be. Ranges from 0 to 59.



626
627
628
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 626

def minute
  @minute
end

#monthObject

The month to start full cycle periods. Ranges from 1 to 12.



628
629
630
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 628

def month
  @month
end

#secondObject

The second of the minute the anchor should be. Ranges from 0 to 59.



630
631
632
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 630

def second
  @second
end