Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Add::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



715
716
717
718
719
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 715

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



709
710
711
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 709

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



711
712
713
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 711

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



713
714
715
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 713

def type
  @type
end