Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Add::Discount::Settings::ServicePeriodAnchorConfig::Custom

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom

Returns a new instance of Custom.



736
737
738
739
740
741
742
743
744
745
746
747
748
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 736

def initialize(
  day_of_month: nil,
  hour: nil,
  minute: nil,
  month: nil,
  second: nil
)
  @day_of_month = day_of_month
  @hour = hour
  @minute = minute
  @month = month
  @second = second
end

Instance Attribute Details

#day_of_monthObject

The day of the month the anchor should be. Ranges from 1 to 31.



726
727
728
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 726

def day_of_month
  @day_of_month
end

#hourObject

The hour of the day the anchor should be. Ranges from 0 to 23.



728
729
730
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 728

def hour
  @hour
end

#minuteObject

The minute of the hour the anchor should be. Ranges from 0 to 59.



730
731
732
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 730

def minute
  @minute
end

#monthObject

The month to start full cycle periods. Ranges from 1 to 12.



732
733
734
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 732

def month
  @month
end

#secondObject

The second of the minute the anchor should be. Ranges from 0 to 59.



734
735
736
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 734

def second
  @second
end