Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Set

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: Discount, Trial

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil) ⇒ Set

Returns a new instance of Set.



978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 978

def initialize(
  discounts: nil,
  metadata: nil,
  price: nil,
  quantity: nil,
  tax_rates: nil,
  trial: nil,
  trial_offer: nil
)
  @discounts = discounts
  @metadata = 
  @price = price
  @quantity = quantity
  @tax_rates = tax_rates
  @trial = trial
  @trial_offer = trial_offer
end

Instance Attribute Details

#discountsObject

If an item with the price already exists, passing this will override the discounts array on the subscription item that matches that price. Otherwise, the items array is cleared and a single new item is added with the supplied discounts.



964
965
966
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 964

def discounts
  @discounts
end

#metadataObject

If an item with the price already exists, passing this will override the metadata on the subscription item that matches that price. Otherwise, the items array is cleared and a single new item is added with the supplied metadata.



966
967
968
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 966

def 
  @metadata
end

#priceObject

The ID of the price object.



968
969
970
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 968

def price
  @price
end

#quantityObject

If an item with the price already exists, passing this will override the quantity on the subscription item that matches that price. Otherwise, the items array is cleared and a single new item is added with the supplied quantity.



970
971
972
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 970

def quantity
  @quantity
end

#tax_ratesObject

If an item with the price already exists, passing this will override the tax_rates array on the subscription item that matches that price. Otherwise, the items array is cleared and a single new item is added with the supplied tax_rates.



972
973
974
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 972

def tax_rates
  @tax_rates
end

#trialObject

If an item with the price already exists, passing this will override the trial configuration on the subscription item that matches that price. Otherwise, the items array is cleared and a single new item is added with the supplied trial.



974
975
976
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 974

def trial
  @trial
end

#trial_offerObject

The ID of the trial offer to apply to the configuration item.



976
977
978
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 976

def trial_offer
  @trial_offer
end