Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Set::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



871
872
873
874
875
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 871

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



865
866
867
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 865

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



867
868
869
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 867

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



869
870
871
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 869

def type
  @type
end