Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::SetPauseCollection::Set
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::SetPauseCollection::Set
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Instance Attribute Summary collapse
-
#behavior ⇒ Object
The payment collection behavior for this subscription while paused.
Instance Method Summary collapse
-
#initialize(behavior: nil) ⇒ Set
constructor
A new instance of Set.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(behavior: nil) ⇒ Set
Returns a new instance of Set.
753 754 755 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 753 def initialize(behavior: nil) @behavior = behavior end |
Instance Attribute Details
#behavior ⇒ Object
The payment collection behavior for this subscription while paused.
751 752 753 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 751 def behavior @behavior end |