Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::BillingSchedule

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: AppliesTo, BillUntil

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(applies_to: nil, bill_until: nil, key: nil) ⇒ BillingSchedule

Returns a new instance of BillingSchedule.



1186
1187
1188
1189
1190
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1186

def initialize(applies_to: nil, bill_until: nil, key: nil)
  @applies_to = applies_to
  @bill_until = bill_until
  @key = key
end

Instance Attribute Details

#applies_toObject

Configure billing schedule differently for individual subscription items.



1180
1181
1182
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1180

def applies_to
  @applies_to
end

#bill_untilObject

The end date for the billing schedule.



1182
1183
1184
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1182

def bill_until
  @bill_until
end

#keyObject

Specify a key for the billing schedule. Must be unique to this field, alphanumeric, and up to 200 characters. If not provided, a unique key will be generated.



1184
1185
1186
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1184

def key
  @key
end