Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::BillingSchedule::BillUntil
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::ScheduleDetails::BillingSchedule::BillUntil
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Specifies the billing period.
-
#timestamp ⇒ Object
The end date of the billing schedule.
-
#type ⇒ Object
Describes how the billing schedule will determine the end date.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ BillUntil
constructor
A new instance of BillUntil.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ BillUntil
Returns a new instance of BillUntil.
1173 1174 1175 1176 1177 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1173 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Specifies the billing period.
1167 1168 1169 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1167 def duration @duration end |
#timestamp ⇒ Object
The end date of the billing schedule.
1169 1170 1171 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1169 def @timestamp end |
#type ⇒ Object
Describes how the billing schedule will determine the end date. Either ‘duration` or `timestamp`.
1171 1172 1173 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1171 def type @type end |