Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::DefaultSettings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::ScheduleDetails::DefaultSettings
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Instance Attribute Summary collapse
-
#phase_effective_at ⇒ Object
Configures how the subscription schedule handles billing for phase transitions.
Instance Method Summary collapse
-
#initialize(phase_effective_at: nil) ⇒ DefaultSettings
constructor
A new instance of DefaultSettings.
Methods inherited from RequestParams
Constructor Details
#initialize(phase_effective_at: nil) ⇒ DefaultSettings
Returns a new instance of DefaultSettings.
1181 1182 1183 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1181 def initialize(phase_effective_at: nil) @phase_effective_at = phase_effective_at end |
Instance Attribute Details
#phase_effective_at ⇒ Object
Configures how the subscription schedule handles billing for phase transitions.
1179 1180 1181 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1179 def phase_effective_at @phase_effective_at end |