Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::AddInvoiceItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::AddInvoiceItem
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Defined Under Namespace
Classes: Discount, Period, PriceData
Instance Attribute Summary collapse
-
#discounts ⇒ Object
The coupons to redeem into discounts for the item.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#period ⇒ Object
The period associated with this invoice item.
-
#price ⇒ Object
The ID of the price object.
-
#price_data ⇒ Object
Data used to generate a new [Price](docs.stripe.com/api/prices) object inline.
-
#quantity ⇒ Object
Quantity for this item.
-
#tax_rates ⇒ Object
The tax rates which apply to the item.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(discounts: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ AddInvoiceItem
constructor
A new instance of AddInvoiceItem.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(discounts: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ AddInvoiceItem
Returns a new instance of AddInvoiceItem.
431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 431 def initialize( discounts: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil ) @discounts = discounts = @period = period @price = price @price_data = price_data @quantity = quantity @tax_rates = tax_rates end |
Instance Attribute Details
#discounts ⇒ Object
The coupons to redeem into discounts for the item.
417 418 419 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 417 def discounts @discounts end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
419 420 421 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 419 def end |
#period ⇒ Object
The period associated with this invoice item. If not set, period.start.type defaults to max_item_period_start and period.end.type defaults to min_item_period_end.
421 422 423 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 421 def period @period end |
#price ⇒ Object
The ID of the price object. One of price or price_data is required.
423 424 425 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 423 def price @price end |
#price_data ⇒ Object
Data used to generate a new [Price](docs.stripe.com/api/prices) object inline. One of price or price_data is required.
425 426 427 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 425 def price_data @price_data end |
#quantity ⇒ Object
Quantity for this item. Defaults to 1.
427 428 429 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 427 def quantity @quantity end |
#tax_rates ⇒ Object
The tax rates which apply to the item. When set, the default_tax_rates do not apply to this item.
429 430 431 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 429 def tax_rates @tax_rates end |
Class Method Details
.field_encodings ⇒ Object
449 450 451 452 453 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 449 def self.field_encodings @field_encodings = { price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } }, } end |