Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::AddInvoiceItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



1224
1225
1226
1227
1228
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1224

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



1218
1219
1220
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1218

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



1220
1221
1222
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1220

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



1222
1223
1224
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1222

def type
  @type
end