Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::AddInvoiceItem::Period::End

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(timestamp: nil, type: nil) ⇒ End

Returns a new instance of End.



902
903
904
905
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 902

def initialize(timestamp: nil, type: nil)
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#timestampObject

A precise Unix timestamp for the end of the invoice item period. Must be greater than or equal to ‘period.start`.



898
899
900
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 898

def timestamp
  @timestamp
end

#typeObject

Select how to calculate the end of the invoice item period.



900
901
902
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 900

def type
  @type
end