Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::AddInvoiceItem::Period::Start

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(timestamp: nil, type: nil) ⇒ Start

Returns a new instance of Start.



1266
1267
1268
1269
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1266

def initialize(timestamp: nil, type: nil)
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#timestampObject

A precise Unix timestamp for the start of the invoice item period. Must be less than or equal to ‘period.end`.



1262
1263
1264
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1262

def timestamp
  @timestamp
end

#typeObject

Select how to calculate the start of the invoice item period.



1264
1265
1266
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1264

def type
  @type
end