Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



1055
1056
1057
1058
1059
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1055

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



1049
1050
1051
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1049

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



1051
1052
1053
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1051

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



1053
1054
1055
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1053

def type
  @type
end