Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::Discount::DiscountEnd::Duration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(interval: nil, interval_count: nil) ⇒ Duration

Returns a new instance of Duration.



1395
1396
1397
1398
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1395

def initialize(interval: nil, interval_count: nil)
  @interval = interval
  @interval_count = interval_count
end

Instance Attribute Details

#intervalObject

Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.



1391
1392
1393
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1391

def interval
  @interval
end

#interval_countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



1393
1394
1395
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1393

def interval_count
  @interval_count
end