Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::Discount::Settings::ServicePeriodAnchorConfig::Custom

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom

Returns a new instance of Custom.



1432
1433
1434
1435
1436
1437
1438
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1432

def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil)
  @day_of_month = day_of_month
  @hour = hour
  @minute = minute
  @month = month
  @second = second
end

Instance Attribute Details

#day_of_monthObject

The day of the month the anchor should be. Ranges from 1 to 31.



1422
1423
1424
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1422

def day_of_month
  @day_of_month
end

#hourObject

The hour of the day the anchor should be. Ranges from 0 to 23.



1424
1425
1426
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1424

def hour
  @hour
end

#minuteObject

The minute of the hour the anchor should be. Ranges from 0 to 59.



1426
1427
1428
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1426

def minute
  @minute
end

#monthObject

The month to start full cycle periods. Ranges from 1 to 12.



1428
1429
1430
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1428

def month
  @month
end

#secondObject

The second of the minute the anchor should be. Ranges from 0 to 59.



1430
1431
1432
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1430

def second
  @second
end