Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::InvoiceSettings

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: Issuer

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(account_tax_ids: nil, days_until_due: nil, issuer: nil) ⇒ InvoiceSettings

Returns a new instance of InvoiceSettings.



1109
1110
1111
1112
1113
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1109

def initialize(account_tax_ids: nil, days_until_due: nil, issuer: nil)
  @account_tax_ids = 
  @days_until_due = days_until_due
  @issuer = issuer
end

Instance Attribute Details

#account_tax_idsObject

The account tax IDs associated with this phase of the subscription schedule. Will be set on invoices generated by this phase of the subscription schedule.



1103
1104
1105
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1103

def 
  @account_tax_ids
end

#days_until_dueObject

Number of days within which a customer must pay invoices generated by this subscription schedule. This value will be ‘null` for subscription schedules where `billing=charge_automatically`.



1105
1106
1107
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1105

def days_until_due
  @days_until_due
end

#issuerObject

The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.



1107
1108
1109
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1107

def issuer
  @issuer
end