Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::Item::BillingThresholds

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(usage_gte: nil) ⇒ BillingThresholds

Returns a new instance of BillingThresholds.



1087
1088
1089
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1087

def initialize(usage_gte: nil)
  @usage_gte = usage_gte
end

Instance Attribute Details

#usage_gteObject

Number of units that meets the billing threshold to advance the subscription to a new billing period (e.g., it takes 10 $5 units to meet a $50 [monetary threshold](docs.stripe.com/api/subscriptions/update#update_subscription-billing_thresholds-amount_gte))



1085
1086
1087
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1085

def usage_gte
  @usage_gte
end