Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::Item::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::Item::Discount
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Defined Under Namespace
Classes: DiscountEnd, Settings
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
-
#settings ⇒ Object
Settings for discount application including service period anchoring.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil, settings: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil, settings: nil) ⇒ Discount
Returns a new instance of Discount.
1610 1611 1612 1613 1614 1615 1616 1617 1618 1619 1620 1621 1622 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1610 def initialize( coupon: nil, discount: nil, discount_end: nil, promotion_code: nil, settings: nil ) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code @settings = settings end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
1600 1601 1602 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1600 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
1602 1603 1604 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1602 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
1604 1605 1606 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1604 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
1606 1607 1608 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1606 def promotion_code @promotion_code end |
#settings ⇒ Object
Settings for discount application including service period anchoring.
1608 1609 1610 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1608 def settings @settings end |