Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::Item::Discount::Settings::ServicePeriodAnchorConfig::Custom
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::Item::Discount::Settings::ServicePeriodAnchorConfig::Custom
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Instance Attribute Summary collapse
-
#day_of_month ⇒ Object
The day of the month the anchor should be.
-
#hour ⇒ Object
The hour of the day the anchor should be.
-
#minute ⇒ Object
The minute of the hour the anchor should be.
-
#month ⇒ Object
The month to start full cycle periods.
-
#second ⇒ Object
The second of the minute the anchor should be.
Instance Method Summary collapse
-
#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom
constructor
A new instance of Custom.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom
Returns a new instance of Custom.
1575 1576 1577 1578 1579 1580 1581 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1575 def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) @day_of_month = day_of_month @hour = hour @minute = minute @month = month @second = second end |
Instance Attribute Details
#day_of_month ⇒ Object
The day of the month the anchor should be. Ranges from 1 to 31.
1565 1566 1567 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1565 def day_of_month @day_of_month end |
#hour ⇒ Object
The hour of the day the anchor should be. Ranges from 0 to 23.
1567 1568 1569 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1567 def hour @hour end |
#minute ⇒ Object
The minute of the hour the anchor should be. Ranges from 0 to 59.
1569 1570 1571 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1569 def minute @minute end |
#month ⇒ Object
The month to start full cycle periods. Ranges from 1 to 12.
1571 1572 1573 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1571 def month @month end |
#second ⇒ Object
The second of the minute the anchor should be. Ranges from 0 to 59.
1573 1574 1575 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1573 def second @second end |