Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::Item::PriceData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: Recurring

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(currency: nil, product: nil, recurring: nil, tax_behavior: nil, unit_amount: nil, unit_amount_decimal: nil) ⇒ PriceData

Returns a new instance of PriceData.



1654
1655
1656
1657
1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1654

def initialize(
  currency: nil,
  product: nil,
  recurring: nil,
  tax_behavior: nil,
  unit_amount: nil,
  unit_amount_decimal: nil
)
  @currency = currency
  @product = product
  @recurring = recurring
  @tax_behavior = tax_behavior
  @unit_amount = unit_amount
  @unit_amount_decimal = unit_amount_decimal
end

Instance Attribute Details

#currencyObject

Three-letter ISO currency code, in lowercase. Must be a supported currency.



1642
1643
1644
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1642

def currency
  @currency
end

#productObject

The ID of the Product that this Price will belong to.



1644
1645
1646
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1644

def product
  @product
end

#recurringObject

The recurring components of a price such as interval and interval_count.



1646
1647
1648
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1646

def recurring
  @recurring
end

#tax_behaviorObject

Only required if a default tax behavior was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One of inclusive, exclusive, or unspecified. Once specified as either inclusive or exclusive, it cannot be changed.



1648
1649
1650
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1648

def tax_behavior
  @tax_behavior
end

#unit_amountObject

A positive integer in cents (or local equivalent) (or 0 for a free price) representing how much to charge.



1650
1651
1652
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1650

def unit_amount
  @unit_amount
end

#unit_amount_decimalObject

Same as unit_amount, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places. Only one of unit_amount and unit_amount_decimal can be set.



1652
1653
1654
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1652

def unit_amount_decimal
  @unit_amount_decimal
end

Class Method Details

.field_encodingsObject



1670
1671
1672
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1670

def self.field_encodings
  @field_encodings = { unit_amount_decimal: :decimal_string }
end