Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::Item::Trial
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::Item::Trial
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Instance Attribute Summary collapse
-
#converts_to ⇒ Object
List of price IDs which, if present on the subscription following a paid trial, constitute opting-in to the paid trial.
-
#type ⇒ Object
Determines the type of trial for this item.
Instance Method Summary collapse
-
#initialize(converts_to: nil, type: nil) ⇒ Trial
constructor
A new instance of Trial.
Methods inherited from RequestParams
Constructor Details
#initialize(converts_to: nil, type: nil) ⇒ Trial
Returns a new instance of Trial.
1647 1648 1649 1650 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1647 def initialize(converts_to: nil, type: nil) @converts_to = converts_to @type = type end |
Instance Attribute Details
#converts_to ⇒ Object
List of price IDs which, if present on the subscription following a paid trial, constitute opting-in to the paid trial. Currently only supports at most 1 price ID.
1643 1644 1645 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1643 def converts_to @converts_to end |
#type ⇒ Object
Determines the type of trial for this item.
1645 1646 1647 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1645 def type @type end |