Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::PauseCollection
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::PauseCollection
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Instance Attribute Summary collapse
-
#behavior ⇒ Object
The payment collection behavior for this subscription while paused.
Instance Method Summary collapse
-
#initialize(behavior: nil) ⇒ PauseCollection
constructor
A new instance of PauseCollection.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(behavior: nil) ⇒ PauseCollection
Returns a new instance of PauseCollection.
1282 1283 1284 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1282 def initialize(behavior: nil) @behavior = behavior end |
Instance Attribute Details
#behavior ⇒ Object
The payment collection behavior for this subscription while paused.
1280 1281 1282 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1280 def behavior @behavior end |