Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount_percent: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



1753
1754
1755
1756
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1753

def initialize(amount_percent: nil, destination: nil)
  @amount_percent = amount_percent
  @destination = destination
end

Instance Attribute Details

#amount_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination.



1749
1750
1751
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1749

def amount_percent
  @amount_percent
end

#destinationObject

ID of an existing, connected Stripe account.



1751
1752
1753
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1751

def destination
  @destination
end