Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::TrialSettings::EndBehavior
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::TrialSettings::EndBehavior
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Instance Attribute Summary collapse
-
#prorate_up_front ⇒ Object
Configure how an opt-in following a paid trial is billed when using ‘billing_behavior: prorate_up_front`.
Instance Method Summary collapse
-
#initialize(prorate_up_front: nil) ⇒ EndBehavior
constructor
A new instance of EndBehavior.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(prorate_up_front: nil) ⇒ EndBehavior
Returns a new instance of EndBehavior.
1304 1305 1306 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1304 def initialize(prorate_up_front: nil) @prorate_up_front = prorate_up_front end |
Instance Attribute Details
#prorate_up_front ⇒ Object
Configure how an opt-in following a paid trial is billed when using ‘billing_behavior: prorate_up_front`.
1302 1303 1304 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1302 def prorate_up_front @prorate_up_front end |