Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Prebilling::BillUntil
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Prebilling::BillUntil
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Defined Under Namespace
Classes: AmendmentEnd, Duration
Instance Attribute Summary collapse
-
#amendment_end ⇒ Object
End the prebilled period when a specified amendment ends.
-
#duration ⇒ Object
Time span for prebilling, starting from ‘bill_from`.
-
#timestamp ⇒ Object
End the prebilled period at a precise integer timestamp, starting from the Unix epoch.
-
#type ⇒ Object
Select one of several ways to pass the ‘bill_until` value.
Instance Method Summary collapse
-
#initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ BillUntil
constructor
A new instance of BillUntil.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ BillUntil
Returns a new instance of BillUntil.
1939 1940 1941 1942 1943 1944 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1939 def initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil) @amendment_end = amendment_end @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#amendment_end ⇒ Object
End the prebilled period when a specified amendment ends.
1931 1932 1933 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1931 def amendment_end @amendment_end end |
#duration ⇒ Object
Time span for prebilling, starting from ‘bill_from`.
1933 1934 1935 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1933 def duration @duration end |
#timestamp ⇒ Object
End the prebilled period at a precise integer timestamp, starting from the Unix epoch.
1935 1936 1937 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1935 def @timestamp end |
#type ⇒ Object
Select one of several ways to pass the ‘bill_until` value.
1937 1938 1939 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1937 def type @type end |