Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Prebilling::BillUntil::Duration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(interval: nil, interval_count: nil) ⇒ Duration

Returns a new instance of Duration.



1461
1462
1463
1464
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1461

def initialize(interval: nil, interval_count: nil)
  @interval = interval
  @interval_count = interval_count
end

Instance Attribute Details

#intervalObject

Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.



1457
1458
1459
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1457

def interval
  @interval
end

#interval_countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



1459
1460
1461
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1459

def interval_count
  @interval_count
end