Class: Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::BillingCycleAnchor
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::BillingCycleAnchor
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Instance Attribute Summary collapse
-
#timestamp ⇒ Object
A timestamp to use as the subscription's billing cycle anchor.
-
#type ⇒ Object
Determines how the subscription's billing cycle anchor behaves for the invoice preview.
Instance Method Summary collapse
-
#initialize(timestamp: nil, type: nil) ⇒ BillingCycleAnchor
constructor
A new instance of BillingCycleAnchor.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(timestamp: nil, type: nil) ⇒ BillingCycleAnchor
Returns a new instance of BillingCycleAnchor.
844 845 846 847 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 844 def initialize(timestamp: nil, type: nil) = @type = type end |
Instance Attribute Details
#timestamp ⇒ Object
A timestamp to use as the subscription's billing cycle anchor. Only valid when type is timestamp.
840 841 842 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 840 def end |
#type ⇒ Object
Determines how the subscription's billing cycle anchor behaves for the invoice preview.
842 843 844 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 842 def type @type end |