Class: Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::BillingSchedule::AppliesTo
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::BillingSchedule::AppliesTo
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Instance Attribute Summary collapse
-
#price ⇒ Object
The ID of the price object.
-
#type ⇒ Object
Controls which subscription items the billing schedule applies to.
Instance Method Summary collapse
-
#initialize(price: nil, type: nil) ⇒ AppliesTo
constructor
A new instance of AppliesTo.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(price: nil, type: nil) ⇒ AppliesTo
Returns a new instance of AppliesTo.
2057 2058 2059 2060 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2057 def initialize(price: nil, type: nil) @price = price @type = type end |
Instance Attribute Details
#price ⇒ Object
The ID of the price object.
2053 2054 2055 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2053 def price @price end |
#type ⇒ Object
Controls which subscription items the billing schedule applies to.
2055 2056 2057 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2055 def type @type end |