Class: Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::BillingSchedule::BillUntil
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::BillingSchedule::BillUntil
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Specifies the billing period.
-
#timestamp ⇒ Object
The end date of the billing schedule.
-
#type ⇒ Object
Describes how the billing schedule will determine the end date.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ BillUntil
constructor
A new instance of BillUntil.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ BillUntil
Returns a new instance of BillUntil.
2078 2079 2080 2081 2082 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2078 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Specifies the billing period.
2072 2073 2074 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2072 def duration @duration end |
#timestamp ⇒ Object
The end date of the billing schedule.
2074 2075 2076 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2074 def @timestamp end |
#type ⇒ Object
Describes how the billing schedule will determine the end date. Either ‘duration` or `timestamp`.
2076 2077 2078 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2076 def type @type end |