Class: Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::Item

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: BillingThresholds, Discount, PriceData

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(billing_thresholds: nil, clear_usage: nil, deleted: nil, discounts: nil, id: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ Item

Returns a new instance of Item.



947
948
949
950
951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
970
971
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 947

def initialize(
  billing_thresholds: nil,
  clear_usage: nil,
  deleted: nil,
  discounts: nil,
  id: nil,
  metadata: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @billing_thresholds = billing_thresholds
  @clear_usage = clear_usage
  @deleted = deleted
  @discounts = discounts
  @id = id
   = 
  @plan = plan
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.



925
926
927
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 925

def billing_thresholds
  @billing_thresholds
end

#clear_usageObject

Delete all usage for a given subscription item. You must pass this when deleting a usage records subscription item. clear_usage has no effect if the plan has a billing meter attached.



927
928
929
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 927

def clear_usage
  @clear_usage
end

#deletedObject

A flag that, if set to true, will delete the specified item.



929
930
931
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 929

def deleted
  @deleted
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



931
932
933
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 931

def discounts
  @discounts
end

#idObject

Subscription item to update.



933
934
935
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 933

def id
  @id
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.



935
936
937
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 935

def 
  
end

#planObject

Plan ID for this item, as a string.



937
938
939
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 937

def plan
  @plan
end

#priceObject

The ID of the price object. One of price or price_data is required. When changing a subscription item’s price, quantity is set to 1 unless a quantity parameter is provided.



939
940
941
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 939

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](docs.stripe.com/api/prices) object inline. One of price or price_data is required.



941
942
943
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 941

def price_data
  @price_data
end

#quantityObject

Quantity for this item.



943
944
945
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 943

def quantity
  @quantity
end

#tax_ratesObject

A list of [Tax Rate](docs.stripe.com/api/tax_rates) ids. These Tax Rates will override the [default_tax_rates](docs.stripe.com/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



945
946
947
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 945

def tax_rates
  @tax_rates
end

Class Method Details

.field_encodingsObject



973
974
975
976
977
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 973

def self.field_encodings
  @field_encodings = {
    price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } },
  }
end