Class: Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::Item::BillingThresholds

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(usage_gte: nil) ⇒ BillingThresholds

Returns a new instance of BillingThresholds.



1533
1534
1535
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1533

def initialize(usage_gte: nil)
  @usage_gte = usage_gte
end

Instance Attribute Details

#usage_gteObject

Number of units that meets the billing threshold to advance the subscription to a new billing period (e.g., it takes 10 $5 units to meet a $50 [monetary threshold](docs.stripe.com/api/subscriptions/update#update_subscription-billing_thresholds-amount_gte))



1531
1532
1533
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1531

def usage_gte
  @usage_gte
end