Class: Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::Item::CurrentTrial

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(trial_end: nil, trial_offer: nil) ⇒ CurrentTrial

Returns a new instance of CurrentTrial.



2118
2119
2120
2121
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2118

def initialize(trial_end: nil, trial_offer: nil)
  @trial_end = trial_end
  @trial_offer = trial_offer
end

Instance Attribute Details

#trial_endObject

Unix timestamp representing the end of the trial offer period. Required when the trial offer has ‘duration.type=timestamp`. Cannot be specified when `duration.type=relative`.



2114
2115
2116
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2114

def trial_end
  @trial_end
end

#trial_offerObject

The ID of the trial offer to apply to the subscription item.



2116
2117
2118
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2116

def trial_offer
  @trial_offer
end