Class: Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::Item::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



2144
2145
2146
2147
2148
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2144

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



2138
2139
2140
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2138

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



2140
2141
2142
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2140

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



2142
2143
2144
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2142

def type
  @type
end