Class: Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::Item::Discount::DiscountEnd::Duration
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::Item::Discount::DiscountEnd::Duration
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Instance Attribute Summary collapse
-
#interval ⇒ Object
Specifies a type of interval unit.
-
#interval_count ⇒ Object
The number of intervals, as an whole number greater than 0.
Instance Method Summary collapse
-
#initialize(interval: nil, interval_count: nil) ⇒ Duration
constructor
A new instance of Duration.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(interval: nil, interval_count: nil) ⇒ Duration
Returns a new instance of Duration.
1660 1661 1662 1663 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1660 def initialize(interval: nil, interval_count: nil) @interval = interval @interval_count = interval_count end |
Instance Attribute Details
#interval ⇒ Object
Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.
1656 1657 1658 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1656 def interval @interval end |
#interval_count ⇒ Object
The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.
1658 1659 1660 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1658 def interval_count @interval_count end |