Class: Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::Item::Discount::Settings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::Item::Discount::Settings
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Defined Under Namespace
Classes: ServicePeriodAnchorConfig
Instance Attribute Summary collapse
-
#service_period_anchor_config ⇒ Object
Configures service period cycle anchoring.
-
#start_date ⇒ Object
The start date of the discount’s service period when applying a coupon or promotion code with a service period duration.
Instance Method Summary collapse
-
#initialize(service_period_anchor_config: nil, start_date: nil) ⇒ Settings
constructor
A new instance of Settings.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(service_period_anchor_config: nil, start_date: nil) ⇒ Settings
Returns a new instance of Settings.
2184 2185 2186 2187 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2184 def initialize(service_period_anchor_config: nil, start_date: nil) @service_period_anchor_config = service_period_anchor_config @start_date = start_date end |
Instance Attribute Details
#service_period_anchor_config ⇒ Object
Configures service period cycle anchoring.
2180 2181 2182 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2180 def service_period_anchor_config @service_period_anchor_config end |
#start_date ⇒ Object
The start date of the discount’s service period when applying a coupon or promotion code with a service period duration. Defaults to ‘now` if omitted.
2182 2183 2184 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2182 def start_date @start_date end |