Class: Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::Item::Discount::Settings::ServicePeriodAnchorConfig::Custom

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom

Returns a new instance of Custom.



2161
2162
2163
2164
2165
2166
2167
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2161

def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil)
  @day_of_month = day_of_month
  @hour = hour
  @minute = minute
  @month = month
  @second = second
end

Instance Attribute Details

#day_of_monthObject

The day of the month the anchor should be. Ranges from 1 to 31.



2151
2152
2153
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2151

def day_of_month
  @day_of_month
end

#hourObject

The hour of the day the anchor should be. Ranges from 0 to 23.



2153
2154
2155
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2153

def hour
  @hour
end

#minuteObject

The minute of the hour the anchor should be. Ranges from 0 to 59.



2155
2156
2157
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2155

def minute
  @minute
end

#monthObject

The month to start full cycle periods. Ranges from 1 to 12.



2157
2158
2159
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2157

def month
  @month
end

#secondObject

The second of the minute the anchor should be. Ranges from 0 to 59.



2159
2160
2161
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2159

def second
  @second
end