Class: Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::Item::PriceData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: Recurring

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(currency: nil, product: nil, recurring: nil, tax_behavior: nil, unit_amount: nil, unit_amount_decimal: nil) ⇒ PriceData

Returns a new instance of PriceData.



2244
2245
2246
2247
2248
2249
2250
2251
2252
2253
2254
2255
2256
2257
2258
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2244

def initialize(
  currency: nil,
  product: nil,
  recurring: nil,
  tax_behavior: nil,
  unit_amount: nil,
  unit_amount_decimal: nil
)
  @currency = currency
  @product = product
  @recurring = recurring
  @tax_behavior = tax_behavior
  @unit_amount = unit_amount
  @unit_amount_decimal = unit_amount_decimal
end

Instance Attribute Details

#currencyObject

Three-letter ISO currency code, in lowercase. Must be a supported currency.



2232
2233
2234
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2232

def currency
  @currency
end

#productObject

The ID of the Product that this Price will belong to.



2234
2235
2236
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2234

def product
  @product
end

#recurringObject

The recurring components of a price such as interval and interval_count.



2236
2237
2238
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2236

def recurring
  @recurring
end

#tax_behaviorObject

Only required if a default tax behavior was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One of inclusive, exclusive, or unspecified. Once specified as either inclusive or exclusive, it cannot be changed.



2238
2239
2240
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2238

def tax_behavior
  @tax_behavior
end

#unit_amountObject

A positive integer in cents (or local equivalent) (or 0 for a free price) representing how much to charge.



2240
2241
2242
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2240

def unit_amount
  @unit_amount
end

#unit_amount_decimalObject

Same as unit_amount, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places. Only one of unit_amount and unit_amount_decimal can be set.



2242
2243
2244
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2242

def unit_amount_decimal
  @unit_amount_decimal
end

Class Method Details

.field_encodingsObject



2260
2261
2262
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2260

def self.field_encodings
  @field_encodings = { unit_amount_decimal: :decimal_string }
end