Class: Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::Pause::BillFor

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: OutstandingUsageThrough, UnusedTimeFrom

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h

Constructor Details

#initialize(outstanding_usage_through: nil, unused_time_from: nil) ⇒ BillFor

Returns a new instance of BillFor.



1085
1086
1087
1088
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1085

def initialize(outstanding_usage_through: nil, unused_time_from: nil)
  @outstanding_usage_through = outstanding_usage_through
  @unused_time_from = unused_time_from
end

Instance Attribute Details

#outstanding_usage_through ⇒ Object

Controls when to bill for metered usage in the current period. Defaults to { type: "now" }.



1081
1082
1083
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1081

def outstanding_usage_through
  @outstanding_usage_through
end

#unused_time_from ⇒ Object

Controls when to credit for unused time on licensed items. Defaults to { type: "now" }.



1083
1084
1085
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1083

def unused_time_from
  @unused_time_from
end