Class: Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::Pause::BillFor::OutstandingUsageThrough
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::Pause::BillFor::OutstandingUsageThrough
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Instance Attribute Summary collapse
-
#type ⇒ Object
When to bill metered usage in the current period.
Instance Method Summary collapse
-
#initialize(type: nil) ⇒ OutstandingUsageThrough
constructor
A new instance of OutstandingUsageThrough.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(type: nil) ⇒ OutstandingUsageThrough
Returns a new instance of OutstandingUsageThrough.
1810 1811 1812 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1810 def initialize(type: nil) @type = type end |
Instance Attribute Details
#type ⇒ Object
When to bill metered usage in the current period.
1808 1809 1810 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1808 def type @type end |