Class: Stripe::InvoiceDetachPaymentParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceDetachPaymentParams
- Defined in:
- lib/stripe/params/invoice_detach_payment_params.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#payment_intent ⇒ Object
The ID of the PaymentIntent to detach from the invoice.
Instance Method Summary collapse
-
#initialize(expand: nil, payment_intent: nil) ⇒ InvoiceDetachPaymentParams
constructor
A new instance of InvoiceDetachPaymentParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(expand: nil, payment_intent: nil) ⇒ InvoiceDetachPaymentParams
Returns a new instance of InvoiceDetachPaymentParams.
11 12 13 14 |
# File 'lib/stripe/params/invoice_detach_payment_params.rb', line 11 def initialize(expand: nil, payment_intent: nil) @expand = @payment_intent = payment_intent end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
7 8 9 |
# File 'lib/stripe/params/invoice_detach_payment_params.rb', line 7 def @expand end |
#payment_intent ⇒ Object
The ID of the PaymentIntent to detach from the invoice.
9 10 11 |
# File 'lib/stripe/params/invoice_detach_payment_params.rb', line 9 def payment_intent @payment_intent end |