Class: Stripe::InvoiceItem::CreateParams::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceItem::CreateParams::Discount
- Defined in:
- lib/stripe/resources/invoice_item.rb
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
251 252 253 254 255 |
# File 'lib/stripe/resources/invoice_item.rb', line 251 def initialize(coupon: nil, discount: nil, promotion_code: nil) @coupon = coupon @discount = discount @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
245 246 247 |
# File 'lib/stripe/resources/invoice_item.rb', line 245 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
247 248 249 |
# File 'lib/stripe/resources/invoice_item.rb', line 247 def discount @discount end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
249 250 251 |
# File 'lib/stripe/resources/invoice_item.rb', line 249 def promotion_code @promotion_code end |