Class: Stripe::InvoiceItem::CreateParams::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice_item.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



427
428
429
430
431
# File 'lib/stripe/resources/invoice_item.rb', line 427

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



421
422
423
# File 'lib/stripe/resources/invoice_item.rb', line 421

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



423
424
425
# File 'lib/stripe/resources/invoice_item.rb', line 423

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



425
426
427
# File 'lib/stripe/resources/invoice_item.rb', line 425

def type
  @type
end