Class: Stripe::InvoiceItem::CreateParams::Period
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceItem::CreateParams::Period
- Defined in:
- lib/stripe/resources/invoice_item.rb
Instance Attribute Summary collapse
-
#end ⇒ Object
The end of the period, which must be greater than or equal to the start.
-
#start ⇒ Object
The start of the period.
Instance Method Summary collapse
-
#initialize(end_: nil, start: nil) ⇒ Period
constructor
A new instance of Period.
Methods inherited from RequestParams
Constructor Details
#initialize(end_: nil, start: nil) ⇒ Period
Returns a new instance of Period.
331 332 333 334 |
# File 'lib/stripe/resources/invoice_item.rb', line 331 def initialize(end_: nil, start: nil) @end = end_ @start = start end |
Instance Attribute Details
#end ⇒ Object
The end of the period, which must be greater than or equal to the start. This value is inclusive.
327 328 329 |
# File 'lib/stripe/resources/invoice_item.rb', line 327 def end @end end |
#start ⇒ Object
The start of the period. This value is inclusive.
329 330 331 |
# File 'lib/stripe/resources/invoice_item.rb', line 329 def start @start end |