Class: Stripe::InvoiceItem::Parent::LicenseFeeSubscriptionDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::InvoiceItem::Parent::LicenseFeeSubscriptionDetails
- Defined in:
- lib/stripe/resources/invoice_item.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#license_fee_subscription ⇒ Object
readonly
The license fee subscription that generated this invoice item.
-
#license_fee_version ⇒ Object
readonly
The license fee version that generated this invoice item.
-
#pricing_plan_subscription ⇒ Object
readonly
The pricing plan subscription that manages the license fee subscription.
-
#pricing_plan_version ⇒ Object
readonly
The pricing plan version at the time this invoice item was generated.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#license_fee_subscription ⇒ Object (readonly)
The license fee subscription that generated this invoice item
27 28 29 |
# File 'lib/stripe/resources/invoice_item.rb', line 27 def license_fee_subscription @license_fee_subscription end |
#license_fee_version ⇒ Object (readonly)
The license fee version that generated this invoice item
29 30 31 |
# File 'lib/stripe/resources/invoice_item.rb', line 29 def license_fee_version @license_fee_version end |
#pricing_plan_subscription ⇒ Object (readonly)
The pricing plan subscription that manages the license fee subscription
31 32 33 |
# File 'lib/stripe/resources/invoice_item.rb', line 31 def pricing_plan_subscription @pricing_plan_subscription end |
#pricing_plan_version ⇒ Object (readonly)
The pricing plan version at the time this invoice item was generated
33 34 35 |
# File 'lib/stripe/resources/invoice_item.rb', line 33 def pricing_plan_version @pricing_plan_version end |
Class Method Details
.field_remappings ⇒ Object
39 40 41 |
# File 'lib/stripe/resources/invoice_item.rb', line 39 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
35 36 37 |
# File 'lib/stripe/resources/invoice_item.rb', line 35 def self.inner_class_types @inner_class_types = {} end |