Class: Stripe::InvoiceItem::Pricing
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::InvoiceItem::Pricing
- Defined in:
- lib/stripe/resources/invoice_item.rb
Defined Under Namespace
Classes: LicenseFeeDetails, PriceDetails, RateCardRateDetails
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#license_fee_details ⇒ Object
readonly
Attribute for field license_fee_details.
-
#price_details ⇒ Object
readonly
Attribute for field price_details.
-
#rate_card_rate_details ⇒ Object
readonly
Attribute for field rate_card_rate_details.
-
#type ⇒ Object
readonly
The type of the pricing details.
-
#unit_amount_decimal ⇒ Object
readonly
The unit amount (in the ‘currency` specified) of the item which contains a decimal value with at most 12 decimal places.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#license_fee_details ⇒ Object (readonly)
Attribute for field license_fee_details
164 165 166 |
# File 'lib/stripe/resources/invoice_item.rb', line 164 def license_fee_details @license_fee_details end |
#price_details ⇒ Object (readonly)
Attribute for field price_details
166 167 168 |
# File 'lib/stripe/resources/invoice_item.rb', line 166 def price_details @price_details end |
#rate_card_rate_details ⇒ Object (readonly)
Attribute for field rate_card_rate_details
168 169 170 |
# File 'lib/stripe/resources/invoice_item.rb', line 168 def rate_card_rate_details @rate_card_rate_details end |
#type ⇒ Object (readonly)
The type of the pricing details.
170 171 172 |
# File 'lib/stripe/resources/invoice_item.rb', line 170 def type @type end |
#unit_amount_decimal ⇒ Object (readonly)
The unit amount (in the ‘currency` specified) of the item which contains a decimal value with at most 12 decimal places.
172 173 174 |
# File 'lib/stripe/resources/invoice_item.rb', line 172 def unit_amount_decimal @unit_amount_decimal end |
Class Method Details
.field_remappings ⇒ Object
182 183 184 |
# File 'lib/stripe/resources/invoice_item.rb', line 182 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
174 175 176 177 178 179 180 |
# File 'lib/stripe/resources/invoice_item.rb', line 174 def self.inner_class_types @inner_class_types = { license_fee_details: LicenseFeeDetails, price_details: PriceDetails, rate_card_rate_details: RateCardRateDetails, } end |