Class: Stripe::InvoiceItem::Pricing::RateCardCustomPricingUnitOverageRateDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::InvoiceItem::Pricing::RateCardCustomPricingUnitOverageRateDetails
- Defined in:
- lib/stripe/resources/invoice_item.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#custom_pricing_unit ⇒ Object
readonly
The ID of the custom pricing unit this item is associated with.
-
#custom_pricing_unit_overage_rate ⇒ Object
readonly
The ID of the custom pricing unit overage rate this item is associated with.
-
#one_time_item ⇒ Object
readonly
The ID of the one-time item this custom pricing unit overage rate is associated with.
-
#rate_card ⇒ Object
readonly
The ID of the rate card this item is associated with.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#custom_pricing_unit ⇒ Object (readonly)
The ID of the custom pricing unit this item is associated with
165 166 167 |
# File 'lib/stripe/resources/invoice_item.rb', line 165 def custom_pricing_unit @custom_pricing_unit end |
#custom_pricing_unit_overage_rate ⇒ Object (readonly)
The ID of the custom pricing unit overage rate this item is associated with
167 168 169 |
# File 'lib/stripe/resources/invoice_item.rb', line 167 def custom_pricing_unit_overage_rate @custom_pricing_unit_overage_rate end |
#one_time_item ⇒ Object (readonly)
The ID of the one-time item this custom pricing unit overage rate is associated with
169 170 171 |
# File 'lib/stripe/resources/invoice_item.rb', line 169 def one_time_item @one_time_item end |
#rate_card ⇒ Object (readonly)
The ID of the rate card this item is associated with
171 172 173 |
# File 'lib/stripe/resources/invoice_item.rb', line 171 def rate_card @rate_card end |
Class Method Details
.field_remappings ⇒ Object
177 178 179 |
# File 'lib/stripe/resources/invoice_item.rb', line 177 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
173 174 175 |
# File 'lib/stripe/resources/invoice_item.rb', line 173 def self.inner_class_types @inner_class_types = {} end |