Class: Stripe::InvoiceItem::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/invoice_item.rb

Defined Under Namespace

Classes: Discount, Period, PriceData, Pricing

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, description: nil, discountable: nil, discounts: nil, expand: nil, margins: nil, metadata: nil, period: nil, price_data: nil, pricing: nil, quantity: nil, tax_behavior: nil, tax_code: nil, tax_rates: nil, unit_amount_decimal: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
# File 'lib/stripe/resources/invoice_item.rb', line 231

def initialize(
  amount: nil,
  description: nil,
  discountable: nil,
  discounts: nil,
  expand: nil,
  margins: nil,
  metadata: nil,
  period: nil,
  price_data: nil,
  pricing: nil,
  quantity: nil,
  tax_behavior: nil,
  tax_code: nil,
  tax_rates: nil,
  unit_amount_decimal: nil
)
  @amount = amount
  @description = description
  @discountable = discountable
  @discounts = discounts
  @expand = expand
  @margins = margins
  @metadata = 
  @period = period
  @price_data = price_data
  @pricing = pricing
  @quantity = quantity
  @tax_behavior = tax_behavior
  @tax_code = tax_code
  @tax_rates = tax_rates
  @unit_amount_decimal = unit_amount_decimal
end

Instance Attribute Details

#amountObject

The integer amount in cents (or local equivalent) of the charge to be applied to the upcoming invoice. If you want to apply a credit to the customer’s account, pass a negative amount.



201
202
203
# File 'lib/stripe/resources/invoice_item.rb', line 201

def amount
  @amount
end

#descriptionObject

An arbitrary string which you can attach to the invoice item. The description is displayed in the invoice for easy tracking.



203
204
205
# File 'lib/stripe/resources/invoice_item.rb', line 203

def description
  @description
end

#discountableObject

Controls whether discounts apply to this invoice item. Defaults to false for prorations or negative invoice items, and true for all other invoice items. Cannot be set to true for prorations.



205
206
207
# File 'lib/stripe/resources/invoice_item.rb', line 205

def discountable
  @discountable
end

#discountsObject

The coupons, promotion codes & existing discounts which apply to the invoice item or invoice line item. Item discounts are applied before invoice discounts. Pass an empty string to remove previously-defined discounts.



207
208
209
# File 'lib/stripe/resources/invoice_item.rb', line 207

def discounts
  @discounts
end

#expandObject

Specifies which fields in the response should be expanded.



209
210
211
# File 'lib/stripe/resources/invoice_item.rb', line 209

def expand
  @expand
end

#marginsObject

The ids of the margins to apply to the invoice item. When set, the ‘default_margins` on the invoice do not apply to this invoice item.



211
212
213
# File 'lib/stripe/resources/invoice_item.rb', line 211

def margins
  @margins
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



213
214
215
# File 'lib/stripe/resources/invoice_item.rb', line 213

def 
  @metadata
end

#periodObject

The period associated with this invoice item. When set to different values, the period will be rendered on the invoice. If you have [Stripe Revenue Recognition](stripe.com/docs/revenue-recognition) enabled, the period will be used to recognize and defer revenue. See the [Revenue Recognition documentation](stripe.com/docs/revenue-recognition/methodology/subscriptions-and-invoicing) for details.



215
216
217
# File 'lib/stripe/resources/invoice_item.rb', line 215

def period
  @period
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.



217
218
219
# File 'lib/stripe/resources/invoice_item.rb', line 217

def price_data
  @price_data
end

#pricingObject

The pricing information for the invoice item.



219
220
221
# File 'lib/stripe/resources/invoice_item.rb', line 219

def pricing
  @pricing
end

#quantityObject

Non-negative integer. The quantity of units for the invoice item.



221
222
223
# File 'lib/stripe/resources/invoice_item.rb', line 221

def quantity
  @quantity
end

#tax_behaviorObject

Only required if a [default tax behavior](stripe.com/docs/tax/products-prices-tax-categories-tax-behavior#setting-a-default-tax-behavior-(recommended)) was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`. Once specified as either `inclusive` or `exclusive`, it cannot be changed.



223
224
225
# File 'lib/stripe/resources/invoice_item.rb', line 223

def tax_behavior
  @tax_behavior
end

#tax_codeObject



225
226
227
# File 'lib/stripe/resources/invoice_item.rb', line 225

def tax_code
  @tax_code
end

#tax_ratesObject

The tax rates which apply to the invoice item. When set, the ‘default_tax_rates` on the invoice do not apply to this invoice item. Pass an empty string to remove previously-defined tax rates.



227
228
229
# File 'lib/stripe/resources/invoice_item.rb', line 227

def tax_rates
  @tax_rates
end

#unit_amount_decimalObject

The decimal unit amount in cents (or local equivalent) of the charge to be applied to the upcoming invoice. This ‘unit_amount_decimal` will be multiplied by the quantity to get the full amount. Passing in a negative `unit_amount_decimal` will reduce the `amount_due` on the invoice. Accepts at most 12 decimal places.



229
230
231
# File 'lib/stripe/resources/invoice_item.rb', line 229

def unit_amount_decimal
  @unit_amount_decimal
end