Class: Stripe::InvoiceItem::UpdateParams::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice_item.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



97
98
99
100
101
102
# File 'lib/stripe/resources/invoice_item.rb', line 97

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



89
90
91
# File 'lib/stripe/resources/invoice_item.rb', line 89

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



91
92
93
# File 'lib/stripe/resources/invoice_item.rb', line 91

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



93
94
95
# File 'lib/stripe/resources/invoice_item.rb', line 93

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



95
96
97
# File 'lib/stripe/resources/invoice_item.rb', line 95

def promotion_code
  @promotion_code
end