Class: Stripe::InvoiceItem::UpdateParams::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice_item.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



85
86
87
88
89
# File 'lib/stripe/resources/invoice_item.rb', line 85

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



79
80
81
# File 'lib/stripe/resources/invoice_item.rb', line 79

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



81
82
83
# File 'lib/stripe/resources/invoice_item.rb', line 81

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



83
84
85
# File 'lib/stripe/resources/invoice_item.rb', line 83

def type
  @type
end