Class: Stripe::InvoiceItem::UpdateParams::Period
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceItem::UpdateParams::Period
- Defined in:
- lib/stripe/resources/invoice_item.rb
Instance Attribute Summary collapse
-
#end ⇒ Object
The end of the period, which must be greater than or equal to the start.
-
#start ⇒ Object
The start of the period.
Instance Method Summary collapse
-
#initialize(end_: nil, start: nil) ⇒ Period
constructor
A new instance of Period.
Methods inherited from RequestParams
Constructor Details
#initialize(end_: nil, start: nil) ⇒ Period
Returns a new instance of Period.
159 160 161 162 |
# File 'lib/stripe/resources/invoice_item.rb', line 159 def initialize(end_: nil, start: nil) @end = end_ @start = start end |
Instance Attribute Details
#end ⇒ Object
The end of the period, which must be greater than or equal to the start. This value is inclusive.
155 156 157 |
# File 'lib/stripe/resources/invoice_item.rb', line 155 def end @end end |
#start ⇒ Object
The start of the period. This value is inclusive.
157 158 159 |
# File 'lib/stripe/resources/invoice_item.rb', line 157 def start @start end |