Class: Stripe::InvoiceItemCreateParams::PriceData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceItemCreateParams::PriceData
- Defined in:
- lib/stripe/params/invoice_item_create_params.rb
Instance Attribute Summary collapse
-
#currency ⇒ Object
Three-letter ISO currency code, in lowercase.
- #product ⇒ Object
-
#tax_behavior ⇒ Object
Only required if a default tax behavior was not provided in the Stripe Tax settings.
-
#unit_amount ⇒ Object
A positive integer in cents (or local equivalent) (or 0 for a free price) representing how much to charge.
-
#unit_amount_decimal ⇒ Object
Same as
unit_amount, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(currency: nil, product: nil, tax_behavior: nil, unit_amount: nil, unit_amount_decimal: nil) ⇒ PriceData
constructor
A new instance of PriceData.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(currency: nil, product: nil, tax_behavior: nil, unit_amount: nil, unit_amount_decimal: nil) ⇒ PriceData
Returns a new instance of PriceData.
82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/stripe/params/invoice_item_create_params.rb', line 82 def initialize( currency: nil, product: nil, tax_behavior: nil, unit_amount: nil, unit_amount_decimal: nil ) @currency = currency @product = product @tax_behavior = tax_behavior @unit_amount = unit_amount @unit_amount_decimal = unit_amount_decimal end |
Instance Attribute Details
#currency ⇒ Object
Three-letter ISO currency code, in lowercase. Must be a supported currency.
72 73 74 |
# File 'lib/stripe/params/invoice_item_create_params.rb', line 72 def currency @currency end |
#product ⇒ Object
74 75 76 |
# File 'lib/stripe/params/invoice_item_create_params.rb', line 74 def product @product end |
#tax_behavior ⇒ Object
Only required if a default tax behavior was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One of inclusive, exclusive, or unspecified. Once specified as either inclusive or exclusive, it cannot be changed.
76 77 78 |
# File 'lib/stripe/params/invoice_item_create_params.rb', line 76 def tax_behavior @tax_behavior end |
#unit_amount ⇒ Object
A positive integer in cents (or local equivalent) (or 0 for a free price) representing how much to charge.
78 79 80 |
# File 'lib/stripe/params/invoice_item_create_params.rb', line 78 def unit_amount @unit_amount end |
#unit_amount_decimal ⇒ Object
Same as unit_amount, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places. Only one of unit_amount and unit_amount_decimal can be set.
80 81 82 |
# File 'lib/stripe/params/invoice_item_create_params.rb', line 80 def unit_amount_decimal @unit_amount_decimal end |
Class Method Details
.field_encodings ⇒ Object
96 97 98 |
# File 'lib/stripe/params/invoice_item_create_params.rb', line 96 def self.field_encodings @field_encodings = { unit_amount_decimal: :decimal_string } end |