Class: Stripe::InvoiceItemService::CreateParams::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceItemService::CreateParams::Discount
- Defined in:
- lib/stripe/services/invoice_item_service.rb
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
208 209 210 211 212 |
# File 'lib/stripe/services/invoice_item_service.rb', line 208 def initialize(coupon: nil, discount: nil, promotion_code: nil) @coupon = coupon @discount = discount @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
202 203 204 |
# File 'lib/stripe/services/invoice_item_service.rb', line 202 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
204 205 206 |
# File 'lib/stripe/services/invoice_item_service.rb', line 204 def discount @discount end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
206 207 208 |
# File 'lib/stripe/services/invoice_item_service.rb', line 206 def promotion_code @promotion_code end |