Class: Stripe::InvoiceItemService::CreateParams::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_item_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



255
256
257
258
259
# File 'lib/stripe/services/invoice_item_service.rb', line 255

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



249
250
251
# File 'lib/stripe/services/invoice_item_service.rb', line 249

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



251
252
253
# File 'lib/stripe/services/invoice_item_service.rb', line 251

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



253
254
255
# File 'lib/stripe/services/invoice_item_service.rb', line 253

def type
  @type
end