Class: Stripe::InvoiceItemService::CreateParams::Period
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceItemService::CreateParams::Period
- Defined in:
- lib/stripe/services/invoice_item_service.rb
Instance Attribute Summary collapse
-
#end ⇒ Object
The end of the period, which must be greater than or equal to the start.
-
#start ⇒ Object
The start of the period.
Instance Method Summary collapse
-
#initialize(end_: nil, start: nil) ⇒ Period
constructor
A new instance of Period.
Methods inherited from RequestParams
Constructor Details
#initialize(end_: nil, start: nil) ⇒ Period
Returns a new instance of Period.
221 222 223 224 |
# File 'lib/stripe/services/invoice_item_service.rb', line 221 def initialize(end_: nil, start: nil) @end = end_ @start = start end |
Instance Attribute Details
#end ⇒ Object
The end of the period, which must be greater than or equal to the start. This value is inclusive.
217 218 219 |
# File 'lib/stripe/services/invoice_item_service.rb', line 217 def end @end end |
#start ⇒ Object
The start of the period. This value is inclusive.
219 220 221 |
# File 'lib/stripe/services/invoice_item_service.rb', line 219 def start @start end |