Class: Stripe::InvoiceItemService::UpdateParams::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_item_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



38
39
40
41
42
# File 'lib/stripe/services/invoice_item_service.rb', line 38

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



32
33
34
# File 'lib/stripe/services/invoice_item_service.rb', line 32

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



34
35
36
# File 'lib/stripe/services/invoice_item_service.rb', line 34

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



36
37
38
# File 'lib/stripe/services/invoice_item_service.rb', line 36

def type
  @type
end