Class: Stripe::InvoiceItemUpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/invoice_item_update_params.rb

Defined Under Namespace

Classes: Discount, Period, PriceData, Pricing

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(amount: nil, description: nil, discountable: nil, discounts: nil, expand: nil, metadata: nil, period: nil, price_data: nil, pricing: nil, quantity: nil, quantity_decimal: nil, tax_behavior: nil, tax_code: nil, tax_rates: nil, unit_amount_decimal: nil) ⇒ InvoiceItemUpdateParams

Returns a new instance of InvoiceItemUpdateParams.



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
# File 'lib/stripe/params/invoice_item_update_params.rb', line 103

def initialize(
  amount: nil,
  description: nil,
  discountable: nil,
  discounts: nil,
  expand: nil,
  metadata: nil,
  period: nil,
  price_data: nil,
  pricing: nil,
  quantity: nil,
  quantity_decimal: nil,
  tax_behavior: nil,
  tax_code: nil,
  tax_rates: nil,
  unit_amount_decimal: nil
)
  @amount = amount
  @description = description
  @discountable = discountable
  @discounts = discounts
  @expand = expand
  @metadata = 
  @period = period
  @price_data = price_data
  @pricing = pricing
  @quantity = quantity
  @quantity_decimal = quantity_decimal
  @tax_behavior = tax_behavior
  @tax_code = tax_code
  @tax_rates = tax_rates
  @unit_amount_decimal = unit_amount_decimal
end

Instance Attribute Details

#amountObject

The integer amount in cents (or local equivalent) of the charge to be applied to the upcoming invoice. If you want to apply a credit to the customer’s account, pass a negative amount.



73
74
75
# File 'lib/stripe/params/invoice_item_update_params.rb', line 73

def amount
  @amount
end

#descriptionObject

An arbitrary string which you can attach to the invoice item. The description is displayed in the invoice for easy tracking.



75
76
77
# File 'lib/stripe/params/invoice_item_update_params.rb', line 75

def description
  @description
end

#discountableObject

Controls whether discounts apply to this invoice item. Defaults to false for prorations or negative invoice items, and true for all other invoice items. Cannot be set to true for prorations.



77
78
79
# File 'lib/stripe/params/invoice_item_update_params.rb', line 77

def discountable
  @discountable
end

#discountsObject

The coupons, promotion codes & existing discounts which apply to the invoice item or invoice line item. Item discounts are applied before invoice discounts. Pass an empty string to remove previously-defined discounts.



79
80
81
# File 'lib/stripe/params/invoice_item_update_params.rb', line 79

def discounts
  @discounts
end

#expandObject

Specifies which fields in the response should be expanded.



81
82
83
# File 'lib/stripe/params/invoice_item_update_params.rb', line 81

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.



83
84
85
# File 'lib/stripe/params/invoice_item_update_params.rb', line 83

def 
  @metadata
end

#periodObject

The period associated with this invoice item. When set to different values, the period will be rendered on the invoice. If you have [Stripe Revenue Recognition](docs.stripe.com/revenue-recognition) enabled, the period will be used to recognize and defer revenue. See the [Revenue Recognition documentation](docs.stripe.com/revenue-recognition/methodology/subscriptions-and-invoicing) for details.



85
86
87
# File 'lib/stripe/params/invoice_item_update_params.rb', line 85

def period
  @period
end

#price_dataObject

Data used to generate a new [Price](docs.stripe.com/api/prices) object inline.



87
88
89
# File 'lib/stripe/params/invoice_item_update_params.rb', line 87

def price_data
  @price_data
end

#pricingObject

The pricing information for the invoice item.



89
90
91
# File 'lib/stripe/params/invoice_item_update_params.rb', line 89

def pricing
  @pricing
end

#quantityObject

Non-negative integer. The quantity of units for the invoice item. Use quantity_decimal instead to provide decimal precision. This field will be deprecated in favor of quantity_decimal in a future version.



91
92
93
# File 'lib/stripe/params/invoice_item_update_params.rb', line 91

def quantity
  @quantity
end

#quantity_decimalObject

Non-negative decimal with at most 12 decimal places. The quantity of units for the line item.



93
94
95
# File 'lib/stripe/params/invoice_item_update_params.rb', line 93

def quantity_decimal
  @quantity_decimal
end

#tax_behaviorObject

Only required if a [default tax behavior](docs.stripe.com/tax/products-prices-tax-categories-tax-behavior#setting-a-default-tax-behavior-(recommended)) was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One of inclusive, exclusive, or unspecified. Once specified as either inclusive or exclusive, it cannot be changed.



95
96
97
# File 'lib/stripe/params/invoice_item_update_params.rb', line 95

def tax_behavior
  @tax_behavior
end

#tax_codeObject



97
98
99
# File 'lib/stripe/params/invoice_item_update_params.rb', line 97

def tax_code
  @tax_code
end

#tax_ratesObject

The tax rates which apply to the invoice item. When set, the default_tax_rates on the invoice do not apply to this invoice item. Pass an empty string to remove previously-defined tax rates.



99
100
101
# File 'lib/stripe/params/invoice_item_update_params.rb', line 99

def tax_rates
  @tax_rates
end

#unit_amount_decimalObject

The decimal unit amount in cents (or local equivalent) of the charge to be applied to the upcoming invoice. This unit_amount_decimal will be multiplied by the quantity to get the full amount. Passing in a negative unit_amount_decimal will reduce the amount_due on the invoice. Accepts at most 12 decimal places.



101
102
103
# File 'lib/stripe/params/invoice_item_update_params.rb', line 101

def unit_amount_decimal
  @unit_amount_decimal
end

Class Method Details

.field_encodingsObject



137
138
139
140
141
142
143
# File 'lib/stripe/params/invoice_item_update_params.rb', line 137

def self.field_encodings
  @field_encodings = {
    price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } },
    quantity_decimal: :decimal_string,
    unit_amount_decimal: :decimal_string,
  }
end