Class: Stripe::InvoiceLineItem::MarginAmount
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::InvoiceLineItem::MarginAmount
- Defined in:
- lib/stripe/resources/invoice_line_item.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The amount, in cents (or local equivalent), of the reduction in line item amount.
-
#margin ⇒ Object
readonly
The margin that was applied to get this margin amount.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The amount, in cents (or local equivalent), of the reduction in line item amount.
25 26 27 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 25 def amount @amount end |
#margin ⇒ Object (readonly)
The margin that was applied to get this margin amount.
27 28 29 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 27 def margin @margin end |