Class: Stripe::InvoiceLineItem::Parent
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::InvoiceLineItem::Parent
- Defined in:
- lib/stripe/resources/invoice_line_item.rb
Defined Under Namespace
Classes: InvoiceItemDetails, SubscriptionItemDetails
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#invoice_item_details ⇒ Object
readonly
Details about the invoice item that generated this line item.
-
#subscription_item_details ⇒ Object
readonly
Details about the subscription item that generated this line item.
-
#type ⇒ Object
readonly
The type of parent that generated this line item.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#invoice_item_details ⇒ Object (readonly)
Details about the invoice item that generated this line item
75 76 77 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 75 def invoice_item_details @invoice_item_details end |
#subscription_item_details ⇒ Object (readonly)
Details about the subscription item that generated this line item
77 78 79 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 77 def subscription_item_details @subscription_item_details end |
#type ⇒ Object (readonly)
The type of parent that generated this line item
79 80 81 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 79 def type @type end |