Class: Stripe::InvoiceLineItem::Parent::LicenseFeeSubscriptionDetails

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/invoice_line_item.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#invoice_itemObject (readonly)

The invoice item that generated this line item



54
55
56
# File 'lib/stripe/resources/invoice_line_item.rb', line 54

def invoice_item
  @invoice_item
end

#license_fee_subscriptionObject (readonly)

The license fee subscription that generated this line item



56
57
58
# File 'lib/stripe/resources/invoice_line_item.rb', line 56

def license_fee_subscription
  @license_fee_subscription
end

#license_fee_versionObject (readonly)

The license fee version at the time this line item was generated



58
59
60
# File 'lib/stripe/resources/invoice_line_item.rb', line 58

def license_fee_version
  @license_fee_version
end

#pricing_plan_subscriptionObject (readonly)

The pricing plan subscription that manages the license fee subscription



60
61
62
# File 'lib/stripe/resources/invoice_line_item.rb', line 60

def pricing_plan_subscription
  @pricing_plan_subscription
end

#pricing_plan_versionObject (readonly)

The pricing plan version at the time this line item was generated



62
63
64
# File 'lib/stripe/resources/invoice_line_item.rb', line 62

def pricing_plan_version
  @pricing_plan_version
end