Class: Stripe::InvoiceLineItem::PretaxCreditAmount
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::InvoiceLineItem::PretaxCreditAmount
- Defined in:
- lib/stripe/resources/invoice_line_item.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The amount, in cents (or local equivalent), of the pretax credit amount.
-
#credit_balance_transaction ⇒ Object
readonly
The credit balance transaction that was applied to get this pretax credit amount.
-
#discount ⇒ Object
readonly
The discount that was applied to get this pretax credit amount.
-
#margin ⇒ Object
readonly
The margin that was applied to get this pretax credit amount.
-
#type ⇒ Object
readonly
Type of the pretax credit amount referenced.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The amount, in cents (or local equivalent), of the pretax credit amount.
39 40 41 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 39 def amount @amount end |
#credit_balance_transaction ⇒ Object (readonly)
The credit balance transaction that was applied to get this pretax credit amount.
41 42 43 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 41 def credit_balance_transaction @credit_balance_transaction end |
#discount ⇒ Object (readonly)
The discount that was applied to get this pretax credit amount.
43 44 45 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 43 def discount @discount end |
#margin ⇒ Object (readonly)
The margin that was applied to get this pretax credit amount.
45 46 47 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 45 def margin @margin end |
#type ⇒ Object (readonly)
Type of the pretax credit amount referenced.
47 48 49 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 47 def type @type end |