Class: Stripe::InvoiceLineItem::Pricing
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::InvoiceLineItem::Pricing
- Defined in:
- lib/stripe/resources/invoice_line_item.rb
Defined Under Namespace
Classes: LicenseFeeDetails, PriceDetails, RateCardRateDetails
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#license_fee_details ⇒ Object
readonly
Attribute for field license_fee_details.
-
#price_details ⇒ Object
readonly
Attribute for field price_details.
-
#rate_card_rate_details ⇒ Object
readonly
Attribute for field rate_card_rate_details.
-
#type ⇒ Object
readonly
The type of the pricing details.
-
#unit_amount_decimal ⇒ Object
readonly
The unit amount (in the ‘currency` specified) of the item which contains a decimal value with at most 12 decimal places.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#license_fee_details ⇒ Object (readonly)
Attribute for field license_fee_details
158 159 160 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 158 def license_fee_details @license_fee_details end |
#price_details ⇒ Object (readonly)
Attribute for field price_details
160 161 162 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 160 def price_details @price_details end |
#rate_card_rate_details ⇒ Object (readonly)
Attribute for field rate_card_rate_details
162 163 164 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 162 def rate_card_rate_details @rate_card_rate_details end |
#type ⇒ Object (readonly)
The type of the pricing details.
164 165 166 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 164 def type @type end |
#unit_amount_decimal ⇒ Object (readonly)
The unit amount (in the ‘currency` specified) of the item which contains a decimal value with at most 12 decimal places.
166 167 168 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 166 def unit_amount_decimal @unit_amount_decimal end |