Class: Stripe::InvoiceLineItem::Pricing::LicenseFeeDetails

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/invoice_line_item.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#license_feeObject (readonly)

The ID of the license fee this item is associated with



286
287
288
# File 'lib/stripe/resources/invoice_line_item.rb', line 286

def license_fee
  @license_fee
end

#license_fee_versionObject (readonly)

The version of the license fee this item is associated with



288
289
290
# File 'lib/stripe/resources/invoice_line_item.rb', line 288

def license_fee_version
  @license_fee_version
end

#licensed_itemObject (readonly)

The ID of the licensed item this item is associated with



290
291
292
# File 'lib/stripe/resources/invoice_line_item.rb', line 290

def licensed_item
  @licensed_item
end

Class Method Details

.field_remappingsObject



296
297
298
# File 'lib/stripe/resources/invoice_line_item.rb', line 296

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



292
293
294
# File 'lib/stripe/resources/invoice_line_item.rb', line 292

def self.inner_class_types
  @inner_class_types = {}
end