Class: Stripe::InvoiceLineItem::Pricing::RateCardCustomPricingUnitOverageRateDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::InvoiceLineItem::Pricing::RateCardCustomPricingUnitOverageRateDetails
- Defined in:
- lib/stripe/resources/invoice_line_item.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#custom_pricing_unit ⇒ Object
readonly
The ID of the custom pricing unit this item is associated with.
-
#custom_pricing_unit_overage_rate ⇒ Object
readonly
The ID of the custom pricing unit overage rate this item is associated with.
-
#one_time_item ⇒ Object
readonly
The ID of the one-time item this custom pricing unit overage rate is associated with.
-
#rate_card ⇒ Object
readonly
The ID of the rate card this item is associated with.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#custom_pricing_unit ⇒ Object (readonly)
The ID of the custom pricing unit this item is associated with
326 327 328 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 326 def custom_pricing_unit @custom_pricing_unit end |
#custom_pricing_unit_overage_rate ⇒ Object (readonly)
The ID of the custom pricing unit overage rate this item is associated with
328 329 330 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 328 def custom_pricing_unit_overage_rate @custom_pricing_unit_overage_rate end |
#one_time_item ⇒ Object (readonly)
The ID of the one-time item this custom pricing unit overage rate is associated with
330 331 332 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 330 def one_time_item @one_time_item end |
#rate_card ⇒ Object (readonly)
The ID of the rate card this item is associated with
332 333 334 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 332 def rate_card @rate_card end |
Class Method Details
.field_remappings ⇒ Object
338 339 340 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 338 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
334 335 336 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 334 def self.inner_class_types @inner_class_types = {} end |