Class: Stripe::InvoiceLineItem::UpdateParams::Period
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceLineItem::UpdateParams::Period
- Defined in:
- lib/stripe/resources/invoice_line_item.rb
Instance Attribute Summary collapse
-
#end ⇒ Object
The end of the period, which must be greater than or equal to the start.
-
#start ⇒ Object
The start of the period.
Instance Method Summary collapse
-
#initialize(end_: nil, start: nil) ⇒ Period
constructor
A new instance of Period.
Methods inherited from RequestParams
Constructor Details
#initialize(end_: nil, start: nil) ⇒ Period
Returns a new instance of Period.
245 246 247 248 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 245 def initialize(end_: nil, start: nil) @end = end_ @start = start end |
Instance Attribute Details
#end ⇒ Object
The end of the period, which must be greater than or equal to the start. This value is inclusive.
241 242 243 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 241 def end @end end |
#start ⇒ Object
The start of the period. This value is inclusive.
243 244 245 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 243 def start @start end |