Class: Stripe::InvoiceLineItem::UpdateParams::PriceData::ProductData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceLineItem::UpdateParams::PriceData::ProductData
- Defined in:
- lib/stripe/resources/invoice_line_item.rb
Instance Attribute Summary collapse
-
#description ⇒ Object
The product’s description, meant to be displayable to the customer.
-
#images ⇒ Object
A list of up to 8 URLs of images for this product, meant to be displayable to the customer.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#name ⇒ Object
The product’s name, meant to be displayable to the customer.
-
#tax_code ⇒ Object
A [tax code](stripe.com/docs/tax/tax-categories) ID.
Instance Method Summary collapse
-
#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil) ⇒ ProductData
constructor
A new instance of ProductData.
Methods inherited from RequestParams
Constructor Details
#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil) ⇒ ProductData
Returns a new instance of ProductData.
264 265 266 267 268 269 270 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 264 def initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil) @description = description @images = images @metadata = @name = name @tax_code = tax_code end |
Instance Attribute Details
#description ⇒ Object
The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.
254 255 256 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 254 def description @description end |
#images ⇒ Object
A list of up to 8 URLs of images for this product, meant to be displayable to the customer.
256 257 258 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 256 def images @images end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
258 259 260 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 258 def @metadata end |
#name ⇒ Object
The product’s name, meant to be displayable to the customer.
260 261 262 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 260 def name @name end |
#tax_code ⇒ Object
A [tax code](stripe.com/docs/tax/tax-categories) ID.
262 263 264 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 262 def tax_code @tax_code end |