Class: Stripe::InvoiceLineItem::UpdateParams::TaxAmount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice_line_item.rb

Defined Under Namespace

Classes: TaxRateData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, tax_rate_data: nil, taxability_reason: nil, taxable_amount: nil) ⇒ TaxAmount

Returns a new instance of TaxAmount.



313
314
315
316
317
318
# File 'lib/stripe/resources/invoice_line_item.rb', line 313

def initialize(amount: nil, tax_rate_data: nil, taxability_reason: nil, taxable_amount: nil)
  @amount = amount
  @tax_rate_data = tax_rate_data
  @taxability_reason = taxability_reason
  @taxable_amount = taxable_amount
end

Instance Attribute Details

#amountObject

The amount, in cents (or local equivalent), of the tax.



303
304
305
# File 'lib/stripe/resources/invoice_line_item.rb', line 303

def amount
  @amount
end

#tax_rate_dataObject

Data to find or create a TaxRate object.

Stripe automatically creates or reuses a TaxRate object for each tax amount. If the ‘tax_rate_data` exactly matches a previous value, Stripe will reuse the TaxRate object. TaxRate objects created automatically by Stripe are immediately archived, do not appear in the line item’s `tax_rates`, and cannot be directly added to invoices, payments, or line items.



307
308
309
# File 'lib/stripe/resources/invoice_line_item.rb', line 307

def tax_rate_data
  @tax_rate_data
end

#taxability_reasonObject

The reasoning behind this tax, for example, if the product is tax exempt.



309
310
311
# File 'lib/stripe/resources/invoice_line_item.rb', line 309

def taxability_reason
  @taxability_reason
end

#taxable_amountObject

The amount on which tax is calculated, in cents (or local equivalent).



311
312
313
# File 'lib/stripe/resources/invoice_line_item.rb', line 311

def taxable_amount
  @taxable_amount
end