Class: Stripe::InvoiceLineItemService::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_line_item_service.rb

Defined Under Namespace

Classes: Discount, Period, PriceData, TaxAmount

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, description: nil, discountable: nil, discounts: nil, expand: nil, margins: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_amounts: nil, tax_rates: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
# File 'lib/stripe/services/invoice_line_item_service.rb', line 212

def initialize(
  amount: nil,
  description: nil,
  discountable: nil,
  discounts: nil,
  expand: nil,
  margins: nil,
  metadata: nil,
  period: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_amounts: nil,
  tax_rates: nil
)
  @amount = amount
  @description = description
  @discountable = discountable
  @discounts = discounts
  @expand = expand
  @margins = margins
  @metadata = 
  @period = period
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_amounts = tax_amounts
  @tax_rates = tax_rates
end

Instance Attribute Details

#amountObject

The integer amount in cents (or local equivalent) of the charge to be applied to the upcoming invoice. If you want to apply a credit to the customer’s account, pass a negative amount.



186
187
188
# File 'lib/stripe/services/invoice_line_item_service.rb', line 186

def amount
  @amount
end

#descriptionObject

An arbitrary string which you can attach to the invoice item. The description is displayed in the invoice for easy tracking.



188
189
190
# File 'lib/stripe/services/invoice_line_item_service.rb', line 188

def description
  @description
end

#discountableObject

Controls whether discounts apply to this line item. Defaults to false for prorations or negative line items, and true for all other line items. Cannot be set to true for prorations.



190
191
192
# File 'lib/stripe/services/invoice_line_item_service.rb', line 190

def discountable
  @discountable
end

#discountsObject

The coupons, promotion codes & existing discounts which apply to the line item. Item discounts are applied before invoice discounts. Pass an empty string to remove previously-defined discounts.



192
193
194
# File 'lib/stripe/services/invoice_line_item_service.rb', line 192

def discounts
  @discounts
end

#expandObject

Specifies which fields in the response should be expanded.



194
195
196
# File 'lib/stripe/services/invoice_line_item_service.rb', line 194

def expand
  @expand
end

#marginsObject

The IDs of the margins to apply to the line item. When set, the ‘default_margins` on the invoice do not apply to this line item.



196
197
198
# File 'lib/stripe/services/invoice_line_item_service.rb', line 196

def margins
  @margins
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`. For [type=subscription](stripe.com/docs/api/invoices/line_item#invoice_line_item_object-type) line items, the incoming metadata specified on the request is directly used to set this value, in contrast to [type=invoiceitem](api/invoices/line_item#invoice_line_item_object-type) line items, where any existing metadata on the invoice line is merged with the incoming data.



198
199
200
# File 'lib/stripe/services/invoice_line_item_service.rb', line 198

def 
  @metadata
end

#periodObject

The period associated with this invoice item. When set to different values, the period will be rendered on the invoice. If you have [Stripe Revenue Recognition](stripe.com/docs/revenue-recognition) enabled, the period will be used to recognize and defer revenue. See the [Revenue Recognition documentation](stripe.com/docs/revenue-recognition/methodology/subscriptions-and-invoicing) for details.



200
201
202
# File 'lib/stripe/services/invoice_line_item_service.rb', line 200

def period
  @period
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required.



202
203
204
# File 'lib/stripe/services/invoice_line_item_service.rb', line 202

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.



204
205
206
# File 'lib/stripe/services/invoice_line_item_service.rb', line 204

def price_data
  @price_data
end

#quantityObject

Non-negative integer. The quantity of units for the line item.



206
207
208
# File 'lib/stripe/services/invoice_line_item_service.rb', line 206

def quantity
  @quantity
end

#tax_amountsObject

A list of up to 10 tax amounts for this line item. This can be useful if you calculate taxes on your own or use a third-party to calculate them. You cannot set tax amounts if any line item has [tax_rates](stripe.com/docs/api/invoices/line_item#invoice_line_item_object-tax_rates) or if the invoice has [default_tax_rates](stripe.com/docs/api/invoices/object#invoice_object-default_tax_rates) or uses [automatic tax](stripe.com/docs/tax/invoicing). Pass an empty string to remove previously defined tax amounts.



208
209
210
# File 'lib/stripe/services/invoice_line_item_service.rb', line 208

def tax_amounts
  @tax_amounts
end

#tax_ratesObject

The tax rates which apply to the line item. When set, the ‘default_tax_rates` on the invoice do not apply to this line item. Pass an empty string to remove previously-defined tax rates.



210
211
212
# File 'lib/stripe/services/invoice_line_item_service.rb', line 210

def tax_rates
  @tax_rates
end