Class: Stripe::InvoiceLineItemService::UpdateParams::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_line_item_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



45
46
47
48
49
# File 'lib/stripe/services/invoice_line_item_service.rb', line 45

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



39
40
41
# File 'lib/stripe/services/invoice_line_item_service.rb', line 39

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



41
42
43
# File 'lib/stripe/services/invoice_line_item_service.rb', line 41

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



43
44
45
# File 'lib/stripe/services/invoice_line_item_service.rb', line 43

def type
  @type
end