Class: Stripe::InvoiceLineItemService::UpdateParams::PriceData::ProductData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceLineItemService::UpdateParams::PriceData::ProductData
- Defined in:
- lib/stripe/services/invoice_line_item_service.rb
Instance Attribute Summary collapse
-
#description ⇒ Object
The product’s description, meant to be displayable to the customer.
-
#images ⇒ Object
A list of up to 8 URLs of images for this product, meant to be displayable to the customer.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#name ⇒ Object
The product’s name, meant to be displayable to the customer.
-
#tax_code ⇒ Object
A [tax code](stripe.com/docs/tax/tax-categories) ID.
Instance Method Summary collapse
-
#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil) ⇒ ProductData
constructor
A new instance of ProductData.
Methods inherited from RequestParams
Constructor Details
#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil) ⇒ ProductData
Returns a new instance of ProductData.
93 94 95 96 97 98 99 |
# File 'lib/stripe/services/invoice_line_item_service.rb', line 93 def initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil) @description = description @images = images @metadata = @name = name @tax_code = tax_code end |
Instance Attribute Details
#description ⇒ Object
The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.
83 84 85 |
# File 'lib/stripe/services/invoice_line_item_service.rb', line 83 def description @description end |
#images ⇒ Object
A list of up to 8 URLs of images for this product, meant to be displayable to the customer.
85 86 87 |
# File 'lib/stripe/services/invoice_line_item_service.rb', line 85 def images @images end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
87 88 89 |
# File 'lib/stripe/services/invoice_line_item_service.rb', line 87 def @metadata end |
#name ⇒ Object
The product’s name, meant to be displayable to the customer.
89 90 91 |
# File 'lib/stripe/services/invoice_line_item_service.rb', line 89 def name @name end |
#tax_code ⇒ Object
A [tax code](stripe.com/docs/tax/tax-categories) ID.
91 92 93 |
# File 'lib/stripe/services/invoice_line_item_service.rb', line 91 def tax_code @tax_code end |