Class: Stripe::InvoiceLineItemService::UpdateParams::TaxAmount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceLineItemService::UpdateParams::TaxAmount
- Defined in:
- lib/stripe/services/invoice_line_item_service.rb
Defined Under Namespace
Classes: TaxRateData
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount, in cents (or local equivalent), of the tax.
-
#tax_rate_data ⇒ Object
Data to find or create a TaxRate object.
-
#taxability_reason ⇒ Object
The reasoning behind this tax, for example, if the product is tax exempt.
-
#taxable_amount ⇒ Object
The amount on which tax is calculated, in cents (or local equivalent).
Instance Method Summary collapse
-
#initialize(amount: nil, tax_rate_data: nil, taxability_reason: nil, taxable_amount: nil) ⇒ TaxAmount
constructor
A new instance of TaxAmount.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, tax_rate_data: nil, taxability_reason: nil, taxable_amount: nil) ⇒ TaxAmount
Returns a new instance of TaxAmount.
194 195 196 197 198 199 |
# File 'lib/stripe/services/invoice_line_item_service.rb', line 194 def initialize(amount: nil, tax_rate_data: nil, taxability_reason: nil, taxable_amount: nil) @amount = amount @tax_rate_data = tax_rate_data @taxability_reason = taxability_reason @taxable_amount = taxable_amount end |
Instance Attribute Details
#amount ⇒ Object
The amount, in cents (or local equivalent), of the tax.
184 185 186 |
# File 'lib/stripe/services/invoice_line_item_service.rb', line 184 def amount @amount end |
#tax_rate_data ⇒ Object
Data to find or create a TaxRate object.
Stripe automatically creates or reuses a TaxRate object for each tax amount. If the ‘tax_rate_data` exactly matches a previous value, Stripe will reuse the TaxRate object. TaxRate objects created automatically by Stripe are immediately archived, do not appear in the line item’s `tax_rates`, and cannot be directly added to invoices, payments, or line items.
188 189 190 |
# File 'lib/stripe/services/invoice_line_item_service.rb', line 188 def tax_rate_data @tax_rate_data end |
#taxability_reason ⇒ Object
The reasoning behind this tax, for example, if the product is tax exempt.
190 191 192 |
# File 'lib/stripe/services/invoice_line_item_service.rb', line 190 def taxability_reason @taxability_reason end |
#taxable_amount ⇒ Object
The amount on which tax is calculated, in cents (or local equivalent).
192 193 194 |
# File 'lib/stripe/services/invoice_line_item_service.rb', line 192 def taxable_amount @taxable_amount end |