Class: Stripe::InvoiceLineItemUpdateParams::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_line_item_update_params.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



41
42
43
44
45
46
# File 'lib/stripe/params/invoice_line_item_update_params.rb', line 41

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



33
34
35
# File 'lib/stripe/params/invoice_line_item_update_params.rb', line 33

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



35
36
37
# File 'lib/stripe/params/invoice_line_item_update_params.rb', line 35

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



37
38
39
# File 'lib/stripe/params/invoice_line_item_update_params.rb', line 37

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



39
40
41
# File 'lib/stripe/params/invoice_line_item_update_params.rb', line 39

def promotion_code
  @promotion_code
end