Class: Stripe::InvoiceLineItemUpdateParams::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_line_item_update_params.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



26
27
28
29
30
# File 'lib/stripe/params/invoice_line_item_update_params.rb', line 26

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



20
21
22
# File 'lib/stripe/params/invoice_line_item_update_params.rb', line 20

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



22
23
24
# File 'lib/stripe/params/invoice_line_item_update_params.rb', line 22

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



24
25
26
# File 'lib/stripe/params/invoice_line_item_update_params.rb', line 24

def type
  @type
end