Class: Stripe::InvoiceLineItemUpdateParams::PriceData::ProductData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_line_item_update_params.rb

Defined Under Namespace

Classes: TaxDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil, tax_details: nil, unit_label: nil) ⇒ ProductData

Returns a new instance of ProductData.



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/stripe/params/invoice_line_item_update_params.rb', line 89

def initialize(
  description: nil,
  images: nil,
  metadata: nil,
  name: nil,
  tax_code: nil,
  tax_details: nil,
  unit_label: nil
)
  @description = description
  @images = images
  @metadata = 
  @name = name
  @tax_code = tax_code
  @tax_details = tax_details
  @unit_label = unit_label
end

Instance Attribute Details

#descriptionObject

The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.



75
76
77
# File 'lib/stripe/params/invoice_line_item_update_params.rb', line 75

def description
  @description
end

#imagesObject

A list of up to 8 URLs of images for this product, meant to be displayable to the customer.



77
78
79
# File 'lib/stripe/params/invoice_line_item_update_params.rb', line 77

def images
  @images
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



79
80
81
# File 'lib/stripe/params/invoice_line_item_update_params.rb', line 79

def 
  @metadata
end

#nameObject

The product’s name, meant to be displayable to the customer.



81
82
83
# File 'lib/stripe/params/invoice_line_item_update_params.rb', line 81

def name
  @name
end

#tax_codeObject



83
84
85
# File 'lib/stripe/params/invoice_line_item_update_params.rb', line 83

def tax_code
  @tax_code
end

#tax_detailsObject

Tax details for this product, including the [tax code](/tax/tax-codes) and an optional performance location.



85
86
87
# File 'lib/stripe/params/invoice_line_item_update_params.rb', line 85

def tax_details
  @tax_details
end

#unit_labelObject

A label that represents units of this product. When set, this will be included in customers’ receipts, invoices, Checkout, and the customer portal.



87
88
89
# File 'lib/stripe/params/invoice_line_item_update_params.rb', line 87

def unit_label
  @unit_label
end