Class: Stripe::InvoicePayment::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/invoice_payment.rb

Defined Under Namespace

Classes: Payment

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(ending_before: nil, expand: nil, invoice: nil, limit: nil, payment: nil, starting_after: nil, status: nil) ⇒ ListParams

Returns a new instance of ListParams.



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/stripe/resources/invoice_payment.rb', line 69

def initialize(
  ending_before: nil,
  expand: nil,
  invoice: nil,
  limit: nil,
  payment: nil,
  starting_after: nil,
  status: nil
)
  @ending_before = ending_before
  @expand = expand
  @invoice = invoice
  @limit = limit
  @payment = payment
  @starting_after = starting_after
  @status = status
end

Instance Attribute Details

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



55
56
57
# File 'lib/stripe/resources/invoice_payment.rb', line 55

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



57
58
59
# File 'lib/stripe/resources/invoice_payment.rb', line 57

def expand
  @expand
end

#invoiceObject

The identifier of the invoice whose payments to return.



59
60
61
# File 'lib/stripe/resources/invoice_payment.rb', line 59

def invoice
  @invoice
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



61
62
63
# File 'lib/stripe/resources/invoice_payment.rb', line 61

def limit
  @limit
end

#paymentObject

The payment details of the invoice payments to return.



63
64
65
# File 'lib/stripe/resources/invoice_payment.rb', line 63

def payment
  @payment
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



65
66
67
# File 'lib/stripe/resources/invoice_payment.rb', line 65

def starting_after
  @starting_after
end

#statusObject

The status of the invoice payments to return.



67
68
69
# File 'lib/stripe/resources/invoice_payment.rb', line 67

def status
  @status
end