Class: Stripe::InvoicePayment::ListParams::Payment

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice_payment.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(payment_intent: nil, payment_record: nil, type: nil) ⇒ Payment

Returns a new instance of Payment.



64
65
66
67
68
# File 'lib/stripe/resources/invoice_payment.rb', line 64

def initialize(payment_intent: nil, payment_record: nil, type: nil)
  @payment_intent = payment_intent
  @payment_record = payment_record
  @type = type
end

Instance Attribute Details

#payment_intentObject

Only return invoice payments associated by this payment intent ID.



58
59
60
# File 'lib/stripe/resources/invoice_payment.rb', line 58

def payment_intent
  @payment_intent
end

#payment_recordObject

Only return invoice payments associated by this payment record ID.



60
61
62
# File 'lib/stripe/resources/invoice_payment.rb', line 60

def payment_record
  @payment_record
end

#typeObject

Only return invoice payments associated by this payment type.



62
63
64
# File 'lib/stripe/resources/invoice_payment.rb', line 62

def type
  @type
end