Class: Stripe::InvoicePayment::Payment
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::InvoicePayment::Payment
- Defined in:
- lib/stripe/resources/invoice_payment.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#charge ⇒ Object
readonly
ID of the successful charge for this payment when ‘type` is `charge`.Note: charge is only surfaced if the charge object is not associated with a payment intent.
-
#payment_intent ⇒ Object
readonly
ID of the PaymentIntent associated with this payment when ‘type` is `payment_intent`.
-
#type ⇒ Object
readonly
Type of payment object associated with this invoice payment.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#charge ⇒ Object (readonly)
ID of the successful charge for this payment when ‘type` is `charge`.Note: charge is only surfaced if the charge object is not associated with a payment intent. If the charge object does have a payment intent, the Invoice Payment surfaces the payment intent instead.
23 24 25 |
# File 'lib/stripe/resources/invoice_payment.rb', line 23 def charge @charge end |
#payment_intent ⇒ Object (readonly)
ID of the PaymentIntent associated with this payment when ‘type` is `payment_intent`. Note: This property is only populated for invoices finalized on or after March 15th, 2019.
25 26 27 |
# File 'lib/stripe/resources/invoice_payment.rb', line 25 def payment_intent @payment_intent end |
#type ⇒ Object (readonly)
Type of payment object associated with this invoice payment.
27 28 29 |
# File 'lib/stripe/resources/invoice_payment.rb', line 27 def type @type end |