Class: Stripe::InvoicePaymentService::ListParams::Payment

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_payment_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(payment_intent: nil, payment_record: nil, type: nil) ⇒ Payment

Returns a new instance of Payment.



15
16
17
18
19
# File 'lib/stripe/services/invoice_payment_service.rb', line 15

def initialize(payment_intent: nil, payment_record: nil, type: nil)
  @payment_intent = payment_intent
  @payment_record = payment_record
  @type = type
end

Instance Attribute Details

#payment_intentObject

Only return invoice payments associated by this payment intent ID.



9
10
11
# File 'lib/stripe/services/invoice_payment_service.rb', line 9

def payment_intent
  @payment_intent
end

#payment_recordObject

Only return invoice payments associated by this payment record ID.



11
12
13
# File 'lib/stripe/services/invoice_payment_service.rb', line 11

def payment_record
  @payment_record
end

#typeObject

Only return invoice payments associated by this payment type.



13
14
15
# File 'lib/stripe/services/invoice_payment_service.rb', line 13

def type
  @type
end