Class: Stripe::InvoiceRenderingTemplate::RetrieveParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceRenderingTemplate::RetrieveParams
- Defined in:
- lib/stripe/resources/invoice_rendering_template.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#version ⇒ Object
Attribute for param field version.
Instance Method Summary collapse
-
#initialize(expand: nil, version: nil) ⇒ RetrieveParams
constructor
A new instance of RetrieveParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, version: nil) ⇒ RetrieveParams
Returns a new instance of RetrieveParams.
42 43 44 45 |
# File 'lib/stripe/resources/invoice_rendering_template.rb', line 42 def initialize(expand: nil, version: nil) @expand = @version = version end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
38 39 40 |
# File 'lib/stripe/resources/invoice_rendering_template.rb', line 38 def @expand end |
#version ⇒ Object
Attribute for param field version
40 41 42 |
# File 'lib/stripe/resources/invoice_rendering_template.rb', line 40 def version @version end |