Class: Stripe::InvoiceRenderingTemplateService::RetrieveParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceRenderingTemplateService::RetrieveParams
- Defined in:
- lib/stripe/services/invoice_rendering_template_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#version ⇒ Object
Attribute for param field version.
Instance Method Summary collapse
-
#initialize(expand: nil, version: nil) ⇒ RetrieveParams
constructor
A new instance of RetrieveParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, version: nil) ⇒ RetrieveParams
Returns a new instance of RetrieveParams.
38 39 40 41 |
# File 'lib/stripe/services/invoice_rendering_template_service.rb', line 38 def initialize(expand: nil, version: nil) @expand = @version = version end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
33 34 35 |
# File 'lib/stripe/services/invoice_rendering_template_service.rb', line 33 def @expand end |
#version ⇒ Object
Attribute for param field version
36 37 38 |
# File 'lib/stripe/services/invoice_rendering_template_service.rb', line 36 def version @version end |