Class: Stripe::InvoiceService::AddLinesParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::AddLinesParams
- Defined in:
- lib/stripe/services/invoice_service.rb
Defined Under Namespace
Classes: Line
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#invoice_metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#lines ⇒ Object
The line items to add.
Instance Method Summary collapse
-
#initialize(expand: nil, invoice_metadata: nil, lines: nil) ⇒ AddLinesParams
constructor
A new instance of AddLinesParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, invoice_metadata: nil, lines: nil) ⇒ AddLinesParams
Returns a new instance of AddLinesParams.
1701 1702 1703 1704 1705 |
# File 'lib/stripe/services/invoice_service.rb', line 1701 def initialize(expand: nil, invoice_metadata: nil, lines: nil) @expand = @invoice_metadata = @lines = lines end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1695 1696 1697 |
# File 'lib/stripe/services/invoice_service.rb', line 1695 def @expand end |
#invoice_metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
1697 1698 1699 |
# File 'lib/stripe/services/invoice_service.rb', line 1697 def @invoice_metadata end |
#lines ⇒ Object
The line items to add.
1699 1700 1701 |
# File 'lib/stripe/services/invoice_service.rb', line 1699 def lines @lines end |