Class: Stripe::InvoiceService::AddLinesParams::Line::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::AddLinesParams::Line::Discount::DiscountEnd
- Defined in:
- lib/stripe/services/invoice_service.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
1476 1477 1478 1479 1480 |
# File 'lib/stripe/services/invoice_service.rb', line 1476 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
1470 1471 1472 |
# File 'lib/stripe/services/invoice_service.rb', line 1470 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
1472 1473 1474 |
# File 'lib/stripe/services/invoice_service.rb', line 1472 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
1474 1475 1476 |
# File 'lib/stripe/services/invoice_service.rb', line 1474 def type @type end |