Class: Stripe::InvoiceService::AddLinesParams::Line::Period
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::AddLinesParams::Line::Period
- Defined in:
- lib/stripe/services/invoice_service.rb
Instance Attribute Summary collapse
-
#end ⇒ Object
The end of the period, which must be greater than or equal to the start.
-
#start ⇒ Object
The start of the period.
Instance Method Summary collapse
-
#initialize(end_: nil, start: nil) ⇒ Period
constructor
A new instance of Period.
Methods inherited from RequestParams
Constructor Details
#initialize(end_: nil, start: nil) ⇒ Period
Returns a new instance of Period.
3778 3779 3780 3781 |
# File 'lib/stripe/services/invoice_service.rb', line 3778 def initialize(end_: nil, start: nil) @end = end_ @start = start end |
Instance Attribute Details
#end ⇒ Object
The end of the period, which must be greater than or equal to the start. This value is inclusive.
3773 3774 3775 |
# File 'lib/stripe/services/invoice_service.rb', line 3773 def end @end end |
#start ⇒ Object
The start of the period. This value is inclusive.
3776 3777 3778 |
# File 'lib/stripe/services/invoice_service.rb', line 3776 def start @start end |