Class: Stripe::InvoiceService::AttachPaymentIntentParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::AttachPaymentIntentParams
- Defined in:
- lib/stripe/services/invoice_service.rb
Instance Attribute Summary collapse
-
#amount_requested ⇒ Object
The portion of the PaymentIntent’s ‘amount` that should be applied to thisinvoice.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#payment_intent ⇒ Object
The ID of the PaymentIntent to attach to the invoice.
Instance Method Summary collapse
-
#initialize(amount_requested: nil, expand: nil, payment_intent: nil) ⇒ AttachPaymentIntentParams
constructor
A new instance of AttachPaymentIntentParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount_requested: nil, expand: nil, payment_intent: nil) ⇒ AttachPaymentIntentParams
Returns a new instance of AttachPaymentIntentParams.
1725 1726 1727 1728 1729 |
# File 'lib/stripe/services/invoice_service.rb', line 1725 def initialize(amount_requested: nil, expand: nil, payment_intent: nil) @amount_requested = amount_requested @expand = @payment_intent = payment_intent end |
Instance Attribute Details
#amount_requested ⇒ Object
The portion of the PaymentIntent’s ‘amount` that should be applied to thisinvoice. Defaults to the entire amount.
1719 1720 1721 |
# File 'lib/stripe/services/invoice_service.rb', line 1719 def amount_requested @amount_requested end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1721 1722 1723 |
# File 'lib/stripe/services/invoice_service.rb', line 1721 def @expand end |
#payment_intent ⇒ Object
The ID of the PaymentIntent to attach to the invoice.
1723 1724 1725 |
# File 'lib/stripe/services/invoice_service.rb', line 1723 def payment_intent @payment_intent end |