Class: Stripe::InvoiceService::AttachPaymentParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: PaymentRecordData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_requested: nil, expand: nil, payment_intent: nil, payment_record: nil, payment_record_data: nil) ⇒ AttachPaymentParams

Returns a new instance of AttachPaymentParams.



1750
1751
1752
1753
1754
1755
1756
1757
1758
1759
1760
1761
1762
# File 'lib/stripe/services/invoice_service.rb', line 1750

def initialize(
  amount_requested: nil,
  expand: nil,
  payment_intent: nil,
  payment_record: nil,
  payment_record_data: nil
)
  @amount_requested = amount_requested
  @expand = expand
  @payment_intent = payment_intent
  @payment_record = payment_record
  @payment_record_data = payment_record_data
end

Instance Attribute Details

#amount_requestedObject

The portion of the ‘amount` on the PaymentIntent or out of band payment to apply to this invoice. It defaults to the entire amount.



1740
1741
1742
# File 'lib/stripe/services/invoice_service.rb', line 1740

def amount_requested
  @amount_requested
end

#expandObject

Specifies which fields in the response should be expanded.



1742
1743
1744
# File 'lib/stripe/services/invoice_service.rb', line 1742

def expand
  @expand
end

#payment_intentObject

The ID of the PaymentIntent to attach to the invoice.



1744
1745
1746
# File 'lib/stripe/services/invoice_service.rb', line 1744

def payment_intent
  @payment_intent
end

#payment_recordObject

The ID of the PaymentRecord to attach to the invoice.



1746
1747
1748
# File 'lib/stripe/services/invoice_service.rb', line 1746

def payment_record
  @payment_record
end

#payment_record_dataObject

The PaymentRecord data for attaching an out of band payment to the invoice.



1748
1749
1750
# File 'lib/stripe/services/invoice_service.rb', line 1748

def payment_record_data
  @payment_record_data
end