Class: Stripe::InvoiceService::CreateParams::AmountsDue
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::CreateParams::AmountsDue
- Defined in:
- lib/stripe/services/invoice_service.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount in cents (or local equivalent).
-
#days_until_due ⇒ Object
Number of days from when invoice is finalized until the payment is due.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#due_date ⇒ Object
Date on which a payment plan’s payment is due.
Instance Method Summary collapse
-
#initialize(amount: nil, days_until_due: nil, description: nil, due_date: nil) ⇒ AmountsDue
constructor
A new instance of AmountsDue.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, days_until_due: nil, description: nil, due_date: nil) ⇒ AmountsDue
Returns a new instance of AmountsDue.
740 741 742 743 744 745 |
# File 'lib/stripe/services/invoice_service.rb', line 740 def initialize(amount: nil, days_until_due: nil, description: nil, due_date: nil) @amount = amount @days_until_due = days_until_due @description = description @due_date = due_date end |
Instance Attribute Details
#amount ⇒ Object
The amount in cents (or local equivalent).
732 733 734 |
# File 'lib/stripe/services/invoice_service.rb', line 732 def amount @amount end |
#days_until_due ⇒ Object
Number of days from when invoice is finalized until the payment is due.
734 735 736 |
# File 'lib/stripe/services/invoice_service.rb', line 734 def days_until_due @days_until_due end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
736 737 738 |
# File 'lib/stripe/services/invoice_service.rb', line 736 def description @description end |
#due_date ⇒ Object
Date on which a payment plan’s payment is due.
738 739 740 |
# File 'lib/stripe/services/invoice_service.rb', line 738 def due_date @due_date end |