Class: Stripe::InvoiceService::CreateParams::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



707
708
709
710
711
# File 'lib/stripe/services/invoice_service.rb', line 707

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



701
702
703
# File 'lib/stripe/services/invoice_service.rb', line 701

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



703
704
705
# File 'lib/stripe/services/invoice_service.rb', line 703

def discount
  @discount
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



705
706
707
# File 'lib/stripe/services/invoice_service.rb', line 705

def promotion_code
  @promotion_code
end