Class: Stripe::InvoiceService::CreateParams::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



829
830
831
832
833
# File 'lib/stripe/services/invoice_service.rb', line 829

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



823
824
825
# File 'lib/stripe/services/invoice_service.rb', line 823

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



825
826
827
# File 'lib/stripe/services/invoice_service.rb', line 825

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



827
828
829
# File 'lib/stripe/services/invoice_service.rb', line 827

def type
  @type
end