Class: Stripe::InvoiceService::CreateParams::PaymentSettings::PaymentMethodOptions::Card::Installments::Plan
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::CreateParams::PaymentSettings::PaymentMethodOptions::Card::Installments::Plan
- Defined in:
- lib/stripe/services/invoice_service.rb
Instance Attribute Summary collapse
-
#count ⇒ Object
For ‘fixed_count` installment plans, this is required.
-
#interval ⇒ Object
For ‘fixed_count` installment plans, this is required.
-
#type ⇒ Object
Type of installment plan, one of ‘fixed_count`.
Instance Method Summary collapse
-
#initialize(count: nil, interval: nil, type: nil) ⇒ Plan
constructor
A new instance of Plan.
Methods inherited from RequestParams
Constructor Details
#initialize(count: nil, interval: nil, type: nil) ⇒ Plan
Returns a new instance of Plan.
888 889 890 891 892 |
# File 'lib/stripe/services/invoice_service.rb', line 888 def initialize(count: nil, interval: nil, type: nil) @count = count @interval = interval @type = type end |
Instance Attribute Details
#count ⇒ Object
For ‘fixed_count` installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.
881 882 883 |
# File 'lib/stripe/services/invoice_service.rb', line 881 def count @count end |
#interval ⇒ Object
For ‘fixed_count` installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of `month`.
884 885 886 |
# File 'lib/stripe/services/invoice_service.rb', line 884 def interval @interval end |
#type ⇒ Object
Type of installment plan, one of ‘fixed_count`.
886 887 888 |
# File 'lib/stripe/services/invoice_service.rb', line 886 def type @type end |