Class: Stripe::InvoiceService::CreateParams::PaymentSettings::PaymentMethodOptions::CustomerBalance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: BankTransfer

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bank_transfer: nil, funding_type: nil) ⇒ CustomerBalance

Returns a new instance of CustomerBalance.



831
832
833
834
# File 'lib/stripe/services/invoice_service.rb', line 831

def initialize(bank_transfer: nil, funding_type: nil)
  @bank_transfer = bank_transfer
  @funding_type = funding_type
end

Instance Attribute Details

#bank_transferObject

Configuration for the bank transfer funding type, if the ‘funding_type` is set to `bank_transfer`.



827
828
829
# File 'lib/stripe/services/invoice_service.rb', line 827

def bank_transfer
  @bank_transfer
end

#funding_typeObject

The funding method type to be used when there are not enough funds in the customer balance. Permitted values include: ‘bank_transfer`.



829
830
831
# File 'lib/stripe/services/invoice_service.rb', line 829

def funding_type
  @funding_type
end