Class: Stripe::InvoiceService::CreateParams::Rendering

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Pdf

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_tax_display: nil, pdf: nil, template: nil, template_version: nil) ⇒ Rendering

Returns a new instance of Rendering.



1120
1121
1122
1123
1124
1125
# File 'lib/stripe/services/invoice_service.rb', line 1120

def initialize(amount_tax_display: nil, pdf: nil, template: nil, template_version: nil)
  @amount_tax_display = amount_tax_display
  @pdf = pdf
  @template = template
  @template_version = template_version
end

Instance Attribute Details

#amount_tax_displayObject

How line-item prices and amounts will be displayed with respect to tax on invoice PDFs. One of ‘exclude_tax` or `include_inclusive_tax`. `include_inclusive_tax` will include inclusive tax (and exclude exclusive tax) in invoice PDF amounts. `exclude_tax` will exclude all tax (inclusive and exclusive alike) from invoice PDF amounts.



1112
1113
1114
# File 'lib/stripe/services/invoice_service.rb', line 1112

def amount_tax_display
  @amount_tax_display
end

#pdfObject

Invoice pdf rendering options



1114
1115
1116
# File 'lib/stripe/services/invoice_service.rb', line 1114

def pdf
  @pdf
end

#templateObject

ID of the invoice rendering template to use for this invoice.



1116
1117
1118
# File 'lib/stripe/services/invoice_service.rb', line 1116

def template
  @template
end

#template_versionObject

The specific version of invoice rendering template to use for this invoice.



1118
1119
1120
# File 'lib/stripe/services/invoice_service.rb', line 1118

def template_version
  @template_version
end