Class: Stripe::InvoiceService::CreateParams::ShippingCost::ShippingRateData::FixedAmount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::CreateParams::ShippingCost::ShippingRateData::FixedAmount
- Defined in:
- lib/stripe/services/invoice_service.rb
Defined Under Namespace
Classes: CurrencyOptions
Instance Attribute Summary collapse
-
#amount ⇒ Object
A non-negative integer in cents representing how much to charge.
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#currency_options ⇒ Object
Shipping rates defined in each available currency option.
Instance Method Summary collapse
-
#initialize(amount: nil, currency: nil, currency_options: nil) ⇒ FixedAmount
constructor
A new instance of FixedAmount.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, currency: nil, currency_options: nil) ⇒ FixedAmount
Returns a new instance of FixedAmount.
1136 1137 1138 1139 1140 |
# File 'lib/stripe/services/invoice_service.rb', line 1136 def initialize(amount: nil, currency: nil, currency_options: nil) @amount = amount @currency = currency @currency_options = end |
Instance Attribute Details
#amount ⇒ Object
A non-negative integer in cents representing how much to charge.
1130 1131 1132 |
# File 'lib/stripe/services/invoice_service.rb', line 1130 def amount @amount end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
1132 1133 1134 |
# File 'lib/stripe/services/invoice_service.rb', line 1132 def currency @currency end |
#currency_options ⇒ Object
Shipping rates defined in each available currency option. Each key must be a three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html) and a [supported currency](stripe.com/docs/currencies).
1134 1135 1136 |
# File 'lib/stripe/services/invoice_service.rb', line 1134 def @currency_options end |