Class: Stripe::InvoiceService::CreateParams::TransferData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::CreateParams::TransferData
- Defined in:
- lib/stripe/services/invoice_service.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount that will be transferred automatically when the invoice is paid.
-
#destination ⇒ Object
ID of an existing, connected Stripe account.
Instance Method Summary collapse
-
#initialize(amount: nil, destination: nil) ⇒ TransferData
constructor
A new instance of TransferData.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, destination: nil) ⇒ TransferData
Returns a new instance of TransferData.
1392 1393 1394 1395 |
# File 'lib/stripe/services/invoice_service.rb', line 1392 def initialize(amount: nil, destination: nil) @amount = amount @destination = destination end |
Instance Attribute Details
#amount ⇒ Object
The amount that will be transferred automatically when the invoice is paid. If no amount is set, the full amount is transferred.
1387 1388 1389 |
# File 'lib/stripe/services/invoice_service.rb', line 1387 def amount @amount end |
#destination ⇒ Object
ID of an existing, connected Stripe account.
1390 1391 1392 |
# File 'lib/stripe/services/invoice_service.rb', line 1390 def destination @destination end |