Class: Stripe::InvoiceService::CreatePreviewParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: AutomaticTax, CustomerDetails, Discount, InvoiceItem, Issuer, ScheduleDetails, SubscriptionDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(automatic_tax: nil, billing_cadence: nil, currency: nil, customer: nil, customer_account: nil, customer_details: nil, discounts: nil, expand: nil, invoice_items: nil, issuer: nil, on_behalf_of: nil, preview_mode: nil, schedule: nil, schedule_details: nil, subscription: nil, subscription_details: nil) ⇒ CreatePreviewParams

Returns a new instance of CreatePreviewParams.



3816
3817
3818
3819
3820
3821
3822
3823
3824
3825
3826
3827
3828
3829
3830
3831
3832
3833
3834
3835
3836
3837
3838
3839
3840
3841
3842
3843
3844
3845
3846
3847
3848
3849
3850
# File 'lib/stripe/services/invoice_service.rb', line 3816

def initialize(
  automatic_tax: nil,
  billing_cadence: nil,
  currency: nil,
  customer: nil,
  customer_account: nil,
  customer_details: nil,
  discounts: nil,
  expand: nil,
  invoice_items: nil,
  issuer: nil,
  on_behalf_of: nil,
  preview_mode: nil,
  schedule: nil,
  schedule_details: nil,
  subscription: nil,
  subscription_details: nil
)
  @automatic_tax = automatic_tax
  @billing_cadence = billing_cadence
  @currency = currency
  @customer = customer
  @customer_account = 
  @customer_details = customer_details
  @discounts = discounts
  @expand = expand
  @invoice_items = invoice_items
  @issuer = issuer
  @on_behalf_of = on_behalf_of
  @preview_mode = preview_mode
  @schedule = schedule
  @schedule_details = schedule_details
  @subscription = subscription
  @subscription_details = subscription_details
end

Instance Attribute Details

#automatic_taxObject

Settings for automatic tax lookup for this invoice preview.



3784
3785
3786
# File 'lib/stripe/services/invoice_service.rb', line 3784

def automatic_tax
  @automatic_tax
end

#billing_cadenceObject

The identifier of the billing cadence for which you’d like to retrieve the upcoming invoice.Cannot be provided when ‘subscription`, `schedule`, `subscription_details` or `schedule_details` are provided.



3786
3787
3788
# File 'lib/stripe/services/invoice_service.rb', line 3786

def billing_cadence
  @billing_cadence
end

#currencyObject

The currency to preview this invoice in. Defaults to that of ‘customer` if not specified.



3788
3789
3790
# File 'lib/stripe/services/invoice_service.rb', line 3788

def currency
  @currency
end

#customerObject

The identifier of the customer whose upcoming invoice you’d like to retrieve. If ‘automatic_tax` is enabled then one of `customer`, `customer_details`, `subscription`, or `schedule` must be set.



3790
3791
3792
# File 'lib/stripe/services/invoice_service.rb', line 3790

def customer
  @customer
end

#customer_accountObject

The identifier of the account whose upcoming invoice you’d like to retrieve. If ‘automatic_tax` is enabled then one of `customer`, `customer_account`, `customer_details`, `subscription`, or `schedule` must be set.



3792
3793
3794
# File 'lib/stripe/services/invoice_service.rb', line 3792

def 
  @customer_account
end

#customer_detailsObject

Details about the customer you want to invoice or overrides for an existing customer. If ‘automatic_tax` is enabled then one of `customer`, `customer_details`, `subscription`, or `schedule` must be set.



3794
3795
3796
# File 'lib/stripe/services/invoice_service.rb', line 3794

def customer_details
  @customer_details
end

#discountsObject

The coupons to redeem into discounts for the invoice preview. If not specified, inherits the discount from the subscription or customer. This works for both coupons directly applied to an invoice and coupons applied to a subscription. Pass an empty string to avoid inheriting any discounts.



3796
3797
3798
# File 'lib/stripe/services/invoice_service.rb', line 3796

def discounts
  @discounts
end

#expandObject

Specifies which fields in the response should be expanded.



3798
3799
3800
# File 'lib/stripe/services/invoice_service.rb', line 3798

def expand
  @expand
end

#invoice_itemsObject

List of invoice items to add or update in the upcoming invoice preview (up to 250).



3800
3801
3802
# File 'lib/stripe/services/invoice_service.rb', line 3800

def invoice_items
  @invoice_items
end

#issuerObject

The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.



3802
3803
3804
# File 'lib/stripe/services/invoice_service.rb', line 3802

def issuer
  @issuer
end

#on_behalf_ofObject

The account (if any) for which the funds of the invoice payment are intended. If set, the invoice will be presented with the branding and support information of the specified account. See the [Invoices with Connect](stripe.com/docs/billing/invoices/connect) documentation for details.



3804
3805
3806
# File 'lib/stripe/services/invoice_service.rb', line 3804

def on_behalf_of
  @on_behalf_of
end

#preview_modeObject

Customizes the types of values to include when calculating the invoice. Defaults to ‘next` if unspecified.



3806
3807
3808
# File 'lib/stripe/services/invoice_service.rb', line 3806

def preview_mode
  @preview_mode
end

#scheduleObject

The identifier of the schedule whose upcoming invoice you’d like to retrieve. Cannot be used with subscription or subscription fields.



3808
3809
3810
# File 'lib/stripe/services/invoice_service.rb', line 3808

def schedule
  @schedule
end

#schedule_detailsObject

The schedule creation or modification params to apply as a preview. Cannot be used with ‘subscription` or `subscription_` prefixed fields.



3810
3811
3812
# File 'lib/stripe/services/invoice_service.rb', line 3810

def schedule_details
  @schedule_details
end

#subscriptionObject

The identifier of the subscription for which you’d like to retrieve the upcoming invoice. If not provided, but a ‘subscription_details.items` is provided, you will preview creating a subscription with those items. If neither `subscription` nor `subscription_details.items` is provided, you will retrieve the next upcoming invoice from among the customer’s subscriptions.



3812
3813
3814
# File 'lib/stripe/services/invoice_service.rb', line 3812

def subscription
  @subscription
end

#subscription_detailsObject

The subscription creation or modification params to apply as a preview. Cannot be used with ‘schedule` or `schedule_details` fields.



3814
3815
3816
# File 'lib/stripe/services/invoice_service.rb', line 3814

def subscription_details
  @subscription_details
end