Class: Stripe::InvoiceService::CreatePreviewParams::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1969
1970
1971
1972
1973
# File 'lib/stripe/services/invoice_service.rb', line 1969

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1963
1964
1965
# File 'lib/stripe/services/invoice_service.rb', line 1963

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1965
1966
1967
# File 'lib/stripe/services/invoice_service.rb', line 1965

def discount
  @discount
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1967
1968
1969
# File 'lib/stripe/services/invoice_service.rb', line 1967

def promotion_code
  @promotion_code
end