Class: Stripe::InvoiceService::CreatePreviewParams::InvoiceItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1985
1986
1987
1988
1989
# File 'lib/stripe/services/invoice_service.rb', line 1985

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1979
1980
1981
# File 'lib/stripe/services/invoice_service.rb', line 1979

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1981
1982
1983
# File 'lib/stripe/services/invoice_service.rb', line 1981

def discount
  @discount
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1983
1984
1985
# File 'lib/stripe/services/invoice_service.rb', line 1983

def promotion_code
  @promotion_code
end