Class: Stripe::InvoiceService::CreatePreviewParams::InvoiceItem::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::CreatePreviewParams::InvoiceItem::Discount::DiscountEnd
- Defined in:
- lib/stripe/services/invoice_service.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
2266 2267 2268 2269 2270 |
# File 'lib/stripe/services/invoice_service.rb', line 2266 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
2260 2261 2262 |
# File 'lib/stripe/services/invoice_service.rb', line 2260 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
2262 2263 2264 |
# File 'lib/stripe/services/invoice_service.rb', line 2262 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
2264 2265 2266 |
# File 'lib/stripe/services/invoice_service.rb', line 2264 def type @type end |