Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: BillingMode, Phase

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_mode: nil, end_behavior: nil, phases: nil, proration_behavior: nil) ⇒ ScheduleDetails

Returns a new instance of ScheduleDetails.



2543
2544
2545
2546
2547
2548
# File 'lib/stripe/services/invoice_service.rb', line 2543

def initialize(billing_mode: nil, end_behavior: nil, phases: nil, proration_behavior: nil)
  @billing_mode = billing_mode
  @end_behavior = end_behavior
  @phases = phases
  @proration_behavior = proration_behavior
end

Instance Attribute Details

#billing_modeObject

Controls how prorations and invoices for subscriptions are calculated and orchestrated.



2535
2536
2537
# File 'lib/stripe/services/invoice_service.rb', line 2535

def billing_mode
  @billing_mode
end

#end_behaviorObject

Behavior of the subscription schedule and underlying subscription when it ends. Possible values are ‘release` or `cancel` with the default being `release`. `release` will end the subscription schedule and keep the underlying subscription running. `cancel` will end the subscription schedule and cancel the underlying subscription.



2537
2538
2539
# File 'lib/stripe/services/invoice_service.rb', line 2537

def end_behavior
  @end_behavior
end

#phasesObject

List representing phases of the subscription schedule. Each phase can be customized to have different durations, plans, and coupons. If there are multiple phases, the ‘end_date` of one phase will always equal the `start_date` of the next phase.



2539
2540
2541
# File 'lib/stripe/services/invoice_service.rb', line 2539

def phases
  @phases
end

#proration_behaviorObject

In cases where the ‘schedule_details` params update the currently active phase, specifies if and how to prorate at the time of the request.



2541
2542
2543
# File 'lib/stripe/services/invoice_service.rb', line 2541

def proration_behavior
  @proration_behavior
end