Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Amendment

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: AmendmentEnd, AmendmentStart, DiscountAction, ItemAction, MetadataAction, SetPauseCollection, TrialSettings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendment_end: nil, amendment_start: nil, billing_cycle_anchor: nil, discount_actions: nil, item_actions: nil, metadata_actions: nil, proration_behavior: nil, set_pause_collection: nil, set_schedule_end: nil, trial_settings: nil) ⇒ Amendment

Returns a new instance of Amendment.



2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
2917
2918
2919
# File 'lib/stripe/services/invoice_service.rb', line 2897

def initialize(
  amendment_end: nil,
  amendment_start: nil,
  billing_cycle_anchor: nil,
  discount_actions: nil,
  item_actions: nil,
  metadata_actions: nil,
  proration_behavior: nil,
  set_pause_collection: nil,
  set_schedule_end: nil,
  trial_settings: nil
)
  @amendment_end = amendment_end
  @amendment_start = amendment_start
  @billing_cycle_anchor = billing_cycle_anchor
  @discount_actions = discount_actions
  @item_actions = item_actions
  @metadata_actions = 
  @proration_behavior = proration_behavior
  @set_pause_collection = set_pause_collection
  @set_schedule_end = set_schedule_end
  @trial_settings = trial_settings
end

Instance Attribute Details

#amendment_endObject

Details to identify the end of the time range modified by the proposed change. If not supplied, the amendment is considered a point-in-time operation that only affects the exact timestamp at ‘amendment_start`, and a restricted set of attributes is supported on the amendment.



2877
2878
2879
# File 'lib/stripe/services/invoice_service.rb', line 2877

def amendment_end
  @amendment_end
end

#amendment_startObject

Details to identify the earliest timestamp where the proposed change should take effect.



2879
2880
2881
# File 'lib/stripe/services/invoice_service.rb', line 2879

def amendment_start
  @amendment_start
end

#billing_cycle_anchorObject

For point-in-time amendments (having no ‘amendment_end`), this attribute lets you set or remove whether the subscription’s billing cycle anchor is reset at the ‘amendment_start` timestamp.For time-span based amendments (having both `amendment_start` and `amendment_end`), the only value valid is `automatic`, which removes any previously configured billing cycle anchor resets scheduled to occur during the window of time spanned by the amendment.



2881
2882
2883
# File 'lib/stripe/services/invoice_service.rb', line 2881

def billing_cycle_anchor
  @billing_cycle_anchor
end

#discount_actionsObject

Changes to the coupons being redeemed or discounts being applied during the amendment time span.



2883
2884
2885
# File 'lib/stripe/services/invoice_service.rb', line 2883

def discount_actions
  @discount_actions
end

#item_actionsObject

Changes to the subscription items during the amendment time span.



2885
2886
2887
# File 'lib/stripe/services/invoice_service.rb', line 2885

def item_actions
  @item_actions
end

#metadata_actionsObject

Instructions for how to modify phase metadata



2887
2888
2889
# File 'lib/stripe/services/invoice_service.rb', line 2887

def 
  @metadata_actions
end

#proration_behaviorObject

Changes to how Stripe handles prorations during the amendment time span. Affects if and how prorations are created when a future phase starts. In cases where the amendment changes the currently active phase, it is used to determine whether or how to prorate now, at the time of the request. Also supported as a point-in-time operation when ‘amendment_end` is `null`.



2889
2890
2891
# File 'lib/stripe/services/invoice_service.rb', line 2889

def proration_behavior
  @proration_behavior
end

#set_pause_collectionObject

Defines how to pause collection for the underlying subscription throughout the duration of the amendment.



2891
2892
2893
# File 'lib/stripe/services/invoice_service.rb', line 2891

def set_pause_collection
  @set_pause_collection
end

#set_schedule_endObject

Ends the subscription schedule early as dictated by either the accompanying amendment’s start or end.



2893
2894
2895
# File 'lib/stripe/services/invoice_service.rb', line 2893

def set_schedule_end
  @set_schedule_end
end

#trial_settingsObject

Settings related to subscription trials.



2895
2896
2897
# File 'lib/stripe/services/invoice_service.rb', line 2895

def trial_settings
  @trial_settings
end