Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Amendment::AmendmentEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: DiscountEnd, Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ AmendmentEnd

Returns a new instance of AmendmentEnd.



2441
2442
2443
2444
2445
2446
# File 'lib/stripe/services/invoice_service.rb', line 2441

def initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil)
  @discount_end = discount_end
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#discount_endObject

Use the ‘end` time of a given discount.



2433
2434
2435
# File 'lib/stripe/services/invoice_service.rb', line 2433

def discount_end
  @discount_end
end

#durationObject

Time span for the amendment starting from the ‘amendment_start`.



2435
2436
2437
# File 'lib/stripe/services/invoice_service.rb', line 2435

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the amendment to end. Must be after the ‘amendment_start`.



2437
2438
2439
# File 'lib/stripe/services/invoice_service.rb', line 2437

def timestamp
  @timestamp
end

#typeObject

Select one of three ways to pass the ‘amendment_end`.



2439
2440
2441
# File 'lib/stripe/services/invoice_service.rb', line 2439

def type
  @type
end