Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Amendment::AmendmentStart

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: AmendmentEnd, DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendment_end: nil, discount_end: nil, timestamp: nil, type: nil) ⇒ AmendmentStart

Returns a new instance of AmendmentStart.



2503
2504
2505
2506
2507
2508
# File 'lib/stripe/services/invoice_service.rb', line 2503

def initialize(amendment_end: nil, discount_end: nil, timestamp: nil, type: nil)
  @amendment_end = amendment_end
  @discount_end = discount_end
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#amendment_endObject

Details of another amendment in the same array, immediately after which this amendment should begin.



2495
2496
2497
# File 'lib/stripe/services/invoice_service.rb', line 2495

def amendment_end
  @amendment_end
end

#discount_endObject

Use the ‘end` time of a given discount.



2497
2498
2499
# File 'lib/stripe/services/invoice_service.rb', line 2497

def discount_end
  @discount_end
end

#timestampObject

A precise Unix timestamp for the amendment to start.



2499
2500
2501
# File 'lib/stripe/services/invoice_service.rb', line 2499

def timestamp
  @timestamp
end

#typeObject

Select one of three ways to pass the ‘amendment_start`.



2501
2502
2503
# File 'lib/stripe/services/invoice_service.rb', line 2501

def type
  @type
end