Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Amendment::DiscountAction
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Amendment::DiscountAction
- Defined in:
- lib/stripe/services/invoice_service.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#add ⇒ Object
Details of the discount to add.
-
#remove ⇒ Object
Details of the discount to remove.
-
#set ⇒ Object
Details of the discount to replace the existing discounts with.
-
#type ⇒ Object
Determines the type of discount action.
Instance Method Summary collapse
-
#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ DiscountAction
constructor
A new instance of DiscountAction.
Methods inherited from RequestParams
Constructor Details
#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ DiscountAction
Returns a new instance of DiscountAction.
2558 2559 2560 2561 2562 2563 |
# File 'lib/stripe/services/invoice_service.rb', line 2558 def initialize(add: nil, remove: nil, set: nil, type: nil) @add = add @remove = remove @set = set @type = type end |
Instance Attribute Details
#add ⇒ Object
Details of the discount to add.
2550 2551 2552 |
# File 'lib/stripe/services/invoice_service.rb', line 2550 def add @add end |
#remove ⇒ Object
Details of the discount to remove.
2552 2553 2554 |
# File 'lib/stripe/services/invoice_service.rb', line 2552 def remove @remove end |
#set ⇒ Object
Details of the discount to replace the existing discounts with.
2554 2555 2556 |
# File 'lib/stripe/services/invoice_service.rb', line 2554 def set @set end |
#type ⇒ Object
Determines the type of discount action.
2556 2557 2558 |
# File 'lib/stripe/services/invoice_service.rb', line 2556 def type @type end |