Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Amendment::DiscountAction::Add

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ Add

Returns a new instance of Add.



2565
2566
2567
2568
2569
2570
2571
2572
2573
2574
2575
2576
2577
# File 'lib/stripe/services/invoice_service.rb', line 2565

def initialize(
  coupon: nil,
  discount: nil,
  discount_end: nil,
  index: nil,
  promotion_code: nil
)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @index = index
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to redeem.



2555
2556
2557
# File 'lib/stripe/services/invoice_service.rb', line 2555

def coupon
  @coupon
end

#discountObject

An ID of an existing discount for a coupon that was already redeemed.



2557
2558
2559
# File 'lib/stripe/services/invoice_service.rb', line 2557

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



2559
2560
2561
# File 'lib/stripe/services/invoice_service.rb', line 2559

def discount_end
  @discount_end
end

#indexObject

The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the ‘discounts` array.



2561
2562
2563
# File 'lib/stripe/services/invoice_service.rb', line 2561

def index
  @index
end

#promotion_codeObject

The promotion code to redeem.



2563
2564
2565
# File 'lib/stripe/services/invoice_service.rb', line 2563

def promotion_code
  @promotion_code
end