Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Amendment::DiscountAction::Add::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Amendment::DiscountAction::Add::DiscountEnd
- Defined in:
- lib/stripe/services/invoice_service.rb
Instance Attribute Summary collapse
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
2550 2551 2552 |
# File 'lib/stripe/services/invoice_service.rb', line 2550 def initialize(type: nil) @type = type end |
Instance Attribute Details
#type ⇒ Object
The type of calculation made to determine when the discount ends.
2548 2549 2550 |
# File 'lib/stripe/services/invoice_service.rb', line 2548 def type @type end |