Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Amendment::DiscountAction::Remove

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Remove

Returns a new instance of Remove.



2588
2589
2590
2591
2592
# File 'lib/stripe/services/invoice_service.rb', line 2588

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to remove from the ‘discounts` array.



2582
2583
2584
# File 'lib/stripe/services/invoice_service.rb', line 2582

def coupon
  @coupon
end

#discountObject

The ID of a discount to remove from the ‘discounts` array.



2584
2585
2586
# File 'lib/stripe/services/invoice_service.rb', line 2584

def discount
  @discount
end

#promotion_codeObject

The ID of a promotion code to remove from the ‘discounts` array.



2586
2587
2588
# File 'lib/stripe/services/invoice_service.rb', line 2586

def promotion_code
  @promotion_code
end