Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Amendment::DiscountAction::Set
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Amendment::DiscountAction::Set
- Defined in:
- lib/stripe/services/invoice_service.rb
Instance Attribute Summary collapse
-
#coupon ⇒ Object
The coupon code to replace the ‘discounts` array with.
-
#discount ⇒ Object
An ID of an existing discount to replace the ‘discounts` array with.
-
#promotion_code ⇒ Object
An ID of an existing promotion code to replace the ‘discounts` array with.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Set
constructor
A new instance of Set.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Set
Returns a new instance of Set.
2603 2604 2605 2606 2607 |
# File 'lib/stripe/services/invoice_service.rb', line 2603 def initialize(coupon: nil, discount: nil, promotion_code: nil) @coupon = coupon @discount = discount @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
The coupon code to replace the ‘discounts` array with.
2597 2598 2599 |
# File 'lib/stripe/services/invoice_service.rb', line 2597 def coupon @coupon end |
#discount ⇒ Object
An ID of an existing discount to replace the ‘discounts` array with.
2599 2600 2601 |
# File 'lib/stripe/services/invoice_service.rb', line 2599 def discount @discount end |
#promotion_code ⇒ Object
An ID of an existing promotion code to replace the ‘discounts` array with.
2601 2602 2603 |
# File 'lib/stripe/services/invoice_service.rb', line 2601 def promotion_code @promotion_code end |