Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Amendment::ItemAction

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Add, Remove, Set

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ ItemAction

Returns a new instance of ItemAction.



2814
2815
2816
2817
2818
2819
# File 'lib/stripe/services/invoice_service.rb', line 2814

def initialize(add: nil, remove: nil, set: nil, type: nil)
  @add = add
  @remove = remove
  @set = set
  @type = type
end

Instance Attribute Details

#addObject

Details of the subscription item to add. If an item with the same ‘price` exists, it will be replaced by this new item. Otherwise, it adds the new item.



2806
2807
2808
# File 'lib/stripe/services/invoice_service.rb', line 2806

def add
  @add
end

#removeObject

Details of the subscription item to remove.



2808
2809
2810
# File 'lib/stripe/services/invoice_service.rb', line 2808

def remove
  @remove
end

#setObject

Details of the subscription item to replace the existing items with. If an item with the ‘set` already exists, the `items` array is not cleared. Instead, all of the other `set` properties that are passed in this request will replace the existing values for the configuration item.



2810
2811
2812
# File 'lib/stripe/services/invoice_service.rb', line 2810

def set
  @set
end

#typeObject

Determines the type of item action.



2812
2813
2814
# File 'lib/stripe/services/invoice_service.rb', line 2812

def type
  @type
end