Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Add

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Discount, Trial

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Add

Returns a new instance of Add.



2695
2696
2697
2698
2699
2700
2701
2702
2703
2704
2705
2706
2707
2708
2709
# File 'lib/stripe/services/invoice_service.rb', line 2695

def initialize(
  discounts: nil,
  metadata: nil,
  price: nil,
  quantity: nil,
  tax_rates: nil,
  trial: nil
)
  @discounts = discounts
  @metadata = 
  @price = price
  @quantity = quantity
  @tax_rates = tax_rates
  @trial = trial
end

Instance Attribute Details

#discountsObject

The discounts applied to the item. Subscription item discounts are applied before subscription discounts.



2683
2684
2685
# File 'lib/stripe/services/invoice_service.rb', line 2683

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2685
2686
2687
# File 'lib/stripe/services/invoice_service.rb', line 2685

def 
  @metadata
end

#priceObject

The ID of the price object.



2687
2688
2689
# File 'lib/stripe/services/invoice_service.rb', line 2687

def price
  @price
end

#quantityObject

Quantity for this item.



2689
2690
2691
# File 'lib/stripe/services/invoice_service.rb', line 2689

def quantity
  @quantity
end

#tax_ratesObject

The tax rates that apply to this subscription item. When set, the ‘default_tax_rates` on the subscription do not apply to this `subscription_item`.



2691
2692
2693
# File 'lib/stripe/services/invoice_service.rb', line 2691

def tax_rates
  @tax_rates
end

#trialObject

Options that configure the trial on the subscription item.



2693
2694
2695
# File 'lib/stripe/services/invoice_service.rb', line 2693

def trial
  @trial
end