Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Add::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



2663
2664
2665
2666
2667
2668
# File 'lib/stripe/services/invoice_service.rb', line 2663

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



2655
2656
2657
# File 'lib/stripe/services/invoice_service.rb', line 2655

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



2657
2658
2659
# File 'lib/stripe/services/invoice_service.rb', line 2657

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



2659
2660
2661
# File 'lib/stripe/services/invoice_service.rb', line 2659

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



2661
2662
2663
# File 'lib/stripe/services/invoice_service.rb', line 2661

def promotion_code
  @promotion_code
end