Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Add::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



2648
2649
2650
2651
2652
# File 'lib/stripe/services/invoice_service.rb', line 2648

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



2642
2643
2644
# File 'lib/stripe/services/invoice_service.rb', line 2642

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



2644
2645
2646
# File 'lib/stripe/services/invoice_service.rb', line 2644

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



2646
2647
2648
# File 'lib/stripe/services/invoice_service.rb', line 2646

def type
  @type
end