Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Set::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



2742
2743
2744
2745
2746
# File 'lib/stripe/services/invoice_service.rb', line 2742

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



2736
2737
2738
# File 'lib/stripe/services/invoice_service.rb', line 2736

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



2738
2739
2740
# File 'lib/stripe/services/invoice_service.rb', line 2738

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



2740
2741
2742
# File 'lib/stripe/services/invoice_service.rb', line 2740

def type
  @type
end