Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::BillingMode
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::BillingMode
- Defined in:
- lib/stripe/services/invoice_service.rb
Instance Attribute Summary collapse
-
#type ⇒ Object
Controls the calculation and orchestration of prorations and invoices for subscriptions.
Instance Method Summary collapse
-
#initialize(type: nil) ⇒ BillingMode
constructor
A new instance of BillingMode.
Methods inherited from RequestParams
Constructor Details
#initialize(type: nil) ⇒ BillingMode
Returns a new instance of BillingMode.
2926 2927 2928 |
# File 'lib/stripe/services/invoice_service.rb', line 2926 def initialize(type: nil) @type = type end |
Instance Attribute Details
#type ⇒ Object
Controls the calculation and orchestration of prorations and invoices for subscriptions.
2924 2925 2926 |
# File 'lib/stripe/services/invoice_service.rb', line 2924 def type @type end |