Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Phase::AddInvoiceItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Discount, Period, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discounts: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ AddInvoiceItem

Returns a new instance of AddInvoiceItem.



3052
3053
3054
3055
3056
3057
3058
3059
3060
3061
3062
3063
3064
3065
3066
3067
3068
# File 'lib/stripe/services/invoice_service.rb', line 3052

def initialize(
  discounts: nil,
  metadata: nil,
  period: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @discounts = discounts
  @metadata = 
  @period = period
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#discountsObject

The coupons to redeem into discounts for the item.



3038
3039
3040
# File 'lib/stripe/services/invoice_service.rb', line 3038

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



3040
3041
3042
# File 'lib/stripe/services/invoice_service.rb', line 3040

def 
  @metadata
end

#periodObject

The period associated with this invoice item. Defaults to the period of the underlying subscription that surrounds the start of the phase.



3042
3043
3044
# File 'lib/stripe/services/invoice_service.rb', line 3042

def period
  @period
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required.



3044
3045
3046
# File 'lib/stripe/services/invoice_service.rb', line 3044

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.



3046
3047
3048
# File 'lib/stripe/services/invoice_service.rb', line 3046

def price_data
  @price_data
end

#quantityObject

Quantity for this item. Defaults to 1.



3048
3049
3050
# File 'lib/stripe/services/invoice_service.rb', line 3048

def quantity
  @quantity
end

#tax_ratesObject

The tax rates which apply to the item. When set, the ‘default_tax_rates` do not apply to this item.



3050
3051
3052
# File 'lib/stripe/services/invoice_service.rb', line 3050

def tax_rates
  @tax_rates
end