Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Phase::AddInvoiceItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



2968
2969
2970
2971
2972
2973
# File 'lib/stripe/services/invoice_service.rb', line 2968

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



2960
2961
2962
# File 'lib/stripe/services/invoice_service.rb', line 2960

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



2962
2963
2964
# File 'lib/stripe/services/invoice_service.rb', line 2962

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



2964
2965
2966
# File 'lib/stripe/services/invoice_service.rb', line 2964

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



2966
2967
2968
# File 'lib/stripe/services/invoice_service.rb', line 2966

def promotion_code
  @promotion_code
end