Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Phase::AddInvoiceItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



2953
2954
2955
2956
2957
# File 'lib/stripe/services/invoice_service.rb', line 2953

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



2947
2948
2949
# File 'lib/stripe/services/invoice_service.rb', line 2947

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



2949
2950
2951
# File 'lib/stripe/services/invoice_service.rb', line 2949

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



2951
2952
2953
# File 'lib/stripe/services/invoice_service.rb', line 2951

def type
  @type
end