Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Phase::AddInvoiceItem::Period::End
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Phase::AddInvoiceItem::Period::End
- Defined in:
- lib/stripe/services/invoice_service.rb
Instance Attribute Summary collapse
-
#timestamp ⇒ Object
A precise Unix timestamp for the end of the invoice item period.
-
#type ⇒ Object
Select how to calculate the end of the invoice item period.
Instance Method Summary collapse
-
#initialize(timestamp: nil, type: nil) ⇒ End
constructor
A new instance of End.
Methods inherited from RequestParams
Constructor Details
#initialize(timestamp: nil, type: nil) ⇒ End
Returns a new instance of End.
2983 2984 2985 2986 |
# File 'lib/stripe/services/invoice_service.rb', line 2983 def initialize(timestamp: nil, type: nil) @timestamp = @type = type end |
Instance Attribute Details
#timestamp ⇒ Object
A precise Unix timestamp for the end of the invoice item period. Must be greater than or equal to ‘period.start`.
2979 2980 2981 |
# File 'lib/stripe/services/invoice_service.rb', line 2979 def @timestamp end |
#type ⇒ Object
Select how to calculate the end of the invoice item period.
2981 2982 2983 |
# File 'lib/stripe/services/invoice_service.rb', line 2981 def type @type end |