Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Phase::AddInvoiceItem::Period::Start

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(timestamp: nil, type: nil) ⇒ Start

Returns a new instance of Start.



2158
2159
2160
2161
# File 'lib/stripe/services/invoice_service.rb', line 2158

def initialize(timestamp: nil, type: nil)
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#timestampObject

A precise Unix timestamp for the start of the invoice item period. Must be less than or equal to ‘period.end`.



2154
2155
2156
# File 'lib/stripe/services/invoice_service.rb', line 2154

def timestamp
  @timestamp
end

#typeObject

Select how to calculate the start of the invoice item period.



2156
2157
2158
# File 'lib/stripe/services/invoice_service.rb', line 2156

def type
  @type
end