Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Phase::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Phase::Discount
- Defined in:
- lib/stripe/services/invoice_service.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
3141 3142 3143 3144 3145 3146 |
# File 'lib/stripe/services/invoice_service.rb', line 3141 def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
3133 3134 3135 |
# File 'lib/stripe/services/invoice_service.rb', line 3133 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
3135 3136 3137 |
# File 'lib/stripe/services/invoice_service.rb', line 3135 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
3137 3138 3139 |
# File 'lib/stripe/services/invoice_service.rb', line 3137 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
3139 3140 3141 |
# File 'lib/stripe/services/invoice_service.rb', line 3139 def promotion_code @promotion_code end |