Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Phase::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



3126
3127
3128
3129
3130
# File 'lib/stripe/services/invoice_service.rb', line 3126

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



3120
3121
3122
# File 'lib/stripe/services/invoice_service.rb', line 3120

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



3122
3123
3124
# File 'lib/stripe/services/invoice_service.rb', line 3122

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



3124
3125
3126
# File 'lib/stripe/services/invoice_service.rb', line 3124

def type
  @type
end