Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Phase::InvoiceSettings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Phase::InvoiceSettings
- Defined in:
- lib/stripe/services/invoice_service.rb
Defined Under Namespace
Classes: Issuer
Instance Attribute Summary collapse
-
#account_tax_ids ⇒ Object
The account tax IDs associated with this phase of the subscription schedule.
-
#days_until_due ⇒ Object
Number of days within which a customer must pay invoices generated by this subscription schedule.
-
#issuer ⇒ Object
The connected account that issues the invoice.
Instance Method Summary collapse
-
#initialize(account_tax_ids: nil, days_until_due: nil, issuer: nil) ⇒ InvoiceSettings
constructor
A new instance of InvoiceSettings.
Methods inherited from RequestParams
Constructor Details
#initialize(account_tax_ids: nil, days_until_due: nil, issuer: nil) ⇒ InvoiceSettings
Returns a new instance of InvoiceSettings.
3065 3066 3067 3068 3069 |
# File 'lib/stripe/services/invoice_service.rb', line 3065 def initialize(account_tax_ids: nil, days_until_due: nil, issuer: nil) @account_tax_ids = account_tax_ids @days_until_due = days_until_due @issuer = issuer end |
Instance Attribute Details
#account_tax_ids ⇒ Object
The account tax IDs associated with this phase of the subscription schedule. Will be set on invoices generated by this phase of the subscription schedule.
3059 3060 3061 |
# File 'lib/stripe/services/invoice_service.rb', line 3059 def account_tax_ids @account_tax_ids end |
#days_until_due ⇒ Object
Number of days within which a customer must pay invoices generated by this subscription schedule. This value will be ‘null` for subscription schedules where `billing=charge_automatically`.
3061 3062 3063 |
# File 'lib/stripe/services/invoice_service.rb', line 3061 def days_until_due @days_until_due end |
#issuer ⇒ Object
The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.
3063 3064 3065 |
# File 'lib/stripe/services/invoice_service.rb', line 3063 def issuer @issuer end |