Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Phase::Item::BillingThresholds

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(usage_gte: nil) ⇒ BillingThresholds

Returns a new instance of BillingThresholds.



5602
5603
5604
# File 'lib/stripe/services/invoice_service.rb', line 5602

def initialize(usage_gte: nil)
  @usage_gte = usage_gte
end

Instance Attribute Details

#usage_gteObject

Number of units that meets the billing threshold to advance the subscription to a new billing period (e.g., it takes 10 $5 units to meet a $50 [monetary threshold](stripe.com/docs/api/subscriptions/update#update_subscription-billing_thresholds-amount_gte))



5600
5601
5602
# File 'lib/stripe/services/invoice_service.rb', line 5600

def usage_gte
  @usage_gte
end