Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Phase::Item::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



3232
3233
3234
3235
3236
3237
# File 'lib/stripe/services/invoice_service.rb', line 3232

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



3224
3225
3226
# File 'lib/stripe/services/invoice_service.rb', line 3224

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



3226
3227
3228
# File 'lib/stripe/services/invoice_service.rb', line 3226

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



3228
3229
3230
# File 'lib/stripe/services/invoice_service.rb', line 3228

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



3230
3231
3232
# File 'lib/stripe/services/invoice_service.rb', line 3230

def promotion_code
  @promotion_code
end