Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Phase::Item::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



3217
3218
3219
3220
3221
# File 'lib/stripe/services/invoice_service.rb', line 3217

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



3211
3212
3213
# File 'lib/stripe/services/invoice_service.rb', line 3211

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



3213
3214
3215
# File 'lib/stripe/services/invoice_service.rb', line 3213

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



3215
3216
3217
# File 'lib/stripe/services/invoice_service.rb', line 3215

def type
  @type
end