Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Phase::Item::Trial
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Phase::Item::Trial
- Defined in:
- lib/stripe/services/invoice_service.rb
Instance Attribute Summary collapse
-
#converts_to ⇒ Object
List of price IDs which, if present on the subscription following a paid trial, constitute opting-in to the paid trial.
-
#type ⇒ Object
Determines the type of trial for this item.
Instance Method Summary collapse
-
#initialize(converts_to: nil, type: nil) ⇒ Trial
constructor
A new instance of Trial.
Methods inherited from RequestParams
Constructor Details
#initialize(converts_to: nil, type: nil) ⇒ Trial
Returns a new instance of Trial.
3154 3155 3156 3157 |
# File 'lib/stripe/services/invoice_service.rb', line 3154 def initialize(converts_to: nil, type: nil) @converts_to = converts_to @type = type end |
Instance Attribute Details
#converts_to ⇒ Object
List of price IDs which, if present on the subscription following a paid trial, constitute opting-in to the paid trial. Currently only supports at most 1 price ID.
3150 3151 3152 |
# File 'lib/stripe/services/invoice_service.rb', line 3150 def converts_to @converts_to end |
#type ⇒ Object
Determines the type of trial for this item.
3152 3153 3154 |
# File 'lib/stripe/services/invoice_service.rb', line 3152 def type @type end |