Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Phase::TrialSettings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Phase::TrialSettings
- Defined in:
- lib/stripe/services/invoice_service.rb
Defined Under Namespace
Classes: EndBehavior
Instance Attribute Summary collapse
-
#end_behavior ⇒ Object
Defines how the subscription should behave when a trial ends.
Instance Method Summary collapse
-
#initialize(end_behavior: nil) ⇒ TrialSettings
constructor
A new instance of TrialSettings.
Methods inherited from RequestParams
Constructor Details
#initialize(end_behavior: nil) ⇒ TrialSettings
Returns a new instance of TrialSettings.
5800 5801 5802 |
# File 'lib/stripe/services/invoice_service.rb', line 5800 def initialize(end_behavior: nil) @end_behavior = end_behavior end |
Instance Attribute Details
#end_behavior ⇒ Object
Defines how the subscription should behave when a trial ends.
5798 5799 5800 |
# File 'lib/stripe/services/invoice_service.rb', line 5798 def end_behavior @end_behavior end |