Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Prebilling::BillUntil

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: AmendmentEnd, Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ BillUntil

Returns a new instance of BillUntil.



3513
3514
3515
3516
3517
3518
# File 'lib/stripe/services/invoice_service.rb', line 3513

def initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil)
  @amendment_end = amendment_end
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#amendment_endObject

End the prebilled period when a specified amendment ends.



3505
3506
3507
# File 'lib/stripe/services/invoice_service.rb', line 3505

def amendment_end
  @amendment_end
end

#durationObject

Time span for prebilling, starting from ‘bill_from`.



3507
3508
3509
# File 'lib/stripe/services/invoice_service.rb', line 3507

def duration
  @duration
end

#timestampObject

End the prebilled period at a precise integer timestamp, starting from the Unix epoch.



3509
3510
3511
# File 'lib/stripe/services/invoice_service.rb', line 3509

def timestamp
  @timestamp
end

#typeObject

Select one of several ways to pass the ‘bill_until` value.



3511
3512
3513
# File 'lib/stripe/services/invoice_service.rb', line 3511

def type
  @type
end