Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Prebilling::BillUntil::Duration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(interval: nil, interval_count: nil) ⇒ Duration

Returns a new instance of Duration.



3369
3370
3371
3372
# File 'lib/stripe/services/invoice_service.rb', line 3369

def initialize(interval: nil, interval_count: nil)
  @interval = interval
  @interval_count = interval_count
end

Instance Attribute Details

#intervalObject

Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.



3365
3366
3367
# File 'lib/stripe/services/invoice_service.rb', line 3365

def interval
  @interval
end

#interval_countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



3367
3368
3369
# File 'lib/stripe/services/invoice_service.rb', line 3367

def interval_count
  @interval_count
end