Class: Stripe::InvoiceService::CreatePreviewParams::SubscriptionDetails::Item

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: BillingThresholds, Discount, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_thresholds: nil, clear_usage: nil, deleted: nil, discounts: nil, id: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ Item

Returns a new instance of Item.



3691
3692
3693
3694
3695
3696
3697
3698
3699
3700
3701
3702
3703
3704
3705
3706
3707
3708
3709
3710
3711
3712
3713
3714
3715
# File 'lib/stripe/services/invoice_service.rb', line 3691

def initialize(
  billing_thresholds: nil,
  clear_usage: nil,
  deleted: nil,
  discounts: nil,
  id: nil,
  metadata: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @billing_thresholds = billing_thresholds
  @clear_usage = clear_usage
  @deleted = deleted
  @discounts = discounts
  @id = id
  @metadata = 
  @plan = plan
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.



3669
3670
3671
# File 'lib/stripe/services/invoice_service.rb', line 3669

def billing_thresholds
  @billing_thresholds
end

#clear_usageObject

Delete all usage for a given subscription item. You must pass this when deleting a usage records subscription item. ‘clear_usage` has no effect if the plan has a billing meter attached.



3671
3672
3673
# File 'lib/stripe/services/invoice_service.rb', line 3671

def clear_usage
  @clear_usage
end

#deletedObject

A flag that, if set to ‘true`, will delete the specified item.



3673
3674
3675
# File 'lib/stripe/services/invoice_service.rb', line 3673

def deleted
  @deleted
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



3675
3676
3677
# File 'lib/stripe/services/invoice_service.rb', line 3675

def discounts
  @discounts
end

#idObject

Subscription item to update.



3677
3678
3679
# File 'lib/stripe/services/invoice_service.rb', line 3677

def id
  @id
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



3679
3680
3681
# File 'lib/stripe/services/invoice_service.rb', line 3679

def 
  @metadata
end

#planObject

Plan ID for this item, as a string.



3681
3682
3683
# File 'lib/stripe/services/invoice_service.rb', line 3681

def plan
  @plan
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required. When changing a subscription item’s price, ‘quantity` is set to 1 unless a `quantity` parameter is provided.



3683
3684
3685
# File 'lib/stripe/services/invoice_service.rb', line 3683

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.



3685
3686
3687
# File 'lib/stripe/services/invoice_service.rb', line 3685

def price_data
  @price_data
end

#quantityObject

Quantity for this item.



3687
3688
3689
# File 'lib/stripe/services/invoice_service.rb', line 3687

def quantity
  @quantity
end

#tax_ratesObject

A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



3689
3690
3691
# File 'lib/stripe/services/invoice_service.rb', line 3689

def tax_rates
  @tax_rates
end