Class: Stripe::InvoiceService::CreatePreviewParams::SubscriptionDetails::Item::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



3619
3620
3621
3622
3623
3624
# File 'lib/stripe/services/invoice_service.rb', line 3619

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



3611
3612
3613
# File 'lib/stripe/services/invoice_service.rb', line 3611

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



3613
3614
3615
# File 'lib/stripe/services/invoice_service.rb', line 3613

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



3615
3616
3617
# File 'lib/stripe/services/invoice_service.rb', line 3615

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



3617
3618
3619
# File 'lib/stripe/services/invoice_service.rb', line 3617

def promotion_code
  @promotion_code
end