Class: Stripe::InvoiceService::CreatePreviewParams::SubscriptionDetails::Item::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



3604
3605
3606
3607
3608
# File 'lib/stripe/services/invoice_service.rb', line 3604

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



3598
3599
3600
# File 'lib/stripe/services/invoice_service.rb', line 3598

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



3600
3601
3602
# File 'lib/stripe/services/invoice_service.rb', line 3600

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



3602
3603
3604
# File 'lib/stripe/services/invoice_service.rb', line 3602

def type
  @type
end