Class: Stripe::InvoiceService::FinalizeInvoiceParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::FinalizeInvoiceParams
- Defined in:
- lib/stripe/services/invoice_service.rb
Instance Attribute Summary collapse
-
#auto_advance ⇒ Object
Controls whether Stripe performs [automatic collection](stripe.com/docs/invoicing/integration/automatic-advancement-collection) of the invoice.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(auto_advance: nil, expand: nil) ⇒ FinalizeInvoiceParams
constructor
A new instance of FinalizeInvoiceParams.
Methods inherited from RequestParams
Constructor Details
#initialize(auto_advance: nil, expand: nil) ⇒ FinalizeInvoiceParams
Returns a new instance of FinalizeInvoiceParams.
1771 1772 1773 1774 |
# File 'lib/stripe/services/invoice_service.rb', line 1771 def initialize(auto_advance: nil, expand: nil) @auto_advance = auto_advance @expand = end |
Instance Attribute Details
#auto_advance ⇒ Object
Controls whether Stripe performs [automatic collection](stripe.com/docs/invoicing/integration/automatic-advancement-collection) of the invoice. If ‘false`, the invoice’s state doesn’t automatically advance without an explicit action.
1767 1768 1769 |
# File 'lib/stripe/services/invoice_service.rb', line 1767 def auto_advance @auto_advance end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1769 1770 1771 |
# File 'lib/stripe/services/invoice_service.rb', line 1769 def @expand end |