Class: Stripe::InvoiceService::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Created, DueDate

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(collection_method: nil, created: nil, customer: nil, customer_account: nil, due_date: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, status: nil, subscription: nil) ⇒ ListParams

Returns a new instance of ListParams.



728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
# File 'lib/stripe/services/invoice_service.rb', line 728

def initialize(
  collection_method: nil,
  created: nil,
  customer: nil,
  customer_account: nil,
  due_date: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  starting_after: nil,
  status: nil,
  subscription: nil
)
  @collection_method = collection_method
  @created = created
  @customer = customer
  @customer_account = 
  @due_date = due_date
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
  @status = status
  @subscription = subscription
end

Instance Attribute Details

#collection_methodObject

The collection method of the invoice to retrieve. Either ‘charge_automatically` or `send_invoice`.



706
707
708
# File 'lib/stripe/services/invoice_service.rb', line 706

def collection_method
  @collection_method
end

#createdObject

Only return invoices that were created during the given date interval.



708
709
710
# File 'lib/stripe/services/invoice_service.rb', line 708

def created
  @created
end

#customerObject

Only return invoices for the customer specified by this customer ID.



710
711
712
# File 'lib/stripe/services/invoice_service.rb', line 710

def customer
  @customer
end

#customer_accountObject

Only return invoices for the account specified by this account ID.



712
713
714
# File 'lib/stripe/services/invoice_service.rb', line 712

def 
  @customer_account
end

#due_dateObject

Attribute for param field due_date



714
715
716
# File 'lib/stripe/services/invoice_service.rb', line 714

def due_date
  @due_date
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



716
717
718
# File 'lib/stripe/services/invoice_service.rb', line 716

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



718
719
720
# File 'lib/stripe/services/invoice_service.rb', line 718

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



720
721
722
# File 'lib/stripe/services/invoice_service.rb', line 720

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



722
723
724
# File 'lib/stripe/services/invoice_service.rb', line 722

def starting_after
  @starting_after
end

#statusObject

The status of the invoice, one of ‘draft`, `open`, `paid`, `uncollectible`, or `void`. [Learn more](stripe.com/docs/billing/invoices/workflow#workflow-overview)



724
725
726
# File 'lib/stripe/services/invoice_service.rb', line 724

def status
  @status
end

#subscriptionObject

Only return invoices for the subscription specified by this subscription ID.



726
727
728
# File 'lib/stripe/services/invoice_service.rb', line 726

def subscription
  @subscription
end