Class: Stripe::InvoiceService::SearchParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/invoice_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, limit: nil, page: nil, query: nil) ⇒ SearchParams

Returns a new instance of SearchParams.



1386
1387
1388
1389
1390
1391
# File 'lib/stripe/services/invoice_service.rb', line 1386

def initialize(expand: nil, limit: nil, page: nil, query: nil)
  @expand = expand
  @limit = limit
  @page = page
  @query = query
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



1378
1379
1380
# File 'lib/stripe/services/invoice_service.rb', line 1378

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



1380
1381
1382
# File 'lib/stripe/services/invoice_service.rb', line 1380

def limit
  @limit
end

#pageObject

A cursor for pagination across multiple pages of results. Don’t include this parameter on the first call. Use the next_page value returned in a previous response to request subsequent results.



1382
1383
1384
# File 'lib/stripe/services/invoice_service.rb', line 1382

def page
  @page
end

#queryObject

The search query string. See [search query language](stripe.com/docs/search#search-query-language) and the list of supported [query fields for invoices](stripe.com/docs/search#query-fields-for-invoices).



1384
1385
1386
# File 'lib/stripe/services/invoice_service.rb', line 1384

def query
  @query
end