Class: Stripe::InvoiceService::SendInvoiceParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::SendInvoiceParams
- Defined in:
- lib/stripe/services/invoice_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ SendInvoiceParams
constructor
A new instance of SendInvoiceParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ SendInvoiceParams
Returns a new instance of SendInvoiceParams.
1853 1854 1855 |
# File 'lib/stripe/services/invoice_service.rb', line 1853 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1851 1852 1853 |
# File 'lib/stripe/services/invoice_service.rb', line 1851 def @expand end |