Class: Stripe::InvoiceService::UpcomingParams::InvoiceItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



1826
1827
1828
1829
1830
# File 'lib/stripe/services/invoice_service.rb', line 1826

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



1818
1819
1820
# File 'lib/stripe/services/invoice_service.rb', line 1818

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



1821
1822
1823
# File 'lib/stripe/services/invoice_service.rb', line 1821

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



1824
1825
1826
# File 'lib/stripe/services/invoice_service.rb', line 1824

def type
  @type
end