Class: Stripe::InvoiceService::UpcomingParams::InvoiceItem::Period
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::UpcomingParams::InvoiceItem::Period
- Defined in:
- lib/stripe/services/invoice_service.rb
Instance Attribute Summary collapse
-
#end ⇒ Object
The end of the period, which must be greater than or equal to the start.
-
#start ⇒ Object
The start of the period.
Instance Method Summary collapse
-
#initialize(end_: nil, start: nil) ⇒ Period
constructor
A new instance of Period.
Methods inherited from RequestParams
Constructor Details
#initialize(end_: nil, start: nil) ⇒ Period
Returns a new instance of Period.
1859 1860 1861 1862 |
# File 'lib/stripe/services/invoice_service.rb', line 1859 def initialize(end_: nil, start: nil) @end = end_ @start = start end |
Instance Attribute Details
#end ⇒ Object
The end of the period, which must be greater than or equal to the start. This value is inclusive.
1854 1855 1856 |
# File 'lib/stripe/services/invoice_service.rb', line 1854 def end @end end |
#start ⇒ Object
The start of the period. This value is inclusive.
1857 1858 1859 |
# File 'lib/stripe/services/invoice_service.rb', line 1857 def start @start end |