Class: Stripe::InvoiceService::UpcomingParams::ScheduleDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::UpcomingParams::ScheduleDetails
- Defined in:
- lib/stripe/services/invoice_service.rb
Defined Under Namespace
Classes: Amendment, Phase, Prebilling
Instance Attribute Summary collapse
-
#amendments ⇒ Object
Changes to apply to the phases of the subscription schedule, in the order provided.
-
#billing_behavior ⇒ Object
Configures when the subscription schedule generates prorations for phase transitions.
-
#end_behavior ⇒ Object
Behavior of the subscription schedule and underlying subscription when it ends.
-
#phases ⇒ Object
List representing phases of the subscription schedule.
-
#prebilling ⇒ Object
Provide any time periods to bill in advance.
-
#proration_behavior ⇒ Object
In cases where the ‘schedule_details` params update the currently active phase, specifies if and how to prorate at the time of the request.
Instance Method Summary collapse
-
#initialize(amendments: nil, billing_behavior: nil, end_behavior: nil, phases: nil, prebilling: nil, proration_behavior: nil) ⇒ ScheduleDetails
constructor
A new instance of ScheduleDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(amendments: nil, billing_behavior: nil, end_behavior: nil, phases: nil, prebilling: nil, proration_behavior: nil) ⇒ ScheduleDetails
Returns a new instance of ScheduleDetails.
2757 2758 2759 2760 2761 2762 2763 2764 2765 2766 2767 2768 2769 2770 2771 |
# File 'lib/stripe/services/invoice_service.rb', line 2757 def initialize( amendments: nil, billing_behavior: nil, end_behavior: nil, phases: nil, prebilling: nil, proration_behavior: nil ) @amendments = amendments @billing_behavior = billing_behavior @end_behavior = end_behavior @phases = phases @prebilling = prebilling @proration_behavior = proration_behavior end |
Instance Attribute Details
#amendments ⇒ Object
Changes to apply to the phases of the subscription schedule, in the order provided.
2745 2746 2747 |
# File 'lib/stripe/services/invoice_service.rb', line 2745 def amendments @amendments end |
#billing_behavior ⇒ Object
Configures when the subscription schedule generates prorations for phase transitions. Possible values are ‘prorate_on_next_phase` or `prorate_up_front` with the default being `prorate_on_next_phase`. `prorate_on_next_phase` will apply phase changes and generate prorations at transition time. `prorate_up_front` will bill for all phases within the current billing cycle up front.
2747 2748 2749 |
# File 'lib/stripe/services/invoice_service.rb', line 2747 def billing_behavior @billing_behavior end |
#end_behavior ⇒ Object
Behavior of the subscription schedule and underlying subscription when it ends. Possible values are ‘release` or `cancel` with the default being `release`. `release` will end the subscription schedule and keep the underlying subscription running. `cancel` will end the subscription schedule and cancel the underlying subscription.
2749 2750 2751 |
# File 'lib/stripe/services/invoice_service.rb', line 2749 def end_behavior @end_behavior end |
#phases ⇒ Object
List representing phases of the subscription schedule. Each phase can be customized to have different durations, plans, and coupons. If there are multiple phases, the ‘end_date` of one phase will always equal the `start_date` of the next phase.
2751 2752 2753 |
# File 'lib/stripe/services/invoice_service.rb', line 2751 def phases @phases end |
#prebilling ⇒ Object
Provide any time periods to bill in advance.
2753 2754 2755 |
# File 'lib/stripe/services/invoice_service.rb', line 2753 def prebilling @prebilling end |
#proration_behavior ⇒ Object
In cases where the ‘schedule_details` params update the currently active phase, specifies if and how to prorate at the time of the request.
2755 2756 2757 |
# File 'lib/stripe/services/invoice_service.rb', line 2755 def proration_behavior @proration_behavior end |