Class: Stripe::InvoiceService::UpcomingParams::ScheduleDetails::Amendment::AmendmentEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: DiscountEnd, Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ AmendmentEnd

Returns a new instance of AmendmentEnd.



1779
1780
1781
1782
1783
1784
# File 'lib/stripe/services/invoice_service.rb', line 1779

def initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil)
  @discount_end = discount_end
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#discount_endObject

Use the ‘end` time of a given discount.



1771
1772
1773
# File 'lib/stripe/services/invoice_service.rb', line 1771

def discount_end
  @discount_end
end

#durationObject

Time span for the amendment starting from the ‘amendment_start`.



1773
1774
1775
# File 'lib/stripe/services/invoice_service.rb', line 1773

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the amendment to end. Must be after the ‘amendment_start`.



1775
1776
1777
# File 'lib/stripe/services/invoice_service.rb', line 1775

def timestamp
  @timestamp
end

#typeObject

Select one of three ways to pass the ‘amendment_end`.



1777
1778
1779
# File 'lib/stripe/services/invoice_service.rb', line 1777

def type
  @type
end