Class: Stripe::InvoiceService::UpcomingParams::ScheduleDetails::Amendment::AmendmentEnd::Duration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(interval: nil, interval_count: nil) ⇒ Duration

Returns a new instance of Duration.



1765
1766
1767
1768
# File 'lib/stripe/services/invoice_service.rb', line 1765

def initialize(interval: nil, interval_count: nil)
  @interval = interval
  @interval_count = interval_count
end

Instance Attribute Details

#intervalObject

Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.



1761
1762
1763
# File 'lib/stripe/services/invoice_service.rb', line 1761

def interval
  @interval
end

#interval_countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



1763
1764
1765
# File 'lib/stripe/services/invoice_service.rb', line 1763

def interval_count
  @interval_count
end