Class: Stripe::InvoiceService::UpcomingParams::ScheduleDetails::Amendment::AmendmentStart::AmendmentEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(index: nil) ⇒ AmendmentEnd

Returns a new instance of AmendmentEnd.



2042
2043
2044
# File 'lib/stripe/services/invoice_service.rb', line 2042

def initialize(index: nil)
  @index = index
end

Instance Attribute Details

#indexObject

The position of the previous amendment in the ‘amendments` array after which this amendment should begin. Indexes start from 0 and must be less than the index of the current amendment in the array.



2040
2041
2042
# File 'lib/stripe/services/invoice_service.rb', line 2040

def index
  @index
end