Class: Stripe::InvoiceService::UpcomingParams::ScheduleDetails::Amendment::DiscountAction
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::UpcomingParams::ScheduleDetails::Amendment::DiscountAction
- Defined in:
- lib/stripe/services/invoice_service.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#add ⇒ Object
Details of the discount to add.
-
#remove ⇒ Object
Details of the discount to remove.
-
#set ⇒ Object
Details of the discount to replace the existing discounts with.
-
#type ⇒ Object
Determines the type of discount action.
Instance Method Summary collapse
-
#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ DiscountAction
constructor
A new instance of DiscountAction.
Methods inherited from RequestParams
Constructor Details
#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ DiscountAction
Returns a new instance of DiscountAction.
2160 2161 2162 2163 2164 2165 |
# File 'lib/stripe/services/invoice_service.rb', line 2160 def initialize(add: nil, remove: nil, set: nil, type: nil) @add = add @remove = remove @set = set @type = type end |
Instance Attribute Details
#add ⇒ Object
Details of the discount to add.
2149 2150 2151 |
# File 'lib/stripe/services/invoice_service.rb', line 2149 def add @add end |
#remove ⇒ Object
Details of the discount to remove.
2152 2153 2154 |
# File 'lib/stripe/services/invoice_service.rb', line 2152 def remove @remove end |
#set ⇒ Object
Details of the discount to replace the existing discounts with.
2155 2156 2157 |
# File 'lib/stripe/services/invoice_service.rb', line 2155 def set @set end |
#type ⇒ Object
Determines the type of discount action.
2158 2159 2160 |
# File 'lib/stripe/services/invoice_service.rb', line 2158 def type @type end |