Class: Stripe::InvoiceService::UpcomingParams::ScheduleDetails::Amendment::DiscountAction::Add

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ Add

Returns a new instance of Add.



1843
1844
1845
1846
1847
1848
1849
1850
1851
1852
1853
1854
1855
# File 'lib/stripe/services/invoice_service.rb', line 1843

def initialize(
  coupon: nil,
  discount: nil,
  discount_end: nil,
  index: nil,
  promotion_code: nil
)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @index = index
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to redeem.



1833
1834
1835
# File 'lib/stripe/services/invoice_service.rb', line 1833

def coupon
  @coupon
end

#discountObject

An ID of an existing discount for a coupon that was already redeemed.



1835
1836
1837
# File 'lib/stripe/services/invoice_service.rb', line 1835

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1837
1838
1839
# File 'lib/stripe/services/invoice_service.rb', line 1837

def discount_end
  @discount_end
end

#indexObject

The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the ‘discounts` array.



1839
1840
1841
# File 'lib/stripe/services/invoice_service.rb', line 1839

def index
  @index
end

#promotion_codeObject

The promotion code to redeem.



1841
1842
1843
# File 'lib/stripe/services/invoice_service.rb', line 1841

def promotion_code
  @promotion_code
end