Class: Stripe::InvoiceService::UpcomingParams::ScheduleDetails::Amendment::DiscountAction::Remove

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Remove

Returns a new instance of Remove.



2125
2126
2127
2128
2129
# File 'lib/stripe/services/invoice_service.rb', line 2125

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to remove from the ‘discounts` array.



2117
2118
2119
# File 'lib/stripe/services/invoice_service.rb', line 2117

def coupon
  @coupon
end

#discountObject

The ID of a discount to remove from the ‘discounts` array.



2120
2121
2122
# File 'lib/stripe/services/invoice_service.rb', line 2120

def discount
  @discount
end

#promotion_codeObject

The ID of a promotion code to remove from the ‘discounts` array.



2123
2124
2125
# File 'lib/stripe/services/invoice_service.rb', line 2123

def promotion_code
  @promotion_code
end