Class: Stripe::InvoiceService::UpcomingParams::ScheduleDetails::Amendment::DiscountAction::Set

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Set

Returns a new instance of Set.



2142
2143
2144
2145
2146
# File 'lib/stripe/services/invoice_service.rb', line 2142

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to replace the ‘discounts` array with.



2134
2135
2136
# File 'lib/stripe/services/invoice_service.rb', line 2134

def coupon
  @coupon
end

#discountObject

An ID of an existing discount to replace the ‘discounts` array with.



2137
2138
2139
# File 'lib/stripe/services/invoice_service.rb', line 2137

def discount
  @discount
end

#promotion_codeObject

An ID of an existing promotion code to replace the ‘discounts` array with.



2140
2141
2142
# File 'lib/stripe/services/invoice_service.rb', line 2140

def promotion_code
  @promotion_code
end