Class: Stripe::InvoiceService::UpcomingParams::ScheduleDetails::Amendment::ItemAction

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Add, Remove, Set

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ ItemAction

Returns a new instance of ItemAction.



2383
2384
2385
2386
2387
2388
# File 'lib/stripe/services/invoice_service.rb', line 2383

def initialize(add: nil, remove: nil, set: nil, type: nil)
  @add = add
  @remove = remove
  @set = set
  @type = type
end

Instance Attribute Details

#addObject

Details of the subscription item to add. If an item with the same ‘price` exists, it will be replaced by this new item. Otherwise, it adds the new item.



2372
2373
2374
# File 'lib/stripe/services/invoice_service.rb', line 2372

def add
  @add
end

#removeObject

Details of the subscription item to remove.



2375
2376
2377
# File 'lib/stripe/services/invoice_service.rb', line 2375

def remove
  @remove
end

#setObject

Details of the subscription item to replace the existing items with. If an item with the ‘set` already exists, the `items` array is not cleared. Instead, all of the other `set` properties that are passed in this request will replace the existing values for the configuration item.



2378
2379
2380
# File 'lib/stripe/services/invoice_service.rb', line 2378

def set
  @set
end

#typeObject

Determines the type of item action.



2381
2382
2383
# File 'lib/stripe/services/invoice_service.rb', line 2381

def type
  @type
end