Class: Stripe::InvoiceService::UpcomingParams::ScheduleDetails::Amendment::ItemAction::Add::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1941
1942
1943
1944
1945
1946
# File 'lib/stripe/services/invoice_service.rb', line 1941

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1933
1934
1935
# File 'lib/stripe/services/invoice_service.rb', line 1933

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1935
1936
1937
# File 'lib/stripe/services/invoice_service.rb', line 1935

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1937
1938
1939
# File 'lib/stripe/services/invoice_service.rb', line 1937

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1939
1940
1941
# File 'lib/stripe/services/invoice_service.rb', line 1939

def promotion_code
  @promotion_code
end