Class: Stripe::InvoiceService::UpcomingParams::ScheduleDetails::Amendment::ItemAction::Add::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



2193
2194
2195
2196
2197
# File 'lib/stripe/services/invoice_service.rb', line 2193

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



2185
2186
2187
# File 'lib/stripe/services/invoice_service.rb', line 2185

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



2188
2189
2190
# File 'lib/stripe/services/invoice_service.rb', line 2188

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



2191
2192
2193
# File 'lib/stripe/services/invoice_service.rb', line 2191

def type
  @type
end