Class: Stripe::InvoiceService::UpcomingParams::ScheduleDetails::Phase::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



2676
2677
2678
2679
2680
# File 'lib/stripe/services/invoice_service.rb', line 2676

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



2668
2669
2670
# File 'lib/stripe/services/invoice_service.rb', line 2668

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



2671
2672
2673
# File 'lib/stripe/services/invoice_service.rb', line 2671

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



2674
2675
2676
# File 'lib/stripe/services/invoice_service.rb', line 2674

def type
  @type
end