Class: Stripe::InvoiceService::UpcomingParams::ScheduleDetails::Phase::Item::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



2782
2783
2784
2785
2786
2787
# File 'lib/stripe/services/invoice_service.rb', line 2782

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



2771
2772
2773
# File 'lib/stripe/services/invoice_service.rb', line 2771

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



2774
2775
2776
# File 'lib/stripe/services/invoice_service.rb', line 2774

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



2777
2778
2779
# File 'lib/stripe/services/invoice_service.rb', line 2777

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



2780
2781
2782
# File 'lib/stripe/services/invoice_service.rb', line 2780

def promotion_code
  @promotion_code
end