Class: Stripe::InvoiceService::UpcomingParams::ScheduleDetails::Phase::Item::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



2431
2432
2433
2434
2435
# File 'lib/stripe/services/invoice_service.rb', line 2431

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



2425
2426
2427
# File 'lib/stripe/services/invoice_service.rb', line 2425

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



2427
2428
2429
# File 'lib/stripe/services/invoice_service.rb', line 2427

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



2429
2430
2431
# File 'lib/stripe/services/invoice_service.rb', line 2429

def type
  @type
end