Class: Stripe::InvoiceService::UpcomingParams::ScheduleDetails::Phase::Item::PriceData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::UpcomingParams::ScheduleDetails::Phase::Item::PriceData
- Defined in:
- lib/stripe/services/invoice_service.rb
Defined Under Namespace
Classes: Recurring
Instance Attribute Summary collapse
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#product ⇒ Object
The ID of the product that this price will belong to.
-
#recurring ⇒ Object
The recurring components of a price such as ‘interval` and `interval_count`.
-
#tax_behavior ⇒ Object
Only required if a [default tax behavior](stripe.com/docs/tax/products-prices-tax-categories-tax-behavior#setting-a-default-tax-behavior-(recommended)) was not provided in the Stripe Tax settings.
-
#unit_amount ⇒ Object
A positive integer in cents (or local equivalent) (or 0 for a free price) representing how much to charge.
-
#unit_amount_decimal ⇒ Object
Same as ‘unit_amount`, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places.
Instance Method Summary collapse
-
#initialize(currency: nil, product: nil, recurring: nil, tax_behavior: nil, unit_amount: nil, unit_amount_decimal: nil) ⇒ PriceData
constructor
A new instance of PriceData.
Methods inherited from RequestParams
Constructor Details
#initialize(currency: nil, product: nil, recurring: nil, tax_behavior: nil, unit_amount: nil, unit_amount_decimal: nil) ⇒ PriceData
Returns a new instance of PriceData.
2479 2480 2481 2482 2483 2484 2485 2486 2487 2488 2489 2490 2491 2492 2493 |
# File 'lib/stripe/services/invoice_service.rb', line 2479 def initialize( currency: nil, product: nil, recurring: nil, tax_behavior: nil, unit_amount: nil, unit_amount_decimal: nil ) @currency = currency @product = product @recurring = recurring @tax_behavior = tax_behavior @unit_amount = unit_amount @unit_amount_decimal = unit_amount_decimal end |
Instance Attribute Details
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
2467 2468 2469 |
# File 'lib/stripe/services/invoice_service.rb', line 2467 def currency @currency end |
#product ⇒ Object
The ID of the product that this price will belong to.
2469 2470 2471 |
# File 'lib/stripe/services/invoice_service.rb', line 2469 def product @product end |
#recurring ⇒ Object
The recurring components of a price such as ‘interval` and `interval_count`.
2471 2472 2473 |
# File 'lib/stripe/services/invoice_service.rb', line 2471 def recurring @recurring end |
#tax_behavior ⇒ Object
Only required if a [default tax behavior](stripe.com/docs/tax/products-prices-tax-categories-tax-behavior#setting-a-default-tax-behavior-(recommended)) was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`. Once specified as either `inclusive` or `exclusive`, it cannot be changed.
2473 2474 2475 |
# File 'lib/stripe/services/invoice_service.rb', line 2473 def tax_behavior @tax_behavior end |
#unit_amount ⇒ Object
A positive integer in cents (or local equivalent) (or 0 for a free price) representing how much to charge.
2475 2476 2477 |
# File 'lib/stripe/services/invoice_service.rb', line 2475 def unit_amount @unit_amount end |
#unit_amount_decimal ⇒ Object
Same as ‘unit_amount`, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places. Only one of `unit_amount` and `unit_amount_decimal` can be set.
2477 2478 2479 |
# File 'lib/stripe/services/invoice_service.rb', line 2477 def unit_amount_decimal @unit_amount_decimal end |