Class: Stripe::InvoiceService::UpcomingParams::ScheduleDetails::Phase::TrialSettings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::UpcomingParams::ScheduleDetails::Phase::TrialSettings
- Defined in:
- lib/stripe/services/invoice_service.rb
Defined Under Namespace
Classes: EndBehavior
Instance Attribute Summary collapse
-
#end_behavior ⇒ Object
Defines how the subscription should behave when a trial ends.
Instance Method Summary collapse
-
#initialize(end_behavior: nil) ⇒ TrialSettings
constructor
A new instance of TrialSettings.
Methods inherited from RequestParams
Constructor Details
#initialize(end_behavior: nil) ⇒ TrialSettings
Returns a new instance of TrialSettings.
2582 2583 2584 |
# File 'lib/stripe/services/invoice_service.rb', line 2582 def initialize(end_behavior: nil) @end_behavior = end_behavior end |
Instance Attribute Details
#end_behavior ⇒ Object
Defines how the subscription should behave when a trial ends.
2580 2581 2582 |
# File 'lib/stripe/services/invoice_service.rb', line 2580 def end_behavior @end_behavior end |