Class: Stripe::InvoiceService::UpcomingParams::ScheduleDetails::Prebilling
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::UpcomingParams::ScheduleDetails::Prebilling
- Defined in:
- lib/stripe/services/invoice_service.rb
Defined Under Namespace
Classes: BillUntil
Instance Attribute Summary collapse
-
#bill_until ⇒ Object
The end of the prebilled time period.
-
#iterations ⇒ Object
This is used to determine the number of billing cycles to prebill.
Instance Method Summary collapse
-
#initialize(bill_until: nil, iterations: nil) ⇒ Prebilling
constructor
A new instance of Prebilling.
Methods inherited from RequestParams
Constructor Details
#initialize(bill_until: nil, iterations: nil) ⇒ Prebilling
Returns a new instance of Prebilling.
2739 2740 2741 2742 |
# File 'lib/stripe/services/invoice_service.rb', line 2739 def initialize(bill_until: nil, iterations: nil) @bill_until = bill_until @iterations = iterations end |
Instance Attribute Details
#bill_until ⇒ Object
The end of the prebilled time period.
2735 2736 2737 |
# File 'lib/stripe/services/invoice_service.rb', line 2735 def bill_until @bill_until end |
#iterations ⇒ Object
This is used to determine the number of billing cycles to prebill.
2737 2738 2739 |
# File 'lib/stripe/services/invoice_service.rb', line 2737 def iterations @iterations end |