Class: Stripe::InvoiceService::UpcomingParams::SubscriptionDetails::Item

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: BillingThresholds, Discount, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_thresholds: nil, clear_usage: nil, deleted: nil, discounts: nil, id: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ Item

Returns a new instance of Item.



3301
3302
3303
3304
3305
3306
3307
3308
3309
3310
3311
3312
3313
3314
3315
3316
3317
3318
3319
3320
3321
3322
3323
3324
3325
# File 'lib/stripe/services/invoice_service.rb', line 3301

def initialize(
  billing_thresholds: nil,
  clear_usage: nil,
  deleted: nil,
  discounts: nil,
  id: nil,
  metadata: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @billing_thresholds = billing_thresholds
  @clear_usage = clear_usage
  @deleted = deleted
  @discounts = discounts
  @id = id
  @metadata = 
  @plan = plan
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. When updating, pass an empty string to remove previously-defined thresholds.



3269
3270
3271
# File 'lib/stripe/services/invoice_service.rb', line 3269

def billing_thresholds
  @billing_thresholds
end

#clear_usageObject

Delete all usage for a given subscription item. You must pass this when deleting a usage records subscription item. ‘clear_usage` has no effect if the plan has a billing meter attached.



3272
3273
3274
# File 'lib/stripe/services/invoice_service.rb', line 3272

def clear_usage
  @clear_usage
end

#deletedObject

A flag that, if set to ‘true`, will delete the specified item.



3275
3276
3277
# File 'lib/stripe/services/invoice_service.rb', line 3275

def deleted
  @deleted
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



3278
3279
3280
# File 'lib/stripe/services/invoice_service.rb', line 3278

def discounts
  @discounts
end

#idObject

Subscription item to update.



3281
3282
3283
# File 'lib/stripe/services/invoice_service.rb', line 3281

def id
  @id
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



3284
3285
3286
# File 'lib/stripe/services/invoice_service.rb', line 3284

def 
  @metadata
end

#planObject

Plan ID for this item, as a string.



3287
3288
3289
# File 'lib/stripe/services/invoice_service.rb', line 3287

def plan
  @plan
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required. When changing a subscription item’s price, ‘quantity` is set to 1 unless a `quantity` parameter is provided.



3290
3291
3292
# File 'lib/stripe/services/invoice_service.rb', line 3290

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.



3293
3294
3295
# File 'lib/stripe/services/invoice_service.rb', line 3293

def price_data
  @price_data
end

#quantityObject

Quantity for this item.



3296
3297
3298
# File 'lib/stripe/services/invoice_service.rb', line 3296

def quantity
  @quantity
end

#tax_ratesObject

A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



3299
3300
3301
# File 'lib/stripe/services/invoice_service.rb', line 3299

def tax_rates
  @tax_rates
end