Class: Stripe::InvoiceService::UpcomingParams::SubscriptionDetails::Item::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



3213
3214
3215
3216
3217
3218
# File 'lib/stripe/services/invoice_service.rb', line 3213

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



3202
3203
3204
# File 'lib/stripe/services/invoice_service.rb', line 3202

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



3205
3206
3207
# File 'lib/stripe/services/invoice_service.rb', line 3205

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



3208
3209
3210
# File 'lib/stripe/services/invoice_service.rb', line 3208

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



3211
3212
3213
# File 'lib/stripe/services/invoice_service.rb', line 3211

def promotion_code
  @promotion_code
end