Class: Stripe::InvoiceService::UpcomingParams::SubscriptionDetails::Item::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



3195
3196
3197
3198
3199
# File 'lib/stripe/services/invoice_service.rb', line 3195

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



3187
3188
3189
# File 'lib/stripe/services/invoice_service.rb', line 3187

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



3190
3191
3192
# File 'lib/stripe/services/invoice_service.rb', line 3190

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



3193
3194
3195
# File 'lib/stripe/services/invoice_service.rb', line 3193

def type
  @type
end