Class: Stripe::InvoiceService::UpcomingParams::SubscriptionItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: BillingThresholds, Discount, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_thresholds: nil, clear_usage: nil, deleted: nil, discounts: nil, id: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ SubscriptionItem

Returns a new instance of SubscriptionItem.



3098
3099
3100
3101
3102
3103
3104
3105
3106
3107
3108
3109
3110
3111
3112
3113
3114
3115
3116
3117
3118
3119
3120
3121
3122
# File 'lib/stripe/services/invoice_service.rb', line 3098

def initialize(
  billing_thresholds: nil,
  clear_usage: nil,
  deleted: nil,
  discounts: nil,
  id: nil,
  metadata: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @billing_thresholds = billing_thresholds
  @clear_usage = clear_usage
  @deleted = deleted
  @discounts = discounts
  @id = id
  @metadata = 
  @plan = plan
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. When updating, pass an empty string to remove previously-defined thresholds.



3076
3077
3078
# File 'lib/stripe/services/invoice_service.rb', line 3076

def billing_thresholds
  @billing_thresholds
end

#clear_usageObject

Delete all usage for a given subscription item. You must pass this when deleting a usage records subscription item. ‘clear_usage` has no effect if the plan has a billing meter attached.



3078
3079
3080
# File 'lib/stripe/services/invoice_service.rb', line 3078

def clear_usage
  @clear_usage
end

#deletedObject

A flag that, if set to ‘true`, will delete the specified item.



3080
3081
3082
# File 'lib/stripe/services/invoice_service.rb', line 3080

def deleted
  @deleted
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



3082
3083
3084
# File 'lib/stripe/services/invoice_service.rb', line 3082

def discounts
  @discounts
end

#idObject

Subscription item to update.



3084
3085
3086
# File 'lib/stripe/services/invoice_service.rb', line 3084

def id
  @id
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



3086
3087
3088
# File 'lib/stripe/services/invoice_service.rb', line 3086

def 
  @metadata
end

#planObject

Plan ID for this item, as a string.



3088
3089
3090
# File 'lib/stripe/services/invoice_service.rb', line 3088

def plan
  @plan
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required. When changing a subscription item’s price, ‘quantity` is set to 1 unless a `quantity` parameter is provided.



3090
3091
3092
# File 'lib/stripe/services/invoice_service.rb', line 3090

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.



3092
3093
3094
# File 'lib/stripe/services/invoice_service.rb', line 3092

def price_data
  @price_data
end

#quantityObject

Quantity for this item.



3094
3095
3096
# File 'lib/stripe/services/invoice_service.rb', line 3094

def quantity
  @quantity
end

#tax_ratesObject

A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



3096
3097
3098
# File 'lib/stripe/services/invoice_service.rb', line 3096

def tax_rates
  @tax_rates
end