Class: Stripe::InvoiceService::UpcomingParams::SubscriptionItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



3026
3027
3028
3029
3030
3031
# File 'lib/stripe/services/invoice_service.rb', line 3026

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



3018
3019
3020
# File 'lib/stripe/services/invoice_service.rb', line 3018

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



3020
3021
3022
# File 'lib/stripe/services/invoice_service.rb', line 3020

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



3022
3023
3024
# File 'lib/stripe/services/invoice_service.rb', line 3022

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



3024
3025
3026
# File 'lib/stripe/services/invoice_service.rb', line 3024

def promotion_code
  @promotion_code
end