Class: Stripe::InvoiceService::UpcomingParams::SubscriptionItem::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::UpcomingParams::SubscriptionItem::Discount::DiscountEnd
- Defined in:
- lib/stripe/services/invoice_service.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
3011 3012 3013 3014 3015 |
# File 'lib/stripe/services/invoice_service.rb', line 3011 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
3005 3006 3007 |
# File 'lib/stripe/services/invoice_service.rb', line 3005 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
3007 3008 3009 |
# File 'lib/stripe/services/invoice_service.rb', line 3007 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
3009 3010 3011 |
# File 'lib/stripe/services/invoice_service.rb', line 3009 def type @type end |