Class: Stripe::InvoiceService::UpdateLinesParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::UpdateLinesParams
- Defined in:
- lib/stripe/services/invoice_service.rb
Defined Under Namespace
Classes: Line
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#invoice_metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#lines ⇒ Object
The line items to update.
Instance Method Summary collapse
-
#initialize(expand: nil, invoice_metadata: nil, lines: nil) ⇒ UpdateLinesParams
constructor
A new instance of UpdateLinesParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, invoice_metadata: nil, lines: nil) ⇒ UpdateLinesParams
Returns a new instance of UpdateLinesParams.
1799 1800 1801 1802 1803 |
# File 'lib/stripe/services/invoice_service.rb', line 1799 def initialize(expand: nil, invoice_metadata: nil, lines: nil) @expand = @invoice_metadata = @lines = lines end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1793 1794 1795 |
# File 'lib/stripe/services/invoice_service.rb', line 1793 def @expand end |
#invoice_metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`. For [type=subscription](stripe.com/docs/api/invoices/line_item#invoice_line_item_object-type) line items, the incoming metadata specified on the request is directly used to set this value, in contrast to [type=invoiceitem](api/invoices/line_item#invoice_line_item_object-type) line items, where any existing metadata on the invoice line is merged with the incoming data.
1795 1796 1797 |
# File 'lib/stripe/services/invoice_service.rb', line 1795 def @invoice_metadata end |
#lines ⇒ Object
The line items to update.
1797 1798 1799 |
# File 'lib/stripe/services/invoice_service.rb', line 1797 def lines @lines end |