Class: Stripe::InvoiceService::UpdateLinesParams::Line::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1895
1896
1897
1898
1899
1900
# File 'lib/stripe/services/invoice_service.rb', line 1895

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1887
1888
1889
# File 'lib/stripe/services/invoice_service.rb', line 1887

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1889
1890
1891
# File 'lib/stripe/services/invoice_service.rb', line 1889

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1891
1892
1893
# File 'lib/stripe/services/invoice_service.rb', line 1891

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1893
1894
1895
# File 'lib/stripe/services/invoice_service.rb', line 1893

def promotion_code
  @promotion_code
end