Class: Stripe::InvoiceService::UpdateLinesParams::Line::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::UpdateLinesParams::Line::Discount::DiscountEnd
- Defined in:
- lib/stripe/services/invoice_service.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
1820 1821 1822 1823 1824 |
# File 'lib/stripe/services/invoice_service.rb', line 1820 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
1814 1815 1816 |
# File 'lib/stripe/services/invoice_service.rb', line 1814 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
1816 1817 1818 |
# File 'lib/stripe/services/invoice_service.rb', line 1816 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
1818 1819 1820 |
# File 'lib/stripe/services/invoice_service.rb', line 1818 def type @type end |