Class: Stripe::InvoiceService::UpdateLinesParams::Line::Discount::DiscountEnd::Duration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(interval: nil, interval_count: nil) ⇒ Duration

Returns a new instance of Duration.



1808
1809
1810
1811
# File 'lib/stripe/services/invoice_service.rb', line 1808

def initialize(interval: nil, interval_count: nil)
  @interval = interval
  @interval_count = interval_count
end

Instance Attribute Details

#intervalObject

Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.



1804
1805
1806
# File 'lib/stripe/services/invoice_service.rb', line 1804

def interval
  @interval
end

#interval_countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



1806
1807
1808
# File 'lib/stripe/services/invoice_service.rb', line 1806

def interval_count
  @interval_count
end