Class: Stripe::InvoiceService::UpdateLinesParams::Line::Period
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::UpdateLinesParams::Line::Period
- Defined in:
- lib/stripe/services/invoice_service.rb
Instance Attribute Summary collapse
-
#end ⇒ Object
The end of the period, which must be greater than or equal to the start.
-
#start ⇒ Object
The start of the period.
Instance Method Summary collapse
-
#initialize(end_: nil, start: nil) ⇒ Period
constructor
A new instance of Period.
Methods inherited from RequestParams
Constructor Details
#initialize(end_: nil, start: nil) ⇒ Period
Returns a new instance of Period.
3700 3701 3702 3703 |
# File 'lib/stripe/services/invoice_service.rb', line 3700 def initialize(end_: nil, start: nil) @end = end_ @start = start end |
Instance Attribute Details
#end ⇒ Object
The end of the period, which must be greater than or equal to the start. This value is inclusive.
3696 3697 3698 |
# File 'lib/stripe/services/invoice_service.rb', line 3696 def end @end end |
#start ⇒ Object
The start of the period. This value is inclusive.
3698 3699 3700 |
# File 'lib/stripe/services/invoice_service.rb', line 3698 def start @start end |