Class: Stripe::InvoiceService::UpdateLinesParams::Line::PriceData::ProductData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil) ⇒ ProductData

Returns a new instance of ProductData.



1868
1869
1870
1871
1872
1873
1874
# File 'lib/stripe/services/invoice_service.rb', line 1868

def initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil)
  @description = description
  @images = images
  @metadata = 
  @name = name
  @tax_code = tax_code
end

Instance Attribute Details

#descriptionObject

The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.



1858
1859
1860
# File 'lib/stripe/services/invoice_service.rb', line 1858

def description
  @description
end

#imagesObject

A list of up to 8 URLs of images for this product, meant to be displayable to the customer.



1860
1861
1862
# File 'lib/stripe/services/invoice_service.rb', line 1860

def images
  @images
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1862
1863
1864
# File 'lib/stripe/services/invoice_service.rb', line 1862

def 
  @metadata
end

#nameObject

The product’s name, meant to be displayable to the customer.



1864
1865
1866
# File 'lib/stripe/services/invoice_service.rb', line 1864

def name
  @name
end

#tax_codeObject



1866
1867
1868
# File 'lib/stripe/services/invoice_service.rb', line 1866

def tax_code
  @tax_code
end