Class: Stripe::InvoiceService::UpdateLinesParams::Line::TaxAmount::TaxRateData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(country: nil, description: nil, display_name: nil, inclusive: nil, jurisdiction: nil, jurisdiction_level: nil, percentage: nil, state: nil, tax_type: nil) ⇒ TaxRateData

Returns a new instance of TaxRateData.



1936
1937
1938
1939
1940
1941
1942
1943
1944
1945
1946
1947
1948
1949
1950
1951
1952
1953
1954
1955
1956
# File 'lib/stripe/services/invoice_service.rb', line 1936

def initialize(
  country: nil,
  description: nil,
  display_name: nil,
  inclusive: nil,
  jurisdiction: nil,
  jurisdiction_level: nil,
  percentage: nil,
  state: nil,
  tax_type: nil
)
  @country = country
  @description = description
  @display_name = display_name
  @inclusive = inclusive
  @jurisdiction = jurisdiction
  @jurisdiction_level = jurisdiction_level
  @percentage = percentage
  @state = state
  @tax_type = tax_type
end

Instance Attribute Details

#countryObject

Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).



1918
1919
1920
# File 'lib/stripe/services/invoice_service.rb', line 1918

def country
  @country
end

#descriptionObject

An arbitrary string attached to the tax rate for your internal use only. It will not be visible to your customers.



1920
1921
1922
# File 'lib/stripe/services/invoice_service.rb', line 1920

def description
  @description
end

#display_nameObject

The display name of the tax rate, which will be shown to users.



1922
1923
1924
# File 'lib/stripe/services/invoice_service.rb', line 1922

def display_name
  @display_name
end

#inclusiveObject

This specifies if the tax rate is inclusive or exclusive.



1924
1925
1926
# File 'lib/stripe/services/invoice_service.rb', line 1924

def inclusive
  @inclusive
end

#jurisdictionObject

The jurisdiction for the tax rate. You can use this label field for tax reporting purposes. It also appears on your customer’s invoice.



1926
1927
1928
# File 'lib/stripe/services/invoice_service.rb', line 1926

def jurisdiction
  @jurisdiction
end

#jurisdiction_levelObject

The level of the jurisdiction that imposes this tax rate.



1928
1929
1930
# File 'lib/stripe/services/invoice_service.rb', line 1928

def jurisdiction_level
  @jurisdiction_level
end

#percentageObject

The statutory tax rate percent. This field accepts decimal values between 0 and 100 inclusive with at most 4 decimal places. To accommodate fixed-amount taxes, set the percentage to zero. Stripe will not display zero percentages on the invoice unless the ‘amount` of the tax is also zero.



1930
1931
1932
# File 'lib/stripe/services/invoice_service.rb', line 1930

def percentage
  @percentage
end

#stateObject

[ISO 3166-2 subdivision code](en.wikipedia.org/wiki/ISO_3166-2:US), without country prefix. For example, “NY” for New York, United States.



1932
1933
1934
# File 'lib/stripe/services/invoice_service.rb', line 1932

def state
  @state
end

#tax_typeObject

The high-level tax type, such as ‘vat` or `sales_tax`.



1934
1935
1936
# File 'lib/stripe/services/invoice_service.rb', line 1934

def tax_type
  @tax_type
end