Class: Stripe::InvoiceService::UpdateParams::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



113
114
115
116
117
118
# File 'lib/stripe/services/invoice_service.rb', line 113

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



105
106
107
# File 'lib/stripe/services/invoice_service.rb', line 105

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



107
108
109
# File 'lib/stripe/services/invoice_service.rb', line 107

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



109
110
111
# File 'lib/stripe/services/invoice_service.rb', line 109

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



111
112
113
# File 'lib/stripe/services/invoice_service.rb', line 111

def promotion_code
  @promotion_code
end