Class: Stripe::InvoiceService::UpdateParams::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



99
100
101
102
103
# File 'lib/stripe/services/invoice_service.rb', line 99

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



93
94
95
# File 'lib/stripe/services/invoice_service.rb', line 93

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



95
96
97
# File 'lib/stripe/services/invoice_service.rb', line 95

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



97
98
99
# File 'lib/stripe/services/invoice_service.rb', line 97

def type
  @type
end