Class: Stripe::InvoiceService::UpdateParams::PaymentSettings::PaymentMethodOptions::Card::Installments::Plan

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(count: nil, interval: nil, type: nil) ⇒ Plan

Returns a new instance of Plan.



129
130
131
132
133
# File 'lib/stripe/services/invoice_service.rb', line 129

def initialize(count: nil, interval: nil, type: nil)
  @count = count
  @interval = interval
  @type = type
end

Instance Attribute Details

#countObject

For ‘fixed_count` installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.



122
123
124
# File 'lib/stripe/services/invoice_service.rb', line 122

def count
  @count
end

#intervalObject

For ‘fixed_count` installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of `month`.



125
126
127
# File 'lib/stripe/services/invoice_service.rb', line 125

def interval
  @interval
end

#typeObject

Type of installment plan, one of ‘fixed_count`.



127
128
129
# File 'lib/stripe/services/invoice_service.rb', line 127

def type
  @type
end