Class: Stripe::InvoiceService::UpdateParams::TransferData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::UpdateParams::TransferData
- Defined in:
- lib/stripe/services/invoice_service.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount that will be transferred automatically when the invoice is paid.
-
#destination ⇒ Object
ID of an existing, connected Stripe account.
Instance Method Summary collapse
-
#initialize(amount: nil, destination: nil) ⇒ TransferData
constructor
A new instance of TransferData.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, destination: nil) ⇒ TransferData
Returns a new instance of TransferData.
520 521 522 523 |
# File 'lib/stripe/services/invoice_service.rb', line 520 def initialize(amount: nil, destination: nil) @amount = amount @destination = destination end |
Instance Attribute Details
#amount ⇒ Object
The amount that will be transferred automatically when the invoice is paid. If no amount is set, the full amount is transferred.
516 517 518 |
# File 'lib/stripe/services/invoice_service.rb', line 516 def amount @amount end |
#destination ⇒ Object
ID of an existing, connected Stripe account.
518 519 520 |
# File 'lib/stripe/services/invoice_service.rb', line 518 def destination @destination end |