Class: Stripe::InvoiceUpcomingLinesService

Inherits:
StripeService show all
Defined in:
lib/stripe/services/invoice_upcoming_lines_service.rb

Defined Under Namespace

Classes: ListParams

Instance Method Summary collapse

Methods inherited from StripeService

#initialize, #request, #request_stream

Constructor Details

This class inherits a constructor from Stripe::StripeService

Instance Method Details

#list(params = {}, opts = {}) ⇒ Object

When retrieving an upcoming invoice, you’ll get a lines property containing the total count of line items and the first handful of those items. There is also a URL where you can retrieve the full (paginated) list of line items.



1871
1872
1873
1874
1875
1876
1877
1878
1879
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1871

def list(params = {}, opts = {})
  request(
    method: :get,
    path: "/v1/invoices/upcoming/lines",
    params: params,
    opts: opts,
    base_address: :api
  )
end