Class: Stripe::InvoiceUpcomingLinesService::ListParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_upcoming_lines_service.rb

Defined Under Namespace

Classes: AutomaticTax, CustomerDetails, Discount, InvoiceItem, Issuer, ScheduleDetails, SubscriptionDetails, SubscriptionItem, SubscriptionPrebilling

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(automatic_tax: nil, coupon: nil, currency: nil, customer: nil, customer_details: nil, discounts: nil, ending_before: nil, expand: nil, invoice_items: nil, issuer: nil, limit: nil, on_behalf_of: nil, preview_mode: nil, schedule: nil, schedule_details: nil, starting_after: nil, subscription: nil, subscription_billing_cycle_anchor: nil, subscription_cancel_at: nil, subscription_cancel_at_period_end: nil, subscription_cancel_now: nil, subscription_default_tax_rates: nil, subscription_details: nil, subscription_items: nil, subscription_prebilling: nil, subscription_proration_behavior: nil, subscription_proration_date: nil, subscription_resume_at: nil, subscription_start_date: nil, subscription_trial_end: nil, subscription_trial_from_plan: nil) ⇒ ListParams

Returns a new instance of ListParams.



1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
1831
1832
1833
1834
1835
1836
1837
1838
1839
1840
1841
1842
1843
1844
1845
1846
1847
1848
1849
1850
1851
1852
1853
1854
1855
1856
1857
1858
1859
1860
1861
1862
1863
1864
1865
1866
1867
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1803

def initialize(
  automatic_tax: nil,
  coupon: nil,
  currency: nil,
  customer: nil,
  customer_details: nil,
  discounts: nil,
  ending_before: nil,
  expand: nil,
  invoice_items: nil,
  issuer: nil,
  limit: nil,
  on_behalf_of: nil,
  preview_mode: nil,
  schedule: nil,
  schedule_details: nil,
  starting_after: nil,
  subscription: nil,
  subscription_billing_cycle_anchor: nil,
  subscription_cancel_at: nil,
  subscription_cancel_at_period_end: nil,
  subscription_cancel_now: nil,
  subscription_default_tax_rates: nil,
  subscription_details: nil,
  subscription_items: nil,
  subscription_prebilling: nil,
  subscription_proration_behavior: nil,
  subscription_proration_date: nil,
  subscription_resume_at: nil,
  subscription_start_date: nil,
  subscription_trial_end: nil,
  subscription_trial_from_plan: nil
)
  @automatic_tax = automatic_tax
  @coupon = coupon
  @currency = currency
  @customer = customer
  @customer_details = customer_details
  @discounts = discounts
  @ending_before = ending_before
  @expand = expand
  @invoice_items = invoice_items
  @issuer = issuer
  @limit = limit
  @on_behalf_of = on_behalf_of
  @preview_mode = preview_mode
  @schedule = schedule
  @schedule_details = schedule_details
  @starting_after = starting_after
  @subscription = subscription
  @subscription_billing_cycle_anchor = subscription_billing_cycle_anchor
  @subscription_cancel_at = subscription_cancel_at
  @subscription_cancel_at_period_end = subscription_cancel_at_period_end
  @subscription_cancel_now = subscription_cancel_now
  @subscription_default_tax_rates = subscription_default_tax_rates
  @subscription_details = subscription_details
  @subscription_items = subscription_items
  @subscription_prebilling = subscription_prebilling
  @subscription_proration_behavior = subscription_proration_behavior
  @subscription_proration_date = subscription_proration_date
  @subscription_resume_at = subscription_resume_at
  @subscription_start_date = subscription_start_date
  @subscription_trial_end = subscription_trial_end
  @subscription_trial_from_plan = subscription_trial_from_plan
end

Instance Attribute Details

#automatic_taxObject

Settings for automatic tax lookup for this invoice preview.



1741
1742
1743
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1741

def automatic_tax
  @automatic_tax
end

#couponObject

The ID of the coupon to apply to this phase of the subscription schedule. This field has been deprecated and will be removed in a future API version. Use ‘discounts` instead.



1743
1744
1745
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1743

def coupon
  @coupon
end

#currencyObject

The currency to preview this invoice in. Defaults to that of ‘customer` if not specified.



1745
1746
1747
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1745

def currency
  @currency
end

#customerObject

The identifier of the customer whose upcoming invoice you’d like to retrieve. If ‘automatic_tax` is enabled then one of `customer`, `customer_details`, `subscription`, or `schedule` must be set.



1747
1748
1749
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1747

def customer
  @customer
end

#customer_detailsObject

Details about the customer you want to invoice or overrides for an existing customer. If ‘automatic_tax` is enabled then one of `customer`, `customer_details`, `subscription`, or `schedule` must be set.



1749
1750
1751
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1749

def customer_details
  @customer_details
end

#discountsObject

The coupons to redeem into discounts for the invoice preview. If not specified, inherits the discount from the subscription or customer. This works for both coupons directly applied to an invoice and coupons applied to a subscription. Pass an empty string to avoid inheriting any discounts.



1751
1752
1753
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1751

def discounts
  @discounts
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



1753
1754
1755
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1753

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



1755
1756
1757
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1755

def expand
  @expand
end

#invoice_itemsObject

List of invoice items to add or update in the upcoming invoice preview (up to 250).



1757
1758
1759
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1757

def invoice_items
  @invoice_items
end

#issuerObject

The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.



1759
1760
1761
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1759

def issuer
  @issuer
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



1761
1762
1763
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1761

def limit
  @limit
end

#on_behalf_ofObject

The account (if any) for which the funds of the invoice payment are intended. If set, the invoice will be presented with the branding and support information of the specified account. See the [Invoices with Connect](stripe.com/docs/billing/invoices/connect) documentation for details.



1763
1764
1765
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1763

def on_behalf_of
  @on_behalf_of
end

#preview_modeObject

Customizes the types of values to include when calculating the invoice. Defaults to ‘next` if unspecified.



1765
1766
1767
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1765

def preview_mode
  @preview_mode
end

#scheduleObject

The identifier of the schedule whose upcoming invoice you’d like to retrieve. Cannot be used with subscription or subscription fields.



1767
1768
1769
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1767

def schedule
  @schedule
end

#schedule_detailsObject

The schedule creation or modification params to apply as a preview. Cannot be used with ‘subscription` or `subscription_` prefixed fields.



1769
1770
1771
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1769

def schedule_details
  @schedule_details
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



1771
1772
1773
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1771

def starting_after
  @starting_after
end

#subscriptionObject

The identifier of the subscription for which you’d like to retrieve the upcoming invoice. If not provided, but a ‘subscription_details.items` is provided, you will preview creating a subscription with those items. If neither `subscription` nor `subscription_details.items` is provided, you will retrieve the next upcoming invoice from among the customer’s subscriptions.



1773
1774
1775
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1773

def subscription
  @subscription
end

#subscription_billing_cycle_anchorObject

For new subscriptions, a future timestamp to anchor the subscription’s [billing cycle](stripe.com/docs/subscriptions/billing-cycle). This is used to determine the date of the first full invoice, and, for plans with ‘month` or `year` intervals, the day of the month for subsequent invoices. For existing subscriptions, the value can only be set to `now` or `unchanged`. This field has been deprecated and will be removed in a future API version. Use `subscription_details.billing_cycle_anchor` instead.



1775
1776
1777
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1775

def subscription_billing_cycle_anchor
  @subscription_billing_cycle_anchor
end

#subscription_cancel_atObject

A timestamp at which the subscription should cancel. If set to a date before the current period ends, this will cause a proration if prorations have been enabled using ‘proration_behavior`. If set during a future period, this will always cause a proration for that period. This field has been deprecated and will be removed in a future API version. Use `subscription_details.cancel_at` instead.



1777
1778
1779
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1777

def subscription_cancel_at
  @subscription_cancel_at
end

#subscription_cancel_at_period_endObject

Indicate whether this subscription should cancel at the end of the current period (‘current_period_end`). Defaults to `false`. This field has been deprecated and will be removed in a future API version. Use `subscription_details.cancel_at_period_end` instead.



1779
1780
1781
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1779

def subscription_cancel_at_period_end
  @subscription_cancel_at_period_end
end

#subscription_cancel_nowObject

This simulates the subscription being canceled or expired immediately. This field has been deprecated and will be removed in a future API version. Use ‘subscription_details.cancel_now` instead.



1781
1782
1783
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1781

def subscription_cancel_now
  @subscription_cancel_now
end

#subscription_default_tax_ratesObject

If provided, the invoice returned will preview updating or creating a subscription with these default tax rates. The default tax rates will apply to any line item that does not have ‘tax_rates` set. This field has been deprecated and will be removed in a future API version. Use `subscription_details.default_tax_rates` instead.



1783
1784
1785
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1783

def subscription_default_tax_rates
  @subscription_default_tax_rates
end

#subscription_detailsObject

The subscription creation or modification params to apply as a preview. Cannot be used with ‘schedule` or `schedule_details` fields.



1785
1786
1787
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1785

def subscription_details
  @subscription_details
end

#subscription_itemsObject

A list of up to 20 subscription items, each with an attached price. This field has been deprecated and will be removed in a future API version. Use ‘subscription_details.items` instead.



1787
1788
1789
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1787

def subscription_items
  @subscription_items
end

#subscription_prebillingObject

The pre-billing to apply to the subscription as a preview. This field has been deprecated and will be removed in a future API version. Use ‘subscription_details.prebilling` instead.



1789
1790
1791
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1789

def subscription_prebilling
  @subscription_prebilling
end

#subscription_proration_behaviorObject

Determines how to handle [prorations](stripe.com/docs/billing/subscriptions/prorations) when the billing cycle changes (e.g., when switching plans, resetting ‘billing_cycle_anchor=now`, or starting a trial), or if an item’s ‘quantity` changes. The default value is `create_prorations`. This field has been deprecated and will be removed in a future API version. Use `subscription_details.proration_behavior` instead.



1791
1792
1793
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1791

def subscription_proration_behavior
  @subscription_proration_behavior
end

#subscription_proration_dateObject

If previewing an update to a subscription, and doing proration, ‘subscription_proration_date` forces the proration to be calculated as though the update was done at the specified time. The time given must be within the current subscription period and within the current phase of the schedule backing this subscription, if the schedule exists. If set, `subscription`, and one of `subscription_items`, or `subscription_trial_end` are required. Also, `subscription_proration_behavior` cannot be set to ’none’. This field has been deprecated and will be removed in a future API version. Use ‘subscription_details.proration_date` instead.



1793
1794
1795
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1793

def subscription_proration_date
  @subscription_proration_date
end

#subscription_resume_atObject

For paused subscriptions, setting ‘subscription_resume_at` to `now` will preview the invoice that will be generated if the subscription is resumed. This field has been deprecated and will be removed in a future API version. Use `subscription_details.resume_at` instead.



1795
1796
1797
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1795

def subscription_resume_at
  @subscription_resume_at
end

#subscription_start_dateObject

Date a subscription is intended to start (can be future or past). This field has been deprecated and will be removed in a future API version. Use ‘subscription_details.start_date` instead.



1797
1798
1799
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1797

def subscription_start_date
  @subscription_start_date
end

#subscription_trial_endObject

If provided, the invoice returned will preview updating or creating a subscription with that trial end. If set, one of ‘subscription_items` or `subscription` is required. This field has been deprecated and will be removed in a future API version. Use `subscription_details.trial_end` instead.



1799
1800
1801
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1799

def subscription_trial_end
  @subscription_trial_end
end

#subscription_trial_from_planObject

Indicates if a plan’s ‘trial_period_days` should be applied to the subscription. Setting `subscription_trial_end` per subscription is preferred, and this defaults to `false`. Setting this flag to `true` together with `subscription_trial_end` is not allowed. See [Using trial periods on subscriptions](stripe.com/docs/billing/subscriptions/trials) to learn more.



1801
1802
1803
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1801

def subscription_trial_from_plan
  @subscription_trial_from_plan
end