Class: Stripe::InvoiceUpcomingLinesService::ListParams::InvoiceItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_upcoming_lines_service.rb

Defined Under Namespace

Classes: Discount, Period, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, currency: nil, description: nil, discountable: nil, discounts: nil, invoiceitem: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_behavior: nil, tax_code: nil, tax_rates: nil, unit_amount: nil, unit_amount_decimal: nil) ⇒ InvoiceItem

Returns a new instance of InvoiceItem.



356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 356

def initialize(
  amount: nil,
  currency: nil,
  description: nil,
  discountable: nil,
  discounts: nil,
  invoiceitem: nil,
  metadata: nil,
  period: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_behavior: nil,
  tax_code: nil,
  tax_rates: nil,
  unit_amount: nil,
  unit_amount_decimal: nil
)
  @amount = amount
  @currency = currency
  @description = description
  @discountable = discountable
  @discounts = discounts
  @invoiceitem = invoiceitem
  @metadata = 
  @period = period
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_behavior = tax_behavior
  @tax_code = tax_code
  @tax_rates = tax_rates
  @unit_amount = unit_amount
  @unit_amount_decimal = unit_amount_decimal
end

Instance Attribute Details

#amountObject

The integer amount in cents (or local equivalent) of previewed invoice item.



309
310
311
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 309

def amount
  @amount
end

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies). Only applicable to new invoice items.



312
313
314
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 312

def currency
  @currency
end

#descriptionObject

An arbitrary string which you can attach to the invoice item. The description is displayed in the invoice for easy tracking.



315
316
317
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 315

def description
  @description
end

#discountableObject

Explicitly controls whether discounts apply to this invoice item. Defaults to true, except for negative invoice items.



318
319
320
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 318

def discountable
  @discountable
end

#discountsObject

The coupons to redeem into discounts for the invoice item in the preview.



321
322
323
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 321

def discounts
  @discounts
end

#invoiceitemObject

The ID of the invoice item to update in preview. If not specified, a new invoice item will be added to the preview of the upcoming invoice.



324
325
326
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 324

def invoiceitem
  @invoiceitem
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



327
328
329
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 327

def 
  @metadata
end

#periodObject

The period associated with this invoice item. When set to different values, the period will be rendered on the invoice. If you have [Stripe Revenue Recognition](stripe.com/docs/revenue-recognition) enabled, the period will be used to recognize and defer revenue. See the [Revenue Recognition documentation](stripe.com/docs/revenue-recognition/methodology/subscriptions-and-invoicing) for details.



330
331
332
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 330

def period
  @period
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required.



333
334
335
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 333

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.



336
337
338
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 336

def price_data
  @price_data
end

#quantityObject

Non-negative integer. The quantity of units for the invoice item.



339
340
341
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 339

def quantity
  @quantity
end

#tax_behaviorObject

Only required if a [default tax behavior](stripe.com/docs/tax/products-prices-tax-categories-tax-behavior#setting-a-default-tax-behavior-(recommended)) was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`. Once specified as either `inclusive` or `exclusive`, it cannot be changed.



342
343
344
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 342

def tax_behavior
  @tax_behavior
end

#tax_codeObject



345
346
347
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 345

def tax_code
  @tax_code
end

#tax_ratesObject

The tax rates that apply to the item. When set, any ‘default_tax_rates` do not apply to this item.



348
349
350
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 348

def tax_rates
  @tax_rates
end

#unit_amountObject

The integer unit amount in cents (or local equivalent) of the charge to be applied to the upcoming invoice. This unit_amount will be multiplied by the quantity to get the full amount. If you want to apply a credit to the customer’s account, pass a negative unit_amount.



351
352
353
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 351

def unit_amount
  @unit_amount
end

#unit_amount_decimalObject

Same as ‘unit_amount`, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places. Only one of `unit_amount` and `unit_amount_decimal` can be set.



354
355
356
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 354

def unit_amount_decimal
  @unit_amount_decimal
end