Class: Stripe::InvoiceUpcomingLinesService::ListParams::InvoiceItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_upcoming_lines_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



211
212
213
214
215
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 211

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



205
206
207
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 205

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



207
208
209
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 207

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



209
210
211
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 209

def type
  @type
end