Class: Stripe::InvoiceUpcomingLinesService::ListParams::ScheduleDetails::Amendment::AmendmentStart::AmendmentEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceUpcomingLinesService::ListParams::ScheduleDetails::Amendment::AmendmentStart::AmendmentEnd
- Defined in:
- lib/stripe/services/invoice_upcoming_lines_service.rb
Instance Attribute Summary collapse
-
#index ⇒ Object
The position of the previous amendment in the ‘amendments` array after which this amendment should begin.
Instance Method Summary collapse
-
#initialize(index: nil) ⇒ AmendmentEnd
constructor
A new instance of AmendmentEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(index: nil) ⇒ AmendmentEnd
Returns a new instance of AmendmentEnd.
455 456 457 |
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 455 def initialize(index: nil) @index = index end |
Instance Attribute Details
#index ⇒ Object
The position of the previous amendment in the ‘amendments` array after which this amendment should begin. Indexes start from 0 and must be less than the index of the current amendment in the array.
453 454 455 |
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 453 def index @index end |