Class: Stripe::InvoiceUpcomingLinesService::ListParams::ScheduleDetails::Amendment::DiscountAction
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceUpcomingLinesService::ListParams::ScheduleDetails::Amendment::DiscountAction
- Defined in:
- lib/stripe/services/invoice_upcoming_lines_service.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#add ⇒ Object
Details of the discount to add.
-
#remove ⇒ Object
Details of the discount to remove.
-
#set ⇒ Object
Details of the discount to replace the existing discounts with.
-
#type ⇒ Object
Determines the type of discount action.
Instance Method Summary collapse
-
#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ DiscountAction
constructor
A new instance of DiscountAction.
Methods inherited from RequestParams
Constructor Details
#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ DiscountAction
Returns a new instance of DiscountAction.
573 574 575 576 577 578 |
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 573 def initialize(add: nil, remove: nil, set: nil, type: nil) @add = add @remove = remove @set = set @type = type end |
Instance Attribute Details
#add ⇒ Object
Details of the discount to add.
562 563 564 |
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 562 def add @add end |
#remove ⇒ Object
Details of the discount to remove.
565 566 567 |
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 565 def remove @remove end |
#set ⇒ Object
Details of the discount to replace the existing discounts with.
568 569 570 |
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 568 def set @set end |
#type ⇒ Object
Determines the type of discount action.
571 572 573 |
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 571 def type @type end |