Class: Stripe::InvoiceUpcomingLinesService::ListParams::ScheduleDetails::Amendment::DiscountAction::Remove

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_upcoming_lines_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Remove

Returns a new instance of Remove.



538
539
540
541
542
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 538

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to remove from the ‘discounts` array.



530
531
532
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 530

def coupon
  @coupon
end

#discountObject

The ID of a discount to remove from the ‘discounts` array.



533
534
535
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 533

def discount
  @discount
end

#promotion_codeObject

The ID of a promotion code to remove from the ‘discounts` array.



536
537
538
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 536

def promotion_code
  @promotion_code
end