Class: Stripe::InvoiceUpcomingLinesService::ListParams::ScheduleDetails::Amendment::ItemAction

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_upcoming_lines_service.rb

Defined Under Namespace

Classes: Add, Remove, Set

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ ItemAction

Returns a new instance of ItemAction.



699
700
701
702
703
704
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 699

def initialize(add: nil, remove: nil, set: nil, type: nil)
  @add = add
  @remove = remove
  @set = set
  @type = type
end

Instance Attribute Details

#addObject

Details of the subscription item to add. If an item with the same ‘price` exists, it will be replaced by this new item. Otherwise, it adds the new item.



691
692
693
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 691

def add
  @add
end

#removeObject

Details of the subscription item to remove.



693
694
695
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 693

def remove
  @remove
end

#setObject

Details of the subscription item to replace the existing items with. If an item with the ‘set` already exists, the `items` array is not cleared. Instead, all of the other `set` properties that are passed in this request will replace the existing values for the configuration item.



695
696
697
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 695

def set
  @set
end

#typeObject

Determines the type of item action.



697
698
699
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 697

def type
  @type
end