Class: Stripe::InvoiceUpcomingLinesService::ListParams::ScheduleDetails::Amendment::ItemAction::Add

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_upcoming_lines_service.rb

Defined Under Namespace

Classes: Discount, Trial

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Add

Returns a new instance of Add.



662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 662

def initialize(
  discounts: nil,
  metadata: nil,
  price: nil,
  quantity: nil,
  tax_rates: nil,
  trial: nil
)
  @discounts = discounts
  @metadata = 
  @price = price
  @quantity = quantity
  @tax_rates = tax_rates
  @trial = trial
end

Instance Attribute Details

#discountsObject

The discounts applied to the item. Subscription item discounts are applied before subscription discounts.



645
646
647
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 645

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



648
649
650
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 648

def 
  @metadata
end

#priceObject

The ID of the price object.



651
652
653
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 651

def price
  @price
end

#quantityObject

Quantity for this item.



654
655
656
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 654

def quantity
  @quantity
end

#tax_ratesObject

The tax rates that apply to this subscription item. When set, the ‘default_tax_rates` on the subscription do not apply to this `subscription_item`.



657
658
659
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 657

def tax_rates
  @tax_rates
end

#trialObject

Options that configure the trial on the subscription item.



660
661
662
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 660

def trial
  @trial
end