Class: Stripe::InvoiceUpcomingLinesService::ListParams::ScheduleDetails::Amendment::ItemAction::Add::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_upcoming_lines_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



548
549
550
551
552
553
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 548

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



540
541
542
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 540

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



542
543
544
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 542

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



544
545
546
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 544

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



546
547
548
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 546

def promotion_code
  @promotion_code
end