Class: Stripe::InvoiceUpcomingLinesService::ListParams::ScheduleDetails::Amendment::ItemAction::Set::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_upcoming_lines_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



642
643
644
645
646
647
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 642

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



634
635
636
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 634

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



636
637
638
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 636

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



638
639
640
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 638

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



640
641
642
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 640

def promotion_code
  @promotion_code
end