Class: Stripe::InvoiceUpcomingLinesService::ListParams::ScheduleDetails::Amendment::ItemAction::Set::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_upcoming_lines_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



712
713
714
715
716
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 712

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



704
705
706
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 704

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



707
708
709
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 707

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



710
711
712
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 710

def type
  @type
end