Class: Stripe::InvoiceUpcomingLinesService::ListParams::ScheduleDetails::Amendment::SetPauseCollection::Set
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceUpcomingLinesService::ListParams::ScheduleDetails::Amendment::SetPauseCollection::Set
- Defined in:
- lib/stripe/services/invoice_upcoming_lines_service.rb
Instance Attribute Summary collapse
-
#behavior ⇒ Object
The payment collection behavior for this subscription while paused.
Instance Method Summary collapse
-
#initialize(behavior: nil) ⇒ Set
constructor
A new instance of Set.
Methods inherited from RequestParams
Constructor Details
#initialize(behavior: nil) ⇒ Set
Returns a new instance of Set.
830 831 832 |
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 830 def initialize(behavior: nil) @behavior = behavior end |
Instance Attribute Details
#behavior ⇒ Object
The payment collection behavior for this subscription while paused. One of ‘keep_as_draft`, `mark_uncollectible`, or `void`.
828 829 830 |
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 828 def behavior @behavior end |