Class: Stripe::InvoiceUpcomingLinesService::ListParams::ScheduleDetails::Phase::AddInvoiceItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_upcoming_lines_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



942
943
944
945
946
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 942

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



934
935
936
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 934

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



937
938
939
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 937

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



940
941
942
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 940

def type
  @type
end