Class: Stripe::InvoiceUpcomingLinesService::ListParams::ScheduleDetails::Phase::AutomaticTax

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_upcoming_lines_service.rb

Defined Under Namespace

Classes: Liability

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(enabled: nil, liability: nil) ⇒ AutomaticTax

Returns a new instance of AutomaticTax.



1047
1048
1049
1050
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1047

def initialize(enabled: nil, liability: nil)
  @enabled = enabled
  @liability = liability
end

Instance Attribute Details

#enabledObject

Enabled automatic tax calculation which will automatically compute tax rates on all invoices generated by the subscription.



1042
1043
1044
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1042

def enabled
  @enabled
end

#liabilityObject

The account that’s liable for tax. If set, the business address and tax registrations required to perform the tax calculation are loaded from this account. The tax transaction is returned in the report of the connected account.



1045
1046
1047
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1045

def liability
  @liability
end