Class: Stripe::InvoiceUpcomingLinesService::ListParams::ScheduleDetails::Phase::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_upcoming_lines_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1107
1108
1109
1110
1111
1112
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1107

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1096
1097
1098
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1096

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1099
1100
1101
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1099

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1102
1103
1104
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1102

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1105
1106
1107
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1105

def promotion_code
  @promotion_code
end