Class: Stripe::InvoiceUpcomingLinesService::ListParams::ScheduleDetails::Phase::Item::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_upcoming_lines_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



1177
1178
1179
1180
1181
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1177

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



1169
1170
1171
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1169

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



1172
1173
1174
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1172

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



1175
1176
1177
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1175

def type
  @type
end