Class: Stripe::InvoiceUpcomingLinesService::ListParams::ScheduleDetails::Prebilling
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceUpcomingLinesService::ListParams::ScheduleDetails::Prebilling
- Defined in:
- lib/stripe/services/invoice_upcoming_lines_service.rb
Defined Under Namespace
Classes: BillUntil
Instance Attribute Summary collapse
-
#bill_until ⇒ Object
The end of the prebilled time period.
-
#iterations ⇒ Object
This is used to determine the number of billing cycles to prebill.
Instance Method Summary collapse
-
#initialize(bill_until: nil, iterations: nil) ⇒ Prebilling
constructor
A new instance of Prebilling.
Methods inherited from RequestParams
Constructor Details
#initialize(bill_until: nil, iterations: nil) ⇒ Prebilling
Returns a new instance of Prebilling.
1346 1347 1348 1349 |
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1346 def initialize(bill_until: nil, iterations: nil) @bill_until = bill_until @iterations = iterations end |
Instance Attribute Details
#bill_until ⇒ Object
The end of the prebilled time period.
1342 1343 1344 |
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1342 def bill_until @bill_until end |
#iterations ⇒ Object
This is used to determine the number of billing cycles to prebill.
1344 1345 1346 |
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1344 def iterations @iterations end |