Class: Stripe::InvoiceUpcomingLinesService::ListParams::ScheduleDetails::Prebilling::BillUntil

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_upcoming_lines_service.rb

Defined Under Namespace

Classes: AmendmentEnd, Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ BillUntil

Returns a new instance of BillUntil.



1334
1335
1336
1337
1338
1339
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1334

def initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil)
  @amendment_end = amendment_end
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#amendment_endObject

End the prebilled period when a specified amendment ends.



1326
1327
1328
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1326

def amendment_end
  @amendment_end
end

#durationObject

Time span for prebilling, starting from ‘bill_from`.



1328
1329
1330
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1328

def duration
  @duration
end

#timestampObject

End the prebilled period at a precise integer timestamp, starting from the Unix epoch.



1330
1331
1332
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1330

def timestamp
  @timestamp
end

#typeObject

Select one of several ways to pass the ‘bill_until` value.



1332
1333
1334
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1332

def type
  @type
end