Class: Stripe::InvoiceUpcomingLinesService::ListParams::ScheduleDetails::Prebilling::BillUntil::Duration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_upcoming_lines_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(interval: nil, interval_count: nil) ⇒ Duration

Returns a new instance of Duration.



1504
1505
1506
1507
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1504

def initialize(interval: nil, interval_count: nil)
  @interval = interval
  @interval_count = interval_count
end

Instance Attribute Details

#intervalObject

Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.



1499
1500
1501
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1499

def interval
  @interval
end

#interval_countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



1502
1503
1504
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1502

def interval_count
  @interval_count
end