Class: Stripe::InvoiceUpcomingLinesService::ListParams::SubscriptionItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceUpcomingLinesService::ListParams::SubscriptionItem
- Defined in:
- lib/stripe/services/invoice_upcoming_lines_service.rb
Defined Under Namespace
Classes: BillingThresholds, Discount, PriceData
Instance Attribute Summary collapse
-
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period.
-
#clear_usage ⇒ Object
Delete all usage for a given subscription item.
-
#deleted ⇒ Object
A flag that, if set to ‘true`, will delete the specified item.
-
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription item.
-
#id ⇒ Object
Subscription item to update.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#plan ⇒ Object
Plan ID for this item, as a string.
-
#price ⇒ Object
The ID of the price object.
-
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.
-
#quantity ⇒ Object
Quantity for this item.
-
#tax_rates ⇒ Object
A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids.
Instance Method Summary collapse
-
#initialize(billing_thresholds: nil, clear_usage: nil, deleted: nil, discounts: nil, id: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ SubscriptionItem
constructor
A new instance of SubscriptionItem.
Methods inherited from RequestParams
Constructor Details
#initialize(billing_thresholds: nil, clear_usage: nil, deleted: nil, discounts: nil, id: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ SubscriptionItem
Returns a new instance of SubscriptionItem.
1705 1706 1707 1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 1727 1728 1729 |
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1705 def initialize( billing_thresholds: nil, clear_usage: nil, deleted: nil, discounts: nil, id: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil ) @billing_thresholds = billing_thresholds @clear_usage = clear_usage @deleted = deleted @discounts = discounts @id = id @metadata = @plan = plan @price = price @price_data = price_data @quantity = quantity @tax_rates = tax_rates end |
Instance Attribute Details
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. When updating, pass an empty string to remove previously-defined thresholds.
1683 1684 1685 |
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1683 def billing_thresholds @billing_thresholds end |
#clear_usage ⇒ Object
Delete all usage for a given subscription item. You must pass this when deleting a usage records subscription item. ‘clear_usage` has no effect if the plan has a billing meter attached.
1685 1686 1687 |
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1685 def clear_usage @clear_usage end |
#deleted ⇒ Object
A flag that, if set to ‘true`, will delete the specified item.
1687 1688 1689 |
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1687 def deleted @deleted end |
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription item.
1689 1690 1691 |
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1689 def discounts @discounts end |
#id ⇒ Object
Subscription item to update.
1691 1692 1693 |
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1691 def id @id end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
1693 1694 1695 |
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1693 def @metadata end |
#plan ⇒ Object
Plan ID for this item, as a string.
1695 1696 1697 |
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1695 def plan @plan end |
#price ⇒ Object
The ID of the price object. One of ‘price` or `price_data` is required. When changing a subscription item’s price, ‘quantity` is set to 1 unless a `quantity` parameter is provided.
1697 1698 1699 |
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1697 def price @price end |
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.
1699 1700 1701 |
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1699 def price_data @price_data end |
#quantity ⇒ Object
Quantity for this item.
1701 1702 1703 |
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1701 def quantity @quantity end |
#tax_rates ⇒ Object
A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.
1703 1704 1705 |
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1703 def tax_rates @tax_rates end |