Class: Stripe::InvoiceUpcomingLinesService::ListParams::SubscriptionItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_upcoming_lines_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1633
1634
1635
1636
1637
1638
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1633

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1625
1626
1627
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1625

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1627
1628
1629
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1627

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1629
1630
1631
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1629

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1631
1632
1633
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1631

def promotion_code
  @promotion_code
end