Class: Stripe::InvoiceUpcomingLinesService::ListParams::SubscriptionItem::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceUpcomingLinesService::ListParams::SubscriptionItem::Discount::DiscountEnd
- Defined in:
- lib/stripe/services/invoice_upcoming_lines_service.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
1618 1619 1620 1621 1622 |
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1618 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
1612 1613 1614 |
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1612 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
1614 1615 1616 |
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1614 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
1616 1617 1618 |
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1616 def type @type end |