Class: Stripe::InvoiceUpdateLinesParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceUpdateLinesParams
- Defined in:
- lib/stripe/params/invoice_update_lines_params.rb
Defined Under Namespace
Classes: Line
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#invoice_metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#lines ⇒ Object
The line items to update.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(expand: nil, invoice_metadata: nil, lines: nil) ⇒ InvoiceUpdateLinesParams
constructor
A new instance of InvoiceUpdateLinesParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(expand: nil, invoice_metadata: nil, lines: nil) ⇒ InvoiceUpdateLinesParams
Returns a new instance of InvoiceUpdateLinesParams.
287 288 289 290 291 |
# File 'lib/stripe/params/invoice_update_lines_params.rb', line 287 def initialize(expand: nil, invoice_metadata: nil, lines: nil) @expand = @invoice_metadata = @lines = lines end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
281 282 283 |
# File 'lib/stripe/params/invoice_update_lines_params.rb', line 281 def @expand end |
#invoice_metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`. For [type=subscription](docs.stripe.com/api/invoices/line_item#invoice_line_item_object-type) line items, the incoming metadata specified on the request is directly used to set this value, in contrast to [type=invoiceitem](api/invoices/line_item#invoice_line_item_object-type) line items, where any existing metadata on the invoice line is merged with the incoming data.
283 284 285 |
# File 'lib/stripe/params/invoice_update_lines_params.rb', line 283 def @invoice_metadata end |
#lines ⇒ Object
The line items to update.
285 286 287 |
# File 'lib/stripe/params/invoice_update_lines_params.rb', line 285 def lines @lines end |
Class Method Details
.field_encodings ⇒ Object
293 294 295 296 297 298 299 300 301 302 303 304 305 306 |
# File 'lib/stripe/params/invoice_update_lines_params.rb', line 293 def self.field_encodings @field_encodings = { lines: { kind: :array, element: { kind: :object, fields: { price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } }, quantity_decimal: :decimal_string, }, }, }, } end |