Class: Stripe::InvoiceUpdateLinesParams::Line::TaxAmount::TaxRateData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceUpdateLinesParams::Line::TaxAmount::TaxRateData
- Defined in:
- lib/stripe/params/invoice_update_lines_params.rb
Instance Attribute Summary collapse
-
#country ⇒ Object
Two-letter country code (ISO 3166-1 alpha-2).
-
#description ⇒ Object
An arbitrary string attached to the tax rate for your internal use only.
-
#display_name ⇒ Object
The display name of the tax rate, which will be shown to users.
-
#inclusive ⇒ Object
This specifies if the tax rate is inclusive or exclusive.
-
#jurisdiction ⇒ Object
The jurisdiction for the tax rate.
-
#jurisdiction_level ⇒ Object
The level of the jurisdiction that imposes this tax rate.
-
#percentage ⇒ Object
The statutory tax rate percent.
-
#state ⇒ Object
ISO 3166-2 subdivision code, without country prefix.
-
#tax_type ⇒ Object
The high-level tax type, such as
vatorsales_tax.
Instance Method Summary collapse
-
#initialize(country: nil, description: nil, display_name: nil, inclusive: nil, jurisdiction: nil, jurisdiction_level: nil, percentage: nil, state: nil, tax_type: nil) ⇒ TaxRateData
constructor
A new instance of TaxRateData.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(country: nil, description: nil, display_name: nil, inclusive: nil, jurisdiction: nil, jurisdiction_level: nil, percentage: nil, state: nil, tax_type: nil) ⇒ TaxRateData
Returns a new instance of TaxRateData.
144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/stripe/params/invoice_update_lines_params.rb', line 144 def initialize( country: nil, description: nil, display_name: nil, inclusive: nil, jurisdiction: nil, jurisdiction_level: nil, percentage: nil, state: nil, tax_type: nil ) @country = country @description = description @display_name = display_name @inclusive = inclusive @jurisdiction = jurisdiction @jurisdiction_level = jurisdiction_level @percentage = percentage @state = state @tax_type = tax_type end |
Instance Attribute Details
#country ⇒ Object
Two-letter country code (ISO 3166-1 alpha-2).
126 127 128 |
# File 'lib/stripe/params/invoice_update_lines_params.rb', line 126 def country @country end |
#description ⇒ Object
An arbitrary string attached to the tax rate for your internal use only. It will not be visible to your customers.
128 129 130 |
# File 'lib/stripe/params/invoice_update_lines_params.rb', line 128 def description @description end |
#display_name ⇒ Object
The display name of the tax rate, which will be shown to users.
130 131 132 |
# File 'lib/stripe/params/invoice_update_lines_params.rb', line 130 def display_name @display_name end |
#inclusive ⇒ Object
This specifies if the tax rate is inclusive or exclusive.
132 133 134 |
# File 'lib/stripe/params/invoice_update_lines_params.rb', line 132 def inclusive @inclusive end |
#jurisdiction ⇒ Object
The jurisdiction for the tax rate. You can use this label field for tax reporting purposes. It also appears on your customer’s invoice.
134 135 136 |
# File 'lib/stripe/params/invoice_update_lines_params.rb', line 134 def jurisdiction @jurisdiction end |
#jurisdiction_level ⇒ Object
The level of the jurisdiction that imposes this tax rate.
136 137 138 |
# File 'lib/stripe/params/invoice_update_lines_params.rb', line 136 def jurisdiction_level @jurisdiction_level end |
#percentage ⇒ Object
The statutory tax rate percent. This field accepts decimal values between 0 and 100 inclusive with at most 4 decimal places. To accommodate fixed-amount taxes, set the percentage to zero. Stripe will not display zero percentages on the invoice unless the amount of the tax is also zero.
138 139 140 |
# File 'lib/stripe/params/invoice_update_lines_params.rb', line 138 def percentage @percentage end |
#state ⇒ Object
ISO 3166-2 subdivision code, without country prefix. For example, "NY" for New York, United States.
140 141 142 |
# File 'lib/stripe/params/invoice_update_lines_params.rb', line 140 def state @state end |
#tax_type ⇒ Object
The high-level tax type, such as vat or sales_tax.
142 143 144 |
# File 'lib/stripe/params/invoice_update_lines_params.rb', line 142 def tax_type @tax_type end |