Class: Stripe::InvoiceUpdateParams::PaymentSettings::PaymentMethodOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_update_params.rb

Defined Under Namespace

Classes: AcssDebit, Bancontact, Billie, Blik, Card, CustomerBalance, IdBankTransfer, Konbini, Payto, Pix, SepaDebit, Upi, UsBankAccount

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h

Constructor Details

#initialize(acss_debit: nil, bancontact: nil, billie: nil, blik: nil, card: nil, customer_balance: nil, id_bank_transfer: nil, konbini: nil, payto: nil, pix: nil, sepa_debit: nil, upi: nil, us_bank_account: nil) ⇒ PaymentMethodOptions

Returns a new instance of PaymentMethodOptions.



346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
# File 'lib/stripe/params/invoice_update_params.rb', line 346

def initialize(
  acss_debit: nil,
  bancontact: nil,
  billie: nil,
  blik: nil,
  card: nil,
  customer_balance: nil,
  id_bank_transfer: nil,
  konbini: nil,
  payto: nil,
  pix: nil,
  sepa_debit: nil,
  upi: nil,
  us_bank_account: nil
)
  @acss_debit = acss_debit
  @bancontact = bancontact
  @billie = billie
  @blik = blik
  @card = card
  @customer_balance = customer_balance
  @id_bank_transfer = id_bank_transfer
  @konbini = konbini
  @payto = payto
  @pix = pix
  @sepa_debit = sepa_debit
  @upi = upi
  @us_bank_account = 
end

Instance Attribute Details

#acss_debitObject

If paying by acss_debit, this sub-hash contains details about the Canadian pre-authorized debit payment method options to pass to the invoice’s PaymentIntent.



320
321
322
# File 'lib/stripe/params/invoice_update_params.rb', line 320

def acss_debit
  @acss_debit
end

#bancontactObject

If paying by bancontact, this sub-hash contains details about the Bancontact payment method options to pass to the invoice’s PaymentIntent.



322
323
324
# File 'lib/stripe/params/invoice_update_params.rb', line 322

def bancontact
  @bancontact
end

#billieObject

If paying by billie, this sub-hash contains details about the Billie payment method options to pass to the invoice’s PaymentIntent.



324
325
326
# File 'lib/stripe/params/invoice_update_params.rb', line 324

def billie
  @billie
end

#blikObject

If paying by blik, this sub-hash contains details about the Blik payment method options to pass to the invoice’s PaymentIntent.



326
327
328
# File 'lib/stripe/params/invoice_update_params.rb', line 326

def blik
  @blik
end

#cardObject

If paying by card, this sub-hash contains details about the Card payment method options to pass to the invoice’s PaymentIntent.



328
329
330
# File 'lib/stripe/params/invoice_update_params.rb', line 328

def card
  @card
end

#customer_balanceObject

If paying by customer_balance, this sub-hash contains details about the Bank transfer payment method options to pass to the invoice’s PaymentIntent.



330
331
332
# File 'lib/stripe/params/invoice_update_params.rb', line 330

def customer_balance
  @customer_balance
end

#id_bank_transferObject

If paying by id_bank_transfer, this sub-hash contains details about the Indonesia bank transfer payment method options to pass to the invoice’s PaymentIntent.



332
333
334
# File 'lib/stripe/params/invoice_update_params.rb', line 332

def id_bank_transfer
  @id_bank_transfer
end

#konbiniObject

If paying by konbini, this sub-hash contains details about the Konbini payment method options to pass to the invoice’s PaymentIntent.



334
335
336
# File 'lib/stripe/params/invoice_update_params.rb', line 334

def konbini
  @konbini
end

#paytoObject

If paying by payto, this sub-hash contains details about the PayTo payment method options to pass to the invoice’s PaymentIntent.



336
337
338
# File 'lib/stripe/params/invoice_update_params.rb', line 336

def payto
  @payto
end

#pixObject

If paying by pix, this sub-hash contains details about the Pix payment method options to pass to the invoice’s PaymentIntent.



338
339
340
# File 'lib/stripe/params/invoice_update_params.rb', line 338

def pix
  @pix
end

#sepa_debitObject

If paying by sepa_debit, this sub-hash contains details about the SEPA Direct Debit payment method options to pass to the invoice’s PaymentIntent.



340
341
342
# File 'lib/stripe/params/invoice_update_params.rb', line 340

def sepa_debit
  @sepa_debit
end

#upiObject

If paying by upi, this sub-hash contains details about the UPI payment method options to pass to the invoice’s PaymentIntent.



342
343
344
# File 'lib/stripe/params/invoice_update_params.rb', line 342

def upi
  @upi
end

#us_bank_accountObject

If paying by us_bank_account, this sub-hash contains details about the ACH direct debit payment method options to pass to the invoice’s PaymentIntent.



344
345
346
# File 'lib/stripe/params/invoice_update_params.rb', line 344

def 
  @us_bank_account
end