Class: Stripe::InvoiceUpdateParams::PaymentSettings::PaymentMethodOptions::Bancontact
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceUpdateParams::PaymentSettings::PaymentMethodOptions::Bancontact
- Defined in:
- lib/stripe/params/invoice_update_params.rb
Instance Attribute Summary collapse
-
#preferred_language ⇒ Object
Preferred language of the Bancontact authorization page that the customer is redirected to.
Instance Method Summary collapse
-
#initialize(preferred_language: nil) ⇒ Bancontact
constructor
A new instance of Bancontact.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(preferred_language: nil) ⇒ Bancontact
Returns a new instance of Bancontact.
140 141 142 |
# File 'lib/stripe/params/invoice_update_params.rb', line 140 def initialize(preferred_language: nil) @preferred_language = preferred_language end |
Instance Attribute Details
#preferred_language ⇒ Object
Preferred language of the Bancontact authorization page that the customer is redirected to.
138 139 140 |
# File 'lib/stripe/params/invoice_update_params.rb', line 138 def preferred_language @preferred_language end |