Class: Stripe::InvoiceUpdateParams::PaymentSettings::PaymentMethodOptions::Billie::CompanyDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceUpdateParams::PaymentSettings::PaymentMethodOptions::Billie::CompanyDetails
- Defined in:
- lib/stripe/params/invoice_update_params.rb
Defined Under Namespace
Classes: RegisteredAddress
Instance Attribute Summary collapse
-
#registered_address ⇒ Object
The address the company or entity is registered with.
-
#registered_name ⇒ Object
Company or entity name.
-
#registration_number ⇒ Object
The official registration number for the given registration type.
-
#registration_type ⇒ Object
Type of registration the company or entity holds in their registered country.
-
#vat ⇒ Object
VAT ID number.
Instance Method Summary collapse
-
#initialize(registered_address: nil, registered_name: nil, registration_number: nil, registration_type: nil, vat: nil) ⇒ CompanyDetails
constructor
A new instance of CompanyDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(registered_address: nil, registered_name: nil, registration_number: nil, registration_type: nil, vat: nil) ⇒ CompanyDetails
Returns a new instance of CompanyDetails.
142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/stripe/params/invoice_update_params.rb', line 142 def initialize( registered_address: nil, registered_name: nil, registration_number: nil, registration_type: nil, vat: nil ) @registered_address = registered_address @registered_name = registered_name @registration_number = registration_number @registration_type = registration_type @vat = vat end |
Instance Attribute Details
#registered_address ⇒ Object
The address the company or entity is registered with.
132 133 134 |
# File 'lib/stripe/params/invoice_update_params.rb', line 132 def registered_address @registered_address end |
#registered_name ⇒ Object
Company or entity name.
134 135 136 |
# File 'lib/stripe/params/invoice_update_params.rb', line 134 def registered_name @registered_name end |
#registration_number ⇒ Object
The official registration number for the given registration type.
136 137 138 |
# File 'lib/stripe/params/invoice_update_params.rb', line 136 def registration_number @registration_number end |
#registration_type ⇒ Object
Type of registration the company or entity holds in their registered country.
138 139 140 |
# File 'lib/stripe/params/invoice_update_params.rb', line 138 def registration_type @registration_type end |
#vat ⇒ Object
VAT ID number.
140 141 142 |
# File 'lib/stripe/params/invoice_update_params.rb', line 140 def vat @vat end |