Class: Stripe::InvoiceUpdateParams::PaymentSettings::PaymentMethodOptions::Card::Installments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_update_params.rb

Defined Under Namespace

Classes: Plan

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(enabled: nil, plan: nil) ⇒ Installments

Returns a new instance of Installments.



171
172
173
174
# File 'lib/stripe/params/invoice_update_params.rb', line 171

def initialize(enabled: nil, plan: nil)
  @enabled = enabled
  @plan = plan
end

Instance Attribute Details

#enabledObject

Setting to true enables installments for this invoice. Setting to false will prevent any selected plan from applying to a payment.



167
168
169
# File 'lib/stripe/params/invoice_update_params.rb', line 167

def enabled
  @enabled
end

#planObject

The selected installment plan to use for this invoice.



169
170
171
# File 'lib/stripe/params/invoice_update_params.rb', line 169

def plan
  @plan
end