Class: Stripe::InvoiceUpdateParams::PaymentSettings::PaymentMethodOptions::Card::Installments::Plan

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h

Constructor Details

#initialize(count: nil, interval: nil, type: nil) ⇒ Plan

Returns a new instance of Plan.



112
113
114
115
116
# File 'lib/stripe/params/invoice_update_params.rb', line 112

def initialize(count: nil, interval: nil, type: nil)
  @count = count
  @interval = interval
  @type = type
end

Instance Attribute Details

#countObject

For fixed_count installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.



105
106
107
# File 'lib/stripe/params/invoice_update_params.rb', line 105

def count
  @count
end

#intervalObject

For fixed_count installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of month.



108
109
110
# File 'lib/stripe/params/invoice_update_params.rb', line 108

def interval
  @interval
end

#typeObject

Type of installment plan, one of fixed_count, bonus, or revolving.



110
111
112
# File 'lib/stripe/params/invoice_update_params.rb', line 110

def type
  @type
end