Class: Stripe::InvoiceUpdateParams::PaymentSettings::PaymentMethodOptions::Payto::MandateOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceUpdateParams::PaymentSettings::PaymentMethodOptions::Payto::MandateOptions
- Defined in:
- lib/stripe/params/invoice_update_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The maximum amount that can be collected in a single invoice.
-
#purpose ⇒ Object
The purpose for which payments are made.
Instance Method Summary collapse
-
#initialize(amount: nil, purpose: nil) ⇒ MandateOptions
constructor
A new instance of MandateOptions.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, purpose: nil) ⇒ MandateOptions
Returns a new instance of MandateOptions.
229 230 231 232 |
# File 'lib/stripe/params/invoice_update_params.rb', line 229 def initialize(amount: nil, purpose: nil) @amount = amount @purpose = purpose end |
Instance Attribute Details
#amount ⇒ Object
The maximum amount that can be collected in a single invoice. If you don’t specify a maximum, then there is no limit.
225 226 227 |
# File 'lib/stripe/params/invoice_update_params.rb', line 225 def amount @amount end |
#purpose ⇒ Object
The purpose for which payments are made. Has a default value based on your merchant category code.
227 228 229 |
# File 'lib/stripe/params/invoice_update_params.rb', line 227 def purpose @purpose end |