Class: Stripe::InvoiceUpdateParams::PaymentSettings::PaymentMethodOptions::Upi::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



270
271
272
273
274
275
# File 'lib/stripe/params/invoice_update_params.rb', line 270

def initialize(amount: nil, amount_type: nil, description: nil, end_date: nil)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



262
263
264
# File 'lib/stripe/params/invoice_update_params.rb', line 262

def amount
  @amount
end

#amount_typeObject

One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.



264
265
266
# File 'lib/stripe/params/invoice_update_params.rb', line 264

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



266
267
268
# File 'lib/stripe/params/invoice_update_params.rb', line 266

def description
  @description
end

#end_dateObject

End date of the mandate or subscription.



268
269
270
# File 'lib/stripe/params/invoice_update_params.rb', line 268

def end_date
  @end_date
end