Class: Stripe::InvoiceUpdateParams::ShippingCost::ShippingRateData::FixedAmount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceUpdateParams::ShippingCost::ShippingRateData::FixedAmount
- Defined in:
- lib/stripe/params/invoice_update_params.rb
Defined Under Namespace
Classes: CurrencyOptions
Instance Attribute Summary collapse
-
#amount ⇒ Object
A non-negative integer in cents representing how much to charge.
-
#currency ⇒ Object
Three-letter ISO currency code, in lowercase.
-
#currency_options ⇒ Object
Shipping rates defined in each available currency option.
Instance Method Summary collapse
-
#initialize(amount: nil, currency: nil, currency_options: nil) ⇒ FixedAmount
constructor
A new instance of FixedAmount.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, currency: nil, currency_options: nil) ⇒ FixedAmount
Returns a new instance of FixedAmount.
474 475 476 477 478 |
# File 'lib/stripe/params/invoice_update_params.rb', line 474 def initialize(amount: nil, currency: nil, currency_options: nil) @amount = amount @currency = currency @currency_options = end |
Instance Attribute Details
#amount ⇒ Object
A non-negative integer in cents representing how much to charge.
468 469 470 |
# File 'lib/stripe/params/invoice_update_params.rb', line 468 def amount @amount end |
#currency ⇒ Object
Three-letter ISO currency code, in lowercase. Must be a supported currency.
470 471 472 |
# File 'lib/stripe/params/invoice_update_params.rb', line 470 def currency @currency end |
#currency_options ⇒ Object
Shipping rates defined in each available currency option. Each key must be a three-letter ISO currency code and a supported currency.
472 473 474 |
# File 'lib/stripe/params/invoice_update_params.rb', line 472 def @currency_options end |