Class: Stripe::Issuing::Authorization::ApproveParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/issuing/authorization.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, expand: nil, metadata: nil) ⇒ ApproveParams

Returns a new instance of ApproveParams.



461
462
463
464
465
# File 'lib/stripe/resources/issuing/authorization.rb', line 461

def initialize(amount: nil, expand: nil, metadata: nil)
  @amount = amount
  @expand = expand
  @metadata = 
end

Instance Attribute Details

#amountObject

If the authorization’s ‘pending_request.is_amount_controllable` property is `true`, you may provide this value to control how much to hold for the authorization. Must be positive (use [`decline`](stripe.com/docs/api/issuing/authorizations/decline) to decline an authorization request).



455
456
457
# File 'lib/stripe/resources/issuing/authorization.rb', line 455

def amount
  @amount
end

#expandObject

Specifies which fields in the response should be expanded.



457
458
459
# File 'lib/stripe/resources/issuing/authorization.rb', line 457

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



459
460
461
# File 'lib/stripe/resources/issuing/authorization.rb', line 459

def 
  @metadata
end