Class: Stripe::Issuing::Authorization::BalanceResponse
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Issuing::Authorization::BalanceResponse
- Defined in:
- lib/stripe/resources/issuing/authorization.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_type ⇒ Object
readonly
The cardholder account type affected by this authorization.
-
#available_balance ⇒ Object
readonly
The available balance or credit limit in the cardholder's account after the authorization, in the smallest currency unit.
-
#currency ⇒ Object
readonly
The currency of the remaining balances in the cardholder's account after the authorization.
-
#current_balance ⇒ Object
readonly
The current ledger balance or remaining credit amount in the cardholder's account after the authorization, in the smallest currency unit.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_type ⇒ Object (readonly)
The cardholder account type affected by this authorization.
38 39 40 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 38 def account_type @account_type end |
#available_balance ⇒ Object (readonly)
The available balance or credit limit in the cardholder's account after the authorization, in the smallest currency unit.
40 41 42 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 40 def available_balance @available_balance end |
#currency ⇒ Object (readonly)
The currency of the remaining balances in the cardholder's account after the authorization.
42 43 44 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 42 def currency @currency end |
#current_balance ⇒ Object (readonly)
The current ledger balance or remaining credit amount in the cardholder's account after the authorization, in the smallest currency unit.
44 45 46 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 44 def current_balance @current_balance end |
Class Method Details
.field_remappings ⇒ Object
50 51 52 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 50 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
46 47 48 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 46 def self.inner_class_types @inner_class_types = {} end |