Class: Stripe::Issuing::Authorization::CaptureParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::Authorization::CaptureParams
- Defined in:
- lib/stripe/resources/issuing/authorization.rb
Defined Under Namespace
Classes: PurchaseDetails
Instance Attribute Summary collapse
-
#capture_amount ⇒ Object
The amount to capture from the authorization.
-
#close_authorization ⇒ Object
Whether to close the authorization after capture.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#purchase_details ⇒ Object
Additional purchase information that is optionally provided by the merchant.
Instance Method Summary collapse
-
#initialize(capture_amount: nil, close_authorization: nil, expand: nil, purchase_details: nil) ⇒ CaptureParams
constructor
A new instance of CaptureParams.
Methods inherited from RequestParams
Constructor Details
#initialize(capture_amount: nil, close_authorization: nil, expand: nil, purchase_details: nil) ⇒ CaptureParams
Returns a new instance of CaptureParams.
1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1027 def initialize( capture_amount: nil, close_authorization: nil, expand: nil, purchase_details: nil ) @capture_amount = capture_amount @close_authorization = @expand = @purchase_details = purchase_details end |
Instance Attribute Details
#capture_amount ⇒ Object
The amount to capture from the authorization. If not provided, the full amount of the authorization will be captured. This amount is in the authorization currency and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).
1019 1020 1021 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1019 def capture_amount @capture_amount end |
#close_authorization ⇒ Object
Whether to close the authorization after capture. Defaults to true. Set to false to enable multi-capture flows.
1021 1022 1023 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1021 def @close_authorization end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1023 1024 1025 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1023 def @expand end |
#purchase_details ⇒ Object
Additional purchase information that is optionally provided by the merchant.
1025 1026 1027 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1025 def purchase_details @purchase_details end |