Class: Stripe::Issuing::Authorization::CaptureParams::PurchaseDetails::Fleet::ReportedBreakdown::Tax
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::Authorization::CaptureParams::PurchaseDetails::Fleet::ReportedBreakdown::Tax
- Defined in:
- lib/stripe/resources/issuing/authorization.rb
Instance Attribute Summary collapse
-
#local_amount_decimal ⇒ Object
Amount of state or provincial Sales Tax included in the transaction amount.
-
#national_amount_decimal ⇒ Object
Amount of national Sales Tax or VAT included in the transaction amount.
Instance Method Summary collapse
-
#initialize(local_amount_decimal: nil, national_amount_decimal: nil) ⇒ Tax
constructor
A new instance of Tax.
Methods inherited from RequestParams
Constructor Details
#initialize(local_amount_decimal: nil, national_amount_decimal: nil) ⇒ Tax
Returns a new instance of Tax.
836 837 838 839 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 836 def initialize(local_amount_decimal: nil, national_amount_decimal: nil) @local_amount_decimal = local_amount_decimal @national_amount_decimal = national_amount_decimal end |
Instance Attribute Details
#local_amount_decimal ⇒ Object
Amount of state or provincial Sales Tax included in the transaction amount. Null if not reported by merchant or not subject to tax.
832 833 834 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 832 def local_amount_decimal @local_amount_decimal end |
#national_amount_decimal ⇒ Object
Amount of national Sales Tax or VAT included in the transaction amount. Null if not reported by merchant or not subject to tax.
834 835 836 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 834 def national_amount_decimal @national_amount_decimal end |