Class: Stripe::Issuing::Authorization::CaptureParams::PurchaseDetails::Fuel

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/issuing/authorization.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(industry_product_code: nil, quantity_decimal: nil, type: nil, unit: nil, unit_cost_decimal: nil) ⇒ Fuel

Returns a new instance of Fuel.



945
946
947
948
949
950
951
952
953
954
955
956
957
# File 'lib/stripe/resources/issuing/authorization.rb', line 945

def initialize(
  industry_product_code: nil,
  quantity_decimal: nil,
  type: nil,
  unit: nil,
  unit_cost_decimal: nil
)
  @industry_product_code = industry_product_code
  @quantity_decimal = quantity_decimal
  @type = type
  @unit = unit
  @unit_cost_decimal = unit_cost_decimal
end

Instance Attribute Details

#industry_product_codeObject

[Conexxus Payment System Product Code](www.conexxus.org/conexxus-payment-system-product-codes) identifying the primary fuel product purchased.



935
936
937
# File 'lib/stripe/resources/issuing/authorization.rb', line 935

def industry_product_code
  @industry_product_code
end

#quantity_decimalObject

The quantity of ‘unit`s of fuel that was dispensed, represented as a decimal string with at most 12 decimal places.



937
938
939
# File 'lib/stripe/resources/issuing/authorization.rb', line 937

def quantity_decimal
  @quantity_decimal
end

#typeObject

The type of fuel that was purchased. One of ‘diesel`, `unleaded_plus`, `unleaded_regular`, `unleaded_super`, or `other`.



939
940
941
# File 'lib/stripe/resources/issuing/authorization.rb', line 939

def type
  @type
end

#unitObject

The units for ‘quantity_decimal`. One of `charging_minute`, `imperial_gallon`, `kilogram`, `kilowatt_hour`, `liter`, `pound`, `us_gallon`, or `other`.



941
942
943
# File 'lib/stripe/resources/issuing/authorization.rb', line 941

def unit
  @unit
end

#unit_cost_decimalObject

The cost in cents per each unit of fuel, represented as a decimal string with at most 12 decimal places.



943
944
945
# File 'lib/stripe/resources/issuing/authorization.rb', line 943

def unit_cost_decimal
  @unit_cost_decimal
end