Class: Stripe::Issuing::Authorization::CreateParams::MerchantData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::Authorization::CreateParams::MerchantData
- Defined in:
- lib/stripe/resources/issuing/authorization.rb
Instance Attribute Summary collapse
-
#category ⇒ Object
A categorization of the seller’s type of business.
-
#city ⇒ Object
City where the seller is located.
-
#country ⇒ Object
Country where the seller is located.
-
#name ⇒ Object
Name of the seller.
-
#network_id ⇒ Object
Identifier assigned to the seller by the card network.
-
#postal_code ⇒ Object
Postal code where the seller is located.
-
#state ⇒ Object
State where the seller is located.
-
#terminal_id ⇒ Object
An ID assigned by the seller to the location of the sale.
-
#url ⇒ Object
URL provided by the merchant on a 3DS request.
Instance Method Summary collapse
-
#initialize(category: nil, city: nil, country: nil, name: nil, network_id: nil, postal_code: nil, state: nil, terminal_id: nil, url: nil) ⇒ MerchantData
constructor
A new instance of MerchantData.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, city: nil, country: nil, name: nil, network_id: nil, postal_code: nil, state: nil, terminal_id: nil, url: nil) ⇒ MerchantData
Returns a new instance of MerchantData.
633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 633 def initialize( category: nil, city: nil, country: nil, name: nil, network_id: nil, postal_code: nil, state: nil, terminal_id: nil, url: nil ) @category = category @city = city @country = country @name = name @network_id = network_id @postal_code = postal_code @state = state @terminal_id = terminal_id @url = url end |
Instance Attribute Details
#category ⇒ Object
A categorization of the seller’s type of business. See our [merchant categories guide](stripe.com/docs/issuing/merchant-categories) for a list of possible values.
615 616 617 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 615 def category @category end |
#city ⇒ Object
City where the seller is located
617 618 619 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 617 def city @city end |
#country ⇒ Object
Country where the seller is located
619 620 621 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 619 def country @country end |
#name ⇒ Object
Name of the seller
621 622 623 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 621 def name @name end |
#network_id ⇒ Object
Identifier assigned to the seller by the card network. Different card networks may assign different network_id fields to the same merchant.
623 624 625 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 623 def network_id @network_id end |
#postal_code ⇒ Object
Postal code where the seller is located
625 626 627 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 625 def postal_code @postal_code end |
#state ⇒ Object
State where the seller is located
627 628 629 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 627 def state @state end |
#terminal_id ⇒ Object
An ID assigned by the seller to the location of the sale.
629 630 631 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 629 def terminal_id @terminal_id end |
#url ⇒ Object
URL provided by the merchant on a 3DS request
631 632 633 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 631 def url @url end |