Class: Stripe::Issuing::Authorization::CreateParams::VerificationData::AuthenticationExemption
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::Authorization::CreateParams::VerificationData::AuthenticationExemption
- Defined in:
- lib/stripe/resources/issuing/authorization.rb
Instance Attribute Summary collapse
-
#claimed_by ⇒ Object
The entity that requested the exemption, either the acquiring merchant or the Issuing user.
-
#type ⇒ Object
The specific exemption claimed for this authorization.
Instance Method Summary collapse
-
#initialize(claimed_by: nil, type: nil) ⇒ AuthenticationExemption
constructor
A new instance of AuthenticationExemption.
Methods inherited from RequestParams
Constructor Details
#initialize(claimed_by: nil, type: nil) ⇒ AuthenticationExemption
Returns a new instance of AuthenticationExemption.
514 515 516 517 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 514 def initialize(claimed_by: nil, type: nil) @claimed_by = claimed_by @type = type end |
Instance Attribute Details
#claimed_by ⇒ Object
The entity that requested the exemption, either the acquiring merchant or the Issuing user.
510 511 512 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 510 def claimed_by @claimed_by end |
#type ⇒ Object
The specific exemption claimed for this authorization.
512 513 514 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 512 def type @type end |