Class: Stripe::Issuing::Authorization::CryptoTransaction::CryptoTransactionFailed
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Issuing::Authorization::CryptoTransaction::CryptoTransactionFailed
- Defined in:
- lib/stripe/resources/issuing/authorization.rb
Defined Under Namespace
Classes: Fee
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The crypto amount for the failed transaction.
-
#amount_mcc_upcharged ⇒ Object
readonly
The upcharged MCC amount, if one was applied.
-
#chain ⇒ Object
readonly
The blockchain network for the failed transaction.
-
#currency ⇒ Object
readonly
The currency of the crypto transaction amount.
-
#failed_at ⇒ Object
readonly
When the transaction failed.
-
#failure_reason ⇒ Object
readonly
The reason the transaction failed.
-
#fees ⇒ Object
readonly
Fees associated with the transaction.
-
#from_address ⇒ Object
readonly
The source wallet address for the attempted transaction.
-
#memo ⇒ Object
readonly
Memo metadata attached to the transaction, if present.
-
#to_address ⇒ Object
readonly
The destination wallet address for the attempted transaction when one exists.
-
#transaction_hash ⇒ Object
readonly
The blockchain transaction hash when one exists.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The crypto amount for the failed transaction.
119 120 121 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 119 def amount @amount end |
#amount_mcc_upcharged ⇒ Object (readonly)
The upcharged MCC amount, if one was applied.
121 122 123 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 121 def amount_mcc_upcharged @amount_mcc_upcharged end |
#chain ⇒ Object (readonly)
The blockchain network for the failed transaction.
123 124 125 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 123 def chain @chain end |
#currency ⇒ Object (readonly)
The currency of the crypto transaction amount.
125 126 127 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 125 def currency @currency end |
#failed_at ⇒ Object (readonly)
When the transaction failed.
127 128 129 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 127 def failed_at @failed_at end |
#failure_reason ⇒ Object (readonly)
The reason the transaction failed.
129 130 131 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 129 def failure_reason @failure_reason end |
#fees ⇒ Object (readonly)
Fees associated with the transaction.
131 132 133 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 131 def fees @fees end |
#from_address ⇒ Object (readonly)
The source wallet address for the attempted transaction.
133 134 135 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 133 def from_address @from_address end |
#memo ⇒ Object (readonly)
Memo metadata attached to the transaction, if present.
135 136 137 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 135 def memo @memo end |
#to_address ⇒ Object (readonly)
The destination wallet address for the attempted transaction when one exists.
137 138 139 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 137 def to_address @to_address end |
#transaction_hash ⇒ Object (readonly)
The blockchain transaction hash when one exists.
139 140 141 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 139 def transaction_hash @transaction_hash end |
Class Method Details
.field_remappings ⇒ Object
145 146 147 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 145 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
141 142 143 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 141 def self.inner_class_types @inner_class_types = { fees: Fee } end |