Class: Stripe::Issuing::Authorization::EnrichedMerchantData
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Issuing::Authorization::EnrichedMerchantData
- Defined in:
- lib/stripe/resources/issuing/authorization.rb
Defined Under Namespace
Classes: Merchant, ThirdParty
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#merchant ⇒ Object
readonly
Additional details about the seller (grocery store, e-commerce website, and so on) where the card authorization happened.
-
#third_parties ⇒ Object
readonly
An array of third parties involved in the card authorization, when applicable.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#merchant ⇒ Object (readonly)
Additional details about the seller (grocery store, e-commerce website, and so on) where the card authorization happened.
312 313 314 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 312 def merchant @merchant end |
#third_parties ⇒ Object (readonly)
An array of third parties involved in the card authorization, when applicable.
314 315 316 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 314 def third_parties @third_parties end |
Class Method Details
.field_remappings ⇒ Object
320 321 322 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 320 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
316 317 318 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 316 def self.inner_class_types @inner_class_types = { merchant: Merchant, third_parties: ThirdParty } end |