Class: Stripe::Issuing::Authorization::EnrichedMerchantData::Merchant
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Issuing::Authorization::EnrichedMerchantData::Merchant
- Defined in:
- lib/stripe/resources/issuing/authorization.rb
Defined Under Namespace
Classes: Industry, Location, Spade
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#data_sources ⇒ Object
readonly
Attribute for field data_sources.
-
#industry ⇒ Object
readonly
Attribute for field industry.
-
#location ⇒ Object
readonly
Location data of the seller.
-
#logo ⇒ Object
readonly
Image link to the seller's logo.
-
#name ⇒ Object
readonly
The name of the seller.
-
#phone ⇒ Object
readonly
Phone number of the seller.
-
#spade ⇒ Object
readonly
If
spadeis a data source, this hash contains details provided by Spade. -
#url ⇒ Object
readonly
URL of the seller's website.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#data_sources ⇒ Object (readonly)
Attribute for field data_sources
254 255 256 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 254 def data_sources @data_sources end |
#industry ⇒ Object (readonly)
Attribute for field industry
256 257 258 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 256 def industry @industry end |
#location ⇒ Object (readonly)
Location data of the seller.
258 259 260 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 258 def location @location end |
#logo ⇒ Object (readonly)
Image link to the seller's logo.
260 261 262 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 260 def logo @logo end |
#name ⇒ Object (readonly)
The name of the seller.
262 263 264 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 262 def name @name end |
#phone ⇒ Object (readonly)
Phone number of the seller.
264 265 266 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 264 def phone @phone end |
#spade ⇒ Object (readonly)
If spade is a data source, this hash contains details provided by Spade.
266 267 268 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 266 def spade @spade end |
#url ⇒ Object (readonly)
URL of the seller's website.
268 269 270 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 268 def url @url end |
Class Method Details
.field_remappings ⇒ Object
274 275 276 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 274 def self.field_remappings @field_remappings = {} end |