Class: Stripe::Issuing::Authorization::ExpireParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::Authorization::ExpireParams
- Defined in:
- lib/stripe/resources/issuing/authorization.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ ExpireParams
constructor
A new instance of ExpireParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ ExpireParams
Returns a new instance of ExpireParams.
886 887 888 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 886 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
884 885 886 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 884 def @expand end |