Class: Stripe::Issuing::Authorization::FinalizeAmountParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::Authorization::FinalizeAmountParams
- Defined in:
- lib/stripe/resources/issuing/authorization.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#final_amount ⇒ Object
The final authorization amount that will be captured by the merchant.
-
#fleet ⇒ Object
Fleet-specific information for authorizations using Fleet cards.
-
#fuel ⇒ Object
Information about fuel that was purchased with this transaction.
Instance Method Summary collapse
-
#initialize(expand: nil, final_amount: nil, fleet: nil, fuel: nil) ⇒ FinalizeAmountParams
constructor
A new instance of FinalizeAmountParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, final_amount: nil, fleet: nil, fuel: nil) ⇒ FinalizeAmountParams
Returns a new instance of FinalizeAmountParams.
1178 1179 1180 1181 1182 1183 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1178 def initialize(expand: nil, final_amount: nil, fleet: nil, fuel: nil) @expand = @final_amount = final_amount @fleet = fleet @fuel = fuel end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1170 1171 1172 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1170 def @expand end |
#final_amount ⇒ Object
The final authorization amount that will be captured by the merchant. This amount is in the authorization currency and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).
1172 1173 1174 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1172 def final_amount @final_amount end |
#fleet ⇒ Object
Fleet-specific information for authorizations using Fleet cards.
1174 1175 1176 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1174 def fleet @fleet end |
#fuel ⇒ Object
Information about fuel that was purchased with this transaction.
1176 1177 1178 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1176 def fuel @fuel end |