Class: Stripe::Issuing::Authorization::FinalizeAmountParams::Fleet::ReportedBreakdown::Tax

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/issuing/authorization.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(local_amount_decimal: nil, national_amount_decimal: nil) ⇒ Tax

Returns a new instance of Tax.



1103
1104
1105
1106
# File 'lib/stripe/resources/issuing/authorization.rb', line 1103

def initialize(local_amount_decimal: nil, national_amount_decimal: nil)
  @local_amount_decimal = local_amount_decimal
  @national_amount_decimal = national_amount_decimal
end

Instance Attribute Details

#local_amount_decimalObject

Amount of state or provincial Sales Tax included in the transaction amount. Null if not reported by merchant or not subject to tax.



1099
1100
1101
# File 'lib/stripe/resources/issuing/authorization.rb', line 1099

def local_amount_decimal
  @local_amount_decimal
end

#national_amount_decimalObject

Amount of national Sales Tax or VAT included in the transaction amount. Null if not reported by merchant or not subject to tax.



1101
1102
1103
# File 'lib/stripe/resources/issuing/authorization.rb', line 1101

def national_amount_decimal
  @national_amount_decimal
end