Class: Stripe::Issuing::Authorization::FinalizeAmountParams::Fuel
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::Authorization::FinalizeAmountParams::Fuel
- Defined in:
- lib/stripe/resources/issuing/authorization.rb
Instance Attribute Summary collapse
-
#industry_product_code ⇒ Object
[Conexxus Payment System Product Code](www.conexxus.org/conexxus-payment-system-product-codes) identifying the primary fuel product purchased.
-
#quantity_decimal ⇒ Object
The quantity of ‘unit`s of fuel that was dispensed, represented as a decimal string with at most 12 decimal places.
-
#type ⇒ Object
The type of fuel that was purchased.
-
#unit ⇒ Object
The units for ‘quantity_decimal`.
-
#unit_cost_decimal ⇒ Object
The cost in cents per each unit of fuel, represented as a decimal string with at most 12 decimal places.
Instance Method Summary collapse
-
#initialize(industry_product_code: nil, quantity_decimal: nil, type: nil, unit: nil, unit_cost_decimal: nil) ⇒ Fuel
constructor
A new instance of Fuel.
Methods inherited from RequestParams
Constructor Details
#initialize(industry_product_code: nil, quantity_decimal: nil, type: nil, unit: nil, unit_cost_decimal: nil) ⇒ Fuel
Returns a new instance of Fuel.
1155 1156 1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 1167 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1155 def initialize( industry_product_code: nil, quantity_decimal: nil, type: nil, unit: nil, unit_cost_decimal: nil ) @industry_product_code = industry_product_code @quantity_decimal = quantity_decimal @type = type @unit = unit @unit_cost_decimal = unit_cost_decimal end |
Instance Attribute Details
#industry_product_code ⇒ Object
[Conexxus Payment System Product Code](www.conexxus.org/conexxus-payment-system-product-codes) identifying the primary fuel product purchased.
1145 1146 1147 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1145 def industry_product_code @industry_product_code end |
#quantity_decimal ⇒ Object
The quantity of ‘unit`s of fuel that was dispensed, represented as a decimal string with at most 12 decimal places.
1147 1148 1149 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1147 def quantity_decimal @quantity_decimal end |
#type ⇒ Object
The type of fuel that was purchased. One of ‘diesel`, `unleaded_plus`, `unleaded_regular`, `unleaded_super`, or `other`.
1149 1150 1151 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1149 def type @type end |
#unit ⇒ Object
The units for ‘quantity_decimal`. One of `charging_minute`, `imperial_gallon`, `kilogram`, `kilowatt_hour`, `liter`, `pound`, `us_gallon`, or `other`.
1151 1152 1153 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1151 def unit @unit end |
#unit_cost_decimal ⇒ Object
The cost in cents per each unit of fuel, represented as a decimal string with at most 12 decimal places.
1153 1154 1155 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1153 def unit_cost_decimal @unit_cost_decimal end |