Class: Stripe::Issuing::Authorization::Fleet

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/issuing/authorization.rb

Defined Under Namespace

Classes: CardholderPromptData, ReportedBreakdown

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#cardholder_prompt_dataObject (readonly)

Answers to prompts presented to the cardholder at the point of sale. Prompted fields vary depending on the configuration of your physical fleet cards. Typical points of sale support only numeric entry.



161
162
163
# File 'lib/stripe/resources/issuing/authorization.rb', line 161

def cardholder_prompt_data
  @cardholder_prompt_data
end

#purchase_typeObject (readonly)

The type of purchase.



163
164
165
# File 'lib/stripe/resources/issuing/authorization.rb', line 163

def purchase_type
  @purchase_type
end

#reported_breakdownObject (readonly)

More information about the total amount. Typically this information is received from the merchant after the authorization has been approved and the fuel dispensed. This information is not guaranteed to be accurate as some merchants may provide unreliable data.



165
166
167
# File 'lib/stripe/resources/issuing/authorization.rb', line 165

def reported_breakdown
  @reported_breakdown
end

#service_typeObject (readonly)

The type of fuel service.



167
168
169
# File 'lib/stripe/resources/issuing/authorization.rb', line 167

def service_type
  @service_type
end

Class Method Details

.field_encodingsObject



180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/stripe/resources/issuing/authorization.rb', line 180

def self.field_encodings
  @field_encodings = {
    reported_breakdown: {
      kind: :nullable,
      inner: {
        kind: :object,
        fields: {
          fuel: {
            kind: :nullable,
            inner: {
              kind: :object,
              fields: { gross_amount_decimal: { kind: :nullable, inner: :decimal_string } },
            },
          },
          non_fuel: {
            kind: :nullable,
            inner: {
              kind: :object,
              fields: { gross_amount_decimal: { kind: :nullable, inner: :decimal_string } },
            },
          },
          tax: {
            kind: :nullable,
            inner: {
              kind: :object,
              fields: {
                local_amount_decimal: { kind: :nullable, inner: :decimal_string },
                national_amount_decimal: { kind: :nullable, inner: :decimal_string },
              },
            },
          },
        },
      },
    },
  }
end

.field_remappingsObject



176
177
178
# File 'lib/stripe/resources/issuing/authorization.rb', line 176

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



169
170
171
172
173
174
# File 'lib/stripe/resources/issuing/authorization.rb', line 169

def self.inner_class_types
  @inner_class_types = {
    cardholder_prompt_data: CardholderPromptData,
    reported_breakdown: ReportedBreakdown,
  }
end