Class: Stripe::Issuing::Authorization::Fleet::CardholderPromptData

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/issuing/authorization.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#alphanumeric_idObject (readonly)

Deprecated

An alphanumeric ID, though typical point of sales only support numeric entry. The card program can be configured to prompt for a vehicle ID, driver ID, or generic ID.



31
32
33
# File 'lib/stripe/resources/issuing/authorization.rb', line 31

def alphanumeric_id
  @alphanumeric_id
end

#driver_idObject (readonly)

Driver ID.



33
34
35
# File 'lib/stripe/resources/issuing/authorization.rb', line 33

def driver_id
  @driver_id
end

#odometerObject (readonly)

Odometer reading.



35
36
37
# File 'lib/stripe/resources/issuing/authorization.rb', line 35

def odometer
  @odometer
end

#unspecified_idObject (readonly)

An alphanumeric ID. This field is used when a vehicle ID, driver ID, or generic ID is entered by the cardholder, but the merchant or card network did not specify the prompt type.



37
38
39
# File 'lib/stripe/resources/issuing/authorization.rb', line 37

def unspecified_id
  @unspecified_id
end

#user_idObject (readonly)

User ID.



39
40
41
# File 'lib/stripe/resources/issuing/authorization.rb', line 39

def user_id
  @user_id
end

#vehicle_numberObject (readonly)

Vehicle number.



41
42
43
# File 'lib/stripe/resources/issuing/authorization.rb', line 41

def vehicle_number
  @vehicle_number
end