Class: Stripe::Issuing::Authorization::FraudChallenge

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/issuing/authorization.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#channelObject (readonly)

The method by which the fraud challenge was delivered to the cardholder.



92
93
94
# File 'lib/stripe/resources/issuing/authorization.rb', line 92

def channel
  @channel
end

#statusObject (readonly)

The status of the fraud challenge.



95
96
97
# File 'lib/stripe/resources/issuing/authorization.rb', line 95

def status
  @status
end

#undeliverable_reasonObject (readonly)

If the challenge is not deliverable, the reason why.



98
99
100
# File 'lib/stripe/resources/issuing/authorization.rb', line 98

def undeliverable_reason
  @undeliverable_reason
end