Class: Stripe::Issuing::Authorization::ListParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/issuing/authorization.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(card: nil, cardholder: nil, created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, status: nil) ⇒ ListParams

Returns a new instance of ListParams.



330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
# File 'lib/stripe/resources/issuing/authorization.rb', line 330

def initialize(
  card: nil,
  cardholder: nil,
  created: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  starting_after: nil,
  status: nil
)
  @card = card
  @cardholder = cardholder
  @created = created
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
  @status = status
end

Instance Attribute Details

#cardObject

Only return authorizations that belong to the given card.



307
308
309
# File 'lib/stripe/resources/issuing/authorization.rb', line 307

def card
  @card
end

#cardholderObject

Only return authorizations that belong to the given cardholder.



310
311
312
# File 'lib/stripe/resources/issuing/authorization.rb', line 310

def cardholder
  @cardholder
end

#createdObject

Only return authorizations that were created during the given date interval.



313
314
315
# File 'lib/stripe/resources/issuing/authorization.rb', line 313

def created
  @created
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



316
317
318
# File 'lib/stripe/resources/issuing/authorization.rb', line 316

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



319
320
321
# File 'lib/stripe/resources/issuing/authorization.rb', line 319

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



322
323
324
# File 'lib/stripe/resources/issuing/authorization.rb', line 322

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



325
326
327
# File 'lib/stripe/resources/issuing/authorization.rb', line 325

def starting_after
  @starting_after
end

#statusObject

Only return authorizations with the given status. One of ‘pending`, `closed`, or `reversed`.



328
329
330
# File 'lib/stripe/resources/issuing/authorization.rb', line 328

def status
  @status
end