Class: Stripe::Issuing::Authorization::MerchantData

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/issuing/authorization.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#categoryObject (readonly)

A categorization of the seller's type of business. See our merchant categories guide for a list of possible values.



265
266
267
# File 'lib/stripe/resources/issuing/authorization.rb', line 265

def category
  @category
end

#category_codeObject (readonly)

The merchant category code for the seller’s business



267
268
269
# File 'lib/stripe/resources/issuing/authorization.rb', line 267

def category_code
  @category_code
end

#cityObject (readonly)

City where the seller is located



269
270
271
# File 'lib/stripe/resources/issuing/authorization.rb', line 269

def city
  @city
end

#countryObject (readonly)

Country where the seller is located



271
272
273
# File 'lib/stripe/resources/issuing/authorization.rb', line 271

def country
  @country
end

#nameObject (readonly)

Name of the seller



273
274
275
# File 'lib/stripe/resources/issuing/authorization.rb', line 273

def name
  @name
end

#network_idObject (readonly)

Identifier assigned to the seller by the card network. Different card networks may assign different network_id fields to the same merchant.



275
276
277
# File 'lib/stripe/resources/issuing/authorization.rb', line 275

def network_id
  @network_id
end

#postal_codeObject (readonly)

Postal code where the seller is located



277
278
279
# File 'lib/stripe/resources/issuing/authorization.rb', line 277

def postal_code
  @postal_code
end

#stateObject (readonly)

State where the seller is located



279
280
281
# File 'lib/stripe/resources/issuing/authorization.rb', line 279

def state
  @state
end

#tax_idObject (readonly)

The seller's tax identification number. Currently populated for French merchants only.



281
282
283
# File 'lib/stripe/resources/issuing/authorization.rb', line 281

def tax_id
  @tax_id
end

#terminal_idObject (readonly)

An ID assigned by the seller to the location of the sale.



283
284
285
# File 'lib/stripe/resources/issuing/authorization.rb', line 283

def terminal_id
  @terminal_id
end

#urlObject (readonly)

URL provided by the merchant on a 3DS request



285
286
287
# File 'lib/stripe/resources/issuing/authorization.rb', line 285

def url
  @url
end

Class Method Details

.field_remappingsObject



291
292
293
# File 'lib/stripe/resources/issuing/authorization.rb', line 291

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



287
288
289
# File 'lib/stripe/resources/issuing/authorization.rb', line 287

def self.inner_class_types
  @inner_class_types = {}
end