Class: Stripe::Issuing::Authorization::NetworkData
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Issuing::Authorization::NetworkData
- Defined in:
- lib/stripe/resources/issuing/authorization.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#acquiring_institution_id ⇒ Object
readonly
Identifier assigned to the acquirer by the card network.
-
#system_trace_audit_number ⇒ Object
readonly
The System Trace Audit Number (STAN) is a 6-digit identifier assigned by the acquirer.
-
#transaction_id ⇒ Object
readonly
Unique identifier for the authorization assigned by the card network used to match subsequent messages, disputes, and transactions.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#acquiring_institution_id ⇒ Object (readonly)
Identifier assigned to the acquirer by the card network. Sometimes this value is not provided by the network; in this case, the value will be null.
298 299 300 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 298 def acquiring_institution_id @acquiring_institution_id end |
#system_trace_audit_number ⇒ Object (readonly)
The System Trace Audit Number (STAN) is a 6-digit identifier assigned by the acquirer. Prefer network_data.transaction_id if present, unless you have special requirements.
300 301 302 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 300 def system_trace_audit_number @system_trace_audit_number end |
#transaction_id ⇒ Object (readonly)
Unique identifier for the authorization assigned by the card network used to match subsequent messages, disputes, and transactions.
302 303 304 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 302 def transaction_id @transaction_id end |
Class Method Details
.field_remappings ⇒ Object
308 309 310 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 308 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
304 305 306 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 304 def self.inner_class_types @inner_class_types = {} end |