Class: Stripe::Issuing::Authorization::PendingRequest
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Issuing::Authorization::PendingRequest
- Defined in:
- lib/stripe/resources/issuing/authorization.rb
Defined Under Namespace
Classes: AmountDetails, HoldAmount, HoldAmountDetails
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The additional amount Stripe will hold if the authorization is approved, in the card's currency and in the smallest currency unit.
-
#amount_details ⇒ Object
readonly
Detailed breakdown of amount components.
-
#currency ⇒ Object
readonly
Three-letter ISO currency code, in lowercase.
-
#hold_amount ⇒ Object
readonly
The total amount to be held for this authorization request.
-
#hold_amount_details ⇒ Object
readonly
Breakdown of the amounts contributing to hold_amount.
-
#is_amount_controllable ⇒ Object
readonly
If set
true, you may provide amount to control how much to hold for the authorization. -
#merchant_amount ⇒ Object
readonly
The amount the merchant is requesting to be authorized in the
merchant_currency. -
#merchant_currency ⇒ Object
readonly
The local currency the merchant is requesting to authorize.
-
#network_risk_score ⇒ Object
readonly
The card network's estimate of the likelihood that an authorization is fraudulent.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The additional amount Stripe will hold if the authorization is approved, in the card's currency and in the smallest currency unit.
794 795 796 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 794 def amount @amount end |
#amount_details ⇒ Object (readonly)
Detailed breakdown of amount components. These amounts are denominated in currency and in the smallest currency unit.
796 797 798 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 796 def amount_details @amount_details end |
#currency ⇒ Object (readonly)
Three-letter ISO currency code, in lowercase. Must be a supported currency.
798 799 800 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 798 def currency @currency end |
#hold_amount ⇒ Object (readonly)
The total amount to be held for this authorization request.
800 801 802 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 800 def hold_amount @hold_amount end |
#hold_amount_details ⇒ Object (readonly)
Breakdown of the amounts contributing to hold_amount.
802 803 804 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 802 def hold_amount_details @hold_amount_details end |
#is_amount_controllable ⇒ Object (readonly)
If set true, you may provide amount to control how much to hold for the authorization.
804 805 806 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 804 def is_amount_controllable @is_amount_controllable end |
#merchant_amount ⇒ Object (readonly)
The amount the merchant is requesting to be authorized in the merchant_currency. The amount is in the smallest currency unit.
806 807 808 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 806 def merchant_amount @merchant_amount end |
#merchant_currency ⇒ Object (readonly)
The local currency the merchant is requesting to authorize.
808 809 810 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 808 def merchant_currency @merchant_currency end |
#network_risk_score ⇒ Object (readonly)
The card network's estimate of the likelihood that an authorization is fraudulent. Takes on values between 1 and 99.
810 811 812 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 810 def network_risk_score @network_risk_score end |
Class Method Details
.field_remappings ⇒ Object
820 821 822 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 820 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
812 813 814 815 816 817 818 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 812 def self.inner_class_types @inner_class_types = { amount_details: AmountDetails, hold_amount: HoldAmount, hold_amount_details: HoldAmountDetails, } end |