Class: Stripe::Issuing::Authorization::PendingRequest::HoldAmountDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Issuing::Authorization::PendingRequest::HoldAmountDetails
- Defined in:
- lib/stripe/resources/issuing/authorization.rb
Defined Under Namespace
Classes: EstimatedFee, EstimatedFeeDetail, Network, Reserve
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#estimated_fee ⇒ Object
readonly
Advisory estimate of total fees for this authorization request.
-
#estimated_fee_details ⇒ Object
readonly
Per-fee-type breakdown of the estimated fees for this authorization request.
-
#network ⇒ Object
readonly
Attribute for field network.
-
#reserve ⇒ Object
readonly
The reserve amount held for this authorization.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#estimated_fee ⇒ Object (readonly)
Advisory estimate of total fees for this authorization request.
772 773 774 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 772 def estimated_fee @estimated_fee end |
#estimated_fee_details ⇒ Object (readonly)
Per-fee-type breakdown of the estimated fees for this authorization request.
774 775 776 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 774 def estimated_fee_details @estimated_fee_details end |
#network ⇒ Object (readonly)
Attribute for field network
776 777 778 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 776 def network @network end |
#reserve ⇒ Object (readonly)
The reserve amount held for this authorization. Present for certain MCCs that may have overcaptures.
778 779 780 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 778 def reserve @reserve end |
Class Method Details
.field_remappings ⇒ Object
789 790 791 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 789 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
780 781 782 783 784 785 786 787 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 780 def self.inner_class_types @inner_class_types = { estimated_fee: EstimatedFee, estimated_fee_details: EstimatedFeeDetail, network: Network, reserve: Reserve, } end |