Class: Stripe::Issuing::Authorization::RequestHistory
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Issuing::Authorization::RequestHistory
- Defined in:
- lib/stripe/resources/issuing/authorization.rb
Defined Under Namespace
Classes: AmountDetails
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The
pending_request.amountat the time of the request, presented in your card's currency and in the smallest currency unit. -
#amount_details ⇒ Object
readonly
Detailed breakdown of amount components.
-
#approved ⇒ Object
readonly
Whether this request was approved.
-
#authorization_code ⇒ Object
readonly
A code created by Stripe which is shared with the merchant to validate the authorization.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#currency ⇒ Object
readonly
Three-letter ISO currency code, in lowercase.
-
#merchant_amount ⇒ Object
readonly
The
pending_request.merchant_amountat the time of the request, presented in themerchant_currencyand in the smallest currency unit. -
#merchant_currency ⇒ Object
readonly
The currency that was collected by the merchant and presented to the cardholder for the authorization.
-
#network_risk_score ⇒ Object
readonly
The card network's estimate of the likelihood that an authorization is fraudulent.
-
#reason ⇒ Object
readonly
When an authorization is approved or declined by you or by Stripe, this field provides additional detail on the reason for the outcome.
-
#reason_message ⇒ Object
readonly
If the
request_history.reasoniswebhook_errorbecause the direct webhook response is invalid (for example, parsing errors or missing parameters), we surface a more detailed error message via this field. -
#requested_at ⇒ Object
readonly
Time when the card network received an authorization request from the acquirer in UTC.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The pending_request.amount at the time of the request, presented in your card's currency and in the smallest currency unit. Stripe held this amount from your account to fund the authorization if the request was approved.
368 369 370 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 368 def amount @amount end |
#amount_details ⇒ Object (readonly)
Detailed breakdown of amount components. These amounts are denominated in currency and in the smallest currency unit.
370 371 372 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 370 def amount_details @amount_details end |
#approved ⇒ Object (readonly)
Whether this request was approved.
372 373 374 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 372 def approved @approved end |
#authorization_code ⇒ Object (readonly)
A code created by Stripe which is shared with the merchant to validate the authorization. This field will be populated if the authorization message was approved. The code typically starts with the letter "S", followed by a six-digit number. For example, "S498162". Please note that the code is not guaranteed to be unique across authorizations.
374 375 376 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 374 def @authorization_code end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
376 377 378 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 376 def created @created end |
#currency ⇒ Object (readonly)
Three-letter ISO currency code, in lowercase. Must be a supported currency.
378 379 380 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 378 def currency @currency end |
#merchant_amount ⇒ Object (readonly)
The pending_request.merchant_amount at the time of the request, presented in the merchant_currency and in the smallest currency unit.
380 381 382 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 380 def merchant_amount @merchant_amount end |
#merchant_currency ⇒ Object (readonly)
The currency that was collected by the merchant and presented to the cardholder for the authorization. Three-letter ISO currency code, in lowercase. Must be a supported currency.
382 383 384 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 382 def merchant_currency @merchant_currency end |
#network_risk_score ⇒ Object (readonly)
The card network's estimate of the likelihood that an authorization is fraudulent. Takes on values between 1 and 99.
384 385 386 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 384 def network_risk_score @network_risk_score end |
#reason ⇒ Object (readonly)
When an authorization is approved or declined by you or by Stripe, this field provides additional detail on the reason for the outcome.
386 387 388 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 386 def reason @reason end |
#reason_message ⇒ Object (readonly)
If the request_history.reason is webhook_error because the direct webhook response is invalid (for example, parsing errors or missing parameters), we surface a more detailed error message via this field.
388 389 390 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 388 def @reason_message end |
#requested_at ⇒ Object (readonly)
Time when the card network received an authorization request from the acquirer in UTC. Referred to by networks as transmission time.
390 391 392 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 390 def requested_at @requested_at end |
Class Method Details
.field_remappings ⇒ Object
396 397 398 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 396 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
392 393 394 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 392 def self.inner_class_types @inner_class_types = { amount_details: AmountDetails } end |