Class: Stripe::Issuing::Authorization::RequestHistory::NetworkData::TraceId
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Issuing::Authorization::RequestHistory::NetworkData::TraceId
- Defined in:
- lib/stripe/resources/issuing/authorization.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#banknet_reference_number ⇒ Object
readonly
The unique reference number within the specified financial network on the specified network date.
-
#financial_network_code ⇒ Object
readonly
The identifier of the program or service.
-
#network_date ⇒ Object
readonly
The card network's record date for this authorization.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#banknet_reference_number ⇒ Object (readonly)
The unique reference number within the specified financial network on the specified network date.
798 799 800 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 798 def banknet_reference_number @banknet_reference_number end |
#financial_network_code ⇒ Object (readonly)
The identifier of the program or service.
800 801 802 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 800 def financial_network_code @financial_network_code end |
#network_date ⇒ Object (readonly)
The card network's record date for this authorization.
802 803 804 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 802 def network_date @network_date end |
Class Method Details
.field_remappings ⇒ Object
808 809 810 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 808 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
804 805 806 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 804 def self.inner_class_types @inner_class_types = {} end |