Class: Stripe::Issuing::Authorization::RespondParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/issuing/authorization.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(confirmed: nil, expand: nil) ⇒ RespondParams

Returns a new instance of RespondParams.



1192
1193
1194
1195
# File 'lib/stripe/resources/issuing/authorization.rb', line 1192

def initialize(confirmed: nil, expand: nil)
  @confirmed = confirmed
  @expand = expand
end

Instance Attribute Details

#confirmedObject

Whether to simulate the user confirming that the transaction was legitimate (true) or telling Stripe that it was fraudulent (false).



1188
1189
1190
# File 'lib/stripe/resources/issuing/authorization.rb', line 1188

def confirmed
  @confirmed
end

#expandObject

Specifies which fields in the response should be expanded.



1190
1191
1192
# File 'lib/stripe/resources/issuing/authorization.rb', line 1190

def expand
  @expand
end