Class: Stripe::Issuing::Authorization::TokenDetails::NetworkData::Device
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Issuing::Authorization::TokenDetails::NetworkData::Device
- Defined in:
- lib/stripe/resources/issuing/authorization.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#device_id ⇒ Object
readonly
An identifier for the device used during wallet provisioning.
-
#ip_address ⇒ Object
readonly
The IP address of the device at provisioning time.
-
#language ⇒ Object
readonly
The ISO 639-1 language code of the device associated with the tokenization request.
-
#phone_number ⇒ Object
readonly
The phone number of the device used for tokenization.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#device_id ⇒ Object (readonly)
An identifier for the device used during wallet provisioning.
1085 1086 1087 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1085 def device_id @device_id end |
#ip_address ⇒ Object (readonly)
The IP address of the device at provisioning time.
1087 1088 1089 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1087 def ip_address @ip_address end |
#language ⇒ Object (readonly)
The ISO 639-1 language code of the device associated with the tokenization request.
1089 1090 1091 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1089 def language @language end |
#phone_number ⇒ Object (readonly)
The phone number of the device used for tokenization.
1091 1092 1093 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1091 def phone_number @phone_number end |
Class Method Details
.field_remappings ⇒ Object
1097 1098 1099 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1097 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1093 1094 1095 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1093 def self.inner_class_types @inner_class_types = {} end |