Class: Stripe::Issuing::Authorization::TokenDetails::NetworkData::Visa
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Issuing::Authorization::TokenDetails::NetworkData::Visa
- Defined in:
- lib/stripe/resources/issuing/authorization.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#card_reference_id ⇒ Object
readonly
A unique reference ID from the network to represent the card account number.
-
#token_decision_recommendation ⇒ Object
readonly
The network's recommendation to Stripe for this token activation request.
-
#token_reference_id ⇒ Object
readonly
The network-unique identifier for the token.
-
#token_requestor_id ⇒ Object
readonly
The ID of the entity requesting tokenization.
-
#token_risk_score ⇒ Object
readonly
Degree of risk associated with the token between
01and99, with higher number indicating higher risk.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#card_reference_id ⇒ Object (readonly)
A unique reference ID from the network to represent the card account number.
921 922 923 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 921 def card_reference_id @card_reference_id end |
#token_decision_recommendation ⇒ Object (readonly)
The network's recommendation to Stripe for this token activation request.
923 924 925 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 923 def token_decision_recommendation @token_decision_recommendation end |
#token_reference_id ⇒ Object (readonly)
The network-unique identifier for the token.
925 926 927 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 925 def token_reference_id @token_reference_id end |
#token_requestor_id ⇒ Object (readonly)
The ID of the entity requesting tokenization.
927 928 929 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 927 def token_requestor_id @token_requestor_id end |
#token_risk_score ⇒ Object (readonly)
Degree of risk associated with the token between 01 and 99, with higher number indicating higher risk. A 00 value indicates the token was not scored by Visa.
929 930 931 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 929 def token_risk_score @token_risk_score end |
Class Method Details
.field_remappings ⇒ Object
935 936 937 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 935 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
931 932 933 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 931 def self.inner_class_types @inner_class_types = {} end |