Class: Stripe::Issuing::Authorization::TokenDetails::NetworkData::WalletProvider
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Issuing::Authorization::TokenDetails::NetworkData::WalletProvider
- Defined in:
- lib/stripe/resources/issuing/authorization.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_trust_score ⇒ Object
readonly
An evaluation on the trustworthiness of the wallet account between 1 and 5.
-
#card_number_source ⇒ Object
readonly
The method used for tokenizing a card.
-
#device_trust_score ⇒ Object
readonly
An evaluation on the trustworthiness of the device.
-
#reason_codes ⇒ Object
readonly
The reasons for suggested tokenization given by the card network.
-
#suggested_decision ⇒ Object
readonly
The recommendation on responding to the tokenization request.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_trust_score ⇒ Object (readonly)
An evaluation on the trustworthiness of the wallet account between 1 and 5. A higher score indicates more trustworthy.
558 559 560 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 558 def account_trust_score @account_trust_score end |
#card_number_source ⇒ Object (readonly)
The method used for tokenizing a card.
560 561 562 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 560 def card_number_source @card_number_source end |
#device_trust_score ⇒ Object (readonly)
An evaluation on the trustworthiness of the device. A higher score indicates more trustworthy.
562 563 564 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 562 def device_trust_score @device_trust_score end |
#reason_codes ⇒ Object (readonly)
The reasons for suggested tokenization given by the card network.
564 565 566 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 564 def reason_codes @reason_codes end |
#suggested_decision ⇒ Object (readonly)
The recommendation on responding to the tokenization request.
566 567 568 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 566 def suggested_decision @suggested_decision end |
Class Method Details
.field_remappings ⇒ Object
572 573 574 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 572 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
568 569 570 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 568 def self.inner_class_types @inner_class_types = {} end |