Class: Stripe::Issuing::Authorization::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/issuing/authorization.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, metadata: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



298
299
300
301
# File 'lib/stripe/resources/issuing/authorization.rb', line 298

def initialize(expand: nil, metadata: nil)
  @expand = expand
  @metadata = 
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



294
295
296
# File 'lib/stripe/resources/issuing/authorization.rb', line 294

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



296
297
298
# File 'lib/stripe/resources/issuing/authorization.rb', line 296

def 
  @metadata
end