Class: Stripe::Issuing::Authorization::VerificationData

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/issuing/authorization.rb

Defined Under Namespace

Classes: AuthenticationExemption, ThreeDSecure

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#address_line1_checkObject (readonly)

Whether the cardholder provided an address first line and if it matched the cardholder’s billing.address.line1.



1252
1253
1254
# File 'lib/stripe/resources/issuing/authorization.rb', line 1252

def address_line1_check
  @address_line1_check
end

#address_postal_code_checkObject (readonly)

Whether the cardholder provided a postal code and if it matched the cardholder’s billing.address.postal_code.



1254
1255
1256
# File 'lib/stripe/resources/issuing/authorization.rb', line 1254

def address_postal_code_check
  @address_postal_code_check
end

#authentication_exemptionObject (readonly)

The exemption applied to this authorization.



1256
1257
1258
# File 'lib/stripe/resources/issuing/authorization.rb', line 1256

def authentication_exemption
  @authentication_exemption
end

#cvc_checkObject (readonly)

Whether the cardholder provided a CVC and if it matched Stripe’s record.



1258
1259
1260
# File 'lib/stripe/resources/issuing/authorization.rb', line 1258

def cvc_check
  @cvc_check
end

#expiry_checkObject (readonly)

Whether the cardholder provided an expiry date and if it matched Stripe’s record.



1260
1261
1262
# File 'lib/stripe/resources/issuing/authorization.rb', line 1260

def expiry_check
  @expiry_check
end

#postal_codeObject (readonly)

The postal code submitted as part of the authorization used for postal code verification.



1262
1263
1264
# File 'lib/stripe/resources/issuing/authorization.rb', line 1262

def postal_code
  @postal_code
end

#three_d_secureObject (readonly)

3D Secure details.



1264
1265
1266
# File 'lib/stripe/resources/issuing/authorization.rb', line 1264

def three_d_secure
  @three_d_secure
end

Class Method Details

.field_remappingsObject



1273
1274
1275
# File 'lib/stripe/resources/issuing/authorization.rb', line 1273

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1266
1267
1268
1269
1270
1271
# File 'lib/stripe/resources/issuing/authorization.rb', line 1266

def self.inner_class_types
  @inner_class_types = {
    authentication_exemption: AuthenticationExemption,
    three_d_secure: ThreeDSecure,
  }
end