Class: Stripe::Issuing::AuthorizationCaptureParams::PurchaseDetails::Fleet::ReportedBreakdown::Tax
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::AuthorizationCaptureParams::PurchaseDetails::Fleet::ReportedBreakdown::Tax
- Defined in:
- lib/stripe/params/issuing/authorization_capture_params.rb
Instance Attribute Summary collapse
-
#local_amount_decimal ⇒ Object
Amount of state or provincial Sales Tax included in the transaction amount.
-
#national_amount_decimal ⇒ Object
Amount of national Sales Tax or VAT included in the transaction amount.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(local_amount_decimal: nil, national_amount_decimal: nil) ⇒ Tax
constructor
A new instance of Tax.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(local_amount_decimal: nil, national_amount_decimal: nil) ⇒ Tax
Returns a new instance of Tax.
78 79 80 81 |
# File 'lib/stripe/params/issuing/authorization_capture_params.rb', line 78 def initialize(local_amount_decimal: nil, national_amount_decimal: nil) @local_amount_decimal = local_amount_decimal @national_amount_decimal = national_amount_decimal end |
Instance Attribute Details
#local_amount_decimal ⇒ Object
Amount of state or provincial Sales Tax included in the transaction amount. Null if not reported by merchant or not subject to tax.
74 75 76 |
# File 'lib/stripe/params/issuing/authorization_capture_params.rb', line 74 def local_amount_decimal @local_amount_decimal end |
#national_amount_decimal ⇒ Object
Amount of national Sales Tax or VAT included in the transaction amount. Null if not reported by merchant or not subject to tax.
76 77 78 |
# File 'lib/stripe/params/issuing/authorization_capture_params.rb', line 76 def national_amount_decimal @national_amount_decimal end |
Class Method Details
.field_encodings ⇒ Object
83 84 85 86 87 88 |
# File 'lib/stripe/params/issuing/authorization_capture_params.rb', line 83 def self.field_encodings @field_encodings = { local_amount_decimal: :decimal_string, national_amount_decimal: :decimal_string, } end |