Class: Stripe::Issuing::AuthorizationCreateParams::MerchantData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/issuing/authorization_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(category: nil, city: nil, country: nil, name: nil, network_id: nil, postal_code: nil, state: nil, terminal_id: nil, url: nil) ⇒ MerchantData

Returns a new instance of MerchantData.



211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
# File 'lib/stripe/params/issuing/authorization_create_params.rb', line 211

def initialize(
  category: nil,
  city: nil,
  country: nil,
  name: nil,
  network_id: nil,
  postal_code: nil,
  state: nil,
  terminal_id: nil,
  url: nil
)
  @category = category
  @city = city
  @country = country
  @name = name
  @network_id = network_id
  @postal_code = postal_code
  @state = state
  @terminal_id = terminal_id
  @url = url
end

Instance Attribute Details

#categoryObject

A categorization of the seller’s type of business. See our [merchant categories guide](docs.stripe.com/issuing/merchant-categories) for a list of possible values.



193
194
195
# File 'lib/stripe/params/issuing/authorization_create_params.rb', line 193

def category
  @category
end

#cityObject

City where the seller is located



195
196
197
# File 'lib/stripe/params/issuing/authorization_create_params.rb', line 195

def city
  @city
end

#countryObject

Country where the seller is located



197
198
199
# File 'lib/stripe/params/issuing/authorization_create_params.rb', line 197

def country
  @country
end

#nameObject

Name of the seller



199
200
201
# File 'lib/stripe/params/issuing/authorization_create_params.rb', line 199

def name
  @name
end

#network_idObject

Identifier assigned to the seller by the card network. Different card networks may assign different network_id fields to the same merchant.



201
202
203
# File 'lib/stripe/params/issuing/authorization_create_params.rb', line 201

def network_id
  @network_id
end

#postal_codeObject

Postal code where the seller is located



203
204
205
# File 'lib/stripe/params/issuing/authorization_create_params.rb', line 203

def postal_code
  @postal_code
end

#stateObject

State where the seller is located



205
206
207
# File 'lib/stripe/params/issuing/authorization_create_params.rb', line 205

def state
  @state
end

#terminal_idObject

An ID assigned by the seller to the location of the sale.



207
208
209
# File 'lib/stripe/params/issuing/authorization_create_params.rb', line 207

def terminal_id
  @terminal_id
end

#urlObject

URL provided by the merchant on a 3DS request



209
210
211
# File 'lib/stripe/params/issuing/authorization_create_params.rb', line 209

def url
  @url
end