Class: Stripe::Issuing::AuthorizationCreateParams::RiskAssessment::MerchantDisputeRisk

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/issuing/authorization_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(dispute_rate: nil, level: nil) ⇒ MerchantDisputeRisk

Returns a new instance of MerchantDisputeRisk.



281
282
283
284
# File 'lib/stripe/params/issuing/authorization_create_params.rb', line 281

def initialize(dispute_rate: nil, level: nil)
  @dispute_rate = dispute_rate
  @level = level
end

Instance Attribute Details

#dispute_rateObject

The dispute rate observed across all Stripe Issuing authorizations for this merchant. For example, a value of 50 means 50% of authorizations from this merchant on Stripe Issuing have resulted in a dispute. Higher values mean a higher likelihood the authorization is disputed. Takes on values between 0 and 100.



277
278
279
# File 'lib/stripe/params/issuing/authorization_create_params.rb', line 277

def dispute_rate
  @dispute_rate
end

#levelObject

The likelihood that authorizations from this merchant will result in a dispute based on their history on Stripe Issuing.



279
280
281
# File 'lib/stripe/params/issuing/authorization_create_params.rb', line 279

def level
  @level
end