Class: Stripe::Issuing::AuthorizationFinalizeAmountParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::AuthorizationFinalizeAmountParams
- Defined in:
- lib/stripe/params/issuing/authorization_finalize_amount_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#final_amount ⇒ Object
The final authorization amount that will be captured by the merchant.
-
#fleet ⇒ Object
Fleet-specific information for authorizations using Fleet cards.
-
#fuel ⇒ Object
Information about fuel that was purchased with this transaction.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(expand: nil, final_amount: nil, fleet: nil, fuel: nil) ⇒ AuthorizationFinalizeAmountParams
constructor
A new instance of AuthorizationFinalizeAmountParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(expand: nil, final_amount: nil, fleet: nil, fuel: nil) ⇒ AuthorizationFinalizeAmountParams
Returns a new instance of AuthorizationFinalizeAmountParams.
187 188 189 190 191 192 |
# File 'lib/stripe/params/issuing/authorization_finalize_amount_params.rb', line 187 def initialize(expand: nil, final_amount: nil, fleet: nil, fuel: nil) = @final_amount = final_amount @fleet = fleet @fuel = fuel end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
179 180 181 |
# File 'lib/stripe/params/issuing/authorization_finalize_amount_params.rb', line 179 def end |
#final_amount ⇒ Object
The final authorization amount that will be captured by the merchant. This amount is in the authorization currency and in the [smallest currency unit](docs.stripe.com/currencies#zero-decimal).
181 182 183 |
# File 'lib/stripe/params/issuing/authorization_finalize_amount_params.rb', line 181 def final_amount @final_amount end |
#fleet ⇒ Object
Fleet-specific information for authorizations using Fleet cards.
183 184 185 |
# File 'lib/stripe/params/issuing/authorization_finalize_amount_params.rb', line 183 def fleet @fleet end |
#fuel ⇒ Object
Information about fuel that was purchased with this transaction.
185 186 187 |
# File 'lib/stripe/params/issuing/authorization_finalize_amount_params.rb', line 185 def fuel @fuel end |
Class Method Details
.field_encodings ⇒ Object
194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 |
# File 'lib/stripe/params/issuing/authorization_finalize_amount_params.rb', line 194 def self.field_encodings @field_encodings = { fleet: { kind: :object, fields: { reported_breakdown: { kind: :object, fields: { fuel: { kind: :object, fields: { gross_amount_decimal: :decimal_string } }, non_fuel: { kind: :object, fields: { gross_amount_decimal: :decimal_string } }, tax: { kind: :object, fields: { local_amount_decimal: :decimal_string, national_amount_decimal: :decimal_string, }, }, }, }, }, }, fuel: { kind: :object, fields: { quantity_decimal: :decimal_string, unit_cost_decimal: :decimal_string }, }, } end |