Class: Stripe::Issuing::AuthorizationFinalizeAmountParams::Fleet::ReportedBreakdown::Tax
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::AuthorizationFinalizeAmountParams::Fleet::ReportedBreakdown::Tax
- Defined in:
- lib/stripe/params/issuing/authorization_finalize_amount_params.rb
Instance Attribute Summary collapse
-
#local_amount_decimal ⇒ Object
Amount of state or provincial Sales Tax included in the transaction amount.
-
#national_amount_decimal ⇒ Object
Amount of national Sales Tax or VAT included in the transaction amount.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(local_amount_decimal: nil, national_amount_decimal: nil) ⇒ Tax
constructor
A new instance of Tax.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(local_amount_decimal: nil, national_amount_decimal: nil) ⇒ Tax
Returns a new instance of Tax.
68 69 70 71 |
# File 'lib/stripe/params/issuing/authorization_finalize_amount_params.rb', line 68 def initialize(local_amount_decimal: nil, national_amount_decimal: nil) @local_amount_decimal = local_amount_decimal @national_amount_decimal = national_amount_decimal end |
Instance Attribute Details
#local_amount_decimal ⇒ Object
Amount of state or provincial Sales Tax included in the transaction amount. Null if not reported by merchant or not subject to tax.
64 65 66 |
# File 'lib/stripe/params/issuing/authorization_finalize_amount_params.rb', line 64 def local_amount_decimal @local_amount_decimal end |
#national_amount_decimal ⇒ Object
Amount of national Sales Tax or VAT included in the transaction amount. Null if not reported by merchant or not subject to tax.
66 67 68 |
# File 'lib/stripe/params/issuing/authorization_finalize_amount_params.rb', line 66 def national_amount_decimal @national_amount_decimal end |
Class Method Details
.field_encodings ⇒ Object
73 74 75 76 77 78 |
# File 'lib/stripe/params/issuing/authorization_finalize_amount_params.rb', line 73 def self.field_encodings @field_encodings = { local_amount_decimal: :decimal_string, national_amount_decimal: :decimal_string, } end |