Class: Stripe::Issuing::AuthorizationFinalizeAmountParams::Fuel
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::AuthorizationFinalizeAmountParams::Fuel
- Defined in:
- lib/stripe/params/issuing/authorization_finalize_amount_params.rb
Instance Attribute Summary collapse
-
#industry_product_code ⇒ Object
[Conexxus Payment System Product Code](www.conexxus.org/conexxus-payment-system-product-codes) identifying the primary fuel product purchased.
-
#quantity_decimal ⇒ Object
The quantity of ‘unit`s of fuel that was dispensed, represented as a decimal string with at most 12 decimal places.
-
#type ⇒ Object
The type of fuel that was purchased.
-
#unit ⇒ Object
The units for ‘quantity_decimal`.
-
#unit_cost_decimal ⇒ Object
The cost in cents per each unit of fuel, represented as a decimal string with at most 12 decimal places.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(industry_product_code: nil, quantity_decimal: nil, type: nil, unit: nil, unit_cost_decimal: nil) ⇒ Fuel
constructor
A new instance of Fuel.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(industry_product_code: nil, quantity_decimal: nil, type: nil, unit: nil, unit_cost_decimal: nil) ⇒ Fuel
Returns a new instance of Fuel.
160 161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/stripe/params/issuing/authorization_finalize_amount_params.rb', line 160 def initialize( industry_product_code: nil, quantity_decimal: nil, type: nil, unit: nil, unit_cost_decimal: nil ) @industry_product_code = industry_product_code @quantity_decimal = quantity_decimal @type = type @unit = unit @unit_cost_decimal = unit_cost_decimal end |
Instance Attribute Details
#industry_product_code ⇒ Object
[Conexxus Payment System Product Code](www.conexxus.org/conexxus-payment-system-product-codes) identifying the primary fuel product purchased.
150 151 152 |
# File 'lib/stripe/params/issuing/authorization_finalize_amount_params.rb', line 150 def industry_product_code @industry_product_code end |
#quantity_decimal ⇒ Object
The quantity of ‘unit`s of fuel that was dispensed, represented as a decimal string with at most 12 decimal places.
152 153 154 |
# File 'lib/stripe/params/issuing/authorization_finalize_amount_params.rb', line 152 def quantity_decimal @quantity_decimal end |
#type ⇒ Object
The type of fuel that was purchased. One of ‘diesel`, `unleaded_plus`, `unleaded_regular`, `unleaded_super`, or `other`.
154 155 156 |
# File 'lib/stripe/params/issuing/authorization_finalize_amount_params.rb', line 154 def type @type end |
#unit ⇒ Object
The units for ‘quantity_decimal`. One of `charging_minute`, `imperial_gallon`, `kilogram`, `kilowatt_hour`, `liter`, `pound`, `us_gallon`, or `other`.
156 157 158 |
# File 'lib/stripe/params/issuing/authorization_finalize_amount_params.rb', line 156 def unit @unit end |
#unit_cost_decimal ⇒ Object
The cost in cents per each unit of fuel, represented as a decimal string with at most 12 decimal places.
158 159 160 |
# File 'lib/stripe/params/issuing/authorization_finalize_amount_params.rb', line 158 def unit_cost_decimal @unit_cost_decimal end |
Class Method Details
.field_encodings ⇒ Object
174 175 176 |
# File 'lib/stripe/params/issuing/authorization_finalize_amount_params.rb', line 174 def self.field_encodings @field_encodings = { quantity_decimal: :decimal_string, unit_cost_decimal: :decimal_string } end |