Class: Stripe::Issuing::AuthorizationService::DeclineParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/issuing/authorization_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, metadata: nil) ⇒ DeclineParams

Returns a new instance of DeclineParams.



119
120
121
122
# File 'lib/stripe/services/issuing/authorization_service.rb', line 119

def initialize(expand: nil, metadata: nil)
  @expand = expand
  @metadata = 
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



114
115
116
# File 'lib/stripe/services/issuing/authorization_service.rb', line 114

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



117
118
119
# File 'lib/stripe/services/issuing/authorization_service.rb', line 117

def 
  @metadata
end