Class: Stripe::Issuing::Card::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::Card::CreateParams
- Defined in:
- lib/stripe/resources/issuing/card.rb
Defined Under Namespace
Classes: Pin, Shipping, SpendingControls
Instance Attribute Summary collapse
-
#cardholder ⇒ Object
The [Cardholder](stripe.com/docs/api#issuing_cardholder_object) object with which the card will be associated.
-
#currency ⇒ Object
The currency for the card.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#financial_account ⇒ Object
The new financial account ID the card will be associated with.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#personalization_design ⇒ Object
The personalization design object belonging to this card.
-
#pin ⇒ Object
The desired PIN for this card.
-
#replacement_for ⇒ Object
The card this is meant to be a replacement for (if any).
-
#replacement_reason ⇒ Object
If ‘replacement_for` is specified, this should indicate why that card is being replaced.
-
#second_line ⇒ Object
The second line to print on the card.
-
#shipping ⇒ Object
The address where the card will be shipped.
-
#spending_controls ⇒ Object
Rules that control spending for this card.
-
#status ⇒ Object
Whether authorizations can be approved on this card.
-
#type ⇒ Object
The type of card to issue.
Instance Method Summary collapse
-
#initialize(cardholder: nil, currency: nil, expand: nil, financial_account: nil, metadata: nil, personalization_design: nil, pin: nil, replacement_for: nil, replacement_reason: nil, second_line: nil, shipping: nil, spending_controls: nil, status: nil, type: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(cardholder: nil, currency: nil, expand: nil, financial_account: nil, metadata: nil, personalization_design: nil, pin: nil, replacement_for: nil, replacement_reason: nil, second_line: nil, shipping: nil, spending_controls: nil, status: nil, type: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 |
# File 'lib/stripe/resources/issuing/card.rb', line 455 def initialize( cardholder: nil, currency: nil, expand: nil, financial_account: nil, metadata: nil, personalization_design: nil, pin: nil, replacement_for: nil, replacement_reason: nil, second_line: nil, shipping: nil, spending_controls: nil, status: nil, type: nil ) @cardholder = cardholder @currency = currency @expand = @financial_account = financial_account @metadata = @personalization_design = personalization_design @pin = pin @replacement_for = replacement_for @replacement_reason = replacement_reason @second_line = second_line @shipping = shipping @spending_controls = spending_controls @status = status @type = type end |
Instance Attribute Details
#cardholder ⇒ Object
The [Cardholder](stripe.com/docs/api#issuing_cardholder_object) object with which the card will be associated.
427 428 429 |
# File 'lib/stripe/resources/issuing/card.rb', line 427 def cardholder @cardholder end |
#currency ⇒ Object
The currency for the card.
429 430 431 |
# File 'lib/stripe/resources/issuing/card.rb', line 429 def currency @currency end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
431 432 433 |
# File 'lib/stripe/resources/issuing/card.rb', line 431 def @expand end |
#financial_account ⇒ Object
The new financial account ID the card will be associated with. This field allows a card to be reassigned to a different financial account.
433 434 435 |
# File 'lib/stripe/resources/issuing/card.rb', line 433 def financial_account @financial_account end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
435 436 437 |
# File 'lib/stripe/resources/issuing/card.rb', line 435 def @metadata end |
#personalization_design ⇒ Object
The personalization design object belonging to this card.
437 438 439 |
# File 'lib/stripe/resources/issuing/card.rb', line 437 def personalization_design @personalization_design end |
#pin ⇒ Object
The desired PIN for this card.
439 440 441 |
# File 'lib/stripe/resources/issuing/card.rb', line 439 def pin @pin end |
#replacement_for ⇒ Object
The card this is meant to be a replacement for (if any).
441 442 443 |
# File 'lib/stripe/resources/issuing/card.rb', line 441 def replacement_for @replacement_for end |
#replacement_reason ⇒ Object
If ‘replacement_for` is specified, this should indicate why that card is being replaced.
443 444 445 |
# File 'lib/stripe/resources/issuing/card.rb', line 443 def replacement_reason @replacement_reason end |
#second_line ⇒ Object
The second line to print on the card. Max length: 24 characters.
445 446 447 |
# File 'lib/stripe/resources/issuing/card.rb', line 445 def second_line @second_line end |
#shipping ⇒ Object
The address where the card will be shipped.
447 448 449 |
# File 'lib/stripe/resources/issuing/card.rb', line 447 def shipping @shipping end |
#spending_controls ⇒ Object
Rules that control spending for this card. Refer to our [documentation](stripe.com/docs/issuing/controls/spending-controls) for more details.
449 450 451 |
# File 'lib/stripe/resources/issuing/card.rb', line 449 def spending_controls @spending_controls end |
#status ⇒ Object
Whether authorizations can be approved on this card. May be blocked from activating cards depending on past-due Cardholder requirements. Defaults to ‘inactive`.
451 452 453 |
# File 'lib/stripe/resources/issuing/card.rb', line 451 def status @status end |
#type ⇒ Object
The type of card to issue. Possible values are ‘physical` or `virtual`.
453 454 455 |
# File 'lib/stripe/resources/issuing/card.rb', line 453 def type @type end |