Class: Stripe::Issuing::Card::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/issuing/card.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(cardholder: nil, created: nil, ending_before: nil, exp_month: nil, exp_year: nil, expand: nil, last4: nil, limit: nil, personalization_design: nil, starting_after: nil, status: nil, type: nil) ⇒ ListParams

Returns a new instance of ListParams.



260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
# File 'lib/stripe/resources/issuing/card.rb', line 260

def initialize(
  cardholder: nil,
  created: nil,
  ending_before: nil,
  exp_month: nil,
  exp_year: nil,
  expand: nil,
  last4: nil,
  limit: nil,
  personalization_design: nil,
  starting_after: nil,
  status: nil,
  type: nil
)
  @cardholder = cardholder
  @created = created
  @ending_before = ending_before
  @exp_month = exp_month
  @exp_year = exp_year
  @expand = expand
  @last4 = last4
  @limit = limit
  @personalization_design = personalization_design
  @starting_after = starting_after
  @status = status
  @type = type
end

Instance Attribute Details

#cardholderObject

Only return cards belonging to the Cardholder with the provided ID.



236
237
238
# File 'lib/stripe/resources/issuing/card.rb', line 236

def cardholder
  @cardholder
end

#createdObject

Only return cards that were issued during the given date interval.



238
239
240
# File 'lib/stripe/resources/issuing/card.rb', line 238

def created
  @created
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



240
241
242
# File 'lib/stripe/resources/issuing/card.rb', line 240

def ending_before
  @ending_before
end

#exp_monthObject

Only return cards that have the given expiration month.



242
243
244
# File 'lib/stripe/resources/issuing/card.rb', line 242

def exp_month
  @exp_month
end

#exp_yearObject

Only return cards that have the given expiration year.



244
245
246
# File 'lib/stripe/resources/issuing/card.rb', line 244

def exp_year
  @exp_year
end

#expandObject

Specifies which fields in the response should be expanded.



246
247
248
# File 'lib/stripe/resources/issuing/card.rb', line 246

def expand
  @expand
end

#last4Object

Only return cards that have the given last four digits.



248
249
250
# File 'lib/stripe/resources/issuing/card.rb', line 248

def last4
  @last4
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



250
251
252
# File 'lib/stripe/resources/issuing/card.rb', line 250

def limit
  @limit
end

#personalization_designObject

Attribute for param field personalization_design



252
253
254
# File 'lib/stripe/resources/issuing/card.rb', line 252

def personalization_design
  @personalization_design
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



254
255
256
# File 'lib/stripe/resources/issuing/card.rb', line 254

def starting_after
  @starting_after
end

#statusObject

Only return cards that have the given status. One of ‘active`, `inactive`, or `canceled`.



256
257
258
# File 'lib/stripe/resources/issuing/card.rb', line 256

def status
  @status
end

#typeObject

Only return cards that have the given type. One of ‘virtual` or `physical`.



258
259
260
# File 'lib/stripe/resources/issuing/card.rb', line 258

def type
  @type
end