Class: Stripe::Issuing::Card::ShipCardParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::Card::ShipCardParams
- Defined in:
- lib/stripe/resources/issuing/card.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ ShipCardParams
constructor
A new instance of ShipCardParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ ShipCardParams
Returns a new instance of ShipCardParams.
724 725 726 |
# File 'lib/stripe/resources/issuing/card.rb', line 724 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
722 723 724 |
# File 'lib/stripe/resources/issuing/card.rb', line 722 def @expand end |