Class: Stripe::Issuing::Card::Shipping
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Issuing::Card::Shipping
- Defined in:
- lib/stripe/resources/issuing/card.rb
Defined Under Namespace
Classes: Address, AddressValidation, Customs
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#address ⇒ Object
readonly
Attribute for field address.
-
#address_validation ⇒ Object
readonly
Address validation details for the shipment.
-
#business_name ⇒ Object
readonly
The name of the business at the shipping address, used on the shipping label to ensure delivery when the card is shipped to a cardholder's workplace.
-
#carrier ⇒ Object
readonly
The delivery company that shipped a card.
-
#customs ⇒ Object
readonly
Additional information that may be required for clearing customs.
-
#eta ⇒ Object
readonly
A unix timestamp representing a best estimate of when the card will be delivered.
-
#name ⇒ Object
readonly
Recipient name.
-
#phone_number ⇒ Object
readonly
The phone number of the receiver of the shipment.
-
#require_signature ⇒ Object
readonly
Whether a signature is required for card delivery.
-
#service ⇒ Object
readonly
Shipment service, such as
standardorexpress. -
#status ⇒ Object
readonly
The delivery status of the card.
-
#tracking_number ⇒ Object
readonly
A tracking number for a card shipment.
-
#tracking_url ⇒ Object
readonly
A link to the shipping carrier's site where you can view detailed information about a card shipment.
-
#type ⇒ Object
readonly
Packaging options.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#address ⇒ Object (readonly)
Attribute for field address
161 162 163 |
# File 'lib/stripe/resources/issuing/card.rb', line 161 def address @address end |
#address_validation ⇒ Object (readonly)
Address validation details for the shipment.
163 164 165 |
# File 'lib/stripe/resources/issuing/card.rb', line 163 def address_validation @address_validation end |
#business_name ⇒ Object (readonly)
The name of the business at the shipping address, used on the shipping label to ensure delivery when the card is shipped to a cardholder's workplace.
165 166 167 |
# File 'lib/stripe/resources/issuing/card.rb', line 165 def business_name @business_name end |
#carrier ⇒ Object (readonly)
The delivery company that shipped a card.
167 168 169 |
# File 'lib/stripe/resources/issuing/card.rb', line 167 def carrier @carrier end |
#customs ⇒ Object (readonly)
Additional information that may be required for clearing customs.
169 170 171 |
# File 'lib/stripe/resources/issuing/card.rb', line 169 def customs @customs end |
#eta ⇒ Object (readonly)
A unix timestamp representing a best estimate of when the card will be delivered.
171 172 173 |
# File 'lib/stripe/resources/issuing/card.rb', line 171 def eta @eta end |
#name ⇒ Object (readonly)
Recipient name.
173 174 175 |
# File 'lib/stripe/resources/issuing/card.rb', line 173 def name @name end |
#phone_number ⇒ Object (readonly)
The phone number of the receiver of the shipment. Our courier partners will use this number to contact you in the event of card delivery issues. For individual shipments to the EU/UK, if this field is empty, we will provide them with the phone number provided when the cardholder was initially created.
175 176 177 |
# File 'lib/stripe/resources/issuing/card.rb', line 175 def phone_number @phone_number end |
#require_signature ⇒ Object (readonly)
Whether a signature is required for card delivery. This feature is only supported for US users. Standard shipping service does not support signature on delivery. The default value for standard shipping service is false and for express and priority services is true.
177 178 179 |
# File 'lib/stripe/resources/issuing/card.rb', line 177 def require_signature @require_signature end |
#service ⇒ Object (readonly)
Shipment service, such as standard or express.
179 180 181 |
# File 'lib/stripe/resources/issuing/card.rb', line 179 def service @service end |
#status ⇒ Object (readonly)
The delivery status of the card.
181 182 183 |
# File 'lib/stripe/resources/issuing/card.rb', line 181 def status @status end |
#tracking_number ⇒ Object (readonly)
A tracking number for a card shipment.
183 184 185 |
# File 'lib/stripe/resources/issuing/card.rb', line 183 def tracking_number @tracking_number end |
#tracking_url ⇒ Object (readonly)
A link to the shipping carrier's site where you can view detailed information about a card shipment.
185 186 187 |
# File 'lib/stripe/resources/issuing/card.rb', line 185 def tracking_url @tracking_url end |
#type ⇒ Object (readonly)
Packaging options.
187 188 189 |
# File 'lib/stripe/resources/issuing/card.rb', line 187 def type @type end |
Class Method Details
.field_remappings ⇒ Object
197 198 199 |
# File 'lib/stripe/resources/issuing/card.rb', line 197 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
189 190 191 192 193 194 195 |
# File 'lib/stripe/resources/issuing/card.rb', line 189 def self.inner_class_types @inner_class_types = { address: Address, address_validation: AddressValidation, customs: Customs, } end |