Class: Stripe::Issuing::Card::SpendingControls

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/issuing/card.rb

Defined Under Namespace

Classes: SpendingLimit

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#allowed_card_presencesObject (readonly)

Array of card presence statuses from which authorizations will be allowed. Possible options are present, not_present. All other statuses will be blocked. Cannot be set with blocked_card_presences. Provide an empty value to unset this control.



220
221
222
# File 'lib/stripe/resources/issuing/card.rb', line 220

def allowed_card_presences
  @allowed_card_presences
end

#allowed_categoriesObject (readonly)

Array of strings containing categories of authorizations to allow. All other categories will be blocked. Cannot be set with blocked_categories.



222
223
224
# File 'lib/stripe/resources/issuing/card.rb', line 222

def allowed_categories
  @allowed_categories
end

#allowed_merchant_countriesObject (readonly)

Array of strings containing representing countries from which authorizations will be allowed. Authorizations from merchants in all other countries will be declined. Country codes should be ISO 3166 alpha-2 country codes (e.g. US). Cannot be set with blocked_merchant_countries. Provide an empty value to unset this control.



224
225
226
# File 'lib/stripe/resources/issuing/card.rb', line 224

def allowed_merchant_countries
  @allowed_merchant_countries
end

#blocked_card_presencesObject (readonly)

Array of card presence statuses from which authorizations will be declined. Possible options are present, not_present. Cannot be set with allowed_card_presences. Provide an empty value to unset this control.



226
227
228
# File 'lib/stripe/resources/issuing/card.rb', line 226

def blocked_card_presences
  @blocked_card_presences
end

#blocked_categoriesObject (readonly)

Array of strings containing categories of authorizations to decline. All other categories will be allowed. Cannot be set with allowed_categories.



228
229
230
# File 'lib/stripe/resources/issuing/card.rb', line 228

def blocked_categories
  @blocked_categories
end

#blocked_merchant_countriesObject (readonly)

Array of strings containing representing countries from which authorizations will be declined. Country codes should be ISO 3166 alpha-2 country codes (e.g. US). Cannot be set with allowed_merchant_countries. Provide an empty value to unset this control.



230
231
232
# File 'lib/stripe/resources/issuing/card.rb', line 230

def blocked_merchant_countries
  @blocked_merchant_countries
end

#spending_limitsObject (readonly)

Limit spending with amount-based rules that apply across any cards this card replaced (i.e., its replacement_for card and that card's replacement_for card, up the chain).



232
233
234
# File 'lib/stripe/resources/issuing/card.rb', line 232

def spending_limits
  @spending_limits
end

#spending_limits_currencyObject (readonly)

Currency of the amounts within spending_limits. Always the same as the currency of the card.



234
235
236
# File 'lib/stripe/resources/issuing/card.rb', line 234

def spending_limits_currency
  @spending_limits_currency
end

Class Method Details

.field_remappingsObject



240
241
242
# File 'lib/stripe/resources/issuing/card.rb', line 240

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



236
237
238
# File 'lib/stripe/resources/issuing/card.rb', line 236

def self.inner_class_types
  @inner_class_types = { spending_limits: SpendingLimit }
end