Class: Stripe::Issuing::Card::TestHelpers
- Inherits:
-
APIResourceTestHelpers
- Object
- APIResourceTestHelpers
- Stripe::Issuing::Card::TestHelpers
- Defined in:
- lib/stripe/resources/issuing/card.rb
Constant Summary collapse
- RESOURCE_CLASS =
Card
Class Method Summary collapse
-
.deliver_card(card, params = {}, opts = {}) ⇒ Object
Updates the shipping status of the specified Issuing Card object to delivered.
-
.fail_card(card, params = {}, opts = {}) ⇒ Object
Updates the shipping status of the specified Issuing Card object to failure.
- .resource_class ⇒ Object
-
.return_card(card, params = {}, opts = {}) ⇒ Object
Updates the shipping status of the specified Issuing Card object to returned.
-
.ship_card(card, params = {}, opts = {}) ⇒ Object
Updates the shipping status of the specified Issuing Card object to shipped.
-
.submit_card(card, params = {}, opts = {}) ⇒ Object
Updates the shipping status of the specified Issuing Card object to submitted.
Instance Method Summary collapse
-
#deliver_card(params = {}, opts = {}) ⇒ Object
Updates the shipping status of the specified Issuing Card object to delivered.
-
#fail_card(params = {}, opts = {}) ⇒ Object
Updates the shipping status of the specified Issuing Card object to failure.
-
#return_card(params = {}, opts = {}) ⇒ Object
Updates the shipping status of the specified Issuing Card object to returned.
-
#ship_card(params = {}, opts = {}) ⇒ Object
Updates the shipping status of the specified Issuing Card object to shipped.
-
#submit_card(params = {}, opts = {}) ⇒ Object
Updates the shipping status of the specified Issuing Card object to submitted.
Methods inherited from APIResourceTestHelpers
custom_method, #initialize, resource_url, #resource_url
Methods included from APIOperations::Request
Constructor Details
This class inherits a constructor from Stripe::APIResourceTestHelpers
Class Method Details
.deliver_card(card, params = {}, opts = {}) ⇒ Object
Updates the shipping status of the specified Issuing Card object to delivered.
390 391 392 393 394 395 396 397 |
# File 'lib/stripe/resources/issuing/card.rb', line 390 def self.deliver_card(card, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/test_helpers/issuing/cards/%<card>s/shipping/deliver", { card: CGI.escape(card) }), params: params, opts: opts ) end |
.fail_card(card, params = {}, opts = {}) ⇒ Object
Updates the shipping status of the specified Issuing Card object to failure.
410 411 412 413 414 415 416 417 |
# File 'lib/stripe/resources/issuing/card.rb', line 410 def self.fail_card(card, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/test_helpers/issuing/cards/%<card>s/shipping/fail", { card: CGI.escape(card) }), params: params, opts: opts ) end |
.resource_class ⇒ Object
385 386 387 |
# File 'lib/stripe/resources/issuing/card.rb', line 385 def self.resource_class "Card" end |
.return_card(card, params = {}, opts = {}) ⇒ Object
Updates the shipping status of the specified Issuing Card object to returned.
430 431 432 433 434 435 436 437 |
# File 'lib/stripe/resources/issuing/card.rb', line 430 def self.return_card(card, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/test_helpers/issuing/cards/%<card>s/shipping/return", { card: CGI.escape(card) }), params: params, opts: opts ) end |
.ship_card(card, params = {}, opts = {}) ⇒ Object
Updates the shipping status of the specified Issuing Card object to shipped.
450 451 452 453 454 455 456 457 |
# File 'lib/stripe/resources/issuing/card.rb', line 450 def self.ship_card(card, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/test_helpers/issuing/cards/%<card>s/shipping/ship", { card: CGI.escape(card) }), params: params, opts: opts ) end |
.submit_card(card, params = {}, opts = {}) ⇒ Object
Updates the shipping status of the specified Issuing Card object to submitted. This method requires Stripe Version ‘2024-09-30.acacia' or later.
470 471 472 473 474 475 476 477 |
# File 'lib/stripe/resources/issuing/card.rb', line 470 def self.submit_card(card, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/test_helpers/issuing/cards/%<card>s/shipping/submit", { card: CGI.escape(card) }), params: params, opts: opts ) end |
Instance Method Details
#deliver_card(params = {}, opts = {}) ⇒ Object
Updates the shipping status of the specified Issuing Card object to delivered.
400 401 402 403 404 405 406 407 |
# File 'lib/stripe/resources/issuing/card.rb', line 400 def deliver_card(params = {}, opts = {}) @resource.request_stripe_object( method: :post, path: format("/v1/test_helpers/issuing/cards/%<card>s/shipping/deliver", { card: CGI.escape(@resource["id"]) }), params: params, opts: opts ) end |
#fail_card(params = {}, opts = {}) ⇒ Object
Updates the shipping status of the specified Issuing Card object to failure.
420 421 422 423 424 425 426 427 |
# File 'lib/stripe/resources/issuing/card.rb', line 420 def fail_card(params = {}, opts = {}) @resource.request_stripe_object( method: :post, path: format("/v1/test_helpers/issuing/cards/%<card>s/shipping/fail", { card: CGI.escape(@resource["id"]) }), params: params, opts: opts ) end |
#return_card(params = {}, opts = {}) ⇒ Object
Updates the shipping status of the specified Issuing Card object to returned.
440 441 442 443 444 445 446 447 |
# File 'lib/stripe/resources/issuing/card.rb', line 440 def return_card(params = {}, opts = {}) @resource.request_stripe_object( method: :post, path: format("/v1/test_helpers/issuing/cards/%<card>s/shipping/return", { card: CGI.escape(@resource["id"]) }), params: params, opts: opts ) end |
#ship_card(params = {}, opts = {}) ⇒ Object
Updates the shipping status of the specified Issuing Card object to shipped.
460 461 462 463 464 465 466 467 |
# File 'lib/stripe/resources/issuing/card.rb', line 460 def ship_card(params = {}, opts = {}) @resource.request_stripe_object( method: :post, path: format("/v1/test_helpers/issuing/cards/%<card>s/shipping/ship", { card: CGI.escape(@resource["id"]) }), params: params, opts: opts ) end |
#submit_card(params = {}, opts = {}) ⇒ Object
Updates the shipping status of the specified Issuing Card object to submitted. This method requires Stripe Version ‘2024-09-30.acacia' or later.
480 481 482 483 484 485 486 487 |
# File 'lib/stripe/resources/issuing/card.rb', line 480 def submit_card(params = {}, opts = {}) @resource.request_stripe_object( method: :post, path: format("/v1/test_helpers/issuing/cards/%<card>s/shipping/submit", { card: CGI.escape(@resource["id"]) }), params: params, opts: opts ) end |