Class: Stripe::Issuing::CardCreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/issuing/card_create_params.rb

Defined Under Namespace

Classes: LifecycleControls, Pin, Shipping, SpendingControls

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(cardholder: nil, currency: nil, exp_month: nil, exp_year: nil, expand: nil, financial_account: nil, lifecycle_controls: nil, metadata: nil, personalization_design: nil, pin: nil, replacement_for: nil, replacement_reason: nil, second_line: nil, shipping: nil, spending_controls: nil, status: nil, type: nil) ⇒ CardCreateParams

Returns a new instance of CardCreateParams.



207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/stripe/params/issuing/card_create_params.rb', line 207

def initialize(
  cardholder: nil,
  currency: nil,
  exp_month: nil,
  exp_year: nil,
  expand: nil,
  financial_account: nil,
  lifecycle_controls: nil,
  metadata: nil,
  personalization_design: nil,
  pin: nil,
  replacement_for: nil,
  replacement_reason: nil,
  second_line: nil,
  shipping: nil,
  spending_controls: nil,
  status: nil,
  type: nil
)
  @cardholder = cardholder
  @currency = currency
  @exp_month = exp_month
  @exp_year = exp_year
  @expand = expand
  @financial_account = 
  @lifecycle_controls = lifecycle_controls
  @metadata = 
  @personalization_design = personalization_design
  @pin = pin
  @replacement_for = replacement_for
  @replacement_reason = replacement_reason
  @second_line = second_line
  @shipping = shipping
  @spending_controls = spending_controls
  @status = status
  @type = type
end

Instance Attribute Details

#cardholderObject

The Cardholder object with which the card will be associated.



173
174
175
# File 'lib/stripe/params/issuing/card_create_params.rb', line 173

def cardholder
  @cardholder
end

#currencyObject

The currency for the card.



175
176
177
# File 'lib/stripe/params/issuing/card_create_params.rb', line 175

def currency
  @currency
end

#exp_monthObject

The desired expiration month (1-12) for this card if specifying a custom expiration date.



177
178
179
# File 'lib/stripe/params/issuing/card_create_params.rb', line 177

def exp_month
  @exp_month
end

#exp_yearObject

The desired 4-digit expiration year for this card if specifying a custom expiration date.



179
180
181
# File 'lib/stripe/params/issuing/card_create_params.rb', line 179

def exp_year
  @exp_year
end

#expandObject

Specifies which fields in the response should be expanded.



181
182
183
# File 'lib/stripe/params/issuing/card_create_params.rb', line 181

def expand
  @expand
end

#financial_accountObject

The new financial account ID the card will be associated with. This field allows a card to be reassigned to a different financial account.



183
184
185
# File 'lib/stripe/params/issuing/card_create_params.rb', line 183

def 
  @financial_account
end

#lifecycle_controlsObject

Rules that control the lifecycle of this card, such as automatic cancellation. Refer to our documentation for more details.



185
186
187
# File 'lib/stripe/params/issuing/card_create_params.rb', line 185

def lifecycle_controls
  @lifecycle_controls
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.



187
188
189
# File 'lib/stripe/params/issuing/card_create_params.rb', line 187

def 
  @metadata
end

#personalization_designObject

The personalization design object belonging to this card.



189
190
191
# File 'lib/stripe/params/issuing/card_create_params.rb', line 189

def personalization_design
  @personalization_design
end

#pinObject

The desired PIN for this card.



191
192
193
# File 'lib/stripe/params/issuing/card_create_params.rb', line 191

def pin
  @pin
end

#replacement_forObject

The card this is meant to be a replacement for (if any).



193
194
195
# File 'lib/stripe/params/issuing/card_create_params.rb', line 193

def replacement_for
  @replacement_for
end

#replacement_reasonObject

If replacement_for is specified, this should indicate why that card is being replaced.



195
196
197
# File 'lib/stripe/params/issuing/card_create_params.rb', line 195

def replacement_reason
  @replacement_reason
end

#second_lineObject

The second line to print on the card. Max length: 24 characters.



197
198
199
# File 'lib/stripe/params/issuing/card_create_params.rb', line 197

def second_line
  @second_line
end

#shippingObject

The address where the card will be shipped.



199
200
201
# File 'lib/stripe/params/issuing/card_create_params.rb', line 199

def shipping
  @shipping
end

#spending_controlsObject

Rules that control spending for this card. Refer to our documentation for more details.



201
202
203
# File 'lib/stripe/params/issuing/card_create_params.rb', line 201

def spending_controls
  @spending_controls
end

#statusObject

Whether authorizations can be approved on this card. May be blocked from activating cards depending on past-due Cardholder requirements. Defaults to inactive.



203
204
205
# File 'lib/stripe/params/issuing/card_create_params.rb', line 203

def status
  @status
end

#typeObject

The type of card to issue. Possible values are physical or virtual.



205
206
207
# File 'lib/stripe/params/issuing/card_create_params.rb', line 205

def type
  @type
end