Class: Stripe::Issuing::CardCreateParams::LifecycleControls::CancelAfter
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::CardCreateParams::LifecycleControls::CancelAfter
- Defined in:
- lib/stripe/params/issuing/card_create_params.rb
Instance Attribute Summary collapse
-
#payment_count ⇒ Object
The card is automatically cancelled when it makes this number of non-zero payment authorizations and transactions.
Instance Method Summary collapse
-
#initialize(payment_count: nil) ⇒ CancelAfter
constructor
A new instance of CancelAfter.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(payment_count: nil) ⇒ CancelAfter
Returns a new instance of CancelAfter.
12 13 14 |
# File 'lib/stripe/params/issuing/card_create_params.rb', line 12 def initialize(payment_count: nil) @payment_count = payment_count end |
Instance Attribute Details
#payment_count ⇒ Object
The card is automatically cancelled when it makes this number of non-zero payment authorizations and transactions. The count includes penny authorizations, but doesn’t include non-payment actions, such as authorization advice.
10 11 12 |
# File 'lib/stripe/params/issuing/card_create_params.rb', line 10 def payment_count @payment_count end |