Class: Stripe::Issuing::CardCreateParams::Shipping
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::CardCreateParams::Shipping
- Defined in:
- lib/stripe/params/issuing/card_create_params.rb
Defined Under Namespace
Classes: Address, AddressValidation, Customs
Instance Attribute Summary collapse
-
#address ⇒ Object
The address that the card is shipped to.
-
#address_validation ⇒ Object
Address validation settings.
-
#customs ⇒ Object
Customs information for the shipment.
-
#name ⇒ Object
The name printed on the shipping label when shipping the card.
-
#phone_number ⇒ Object
Phone number of the recipient of the shipment.
-
#require_signature ⇒ Object
Whether a signature is required for card delivery.
-
#service ⇒ Object
Shipment service.
-
#type ⇒ Object
Packaging options.
Instance Method Summary collapse
-
#initialize(address: nil, address_validation: nil, customs: nil, name: nil, phone_number: nil, require_signature: nil, service: nil, type: nil) ⇒ Shipping
constructor
A new instance of Shipping.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(address: nil, address_validation: nil, customs: nil, name: nil, phone_number: nil, require_signature: nil, service: nil, type: nil) ⇒ Shipping
Returns a new instance of Shipping.
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/stripe/params/issuing/card_create_params.rb', line 99 def initialize( address: nil, address_validation: nil, customs: nil, name: nil, phone_number: nil, require_signature: nil, service: nil, type: nil ) @address = address @address_validation = address_validation @customs = customs @name = name @phone_number = phone_number @require_signature = require_signature @service = service @type = type end |
Instance Attribute Details
#address ⇒ Object
The address that the card is shipped to.
83 84 85 |
# File 'lib/stripe/params/issuing/card_create_params.rb', line 83 def address @address end |
#address_validation ⇒ Object
Address validation settings.
85 86 87 |
# File 'lib/stripe/params/issuing/card_create_params.rb', line 85 def address_validation @address_validation end |
#customs ⇒ Object
Customs information for the shipment.
87 88 89 |
# File 'lib/stripe/params/issuing/card_create_params.rb', line 87 def customs @customs end |
#name ⇒ Object
The name printed on the shipping label when shipping the card.
89 90 91 |
# File 'lib/stripe/params/issuing/card_create_params.rb', line 89 def name @name end |
#phone_number ⇒ Object
Phone number of the recipient of the shipment.
91 92 93 |
# File 'lib/stripe/params/issuing/card_create_params.rb', line 91 def phone_number @phone_number end |
#require_signature ⇒ Object
Whether a signature is required for card delivery.
93 94 95 |
# File 'lib/stripe/params/issuing/card_create_params.rb', line 93 def require_signature @require_signature end |
#service ⇒ Object
Shipment service.
95 96 97 |
# File 'lib/stripe/params/issuing/card_create_params.rb', line 95 def service @service end |
#type ⇒ Object
Packaging options.
97 98 99 |
# File 'lib/stripe/params/issuing/card_create_params.rb', line 97 def type @type end |