Class: Stripe::Issuing::CardCreateParams::SpendingControls::SpendingLimit

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/issuing/card_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, categories: nil, interval: nil) ⇒ SpendingLimit

Returns a new instance of SpendingLimit.



133
134
135
136
137
# File 'lib/stripe/params/issuing/card_create_params.rb', line 133

def initialize(amount: nil, categories: nil, interval: nil)
  @amount = amount
  @categories = categories
  @interval = interval
end

Instance Attribute Details

#amountObject

Maximum amount allowed to spend per interval.



127
128
129
# File 'lib/stripe/params/issuing/card_create_params.rb', line 127

def amount
  @amount
end

#categoriesObject

Array of strings containing categories this limit applies to. Omitting this field will apply the limit to all categories.



129
130
131
# File 'lib/stripe/params/issuing/card_create_params.rb', line 129

def categories
  @categories
end

#intervalObject

Interval (or event) to which the amount applies.



131
132
133
# File 'lib/stripe/params/issuing/card_create_params.rb', line 131

def interval
  @interval
end