Class: Stripe::Issuing::CardListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::CardListParams
- Defined in:
- lib/stripe/params/issuing/card_list_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#cardholder ⇒ Object
Only return cards belonging to the Cardholder with the provided ID.
-
#created ⇒ Object
Only return cards that were issued during the given date interval.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#exp_month ⇒ Object
Only return cards that have the given expiration month.
-
#exp_year ⇒ Object
Only return cards that have the given expiration year.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#last4 ⇒ Object
Only return cards that have the given last four digits.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#personalization_design ⇒ Object
Attribute for param field personalization_design.
-
#starting_after ⇒ Object
A cursor for use in pagination.
-
#status ⇒ Object
Only return cards that have the given status.
-
#type ⇒ Object
Only return cards that have the given type.
-
#wallets ⇒ Object
Filter cards by wallet settings.
Instance Method Summary collapse
-
#initialize(cardholder: nil, created: nil, ending_before: nil, exp_month: nil, exp_year: nil, expand: nil, last4: nil, limit: nil, personalization_design: nil, starting_after: nil, status: nil, type: nil, wallets: nil) ⇒ CardListParams
constructor
A new instance of CardListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(cardholder: nil, created: nil, ending_before: nil, exp_month: nil, exp_year: nil, expand: nil, last4: nil, limit: nil, personalization_design: nil, starting_after: nil, status: nil, type: nil, wallets: nil) ⇒ CardListParams
Returns a new instance of CardListParams.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/stripe/params/issuing/card_list_params.rb', line 80 def initialize( cardholder: nil, created: nil, ending_before: nil, exp_month: nil, exp_year: nil, expand: nil, last4: nil, limit: nil, personalization_design: nil, starting_after: nil, status: nil, type: nil, wallets: nil ) @cardholder = cardholder @created = created @ending_before = ending_before @exp_month = exp_month @exp_year = exp_year @expand = @last4 = last4 @limit = limit @personalization_design = personalization_design @starting_after = starting_after @status = status @type = type @wallets = wallets end |
Instance Attribute Details
#cardholder ⇒ Object
Only return cards belonging to the Cardholder with the provided ID.
54 55 56 |
# File 'lib/stripe/params/issuing/card_list_params.rb', line 54 def cardholder @cardholder end |
#created ⇒ Object
Only return cards that were issued during the given date interval.
56 57 58 |
# File 'lib/stripe/params/issuing/card_list_params.rb', line 56 def created @created end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
58 59 60 |
# File 'lib/stripe/params/issuing/card_list_params.rb', line 58 def ending_before @ending_before end |
#exp_month ⇒ Object
Only return cards that have the given expiration month.
60 61 62 |
# File 'lib/stripe/params/issuing/card_list_params.rb', line 60 def exp_month @exp_month end |
#exp_year ⇒ Object
Only return cards that have the given expiration year.
62 63 64 |
# File 'lib/stripe/params/issuing/card_list_params.rb', line 62 def exp_year @exp_year end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
64 65 66 |
# File 'lib/stripe/params/issuing/card_list_params.rb', line 64 def @expand end |
#last4 ⇒ Object
Only return cards that have the given last four digits.
66 67 68 |
# File 'lib/stripe/params/issuing/card_list_params.rb', line 66 def last4 @last4 end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
68 69 70 |
# File 'lib/stripe/params/issuing/card_list_params.rb', line 68 def limit @limit end |
#personalization_design ⇒ Object
Attribute for param field personalization_design
70 71 72 |
# File 'lib/stripe/params/issuing/card_list_params.rb', line 70 def personalization_design @personalization_design end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
72 73 74 |
# File 'lib/stripe/params/issuing/card_list_params.rb', line 72 def starting_after @starting_after end |
#status ⇒ Object
Only return cards that have the given status. One of ‘active`, `inactive`, or `canceled`.
74 75 76 |
# File 'lib/stripe/params/issuing/card_list_params.rb', line 74 def status @status end |
#type ⇒ Object
Only return cards that have the given type. One of ‘virtual` or `physical`.
76 77 78 |
# File 'lib/stripe/params/issuing/card_list_params.rb', line 76 def type @type end |
#wallets ⇒ Object
Filter cards by wallet settings.
78 79 80 |
# File 'lib/stripe/params/issuing/card_list_params.rb', line 78 def wallets @wallets end |