Class: Stripe::Issuing::CardService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::CardService::CreateParams
- Defined in:
- lib/stripe/services/issuing/card_service.rb
Defined Under Namespace
Classes: Pin, Shipping, SpendingControls
Instance Attribute Summary collapse
-
#cardholder ⇒ Object
The [Cardholder](stripe.com/docs/api#issuing_cardholder_object) object with which the card will be associated.
-
#currency ⇒ Object
The currency for the card.
-
#exp_month ⇒ Object
The desired expiration month (1-12) for this card if [specifying a custom expiration date](/issuing/cards/virtual/issue-cards?testing-method=with-code#exp-dates).
-
#exp_year ⇒ Object
The desired 4-digit expiration year for this card if [specifying a custom expiration date](/issuing/cards/virtual/issue-cards?testing-method=with-code#exp-dates).
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#financial_account ⇒ Object
The new financial account ID the card will be associated with.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#personalization_design ⇒ Object
The personalization design object belonging to this card.
-
#pin ⇒ Object
The desired PIN for this card.
-
#replacement_for ⇒ Object
The card this is meant to be a replacement for (if any).
-
#replacement_reason ⇒ Object
If ‘replacement_for` is specified, this should indicate why that card is being replaced.
-
#second_line ⇒ Object
The second line to print on the card.
-
#shipping ⇒ Object
The address where the card will be shipped.
-
#spending_controls ⇒ Object
Rules that control spending for this card.
-
#status ⇒ Object
Whether authorizations can be approved on this card.
-
#type ⇒ Object
The type of card to issue.
Instance Method Summary collapse
-
#initialize(cardholder: nil, currency: nil, exp_month: nil, exp_year: nil, expand: nil, financial_account: nil, metadata: nil, personalization_design: nil, pin: nil, replacement_for: nil, replacement_reason: nil, second_line: nil, shipping: nil, spending_controls: nil, status: nil, type: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(cardholder: nil, currency: nil, exp_month: nil, exp_year: nil, expand: nil, financial_account: nil, metadata: nil, personalization_design: nil, pin: nil, replacement_for: nil, replacement_reason: nil, second_line: nil, shipping: nil, spending_controls: nil, status: nil, type: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 |
# File 'lib/stripe/services/issuing/card_service.rb', line 249 def initialize( cardholder: nil, currency: nil, exp_month: nil, exp_year: nil, expand: nil, financial_account: nil, metadata: nil, personalization_design: nil, pin: nil, replacement_for: nil, replacement_reason: nil, second_line: nil, shipping: nil, spending_controls: nil, status: nil, type: nil ) @cardholder = cardholder @currency = currency @exp_month = exp_month @exp_year = exp_year @expand = @financial_account = financial_account @metadata = @personalization_design = personalization_design @pin = pin @replacement_for = replacement_for @replacement_reason = replacement_reason @second_line = second_line @shipping = shipping @spending_controls = spending_controls @status = status @type = type end |
Instance Attribute Details
#cardholder ⇒ Object
The [Cardholder](stripe.com/docs/api#issuing_cardholder_object) object with which the card will be associated.
217 218 219 |
# File 'lib/stripe/services/issuing/card_service.rb', line 217 def cardholder @cardholder end |
#currency ⇒ Object
The currency for the card.
219 220 221 |
# File 'lib/stripe/services/issuing/card_service.rb', line 219 def currency @currency end |
#exp_month ⇒ Object
The desired expiration month (1-12) for this card if [specifying a custom expiration date](/issuing/cards/virtual/issue-cards?testing-method=with-code#exp-dates).
221 222 223 |
# File 'lib/stripe/services/issuing/card_service.rb', line 221 def exp_month @exp_month end |
#exp_year ⇒ Object
The desired 4-digit expiration year for this card if [specifying a custom expiration date](/issuing/cards/virtual/issue-cards?testing-method=with-code#exp-dates).
223 224 225 |
# File 'lib/stripe/services/issuing/card_service.rb', line 223 def exp_year @exp_year end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
225 226 227 |
# File 'lib/stripe/services/issuing/card_service.rb', line 225 def @expand end |
#financial_account ⇒ Object
The new financial account ID the card will be associated with. This field allows a card to be reassigned to a different financial account.
227 228 229 |
# File 'lib/stripe/services/issuing/card_service.rb', line 227 def financial_account @financial_account end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
229 230 231 |
# File 'lib/stripe/services/issuing/card_service.rb', line 229 def @metadata end |
#personalization_design ⇒ Object
The personalization design object belonging to this card.
231 232 233 |
# File 'lib/stripe/services/issuing/card_service.rb', line 231 def personalization_design @personalization_design end |
#pin ⇒ Object
The desired PIN for this card.
233 234 235 |
# File 'lib/stripe/services/issuing/card_service.rb', line 233 def pin @pin end |
#replacement_for ⇒ Object
The card this is meant to be a replacement for (if any).
235 236 237 |
# File 'lib/stripe/services/issuing/card_service.rb', line 235 def replacement_for @replacement_for end |
#replacement_reason ⇒ Object
If ‘replacement_for` is specified, this should indicate why that card is being replaced.
237 238 239 |
# File 'lib/stripe/services/issuing/card_service.rb', line 237 def replacement_reason @replacement_reason end |
#second_line ⇒ Object
The second line to print on the card. Max length: 24 characters.
239 240 241 |
# File 'lib/stripe/services/issuing/card_service.rb', line 239 def second_line @second_line end |
#shipping ⇒ Object
The address where the card will be shipped.
241 242 243 |
# File 'lib/stripe/services/issuing/card_service.rb', line 241 def shipping @shipping end |
#spending_controls ⇒ Object
Rules that control spending for this card. Refer to our [documentation](stripe.com/docs/issuing/controls/spending-controls) for more details.
243 244 245 |
# File 'lib/stripe/services/issuing/card_service.rb', line 243 def spending_controls @spending_controls end |
#status ⇒ Object
Whether authorizations can be approved on this card. May be blocked from activating cards depending on past-due Cardholder requirements. Defaults to ‘inactive`.
245 246 247 |
# File 'lib/stripe/services/issuing/card_service.rb', line 245 def status @status end |
#type ⇒ Object
The type of card to issue. Possible values are ‘physical` or `virtual`.
247 248 249 |
# File 'lib/stripe/services/issuing/card_service.rb', line 247 def type @type end |