Class: Stripe::Issuing::CardService::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/issuing/card_service.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(cardholder: nil, created: nil, ending_before: nil, exp_month: nil, exp_year: nil, expand: nil, last4: nil, limit: nil, personalization_design: nil, starting_after: nil, status: nil, type: nil) ⇒ ListParams

Returns a new instance of ListParams.



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/stripe/services/issuing/card_service.rb', line 64

def initialize(
  cardholder: nil,
  created: nil,
  ending_before: nil,
  exp_month: nil,
  exp_year: nil,
  expand: nil,
  last4: nil,
  limit: nil,
  personalization_design: nil,
  starting_after: nil,
  status: nil,
  type: nil
)
  @cardholder = cardholder
  @created = created
  @ending_before = ending_before
  @exp_month = exp_month
  @exp_year = exp_year
  @expand = expand
  @last4 = last4
  @limit = limit
  @personalization_design = personalization_design
  @starting_after = starting_after
  @status = status
  @type = type
end

Instance Attribute Details

#cardholderObject

Only return cards belonging to the Cardholder with the provided ID.



29
30
31
# File 'lib/stripe/services/issuing/card_service.rb', line 29

def cardholder
  @cardholder
end

#createdObject

Only return cards that were issued during the given date interval.



32
33
34
# File 'lib/stripe/services/issuing/card_service.rb', line 32

def created
  @created
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



35
36
37
# File 'lib/stripe/services/issuing/card_service.rb', line 35

def ending_before
  @ending_before
end

#exp_monthObject

Only return cards that have the given expiration month.



38
39
40
# File 'lib/stripe/services/issuing/card_service.rb', line 38

def exp_month
  @exp_month
end

#exp_yearObject

Only return cards that have the given expiration year.



41
42
43
# File 'lib/stripe/services/issuing/card_service.rb', line 41

def exp_year
  @exp_year
end

#expandObject

Specifies which fields in the response should be expanded.



44
45
46
# File 'lib/stripe/services/issuing/card_service.rb', line 44

def expand
  @expand
end

#last4Object

Only return cards that have the given last four digits.



47
48
49
# File 'lib/stripe/services/issuing/card_service.rb', line 47

def last4
  @last4
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



50
51
52
# File 'lib/stripe/services/issuing/card_service.rb', line 50

def limit
  @limit
end

#personalization_designObject

Attribute for param field personalization_design



53
54
55
# File 'lib/stripe/services/issuing/card_service.rb', line 53

def personalization_design
  @personalization_design
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



56
57
58
# File 'lib/stripe/services/issuing/card_service.rb', line 56

def starting_after
  @starting_after
end

#statusObject

Only return cards that have the given status. One of ‘active`, `inactive`, or `canceled`.



59
60
61
# File 'lib/stripe/services/issuing/card_service.rb', line 59

def status
  @status
end

#typeObject

Only return cards that have the given type. One of ‘virtual` or `physical`.



62
63
64
# File 'lib/stripe/services/issuing/card_service.rb', line 62

def type
  @type
end