Class: Stripe::Issuing::CardService::UpdateParams::Shipping
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::CardService::UpdateParams::Shipping
- Defined in:
- lib/stripe/services/issuing/card_service.rb
Defined Under Namespace
Classes: Address, AddressValidation, Customs
Instance Attribute Summary collapse
-
#address ⇒ Object
The address that the card is shipped to.
-
#address_validation ⇒ Object
Address validation settings.
-
#customs ⇒ Object
Customs information for the shipment.
-
#name ⇒ Object
The name printed on the shipping label when shipping the card.
-
#phone_number ⇒ Object
Phone number of the recipient of the shipment.
-
#require_signature ⇒ Object
Whether a signature is required for card delivery.
-
#service ⇒ Object
Shipment service.
-
#type ⇒ Object
Packaging options.
Instance Method Summary collapse
-
#initialize(address: nil, address_validation: nil, customs: nil, name: nil, phone_number: nil, require_signature: nil, service: nil, type: nil) ⇒ Shipping
constructor
A new instance of Shipping.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, address_validation: nil, customs: nil, name: nil, phone_number: nil, require_signature: nil, service: nil, type: nil) ⇒ Shipping
Returns a new instance of Shipping.
420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 |
# File 'lib/stripe/services/issuing/card_service.rb', line 420 def initialize( address: nil, address_validation: nil, customs: nil, name: nil, phone_number: nil, require_signature: nil, service: nil, type: nil ) @address = address @address_validation = address_validation @customs = customs @name = name @phone_number = phone_number @require_signature = require_signature @service = service @type = type end |
Instance Attribute Details
#address ⇒ Object
The address that the card is shipped to.
397 398 399 |
# File 'lib/stripe/services/issuing/card_service.rb', line 397 def address @address end |
#address_validation ⇒ Object
Address validation settings.
400 401 402 |
# File 'lib/stripe/services/issuing/card_service.rb', line 400 def address_validation @address_validation end |
#customs ⇒ Object
Customs information for the shipment.
403 404 405 |
# File 'lib/stripe/services/issuing/card_service.rb', line 403 def customs @customs end |
#name ⇒ Object
The name printed on the shipping label when shipping the card.
406 407 408 |
# File 'lib/stripe/services/issuing/card_service.rb', line 406 def name @name end |
#phone_number ⇒ Object
Phone number of the recipient of the shipment.
409 410 411 |
# File 'lib/stripe/services/issuing/card_service.rb', line 409 def phone_number @phone_number end |
#require_signature ⇒ Object
Whether a signature is required for card delivery.
412 413 414 |
# File 'lib/stripe/services/issuing/card_service.rb', line 412 def require_signature @require_signature end |
#service ⇒ Object
Shipment service.
415 416 417 |
# File 'lib/stripe/services/issuing/card_service.rb', line 415 def service @service end |
#type ⇒ Object
Packaging options.
418 419 420 |
# File 'lib/stripe/services/issuing/card_service.rb', line 418 def type @type end |