Class: Stripe::Issuing::Cardholder::CreateParams::SpendingControls

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/issuing/cardholder.rb

Defined Under Namespace

Classes: SpendingLimit

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(allowed_categories: nil, allowed_merchant_countries: nil, blocked_categories: nil, blocked_merchant_countries: nil, spending_limits: nil, spending_limits_currency: nil) ⇒ SpendingControls

Returns a new instance of SpendingControls.



435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
# File 'lib/stripe/resources/issuing/cardholder.rb', line 435

def initialize(
  allowed_categories: nil,
  allowed_merchant_countries: nil,
  blocked_categories: nil,
  blocked_merchant_countries: nil,
  spending_limits: nil,
  spending_limits_currency: nil
)
  @allowed_categories = allowed_categories
  @allowed_merchant_countries = allowed_merchant_countries
  @blocked_categories = blocked_categories
  @blocked_merchant_countries = blocked_merchant_countries
  @spending_limits = spending_limits
  @spending_limits_currency = spending_limits_currency
end

Instance Attribute Details

#allowed_categoriesObject

Array of strings containing [categories](stripe.com/docs/api#issuing_authorization_object-merchant_data-category) of authorizations to allow. All other categories will be blocked. Cannot be set with ‘blocked_categories`.



423
424
425
# File 'lib/stripe/resources/issuing/cardholder.rb', line 423

def allowed_categories
  @allowed_categories
end

#allowed_merchant_countriesObject

Array of strings containing representing countries from which authorizations will be allowed. Authorizations from merchants in all other countries will be declined. Country codes should be ISO 3166 alpha-2 country codes (e.g. ‘US`). Cannot be set with `blocked_merchant_countries`. Provide an empty value to unset this control.



425
426
427
# File 'lib/stripe/resources/issuing/cardholder.rb', line 425

def allowed_merchant_countries
  @allowed_merchant_countries
end

#blocked_categoriesObject

Array of strings containing [categories](stripe.com/docs/api#issuing_authorization_object-merchant_data-category) of authorizations to decline. All other categories will be allowed. Cannot be set with ‘allowed_categories`.



427
428
429
# File 'lib/stripe/resources/issuing/cardholder.rb', line 427

def blocked_categories
  @blocked_categories
end

#blocked_merchant_countriesObject

Array of strings containing representing countries from which authorizations will be declined. Country codes should be ISO 3166 alpha-2 country codes (e.g. ‘US`). Cannot be set with `allowed_merchant_countries`. Provide an empty value to unset this control.



429
430
431
# File 'lib/stripe/resources/issuing/cardholder.rb', line 429

def blocked_merchant_countries
  @blocked_merchant_countries
end

#spending_limitsObject

Limit spending with amount-based rules that apply across this cardholder’s cards.



431
432
433
# File 'lib/stripe/resources/issuing/cardholder.rb', line 431

def spending_limits
  @spending_limits
end

#spending_limits_currencyObject

Currency of amounts within ‘spending_limits`. Defaults to your merchant country’s currency.



433
434
435
# File 'lib/stripe/resources/issuing/cardholder.rb', line 433

def spending_limits_currency
  @spending_limits_currency
end