Class: Stripe::Issuing::Cardholder::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::Cardholder::ListParams
- Defined in:
- lib/stripe/resources/issuing/cardholder.rb
Defined Under Namespace
Classes: Created
Instance Attribute Summary collapse
-
#created ⇒ Object
Only return cardholders that were created during the given date interval.
-
#email ⇒ Object
Only return cardholders that have the given email address.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#phone_number ⇒ Object
Only return cardholders that have the given phone number.
-
#starting_after ⇒ Object
A cursor for use in pagination.
-
#status ⇒ Object
Only return cardholders that have the given status.
-
#type ⇒ Object
Only return cardholders that have the given type.
Instance Method Summary collapse
-
#initialize(created: nil, email: nil, ending_before: nil, expand: nil, limit: nil, phone_number: nil, starting_after: nil, status: nil, type: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(created: nil, email: nil, ending_before: nil, expand: nil, limit: nil, phone_number: nil, starting_after: nil, status: nil, type: nil) ⇒ ListParams
Returns a new instance of ListParams.
251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 251 def initialize( created: nil, email: nil, ending_before: nil, expand: nil, limit: nil, phone_number: nil, starting_after: nil, status: nil, type: nil ) @created = created @email = email @ending_before = ending_before @expand = @limit = limit @phone_number = phone_number @starting_after = starting_after @status = status @type = type end |
Instance Attribute Details
#created ⇒ Object
Only return cardholders that were created during the given date interval.
233 234 235 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 233 def created @created end |
#email ⇒ Object
Only return cardholders that have the given email address.
235 236 237 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 235 def email @email end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
237 238 239 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 237 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
239 240 241 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 239 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
241 242 243 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 241 def limit @limit end |
#phone_number ⇒ Object
Only return cardholders that have the given phone number.
243 244 245 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 243 def phone_number @phone_number end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
245 246 247 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 245 def starting_after @starting_after end |
#status ⇒ Object
Only return cardholders that have the given status. One of ‘active`, `inactive`, or `blocked`.
247 248 249 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 247 def status @status end |
#type ⇒ Object
Only return cardholders that have the given type. One of ‘individual` or `company`.
249 250 251 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 249 def type @type end |