Class: Stripe::Issuing::Cardholder::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/issuing/cardholder.rb

Defined Under Namespace

Classes: Billing, Company, Individual, SpendingControls

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing: nil, company: nil, email: nil, expand: nil, individual: nil, metadata: nil, phone_number: nil, preferred_locales: nil, spending_controls: nil, status: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
# File 'lib/stripe/resources/issuing/cardholder.rb', line 610

def initialize(
  billing: nil,
  company: nil,
  email: nil,
  expand: nil,
  individual: nil,
  metadata: nil,
  phone_number: nil,
  preferred_locales: nil,
  spending_controls: nil,
  status: nil
)
  @billing = billing
  @company = company
  @email = email
  @expand = expand
  @individual = individual
  @metadata = 
  @phone_number = phone_number
  @preferred_locales = preferred_locales
  @spending_controls = spending_controls
  @status = status
end

Instance Attribute Details

#billingObject

The cardholder’s billing address.



589
590
591
# File 'lib/stripe/resources/issuing/cardholder.rb', line 589

def billing
  @billing
end

#companyObject

Additional information about a ‘company` cardholder.



591
592
593
# File 'lib/stripe/resources/issuing/cardholder.rb', line 591

def company
  @company
end

#emailObject

The cardholder’s email address.



593
594
595
# File 'lib/stripe/resources/issuing/cardholder.rb', line 593

def email
  @email
end

#expandObject

Specifies which fields in the response should be expanded.



595
596
597
# File 'lib/stripe/resources/issuing/cardholder.rb', line 595

def expand
  @expand
end

#individualObject

Additional information about an ‘individual` cardholder.



597
598
599
# File 'lib/stripe/resources/issuing/cardholder.rb', line 597

def individual
  @individual
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



599
600
601
# File 'lib/stripe/resources/issuing/cardholder.rb', line 599

def 
  @metadata
end

#phone_numberObject

The cardholder’s phone number. This is required for all cardholders who will be creating EU cards. See the [3D Secure documentation](stripe.com/docs/issuing/3d-secure) for more details.



601
602
603
# File 'lib/stripe/resources/issuing/cardholder.rb', line 601

def phone_number
  @phone_number
end

#preferred_localesObject

The cardholder’s preferred locales (languages), ordered by preference. Locales can be ‘de`, `en`, `es`, `fr`, or `it`.

This changes the language of the [3D Secure flow](https://stripe.com/docs/issuing/3d-secure) and one-time password messages sent to the cardholder.


604
605
606
# File 'lib/stripe/resources/issuing/cardholder.rb', line 604

def preferred_locales
  @preferred_locales
end

#spending_controlsObject

Rules that control spending across this cardholder’s cards. Refer to our [documentation](stripe.com/docs/issuing/controls/spending-controls) for more details.



606
607
608
# File 'lib/stripe/resources/issuing/cardholder.rb', line 606

def spending_controls
  @spending_controls
end

#statusObject

Specifies whether to permit authorizations on this cardholder’s cards.



608
609
610
# File 'lib/stripe/resources/issuing/cardholder.rb', line 608

def status
  @status
end