Class: Stripe::Issuing::Cardholder::UpdateParams::Individual
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::Cardholder::UpdateParams::Individual
- Defined in:
- lib/stripe/resources/issuing/cardholder.rb
Defined Under Namespace
Classes: CardIssuing, Dob, Verification
Instance Attribute Summary collapse
-
#card_issuing ⇒ Object
Information related to the card_issuing program for this cardholder.
-
#dob ⇒ Object
The date of birth of this cardholder.
-
#first_name ⇒ Object
The first name of this cardholder.
-
#last_name ⇒ Object
The last name of this cardholder.
-
#verification ⇒ Object
Government-issued ID document for this cardholder.
Instance Method Summary collapse
-
#initialize(card_issuing: nil, dob: nil, first_name: nil, last_name: nil, verification: nil) ⇒ Individual
constructor
A new instance of Individual.
Methods inherited from RequestParams
Constructor Details
#initialize(card_issuing: nil, dob: nil, first_name: nil, last_name: nil, verification: nil) ⇒ Individual
Returns a new instance of Individual.
529 530 531 532 533 534 535 536 537 538 539 540 541 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 529 def initialize( card_issuing: nil, dob: nil, first_name: nil, last_name: nil, verification: nil ) @card_issuing = card_issuing @dob = dob @first_name = first_name @last_name = last_name @verification = verification end |
Instance Attribute Details
#card_issuing ⇒ Object
Information related to the card_issuing program for this cardholder.
519 520 521 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 519 def card_issuing @card_issuing end |
#dob ⇒ Object
The date of birth of this cardholder. Cardholders must be older than 13 years old.
521 522 523 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 521 def dob @dob end |
#first_name ⇒ Object
The first name of this cardholder. Required before activating Cards. This field cannot contain any numbers, special characters (except periods, commas, hyphens, spaces and apostrophes) or non-latin letters.
523 524 525 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 523 def first_name @first_name end |
#last_name ⇒ Object
The last name of this cardholder. Required before activating Cards. This field cannot contain any numbers, special characters (except periods, commas, hyphens, spaces and apostrophes) or non-latin letters.
525 526 527 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 525 def last_name @last_name end |
#verification ⇒ Object
Government-issued ID document for this cardholder.
527 528 529 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 527 def verification @verification end |