Class: Stripe::Issuing::Cardholder::UpdateParams::Individual::CardIssuing::UserTermsAcceptance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::Cardholder::UpdateParams::Individual::CardIssuing::UserTermsAcceptance
- Defined in:
- lib/stripe/resources/issuing/cardholder.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the cardholder accepted the Authorized User Terms.
-
#ip ⇒ Object
The IP address from which the cardholder accepted the Authorized User Terms.
-
#user_agent ⇒ Object
The user agent of the browser from which the cardholder accepted the Authorized User Terms.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ UserTermsAcceptance
constructor
A new instance of UserTermsAcceptance.
Methods inherited from RequestParams
Constructor Details
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ UserTermsAcceptance
Returns a new instance of UserTermsAcceptance.
479 480 481 482 483 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 479 def initialize(date: nil, ip: nil, user_agent: nil) @date = date @ip = ip @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the cardholder accepted the Authorized User Terms. Required for Celtic Spend Card users.
473 474 475 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 473 def date @date end |
#ip ⇒ Object
The IP address from which the cardholder accepted the Authorized User Terms. Required for Celtic Spend Card users.
475 476 477 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 475 def ip @ip end |
#user_agent ⇒ Object
The user agent of the browser from which the cardholder accepted the Authorized User Terms.
477 478 479 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 477 def user_agent @user_agent end |