Class: Stripe::Issuing::CardholderCreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/issuing/cardholder_create_params.rb

Defined Under Namespace

Classes: Billing, Company, Individual, SpendingControls

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(billing: nil, company: nil, email: nil, expand: nil, individual: nil, metadata: nil, name: nil, phone_number: nil, preferred_locales: nil, spending_controls: nil, status: nil, type: nil) ⇒ CardholderCreateParams

Returns a new instance of CardholderCreateParams.



218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
# File 'lib/stripe/params/issuing/cardholder_create_params.rb', line 218

def initialize(
  billing: nil,
  company: nil,
  email: nil,
  expand: nil,
  individual: nil,
  metadata: nil,
  name: nil,
  phone_number: nil,
  preferred_locales: nil,
  spending_controls: nil,
  status: nil,
  type: nil
)
  @billing = billing
  @company = company
  @email = email
  @expand = expand
  @individual = individual
  @metadata = 
  @name = name
  @phone_number = phone_number
  @preferred_locales = preferred_locales
  @spending_controls = spending_controls
  @status = status
  @type = type
end

Instance Attribute Details

#billingObject

The cardholder’s billing address.



192
193
194
# File 'lib/stripe/params/issuing/cardholder_create_params.rb', line 192

def billing
  @billing
end

#companyObject

Additional information about a ‘company` cardholder.



194
195
196
# File 'lib/stripe/params/issuing/cardholder_create_params.rb', line 194

def company
  @company
end

#emailObject

The cardholder’s email address.



196
197
198
# File 'lib/stripe/params/issuing/cardholder_create_params.rb', line 196

def email
  @email
end

#expandObject

Specifies which fields in the response should be expanded.



198
199
200
# File 'lib/stripe/params/issuing/cardholder_create_params.rb', line 198

def expand
  @expand
end

#individualObject

Additional information about an ‘individual` cardholder.



200
201
202
# File 'lib/stripe/params/issuing/cardholder_create_params.rb', line 200

def individual
  @individual
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



202
203
204
# File 'lib/stripe/params/issuing/cardholder_create_params.rb', line 202

def 
  @metadata
end

#nameObject

The cardholder’s name. This will be printed on cards issued to them. The maximum length of this field is 24 characters. This field cannot contain any special characters or numbers.



204
205
206
# File 'lib/stripe/params/issuing/cardholder_create_params.rb', line 204

def name
  @name
end

#phone_numberObject

The cardholder’s phone number. This will be transformed to [E.164](en.wikipedia.org/wiki/E.164) if it is not provided in that format already. This is required for all cardholders who will be creating EU cards.

While phone number is optional if the cardholder will not be creating EU cards, note that this cardholder will not be eligible for 3DS without a phone number. See the [3D Secure documentation](https://docs.stripe.com/issuing/3d-secure#when-is-3d-secure-applied) for more details.


207
208
209
# File 'lib/stripe/params/issuing/cardholder_create_params.rb', line 207

def phone_number
  @phone_number
end

#preferred_localesObject

The cardholder’s preferred locales (languages), ordered by preference. Locales can be ‘da`, `de`, `en`, `es`, `fr`, `it`, `pl`, or `sv`.

This changes the language of the [3D Secure flow](https://docs.stripe.com/issuing/3d-secure) and one-time password messages sent to the cardholder.


210
211
212
# File 'lib/stripe/params/issuing/cardholder_create_params.rb', line 210

def preferred_locales
  @preferred_locales
end

#spending_controlsObject

Rules that control spending across this cardholder’s cards. Refer to our [documentation](docs.stripe.com/issuing/controls/spending-controls) for more details.



212
213
214
# File 'lib/stripe/params/issuing/cardholder_create_params.rb', line 212

def spending_controls
  @spending_controls
end

#statusObject

Specifies whether to permit authorizations on this cardholder’s cards. Defaults to ‘active`.



214
215
216
# File 'lib/stripe/params/issuing/cardholder_create_params.rb', line 214

def status
  @status
end

#typeObject

One of ‘individual` or `company`. See [Choose a cardholder type](docs.stripe.com/issuing/other/choose-cardholder) for more details.



216
217
218
# File 'lib/stripe/params/issuing/cardholder_create_params.rb', line 216

def type
  @type
end