Class: Stripe::Issuing::CardholderService::ListParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/issuing/cardholder_service.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(created: nil, email: nil, ending_before: nil, expand: nil, limit: nil, phone_number: nil, starting_after: nil, status: nil, type: nil) ⇒ ListParams

Returns a new instance of ListParams.



55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/stripe/services/issuing/cardholder_service.rb', line 55

def initialize(
  created: nil,
  email: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  phone_number: nil,
  starting_after: nil,
  status: nil,
  type: nil
)
  @created = created
  @email = email
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @phone_number = phone_number
  @starting_after = starting_after
  @status = status
  @type = type
end

Instance Attribute Details

#createdObject

Only return cardholders that were created during the given date interval.



29
30
31
# File 'lib/stripe/services/issuing/cardholder_service.rb', line 29

def created
  @created
end

#emailObject

Only return cardholders that have the given email address.



32
33
34
# File 'lib/stripe/services/issuing/cardholder_service.rb', line 32

def email
  @email
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



35
36
37
# File 'lib/stripe/services/issuing/cardholder_service.rb', line 35

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



38
39
40
# File 'lib/stripe/services/issuing/cardholder_service.rb', line 38

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



41
42
43
# File 'lib/stripe/services/issuing/cardholder_service.rb', line 41

def limit
  @limit
end

#phone_numberObject

Only return cardholders that have the given phone number.



44
45
46
# File 'lib/stripe/services/issuing/cardholder_service.rb', line 44

def phone_number
  @phone_number
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



47
48
49
# File 'lib/stripe/services/issuing/cardholder_service.rb', line 47

def starting_after
  @starting_after
end

#statusObject

Only return cardholders that have the given status. One of ‘active`, `inactive`, or `blocked`.



50
51
52
# File 'lib/stripe/services/issuing/cardholder_service.rb', line 50

def status
  @status
end

#typeObject

Only return cardholders that have the given type. One of ‘individual` or `company`.



53
54
55
# File 'lib/stripe/services/issuing/cardholder_service.rb', line 53

def type
  @type
end