Class: Stripe::Issuing::CardholderService::UpdateParams::SpendingControls
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::CardholderService::UpdateParams::SpendingControls
- Defined in:
- lib/stripe/services/issuing/cardholder_service.rb
Defined Under Namespace
Classes: SpendingLimit
Instance Attribute Summary collapse
-
#allowed_categories ⇒ Object
Array of strings containing [categories](stripe.com/docs/api#issuing_authorization_object-merchant_data-category) of authorizations to allow.
-
#allowed_merchant_countries ⇒ Object
Array of strings containing representing countries from which authorizations will be allowed.
-
#blocked_categories ⇒ Object
Array of strings containing [categories](stripe.com/docs/api#issuing_authorization_object-merchant_data-category) of authorizations to decline.
-
#blocked_merchant_countries ⇒ Object
Array of strings containing representing countries from which authorizations will be declined.
-
#spending_limits ⇒ Object
Limit spending with amount-based rules that apply across this cardholder’s cards.
-
#spending_limits_currency ⇒ Object
Currency of amounts within ‘spending_limits`.
Instance Method Summary collapse
-
#initialize(allowed_categories: nil, allowed_merchant_countries: nil, blocked_categories: nil, blocked_merchant_countries: nil, spending_limits: nil, spending_limits_currency: nil) ⇒ SpendingControls
constructor
A new instance of SpendingControls.
Methods inherited from RequestParams
Constructor Details
#initialize(allowed_categories: nil, allowed_merchant_countries: nil, blocked_categories: nil, blocked_merchant_countries: nil, spending_limits: nil, spending_limits_currency: nil) ⇒ SpendingControls
Returns a new instance of SpendingControls.
534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 |
# File 'lib/stripe/services/issuing/cardholder_service.rb', line 534 def initialize( allowed_categories: nil, allowed_merchant_countries: nil, blocked_categories: nil, blocked_merchant_countries: nil, spending_limits: nil, spending_limits_currency: nil ) @allowed_categories = allowed_categories @allowed_merchant_countries = allowed_merchant_countries @blocked_categories = blocked_categories @blocked_merchant_countries = blocked_merchant_countries @spending_limits = spending_limits @spending_limits_currency = spending_limits_currency end |
Instance Attribute Details
#allowed_categories ⇒ Object
Array of strings containing [categories](stripe.com/docs/api#issuing_authorization_object-merchant_data-category) of authorizations to allow. All other categories will be blocked. Cannot be set with ‘blocked_categories`.
517 518 519 |
# File 'lib/stripe/services/issuing/cardholder_service.rb', line 517 def allowed_categories @allowed_categories end |
#allowed_merchant_countries ⇒ Object
Array of strings containing representing countries from which authorizations will be allowed. Authorizations from merchants in all other countries will be declined. Country codes should be ISO 3166 alpha-2 country codes (e.g. ‘US`). Cannot be set with `blocked_merchant_countries`. Provide an empty value to unset this control.
520 521 522 |
# File 'lib/stripe/services/issuing/cardholder_service.rb', line 520 def allowed_merchant_countries @allowed_merchant_countries end |
#blocked_categories ⇒ Object
Array of strings containing [categories](stripe.com/docs/api#issuing_authorization_object-merchant_data-category) of authorizations to decline. All other categories will be allowed. Cannot be set with ‘allowed_categories`.
523 524 525 |
# File 'lib/stripe/services/issuing/cardholder_service.rb', line 523 def blocked_categories @blocked_categories end |
#blocked_merchant_countries ⇒ Object
Array of strings containing representing countries from which authorizations will be declined. Country codes should be ISO 3166 alpha-2 country codes (e.g. ‘US`). Cannot be set with `allowed_merchant_countries`. Provide an empty value to unset this control.
526 527 528 |
# File 'lib/stripe/services/issuing/cardholder_service.rb', line 526 def blocked_merchant_countries @blocked_merchant_countries end |
#spending_limits ⇒ Object
Limit spending with amount-based rules that apply across this cardholder’s cards.
529 530 531 |
# File 'lib/stripe/services/issuing/cardholder_service.rb', line 529 def spending_limits @spending_limits end |
#spending_limits_currency ⇒ Object
Currency of amounts within ‘spending_limits`. Defaults to your merchant country’s currency.
532 533 534 |
# File 'lib/stripe/services/issuing/cardholder_service.rb', line 532 def spending_limits_currency @spending_limits_currency end |