Class: Stripe::Issuing::CreditUnderwritingRecord::CorrectParams::Decision::CreditLimitDecreased

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/issuing/credit_underwriting_record.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, currency: nil, reason_other_explanation: nil, reasons: nil) ⇒ CreditLimitDecreased

Returns a new instance of CreditLimitDecreased.



234
235
236
237
238
239
# File 'lib/stripe/resources/issuing/credit_underwriting_record.rb', line 234

def initialize(amount: nil, currency: nil, reason_other_explanation: nil, reasons: nil)
  @amount = amount
  @currency = currency
  @reason_other_explanation = reason_other_explanation
  @reasons = reasons
end

Instance Attribute Details

#amountObject

The credit approved, in the currency of the account and [smallest currency unit](stripe.com/docs/currencies#zero-decimal).



226
227
228
# File 'lib/stripe/resources/issuing/credit_underwriting_record.rb', line 226

def amount
  @amount
end

#currencyObject

The currency of the credit approved, will default to the Account’s Issuing currency.



228
229
230
# File 'lib/stripe/resources/issuing/credit_underwriting_record.rb', line 228

def currency
  @currency
end

#reason_other_explanationObject

Details about the ‘reasons.other` when present.



230
231
232
# File 'lib/stripe/resources/issuing/credit_underwriting_record.rb', line 230

def reason_other_explanation
  @reason_other_explanation
end

#reasonsObject

List of reasons why the existing credit was decreased, up to 4 reasons, in order of importance.



232
233
234
# File 'lib/stripe/resources/issuing/credit_underwriting_record.rb', line 232

def reasons
  @reasons
end