Class: Stripe::Issuing::CreditUnderwritingRecord::CorrectParams::Decision::CreditLineClosed
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::CreditUnderwritingRecord::CorrectParams::Decision::CreditLineClosed
- Defined in:
- lib/stripe/resources/issuing/credit_underwriting_record.rb
Instance Attribute Summary collapse
-
#reason_other_explanation ⇒ Object
Details about the ‘reasons.other` when present.
-
#reasons ⇒ Object
List of reasons why the credit line was closed, up to 4 reasons, in order of importance.
Instance Method Summary collapse
-
#initialize(reason_other_explanation: nil, reasons: nil) ⇒ CreditLineClosed
constructor
A new instance of CreditLineClosed.
Methods inherited from RequestParams
Constructor Details
#initialize(reason_other_explanation: nil, reasons: nil) ⇒ CreditLineClosed
Returns a new instance of CreditLineClosed.
179 180 181 182 |
# File 'lib/stripe/resources/issuing/credit_underwriting_record.rb', line 179 def initialize(reason_other_explanation: nil, reasons: nil) @reason_other_explanation = reason_other_explanation @reasons = reasons end |
Instance Attribute Details
#reason_other_explanation ⇒ Object
Details about the ‘reasons.other` when present.
175 176 177 |
# File 'lib/stripe/resources/issuing/credit_underwriting_record.rb', line 175 def reason_other_explanation @reason_other_explanation end |
#reasons ⇒ Object
List of reasons why the credit line was closed, up to 4 reasons, in order of importance.
177 178 179 |
# File 'lib/stripe/resources/issuing/credit_underwriting_record.rb', line 177 def reasons @reasons end |