Class: Stripe::Issuing::CreditUnderwritingRecord::CreateFromProactiveReviewParams::Decision::CreditLimitDecreased
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::CreditUnderwritingRecord::CreateFromProactiveReviewParams::Decision::CreditLimitDecreased
- Defined in:
- lib/stripe/resources/issuing/credit_underwriting_record.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The credit approved, in the currency of the account and [smallest currency unit](stripe.com/docs/currencies#zero-decimal).
-
#currency ⇒ Object
The currency of the credit approved, will default to the Account’s Issuing currency.
-
#reason_other_explanation ⇒ Object
Details about the ‘reasons.other` when present.
-
#reasons ⇒ Object
List of reasons why the existing credit was decreased, up to 4 reasons, in order of importance.
Instance Method Summary collapse
-
#initialize(amount: nil, currency: nil, reason_other_explanation: nil, reasons: nil) ⇒ CreditLimitDecreased
constructor
A new instance of CreditLimitDecreased.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, currency: nil, reason_other_explanation: nil, reasons: nil) ⇒ CreditLimitDecreased
Returns a new instance of CreditLimitDecreased.
419 420 421 422 423 424 |
# File 'lib/stripe/resources/issuing/credit_underwriting_record.rb', line 419 def initialize(amount: nil, currency: nil, reason_other_explanation: nil, reasons: nil) @amount = amount @currency = currency @reason_other_explanation = reason_other_explanation @reasons = reasons end |
Instance Attribute Details
#amount ⇒ Object
The credit approved, in the currency of the account and [smallest currency unit](stripe.com/docs/currencies#zero-decimal).
411 412 413 |
# File 'lib/stripe/resources/issuing/credit_underwriting_record.rb', line 411 def amount @amount end |
#currency ⇒ Object
The currency of the credit approved, will default to the Account’s Issuing currency.
413 414 415 |
# File 'lib/stripe/resources/issuing/credit_underwriting_record.rb', line 413 def currency @currency end |
#reason_other_explanation ⇒ Object
Details about the ‘reasons.other` when present.
415 416 417 |
# File 'lib/stripe/resources/issuing/credit_underwriting_record.rb', line 415 def reason_other_explanation @reason_other_explanation end |
#reasons ⇒ Object
List of reasons why the existing credit was decreased, up to 4 reasons, in order of importance.
417 418 419 |
# File 'lib/stripe/resources/issuing/credit_underwriting_record.rb', line 417 def reasons @reasons end |