Class: Stripe::Issuing::CreditUnderwritingRecord::CreateFromProactiveReviewParams::Decision::CreditLineClosed
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::CreditUnderwritingRecord::CreateFromProactiveReviewParams::Decision::CreditLineClosed
- Defined in:
- lib/stripe/resources/issuing/credit_underwriting_record.rb
Instance Attribute Summary collapse
-
#reason_other_explanation ⇒ Object
Details about the ‘reasons.other` when present.
-
#reasons ⇒ Object
List of reasons why the credit line was closed, up to 4 reasons, in order of importance.
Instance Method Summary collapse
-
#initialize(reason_other_explanation: nil, reasons: nil) ⇒ CreditLineClosed
constructor
A new instance of CreditLineClosed.
Methods inherited from RequestParams
Constructor Details
#initialize(reason_other_explanation: nil, reasons: nil) ⇒ CreditLineClosed
Returns a new instance of CreditLineClosed.
442 443 444 445 |
# File 'lib/stripe/resources/issuing/credit_underwriting_record.rb', line 442 def initialize(reason_other_explanation: nil, reasons: nil) @reason_other_explanation = reason_other_explanation @reasons = reasons end |
Instance Attribute Details
#reason_other_explanation ⇒ Object
Details about the ‘reasons.other` when present.
438 439 440 |
# File 'lib/stripe/resources/issuing/credit_underwriting_record.rb', line 438 def reason_other_explanation @reason_other_explanation end |
#reasons ⇒ Object
List of reasons why the credit line was closed, up to 4 reasons, in order of importance.
440 441 442 |
# File 'lib/stripe/resources/issuing/credit_underwriting_record.rb', line 440 def reasons @reasons end |