Class: Stripe::Issuing::CreditUnderwritingRecord::Decision::CreditLimitDecreased

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/issuing/credit_underwriting_record.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Credit amount approved after decrease. An approved credit limit is required before you can set a amount in the [CreditPolicy API](stripe.com/docs/api/issuing/credit_policy).



50
51
52
# File 'lib/stripe/resources/issuing/credit_underwriting_record.rb', line 50

def amount
  @amount
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



52
53
54
# File 'lib/stripe/resources/issuing/credit_underwriting_record.rb', line 52

def currency
  @currency
end

#reason_other_explanationObject (readonly)

Details about the ‘reasons.other` when present.



54
55
56
# File 'lib/stripe/resources/issuing/credit_underwriting_record.rb', line 54

def reason_other_explanation
  @reason_other_explanation
end

#reasonsObject (readonly)

List of reasons why the existing credit was decreased, up to 4 reasons, in order of importance.



56
57
58
# File 'lib/stripe/resources/issuing/credit_underwriting_record.rb', line 56

def reasons
  @reasons
end