Class: Stripe::Issuing::CreditUnderwritingRecord::Decision::CreditLineClosed
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Issuing::CreditUnderwritingRecord::Decision::CreditLineClosed
- Defined in:
- lib/stripe/resources/issuing/credit_underwriting_record.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#reason_other_explanation ⇒ Object
readonly
Details about the ‘reasons.other` when present.
-
#reasons ⇒ Object
readonly
List of reasons why the existing account was closed, up to 4 reasons, in order of importance.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#reason_other_explanation ⇒ Object (readonly)
Details about the ‘reasons.other` when present.
61 62 63 |
# File 'lib/stripe/resources/issuing/credit_underwriting_record.rb', line 61 def reason_other_explanation @reason_other_explanation end |
#reasons ⇒ Object (readonly)
List of reasons why the existing account was closed, up to 4 reasons, in order of importance.
63 64 65 |
# File 'lib/stripe/resources/issuing/credit_underwriting_record.rb', line 63 def reasons @reasons end |