Class: Stripe::Issuing::CreditUnderwritingRecord::ReportDecisionParams::Decision::ApplicationRejected
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::CreditUnderwritingRecord::ReportDecisionParams::Decision::ApplicationRejected
- Defined in:
- lib/stripe/resources/issuing/credit_underwriting_record.rb
Instance Attribute Summary collapse
-
#reason_other_explanation ⇒ Object
Details about the ‘reasons.other` when present.
-
#reasons ⇒ Object
List of reasons why the application was rejected, up to 4 reasons, in order of importance.
Instance Method Summary collapse
-
#initialize(reason_other_explanation: nil, reasons: nil) ⇒ ApplicationRejected
constructor
A new instance of ApplicationRejected.
Methods inherited from RequestParams
Constructor Details
#initialize(reason_other_explanation: nil, reasons: nil) ⇒ ApplicationRejected
Returns a new instance of ApplicationRejected.
336 337 338 339 |
# File 'lib/stripe/resources/issuing/credit_underwriting_record.rb', line 336 def initialize(reason_other_explanation: nil, reasons: nil) @reason_other_explanation = reason_other_explanation @reasons = reasons end |
Instance Attribute Details
#reason_other_explanation ⇒ Object
Details about the ‘reasons.other` when present.
332 333 334 |
# File 'lib/stripe/resources/issuing/credit_underwriting_record.rb', line 332 def reason_other_explanation @reason_other_explanation end |
#reasons ⇒ Object
List of reasons why the application was rejected, up to 4 reasons, in order of importance.
334 335 336 |
# File 'lib/stripe/resources/issuing/credit_underwriting_record.rb', line 334 def reasons @reasons end |