Class: Stripe::Issuing::CreditUnderwritingRecordCorrectParams::Application
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::CreditUnderwritingRecordCorrectParams::Application
- Defined in:
- lib/stripe/params/issuing/credit_underwriting_record_correct_params.rb
Instance Attribute Summary collapse
-
#application_method ⇒ Object
The channel through which the applicant has submitted their application.
-
#purpose ⇒ Object
Scope of demand made by the applicant.
-
#submitted_at ⇒ Object
Date when the applicant submitted their application.
Instance Method Summary collapse
-
#initialize(application_method: nil, purpose: nil, submitted_at: nil) ⇒ Application
constructor
A new instance of Application.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(application_method: nil, purpose: nil, submitted_at: nil) ⇒ Application
Returns a new instance of Application.
15 16 17 18 19 |
# File 'lib/stripe/params/issuing/credit_underwriting_record_correct_params.rb', line 15 def initialize(application_method: nil, purpose: nil, submitted_at: nil) @application_method = application_method @purpose = purpose @submitted_at = submitted_at end |
Instance Attribute Details
#application_method ⇒ Object
The channel through which the applicant has submitted their application. Defaults to ‘online`.
9 10 11 |
# File 'lib/stripe/params/issuing/credit_underwriting_record_correct_params.rb', line 9 def application_method @application_method end |
#purpose ⇒ Object
Scope of demand made by the applicant.
11 12 13 |
# File 'lib/stripe/params/issuing/credit_underwriting_record_correct_params.rb', line 11 def purpose @purpose end |
#submitted_at ⇒ Object
Date when the applicant submitted their application.
13 14 15 |
# File 'lib/stripe/params/issuing/credit_underwriting_record_correct_params.rb', line 13 def submitted_at @submitted_at end |