Class: Stripe::Issuing::CreditUnderwritingRecordCorrectParams::Decision::CreditLimitApproved
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::CreditUnderwritingRecordCorrectParams::Decision::CreditLimitApproved
- Defined in:
- lib/stripe/params/issuing/credit_underwriting_record_correct_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The credit approved, in the currency of the account and [smallest currency unit](docs.stripe.com/currencies#zero-decimal).
-
#currency ⇒ Object
The currency of the credit approved, will default to the Account’s Issuing currency.
Instance Method Summary collapse
-
#initialize(amount: nil, currency: nil) ⇒ CreditLimitApproved
constructor
A new instance of CreditLimitApproved.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, currency: nil) ⇒ CreditLimitApproved
Returns a new instance of CreditLimitApproved.
53 54 55 56 |
# File 'lib/stripe/params/issuing/credit_underwriting_record_correct_params.rb', line 53 def initialize(amount: nil, currency: nil) @amount = amount @currency = currency end |
Instance Attribute Details
#amount ⇒ Object
The credit approved, in the currency of the account and [smallest currency unit](docs.stripe.com/currencies#zero-decimal).
49 50 51 |
# File 'lib/stripe/params/issuing/credit_underwriting_record_correct_params.rb', line 49 def amount @amount end |
#currency ⇒ Object
The currency of the credit approved, will default to the Account’s Issuing currency.
51 52 53 |
# File 'lib/stripe/params/issuing/credit_underwriting_record_correct_params.rb', line 51 def currency @currency end |