Class: Stripe::Issuing::CreditUnderwritingRecordCorrectParams::Decision::CreditLineClosed
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::CreditUnderwritingRecordCorrectParams::Decision::CreditLineClosed
- Defined in:
- lib/stripe/params/issuing/credit_underwriting_record_correct_params.rb
Instance Attribute Summary collapse
-
#reason_other_explanation ⇒ Object
Details about the ‘reasons.other` when present.
-
#reasons ⇒ Object
List of reasons why the credit line was closed, up to 4 reasons, in order of importance.
Instance Method Summary collapse
-
#initialize(reason_other_explanation: nil, reasons: nil) ⇒ CreditLineClosed
constructor
A new instance of CreditLineClosed.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(reason_other_explanation: nil, reasons: nil) ⇒ CreditLineClosed
Returns a new instance of CreditLineClosed.
83 84 85 86 |
# File 'lib/stripe/params/issuing/credit_underwriting_record_correct_params.rb', line 83 def initialize(reason_other_explanation: nil, reasons: nil) @reason_other_explanation = reason_other_explanation @reasons = reasons end |
Instance Attribute Details
#reason_other_explanation ⇒ Object
Details about the ‘reasons.other` when present.
79 80 81 |
# File 'lib/stripe/params/issuing/credit_underwriting_record_correct_params.rb', line 79 def reason_other_explanation @reason_other_explanation end |
#reasons ⇒ Object
List of reasons why the credit line was closed, up to 4 reasons, in order of importance.
81 82 83 |
# File 'lib/stripe/params/issuing/credit_underwriting_record_correct_params.rb', line 81 def reasons @reasons end |