Class: Stripe::Issuing::CreditUnderwritingRecordCreateFromApplicationParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/issuing/credit_underwriting_record_create_from_application_params.rb

Defined Under Namespace

Classes: Application, CreditUser

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(application: nil, credit_user: nil, expand: nil, metadata: nil) ⇒ CreditUnderwritingRecordCreateFromApplicationParams

Returns a new instance of CreditUnderwritingRecordCreateFromApplicationParams.



42
43
44
45
46
47
# File 'lib/stripe/params/issuing/credit_underwriting_record_create_from_application_params.rb', line 42

def initialize(application: nil, credit_user: nil, expand: nil, metadata: nil)
  @application = application
  @credit_user = credit_user
  @expand = expand
  @metadata = 
end

Instance Attribute Details

#applicationObject

Details about the application submission.



34
35
36
# File 'lib/stripe/params/issuing/credit_underwriting_record_create_from_application_params.rb', line 34

def application
  @application
end

#credit_userObject

Information about the company or person applying or holding the account.



36
37
38
# File 'lib/stripe/params/issuing/credit_underwriting_record_create_from_application_params.rb', line 36

def credit_user
  @credit_user
end

#expandObject

Specifies which fields in the response should be expanded.



38
39
40
# File 'lib/stripe/params/issuing/credit_underwriting_record_create_from_application_params.rb', line 38

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



40
41
42
# File 'lib/stripe/params/issuing/credit_underwriting_record_create_from_application_params.rb', line 40

def 
  @metadata
end