Class: Stripe::Issuing::CreditUnderwritingRecordReportDecisionParams::Decision::ApplicationRejected
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::CreditUnderwritingRecordReportDecisionParams::Decision::ApplicationRejected
- Defined in:
- lib/stripe/params/issuing/credit_underwriting_record_report_decision_params.rb
Instance Attribute Summary collapse
-
#reason_other_explanation ⇒ Object
Details about the ‘reasons.other` when present.
-
#reasons ⇒ Object
List of reasons why the application was rejected, up to 4 reasons, in order of importance.
Instance Method Summary collapse
-
#initialize(reason_other_explanation: nil, reasons: nil) ⇒ ApplicationRejected
constructor
A new instance of ApplicationRejected.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(reason_other_explanation: nil, reasons: nil) ⇒ ApplicationRejected
Returns a new instance of ApplicationRejected.
14 15 16 17 |
# File 'lib/stripe/params/issuing/credit_underwriting_record_report_decision_params.rb', line 14 def initialize(reason_other_explanation: nil, reasons: nil) @reason_other_explanation = reason_other_explanation @reasons = reasons end |
Instance Attribute Details
#reason_other_explanation ⇒ Object
Details about the ‘reasons.other` when present.
10 11 12 |
# File 'lib/stripe/params/issuing/credit_underwriting_record_report_decision_params.rb', line 10 def reason_other_explanation @reason_other_explanation end |
#reasons ⇒ Object
List of reasons why the application was rejected, up to 4 reasons, in order of importance.
12 13 14 |
# File 'lib/stripe/params/issuing/credit_underwriting_record_report_decision_params.rb', line 12 def reasons @reasons end |