Class: Stripe::Issuing::CreditUnderwritingRecordService::CorrectParams::Decision::CreditLimitApproved
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::CreditUnderwritingRecordService::CorrectParams::Decision::CreditLimitApproved
- Defined in:
- lib/stripe/services/issuing/credit_underwriting_record_service.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The credit approved, in the currency of the account and [smallest currency unit](stripe.com/docs/currencies#zero-decimal).
-
#currency ⇒ Object
The currency of the credit approved, will default to the Account’s Issuing currency.
Instance Method Summary collapse
-
#initialize(amount: nil, currency: nil) ⇒ CreditLimitApproved
constructor
A new instance of CreditLimitApproved.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, currency: nil) ⇒ CreditLimitApproved
Returns a new instance of CreditLimitApproved.
89 90 91 92 |
# File 'lib/stripe/services/issuing/credit_underwriting_record_service.rb', line 89 def initialize(amount: nil, currency: nil) @amount = amount @currency = currency end |
Instance Attribute Details
#amount ⇒ Object
The credit approved, in the currency of the account and [smallest currency unit](stripe.com/docs/currencies#zero-decimal).
84 85 86 |
# File 'lib/stripe/services/issuing/credit_underwriting_record_service.rb', line 84 def amount @amount end |
#currency ⇒ Object
The currency of the credit approved, will default to the Account’s Issuing currency.
87 88 89 |
# File 'lib/stripe/services/issuing/credit_underwriting_record_service.rb', line 87 def currency @currency end |