Class: Stripe::Issuing::CreditUnderwritingRecordService::CreateFromApplicationParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::CreditUnderwritingRecordService::CreateFromApplicationParams
- Defined in:
- lib/stripe/services/issuing/credit_underwriting_record_service.rb
Defined Under Namespace
Classes: Application, CreditUser
Instance Attribute Summary collapse
-
#application ⇒ Object
Details about the application submission.
-
#credit_user ⇒ Object
Information about the company or person applying or holding the account.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
Instance Method Summary collapse
-
#initialize(application: nil, credit_user: nil, expand: nil, metadata: nil) ⇒ CreateFromApplicationParams
constructor
A new instance of CreateFromApplicationParams.
Methods inherited from RequestParams
Constructor Details
#initialize(application: nil, credit_user: nil, expand: nil, metadata: nil) ⇒ CreateFromApplicationParams
Returns a new instance of CreateFromApplicationParams.
307 308 309 310 311 312 |
# File 'lib/stripe/services/issuing/credit_underwriting_record_service.rb', line 307 def initialize(application: nil, credit_user: nil, expand: nil, metadata: nil) @application = application @credit_user = credit_user @expand = @metadata = end |
Instance Attribute Details
#application ⇒ Object
Details about the application submission.
299 300 301 |
# File 'lib/stripe/services/issuing/credit_underwriting_record_service.rb', line 299 def application @application end |
#credit_user ⇒ Object
Information about the company or person applying or holding the account.
301 302 303 |
# File 'lib/stripe/services/issuing/credit_underwriting_record_service.rb', line 301 def credit_user @credit_user end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
303 304 305 |
# File 'lib/stripe/services/issuing/credit_underwriting_record_service.rb', line 303 def @expand end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
305 306 307 |
# File 'lib/stripe/services/issuing/credit_underwriting_record_service.rb', line 305 def @metadata end |