Class: Stripe::Issuing::CreditUnderwritingRecordService::CreateFromProactiveReviewParams::Decision::CreditLimitDecreased

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/issuing/credit_underwriting_record_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, currency: nil, reason_other_explanation: nil, reasons: nil) ⇒ CreditLimitDecreased

Returns a new instance of CreditLimitDecreased.



351
352
353
354
355
356
# File 'lib/stripe/services/issuing/credit_underwriting_record_service.rb', line 351

def initialize(amount: nil, currency: nil, reason_other_explanation: nil, reasons: nil)
  @amount = amount
  @currency = currency
  @reason_other_explanation = reason_other_explanation
  @reasons = reasons
end

Instance Attribute Details

#amountObject

The credit approved, in the currency of the account and [smallest currency unit](stripe.com/docs/currencies#zero-decimal).



343
344
345
# File 'lib/stripe/services/issuing/credit_underwriting_record_service.rb', line 343

def amount
  @amount
end

#currencyObject

The currency of the credit approved, will default to the Account’s Issuing currency.



345
346
347
# File 'lib/stripe/services/issuing/credit_underwriting_record_service.rb', line 345

def currency
  @currency
end

#reason_other_explanationObject

Details about the ‘reasons.other` when present.



347
348
349
# File 'lib/stripe/services/issuing/credit_underwriting_record_service.rb', line 347

def reason_other_explanation
  @reason_other_explanation
end

#reasonsObject

List of reasons why the existing credit was decreased, up to 4 reasons, in order of importance.



349
350
351
# File 'lib/stripe/services/issuing/credit_underwriting_record_service.rb', line 349

def reasons
  @reasons
end