Class: Stripe::Issuing::CreditUnderwritingRecordService::ReportDecisionParams::Decision::ApplicationRejected
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::CreditUnderwritingRecordService::ReportDecisionParams::Decision::ApplicationRejected
- Defined in:
- lib/stripe/services/issuing/credit_underwriting_record_service.rb
Instance Attribute Summary collapse
-
#reason_other_explanation ⇒ Object
Details about the ‘reasons.other` when present.
-
#reasons ⇒ Object
List of reasons why the application was rejected, up to 4 reasons, in order of importance.
Instance Method Summary collapse
-
#initialize(reason_other_explanation: nil, reasons: nil) ⇒ ApplicationRejected
constructor
A new instance of ApplicationRejected.
Methods inherited from RequestParams
Constructor Details
#initialize(reason_other_explanation: nil, reasons: nil) ⇒ ApplicationRejected
Returns a new instance of ApplicationRejected.
199 200 201 202 |
# File 'lib/stripe/services/issuing/credit_underwriting_record_service.rb', line 199 def initialize(reason_other_explanation: nil, reasons: nil) @reason_other_explanation = reason_other_explanation @reasons = reasons end |
Instance Attribute Details
#reason_other_explanation ⇒ Object
Details about the ‘reasons.other` when present.
195 196 197 |
# File 'lib/stripe/services/issuing/credit_underwriting_record_service.rb', line 195 def reason_other_explanation @reason_other_explanation end |
#reasons ⇒ Object
List of reasons why the application was rejected, up to 4 reasons, in order of importance.
197 198 199 |
# File 'lib/stripe/services/issuing/credit_underwriting_record_service.rb', line 197 def reasons @reasons end |