Class: Stripe::Issuing::Dispute::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/issuing/dispute.rb

Defined Under Namespace

Classes: Evidence, Treasury

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, evidence: nil, expand: nil, metadata: nil, transaction: nil, treasury: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
# File 'lib/stripe/resources/issuing/dispute.rb', line 565

def initialize(
  amount: nil,
  evidence: nil,
  expand: nil,
  metadata: nil,
  transaction: nil,
  treasury: nil
)
  @amount = amount
  @evidence = evidence
  @expand = expand
  @metadata = 
  @transaction = transaction
  @treasury = treasury
end

Instance Attribute Details

#amountObject

The dispute amount in the card’s currency and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal). If not set, defaults to the full transaction amount.



553
554
555
# File 'lib/stripe/resources/issuing/dispute.rb', line 553

def amount
  @amount
end

#evidenceObject

Evidence provided for the dispute.



555
556
557
# File 'lib/stripe/resources/issuing/dispute.rb', line 555

def evidence
  @evidence
end

#expandObject

Specifies which fields in the response should be expanded.



557
558
559
# File 'lib/stripe/resources/issuing/dispute.rb', line 557

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



559
560
561
# File 'lib/stripe/resources/issuing/dispute.rb', line 559

def 
  @metadata
end

#transactionObject

The ID of the issuing transaction to create a dispute for. For transaction on Treasury FinancialAccounts, use ‘treasury.received_debit`.



561
562
563
# File 'lib/stripe/resources/issuing/dispute.rb', line 561

def transaction
  @transaction
end

#treasuryObject

Params for disputes related to Treasury FinancialAccounts



563
564
565
# File 'lib/stripe/resources/issuing/dispute.rb', line 563

def treasury
  @treasury
end