Class: Stripe::Issuing::Dispute::CreateParams::Evidence::Duplicate
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::Dispute::CreateParams::Evidence::Duplicate
- Defined in:
- lib/stripe/resources/issuing/dispute.rb
Instance Attribute Summary collapse
-
#additional_documentation ⇒ Object
(ID of a [file upload](stripe.com/docs/guides/file-upload)) Additional documentation supporting the dispute.
-
#card_statement ⇒ Object
(ID of a [file upload](stripe.com/docs/guides/file-upload)) Copy of the card statement showing that the product had already been paid for.
-
#cash_receipt ⇒ Object
(ID of a [file upload](stripe.com/docs/guides/file-upload)) Copy of the receipt showing that the product had been paid for in cash.
-
#check_image ⇒ Object
(ID of a [file upload](stripe.com/docs/guides/file-upload)) Image of the front and back of the check that was used to pay for the product.
-
#explanation ⇒ Object
Explanation of why the cardholder is disputing this transaction.
-
#original_transaction ⇒ Object
Transaction (e.g., ipi_…) that the disputed transaction is a duplicate of.
Instance Method Summary collapse
-
#initialize(additional_documentation: nil, card_statement: nil, cash_receipt: nil, check_image: nil, explanation: nil, original_transaction: nil) ⇒ Duplicate
constructor
A new instance of Duplicate.
Methods inherited from RequestParams
Constructor Details
#initialize(additional_documentation: nil, card_statement: nil, cash_receipt: nil, check_image: nil, explanation: nil, original_transaction: nil) ⇒ Duplicate
Returns a new instance of Duplicate.
265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 265 def initialize( additional_documentation: nil, card_statement: nil, cash_receipt: nil, check_image: nil, explanation: nil, original_transaction: nil ) @additional_documentation = additional_documentation @card_statement = card_statement @cash_receipt = cash_receipt @check_image = check_image @explanation = explanation @original_transaction = original_transaction end |
Instance Attribute Details
#additional_documentation ⇒ Object
(ID of a [file upload](stripe.com/docs/guides/file-upload)) Additional documentation supporting the dispute.
253 254 255 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 253 def additional_documentation @additional_documentation end |
#card_statement ⇒ Object
(ID of a [file upload](stripe.com/docs/guides/file-upload)) Copy of the card statement showing that the product had already been paid for.
255 256 257 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 255 def card_statement @card_statement end |
#cash_receipt ⇒ Object
(ID of a [file upload](stripe.com/docs/guides/file-upload)) Copy of the receipt showing that the product had been paid for in cash.
257 258 259 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 257 def cash_receipt @cash_receipt end |
#check_image ⇒ Object
(ID of a [file upload](stripe.com/docs/guides/file-upload)) Image of the front and back of the check that was used to pay for the product.
259 260 261 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 259 def check_image @check_image end |
#explanation ⇒ Object
Explanation of why the cardholder is disputing this transaction.
261 262 263 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 261 def explanation @explanation end |
#original_transaction ⇒ Object
Transaction (e.g., ipi_…) that the disputed transaction is a duplicate of. Of the two or more transactions that are copies of each other, this is original undisputed one.
263 264 265 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 263 def original_transaction @original_transaction end |