Class: Stripe::Issuing::Dispute::CryptoTransaction::CryptoTransactionFailed
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Issuing::Dispute::CryptoTransaction::CryptoTransactionFailed
- Defined in:
- lib/stripe/resources/issuing/dispute.rb
Defined Under Namespace
Classes: Fee
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The crypto amount for the failed transaction.
-
#amount_mcc_upcharged ⇒ Object
readonly
The upcharged MCC amount, if one was applied.
-
#chain ⇒ Object
readonly
The blockchain network for the failed transaction.
-
#currency ⇒ Object
readonly
The currency of the crypto transaction amount.
-
#failed_at ⇒ Object
readonly
When the transaction failed.
-
#failure_reason ⇒ Object
readonly
The reason the transaction failed.
-
#fees ⇒ Object
readonly
Fees associated with the transaction.
-
#from_address ⇒ Object
readonly
The source wallet address for the attempted transaction.
-
#memo ⇒ Object
readonly
Memo metadata attached to the transaction, if present.
-
#to_address ⇒ Object
readonly
The destination wallet address for the attempted transaction when one exists.
-
#transaction_hash ⇒ Object
readonly
The blockchain transaction hash when one exists.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The crypto amount for the failed transaction.
85 86 87 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 85 def amount @amount end |
#amount_mcc_upcharged ⇒ Object (readonly)
The upcharged MCC amount, if one was applied.
87 88 89 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 87 def amount_mcc_upcharged @amount_mcc_upcharged end |
#chain ⇒ Object (readonly)
The blockchain network for the failed transaction.
89 90 91 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 89 def chain @chain end |
#currency ⇒ Object (readonly)
The currency of the crypto transaction amount.
91 92 93 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 91 def currency @currency end |
#failed_at ⇒ Object (readonly)
When the transaction failed.
93 94 95 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 93 def failed_at @failed_at end |
#failure_reason ⇒ Object (readonly)
The reason the transaction failed.
95 96 97 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 95 def failure_reason @failure_reason end |
#fees ⇒ Object (readonly)
Fees associated with the transaction.
97 98 99 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 97 def fees @fees end |
#from_address ⇒ Object (readonly)
The source wallet address for the attempted transaction.
99 100 101 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 99 def from_address @from_address end |
#memo ⇒ Object (readonly)
Memo metadata attached to the transaction, if present.
101 102 103 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 101 def memo @memo end |
#to_address ⇒ Object (readonly)
The destination wallet address for the attempted transaction when one exists.
103 104 105 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 103 def to_address @to_address end |
#transaction_hash ⇒ Object (readonly)
The blockchain transaction hash when one exists.
105 106 107 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 105 def transaction_hash @transaction_hash end |
Class Method Details
.field_remappings ⇒ Object
111 112 113 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 111 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
107 108 109 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 107 def self.inner_class_types @inner_class_types = { fees: Fee } end |