Class: Stripe::Issuing::Dispute::Evidence::Canceled
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Issuing::Dispute::Evidence::Canceled
- Defined in:
- lib/stripe/resources/issuing/dispute.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#additional_documentation ⇒ Object
readonly
(ID of a [file upload](stripe.com/docs/guides/file-upload)) Additional documentation supporting the dispute.
-
#canceled_at ⇒ Object
readonly
Date when order was canceled.
-
#cancellation_policy_provided ⇒ Object
readonly
Whether the cardholder was provided with a cancellation policy.
-
#cancellation_reason ⇒ Object
readonly
Reason for canceling the order.
-
#expected_at ⇒ Object
readonly
Date when the cardholder expected to receive the product.
-
#explanation ⇒ Object
readonly
Explanation of why the cardholder is disputing this transaction.
-
#product_description ⇒ Object
readonly
Description of the merchandise or service that was purchased.
-
#product_type ⇒ Object
readonly
Whether the product was a merchandise or service.
-
#return_status ⇒ Object
readonly
Result of cardholder’s attempt to return the product.
-
#returned_at ⇒ Object
readonly
Date when the product was returned or attempted to be returned.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#additional_documentation ⇒ Object (readonly)
(ID of a [file upload](stripe.com/docs/guides/file-upload)) Additional documentation supporting the dispute.
22 23 24 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 22 def additional_documentation @additional_documentation end |
#canceled_at ⇒ Object (readonly)
Date when order was canceled.
25 26 27 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 25 def canceled_at @canceled_at end |
#cancellation_policy_provided ⇒ Object (readonly)
Whether the cardholder was provided with a cancellation policy.
28 29 30 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 28 def cancellation_policy_provided @cancellation_policy_provided end |
#cancellation_reason ⇒ Object (readonly)
Reason for canceling the order.
31 32 33 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 31 def cancellation_reason @cancellation_reason end |
#expected_at ⇒ Object (readonly)
Date when the cardholder expected to receive the product.
34 35 36 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 34 def expected_at @expected_at end |
#explanation ⇒ Object (readonly)
Explanation of why the cardholder is disputing this transaction.
37 38 39 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 37 def explanation @explanation end |
#product_description ⇒ Object (readonly)
Description of the merchandise or service that was purchased.
40 41 42 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 40 def product_description @product_description end |
#product_type ⇒ Object (readonly)
Whether the product was a merchandise or service.
43 44 45 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 43 def product_type @product_type end |
#return_status ⇒ Object (readonly)
Result of cardholder’s attempt to return the product.
46 47 48 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 46 def return_status @return_status end |
#returned_at ⇒ Object (readonly)
Date when the product was returned or attempted to be returned.
49 50 51 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 49 def returned_at @returned_at end |