Class: Stripe::Issuing::Dispute::Evidence::Duplicate

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/issuing/dispute.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#additional_documentationObject (readonly)

(ID of a [file upload](stripe.com/docs/guides/file-upload)) Additional documentation supporting the dispute.



168
169
170
# File 'lib/stripe/resources/issuing/dispute.rb', line 168

def additional_documentation
  @additional_documentation
end

#card_statementObject (readonly)

(ID of a [file upload](stripe.com/docs/guides/file-upload)) Copy of the card statement showing that the product had already been paid for.



170
171
172
# File 'lib/stripe/resources/issuing/dispute.rb', line 170

def card_statement
  @card_statement
end

#cash_receiptObject (readonly)

(ID of a [file upload](stripe.com/docs/guides/file-upload)) Copy of the receipt showing that the product had been paid for in cash.



172
173
174
# File 'lib/stripe/resources/issuing/dispute.rb', line 172

def cash_receipt
  @cash_receipt
end

#check_imageObject (readonly)

(ID of a [file upload](stripe.com/docs/guides/file-upload)) Image of the front and back of the check that was used to pay for the product.



174
175
176
# File 'lib/stripe/resources/issuing/dispute.rb', line 174

def check_image
  @check_image
end

#explanationObject (readonly)

Explanation of why the cardholder is disputing this transaction.



176
177
178
# File 'lib/stripe/resources/issuing/dispute.rb', line 176

def explanation
  @explanation
end

#original_transactionObject (readonly)

Transaction (e.g., ipi_…) that the disputed transaction is a duplicate of. Of the two or more transactions that are copies of each other, this is original undisputed one.



178
179
180
# File 'lib/stripe/resources/issuing/dispute.rb', line 178

def original_transaction
  @original_transaction
end

Class Method Details

.field_remappingsObject



184
185
186
# File 'lib/stripe/resources/issuing/dispute.rb', line 184

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



180
181
182
# File 'lib/stripe/resources/issuing/dispute.rb', line 180

def self.inner_class_types
  @inner_class_types = {}
end