Class: Stripe::Issuing::Dispute::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/issuing/dispute.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, status: nil, transaction: nil) ⇒ ListParams

Returns a new instance of ListParams.



272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
# File 'lib/stripe/resources/issuing/dispute.rb', line 272

def initialize(
  created: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  starting_after: nil,
  status: nil,
  transaction: nil
)
  @created = created
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
  @status = status
  @transaction = transaction
end

Instance Attribute Details

#createdObject

Only return Issuing disputes that were created during the given date interval.



258
259
260
# File 'lib/stripe/resources/issuing/dispute.rb', line 258

def created
  @created
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



260
261
262
# File 'lib/stripe/resources/issuing/dispute.rb', line 260

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



262
263
264
# File 'lib/stripe/resources/issuing/dispute.rb', line 262

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



264
265
266
# File 'lib/stripe/resources/issuing/dispute.rb', line 264

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



266
267
268
# File 'lib/stripe/resources/issuing/dispute.rb', line 266

def starting_after
  @starting_after
end

#statusObject

Select Issuing disputes with the given status.



268
269
270
# File 'lib/stripe/resources/issuing/dispute.rb', line 268

def status
  @status
end

#transactionObject

Select the Issuing dispute for the given transaction.



270
271
272
# File 'lib/stripe/resources/issuing/dispute.rb', line 270

def transaction
  @transaction
end