Class: Stripe::Issuing::Dispute::ProvisionalCredit
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Issuing::Dispute::ProvisionalCredit
- Defined in:
- lib/stripe/resources/issuing/dispute.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#grant_deadline ⇒ Object
readonly
The time by which the platform must grant a provisional credit to the consumer.
-
#granted_at ⇒ Object
readonly
The time at which the platform reported granting the provisional credit.
-
#revocable_after ⇒ Object
readonly
The earliest time after which the platform can revoke the provisional credit.
-
#revoked_at ⇒ Object
readonly
The time at which the platform reported revoking the provisional credit.
-
#status ⇒ Object
readonly
The status of the provisional credit obligation.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#grant_deadline ⇒ Object (readonly)
The time by which the platform must grant a provisional credit to the consumer.
406 407 408 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 406 def grant_deadline @grant_deadline end |
#granted_at ⇒ Object (readonly)
The time at which the platform reported granting the provisional credit.
408 409 410 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 408 def granted_at @granted_at end |
#revocable_after ⇒ Object (readonly)
The earliest time after which the platform can revoke the provisional credit.
410 411 412 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 410 def revocable_after @revocable_after end |
#revoked_at ⇒ Object (readonly)
The time at which the platform reported revoking the provisional credit.
412 413 414 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 412 def revoked_at @revoked_at end |
#status ⇒ Object (readonly)
The status of the provisional credit obligation.
414 415 416 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 414 def status @status end |
Class Method Details
.field_remappings ⇒ Object
420 421 422 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 420 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
416 417 418 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 416 def self.inner_class_types @inner_class_types = {} end |