Class: Stripe::Issuing::Dispute::SubmitParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/issuing/dispute.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, metadata: nil) ⇒ SubmitParams

Returns a new instance of SubmitParams.



857
858
859
860
# File 'lib/stripe/resources/issuing/dispute.rb', line 857

def initialize(expand: nil, metadata: nil)
  @expand = expand
  @metadata = 
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



853
854
855
# File 'lib/stripe/resources/issuing/dispute.rb', line 853

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



855
856
857
# File 'lib/stripe/resources/issuing/dispute.rb', line 855

def 
  @metadata
end