Class: Stripe::Issuing::Dispute::TestHelpers
- Inherits:
-
APIResourceTestHelpers
- Object
- APIResourceTestHelpers
- Stripe::Issuing::Dispute::TestHelpers
- Defined in:
- lib/stripe/resources/issuing/dispute.rb
Constant Summary collapse
- RESOURCE_CLASS =
Dispute
Class Method Summary collapse
-
.close(dispute, params = {}, opts = {}) ⇒ Object
Test helper: closes a test-mode Issuing dispute as won or lost.
-
.provisional_credit(dispute, params = {}, opts = {}) ⇒ Object
Test helper: overrides the grant_deadline and revocable_after timestamps on a test-mode Issuing dispute's provisional credit, allowing tests to simulate timer-driven status transitions without waiting for real regulatory deadlines to pass.
- .resource_class ⇒ Object
-
.simulate_network_lifecycle_dispute_response(dispute, params = {}, opts = {}) ⇒ Object
Test helper: populates network_lifecycle.dispute_response on a test-mode Visa Issuing Dispute using placeholder file tokens.
-
.simulate_network_lifecycle_pre_arbitration_response(dispute, params = {}, opts = {}) ⇒ Object
Test helper: populates network_lifecycle.pre_arbitration_response on a test-mode Visa Issuing Dispute using placeholder file tokens.
-
.simulate_network_lifecycle_pre_arbitration_submission(dispute, params = {}, opts = {}) ⇒ Object
Test helper: populates network_lifecycle.pre_arbitration_submission on a test-mode Visa Issuing Dispute using placeholder file tokens.
Instance Method Summary collapse
-
#close(params = {}, opts = {}) ⇒ Object
Test helper: closes a test-mode Issuing dispute as won or lost.
-
#provisional_credit(params = {}, opts = {}) ⇒ Object
Test helper: overrides the grant_deadline and revocable_after timestamps on a test-mode Issuing dispute's provisional credit, allowing tests to simulate timer-driven status transitions without waiting for real regulatory deadlines to pass.
-
#simulate_network_lifecycle_dispute_response(params = {}, opts = {}) ⇒ Object
Test helper: populates network_lifecycle.dispute_response on a test-mode Visa Issuing Dispute using placeholder file tokens.
-
#simulate_network_lifecycle_pre_arbitration_response(params = {}, opts = {}) ⇒ Object
Test helper: populates network_lifecycle.pre_arbitration_response on a test-mode Visa Issuing Dispute using placeholder file tokens.
-
#simulate_network_lifecycle_pre_arbitration_submission(params = {}, opts = {}) ⇒ Object
Test helper: populates network_lifecycle.pre_arbitration_submission on a test-mode Visa Issuing Dispute using placeholder file tokens.
Methods inherited from APIResourceTestHelpers
custom_method, #initialize, resource_url, #resource_url
Methods included from APIOperations::Request
Constructor Details
This class inherits a constructor from Stripe::APIResourceTestHelpers
Class Method Details
.close(dispute, params = {}, opts = {}) ⇒ Object
Test helper: closes a test-mode Issuing dispute as won or lost.
548 549 550 551 552 553 554 555 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 548 def self.close(dispute, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/test_helpers/issuing/disputes/%<dispute>s/close", { dispute: CGI.escape(dispute) }), params: params, opts: opts ) end |
.provisional_credit(dispute, params = {}, opts = {}) ⇒ Object
Test helper: overrides the grant_deadline and revocable_after timestamps on a test-mode Issuing dispute's provisional credit, allowing tests to simulate timer-driven status transitions without waiting for real regulatory deadlines to pass.
568 569 570 571 572 573 574 575 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 568 def self.provisional_credit(dispute, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/test_helpers/issuing/disputes/%<dispute>s/provisional_credit", { dispute: CGI.escape(dispute) }), params: params, opts: opts ) end |
.resource_class ⇒ Object
543 544 545 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 543 def self.resource_class "Dispute" end |
.simulate_network_lifecycle_dispute_response(dispute, params = {}, opts = {}) ⇒ Object
Test helper: populates network_lifecycle.dispute_response on a test-mode Visa Issuing Dispute using placeholder file tokens. Only supported for Visa disputes.
588 589 590 591 592 593 594 595 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 588 def self.simulate_network_lifecycle_dispute_response(dispute, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/test_helpers/issuing/disputes/%<dispute>s/simulate_network_lifecycle_dispute_response", { dispute: CGI.escape(dispute) }), params: params, opts: opts ) end |
.simulate_network_lifecycle_pre_arbitration_response(dispute, params = {}, opts = {}) ⇒ Object
Test helper: populates network_lifecycle.pre_arbitration_response on a test-mode Visa Issuing Dispute using placeholder file tokens. Only supported for Visa disputes in the collaboration flow.
608 609 610 611 612 613 614 615 616 617 618 619 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 608 def self.simulate_network_lifecycle_pre_arbitration_response( dispute, params = {}, opts = {} ) request_stripe_object( method: :post, path: format("/v1/test_helpers/issuing/disputes/%<dispute>s/simulate_network_lifecycle_pre_arbitration_response", { dispute: CGI.escape(dispute) }), params: params, opts: opts ) end |
.simulate_network_lifecycle_pre_arbitration_submission(dispute, params = {}, opts = {}) ⇒ Object
Test helper: populates network_lifecycle.pre_arbitration_submission on a test-mode Visa Issuing Dispute using placeholder file tokens. Only supported for Visa disputes.
632 633 634 635 636 637 638 639 640 641 642 643 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 632 def self.simulate_network_lifecycle_pre_arbitration_submission( dispute, params = {}, opts = {} ) request_stripe_object( method: :post, path: format("/v1/test_helpers/issuing/disputes/%<dispute>s/simulate_network_lifecycle_pre_arbitration_submission", { dispute: CGI.escape(dispute) }), params: params, opts: opts ) end |
Instance Method Details
#close(params = {}, opts = {}) ⇒ Object
Test helper: closes a test-mode Issuing dispute as won or lost.
558 559 560 561 562 563 564 565 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 558 def close(params = {}, opts = {}) @resource.request_stripe_object( method: :post, path: format("/v1/test_helpers/issuing/disputes/%<dispute>s/close", { dispute: CGI.escape(@resource["id"]) }), params: params, opts: opts ) end |
#provisional_credit(params = {}, opts = {}) ⇒ Object
Test helper: overrides the grant_deadline and revocable_after timestamps on a test-mode Issuing dispute's provisional credit, allowing tests to simulate timer-driven status transitions without waiting for real regulatory deadlines to pass.
578 579 580 581 582 583 584 585 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 578 def provisional_credit(params = {}, opts = {}) @resource.request_stripe_object( method: :post, path: format("/v1/test_helpers/issuing/disputes/%<dispute>s/provisional_credit", { dispute: CGI.escape(@resource["id"]) }), params: params, opts: opts ) end |
#simulate_network_lifecycle_dispute_response(params = {}, opts = {}) ⇒ Object
Test helper: populates network_lifecycle.dispute_response on a test-mode Visa Issuing Dispute using placeholder file tokens. Only supported for Visa disputes.
598 599 600 601 602 603 604 605 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 598 def simulate_network_lifecycle_dispute_response(params = {}, opts = {}) @resource.request_stripe_object( method: :post, path: format("/v1/test_helpers/issuing/disputes/%<dispute>s/simulate_network_lifecycle_dispute_response", { dispute: CGI.escape(@resource["id"]) }), params: params, opts: opts ) end |
#simulate_network_lifecycle_pre_arbitration_response(params = {}, opts = {}) ⇒ Object
Test helper: populates network_lifecycle.pre_arbitration_response on a test-mode Visa Issuing Dispute using placeholder file tokens. Only supported for Visa disputes in the collaboration flow.
622 623 624 625 626 627 628 629 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 622 def simulate_network_lifecycle_pre_arbitration_response(params = {}, opts = {}) @resource.request_stripe_object( method: :post, path: format("/v1/test_helpers/issuing/disputes/%<dispute>s/simulate_network_lifecycle_pre_arbitration_response", { dispute: CGI.escape(@resource["id"]) }), params: params, opts: opts ) end |
#simulate_network_lifecycle_pre_arbitration_submission(params = {}, opts = {}) ⇒ Object
Test helper: populates network_lifecycle.pre_arbitration_submission on a test-mode Visa Issuing Dispute using placeholder file tokens. Only supported for Visa disputes.
646 647 648 649 650 651 652 653 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 646 def simulate_network_lifecycle_pre_arbitration_submission(params = {}, opts = {}) @resource.request_stripe_object( method: :post, path: format("/v1/test_helpers/issuing/disputes/%<dispute>s/simulate_network_lifecycle_pre_arbitration_submission", { dispute: CGI.escape(@resource["id"]) }), params: params, opts: opts ) end |