Class: Stripe::Issuing::Dispute::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::Dispute::UpdateParams
- Defined in:
- lib/stripe/resources/issuing/dispute.rb
Defined Under Namespace
Classes: Evidence
Instance Attribute Summary collapse
-
#amount ⇒ Object
The dispute amount in the card’s currency and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).
-
#evidence ⇒ Object
Evidence provided for the dispute.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
Instance Method Summary collapse
-
#initialize(amount: nil, evidence: nil, expand: nil, metadata: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, evidence: nil, expand: nil, metadata: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
754 755 756 757 758 759 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 754 def initialize(amount: nil, evidence: nil, expand: nil, metadata: nil) @amount = amount @evidence = evidence @expand = @metadata = end |
Instance Attribute Details
#amount ⇒ Object
The dispute amount in the card’s currency and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).
746 747 748 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 746 def amount @amount end |
#evidence ⇒ Object
Evidence provided for the dispute.
748 749 750 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 748 def evidence @evidence end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
750 751 752 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 750 def @expand end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
752 753 754 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 752 def @metadata end |