Class: Stripe::Issuing::Dispute::UpdateParams::Evidence::NotReceived
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::Dispute::UpdateParams::Evidence::NotReceived
- Defined in:
- lib/stripe/resources/issuing/dispute.rb
Instance Attribute Summary collapse
-
#additional_documentation ⇒ Object
(ID of a [file upload](stripe.com/docs/guides/file-upload)) Additional documentation supporting the dispute.
-
#expected_at ⇒ Object
Date when the cardholder expected to receive the product.
-
#explanation ⇒ Object
Explanation of why the cardholder is disputing this transaction.
-
#product_description ⇒ Object
Description of the merchandise or service that was purchased.
-
#product_type ⇒ Object
Whether the product was a merchandise or service.
Instance Method Summary collapse
-
#initialize(additional_documentation: nil, expected_at: nil, explanation: nil, product_description: nil, product_type: nil) ⇒ NotReceived
constructor
A new instance of NotReceived.
Methods inherited from RequestParams
Constructor Details
#initialize(additional_documentation: nil, expected_at: nil, explanation: nil, product_description: nil, product_type: nil) ⇒ NotReceived
Returns a new instance of NotReceived.
729 730 731 732 733 734 735 736 737 738 739 740 741 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 729 def initialize( additional_documentation: nil, expected_at: nil, explanation: nil, product_description: nil, product_type: nil ) @additional_documentation = additional_documentation @expected_at = expected_at @explanation = explanation @product_description = product_description @product_type = product_type end |
Instance Attribute Details
#additional_documentation ⇒ Object
(ID of a [file upload](stripe.com/docs/guides/file-upload)) Additional documentation supporting the dispute.
719 720 721 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 719 def additional_documentation @additional_documentation end |
#expected_at ⇒ Object
Date when the cardholder expected to receive the product.
721 722 723 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 721 def expected_at @expected_at end |
#explanation ⇒ Object
Explanation of why the cardholder is disputing this transaction.
723 724 725 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 723 def explanation @explanation end |
#product_description ⇒ Object
Description of the merchandise or service that was purchased.
725 726 727 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 725 def product_description @product_description end |
#product_type ⇒ Object
Whether the product was a merchandise or service.
727 728 729 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 727 def product_type @product_type end |