Class: Stripe::Issuing::DisputeProvisionalCreditParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::DisputeProvisionalCreditParams
- Defined in:
- lib/stripe/params/issuing/dispute_provisional_credit_params.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#grant_deadline ⇒ Object
Override the deadline by which the platform must grant a provisional credit to the consumer.
-
#revocable_after ⇒ Object
Override the earliest time after which the platform may revoke the provisional credit.
Instance Method Summary collapse
-
#initialize(expand: nil, grant_deadline: nil, revocable_after: nil) ⇒ DisputeProvisionalCreditParams
constructor
A new instance of DisputeProvisionalCreditParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(expand: nil, grant_deadline: nil, revocable_after: nil) ⇒ DisputeProvisionalCreditParams
Returns a new instance of DisputeProvisionalCreditParams.
14 15 16 17 18 |
# File 'lib/stripe/params/issuing/dispute_provisional_credit_params.rb', line 14 def initialize(expand: nil, grant_deadline: nil, revocable_after: nil) @expand = @grant_deadline = grant_deadline @revocable_after = revocable_after end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
8 9 10 |
# File 'lib/stripe/params/issuing/dispute_provisional_credit_params.rb', line 8 def @expand end |
#grant_deadline ⇒ Object
Override the deadline by which the platform must grant a provisional credit to the consumer.
10 11 12 |
# File 'lib/stripe/params/issuing/dispute_provisional_credit_params.rb', line 10 def grant_deadline @grant_deadline end |
#revocable_after ⇒ Object
Override the earliest time after which the platform may revoke the provisional credit.
12 13 14 |
# File 'lib/stripe/params/issuing/dispute_provisional_credit_params.rb', line 12 def revocable_after @revocable_after end |