Class: Stripe::Issuing::DisputeService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::DisputeService::CreateParams
- Defined in:
- lib/stripe/services/issuing/dispute_service.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#amount ⇒ Object
The dispute amount in the card’s currency and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).
-
#evidence ⇒ Object
Evidence provided for the dispute.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#transaction ⇒ Object
The ID of the issuing transaction to create a dispute for.
-
#treasury ⇒ Object
Params for disputes related to Treasury FinancialAccounts.
Instance Method Summary collapse
-
#initialize(amount: nil, evidence: nil, expand: nil, metadata: nil, transaction: nil, treasury: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, evidence: nil, expand: nil, metadata: nil, transaction: nil, treasury: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 |
# File 'lib/stripe/services/issuing/dispute_service.rb', line 387 def initialize( amount: nil, evidence: nil, expand: nil, metadata: nil, transaction: nil, treasury: nil ) @amount = amount @evidence = evidence @expand = @metadata = @transaction = transaction @treasury = treasury end |
Instance Attribute Details
#amount ⇒ Object
The dispute amount in the card’s currency and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal). If not set, defaults to the full transaction amount.
370 371 372 |
# File 'lib/stripe/services/issuing/dispute_service.rb', line 370 def amount @amount end |
#evidence ⇒ Object
Evidence provided for the dispute.
373 374 375 |
# File 'lib/stripe/services/issuing/dispute_service.rb', line 373 def evidence @evidence end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
376 377 378 |
# File 'lib/stripe/services/issuing/dispute_service.rb', line 376 def @expand end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
379 380 381 |
# File 'lib/stripe/services/issuing/dispute_service.rb', line 379 def @metadata end |
#transaction ⇒ Object
The ID of the issuing transaction to create a dispute for. For transaction on Treasury FinancialAccounts, use ‘treasury.received_debit`.
382 383 384 |
# File 'lib/stripe/services/issuing/dispute_service.rb', line 382 def transaction @transaction end |
#treasury ⇒ Object
Params for disputes related to Treasury FinancialAccounts
385 386 387 |
# File 'lib/stripe/services/issuing/dispute_service.rb', line 385 def treasury @treasury end |