Class: Stripe::Issuing::DisputeService::SubmitParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/issuing/dispute_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, metadata: nil) ⇒ SubmitParams

Returns a new instance of SubmitParams.



732
733
734
735
# File 'lib/stripe/services/issuing/dispute_service.rb', line 732

def initialize(expand: nil, metadata: nil)
  @expand = expand
  @metadata = 
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



727
728
729
# File 'lib/stripe/services/issuing/dispute_service.rb', line 727

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



730
731
732
# File 'lib/stripe/services/issuing/dispute_service.rb', line 730

def 
  @metadata
end