Class: Stripe::Issuing::DisputeService::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::DisputeService::UpdateParams
- Defined in:
- lib/stripe/services/issuing/dispute_service.rb
Defined Under Namespace
Classes: Evidence
Instance Attribute Summary collapse
-
#amount ⇒ Object
The dispute amount in the card’s currency and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).
-
#evidence ⇒ Object
Evidence provided for the dispute.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
Instance Method Summary collapse
-
#initialize(amount: nil, evidence: nil, expand: nil, metadata: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, evidence: nil, expand: nil, metadata: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
620 621 622 623 624 625 |
# File 'lib/stripe/services/issuing/dispute_service.rb', line 620 def initialize(amount: nil, evidence: nil, expand: nil, metadata: nil) @amount = amount @evidence = evidence @expand = @metadata = end |
Instance Attribute Details
#amount ⇒ Object
The dispute amount in the card’s currency and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).
612 613 614 |
# File 'lib/stripe/services/issuing/dispute_service.rb', line 612 def amount @amount end |
#evidence ⇒ Object
Evidence provided for the dispute.
614 615 616 |
# File 'lib/stripe/services/issuing/dispute_service.rb', line 614 def evidence @evidence end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
616 617 618 |
# File 'lib/stripe/services/issuing/dispute_service.rb', line 616 def @expand end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
618 619 620 |
# File 'lib/stripe/services/issuing/dispute_service.rb', line 618 def @metadata end |