Class: Stripe::Issuing::DisputeService::UpdateParams::Evidence::Canceled
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::DisputeService::UpdateParams::Evidence::Canceled
- Defined in:
- lib/stripe/services/issuing/dispute_service.rb
Instance Attribute Summary collapse
-
#additional_documentation ⇒ Object
(ID of a [file upload](stripe.com/docs/guides/file-upload)) Additional documentation supporting the dispute.
-
#canceled_at ⇒ Object
Date when order was canceled.
-
#cancellation_policy_provided ⇒ Object
Whether the cardholder was provided with a cancellation policy.
-
#cancellation_reason ⇒ Object
Reason for canceling the order.
-
#expected_at ⇒ Object
Date when the cardholder expected to receive the product.
-
#explanation ⇒ Object
Explanation of why the cardholder is disputing this transaction.
-
#product_description ⇒ Object
Description of the merchandise or service that was purchased.
-
#product_type ⇒ Object
Whether the product was a merchandise or service.
-
#return_status ⇒ Object
Result of cardholder’s attempt to return the product.
-
#returned_at ⇒ Object
Date when the product was returned or attempted to be returned.
Instance Method Summary collapse
-
#initialize(additional_documentation: nil, canceled_at: nil, cancellation_policy_provided: nil, cancellation_reason: nil, expected_at: nil, explanation: nil, product_description: nil, product_type: nil, return_status: nil, returned_at: nil) ⇒ Canceled
constructor
A new instance of Canceled.
Methods inherited from RequestParams
Constructor Details
#initialize(additional_documentation: nil, canceled_at: nil, cancellation_policy_provided: nil, cancellation_reason: nil, expected_at: nil, explanation: nil, product_description: nil, product_type: nil, return_status: nil, returned_at: nil) ⇒ Canceled
Returns a new instance of Canceled.
446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 |
# File 'lib/stripe/services/issuing/dispute_service.rb', line 446 def initialize( additional_documentation: nil, canceled_at: nil, cancellation_policy_provided: nil, cancellation_reason: nil, expected_at: nil, explanation: nil, product_description: nil, product_type: nil, return_status: nil, returned_at: nil ) @additional_documentation = additional_documentation @canceled_at = canceled_at @cancellation_policy_provided = cancellation_policy_provided @cancellation_reason = cancellation_reason @expected_at = expected_at @explanation = explanation @product_description = product_description @product_type = product_type @return_status = return_status @returned_at = returned_at end |
Instance Attribute Details
#additional_documentation ⇒ Object
(ID of a [file upload](stripe.com/docs/guides/file-upload)) Additional documentation supporting the dispute.
417 418 419 |
# File 'lib/stripe/services/issuing/dispute_service.rb', line 417 def additional_documentation @additional_documentation end |
#canceled_at ⇒ Object
Date when order was canceled.
420 421 422 |
# File 'lib/stripe/services/issuing/dispute_service.rb', line 420 def canceled_at @canceled_at end |
#cancellation_policy_provided ⇒ Object
Whether the cardholder was provided with a cancellation policy.
423 424 425 |
# File 'lib/stripe/services/issuing/dispute_service.rb', line 423 def cancellation_policy_provided @cancellation_policy_provided end |
#cancellation_reason ⇒ Object
Reason for canceling the order.
426 427 428 |
# File 'lib/stripe/services/issuing/dispute_service.rb', line 426 def cancellation_reason @cancellation_reason end |
#expected_at ⇒ Object
Date when the cardholder expected to receive the product.
429 430 431 |
# File 'lib/stripe/services/issuing/dispute_service.rb', line 429 def expected_at @expected_at end |
#explanation ⇒ Object
Explanation of why the cardholder is disputing this transaction.
432 433 434 |
# File 'lib/stripe/services/issuing/dispute_service.rb', line 432 def explanation @explanation end |
#product_description ⇒ Object
Description of the merchandise or service that was purchased.
435 436 437 |
# File 'lib/stripe/services/issuing/dispute_service.rb', line 435 def product_description @product_description end |
#product_type ⇒ Object
Whether the product was a merchandise or service.
438 439 440 |
# File 'lib/stripe/services/issuing/dispute_service.rb', line 438 def product_type @product_type end |
#return_status ⇒ Object
Result of cardholder’s attempt to return the product.
441 442 443 |
# File 'lib/stripe/services/issuing/dispute_service.rb', line 441 def return_status @return_status end |
#returned_at ⇒ Object
Date when the product was returned or attempted to be returned.
444 445 446 |
# File 'lib/stripe/services/issuing/dispute_service.rb', line 444 def returned_at @returned_at end |