Class: Stripe::Issuing::DisputeService::UpdateParams::Evidence::Duplicate
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::DisputeService::UpdateParams::Evidence::Duplicate
- Defined in:
- lib/stripe/services/issuing/dispute_service.rb
Instance Attribute Summary collapse
-
#additional_documentation ⇒ Object
(ID of a [file upload](stripe.com/docs/guides/file-upload)) Additional documentation supporting the dispute.
-
#card_statement ⇒ Object
(ID of a [file upload](stripe.com/docs/guides/file-upload)) Copy of the card statement showing that the product had already been paid for.
-
#cash_receipt ⇒ Object
(ID of a [file upload](stripe.com/docs/guides/file-upload)) Copy of the receipt showing that the product had been paid for in cash.
-
#check_image ⇒ Object
(ID of a [file upload](stripe.com/docs/guides/file-upload)) Image of the front and back of the check that was used to pay for the product.
-
#explanation ⇒ Object
Explanation of why the cardholder is disputing this transaction.
-
#original_transaction ⇒ Object
Transaction (e.g., ipi_…) that the disputed transaction is a duplicate of.
Instance Method Summary collapse
-
#initialize(additional_documentation: nil, card_statement: nil, cash_receipt: nil, check_image: nil, explanation: nil, original_transaction: nil) ⇒ Duplicate
constructor
A new instance of Duplicate.
Methods inherited from RequestParams
Constructor Details
#initialize(additional_documentation: nil, card_statement: nil, cash_receipt: nil, check_image: nil, explanation: nil, original_transaction: nil) ⇒ Duplicate
Returns a new instance of Duplicate.
490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 |
# File 'lib/stripe/services/issuing/dispute_service.rb', line 490 def initialize( additional_documentation: nil, card_statement: nil, cash_receipt: nil, check_image: nil, explanation: nil, original_transaction: nil ) @additional_documentation = additional_documentation @card_statement = card_statement @cash_receipt = cash_receipt @check_image = check_image @explanation = explanation @original_transaction = original_transaction end |
Instance Attribute Details
#additional_documentation ⇒ Object
(ID of a [file upload](stripe.com/docs/guides/file-upload)) Additional documentation supporting the dispute.
473 474 475 |
# File 'lib/stripe/services/issuing/dispute_service.rb', line 473 def additional_documentation @additional_documentation end |
#card_statement ⇒ Object
(ID of a [file upload](stripe.com/docs/guides/file-upload)) Copy of the card statement showing that the product had already been paid for.
476 477 478 |
# File 'lib/stripe/services/issuing/dispute_service.rb', line 476 def card_statement @card_statement end |
#cash_receipt ⇒ Object
(ID of a [file upload](stripe.com/docs/guides/file-upload)) Copy of the receipt showing that the product had been paid for in cash.
479 480 481 |
# File 'lib/stripe/services/issuing/dispute_service.rb', line 479 def cash_receipt @cash_receipt end |
#check_image ⇒ Object
(ID of a [file upload](stripe.com/docs/guides/file-upload)) Image of the front and back of the check that was used to pay for the product.
482 483 484 |
# File 'lib/stripe/services/issuing/dispute_service.rb', line 482 def check_image @check_image end |
#explanation ⇒ Object
Explanation of why the cardholder is disputing this transaction.
485 486 487 |
# File 'lib/stripe/services/issuing/dispute_service.rb', line 485 def explanation @explanation end |
#original_transaction ⇒ Object
Transaction (e.g., ipi_…) that the disputed transaction is a duplicate of. Of the two or more transactions that are copies of each other, this is original undisputed one.
488 489 490 |
# File 'lib/stripe/services/issuing/dispute_service.rb', line 488 def original_transaction @original_transaction end |