Class: Stripe::Issuing::DisputeService::UpdateParams::Evidence::NotReceived
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::DisputeService::UpdateParams::Evidence::NotReceived
- Defined in:
- lib/stripe/services/issuing/dispute_service.rb
Instance Attribute Summary collapse
-
#additional_documentation ⇒ Object
(ID of a [file upload](stripe.com/docs/guides/file-upload)) Additional documentation supporting the dispute.
-
#expected_at ⇒ Object
Date when the cardholder expected to receive the product.
-
#explanation ⇒ Object
Explanation of why the cardholder is disputing this transaction.
-
#product_description ⇒ Object
Description of the merchandise or service that was purchased.
-
#product_type ⇒ Object
Whether the product was a merchandise or service.
Instance Method Summary collapse
-
#initialize(additional_documentation: nil, expected_at: nil, explanation: nil, product_description: nil, product_type: nil) ⇒ NotReceived
constructor
A new instance of NotReceived.
Methods inherited from RequestParams
Constructor Details
#initialize(additional_documentation: nil, expected_at: nil, explanation: nil, product_description: nil, product_type: nil) ⇒ NotReceived
Returns a new instance of NotReceived.
506 507 508 509 510 511 512 513 514 515 516 517 518 |
# File 'lib/stripe/services/issuing/dispute_service.rb', line 506 def initialize( additional_documentation: nil, expected_at: nil, explanation: nil, product_description: nil, product_type: nil ) @additional_documentation = additional_documentation @expected_at = expected_at @explanation = explanation @product_description = product_description @product_type = product_type end |
Instance Attribute Details
#additional_documentation ⇒ Object
(ID of a [file upload](stripe.com/docs/guides/file-upload)) Additional documentation supporting the dispute.
496 497 498 |
# File 'lib/stripe/services/issuing/dispute_service.rb', line 496 def additional_documentation @additional_documentation end |
#expected_at ⇒ Object
Date when the cardholder expected to receive the product.
498 499 500 |
# File 'lib/stripe/services/issuing/dispute_service.rb', line 498 def expected_at @expected_at end |
#explanation ⇒ Object
Explanation of why the cardholder is disputing this transaction.
500 501 502 |
# File 'lib/stripe/services/issuing/dispute_service.rb', line 500 def explanation @explanation end |
#product_description ⇒ Object
Description of the merchandise or service that was purchased.
502 503 504 |
# File 'lib/stripe/services/issuing/dispute_service.rb', line 502 def product_description @product_description end |
#product_type ⇒ Object
Whether the product was a merchandise or service.
504 505 506 |
# File 'lib/stripe/services/issuing/dispute_service.rb', line 504 def product_type @product_type end |