Class: Stripe::Issuing::DisputeUpdateParams::ProvisionalCredit
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::DisputeUpdateParams::ProvisionalCredit
- Defined in:
- lib/stripe/params/issuing/dispute_update_params.rb
Instance Attribute Summary collapse
-
#granted_at ⇒ Object
The time at which the platform granted the provisional credit to their user.
-
#revoked_at ⇒ Object
The time at which the platform revoked the provisional credit from their user.
Instance Method Summary collapse
-
#initialize(granted_at: nil, revoked_at: nil) ⇒ ProvisionalCredit
constructor
A new instance of ProvisionalCredit.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(granted_at: nil, revoked_at: nil) ⇒ ProvisionalCredit
Returns a new instance of ProvisionalCredit.
265 266 267 268 |
# File 'lib/stripe/params/issuing/dispute_update_params.rb', line 265 def initialize(granted_at: nil, revoked_at: nil) @granted_at = granted_at @revoked_at = revoked_at end |
Instance Attribute Details
#granted_at ⇒ Object
The time at which the platform granted the provisional credit to their user.
261 262 263 |
# File 'lib/stripe/params/issuing/dispute_update_params.rb', line 261 def granted_at @granted_at end |
#revoked_at ⇒ Object
The time at which the platform revoked the provisional credit from their user.
263 264 265 |
# File 'lib/stripe/params/issuing/dispute_update_params.rb', line 263 def revoked_at @revoked_at end |