Class: Stripe::Issuing::FraudLiabilityDebit

Inherits:
APIResource show all
Extended by:
APIOperations::List
Defined in:
lib/stripe/resources/issuing/fraud_liability_debit.rb

Overview

A fraud liability debit occurs when Stripe debits a platform’s account for fraud losses on Issuing transactions.

Constant Summary collapse

OBJECT_NAME =
"issuing.fraud_liability_debit"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods included from APIOperations::List

list

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Debited amount. This is equal to the disputed amount and is given in the card’s currency and in the smallest currency unit.



16
17
18
# File 'lib/stripe/resources/issuing/fraud_liability_debit.rb', line 16

def amount
  @amount
end

#balance_transactionObject (readonly)

ID of the [balance transaction](docs.stripe.com/api/balance_transactions) associated with this debit.



18
19
20
# File 'lib/stripe/resources/issuing/fraud_liability_debit.rb', line 18

def balance_transaction
  @balance_transaction
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



20
21
22
# File 'lib/stripe/resources/issuing/fraud_liability_debit.rb', line 20

def created
  @created
end

#currencyObject (readonly)

The currency of the debit. Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



22
23
24
# File 'lib/stripe/resources/issuing/fraud_liability_debit.rb', line 22

def currency
  @currency
end

#disputeObject (readonly)

The ID of the linked dispute.



24
25
26
# File 'lib/stripe/resources/issuing/fraud_liability_debit.rb', line 24

def dispute
  @dispute
end

#idObject (readonly)

Unique identifier for the object.



26
27
28
# File 'lib/stripe/resources/issuing/fraud_liability_debit.rb', line 26

def id
  @id
end

#livemodeObject (readonly)

If the object exists in live mode, the value is ‘true`. If the object exists in test mode, the value is `false`.



28
29
30
# File 'lib/stripe/resources/issuing/fraud_liability_debit.rb', line 28

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



30
31
32
# File 'lib/stripe/resources/issuing/fraud_liability_debit.rb', line 30

def object
  @object
end

Class Method Details

.field_remappingsObject



46
47
48
# File 'lib/stripe/resources/issuing/fraud_liability_debit.rb', line 46

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



42
43
44
# File 'lib/stripe/resources/issuing/fraud_liability_debit.rb', line 42

def self.inner_class_types
  @inner_class_types = {}
end

.list(params = {}, opts = {}) ⇒ Object

Returns a list of Issuing FraudLiabilityDebit objects. The objects are sorted in descending order by creation date, with the most recently created object appearing first.



33
34
35
36
37
38
39
40
# File 'lib/stripe/resources/issuing/fraud_liability_debit.rb', line 33

def self.list(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/issuing/fraud_liability_debits",
    params: params,
    opts: opts
  )
end

.object_nameObject



11
12
13
# File 'lib/stripe/resources/issuing/fraud_liability_debit.rb', line 11

def self.object_name
  "issuing.fraud_liability_debit"
end