Class: Stripe::Issuing::FraudLiabilityDebitService::ListParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/issuing/fraud_liability_debit_service.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



43
44
45
46
47
48
49
50
51
52
53
54
55
# File 'lib/stripe/services/issuing/fraud_liability_debit_service.rb', line 43

def initialize(
  created: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  starting_after: nil
)
  @created = created
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
end

Instance Attribute Details

#createdObject

Only return Issuing Fraud Liability Debits that were created during the given date interval.



29
30
31
# File 'lib/stripe/services/issuing/fraud_liability_debit_service.rb', line 29

def created
  @created
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



32
33
34
# File 'lib/stripe/services/issuing/fraud_liability_debit_service.rb', line 32

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



35
36
37
# File 'lib/stripe/services/issuing/fraud_liability_debit_service.rb', line 35

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



38
39
40
# File 'lib/stripe/services/issuing/fraud_liability_debit_service.rb', line 38

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



41
42
43
# File 'lib/stripe/services/issuing/fraud_liability_debit_service.rb', line 41

def starting_after
  @starting_after
end