Class: Stripe::Issuing::PersonalizationDesign
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Issuing::PersonalizationDesign
- Extended by:
- APIOperations::Create, APIOperations::List
- Includes:
- APIOperations::Save
- Defined in:
- lib/stripe/resources/issuing/personalization_design.rb
Overview
A Personalization Design is a logical grouping of a Physical Bundle, card logo, and carrier text that represents a product line.
Defined Under Namespace
Classes: ActivateParams, CarrierText, CreateParams, DeactivateParams, ListParams, Preferences, RejectParams, RejectionReasons, RetrieveParams, TestHelpers, UpdateParams
Constant Summary collapse
- OBJECT_NAME =
"issuing.personalization_design"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#card_logo ⇒ Object
readonly
The file for the card logo to use with physical bundles that support card logos.
-
#carrier_text ⇒ Object
readonly
Hash containing carrier text, for use with physical bundles that support carrier text.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#lookup_key ⇒ Object
readonly
A lookup key used to retrieve personalization designs dynamically from a static string.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#name ⇒ Object
readonly
Friendly display name.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#physical_bundle ⇒ Object
readonly
The physical bundle object belonging to this personalization design.
-
#preferences ⇒ Object
readonly
Attribute for field preferences.
-
#rejection_reasons ⇒ Object
readonly
Attribute for field rejection_reasons.
-
#status ⇒ Object
readonly
Whether this personalization design can be used to create cards.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.create(params = {}, opts = {}) ⇒ Object
Creates a personalization design object.
-
.list(params = {}, opts = {}) ⇒ Object
Returns a list of personalization design objects.
- .object_name ⇒ Object
-
.update(personalization_design, params = {}, opts = {}) ⇒ Object
Updates a card personalization object.
Instance Method Summary collapse
Methods included from APIOperations::Create
Methods included from APIOperations::List
Methods included from APIOperations::Save
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#card_logo ⇒ Object (readonly)
The file for the card logo to use with physical bundles that support card logos. Must have a ‘purpose` value of `issuing_logo`.
276 277 278 |
# File 'lib/stripe/resources/issuing/personalization_design.rb', line 276 def card_logo @card_logo end |
#carrier_text ⇒ Object (readonly)
Hash containing carrier text, for use with physical bundles that support carrier text.
278 279 280 |
# File 'lib/stripe/resources/issuing/personalization_design.rb', line 278 def carrier_text @carrier_text end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
280 281 282 |
# File 'lib/stripe/resources/issuing/personalization_design.rb', line 280 def created @created end |
#id ⇒ Object (readonly)
Unique identifier for the object.
282 283 284 |
# File 'lib/stripe/resources/issuing/personalization_design.rb', line 282 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
284 285 286 |
# File 'lib/stripe/resources/issuing/personalization_design.rb', line 284 def livemode @livemode end |
#lookup_key ⇒ Object (readonly)
A lookup key used to retrieve personalization designs dynamically from a static string. This may be up to 200 characters.
286 287 288 |
# File 'lib/stripe/resources/issuing/personalization_design.rb', line 286 def lookup_key @lookup_key end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
288 289 290 |
# File 'lib/stripe/resources/issuing/personalization_design.rb', line 288 def @metadata end |
#name ⇒ Object (readonly)
Friendly display name.
290 291 292 |
# File 'lib/stripe/resources/issuing/personalization_design.rb', line 290 def name @name end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
292 293 294 |
# File 'lib/stripe/resources/issuing/personalization_design.rb', line 292 def object @object end |
#physical_bundle ⇒ Object (readonly)
The physical bundle object belonging to this personalization design.
294 295 296 |
# File 'lib/stripe/resources/issuing/personalization_design.rb', line 294 def physical_bundle @physical_bundle end |
#preferences ⇒ Object (readonly)
Attribute for field preferences
296 297 298 |
# File 'lib/stripe/resources/issuing/personalization_design.rb', line 296 def preferences @preferences end |
#rejection_reasons ⇒ Object (readonly)
Attribute for field rejection_reasons
298 299 300 |
# File 'lib/stripe/resources/issuing/personalization_design.rb', line 298 def rejection_reasons @rejection_reasons end |
#status ⇒ Object (readonly)
Whether this personalization design can be used to create cards.
300 301 302 |
# File 'lib/stripe/resources/issuing/personalization_design.rb', line 300 def status @status end |
Class Method Details
.create(params = {}, opts = {}) ⇒ Object
Creates a personalization design object.
303 304 305 306 307 308 309 310 |
# File 'lib/stripe/resources/issuing/personalization_design.rb', line 303 def self.create(params = {}, opts = {}) request_stripe_object( method: :post, path: "/v1/issuing/personalization_designs", params: params, opts: opts ) end |
.list(params = {}, opts = {}) ⇒ Object
Returns a list of personalization design objects. The objects are sorted in descending order by creation date, with the most recently created object appearing first.
313 314 315 316 317 318 319 320 |
# File 'lib/stripe/resources/issuing/personalization_design.rb', line 313 def self.list(params = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/issuing/personalization_designs", params: params, opts: opts ) end |
.object_name ⇒ Object
13 14 15 |
# File 'lib/stripe/resources/issuing/personalization_design.rb', line 13 def self.object_name "issuing.personalization_design" end |
.update(personalization_design, params = {}, opts = {}) ⇒ Object
Updates a card personalization object.
323 324 325 326 327 328 329 330 |
# File 'lib/stripe/resources/issuing/personalization_design.rb', line 323 def self.update(personalization_design, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/issuing/personalization_designs/%<personalization_design>s", { personalization_design: CGI.escape(personalization_design) }), params: params, opts: opts ) end |
Instance Method Details
#test_helpers ⇒ Object
332 333 334 |
# File 'lib/stripe/resources/issuing/personalization_design.rb', line 332 def test_helpers TestHelpers.new(self) end |