Class: Stripe::Issuing::PersonalizationDesign::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/issuing/personalization_design.rb

Defined Under Namespace

Classes: CarrierText, Preferences

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(card_logo: nil, carrier_text: nil, expand: nil, lookup_key: nil, metadata: nil, name: nil, physical_bundle: nil, preferences: nil, transfer_lookup_key: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
# File 'lib/stripe/resources/issuing/personalization_design.rb', line 246

def initialize(
  card_logo: nil,
  carrier_text: nil,
  expand: nil,
  lookup_key: nil,
  metadata: nil,
  name: nil,
  physical_bundle: nil,
  preferences: nil,
  transfer_lookup_key: nil
)
  @card_logo = 
  @carrier_text = carrier_text
  @expand = expand
  @lookup_key = lookup_key
  @metadata = 
  @name = name
  @physical_bundle = physical_bundle
  @preferences = preferences
  @transfer_lookup_key = transfer_lookup_key
end

Instance Attribute Details

#card_logoObject

The file for the card logo, for use with physical bundles that support card logos. Must have a ‘purpose` value of `issuing_logo`.



220
221
222
# File 'lib/stripe/resources/issuing/personalization_design.rb', line 220

def 
  @card_logo
end

#carrier_textObject

Hash containing carrier text, for use with physical bundles that support carrier text.



223
224
225
# File 'lib/stripe/resources/issuing/personalization_design.rb', line 223

def carrier_text
  @carrier_text
end

#expandObject

Specifies which fields in the response should be expanded.



226
227
228
# File 'lib/stripe/resources/issuing/personalization_design.rb', line 226

def expand
  @expand
end

#lookup_keyObject

A lookup key used to retrieve personalization designs dynamically from a static string. This may be up to 200 characters.



229
230
231
# File 'lib/stripe/resources/issuing/personalization_design.rb', line 229

def lookup_key
  @lookup_key
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



232
233
234
# File 'lib/stripe/resources/issuing/personalization_design.rb', line 232

def 
  @metadata
end

#nameObject

Friendly display name. Providing an empty string will set the field to null.



235
236
237
# File 'lib/stripe/resources/issuing/personalization_design.rb', line 235

def name
  @name
end

#physical_bundleObject

The physical bundle object belonging to this personalization design.



238
239
240
# File 'lib/stripe/resources/issuing/personalization_design.rb', line 238

def physical_bundle
  @physical_bundle
end

#preferencesObject

Information on whether this personalization design is used to create cards when one is not specified.



241
242
243
# File 'lib/stripe/resources/issuing/personalization_design.rb', line 241

def preferences
  @preferences
end

#transfer_lookup_keyObject

If set to true, will atomically remove the lookup key from the existing personalization design, and assign it to this personalization design.



244
245
246
# File 'lib/stripe/resources/issuing/personalization_design.rb', line 244

def transfer_lookup_key
  @transfer_lookup_key
end