Class: Stripe::Issuing::PersonalizationDesignService::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::PersonalizationDesignService::UpdateParams
- Defined in:
- lib/stripe/services/issuing/personalization_design_service.rb
Defined Under Namespace
Classes: CarrierText, Preferences
Instance Attribute Summary collapse
-
#card_logo ⇒ Object
The file for the card logo, for use with physical bundles that support card logos.
-
#carrier_text ⇒ Object
Hash containing carrier text, for use with physical bundles that support carrier text.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#lookup_key ⇒ Object
A lookup key used to retrieve personalization designs dynamically from a static string.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#name ⇒ Object
Friendly display name.
-
#physical_bundle ⇒ Object
The physical bundle object belonging to this personalization design.
-
#preferences ⇒ Object
Information on whether this personalization design is used to create cards when one is not specified.
-
#transfer_lookup_key ⇒ Object
If set to true, will atomically remove the lookup key from the existing personalization design, and assign it to this personalization design.
Instance Method Summary collapse
-
#initialize(card_logo: nil, carrier_text: nil, expand: nil, lookup_key: nil, metadata: nil, name: nil, physical_bundle: nil, preferences: nil, transfer_lookup_key: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(card_logo: nil, carrier_text: nil, expand: nil, lookup_key: nil, metadata: nil, name: nil, physical_bundle: nil, preferences: nil, transfer_lookup_key: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/stripe/services/issuing/personalization_design_service.rb', line 177 def initialize( card_logo: nil, carrier_text: nil, expand: nil, lookup_key: nil, metadata: nil, name: nil, physical_bundle: nil, preferences: nil, transfer_lookup_key: nil ) @card_logo = card_logo @carrier_text = carrier_text @expand = @lookup_key = lookup_key @metadata = @name = name @physical_bundle = physical_bundle @preferences = preferences @transfer_lookup_key = transfer_lookup_key end |
Instance Attribute Details
#card_logo ⇒ Object
The file for the card logo, for use with physical bundles that support card logos. Must have a ‘purpose` value of `issuing_logo`.
159 160 161 |
# File 'lib/stripe/services/issuing/personalization_design_service.rb', line 159 def card_logo @card_logo end |
#carrier_text ⇒ Object
Hash containing carrier text, for use with physical bundles that support carrier text.
161 162 163 |
# File 'lib/stripe/services/issuing/personalization_design_service.rb', line 161 def carrier_text @carrier_text end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
163 164 165 |
# File 'lib/stripe/services/issuing/personalization_design_service.rb', line 163 def @expand end |
#lookup_key ⇒ Object
A lookup key used to retrieve personalization designs dynamically from a static string. This may be up to 200 characters.
165 166 167 |
# File 'lib/stripe/services/issuing/personalization_design_service.rb', line 165 def lookup_key @lookup_key end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
167 168 169 |
# File 'lib/stripe/services/issuing/personalization_design_service.rb', line 167 def @metadata end |
#name ⇒ Object
Friendly display name. Providing an empty string will set the field to null.
169 170 171 |
# File 'lib/stripe/services/issuing/personalization_design_service.rb', line 169 def name @name end |
#physical_bundle ⇒ Object
The physical bundle object belonging to this personalization design.
171 172 173 |
# File 'lib/stripe/services/issuing/personalization_design_service.rb', line 171 def physical_bundle @physical_bundle end |
#preferences ⇒ Object
Information on whether this personalization design is used to create cards when one is not specified.
173 174 175 |
# File 'lib/stripe/services/issuing/personalization_design_service.rb', line 173 def preferences @preferences end |
#transfer_lookup_key ⇒ Object
If set to true, will atomically remove the lookup key from the existing personalization design, and assign it to this personalization design.
175 176 177 |
# File 'lib/stripe/services/issuing/personalization_design_service.rb', line 175 def transfer_lookup_key @transfer_lookup_key end |