Class: Stripe::Issuing::PhysicalBundle

Inherits:
APIResource show all
Extended by:
APIOperations::List
Defined in:
lib/stripe/resources/issuing/physical_bundle.rb

Overview

A Physical Bundle represents the bundle of physical items - card stock, carrier letter, and envelope - that is shipped to a cardholder when you create a physical card.

Defined Under Namespace

Classes: Features, ListParams

Constant Summary collapse

OBJECT_NAME =
"issuing.physical_bundle"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods included from APIOperations::List

list

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#featuresObject (readonly)

Attribute for field features



63
64
65
# File 'lib/stripe/resources/issuing/physical_bundle.rb', line 63

def features
  @features
end

#idObject (readonly)

Unique identifier for the object.



65
66
67
# File 'lib/stripe/resources/issuing/physical_bundle.rb', line 65

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



67
68
69
# File 'lib/stripe/resources/issuing/physical_bundle.rb', line 67

def livemode
  @livemode
end

#nameObject (readonly)

Friendly display name.



69
70
71
# File 'lib/stripe/resources/issuing/physical_bundle.rb', line 69

def name
  @name
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



71
72
73
# File 'lib/stripe/resources/issuing/physical_bundle.rb', line 71

def object
  @object
end

#statusObject (readonly)

Whether this physical bundle can be used to create cards.



73
74
75
# File 'lib/stripe/resources/issuing/physical_bundle.rb', line 73

def status
  @status
end

#typeObject (readonly)

Whether this physical bundle is a standard Stripe offering or custom-made for you.



75
76
77
# File 'lib/stripe/resources/issuing/physical_bundle.rb', line 75

def type
  @type
end

Class Method Details

.field_remappingsObject



91
92
93
# File 'lib/stripe/resources/issuing/physical_bundle.rb', line 91

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



87
88
89
# File 'lib/stripe/resources/issuing/physical_bundle.rb', line 87

def self.inner_class_types
  @inner_class_types = { features: Features }
end

.list(params = {}, opts = {}) ⇒ Object

Returns a list of physical bundle objects. The objects are sorted in descending order by creation date, with the most recently created object appearing first.



78
79
80
81
82
83
84
85
# File 'lib/stripe/resources/issuing/physical_bundle.rb', line 78

def self.list(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/issuing/physical_bundles",
    params: params,
    opts: opts
  )
end

.object_nameObject



11
12
13
# File 'lib/stripe/resources/issuing/physical_bundle.rb', line 11

def self.object_name
  "issuing.physical_bundle"
end