Class: Stripe::Issuing::PhysicalBundle::ListParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/issuing/physical_bundle.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(ending_before: nil, expand: nil, limit: nil, starting_after: nil, status: nil, type: nil) ⇒ ListParams

Returns a new instance of ListParams.



45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
# File 'lib/stripe/resources/issuing/physical_bundle.rb', line 45

def initialize(
  ending_before: nil,
  expand: nil,
  limit: nil,
  starting_after: nil,
  status: nil,
  type: nil
)
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
  @status = status
  @type = type
end

Instance Attribute Details

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



28
29
30
# File 'lib/stripe/resources/issuing/physical_bundle.rb', line 28

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



31
32
33
# File 'lib/stripe/resources/issuing/physical_bundle.rb', line 31

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



34
35
36
# File 'lib/stripe/resources/issuing/physical_bundle.rb', line 34

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



37
38
39
# File 'lib/stripe/resources/issuing/physical_bundle.rb', line 37

def starting_after
  @starting_after
end

#statusObject

Only return physical bundles with the given status.



40
41
42
# File 'lib/stripe/resources/issuing/physical_bundle.rb', line 40

def status
  @status
end

#typeObject

Only return physical bundles with the given type.



43
44
45
# File 'lib/stripe/resources/issuing/physical_bundle.rb', line 43

def type
  @type
end