Class: Stripe::Issuing::PhysicalBundleService

Inherits:
StripeService show all
Defined in:
lib/stripe/services/issuing/physical_bundle_service.rb

Defined Under Namespace

Classes: ListParams, RetrieveParams

Instance Method Summary collapse

Methods inherited from StripeService

#initialize, #request, #request_stream

Constructor Details

This class inherits a constructor from Stripe::StripeService

Instance Method Details

#list(params = {}, opts = {}) ⇒ Object

Returns a list of physical bundle objects. The objects are sorted in descending order by creation date, with the most recently created object appearing first.



48
49
50
51
52
53
54
55
56
# File 'lib/stripe/services/issuing/physical_bundle_service.rb', line 48

def list(params = {}, opts = {})
  request(
    method: :get,
    path: "/v1/issuing/physical_bundles",
    params: params,
    opts: opts,
    base_address: :api
  )
end

#retrieve(physical_bundle, params = {}, opts = {}) ⇒ Object

Retrieves a physical bundle object.



59
60
61
62
63
64
65
66
67
# File 'lib/stripe/services/issuing/physical_bundle_service.rb', line 59

def retrieve(physical_bundle, params = {}, opts = {})
  request(
    method: :get,
    path: format("/v1/issuing/physical_bundles/%<physical_bundle>s", { physical_bundle: CGI.escape(physical_bundle) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end