Class: Stripe::Issuing::ProgramCreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/issuing/program_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(expand: nil, is_default: nil, platform_program: nil) ⇒ ProgramCreateParams

Returns a new instance of ProgramCreateParams.



14
15
16
17
18
# File 'lib/stripe/params/issuing/program_create_params.rb', line 14

def initialize(expand: nil, is_default: nil, platform_program: nil)
  @expand = expand
  @is_default = is_default
  @platform_program = platform_program
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



8
9
10
# File 'lib/stripe/params/issuing/program_create_params.rb', line 8

def expand
  @expand
end

#is_defaultObject

If true, makes the specified program the default for the given account.



10
11
12
# File 'lib/stripe/params/issuing/program_create_params.rb', line 10

def is_default
  @is_default
end

#platform_programObject

The program to use as the parent for the new program to create.



12
13
14
# File 'lib/stripe/params/issuing/program_create_params.rb', line 12

def platform_program
  @platform_program
end