Class: Stripe::Issuing::ProgramService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::Issuing::ProgramService
- Defined in:
- lib/stripe/services/issuing/program_service.rb
Instance Method Summary collapse
-
#create(params = {}, opts = {}) ⇒ Object
Create a Program object.
-
#list(params = {}, opts = {}) ⇒ Object
List all of the programs the given Issuing user has access to.
-
#retrieve(program, params = {}, opts = {}) ⇒ Object
Retrieves the program specified by the given id.
-
#update(program, params = {}, opts = {}) ⇒ Object
Updates a Program object.
Methods inherited from StripeService
#initialize, #request, #request_stream
Constructor Details
This class inherits a constructor from Stripe::StripeService
Instance Method Details
#create(params = {}, opts = {}) ⇒ Object
Create a Program object.
8 9 10 11 12 13 14 15 16 |
# File 'lib/stripe/services/issuing/program_service.rb', line 8 def create(params = {}, opts = {}) request( method: :post, path: "/v1/issuing/programs", params: params, opts: opts, base_address: :api ) end |
#list(params = {}, opts = {}) ⇒ Object
List all of the programs the given Issuing user has access to.
19 20 21 22 23 24 25 26 27 |
# File 'lib/stripe/services/issuing/program_service.rb', line 19 def list(params = {}, opts = {}) request( method: :get, path: "/v1/issuing/programs", params: params, opts: opts, base_address: :api ) end |
#retrieve(program, params = {}, opts = {}) ⇒ Object
Retrieves the program specified by the given id.
30 31 32 33 34 35 36 37 38 |
# File 'lib/stripe/services/issuing/program_service.rb', line 30 def retrieve(program, params = {}, opts = {}) request( method: :get, path: format("/v1/issuing/programs/%<program>s", { program: CGI.escape(program) }), params: params, opts: opts, base_address: :api ) end |
#update(program, params = {}, opts = {}) ⇒ Object
Updates a Program object.
41 42 43 44 45 46 47 48 49 |
# File 'lib/stripe/services/issuing/program_service.rb', line 41 def update(program, params = {}, opts = {}) request( method: :post, path: format("/v1/issuing/programs/%<program>s", { program: CGI.escape(program) }), params: params, opts: opts, base_address: :api ) end |