Class: Stripe::Issuing::ProgramUpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::ProgramUpdateParams
- Defined in:
- lib/stripe/params/issuing/program_update_params.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#is_default ⇒ Object
If true, makes the specified program the default.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
Instance Method Summary collapse
-
#initialize(expand: nil, is_default: nil, metadata: nil) ⇒ ProgramUpdateParams
constructor
A new instance of ProgramUpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, is_default: nil, metadata: nil) ⇒ ProgramUpdateParams
Returns a new instance of ProgramUpdateParams.
14 15 16 17 18 |
# File 'lib/stripe/params/issuing/program_update_params.rb', line 14 def initialize(expand: nil, is_default: nil, metadata: nil) @expand = @is_default = is_default @metadata = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
8 9 10 |
# File 'lib/stripe/params/issuing/program_update_params.rb', line 8 def @expand end |
#is_default ⇒ Object
If true, makes the specified program the default.
10 11 12 |
# File 'lib/stripe/params/issuing/program_update_params.rb', line 10 def is_default @is_default end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
12 13 14 |
# File 'lib/stripe/params/issuing/program_update_params.rb', line 12 def @metadata end |