Class: Stripe::Issuing::Settlement

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/issuing/settlement.rb

Overview

When a non-stripe BIN is used, any use of an issued card must be settled directly with the card network. The net amount owed is represented by an Issuing Settlement object.

Constant Summary collapse

OBJECT_NAME =
"issuing.settlement"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#binObject (readonly)

The Bank Identification Number reflecting this settlement record.



14
15
16
# File 'lib/stripe/resources/issuing/settlement.rb', line 14

def bin
  @bin
end

#clearing_dateObject (readonly)

The date that the transactions are cleared and posted to user's accounts.



16
17
18
# File 'lib/stripe/resources/issuing/settlement.rb', line 16

def clearing_date
  @clearing_date
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



18
19
20
# File 'lib/stripe/resources/issuing/settlement.rb', line 18

def created
  @created
end

#currencyObject (readonly)

Three-letter ISO currency code, in lowercase. Must be a supported currency.



20
21
22
# File 'lib/stripe/resources/issuing/settlement.rb', line 20

def currency
  @currency
end

#idObject (readonly)

Unique identifier for the object.



22
23
24
# File 'lib/stripe/resources/issuing/settlement.rb', line 22

def id
  @id
end

#interchange_fees_amountObject (readonly)

The total interchange received as reimbursement for the transactions.



24
25
26
# File 'lib/stripe/resources/issuing/settlement.rb', line 24

def interchange_fees_amount
  @interchange_fees_amount
end

#livemodeObject (readonly)

If the object exists in live mode, the value is true. If the object exists in test mode, the value is false.



26
27
28
# File 'lib/stripe/resources/issuing/settlement.rb', line 26

def livemode
  @livemode
end

#metadataObject (readonly)

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



28
29
30
# File 'lib/stripe/resources/issuing/settlement.rb', line 28

def 
  @metadata
end

#net_total_amountObject (readonly)

The total net amount required to settle with the network.



30
31
32
# File 'lib/stripe/resources/issuing/settlement.rb', line 30

def net_total_amount
  @net_total_amount
end

#networkObject (readonly)

The card network for this settlement report. One of ["visa", "maestro", "mastercard"]



32
33
34
# File 'lib/stripe/resources/issuing/settlement.rb', line 32

def network
  @network
end

#network_fees_amountObject (readonly)

The total amount of fees owed to the network.



34
35
36
# File 'lib/stripe/resources/issuing/settlement.rb', line 34

def network_fees_amount
  @network_fees_amount
end

#network_settlement_identifierObject (readonly)

The Settlement Identification Number assigned by the network.



36
37
38
# File 'lib/stripe/resources/issuing/settlement.rb', line 36

def network_settlement_identifier
  @network_settlement_identifier
end

#objectObject (readonly)

String representing the object's type. Objects of the same type share the same value.



38
39
40
# File 'lib/stripe/resources/issuing/settlement.rb', line 38

def object
  @object
end

#other_fees_amountObject (readonly)

The total amount of any additional fees assessed by the card network.



40
41
42
# File 'lib/stripe/resources/issuing/settlement.rb', line 40

def other_fees_amount
  @other_fees_amount
end

#other_fees_countObject (readonly)

The total number of additional fees assessed by the card network.



42
43
44
# File 'lib/stripe/resources/issuing/settlement.rb', line 42

def other_fees_count
  @other_fees_count
end

#settlement_serviceObject (readonly)

One of international or uk_national_net.



44
45
46
# File 'lib/stripe/resources/issuing/settlement.rb', line 44

def settlement_service
  @settlement_service
end

#statusObject (readonly)

The current processing status of this settlement.



46
47
48
# File 'lib/stripe/resources/issuing/settlement.rb', line 46

def status
  @status
end

#transaction_amountObject (readonly)

The total transaction amount reflected in this settlement.



48
49
50
# File 'lib/stripe/resources/issuing/settlement.rb', line 48

def transaction_amount
  @transaction_amount
end

#transaction_countObject (readonly)

The total number of transactions reflected in this settlement.



50
51
52
# File 'lib/stripe/resources/issuing/settlement.rb', line 50

def transaction_count
  @transaction_count
end

Class Method Details

.field_remappingsObject



56
57
58
# File 'lib/stripe/resources/issuing/settlement.rb', line 56

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



52
53
54
# File 'lib/stripe/resources/issuing/settlement.rb', line 52

def self.inner_class_types
  @inner_class_types = {}
end

.object_nameObject



9
10
11
# File 'lib/stripe/resources/issuing/settlement.rb', line 9

def self.object_name
  "issuing.settlement"
end