Class: Stripe::Issuing::Token

Inherits:
APIResource show all
Extended by:
APIOperations::List
Includes:
APIOperations::Save
Defined in:
lib/stripe/resources/issuing/token.rb

Overview

An issuing token object is created when an issued card is added to a digital wallet. As a [card issuer](stripe.com/docs/issuing), you can [view and manage these tokens](stripe.com/docs/issuing/controls/token-management) through Stripe.

Defined Under Namespace

Classes: ListParams, NetworkData, UpdateParams

Constant Summary collapse

OBJECT_NAME =
"issuing.token"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods included from APIOperations::List

list

Methods included from APIOperations::Save

included, #save

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#cardObject (readonly)

Card associated with this token.



211
212
213
# File 'lib/stripe/resources/issuing/token.rb', line 211

def card
  @card
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



213
214
215
# File 'lib/stripe/resources/issuing/token.rb', line 213

def created
  @created
end

#device_fingerprintObject (readonly)

The hashed ID derived from the device ID from the card network associated with the token.



215
216
217
# File 'lib/stripe/resources/issuing/token.rb', line 215

def device_fingerprint
  @device_fingerprint
end

#idObject (readonly)

Unique identifier for the object.



217
218
219
# File 'lib/stripe/resources/issuing/token.rb', line 217

def id
  @id
end

#last4Object (readonly)

The last four digits of the token.



219
220
221
# File 'lib/stripe/resources/issuing/token.rb', line 219

def last4
  @last4
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



221
222
223
# File 'lib/stripe/resources/issuing/token.rb', line 221

def livemode
  @livemode
end

#networkObject (readonly)

The token service provider / card network associated with the token.



223
224
225
# File 'lib/stripe/resources/issuing/token.rb', line 223

def network
  @network
end

#network_dataObject (readonly)

Attribute for field network_data



225
226
227
# File 'lib/stripe/resources/issuing/token.rb', line 225

def network_data
  @network_data
end

#network_updated_atObject (readonly)

Time at which the token was last updated by the card network. Measured in seconds since the Unix epoch.



227
228
229
# File 'lib/stripe/resources/issuing/token.rb', line 227

def network_updated_at
  @network_updated_at
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



229
230
231
# File 'lib/stripe/resources/issuing/token.rb', line 229

def object
  @object
end

#statusObject (readonly)

The usage state of the token.



231
232
233
# File 'lib/stripe/resources/issuing/token.rb', line 231

def status
  @status
end

#wallet_providerObject (readonly)

The digital wallet for this token, if one was used.



233
234
235
# File 'lib/stripe/resources/issuing/token.rb', line 233

def wallet_provider
  @wallet_provider
end

Class Method Details

.field_remappingsObject



254
255
256
# File 'lib/stripe/resources/issuing/token.rb', line 254

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



250
251
252
# File 'lib/stripe/resources/issuing/token.rb', line 250

def self.inner_class_types
  @inner_class_types = { network_data: NetworkData }
end

.list(params = {}, opts = {}) ⇒ Object

Lists all Issuing Token objects for a given card.



236
237
238
# File 'lib/stripe/resources/issuing/token.rb', line 236

def self.list(params = {}, opts = {})
  request_stripe_object(method: :get, path: "/v1/issuing/tokens", params: params, opts: opts)
end

.object_nameObject



12
13
14
# File 'lib/stripe/resources/issuing/token.rb', line 12

def self.object_name
  "issuing.token"
end

.update(token, params = {}, opts = {}) ⇒ Object

Attempts to update the specified Issuing Token object to the status specified.



241
242
243
244
245
246
247
248
# File 'lib/stripe/resources/issuing/token.rb', line 241

def self.update(token, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/issuing/tokens/%<token>s", { token: CGI.escape(token) }),
    params: params,
    opts: opts
  )
end