Class: Stripe::Issuing::Token::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/issuing/token.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(card: nil, created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, status: nil) ⇒ ListParams

Returns a new instance of ListParams.



180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/stripe/resources/issuing/token.rb', line 180

def initialize(
  card: nil,
  created: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  starting_after: nil,
  status: nil
)
  @card = card
  @created = created
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
  @status = status
end

Instance Attribute Details

#cardObject

The Issuing card identifier to list tokens for.



166
167
168
# File 'lib/stripe/resources/issuing/token.rb', line 166

def card
  @card
end

#createdObject

Only return Issuing tokens that were created during the given date interval.



168
169
170
# File 'lib/stripe/resources/issuing/token.rb', line 168

def created
  @created
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



170
171
172
# File 'lib/stripe/resources/issuing/token.rb', line 170

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



172
173
174
# File 'lib/stripe/resources/issuing/token.rb', line 172

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



174
175
176
# File 'lib/stripe/resources/issuing/token.rb', line 174

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



176
177
178
# File 'lib/stripe/resources/issuing/token.rb', line 176

def starting_after
  @starting_after
end

#statusObject

Select Issuing tokens with the given status.



178
179
180
# File 'lib/stripe/resources/issuing/token.rb', line 178

def status
  @status
end