Class: Stripe::Issuing::Token::NetworkData

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/issuing/token.rb

Defined Under Namespace

Classes: Device, Mastercard, Visa, WalletProvider

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#deviceObject (readonly)

Attribute for field device



104
105
106
# File 'lib/stripe/resources/issuing/token.rb', line 104

def device
  @device
end

#mastercardObject (readonly)

Attribute for field mastercard



107
108
109
# File 'lib/stripe/resources/issuing/token.rb', line 107

def mastercard
  @mastercard
end

#typeObject (readonly)

The network that the token is associated with. An additional hash is included with a name matching this value, containing tokenization data specific to the card network.



110
111
112
# File 'lib/stripe/resources/issuing/token.rb', line 110

def type
  @type
end

#visaObject (readonly)

Attribute for field visa



113
114
115
# File 'lib/stripe/resources/issuing/token.rb', line 113

def visa
  @visa
end

#wallet_providerObject (readonly)

Attribute for field wallet_provider



116
117
118
# File 'lib/stripe/resources/issuing/token.rb', line 116

def wallet_provider
  @wallet_provider
end