Class: Stripe::Issuing::TokenService::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/issuing/token_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, status: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



84
85
86
87
# File 'lib/stripe/services/issuing/token_service.rb', line 84

def initialize(expand: nil, status: nil)
  @expand = expand
  @status = status
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



79
80
81
# File 'lib/stripe/services/issuing/token_service.rb', line 79

def expand
  @expand
end

#statusObject

Specifies which status the token should be updated to.



82
83
84
# File 'lib/stripe/services/issuing/token_service.rb', line 82

def status
  @status
end