Class: Stripe::Issuing::Transaction::CreateForceCaptureParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/issuing/transaction.rb

Defined Under Namespace

Classes: MerchantData, PurchaseDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, card: nil, currency: nil, expand: nil, merchant_data: nil, purchase_details: nil) ⇒ CreateForceCaptureParams

Returns a new instance of CreateForceCaptureParams.



702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
# File 'lib/stripe/resources/issuing/transaction.rb', line 702

def initialize(
  amount: nil,
  card: nil,
  currency: nil,
  expand: nil,
  merchant_data: nil,
  purchase_details: nil
)
  @amount = amount
  @card = card
  @currency = currency
  @expand = expand
  @merchant_data = merchant_data
  @purchase_details = purchase_details
end

Instance Attribute Details

#amountObject

The total amount to attempt to capture. This amount is in the provided currency, or defaults to the cards currency, and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).



690
691
692
# File 'lib/stripe/resources/issuing/transaction.rb', line 690

def amount
  @amount
end

#cardObject

Card associated with this transaction.



692
693
694
# File 'lib/stripe/resources/issuing/transaction.rb', line 692

def card
  @card
end

#currencyObject

The currency of the capture. If not provided, defaults to the currency of the card. Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



694
695
696
# File 'lib/stripe/resources/issuing/transaction.rb', line 694

def currency
  @currency
end

#expandObject

Specifies which fields in the response should be expanded.



696
697
698
# File 'lib/stripe/resources/issuing/transaction.rb', line 696

def expand
  @expand
end

#merchant_dataObject

Details about the seller (grocery store, e-commerce website, etc.) where the card authorization happened.



698
699
700
# File 'lib/stripe/resources/issuing/transaction.rb', line 698

def merchant_data
  @merchant_data
end

#purchase_detailsObject

Additional purchase information that is optionally provided by the merchant.



700
701
702
# File 'lib/stripe/resources/issuing/transaction.rb', line 700

def purchase_details
  @purchase_details
end