Class: Stripe::Issuing::Transaction::CreateForceCaptureParams::MerchantData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/issuing/transaction.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(category: nil, city: nil, country: nil, name: nil, network_id: nil, postal_code: nil, state: nil, terminal_id: nil, url: nil) ⇒ MerchantData

Returns a new instance of MerchantData.



302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
# File 'lib/stripe/resources/issuing/transaction.rb', line 302

def initialize(
  category: nil,
  city: nil,
  country: nil,
  name: nil,
  network_id: nil,
  postal_code: nil,
  state: nil,
  terminal_id: nil,
  url: nil
)
  @category = category
  @city = city
  @country = country
  @name = name
  @network_id = network_id
  @postal_code = postal_code
  @state = state
  @terminal_id = terminal_id
  @url = url
end

Instance Attribute Details

#categoryObject

A categorization of the seller’s type of business. See our [merchant categories guide](stripe.com/docs/issuing/merchant-categories) for a list of possible values.



284
285
286
# File 'lib/stripe/resources/issuing/transaction.rb', line 284

def category
  @category
end

#cityObject

City where the seller is located



286
287
288
# File 'lib/stripe/resources/issuing/transaction.rb', line 286

def city
  @city
end

#countryObject

Country where the seller is located



288
289
290
# File 'lib/stripe/resources/issuing/transaction.rb', line 288

def country
  @country
end

#nameObject

Name of the seller



290
291
292
# File 'lib/stripe/resources/issuing/transaction.rb', line 290

def name
  @name
end

#network_idObject

Identifier assigned to the seller by the card network. Different card networks may assign different network_id fields to the same merchant.



292
293
294
# File 'lib/stripe/resources/issuing/transaction.rb', line 292

def network_id
  @network_id
end

#postal_codeObject

Postal code where the seller is located



294
295
296
# File 'lib/stripe/resources/issuing/transaction.rb', line 294

def postal_code
  @postal_code
end

#stateObject

State where the seller is located



296
297
298
# File 'lib/stripe/resources/issuing/transaction.rb', line 296

def state
  @state
end

#terminal_idObject

An ID assigned by the seller to the location of the sale.



298
299
300
# File 'lib/stripe/resources/issuing/transaction.rb', line 298

def terminal_id
  @terminal_id
end

#urlObject

URL provided by the merchant on a 3DS request



300
301
302
# File 'lib/stripe/resources/issuing/transaction.rb', line 300

def url
  @url
end