Class: Stripe::Issuing::Transaction::CreateForceCaptureParams::PurchaseDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::Transaction::CreateForceCaptureParams::PurchaseDetails
- Defined in:
- lib/stripe/resources/issuing/transaction.rb
Defined Under Namespace
Classes: Fleet, Flight, Fuel, Lodging, Receipt
Instance Attribute Summary collapse
-
#fleet ⇒ Object
Fleet-specific information for transactions using Fleet cards.
-
#flight ⇒ Object
Information about the flight that was purchased with this transaction.
-
#fuel ⇒ Object
Information about fuel that was purchased with this transaction.
-
#lodging ⇒ Object
Information about lodging that was purchased with this transaction.
-
#receipt ⇒ Object
The line items in the purchase.
-
#reference ⇒ Object
A merchant-specific order number.
Instance Method Summary collapse
-
#initialize(fleet: nil, flight: nil, fuel: nil, lodging: nil, receipt: nil, reference: nil) ⇒ PurchaseDetails
constructor
A new instance of PurchaseDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(fleet: nil, flight: nil, fuel: nil, lodging: nil, receipt: nil, reference: nil) ⇒ PurchaseDetails
Returns a new instance of PurchaseDetails.
673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 673 def initialize( fleet: nil, flight: nil, fuel: nil, lodging: nil, receipt: nil, reference: nil ) @fleet = fleet @flight = flight @fuel = fuel @lodging = lodging @receipt = receipt @reference = reference end |
Instance Attribute Details
#fleet ⇒ Object
Fleet-specific information for transactions using Fleet cards.
661 662 663 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 661 def fleet @fleet end |
#flight ⇒ Object
Information about the flight that was purchased with this transaction.
663 664 665 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 663 def flight @flight end |
#fuel ⇒ Object
Information about fuel that was purchased with this transaction.
665 666 667 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 665 def fuel @fuel end |
#lodging ⇒ Object
Information about lodging that was purchased with this transaction.
667 668 669 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 667 def lodging @lodging end |
#receipt ⇒ Object
The line items in the purchase.
669 670 671 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 669 def receipt @receipt end |
#reference ⇒ Object
A merchant-specific order number.
671 672 673 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 671 def reference @reference end |