Class: Stripe::Issuing::Transaction::CreateForceCaptureParams::PurchaseDetails::Fleet::ReportedBreakdown::Tax

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/issuing/transaction.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(local_amount_decimal: nil, national_amount_decimal: nil) ⇒ Tax

Returns a new instance of Tax.



370
371
372
373
# File 'lib/stripe/resources/issuing/transaction.rb', line 370

def initialize(local_amount_decimal: nil, national_amount_decimal: nil)
  @local_amount_decimal = local_amount_decimal
  @national_amount_decimal = national_amount_decimal
end

Instance Attribute Details

#local_amount_decimalObject

Amount of state or provincial Sales Tax included in the transaction amount. Null if not reported by merchant or not subject to tax.



366
367
368
# File 'lib/stripe/resources/issuing/transaction.rb', line 366

def local_amount_decimal
  @local_amount_decimal
end

#national_amount_decimalObject

Amount of national Sales Tax or VAT included in the transaction amount. Null if not reported by merchant or not subject to tax.



368
369
370
# File 'lib/stripe/resources/issuing/transaction.rb', line 368

def national_amount_decimal
  @national_amount_decimal
end