Class: Stripe::Issuing::Transaction::CreateForceCaptureParams::PurchaseDetails::Fuel

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/issuing/transaction.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(industry_product_code: nil, quantity_decimal: nil, type: nil, unit: nil, unit_cost_decimal: nil) ⇒ Fuel

Returns a new instance of Fuel.



616
617
618
619
620
621
622
623
624
625
626
627
628
# File 'lib/stripe/resources/issuing/transaction.rb', line 616

def initialize(
  industry_product_code: nil,
  quantity_decimal: nil,
  type: nil,
  unit: nil,
  unit_cost_decimal: nil
)
  @industry_product_code = industry_product_code
  @quantity_decimal = quantity_decimal
  @type = type
  @unit = unit
  @unit_cost_decimal = unit_cost_decimal
end

Instance Attribute Details

#industry_product_codeObject

[Conexxus Payment System Product Code](www.conexxus.org/conexxus-payment-system-product-codes) identifying the primary fuel product purchased.



606
607
608
# File 'lib/stripe/resources/issuing/transaction.rb', line 606

def industry_product_code
  @industry_product_code
end

#quantity_decimalObject

The quantity of ‘unit`s of fuel that was dispensed, represented as a decimal string with at most 12 decimal places.



608
609
610
# File 'lib/stripe/resources/issuing/transaction.rb', line 608

def quantity_decimal
  @quantity_decimal
end

#typeObject

The type of fuel that was purchased. One of ‘diesel`, `unleaded_plus`, `unleaded_regular`, `unleaded_super`, or `other`.



610
611
612
# File 'lib/stripe/resources/issuing/transaction.rb', line 610

def type
  @type
end

#unitObject

The units for ‘quantity_decimal`. One of `charging_minute`, `imperial_gallon`, `kilogram`, `kilowatt_hour`, `liter`, `pound`, `us_gallon`, or `other`.



612
613
614
# File 'lib/stripe/resources/issuing/transaction.rb', line 612

def unit
  @unit
end

#unit_cost_decimalObject

The cost in cents per each unit of fuel, represented as a decimal string with at most 12 decimal places.



614
615
616
# File 'lib/stripe/resources/issuing/transaction.rb', line 614

def unit_cost_decimal
  @unit_cost_decimal
end