Class: Stripe::Issuing::Transaction::CreateUnlinkedRefundParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/issuing/transaction.rb

Defined Under Namespace

Classes: MerchantData, PurchaseDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, card: nil, currency: nil, expand: nil, merchant_data: nil, purchase_details: nil) ⇒ CreateUnlinkedRefundParams

Returns a new instance of CreateUnlinkedRefundParams.



1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
1026
# File 'lib/stripe/resources/issuing/transaction.rb', line 1012

def initialize(
  amount: nil,
  card: nil,
  currency: nil,
  expand: nil,
  merchant_data: nil,
  purchase_details: nil
)
  @amount = amount
  @card = card
  @currency = currency
  @expand = expand
  @merchant_data = merchant_data
  @purchase_details = purchase_details
end

Instance Attribute Details

#amountObject

The total amount to attempt to refund. This amount is in the provided currency, or defaults to the cards currency, and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).



1000
1001
1002
# File 'lib/stripe/resources/issuing/transaction.rb', line 1000

def amount
  @amount
end

#cardObject

Card associated with this unlinked refund transaction.



1002
1003
1004
# File 'lib/stripe/resources/issuing/transaction.rb', line 1002

def card
  @card
end

#currencyObject

The currency of the unlinked refund. If not provided, defaults to the currency of the card. Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



1004
1005
1006
# File 'lib/stripe/resources/issuing/transaction.rb', line 1004

def currency
  @currency
end

#expandObject

Specifies which fields in the response should be expanded.



1006
1007
1008
# File 'lib/stripe/resources/issuing/transaction.rb', line 1006

def expand
  @expand
end

#merchant_dataObject

Details about the seller (grocery store, e-commerce website, etc.) where the card authorization happened.



1008
1009
1010
# File 'lib/stripe/resources/issuing/transaction.rb', line 1008

def merchant_data
  @merchant_data
end

#purchase_detailsObject

Additional purchase information that is optionally provided by the merchant.



1010
1011
1012
# File 'lib/stripe/resources/issuing/transaction.rb', line 1010

def purchase_details
  @purchase_details
end