Class: Stripe::Issuing::Transaction::CreateUnlinkedRefundParams::MerchantData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/issuing/transaction.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(category: nil, city: nil, country: nil, name: nil, network_id: nil, postal_code: nil, state: nil, terminal_id: nil, url: nil) ⇒ MerchantData

Returns a new instance of MerchantData.



740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
# File 'lib/stripe/resources/issuing/transaction.rb', line 740

def initialize(
  category: nil,
  city: nil,
  country: nil,
  name: nil,
  network_id: nil,
  postal_code: nil,
  state: nil,
  terminal_id: nil,
  url: nil
)
  @category = category
  @city = city
  @country = country
  @name = name
  @network_id = network_id
  @postal_code = postal_code
  @state = state
  @terminal_id = terminal_id
  @url = url
end

Instance Attribute Details

#categoryObject

A categorization of the seller’s type of business. See our [merchant categories guide](stripe.com/docs/issuing/merchant-categories) for a list of possible values.



722
723
724
# File 'lib/stripe/resources/issuing/transaction.rb', line 722

def category
  @category
end

#cityObject

City where the seller is located



724
725
726
# File 'lib/stripe/resources/issuing/transaction.rb', line 724

def city
  @city
end

#countryObject

Country where the seller is located



726
727
728
# File 'lib/stripe/resources/issuing/transaction.rb', line 726

def country
  @country
end

#nameObject

Name of the seller



728
729
730
# File 'lib/stripe/resources/issuing/transaction.rb', line 728

def name
  @name
end

#network_idObject

Identifier assigned to the seller by the card network. Different card networks may assign different network_id fields to the same merchant.



730
731
732
# File 'lib/stripe/resources/issuing/transaction.rb', line 730

def network_id
  @network_id
end

#postal_codeObject

Postal code where the seller is located



732
733
734
# File 'lib/stripe/resources/issuing/transaction.rb', line 732

def postal_code
  @postal_code
end

#stateObject

State where the seller is located



734
735
736
# File 'lib/stripe/resources/issuing/transaction.rb', line 734

def state
  @state
end

#terminal_idObject

An ID assigned by the seller to the location of the sale.



736
737
738
# File 'lib/stripe/resources/issuing/transaction.rb', line 736

def terminal_id
  @terminal_id
end

#urlObject

URL provided by the merchant on a 3DS request



738
739
740
# File 'lib/stripe/resources/issuing/transaction.rb', line 738

def url
  @url
end