Class: Stripe::Issuing::Transaction::CreateUnlinkedRefundParams::PurchaseDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::Transaction::CreateUnlinkedRefundParams::PurchaseDetails
- Defined in:
- lib/stripe/resources/issuing/transaction.rb
Defined Under Namespace
Classes: Fleet, Flight, Fuel, Lodging, Receipt
Instance Attribute Summary collapse
-
#fleet ⇒ Object
Fleet-specific information for transactions using Fleet cards.
-
#flight ⇒ Object
Information about the flight that was purchased with this transaction.
-
#fuel ⇒ Object
Information about fuel that was purchased with this transaction.
-
#lodging ⇒ Object
Information about lodging that was purchased with this transaction.
-
#receipt ⇒ Object
The line items in the purchase.
-
#reference ⇒ Object
A merchant-specific order number.
Instance Method Summary collapse
-
#initialize(fleet: nil, flight: nil, fuel: nil, lodging: nil, receipt: nil, reference: nil) ⇒ PurchaseDetails
constructor
A new instance of PurchaseDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(fleet: nil, flight: nil, fuel: nil, lodging: nil, receipt: nil, reference: nil) ⇒ PurchaseDetails
Returns a new instance of PurchaseDetails.
983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 983 def initialize( fleet: nil, flight: nil, fuel: nil, lodging: nil, receipt: nil, reference: nil ) @fleet = fleet @flight = flight @fuel = fuel @lodging = lodging @receipt = receipt @reference = reference end |
Instance Attribute Details
#fleet ⇒ Object
Fleet-specific information for transactions using Fleet cards.
971 972 973 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 971 def fleet @fleet end |
#flight ⇒ Object
Information about the flight that was purchased with this transaction.
973 974 975 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 973 def flight @flight end |
#fuel ⇒ Object
Information about fuel that was purchased with this transaction.
975 976 977 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 975 def fuel @fuel end |
#lodging ⇒ Object
Information about lodging that was purchased with this transaction.
977 978 979 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 977 def lodging @lodging end |
#receipt ⇒ Object
The line items in the purchase.
979 980 981 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 979 def receipt @receipt end |
#reference ⇒ Object
A merchant-specific order number.
981 982 983 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 981 def reference @reference end |