Class: Stripe::Issuing::Transaction::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::Transaction::ListParams
- Defined in:
- lib/stripe/resources/issuing/transaction.rb
Defined Under Namespace
Classes: Created
Instance Attribute Summary collapse
-
#card ⇒ Object
Only return transactions that belong to the given card.
-
#cardholder ⇒ Object
Only return transactions that belong to the given cardholder.
-
#created ⇒ Object
Only return transactions that were created during the given date interval.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#settlement ⇒ Object
Only return transactions that are associated with the given settlement.
-
#starting_after ⇒ Object
A cursor for use in pagination.
-
#type ⇒ Object
Only return transactions that have the given type.
Instance Method Summary collapse
-
#initialize(card: nil, cardholder: nil, created: nil, ending_before: nil, expand: nil, limit: nil, settlement: nil, starting_after: nil, type: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(card: nil, cardholder: nil, created: nil, ending_before: nil, expand: nil, limit: nil, settlement: nil, starting_after: nil, type: nil) ⇒ ListParams
Returns a new instance of ListParams.
282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 282 def initialize( card: nil, cardholder: nil, created: nil, ending_before: nil, expand: nil, limit: nil, settlement: nil, starting_after: nil, type: nil ) @card = card @cardholder = cardholder @created = created @ending_before = ending_before @expand = @limit = limit @settlement = settlement @starting_after = starting_after @type = type end |
Instance Attribute Details
#card ⇒ Object
Only return transactions that belong to the given card.
256 257 258 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 256 def card @card end |
#cardholder ⇒ Object
Only return transactions that belong to the given cardholder.
259 260 261 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 259 def cardholder @cardholder end |
#created ⇒ Object
Only return transactions that were created during the given date interval.
262 263 264 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 262 def created @created end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
265 266 267 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 265 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
268 269 270 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 268 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
271 272 273 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 271 def limit @limit end |
#settlement ⇒ Object
Only return transactions that are associated with the given settlement.
274 275 276 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 274 def settlement @settlement end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
277 278 279 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 277 def starting_after @starting_after end |
#type ⇒ Object
Only return transactions that have the given type. One of ‘capture` or `refund`.
280 281 282 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 280 def type @type end |