Class: Stripe::Issuing::Transaction::MerchantData

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/issuing/transaction.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#categoryObject (readonly)

A categorization of the seller’s type of business. See our [merchant categories guide](docs.stripe.com/issuing/merchant-categories) for a list of possible values.



152
153
154
# File 'lib/stripe/resources/issuing/transaction.rb', line 152

def category
  @category
end

#category_codeObject (readonly)

The merchant category code for the seller’s business



154
155
156
# File 'lib/stripe/resources/issuing/transaction.rb', line 154

def category_code
  @category_code
end

#cityObject (readonly)

City where the seller is located



156
157
158
# File 'lib/stripe/resources/issuing/transaction.rb', line 156

def city
  @city
end

#countryObject (readonly)

Country where the seller is located



158
159
160
# File 'lib/stripe/resources/issuing/transaction.rb', line 158

def country
  @country
end

#nameObject (readonly)

Name of the seller



160
161
162
# File 'lib/stripe/resources/issuing/transaction.rb', line 160

def name
  @name
end

#network_idObject (readonly)

Identifier assigned to the seller by the card network. Different card networks may assign different network_id fields to the same merchant.



162
163
164
# File 'lib/stripe/resources/issuing/transaction.rb', line 162

def network_id
  @network_id
end

#payment_facilitator_idObject (readonly)

The identifier of the payment facilitator (PayFac) that processed this authorization, as assigned by the card network. Null when the transaction was not processed through a PayFac.



164
165
166
# File 'lib/stripe/resources/issuing/transaction.rb', line 164

def payment_facilitator_id
  @payment_facilitator_id
end

#postal_codeObject (readonly)

Postal code where the seller is located



166
167
168
# File 'lib/stripe/resources/issuing/transaction.rb', line 166

def postal_code
  @postal_code
end

#stateObject (readonly)

State where the seller is located



168
169
170
# File 'lib/stripe/resources/issuing/transaction.rb', line 168

def state
  @state
end

#sub_merchant_idObject (readonly)

The identifier of the sub-merchant involved in this authorization, as assigned by the payment facilitator. Null when the transaction was not processed through a PayFac or when no sub-merchant ID was provided.



170
171
172
# File 'lib/stripe/resources/issuing/transaction.rb', line 170

def sub_merchant_id
  @sub_merchant_id
end

#tax_idObject (readonly)

The seller’s tax identification number. Currently populated for French merchants only.



172
173
174
# File 'lib/stripe/resources/issuing/transaction.rb', line 172

def tax_id
  @tax_id
end

#terminal_idObject (readonly)

An ID assigned by the seller to the location of the sale.



174
175
176
# File 'lib/stripe/resources/issuing/transaction.rb', line 174

def terminal_id
  @terminal_id
end

#urlObject (readonly)

URL provided by the merchant on a 3DS request



176
177
178
# File 'lib/stripe/resources/issuing/transaction.rb', line 176

def url
  @url
end

Class Method Details

.field_remappingsObject



182
183
184
# File 'lib/stripe/resources/issuing/transaction.rb', line 182

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



178
179
180
# File 'lib/stripe/resources/issuing/transaction.rb', line 178

def self.inner_class_types
  @inner_class_types = {}
end