Class: Stripe::Issuing::Transaction::NetworkData

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/issuing/transaction.rb

Defined Under Namespace

Classes: TraceId

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#acquirer_reference_numberObject (readonly)

The network-provided acquirer reference number for this transaction, if available. Use this value for downstream operational workflows such as filing disputes with the card network.



205
206
207
# File 'lib/stripe/resources/issuing/transaction.rb', line 205

def acquirer_reference_number
  @acquirer_reference_number
end

#acquiring_institution_countryObject (readonly)

The two-letter country code of the acquirer (ISO 3166-1 alpha-2).



207
208
209
# File 'lib/stripe/resources/issuing/transaction.rb', line 207

def acquiring_institution_country
  @acquiring_institution_country
end

#acquiring_institution_idObject (readonly)

Identifier assigned to the acquirer by the card network. Sometimes this value is not provided by the network; in this case, the value will be null.



209
210
211
# File 'lib/stripe/resources/issuing/transaction.rb', line 209

def acquiring_institution_id
  @acquiring_institution_id
end

#authorization_codeObject (readonly)

A code created by Stripe which is shared with the merchant to validate the authorization. This field will be populated if the authorization message was approved. The code typically starts with the letter "S", followed by a six-digit number. For example, "S498162". Please note that the code is not guaranteed to be unique across authorizations.



211
212
213
# File 'lib/stripe/resources/issuing/transaction.rb', line 211

def authorization_code
  @authorization_code
end

#processing_dateObject (readonly)

The date the transaction was processed by the card network. This can be different from the date the seller recorded the transaction depending on when the acquirer submits the transaction to the network.



213
214
215
# File 'lib/stripe/resources/issuing/transaction.rb', line 213

def processing_date
  @processing_date
end

#retrieval_reference_numberObject (readonly)

Identifier assigned by the acquirer to track all messages related to this transaction.



215
216
217
# File 'lib/stripe/resources/issuing/transaction.rb', line 215

def retrieval_reference_number
  @retrieval_reference_number
end

#routed_networkObject (readonly)

The card network over which Stripe received the transaction. This field may differ from the associated card’s primary network.



217
218
219
# File 'lib/stripe/resources/issuing/transaction.rb', line 217

def routed_network
  @routed_network
end

#trace_idObject (readonly)

Mastercard identifier assigned by the card network for the transaction.



219
220
221
# File 'lib/stripe/resources/issuing/transaction.rb', line 219

def trace_id
  @trace_id
end

#transaction_idObject (readonly)

Unique identifier for the authorization assigned by the card network used to match subsequent messages, disputes, and transactions.



221
222
223
# File 'lib/stripe/resources/issuing/transaction.rb', line 221

def transaction_id
  @transaction_id
end

Class Method Details

.field_remappingsObject



227
228
229
# File 'lib/stripe/resources/issuing/transaction.rb', line 227

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



223
224
225
# File 'lib/stripe/resources/issuing/transaction.rb', line 223

def self.inner_class_types
  @inner_class_types = { trace_id: TraceId }
end