Class: Stripe::Issuing::Transaction::NetworkData::TraceId
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Issuing::Transaction::NetworkData::TraceId
- Defined in:
- lib/stripe/resources/issuing/transaction.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#banknet_reference_number ⇒ Object
readonly
The unique reference number within the specified financial network on the specified network date.
-
#financial_network_code ⇒ Object
readonly
The identifier of the program or service.
-
#network_date ⇒ Object
readonly
The card network's record date for this transaction.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#banknet_reference_number ⇒ Object (readonly)
The unique reference number within the specified financial network on the specified network date.
190 191 192 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 190 def banknet_reference_number @banknet_reference_number end |
#financial_network_code ⇒ Object (readonly)
The identifier of the program or service.
192 193 194 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 192 def financial_network_code @financial_network_code end |
#network_date ⇒ Object (readonly)
The card network's record date for this transaction.
194 195 196 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 194 def network_date @network_date end |
Class Method Details
.field_remappings ⇒ Object
200 201 202 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 200 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
196 197 198 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 196 def self.inner_class_types @inner_class_types = {} end |