Class: Stripe::Issuing::Transaction::PurchaseDetails::Fleet

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/issuing/transaction.rb

Defined Under Namespace

Classes: CardholderPromptData, ReportedBreakdown

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#cardholder_prompt_dataObject (readonly)

Answers to prompts presented to cardholder at point of sale.



194
195
196
# File 'lib/stripe/resources/issuing/transaction.rb', line 194

def cardholder_prompt_data
  @cardholder_prompt_data
end

#purchase_typeObject (readonly)

The type of purchase. One of fuel_purchase, non_fuel_purchase, or fuel_and_non_fuel_purchase.



196
197
198
# File 'lib/stripe/resources/issuing/transaction.rb', line 196

def purchase_type
  @purchase_type
end

#reported_breakdownObject (readonly)

More information about the total amount. This information is not guaranteed to be accurate as some merchants may provide unreliable data.



198
199
200
# File 'lib/stripe/resources/issuing/transaction.rb', line 198

def reported_breakdown
  @reported_breakdown
end

#service_typeObject (readonly)

The type of fuel service. One of non_fuel_transaction, full_service, or self_service.



200
201
202
# File 'lib/stripe/resources/issuing/transaction.rb', line 200

def service_type
  @service_type
end

Class Method Details

.field_encodingsObject



213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/stripe/resources/issuing/transaction.rb', line 213

def self.field_encodings
  @field_encodings = {
    reported_breakdown: {
      kind: :object,
      fields: {
        fuel: { kind: :object, fields: { gross_amount_decimal: :decimal_string } },
        non_fuel: { kind: :object, fields: { gross_amount_decimal: :decimal_string } },
        tax: {
          kind: :object,
          fields: {
            local_amount_decimal: :decimal_string,
            national_amount_decimal: :decimal_string,
          },
        },
      },
    },
  }
end

.field_remappingsObject



209
210
211
# File 'lib/stripe/resources/issuing/transaction.rb', line 209

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



202
203
204
205
206
207
# File 'lib/stripe/resources/issuing/transaction.rb', line 202

def self.inner_class_types
  @inner_class_types = {
    cardholder_prompt_data: CardholderPromptData,
    reported_breakdown: ReportedBreakdown,
  }
end