Class: Stripe::Issuing::Transaction::PurchaseDetails::Fleet::ReportedBreakdown::Tax
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Issuing::Transaction::PurchaseDetails::Fleet::ReportedBreakdown::Tax
- Defined in:
- lib/stripe/resources/issuing/transaction.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#local_amount_decimal ⇒ Object
readonly
Amount of state or provincial Sales Tax included in the transaction amount.
-
#national_amount_decimal ⇒ Object
readonly
Amount of national Sales Tax or VAT included in the transaction amount.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#local_amount_decimal ⇒ Object (readonly)
Amount of state or provincial Sales Tax included in the transaction amount. Null if not reported by merchant or not subject to tax.
264 265 266 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 264 def local_amount_decimal @local_amount_decimal end |
#national_amount_decimal ⇒ Object (readonly)
Amount of national Sales Tax or VAT included in the transaction amount. Null if not reported by merchant or not subject to tax.
266 267 268 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 266 def national_amount_decimal @national_amount_decimal end |
Class Method Details
.field_encodings ⇒ Object
276 277 278 279 280 281 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 276 def self.field_encodings @field_encodings = { local_amount_decimal: :decimal_string, national_amount_decimal: :decimal_string, } end |
.field_remappings ⇒ Object
272 273 274 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 272 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
268 269 270 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 268 def self.inner_class_types @inner_class_types = {} end |