Class: Stripe::Issuing::Transaction::PurchaseDetails::Fuel

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/issuing/transaction.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#industry_product_codeObject (readonly)

Conexxus Payment System Product Code identifying the primary fuel product purchased.



458
459
460
# File 'lib/stripe/resources/issuing/transaction.rb', line 458

def industry_product_code
  @industry_product_code
end

#quantity_decimalObject (readonly)

The quantity of units of fuel that was dispensed, represented as a decimal string with at most 12 decimal places.



460
461
462
# File 'lib/stripe/resources/issuing/transaction.rb', line 460

def quantity_decimal
  @quantity_decimal
end

#typeObject (readonly)

The type of fuel that was purchased. One of diesel, unleaded_plus, unleaded_regular, unleaded_super, or other.



462
463
464
# File 'lib/stripe/resources/issuing/transaction.rb', line 462

def type
  @type
end

#unitObject (readonly)

The units for quantity_decimal. One of charging_minute, imperial_gallon, kilogram, kilowatt_hour, liter, pound, us_gallon, or other.



464
465
466
# File 'lib/stripe/resources/issuing/transaction.rb', line 464

def unit
  @unit
end

#unit_cost_decimalObject (readonly)

The cost in cents per each unit of fuel, represented as a decimal string with at most 12 decimal places.



466
467
468
# File 'lib/stripe/resources/issuing/transaction.rb', line 466

def unit_cost_decimal
  @unit_cost_decimal
end

Class Method Details

.field_encodingsObject



476
477
478
479
480
481
# File 'lib/stripe/resources/issuing/transaction.rb', line 476

def self.field_encodings
  @field_encodings = {
    quantity_decimal: { kind: :nullable, inner: :decimal_string },
    unit_cost_decimal: :decimal_string,
  }
end

.field_remappingsObject



472
473
474
# File 'lib/stripe/resources/issuing/transaction.rb', line 472

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



468
469
470
# File 'lib/stripe/resources/issuing/transaction.rb', line 468

def self.inner_class_types
  @inner_class_types = {}
end