Class: Stripe::Issuing::Transaction::TestHelpers

Inherits:
APIResourceTestHelpers show all
Defined in:
lib/stripe/resources/issuing/transaction.rb

Constant Summary collapse

RESOURCE_CLASS =
Transaction

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from APIResourceTestHelpers

custom_method, #initialize, resource_url, #resource_url

Methods included from APIOperations::Request

included

Constructor Details

This class inherits a constructor from Stripe::APIResourceTestHelpers

Class Method Details

.create_force_capture(params = {}, opts = {}) ⇒ Object

Allows the user to capture an arbitrary amount, also known as a forced capture.



547
548
549
550
551
552
553
554
# File 'lib/stripe/resources/issuing/transaction.rb', line 547

def self.create_force_capture(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/test_helpers/issuing/transactions/create_force_capture",
    params: params,
    opts: opts
  )
end

.create_unlinked_refund(params = {}, opts = {}) ⇒ Object

Allows the user to refund an arbitrary amount, also known as a unlinked refund.



557
558
559
560
561
562
563
564
# File 'lib/stripe/resources/issuing/transaction.rb', line 557

def self.create_unlinked_refund(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/test_helpers/issuing/transactions/create_unlinked_refund",
    params: params,
    opts: opts
  )
end

.refund(transaction, params = {}, opts = {}) ⇒ Object

Refund a test-mode Transaction.



567
568
569
570
571
572
573
574
# File 'lib/stripe/resources/issuing/transaction.rb', line 567

def self.refund(transaction, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/test_helpers/issuing/transactions/%<transaction>s/refund", { transaction: CGI.escape(transaction) }),
    params: params,
    opts: opts
  )
end

.resource_classObject



542
543
544
# File 'lib/stripe/resources/issuing/transaction.rb', line 542

def self.resource_class
  "Transaction"
end

Instance Method Details

#refund(params = {}, opts = {}) ⇒ Object

Refund a test-mode Transaction.



577
578
579
580
581
582
583
584
# File 'lib/stripe/resources/issuing/transaction.rb', line 577

def refund(params = {}, opts = {})
  @resource.request_stripe_object(
    method: :post,
    path: format("/v1/test_helpers/issuing/transactions/%<transaction>s/refund", { transaction: CGI.escape(@resource["id"]) }),
    params: params,
    opts: opts
  )
end