Class: Stripe::Issuing::TransactionCreateUnlinkedRefundParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/issuing/transaction_create_unlinked_refund_params.rb

Defined Under Namespace

Classes: MerchantData, PurchaseDetails

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(amount: nil, card: nil, currency: nil, expand: nil, merchant_data: nil, purchase_details: nil) ⇒ TransactionCreateUnlinkedRefundParams

Returns a new instance of TransactionCreateUnlinkedRefundParams.



438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
# File 'lib/stripe/params/issuing/transaction_create_unlinked_refund_params.rb', line 438

def initialize(
  amount: nil,
  card: nil,
  currency: nil,
  expand: nil,
  merchant_data: nil,
  purchase_details: nil
)
  @amount = amount
  @card = card
  @currency = currency
  @expand = expand
  @merchant_data = merchant_data
  @purchase_details = purchase_details
end

Instance Attribute Details

#amountObject

The total amount to attempt to refund. This amount is in the provided currency, or defaults to the cards currency, and in the smallest currency unit.



426
427
428
# File 'lib/stripe/params/issuing/transaction_create_unlinked_refund_params.rb', line 426

def amount
  @amount
end

#cardObject

Card associated with this unlinked refund transaction.



428
429
430
# File 'lib/stripe/params/issuing/transaction_create_unlinked_refund_params.rb', line 428

def card
  @card
end

#currencyObject

The currency of the unlinked refund. If not provided, defaults to the currency of the card. Three-letter ISO currency code, in lowercase. Must be a supported currency.



430
431
432
# File 'lib/stripe/params/issuing/transaction_create_unlinked_refund_params.rb', line 430

def currency
  @currency
end

#expandObject

Specifies which fields in the response should be expanded.



432
433
434
# File 'lib/stripe/params/issuing/transaction_create_unlinked_refund_params.rb', line 432

def expand
  @expand
end

#merchant_dataObject

Details about the seller (grocery store, e-commerce website, etc.) where the card authorization happened.



434
435
436
# File 'lib/stripe/params/issuing/transaction_create_unlinked_refund_params.rb', line 434

def merchant_data
  @merchant_data
end

#purchase_detailsObject

Additional purchase information that is optionally provided by the merchant.



436
437
438
# File 'lib/stripe/params/issuing/transaction_create_unlinked_refund_params.rb', line 436

def purchase_details
  @purchase_details
end

Class Method Details

.field_encodingsObject



454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
# File 'lib/stripe/params/issuing/transaction_create_unlinked_refund_params.rb', line 454

def self.field_encodings
  @field_encodings = {
    purchase_details: {
      kind: :object,
      fields: {
        fleet: {
          kind: :object,
          fields: {
            reported_breakdown: {
              kind: :object,
              fields: {
                fuel: { kind: :object, fields: { gross_amount_decimal: :decimal_string } },
                non_fuel: { kind: :object, fields: { gross_amount_decimal: :decimal_string } },
                tax: {
                  kind: :object,
                  fields: {
                    local_amount_decimal: :decimal_string,
                    national_amount_decimal: :decimal_string,
                  },
                },
              },
            },
          },
        },
        fuel: {
          kind: :object,
          fields: { quantity_decimal: :decimal_string, unit_cost_decimal: :decimal_string },
        },
        receipt: {
          kind: :array,
          element: { kind: :object, fields: { quantity: :decimal_string } },
        },
      },
    },
  }
end