Class: Stripe::Mandate

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/mandate.rb

Overview

A Mandate is a record of the permission that your customer gives you to debit their payment method.

Defined Under Namespace

Classes: CustomerAcceptance, MultiUse, PaymentMethodDetails, SingleUse

Constant Summary collapse

OBJECT_NAME =
"mandate"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#customer_acceptance ⇒ Object (readonly)

Attribute for field customer_acceptance



466
467
468
# File 'lib/stripe/resources/mandate.rb', line 466

def customer_acceptance
  @customer_acceptance
end

#id ⇒ Object (readonly)

Unique identifier for the object.



468
469
470
# File 'lib/stripe/resources/mandate.rb', line 468

def id
  @id
end

#livemode ⇒ Object (readonly)

If the object exists in live mode, the value is true. If the object exists in test mode, the value is false.



470
471
472
# File 'lib/stripe/resources/mandate.rb', line 470

def livemode
  @livemode
end

#multi_use ⇒ Object (readonly)

Attribute for field multi_use



472
473
474
# File 'lib/stripe/resources/mandate.rb', line 472

def multi_use
  @multi_use
end

#object ⇒ Object (readonly)

String representing the object's type. Objects of the same type share the same value.



474
475
476
# File 'lib/stripe/resources/mandate.rb', line 474

def object
  @object
end

#on_behalf_of ⇒ Object (readonly)

The account (if any) that the mandate is intended for.



476
477
478
# File 'lib/stripe/resources/mandate.rb', line 476

def on_behalf_of
  @on_behalf_of
end

#payment_method ⇒ Object (readonly)

ID of the payment method associated with this mandate.



478
479
480
# File 'lib/stripe/resources/mandate.rb', line 478

def payment_method
  @payment_method
end

#payment_method_details ⇒ Object (readonly)

Attribute for field payment_method_details



480
481
482
# File 'lib/stripe/resources/mandate.rb', line 480

def payment_method_details
  @payment_method_details
end

#single_use ⇒ Object (readonly)

Attribute for field single_use



482
483
484
# File 'lib/stripe/resources/mandate.rb', line 482

def single_use
  @single_use
end

#status ⇒ Object (readonly)

The mandate status indicates whether or not you can use it to initiate a payment.



484
485
486
# File 'lib/stripe/resources/mandate.rb', line 484

def status
  @status
end

#type ⇒ Object (readonly)

The type of the mandate.



486
487
488
# File 'lib/stripe/resources/mandate.rb', line 486

def type
  @type
end

Class Method Details

.field_remappings ⇒ Object



497
498
499
# File 'lib/stripe/resources/mandate.rb', line 497

def self.field_remappings
  @field_remappings = {}
end

.inner_class_types ⇒ Object



488
489
490
491
492
493
494
495
# File 'lib/stripe/resources/mandate.rb', line 488

def self.inner_class_types
  @inner_class_types = {
    customer_acceptance: CustomerAcceptance,
    multi_use: MultiUse,
    payment_method_details: PaymentMethodDetails,
    single_use: SingleUse,
  }
end

.object_name ⇒ Object



8
9
10
# File 'lib/stripe/resources/mandate.rb', line 8

def self.object_name
  "mandate"
end