Class: Stripe::Mandate::CustomerAcceptance
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Mandate::CustomerAcceptance
- Defined in:
- lib/stripe/resources/mandate.rb
Defined Under Namespace
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#accepted_at ⇒ Object
readonly
The time that the customer accepts the mandate.
-
#offline ⇒ Object
readonly
Attribute for field offline.
-
#online ⇒ Object
readonly
Attribute for field online.
-
#type ⇒ Object
readonly
The mandate includes the type of customer acceptance information, such as: ‘online` or `offline`.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#accepted_at ⇒ Object (readonly)
The time that the customer accepts the mandate.
22 23 24 |
# File 'lib/stripe/resources/mandate.rb', line 22 def accepted_at @accepted_at end |
#offline ⇒ Object (readonly)
Attribute for field offline
24 25 26 |
# File 'lib/stripe/resources/mandate.rb', line 24 def offline @offline end |
#online ⇒ Object (readonly)
Attribute for field online
26 27 28 |
# File 'lib/stripe/resources/mandate.rb', line 26 def online @online end |
#type ⇒ Object (readonly)
The mandate includes the type of customer acceptance information, such as: ‘online` or `offline`.
28 29 30 |
# File 'lib/stripe/resources/mandate.rb', line 28 def type @type end |