Class: Stripe::Mandate::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/mandate.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(ending_before: nil, expand: nil, limit: nil, on_behalf_of: nil, payment_method: nil, starting_after: nil, status: nil) ⇒ ListParams

Returns a new instance of ListParams.



417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
# File 'lib/stripe/resources/mandate.rb', line 417

def initialize(
  ending_before: nil,
  expand: nil,
  limit: nil,
  on_behalf_of: nil,
  payment_method: nil,
  starting_after: nil,
  status: nil
)
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @on_behalf_of = on_behalf_of
  @payment_method = payment_method
  @starting_after = starting_after
  @status = status
end

Instance Attribute Details

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



403
404
405
# File 'lib/stripe/resources/mandate.rb', line 403

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



405
406
407
# File 'lib/stripe/resources/mandate.rb', line 405

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



407
408
409
# File 'lib/stripe/resources/mandate.rb', line 407

def limit
  @limit
end

#on_behalf_ofObject

The Stripe account ID that the mandates are intended for. Learn more about the [use case for connected accounts payments](stripe.com/docs/payments/connected-accounts).



409
410
411
# File 'lib/stripe/resources/mandate.rb', line 409

def on_behalf_of
  @on_behalf_of
end

#payment_methodObject

Attribute for param field payment_method



411
412
413
# File 'lib/stripe/resources/mandate.rb', line 411

def payment_method
  @payment_method
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



413
414
415
# File 'lib/stripe/resources/mandate.rb', line 413

def starting_after
  @starting_after
end

#statusObject

The status of the mandates to retrieve. Status indicates whether or not you can use it to initiate a payment, and can have a value of ‘active`, `pending`, or `inactive`.



415
416
417
# File 'lib/stripe/resources/mandate.rb', line 415

def status
  @status
end