Class: Stripe::Mandate::MultiUse
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Mandate::MultiUse
- Defined in:
- lib/stripe/resources/mandate.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The amount of the payment on a multi use mandate.
-
#currency ⇒ Object
readonly
The currency of the payment on a multi use mandate.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The amount of the payment on a multi use mandate.
59 60 61 |
# File 'lib/stripe/resources/mandate.rb', line 59 def amount @amount end |
#currency ⇒ Object (readonly)
The currency of the payment on a multi use mandate.
61 62 63 |
# File 'lib/stripe/resources/mandate.rb', line 61 def currency @currency end |
Class Method Details
.field_remappings ⇒ Object
67 68 69 |
# File 'lib/stripe/resources/mandate.rb', line 67 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
63 64 65 |
# File 'lib/stripe/resources/mandate.rb', line 63 def self.inner_class_types @inner_class_types = {} end |