Class: Stripe::Mandate::PaymentMethodDetails::BacsDebit

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/mandate.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#display_nameObject (readonly)

The display name for the account on this mandate.



117
118
119
# File 'lib/stripe/resources/mandate.rb', line 117

def display_name
  @display_name
end

#network_statusObject (readonly)

The status of the mandate on the Bacs network. Can be one of ‘pending`, `revoked`, `refused`, or `accepted`.



119
120
121
# File 'lib/stripe/resources/mandate.rb', line 119

def network_status
  @network_status
end

#referenceObject (readonly)

The unique reference identifying the mandate on the Bacs network.



121
122
123
# File 'lib/stripe/resources/mandate.rb', line 121

def reference
  @reference
end

#revocation_reasonObject (readonly)

When the mandate is revoked on the Bacs network this field displays the reason for the revocation.



123
124
125
# File 'lib/stripe/resources/mandate.rb', line 123

def revocation_reason
  @revocation_reason
end

#service_user_numberObject (readonly)

The service user number for the account on this mandate.



125
126
127
# File 'lib/stripe/resources/mandate.rb', line 125

def service_user_number
  @service_user_number
end

#urlObject (readonly)

The URL that will contain the mandate that the customer has signed.



127
128
129
# File 'lib/stripe/resources/mandate.rb', line 127

def url
  @url
end

Class Method Details

.field_remappingsObject



133
134
135
# File 'lib/stripe/resources/mandate.rb', line 133

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



129
130
131
# File 'lib/stripe/resources/mandate.rb', line 129

def self.inner_class_types
  @inner_class_types = {}
end