Class: Stripe::Mandate::PaymentMethodDetails::Card::India

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/mandate.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#inactive_reason ⇒ Object (readonly)

The reason why the mandate has an inactive status. This field is only populated if the mandate is inactive.



154
155
156
# File 'lib/stripe/resources/mandate.rb', line 154

def inactive_reason
  @inactive_reason
end

Class Method Details

.field_remappings ⇒ Object



160
161
162
# File 'lib/stripe/resources/mandate.rb', line 160

def self.field_remappings
  @field_remappings = {}
end

.inner_class_types ⇒ Object



156
157
158
# File 'lib/stripe/resources/mandate.rb', line 156

def self.inner_class_types
  @inner_class_types = {}
end