Class: Stripe::Mandate::PaymentMethodDetails::Paypal

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/mandate.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#billing_agreement_idObject (readonly)

The PayPal Billing Agreement ID (BAID). This is an ID generated by PayPal which represents the mandate between the merchant and the customer.



235
236
237
# File 'lib/stripe/resources/mandate.rb', line 235

def billing_agreement_id
  @billing_agreement_id
end

#fingerprintObject (readonly)

Uniquely identifies this particular PayPal account. You can use this attribute to check whether two PayPal accounts are the same.



237
238
239
# File 'lib/stripe/resources/mandate.rb', line 237

def fingerprint
  @fingerprint
end

#payer_idObject (readonly)

PayPal account PayerID. This identifier uniquely identifies the PayPal customer.



239
240
241
# File 'lib/stripe/resources/mandate.rb', line 239

def payer_id
  @payer_id
end

#verified_emailObject (readonly)

Owner's verified email. Values are verified or provided by PayPal directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



242
243
244
# File 'lib/stripe/resources/mandate.rb', line 242

def verified_email
  @verified_email
end

Class Method Details

.field_remappingsObject



248
249
250
# File 'lib/stripe/resources/mandate.rb', line 248

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



244
245
246
# File 'lib/stripe/resources/mandate.rb', line 244

def self.inner_class_types
  @inner_class_types = {}
end