Class: Stripe::Mandate::PaymentMethodDetails::Payto
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Mandate::PaymentMethodDetails::Payto
- Defined in:
- lib/stripe/resources/mandate.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
Amount that will be collected.
-
#amount_type ⇒ Object
readonly
The type of amount that will be collected.
-
#end_date ⇒ Object
readonly
Date, in YYYY-MM-DD format, after which payments will not be collected.
-
#payment_schedule ⇒ Object
readonly
The periodicity at which payments will be collected.
-
#payments_per_period ⇒ Object
readonly
The number of payments that will be made during a payment period.
-
#purpose ⇒ Object
readonly
The purpose for which payments are made.
-
#start_date ⇒ Object
readonly
Date, in YYYY-MM-DD format, from which payments will be collected.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
Amount that will be collected. It is required when amount_type is fixed.
255 256 257 |
# File 'lib/stripe/resources/mandate.rb', line 255 def amount @amount end |
#amount_type ⇒ Object (readonly)
The type of amount that will be collected. The amount charged must be exact or up to the value of amount param for fixed or maximum type respectively. Defaults to maximum.
257 258 259 |
# File 'lib/stripe/resources/mandate.rb', line 257 def amount_type @amount_type end |
#end_date ⇒ Object (readonly)
Date, in YYYY-MM-DD format, after which payments will not be collected. Defaults to no end date.
259 260 261 |
# File 'lib/stripe/resources/mandate.rb', line 259 def end_date @end_date end |
#payment_schedule ⇒ Object (readonly)
The periodicity at which payments will be collected. Defaults to adhoc.
261 262 263 |
# File 'lib/stripe/resources/mandate.rb', line 261 def payment_schedule @payment_schedule end |
#payments_per_period ⇒ Object (readonly)
The number of payments that will be made during a payment period. Defaults to 1 except for when payment_schedule is adhoc. In that case, it defaults to no limit.
263 264 265 |
# File 'lib/stripe/resources/mandate.rb', line 263 def payments_per_period @payments_per_period end |
#purpose ⇒ Object (readonly)
The purpose for which payments are made. Has a default value based on your merchant category code.
265 266 267 |
# File 'lib/stripe/resources/mandate.rb', line 265 def purpose @purpose end |
#start_date ⇒ Object (readonly)
Date, in YYYY-MM-DD format, from which payments will be collected. Defaults to confirmation time.
267 268 269 |
# File 'lib/stripe/resources/mandate.rb', line 267 def start_date @start_date end |
Class Method Details
.field_remappings ⇒ Object
273 274 275 |
# File 'lib/stripe/resources/mandate.rb', line 273 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
269 270 271 |
# File 'lib/stripe/resources/mandate.rb', line 269 def self.inner_class_types @inner_class_types = {} end |