Class: Stripe::Mandate::PaymentMethodDetails::Pix
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Mandate::PaymentMethodDetails::Pix
- Defined in:
- lib/stripe/resources/mandate.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount_includes_iof ⇒ Object
readonly
Determines if the amount includes the IOF tax.
-
#amount_type ⇒ Object
readonly
Type of amount.
-
#end_date ⇒ Object
readonly
Date when the mandate expires and no further payments will be charged, in ‘YYYY-MM-DD`.
-
#payment_schedule ⇒ Object
readonly
Schedule at which the future payments will be charged.
-
#reference ⇒ Object
readonly
Subscription name displayed to buyers in their bank app.
-
#start_date ⇒ Object
readonly
Start date of the mandate, in ‘YYYY-MM-DD`.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount_includes_iof ⇒ Object (readonly)
Determines if the amount includes the IOF tax.
265 266 267 |
# File 'lib/stripe/resources/mandate.rb', line 265 def amount_includes_iof @amount_includes_iof end |
#amount_type ⇒ Object (readonly)
Type of amount.
267 268 269 |
# File 'lib/stripe/resources/mandate.rb', line 267 def amount_type @amount_type end |
#end_date ⇒ Object (readonly)
Date when the mandate expires and no further payments will be charged, in ‘YYYY-MM-DD`.
269 270 271 |
# File 'lib/stripe/resources/mandate.rb', line 269 def end_date @end_date end |
#payment_schedule ⇒ Object (readonly)
Schedule at which the future payments will be charged.
271 272 273 |
# File 'lib/stripe/resources/mandate.rb', line 271 def payment_schedule @payment_schedule end |
#reference ⇒ Object (readonly)
Subscription name displayed to buyers in their bank app.
273 274 275 |
# File 'lib/stripe/resources/mandate.rb', line 273 def reference @reference end |
#start_date ⇒ Object (readonly)
Start date of the mandate, in ‘YYYY-MM-DD`.
275 276 277 |
# File 'lib/stripe/resources/mandate.rb', line 275 def start_date @start_date end |
Class Method Details
.field_remappings ⇒ Object
281 282 283 |
# File 'lib/stripe/resources/mandate.rb', line 281 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
277 278 279 |
# File 'lib/stripe/resources/mandate.rb', line 277 def self.inner_class_types @inner_class_types = {} end |