Class: Stripe::MandateListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/mandate_list_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(ending_before: nil, expand: nil, limit: nil, on_behalf_of: nil, payment_method: nil, starting_after: nil, status: nil) ⇒ MandateListParams

Returns a new instance of MandateListParams.



21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
# File 'lib/stripe/params/mandate_list_params.rb', line 21

def initialize(
  ending_before: nil,
  expand: nil,
  limit: nil,
  on_behalf_of: nil,
  payment_method: nil,
  starting_after: nil,
  status: nil
)
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @on_behalf_of = on_behalf_of
  @payment_method = payment_method
  @starting_after = starting_after
  @status = status
end

Instance Attribute Details

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



7
8
9
# File 'lib/stripe/params/mandate_list_params.rb', line 7

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



9
10
11
# File 'lib/stripe/params/mandate_list_params.rb', line 9

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



11
12
13
# File 'lib/stripe/params/mandate_list_params.rb', line 11

def limit
  @limit
end

#on_behalf_ofObject

The Stripe account ID that the mandates are intended for. Learn more about the [use case for connected accounts payments](docs.stripe.com/payments/connected-accounts).



13
14
15
# File 'lib/stripe/params/mandate_list_params.rb', line 13

def on_behalf_of
  @on_behalf_of
end

#payment_methodObject

Attribute for param field payment_method



15
16
17
# File 'lib/stripe/params/mandate_list_params.rb', line 15

def payment_method
  @payment_method
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



17
18
19
# File 'lib/stripe/params/mandate_list_params.rb', line 17

def starting_after
  @starting_after
end

#statusObject

The status of the mandates to retrieve. Status indicates whether or not you can use it to initiate a payment, and can have a value of ‘active`, `pending`, or `inactive`.



19
20
21
# File 'lib/stripe/params/mandate_list_params.rb', line 19

def status
  @status
end