Class: Stripe::MandateService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::MandateService
- Defined in:
- lib/stripe/services/mandate_service.rb
Instance Method Summary collapse
-
#list(params = {}, opts = {}) ⇒ Object
Retrieves a list of Mandates for a given PaymentMethod.
-
#retrieve(mandate, params = {}, opts = {}) ⇒ Object
Retrieves a Mandate object.
Methods inherited from StripeService
#initialize, #request, #request_stream
Constructor Details
This class inherits a constructor from Stripe::StripeService
Instance Method Details
#list(params = {}, opts = {}) ⇒ Object
Retrieves a list of Mandates for a given PaymentMethod.
7 8 9 |
# File 'lib/stripe/services/mandate_service.rb', line 7 def list(params = {}, opts = {}) request(method: :get, path: "/v1/mandates", params: params, opts: opts, base_address: :api) end |
#retrieve(mandate, params = {}, opts = {}) ⇒ Object
Retrieves a Mandate object.
12 13 14 15 16 17 18 19 20 |
# File 'lib/stripe/services/mandate_service.rb', line 12 def retrieve(mandate, params = {}, opts = {}) request( method: :get, path: format("/v1/mandates/%<mandate>s", { mandate: CGI.escape(mandate) }), params: params, opts: opts, base_address: :api ) end |