Class: Stripe::Margin::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/margin.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(active: nil, expand: nil, metadata: nil, name: nil, percent_off: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



50
51
52
53
54
55
56
# File 'lib/stripe/resources/margin.rb', line 50

def initialize(active: nil, expand: nil, metadata: nil, name: nil, percent_off: nil)
  @active = active
  @expand = expand
  @metadata = 
  @name = name
  @percent_off = percent_off
end

Instance Attribute Details

#activeObject

Whether the margin can be applied to invoices, invoice items, or invoice line items or not. Defaults to ‘true`.



40
41
42
# File 'lib/stripe/resources/margin.rb', line 40

def active
  @active
end

#expandObject

Specifies which fields in the response should be expanded.



42
43
44
# File 'lib/stripe/resources/margin.rb', line 42

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



44
45
46
# File 'lib/stripe/resources/margin.rb', line 44

def 
  @metadata
end

#nameObject

Name of the margin, which is displayed to customers, such as on invoices.



46
47
48
# File 'lib/stripe/resources/margin.rb', line 46

def name
  @name
end

#percent_offObject

Percent that will be taken off the subtotal before tax (after all other discounts and promotions) of any invoice to which the margin is applied.



48
49
50
# File 'lib/stripe/resources/margin.rb', line 48

def percent_off
  @percent_off
end