Class: Stripe::MarginCreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/margin_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(active: nil, expand: nil, metadata: nil, name: nil, percent_off: nil) ⇒ MarginCreateParams

Returns a new instance of MarginCreateParams.



17
18
19
20
21
22
23
# File 'lib/stripe/params/margin_create_params.rb', line 17

def initialize(active: nil, expand: nil, metadata: nil, name: nil, percent_off: nil)
  @active = active
  @expand = expand
  @metadata = 
  @name = name
  @percent_off = percent_off
end

Instance Attribute Details

#activeObject

Whether the margin can be applied to invoices, invoice items, or invoice line items or not. Defaults to ‘true`.



7
8
9
# File 'lib/stripe/params/margin_create_params.rb', line 7

def active
  @active
end

#expandObject

Specifies which fields in the response should be expanded.



9
10
11
# File 'lib/stripe/params/margin_create_params.rb', line 9

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



11
12
13
# File 'lib/stripe/params/margin_create_params.rb', line 11

def 
  @metadata
end

#nameObject

Name of the margin, which is displayed to customers, such as on invoices.



13
14
15
# File 'lib/stripe/params/margin_create_params.rb', line 13

def name
  @name
end

#percent_offObject

Percent that will be taken off the subtotal before tax (after all other discounts and promotions) of any invoice to which the margin is applied.



15
16
17
# File 'lib/stripe/params/margin_create_params.rb', line 15

def percent_off
  @percent_off
end