Class: Stripe::MarginService::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/margin_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(active: nil, expand: nil, metadata: nil, name: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



67
68
69
70
71
72
# File 'lib/stripe/services/margin_service.rb', line 67

def initialize(active: nil, expand: nil, metadata: nil, name: nil)
  @active = active
  @expand = expand
  @metadata = 
  @name = name
end

Instance Attribute Details

#activeObject

Whether the margin can be applied to invoices, invoice items, or invoice line items or not.



59
60
61
# File 'lib/stripe/services/margin_service.rb', line 59

def active
  @active
end

#expandObject

Specifies which fields in the response should be expanded.



61
62
63
# File 'lib/stripe/services/margin_service.rb', line 61

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



63
64
65
# File 'lib/stripe/services/margin_service.rb', line 63

def 
  @metadata
end

#nameObject

Name of the margin, which is displayed to customers, such as on invoices.



65
66
67
# File 'lib/stripe/services/margin_service.rb', line 65

def name
  @name
end