Class: Stripe::Orchestration::PaymentAttemptService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::Orchestration::PaymentAttemptService
- Defined in:
- lib/stripe/services/orchestration/payment_attempt_service.rb
Instance Method Summary collapse
-
#retrieve(payment_attempt_record, params = {}, opts = {}) ⇒ Object
Retrieves orchestration information for the given payment attempt record (e.g. return url).
Methods inherited from StripeService
#initialize, #request, #request_stream
Constructor Details
This class inherits a constructor from Stripe::StripeService
Instance Method Details
#retrieve(payment_attempt_record, params = {}, opts = {}) ⇒ Object
Retrieves orchestration information for the given payment attempt record (e.g. return url).
8 9 10 11 12 13 14 15 16 |
# File 'lib/stripe/services/orchestration/payment_attempt_service.rb', line 8 def retrieve(payment_attempt_record, params = {}, opts = {}) request( method: :get, path: format("/v1/orchestration/payment_attempts/%<payment_attempt_record>s", { payment_attempt_record: CGI.escape(payment_attempt_record) }), params: params, opts: opts, base_address: :api ) end |