Class: Stripe::Order::CancelParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Order::CancelParams
- Defined in:
- lib/stripe/resources/order.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ CancelParams
constructor
A new instance of CancelParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ CancelParams
Returns a new instance of CancelParams.
3114 3115 3116 |
# File 'lib/stripe/resources/order.rb', line 3114 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
3112 3113 3114 |
# File 'lib/stripe/resources/order.rb', line 3112 def @expand end |