Class: Stripe::Order::CreateParams::AutomaticTax
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Order::CreateParams::AutomaticTax
- Defined in:
- lib/stripe/resources/order.rb
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Enable automatic tax calculation which will automatically compute tax rates on this order.
Instance Method Summary collapse
-
#initialize(enabled: nil) ⇒ AutomaticTax
constructor
A new instance of AutomaticTax.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil) ⇒ AutomaticTax
Returns a new instance of AutomaticTax.
538 539 540 |
# File 'lib/stripe/resources/order.rb', line 538 def initialize(enabled: nil) @enabled = enabled end |
Instance Attribute Details
#enabled ⇒ Object
Enable automatic tax calculation which will automatically compute tax rates on this order.
536 537 538 |
# File 'lib/stripe/resources/order.rb', line 536 def enabled @enabled end |