Class: Stripe::Order::CreateParams::Credit
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Order::CreateParams::Credit
- Defined in:
- lib/stripe/resources/order.rb
Instance Attribute Summary collapse
-
#gift_card ⇒ Object
The gift card to apply to the order.
-
#type ⇒ Object
The type of credit to apply to the order, only ‘gift_card` currently supported.
Instance Method Summary collapse
-
#initialize(gift_card: nil, type: nil) ⇒ Credit
constructor
A new instance of Credit.
Methods inherited from RequestParams
Constructor Details
#initialize(gift_card: nil, type: nil) ⇒ Credit
Returns a new instance of Credit.
703 704 705 706 |
# File 'lib/stripe/resources/order.rb', line 703 def initialize(gift_card: nil, type: nil) @gift_card = gift_card @type = type end |
Instance Attribute Details
#gift_card ⇒ Object
The gift card to apply to the order.
698 699 700 |
# File 'lib/stripe/resources/order.rb', line 698 def gift_card @gift_card end |
#type ⇒ Object
The type of credit to apply to the order, only ‘gift_card` currently supported.
701 702 703 |
# File 'lib/stripe/resources/order.rb', line 701 def type @type end |