Class: Stripe::Order::CreateParams::Discount

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/order.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



607
608
609
610
611
# File 'lib/stripe/resources/order.rb', line 607

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



601
602
603
# File 'lib/stripe/resources/order.rb', line 601

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



603
604
605
# File 'lib/stripe/resources/order.rb', line 603

def discount
  @discount
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



605
606
607
# File 'lib/stripe/resources/order.rb', line 605

def promotion_code
  @promotion_code
end