Class: Stripe::Order::CreateParams::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Order::CreateParams::LineItem
- Defined in:
- lib/stripe/resources/order.rb
Defined Under Namespace
Classes: Discount, PriceData, ProductData
Instance Attribute Summary collapse
-
#description ⇒ Object
The description for the line item.
-
#discounts ⇒ Object
The discounts applied to this line item.
-
#price ⇒ Object
The ID of a [Price](docs.stripe.com/api/prices) to add to the Order.
-
#price_data ⇒ Object
Data used to generate a new Price object inline.
-
#product ⇒ Object
The ID of a [Product](docs.stripe.com/api/products) to add to the Order.
-
#product_data ⇒ Object
Defines a [Product](docs.stripe.com/api/products) inline and adds it to the Order.
-
#quantity ⇒ Object
The quantity of the line item.
-
#tax_rates ⇒ Object
The tax rates applied to this line item.
Instance Method Summary collapse
-
#initialize(description: nil, discounts: nil, price: nil, price_data: nil, product: nil, product_data: nil, quantity: nil, tax_rates: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(description: nil, discounts: nil, price: nil, price_data: nil, product: nil, product_data: nil, quantity: nil, tax_rates: nil) ⇒ LineItem
Returns a new instance of LineItem.
1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 |
# File 'lib/stripe/resources/order.rb', line 1053 def initialize( description: nil, discounts: nil, price: nil, price_data: nil, product: nil, product_data: nil, quantity: nil, tax_rates: nil ) @description = description @discounts = discounts @price = price @price_data = price_data @product = product @product_data = product_data @quantity = quantity @tax_rates = tax_rates end |
Instance Attribute Details
#description ⇒ Object
The description for the line item. Will default to the name of the associated product.
1025 1026 1027 |
# File 'lib/stripe/resources/order.rb', line 1025 def description @description end |
#discounts ⇒ Object
The discounts applied to this line item.
1027 1028 1029 |
# File 'lib/stripe/resources/order.rb', line 1027 def discounts @discounts end |
#price ⇒ Object
The ID of a [Price](docs.stripe.com/api/prices) to add to the Order.
The ‘price` parameter is an alternative to using the `product` parameter. If each of your products are sold at a single price, you can set `Product.default_price` and then pass the `product` parameter when creating a line item. If your products are sold at several possible prices, use the `price` parameter to explicitly specify which one to use.
1031 1032 1033 |
# File 'lib/stripe/resources/order.rb', line 1031 def price @price end |
#price_data ⇒ Object
Data used to generate a new Price object inline.
The ‘price_data` parameter is an alternative to using the `product` or `price` parameters. If you create a Product upfront and configure a `Product.default_price`, pass the `product` parameter when creating a line item. If you prefer not to define Products upfront, or if you charge variable prices, pass the `price_data` parameter to describe the price for this line item.
Each time you pass ‘price_data` we create a Price for the Product. This Price is hidden in both the Dashboard and API lists and cannot be reused.
1037 1038 1039 |
# File 'lib/stripe/resources/order.rb', line 1037 def price_data @price_data end |
#product ⇒ Object
The ID of a [Product](docs.stripe.com/api/products) to add to the Order.
The Product must have a ‘default_price` specified. Otherwise, specify the price by passing the `price` or `price_data` parameter.
1041 1042 1043 |
# File 'lib/stripe/resources/order.rb', line 1041 def product @product end |
#product_data ⇒ Object
Defines a [Product](docs.stripe.com/api/products) inline and adds it to the Order.
‘product_data` is an alternative to the `product` parameter. If you created a Product upfront, use the `product` parameter to refer to the existing Product. But if you prefer not to create Products upfront, pass the `product_data` parameter to define a Product inline as part of configuring the Order.
‘product_data` automatically creates a Product, just as if you had manually created the Product. If a Product with the same ID already exists, then `product_data` re-uses it to avoid duplicates.
1047 1048 1049 |
# File 'lib/stripe/resources/order.rb', line 1047 def product_data @product_data end |
#quantity ⇒ Object
The quantity of the line item.
1049 1050 1051 |
# File 'lib/stripe/resources/order.rb', line 1049 def quantity @quantity end |
#tax_rates ⇒ Object
The tax rates applied to this line item.
1051 1052 1053 |
# File 'lib/stripe/resources/order.rb', line 1051 def tax_rates @tax_rates end |