Class: Stripe::Order::CreateParams::LineItem::ProductData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/order.rb

Defined Under Namespace

Classes: PackageDimensions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, id: nil, images: nil, metadata: nil, name: nil, package_dimensions: nil, shippable: nil, tax_code: nil, url: nil) ⇒ ProductData

Returns a new instance of ProductData.



1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
# File 'lib/stripe/resources/order.rb', line 1002

def initialize(
  description: nil,
  id: nil,
  images: nil,
  metadata: nil,
  name: nil,
  package_dimensions: nil,
  shippable: nil,
  tax_code: nil,
  url: nil
)
  @description = description
  @id = id
  @images = images
  @metadata = 
  @name = name
  @package_dimensions = package_dimensions
  @shippable = shippable
  @tax_code = tax_code
  @url = url
end

Instance Attribute Details

#descriptionObject

The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.



982
983
984
# File 'lib/stripe/resources/order.rb', line 982

def description
  @description
end

#idObject

A unique identifier for this product.

‘product_data` automatically creates a Product with this ID. If a Product with the same ID already exists, then `product_data` re-uses it to avoid duplicates. If any of the fields in the existing Product are different from the values in `product_data`, `product_data` updates the existing Product with the new information. So set `product_data` to the same string every time you sell the same product, but don’t re-use the same string for different products.



986
987
988
# File 'lib/stripe/resources/order.rb', line 986

def id
  @id
end

#imagesObject

A list of up to 8 URLs of images for this product, meant to be displayable to the customer.



988
989
990
# File 'lib/stripe/resources/order.rb', line 988

def images
  @images
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



990
991
992
# File 'lib/stripe/resources/order.rb', line 990

def 
  @metadata
end

#nameObject

The product’s name, meant to be displayable to the customer.



992
993
994
# File 'lib/stripe/resources/order.rb', line 992

def name
  @name
end

#package_dimensionsObject

The dimensions of this product for shipping purposes.



994
995
996
# File 'lib/stripe/resources/order.rb', line 994

def package_dimensions
  @package_dimensions
end

#shippableObject

Whether this product is shipped (i.e., physical goods).



996
997
998
# File 'lib/stripe/resources/order.rb', line 996

def shippable
  @shippable
end

#tax_codeObject



998
999
1000
# File 'lib/stripe/resources/order.rb', line 998

def tax_code
  @tax_code
end

#urlObject

A URL of a publicly-accessible webpage for this product.



1000
1001
1002
# File 'lib/stripe/resources/order.rb', line 1000

def url
  @url
end