Class: Stripe::Order::CreateParams::Payment::Settings::PaymentMethodOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/order.rb

Defined Under Namespace

Classes: AcssDebit, AfterpayClearpay, Alipay, Bancontact, Card, CustomerBalance, Ideal, Klarna, Link, Oxxo, P24, Paypal, SepaDebit, Sofort, WechatPay

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(acss_debit: nil, afterpay_clearpay: nil, alipay: nil, bancontact: nil, card: nil, customer_balance: nil, ideal: nil, klarna: nil, link: nil, oxxo: nil, p24: nil, paypal: nil, sepa_debit: nil, sofort: nil, wechat_pay: nil) ⇒ PaymentMethodOptions

Returns a new instance of PaymentMethodOptions.



1646
1647
1648
1649
1650
1651
1652
1653
1654
1655
1656
1657
1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
1669
1670
1671
1672
1673
1674
1675
1676
1677
1678
# File 'lib/stripe/resources/order.rb', line 1646

def initialize(
  acss_debit: nil,
  afterpay_clearpay: nil,
  alipay: nil,
  bancontact: nil,
  card: nil,
  customer_balance: nil,
  ideal: nil,
  klarna: nil,
  link: nil,
  oxxo: nil,
  p24: nil,
  paypal: nil,
  sepa_debit: nil,
  sofort: nil,
  wechat_pay: nil
)
  @acss_debit = acss_debit
  @afterpay_clearpay = afterpay_clearpay
  @alipay = alipay
  @bancontact = bancontact
  @card = card
  @customer_balance = customer_balance
  @ideal = ideal
  @klarna = klarna
  @link = link
  @oxxo = oxxo
  @p24 = p24
  @paypal = paypal
  @sepa_debit = sepa_debit
  @sofort = sofort
  @wechat_pay = wechat_pay
end

Instance Attribute Details

#acss_debitObject

If paying by ‘acss_debit`, this sub-hash contains details about the ACSS Debit payment method options to pass to the order’s PaymentIntent.



1616
1617
1618
# File 'lib/stripe/resources/order.rb', line 1616

def acss_debit
  @acss_debit
end

#afterpay_clearpayObject

If paying by ‘afterpay_clearpay`, this sub-hash contains details about the AfterpayClearpay payment method options to pass to the order’s PaymentIntent.



1618
1619
1620
# File 'lib/stripe/resources/order.rb', line 1618

def afterpay_clearpay
  @afterpay_clearpay
end

#alipayObject

If paying by ‘alipay`, this sub-hash contains details about the Alipay payment method options to pass to the order’s PaymentIntent.



1620
1621
1622
# File 'lib/stripe/resources/order.rb', line 1620

def alipay
  @alipay
end

#bancontactObject

If paying by ‘bancontact`, this sub-hash contains details about the Bancontact payment method options to pass to the order’s PaymentIntent.



1622
1623
1624
# File 'lib/stripe/resources/order.rb', line 1622

def bancontact
  @bancontact
end

#cardObject

If paying by ‘card`, this sub-hash contains details about the Card payment method options to pass to the order’s PaymentIntent.



1624
1625
1626
# File 'lib/stripe/resources/order.rb', line 1624

def card
  @card
end

#customer_balanceObject

If paying by ‘customer_balance`, this sub-hash contains details about the Customer Balance payment method options to pass to the order’s PaymentIntent.



1626
1627
1628
# File 'lib/stripe/resources/order.rb', line 1626

def customer_balance
  @customer_balance
end

#idealObject

If paying by ‘ideal`, this sub-hash contains details about the iDEAL payment method options to pass to the order’s PaymentIntent.



1628
1629
1630
# File 'lib/stripe/resources/order.rb', line 1628

def ideal
  @ideal
end

#klarnaObject

If paying by ‘klarna`, this sub-hash contains details about the Klarna payment method options to pass to the order’s PaymentIntent.



1630
1631
1632
# File 'lib/stripe/resources/order.rb', line 1630

def klarna
  @klarna
end

If paying by ‘link`, this sub-hash contains details about the Link payment method options to pass to the order’s PaymentIntent.



1632
1633
1634
# File 'lib/stripe/resources/order.rb', line 1632

def link
  @link
end

#oxxoObject

If paying by ‘oxxo`, this sub-hash contains details about the OXXO payment method options to pass to the order’s PaymentIntent.



1634
1635
1636
# File 'lib/stripe/resources/order.rb', line 1634

def oxxo
  @oxxo
end

#p24Object

If paying by ‘p24`, this sub-hash contains details about the P24 payment method options to pass to the order’s PaymentIntent.



1636
1637
1638
# File 'lib/stripe/resources/order.rb', line 1636

def p24
  @p24
end

#paypalObject

If paying by ‘paypal`, this sub-hash contains details about the PayPal payment method options to pass to the order’s PaymentIntent.



1638
1639
1640
# File 'lib/stripe/resources/order.rb', line 1638

def paypal
  @paypal
end

#sepa_debitObject

If paying by ‘sepa_debit`, this sub-hash contains details about the SEPA Debit payment method options to pass to the order’s PaymentIntent.



1640
1641
1642
# File 'lib/stripe/resources/order.rb', line 1640

def sepa_debit
  @sepa_debit
end

#sofortObject

If paying by ‘sofort`, this sub-hash contains details about the Sofort payment method options to pass to the order’s PaymentIntent.



1642
1643
1644
# File 'lib/stripe/resources/order.rb', line 1642

def sofort
  @sofort
end

#wechat_payObject

If paying by ‘wechat_pay`, this sub-hash contains details about the WeChat Pay payment method options to pass to the order’s PaymentIntent.



1644
1645
1646
# File 'lib/stripe/resources/order.rb', line 1644

def wechat_pay
  @wechat_pay
end