Class: Stripe::Order::CreateParams::Payment::Settings::PaymentMethodOptions::Klarna::Subscription::NextBilling

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/order.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, date: nil) ⇒ NextBilling

Returns a new instance of NextBilling.



979
980
981
982
# File 'lib/stripe/resources/order.rb', line 979

def initialize(amount: nil, date: nil)
  @amount = amount
  @date = date
end

Instance Attribute Details

#amountObject

The amount of the next charge for the subscription.



975
976
977
# File 'lib/stripe/resources/order.rb', line 975

def amount
  @amount
end

#dateObject

The date of the next charge for the subscription in YYYY-MM-DD format.



977
978
979
# File 'lib/stripe/resources/order.rb', line 977

def date
  @date
end