Class: Stripe::Order::CreateParams::Payment::Settings::PaymentMethodOptions::Paypal::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/order.rb

Defined Under Namespace

Classes: Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem

Returns a new instance of LineItem.



1476
1477
1478
1479
1480
1481
1482
1483
1484
1485
1486
1487
1488
1489
1490
1491
1492
1493
1494
# File 'lib/stripe/resources/order.rb', line 1476

def initialize(
  category: nil,
  description: nil,
  name: nil,
  quantity: nil,
  sku: nil,
  sold_by: nil,
  tax: nil,
  unit_amount: nil
)
  @category = category
  @description = description
  @name = name
  @quantity = quantity
  @sku = sku
  @sold_by = sold_by
  @tax = tax
  @unit_amount = unit_amount
end

Instance Attribute Details

#categoryObject

Type of the line item.



1460
1461
1462
# File 'lib/stripe/resources/order.rb', line 1460

def category
  @category
end

#descriptionObject

Description of the line item.



1462
1463
1464
# File 'lib/stripe/resources/order.rb', line 1462

def description
  @description
end

#nameObject

Descriptive name of the line item.



1464
1465
1466
# File 'lib/stripe/resources/order.rb', line 1464

def name
  @name
end

#quantityObject

Quantity of the line item. Must be a positive number.



1466
1467
1468
# File 'lib/stripe/resources/order.rb', line 1466

def quantity
  @quantity
end

#skuObject

Client facing stock keeping unit, article number or similar.



1468
1469
1470
# File 'lib/stripe/resources/order.rb', line 1468

def sku
  @sku
end

#sold_byObject

The Stripe account ID of the connected account that sells the item.



1470
1471
1472
# File 'lib/stripe/resources/order.rb', line 1470

def sold_by
  @sold_by
end

#taxObject

The tax information for the line item.



1472
1473
1474
# File 'lib/stripe/resources/order.rb', line 1472

def tax
  @tax
end

#unit_amountObject

Price for a single unit of the line item in minor units. Cannot be a negative number.



1474
1475
1476
# File 'lib/stripe/resources/order.rb', line 1474

def unit_amount
  @unit_amount
end