Class: Stripe::Order::CreateParams::Payment::Settings::PaymentMethodOptions::Paypal::LineItem::Tax
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Order::CreateParams::Payment::Settings::PaymentMethodOptions::Paypal::LineItem::Tax
- Defined in:
- lib/stripe/resources/order.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The tax for a single unit of the line item in minor units.
-
#behavior ⇒ Object
The tax behavior for the line item.
Instance Method Summary collapse
-
#initialize(amount: nil, behavior: nil) ⇒ Tax
constructor
A new instance of Tax.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, behavior: nil) ⇒ Tax
Returns a new instance of Tax.
1122 1123 1124 1125 |
# File 'lib/stripe/resources/order.rb', line 1122 def initialize(amount: nil, behavior: nil) @amount = amount @behavior = behavior end |
Instance Attribute Details
#amount ⇒ Object
The tax for a single unit of the line item in minor units. Cannot be a negative number.
1118 1119 1120 |
# File 'lib/stripe/resources/order.rb', line 1118 def amount @amount end |
#behavior ⇒ Object
The tax behavior for the line item.
1120 1121 1122 |
# File 'lib/stripe/resources/order.rb', line 1120 def behavior @behavior end |