Class: Stripe::Order::CreateParams::Payment::Settings::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/order.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



1687
1688
1689
1690
# File 'lib/stripe/resources/order.rb', line 1687

def initialize(amount: nil, destination: nil)
  @amount = amount
  @destination = destination
end

Instance Attribute Details

#amountObject

The amount that will be transferred automatically when the order is paid. If no amount is set, the full amount is transferred. There cannot be any line items with recurring prices when using this field.



1683
1684
1685
# File 'lib/stripe/resources/order.rb', line 1683

def amount
  @amount
end

#destinationObject

ID of the Connected account receiving the transfer.



1685
1686
1687
# File 'lib/stripe/resources/order.rb', line 1685

def destination
  @destination
end