Class: Stripe::Order::Credit
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Order::Credit
- Defined in:
- lib/stripe/resources/order.rb
Defined Under Namespace
Classes: GiftCard
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The amount of this credit to apply to the order.
-
#gift_card ⇒ Object
readonly
Details for a gift card.
-
#ineligible_line_items ⇒ Object
readonly
Line items on this order that are ineligible for this credit.
-
#type ⇒ Object
readonly
The type of credit to apply to the order, only ‘gift_card` currently supported.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The amount of this credit to apply to the order.
58 59 60 |
# File 'lib/stripe/resources/order.rb', line 58 def amount @amount end |
#gift_card ⇒ Object (readonly)
Details for a gift card.
60 61 62 |
# File 'lib/stripe/resources/order.rb', line 60 def gift_card @gift_card end |
#ineligible_line_items ⇒ Object (readonly)
Line items on this order that are ineligible for this credit
62 63 64 |
# File 'lib/stripe/resources/order.rb', line 62 def ineligible_line_items @ineligible_line_items end |
#type ⇒ Object (readonly)
The type of credit to apply to the order, only ‘gift_card` currently supported.
64 65 66 |
# File 'lib/stripe/resources/order.rb', line 64 def type @type end |