Class: Stripe::Order::ListLineItemsParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Order::ListLineItemsParams
- Defined in:
- lib/stripe/resources/order.rb
Instance Attribute Summary collapse
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#starting_after ⇒ Object
A cursor for use in pagination.
Instance Method Summary collapse
-
#initialize(ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListLineItemsParams
constructor
A new instance of ListLineItemsParams.
Methods inherited from RequestParams
Constructor Details
#initialize(ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListLineItemsParams
Returns a new instance of ListLineItemsParams.
2770 2771 2772 2773 2774 2775 |
# File 'lib/stripe/resources/order.rb', line 2770 def initialize(ending_before: nil, expand: nil, limit: nil, starting_after: nil) @ending_before = ending_before @expand = @limit = limit @starting_after = starting_after end |
Instance Attribute Details
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
2762 2763 2764 |
# File 'lib/stripe/resources/order.rb', line 2762 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2764 2765 2766 |
# File 'lib/stripe/resources/order.rb', line 2764 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
2766 2767 2768 |
# File 'lib/stripe/resources/order.rb', line 2766 def limit @limit end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
2768 2769 2770 |
# File 'lib/stripe/resources/order.rb', line 2768 def starting_after @starting_after end |