Class: Stripe::Order::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/order.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(customer: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



518
519
520
521
522
523
524
525
526
527
528
529
530
# File 'lib/stripe/resources/order.rb', line 518

def initialize(
  customer: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  starting_after: nil
)
  @customer = customer
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
end

Instance Attribute Details

#customerObject

Only return orders for the given customer.



508
509
510
# File 'lib/stripe/resources/order.rb', line 508

def customer
  @customer
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



510
511
512
# File 'lib/stripe/resources/order.rb', line 510

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



512
513
514
# File 'lib/stripe/resources/order.rb', line 512

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



514
515
516
# File 'lib/stripe/resources/order.rb', line 514

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



516
517
518
# File 'lib/stripe/resources/order.rb', line 516

def starting_after
  @starting_after
end