Class: Stripe::Order::Payment::Settings::PaymentMethodOptions::AcssDebit
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Order::Payment::Settings::PaymentMethodOptions::AcssDebit
- Defined in:
- lib/stripe/resources/order.rb
Defined Under Namespace
Classes: MandateOptions
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#mandate_options ⇒ Object
readonly
Attribute for field mandate_options.
-
#setup_future_usage ⇒ Object
readonly
Indicates that you intend to make future payments with this PaymentIntent's payment method.
-
#target_date ⇒ Object
readonly
Controls when Stripe will attempt to debit the funds from the customer's account.
-
#verification_method ⇒ Object
readonly
Bank account verification method.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#mandate_options ⇒ Object (readonly)
Attribute for field mandate_options
112 113 114 |
# File 'lib/stripe/resources/order.rb', line 112 def @mandate_options end |
#setup_future_usage ⇒ Object (readonly)
Indicates that you intend to make future payments with this PaymentIntent's payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.
If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.
When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.
120 121 122 |
# File 'lib/stripe/resources/order.rb', line 120 def setup_future_usage @setup_future_usage end |
#target_date ⇒ Object (readonly)
Controls when Stripe will attempt to debit the funds from the customer's account. The date must be a string in YYYY-MM-DD format. The date must be in the future and between 3 and 15 calendar days from now.
122 123 124 |
# File 'lib/stripe/resources/order.rb', line 122 def target_date @target_date end |
#verification_method ⇒ Object (readonly)
Bank account verification method. The default value is automatic.
124 125 126 |
# File 'lib/stripe/resources/order.rb', line 124 def verification_method @verification_method end |
Class Method Details
.field_remappings ⇒ Object
130 131 132 |
# File 'lib/stripe/resources/order.rb', line 130 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
126 127 128 |
# File 'lib/stripe/resources/order.rb', line 126 def self.inner_class_types @inner_class_types = { mandate_options: MandateOptions } end |