Class: Stripe::Order::Payment::Settings::PaymentMethodOptions::AfterpayClearpay

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/order.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#capture_methodObject (readonly)

Controls when the funds will be captured from the customer’s account.



137
138
139
# File 'lib/stripe/resources/order.rb', line 137

def capture_method
  @capture_method
end

#referenceObject (readonly)

Order identifier shown to the user in Afterpay’s online portal. We recommend using a value that helps you answer any questions a customer might have about the payment. The identifier is limited to 128 characters and may contain only letters, digits, underscores, backslashes and dashes.



139
140
141
# File 'lib/stripe/resources/order.rb', line 139

def reference
  @reference
end

#setup_future_usageObject (readonly)

Indicates that you intend to make future payments with the payment method.

Providing this parameter will [attach the payment method](docs.stripe.com/payments/save-during-payment) to the order’s Customer, if present, after the order’s PaymentIntent is confirmed and any required actions from the user are complete. If no Customer was provided, the payment method can still be [attached](docs.stripe.com/api/payment_methods/attach) to a Customer after the transaction completes.

When processing card payments, Stripe also uses ‘setup_future_usage` to dynamically optimize your payment flow and comply with regional legislation and network rules, such as [SCA](docs.stripe.com/strong-customer-authentication).

If ‘setup_future_usage` is already set and you are performing a request using a publishable key, you may only update the value from `on_session` to `off_session`.



147
148
149
# File 'lib/stripe/resources/order.rb', line 147

def setup_future_usage
  @setup_future_usage
end

Class Method Details

.field_remappingsObject



153
154
155
# File 'lib/stripe/resources/order.rb', line 153

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



149
150
151
# File 'lib/stripe/resources/order.rb', line 149

def self.inner_class_types
  @inner_class_types = {}
end