Class: Stripe::Order::Payment::Settings::PaymentMethodOptions::Card

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/order.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#capture_methodObject (readonly)

Controls when the funds will be captured from the customer's account.



200
201
202
# File 'lib/stripe/resources/order.rb', line 200

def capture_method
  @capture_method
end

#setup_future_usageObject (readonly)

Indicates that you intend to make future payments with the payment method.

Providing this parameter will attach the payment method to the order's Customer, if present, after the order's PaymentIntent is confirmed and any required actions from the user are complete. If no Customer was provided, the payment method can still be attached to a Customer after the transaction completes.

When processing card payments, Stripe also uses setup_future_usage to dynamically optimize your payment flow and comply with regional legislation and network rules, such as SCA.

If setup_future_usage is already set and you are performing a request using a publishable key, you may only update the value from on_session to off_session.



208
209
210
# File 'lib/stripe/resources/order.rb', line 208

def setup_future_usage
  @setup_future_usage
end

Class Method Details

.field_remappingsObject



214
215
216
# File 'lib/stripe/resources/order.rb', line 214

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



210
211
212
# File 'lib/stripe/resources/order.rb', line 210

def self.inner_class_types
  @inner_class_types = {}
end