Class: Stripe::Order::Payment::Settings::PaymentMethodOptions::Paypal::LineItem::Tax
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Order::Payment::Settings::PaymentMethodOptions::Paypal::LineItem::Tax
- Defined in:
- lib/stripe/resources/order.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The tax for a single unit of the line item in minor units.
-
#behavior ⇒ Object
readonly
The tax behavior for the line item.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The tax for a single unit of the line item in minor units. Cannot be a negative number.
381 382 383 |
# File 'lib/stripe/resources/order.rb', line 381 def amount @amount end |
#behavior ⇒ Object (readonly)
The tax behavior for the line item.
383 384 385 |
# File 'lib/stripe/resources/order.rb', line 383 def behavior @behavior end |
Class Method Details
.field_remappings ⇒ Object
389 390 391 |
# File 'lib/stripe/resources/order.rb', line 389 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
385 386 387 |
# File 'lib/stripe/resources/order.rb', line 385 def self.inner_class_types @inner_class_types = {} end |