Class: Stripe::Order::ReopenParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Order::ReopenParams
- Defined in:
- lib/stripe/resources/order.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ ReopenParams
constructor
A new instance of ReopenParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ ReopenParams
Returns a new instance of ReopenParams.
2688 2689 2690 |
# File 'lib/stripe/resources/order.rb', line 2688 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2686 2687 2688 |
# File 'lib/stripe/resources/order.rb', line 2686 def @expand end |