Class: Stripe::Order::RetrieveParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Order::RetrieveParams
- Defined in:
- lib/stripe/resources/order.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ RetrieveParams
constructor
A new instance of RetrieveParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ RetrieveParams
Returns a new instance of RetrieveParams.
1597 1598 1599 |
# File 'lib/stripe/resources/order.rb', line 1597 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1595 1596 1597 |
# File 'lib/stripe/resources/order.rb', line 1595 def @expand end |