Class: Stripe::Order::TaxDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Order::TaxDetails
- Defined in:
- lib/stripe/resources/order.rb
Defined Under Namespace
Classes: TaxId
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#tax_exempt ⇒ Object
readonly
Describes the purchaser’s tax exemption status.
-
#tax_ids ⇒ Object
readonly
The purchaser’s tax IDs to be used in calculation of tax for this Order.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#tax_exempt ⇒ Object (readonly)
Describes the purchaser’s tax exemption status. One of ‘none`, `exempt`, or `reverse`.
737 738 739 |
# File 'lib/stripe/resources/order.rb', line 737 def tax_exempt @tax_exempt end |
#tax_ids ⇒ Object (readonly)
The purchaser’s tax IDs to be used in calculation of tax for this Order.
739 740 741 |
# File 'lib/stripe/resources/order.rb', line 739 def tax_ids @tax_ids end |
Class Method Details
.field_remappings ⇒ Object
745 746 747 |
# File 'lib/stripe/resources/order.rb', line 745 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
741 742 743 |
# File 'lib/stripe/resources/order.rb', line 741 def self.inner_class_types @inner_class_types = { tax_ids: TaxId } end |