Class: Stripe::Order::UpdateParams::AutomaticTax
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Order::UpdateParams::AutomaticTax
- Defined in:
- lib/stripe/resources/order.rb
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Enable automatic tax calculation which will automatically compute tax rates on this order.
Instance Method Summary collapse
-
#initialize(enabled: nil) ⇒ AutomaticTax
constructor
A new instance of AutomaticTax.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil) ⇒ AutomaticTax
Returns a new instance of AutomaticTax.
1641 1642 1643 |
# File 'lib/stripe/resources/order.rb', line 1641 def initialize(enabled: nil) @enabled = enabled end |
Instance Attribute Details
#enabled ⇒ Object
Enable automatic tax calculation which will automatically compute tax rates on this order.
1639 1640 1641 |
# File 'lib/stripe/resources/order.rb', line 1639 def enabled @enabled end |