Class: Stripe::Order::UpdateParams::Discount

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/order.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1702
1703
1704
1705
1706
# File 'lib/stripe/resources/order.rb', line 1702

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1696
1697
1698
# File 'lib/stripe/resources/order.rb', line 1696

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1698
1699
1700
# File 'lib/stripe/resources/order.rb', line 1698

def discount
  @discount
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1700
1701
1702
# File 'lib/stripe/resources/order.rb', line 1700

def promotion_code
  @promotion_code
end