Class: Stripe::Order::UpdateParams::LineItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/order.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil) ⇒ Discount

Returns a new instance of Discount.



2048
2049
2050
2051
# File 'lib/stripe/resources/order.rb', line 2048

def initialize(coupon: nil, discount: nil)
  @coupon = coupon
  @discount = discount
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



2044
2045
2046
# File 'lib/stripe/resources/order.rb', line 2044

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



2046
2047
2048
# File 'lib/stripe/resources/order.rb', line 2046

def discount
  @discount
end