Class: Stripe::Order::UpdateParams::LineItem::ProductData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Order::UpdateParams::LineItem::ProductData
- Defined in:
- lib/stripe/resources/order.rb
Defined Under Namespace
Classes: PackageDimensions
Instance Attribute Summary collapse
-
#description ⇒ Object
The product’s description, meant to be displayable to the customer.
-
#id ⇒ Object
A unique identifier for this product.
-
#images ⇒ Object
A list of up to 8 URLs of images for this product, meant to be displayable to the customer.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#name ⇒ Object
The product’s name, meant to be displayable to the customer.
-
#package_dimensions ⇒ Object
The dimensions of this product for shipping purposes.
-
#shippable ⇒ Object
Whether this product is shipped (i.e., physical goods).
-
#tax_code ⇒ Object
A [tax code](stripe.com/docs/tax/tax-categories) ID.
-
#url ⇒ Object
A URL of a publicly-accessible webpage for this product.
Instance Method Summary collapse
-
#initialize(description: nil, id: nil, images: nil, metadata: nil, name: nil, package_dimensions: nil, shippable: nil, tax_code: nil, url: nil) ⇒ ProductData
constructor
A new instance of ProductData.
Methods inherited from RequestParams
Constructor Details
#initialize(description: nil, id: nil, images: nil, metadata: nil, name: nil, package_dimensions: nil, shippable: nil, tax_code: nil, url: nil) ⇒ ProductData
Returns a new instance of ProductData.
2122 2123 2124 2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 2135 2136 2137 2138 2139 2140 2141 2142 |
# File 'lib/stripe/resources/order.rb', line 2122 def initialize( description: nil, id: nil, images: nil, metadata: nil, name: nil, package_dimensions: nil, shippable: nil, tax_code: nil, url: nil ) @description = description @id = id @images = images @metadata = @name = name @package_dimensions = package_dimensions @shippable = shippable @tax_code = tax_code @url = url end |
Instance Attribute Details
#description ⇒ Object
The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.
2102 2103 2104 |
# File 'lib/stripe/resources/order.rb', line 2102 def description @description end |
#id ⇒ Object
A unique identifier for this product.
‘product_data` automatically creates a Product with this ID. If a Product with the same ID already exists, then `product_data` re-uses it to avoid duplicates. If any of the fields in the existing Product are different from the values in `product_data`, `product_data` updates the existing Product with the new information. So set `product_data` to the same string every time you sell the same product, but don’t re-use the same string for different products.
2106 2107 2108 |
# File 'lib/stripe/resources/order.rb', line 2106 def id @id end |
#images ⇒ Object
A list of up to 8 URLs of images for this product, meant to be displayable to the customer.
2108 2109 2110 |
# File 'lib/stripe/resources/order.rb', line 2108 def images @images end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
2110 2111 2112 |
# File 'lib/stripe/resources/order.rb', line 2110 def @metadata end |
#name ⇒ Object
The product’s name, meant to be displayable to the customer.
2112 2113 2114 |
# File 'lib/stripe/resources/order.rb', line 2112 def name @name end |
#package_dimensions ⇒ Object
The dimensions of this product for shipping purposes.
2114 2115 2116 |
# File 'lib/stripe/resources/order.rb', line 2114 def package_dimensions @package_dimensions end |
#shippable ⇒ Object
Whether this product is shipped (i.e., physical goods).
2116 2117 2118 |
# File 'lib/stripe/resources/order.rb', line 2116 def shippable @shippable end |
#tax_code ⇒ Object
A [tax code](stripe.com/docs/tax/tax-categories) ID.
2118 2119 2120 |
# File 'lib/stripe/resources/order.rb', line 2118 def tax_code @tax_code end |
#url ⇒ Object
A URL of a publicly-accessible webpage for this product.
2120 2121 2122 |
# File 'lib/stripe/resources/order.rb', line 2120 def url @url end |