Class: Stripe::Order::UpdateParams::Payment
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Order::UpdateParams::Payment
- Defined in:
- lib/stripe/resources/order.rb
Defined Under Namespace
Classes: Settings
Instance Attribute Summary collapse
-
#settings ⇒ Object
Settings describing how the order should configure generated PaymentIntents.
Instance Method Summary collapse
-
#initialize(settings: nil) ⇒ Payment
constructor
A new instance of Payment.
Methods inherited from RequestParams
Constructor Details
#initialize(settings: nil) ⇒ Payment
Returns a new instance of Payment.
2368 2369 2370 |
# File 'lib/stripe/resources/order.rb', line 2368 def initialize(settings: nil) @settings = settings end |
Instance Attribute Details
#settings ⇒ Object
Settings describing how the order should configure generated PaymentIntents.
2366 2367 2368 |
# File 'lib/stripe/resources/order.rb', line 2366 def settings @settings end |