Class: Stripe::Order::UpdateParams::Payment::Settings::PaymentMethodOptions::AfterpayClearpay

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/order.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(capture_method: nil, reference: nil, setup_future_usage: nil) ⇒ AfterpayClearpay

Returns a new instance of AfterpayClearpay.



1920
1921
1922
1923
1924
# File 'lib/stripe/resources/order.rb', line 1920

def initialize(capture_method: nil, reference: nil, setup_future_usage: nil)
  @capture_method = capture_method
  @reference = reference
  @setup_future_usage = setup_future_usage
end

Instance Attribute Details

#capture_methodObject

Controls when the funds are captured from the customer’s account.

If provided, this parameter overrides the behavior of the top-level [capture_method](/api/payment_intents/update#update_payment_intent-capture_method) for this payment method type when finalizing the payment with this payment method type.

If ‘capture_method` is already set on the PaymentIntent, providing an empty value for this parameter unsets the stored value for this payment method type.



1908
1909
1910
# File 'lib/stripe/resources/order.rb', line 1908

def capture_method
  @capture_method
end

#referenceObject

An internal identifier or reference this payment corresponds to. The identifier is limited to 128 characters and may contain only letters, digits, underscores, backslashes and dashes.



1910
1911
1912
# File 'lib/stripe/resources/order.rb', line 1910

def reference
  @reference
end

#setup_future_usageObject

Indicates that you intend to make future payments with the payment method.

Providing this parameter will [attach the payment method](stripe.com/docs/payments/save-during-payment) to the order’s Customer, if present, after the order’s PaymentIntent is confirmed and any required actions from the user are complete. If no Customer was provided, the payment method can still be [attached](stripe.com/docs/api/payment_methods/attach) to a Customer after the transaction completes.

When processing card payments, Stripe also uses ‘setup_future_usage` to dynamically optimize your payment flow and comply with regional legislation and network rules, such as [SCA](stripe.com/docs/strong-customer-authentication).

If ‘setup_future_usage` is already set and you are performing a request using a publishable key, you may only update the value from `on_session` to `off_session`.



1918
1919
1920
# File 'lib/stripe/resources/order.rb', line 1918

def setup_future_usage
  @setup_future_usage
end