Class: Stripe::Order::UpdateParams::Payment::Settings::PaymentMethodOptions::Klarna::Subscription::NextBilling

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/order.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, date: nil) ⇒ NextBilling

Returns a new instance of NextBilling.



2103
2104
2105
2106
# File 'lib/stripe/resources/order.rb', line 2103

def initialize(amount: nil, date: nil)
  @amount = amount
  @date = date
end

Instance Attribute Details

#amountObject

The amount of the next charge for the subscription.



2099
2100
2101
# File 'lib/stripe/resources/order.rb', line 2099

def amount
  @amount
end

#dateObject

The date of the next charge for the subscription in YYYY-MM-DD format.



2101
2102
2103
# File 'lib/stripe/resources/order.rb', line 2101

def date
  @date
end