Class: Stripe::Order::UpdateParams::Payment::Settings::PaymentMethodOptions::Paypal::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/order.rb

Defined Under Namespace

Classes: Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem

Returns a new instance of LineItem.



2268
2269
2270
2271
2272
2273
2274
2275
2276
2277
2278
2279
2280
2281
2282
2283
2284
2285
2286
# File 'lib/stripe/resources/order.rb', line 2268

def initialize(
  category: nil,
  description: nil,
  name: nil,
  quantity: nil,
  sku: nil,
  sold_by: nil,
  tax: nil,
  unit_amount: nil
)
  @category = category
  @description = description
  @name = name
  @quantity = quantity
  @sku = sku
  @sold_by = sold_by
  @tax = tax
  @unit_amount = unit_amount
end

Instance Attribute Details

#categoryObject

Type of the line item.



2252
2253
2254
# File 'lib/stripe/resources/order.rb', line 2252

def category
  @category
end

#descriptionObject

Description of the line item.



2254
2255
2256
# File 'lib/stripe/resources/order.rb', line 2254

def description
  @description
end

#nameObject

Descriptive name of the line item.



2256
2257
2258
# File 'lib/stripe/resources/order.rb', line 2256

def name
  @name
end

#quantityObject

Quantity of the line item. Must be a positive number.



2258
2259
2260
# File 'lib/stripe/resources/order.rb', line 2258

def quantity
  @quantity
end

#skuObject

Client facing stock keeping unit, article number or similar.



2260
2261
2262
# File 'lib/stripe/resources/order.rb', line 2260

def sku
  @sku
end

#sold_byObject

The Stripe account ID of the connected account that sells the item.



2262
2263
2264
# File 'lib/stripe/resources/order.rb', line 2262

def sold_by
  @sold_by
end

#taxObject

The tax information for the line item.



2264
2265
2266
# File 'lib/stripe/resources/order.rb', line 2264

def tax
  @tax
end

#unit_amountObject

Price for a single unit of the line item in minor units. Cannot be a negative number.



2266
2267
2268
# File 'lib/stripe/resources/order.rb', line 2266

def unit_amount
  @unit_amount
end