Class: Stripe::Order::UpdateParams::ShippingCost::ShippingRateData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/order.rb

Defined Under Namespace

Classes: DeliveryEstimate, FixedAmount

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(delivery_estimate: nil, display_name: nil, fixed_amount: nil, metadata: nil, tax_behavior: nil, tax_code: nil, type: nil) ⇒ ShippingRateData

Returns a new instance of ShippingRateData.



2822
2823
2824
2825
2826
2827
2828
2829
2830
2831
2832
2833
2834
2835
2836
2837
2838
# File 'lib/stripe/resources/order.rb', line 2822

def initialize(
  delivery_estimate: nil,
  display_name: nil,
  fixed_amount: nil,
  metadata: nil,
  tax_behavior: nil,
  tax_code: nil,
  type: nil
)
  @delivery_estimate = delivery_estimate
  @display_name = display_name
  @fixed_amount = fixed_amount
  @metadata = 
  @tax_behavior = tax_behavior
  @tax_code = tax_code
  @type = type
end

Instance Attribute Details

#delivery_estimateObject

The estimated range for how long shipping will take, meant to be displayable to the customer. This will appear on CheckoutSessions.



2802
2803
2804
# File 'lib/stripe/resources/order.rb', line 2802

def delivery_estimate
  @delivery_estimate
end

#display_nameObject

The name of the shipping rate, meant to be displayable to the customer. This will appear on CheckoutSessions.



2805
2806
2807
# File 'lib/stripe/resources/order.rb', line 2805

def display_name
  @display_name
end

#fixed_amountObject

Describes a fixed amount to charge for shipping. Must be present if type is ‘fixed_amount`.



2808
2809
2810
# File 'lib/stripe/resources/order.rb', line 2808

def fixed_amount
  @fixed_amount
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2811
2812
2813
# File 'lib/stripe/resources/order.rb', line 2811

def 
  @metadata
end

#tax_behaviorObject

Specifies whether the rate is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`.



2814
2815
2816
# File 'lib/stripe/resources/order.rb', line 2814

def tax_behavior
  @tax_behavior
end

#tax_codeObject

A [tax code](stripe.com/docs/tax/tax-categories) ID. The Shipping tax code is ‘txcd_92010001`.



2817
2818
2819
# File 'lib/stripe/resources/order.rb', line 2817

def tax_code
  @tax_code
end

#typeObject

The type of calculation to use on the shipping rate.



2820
2821
2822
# File 'lib/stripe/resources/order.rb', line 2820

def type
  @type
end