Class: Stripe::Order::UpdateParams::ShippingCost::ShippingRateData::FixedAmount::CurrencyOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/order.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, tax_behavior: nil) ⇒ CurrencyOptions

Returns a new instance of CurrencyOptions.



2569
2570
2571
2572
# File 'lib/stripe/resources/order.rb', line 2569

def initialize(amount: nil, tax_behavior: nil)
  @amount = amount
  @tax_behavior = tax_behavior
end

Instance Attribute Details

#amountObject

A non-negative integer in cents representing how much to charge.



2565
2566
2567
# File 'lib/stripe/resources/order.rb', line 2565

def amount
  @amount
end

#tax_behaviorObject

Specifies whether the rate is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`.



2567
2568
2569
# File 'lib/stripe/resources/order.rb', line 2567

def tax_behavior
  @tax_behavior
end