Class: Stripe::OrderCreateParams::LineItem::ProductData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/order_create_params.rb

Defined Under Namespace

Classes: PackageDimensions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(description: nil, id: nil, images: nil, metadata: nil, name: nil, package_dimensions: nil, shippable: nil, tax_code: nil, url: nil) ⇒ ProductData

Returns a new instance of ProductData.



163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
# File 'lib/stripe/params/order_create_params.rb', line 163

def initialize(
  description: nil,
  id: nil,
  images: nil,
  metadata: nil,
  name: nil,
  package_dimensions: nil,
  shippable: nil,
  tax_code: nil,
  url: nil
)
  @description = description
  @id = id
  @images = images
  @metadata = 
  @name = name
  @package_dimensions = package_dimensions
  @shippable = shippable
  @tax_code = tax_code
  @url = url
end

Instance Attribute Details

#descriptionObject

The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.



143
144
145
# File 'lib/stripe/params/order_create_params.rb', line 143

def description
  @description
end

#idObject

A unique identifier for this product.

‘product_data` automatically creates a Product with this ID. If a Product with the same ID already exists, then `product_data` re-uses it to avoid duplicates. If any of the fields in the existing Product are different from the values in `product_data`, `product_data` updates the existing Product with the new information. So set `product_data` to the same string every time you sell the same product, but don’t re-use the same string for different products.



147
148
149
# File 'lib/stripe/params/order_create_params.rb', line 147

def id
  @id
end

#imagesObject

A list of up to 8 URLs of images for this product, meant to be displayable to the customer.



149
150
151
# File 'lib/stripe/params/order_create_params.rb', line 149

def images
  @images
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



151
152
153
# File 'lib/stripe/params/order_create_params.rb', line 151

def 
  @metadata
end

#nameObject

The product’s name, meant to be displayable to the customer.



153
154
155
# File 'lib/stripe/params/order_create_params.rb', line 153

def name
  @name
end

#package_dimensionsObject

The dimensions of this product for shipping purposes.



155
156
157
# File 'lib/stripe/params/order_create_params.rb', line 155

def package_dimensions
  @package_dimensions
end

#shippableObject

Whether this product is shipped (i.e., physical goods).



157
158
159
# File 'lib/stripe/params/order_create_params.rb', line 157

def shippable
  @shippable
end

#tax_codeObject



159
160
161
# File 'lib/stripe/params/order_create_params.rb', line 159

def tax_code
  @tax_code
end

#urlObject

A URL of a publicly-accessible webpage for this product.



161
162
163
# File 'lib/stripe/params/order_create_params.rb', line 161

def url
  @url
end