Class: Stripe::OrderCreateParams::Payment
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderCreateParams::Payment
- Defined in:
- lib/stripe/params/order_create_params.rb
Defined Under Namespace
Classes: Settings
Instance Attribute Summary collapse
-
#settings ⇒ Object
Settings describing how the order should configure generated PaymentIntents.
Instance Method Summary collapse
-
#initialize(settings: nil) ⇒ Payment
constructor
A new instance of Payment.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(settings: nil) ⇒ Payment
Returns a new instance of Payment.
1832 1833 1834 |
# File 'lib/stripe/params/order_create_params.rb', line 1832 def initialize(settings: nil) @settings = settings end |
Instance Attribute Details
#settings ⇒ Object
Settings describing how the order should configure generated PaymentIntents.
1830 1831 1832 |
# File 'lib/stripe/params/order_create_params.rb', line 1830 def settings @settings end |