Class: Stripe::OrderCreateParams::Payment::Settings::PaymentMethodOptions::AfterpayClearpay

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/order_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(capture_method: nil, reference: nil, setup_future_usage: nil) ⇒ AfterpayClearpay

Returns a new instance of AfterpayClearpay.



348
349
350
351
352
# File 'lib/stripe/params/order_create_params.rb', line 348

def initialize(capture_method: nil, reference: nil, setup_future_usage: nil)
  @capture_method = capture_method
  @reference = reference
  @setup_future_usage = setup_future_usage
end

Instance Attribute Details

#capture_methodObject

Controls when the funds are captured from the customer's account.

If provided, this parameter overrides the behavior of the top-level capture_method for this payment method type when finalizing the payment with this payment method type.

If capture_method is already set on the PaymentIntent, providing an empty value for this parameter unsets the stored value for this payment method type.



336
337
338
# File 'lib/stripe/params/order_create_params.rb', line 336

def capture_method
  @capture_method
end

#referenceObject

An internal identifier or reference this payment corresponds to. The identifier is limited to 128 characters and may contain only letters, digits, underscores, backslashes and dashes.



338
339
340
# File 'lib/stripe/params/order_create_params.rb', line 338

def reference
  @reference
end

#setup_future_usageObject

Indicates that you intend to make future payments with the payment method.

Providing this parameter will attach the payment method to the order's Customer, if present, after the order's PaymentIntent is confirmed and any required actions from the user are complete. If no Customer was provided, the payment method can still be attached to a Customer after the transaction completes.

When processing card payments, Stripe also uses setup_future_usage to dynamically optimize your payment flow and comply with regional legislation and network rules, such as SCA.

If setup_future_usage is already set and you are performing a request using a publishable key, you may only update the value from on_session to off_session.



346
347
348
# File 'lib/stripe/params/order_create_params.rb', line 346

def setup_future_usage
  @setup_future_usage
end