Class: Stripe::OrderCreateParams::Payment::Settings::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::BusReservationDetail::Arrival::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderCreateParams::Payment::Settings::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::BusReservationDetail::Arrival::Address
- Defined in:
- lib/stripe/params/order_create_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 |
# File 'lib/stripe/params/order_create_params.rb', line 557 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
545 546 547 |
# File 'lib/stripe/params/order_create_params.rb', line 545 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
547 548 549 |
# File 'lib/stripe/params/order_create_params.rb', line 547 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
549 550 551 |
# File 'lib/stripe/params/order_create_params.rb', line 549 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
551 552 553 |
# File 'lib/stripe/params/order_create_params.rb', line 551 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
553 554 555 |
# File 'lib/stripe/params/order_create_params.rb', line 553 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
555 556 557 |
# File 'lib/stripe/params/order_create_params.rb', line 555 def street_address2 @street_address2 end |