Class: Stripe::OrderCreateParams::Payment::Settings::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::BusReservationDetail::Departure::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderCreateParams::Payment::Settings::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::BusReservationDetail::Departure::Address
- Defined in:
- lib/stripe/params/order_create_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 |
# File 'lib/stripe/params/order_create_params.rb', line 599 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
587 588 589 |
# File 'lib/stripe/params/order_create_params.rb', line 587 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
589 590 591 |
# File 'lib/stripe/params/order_create_params.rb', line 589 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
591 592 593 |
# File 'lib/stripe/params/order_create_params.rb', line 591 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
593 594 595 |
# File 'lib/stripe/params/order_create_params.rb', line 593 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
595 596 597 |
# File 'lib/stripe/params/order_create_params.rb', line 595 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
597 598 599 |
# File 'lib/stripe/params/order_create_params.rb', line 597 def street_address2 @street_address2 end |