Class: Stripe::OrderCreateParams::Payment::Settings::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::EventReservationDetail

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/order_create_params.rb

Defined Under Namespace

Classes: Address, Insurance

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(access_controlled_venue: nil, address: nil, affiliate_name: nil, ends_at: nil, event_company_name: nil, event_name: nil, event_type: nil, insurances: nil, starts_at: nil, venue_name: nil) ⇒ EventReservationDetail

Returns a new instance of EventReservationDetail.



749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
# File 'lib/stripe/params/order_create_params.rb', line 749

def initialize(
  access_controlled_venue: nil,
  address: nil,
  affiliate_name: nil,
  ends_at: nil,
  event_company_name: nil,
  event_name: nil,
  event_type: nil,
  insurances: nil,
  starts_at: nil,
  venue_name: nil
)
  @access_controlled_venue = access_controlled_venue
  @address = address
  @affiliate_name = affiliate_name
  @ends_at = ends_at
  @event_company_name = event_company_name
  @event_name = event_name
  @event_type = event_type
  @insurances = insurances
  @starts_at = starts_at
  @venue_name = venue_name
end

Instance Attribute Details

#access_controlled_venueObject

Indicates if the tickets are digitally checked when entering the venue.



729
730
731
# File 'lib/stripe/params/order_create_params.rb', line 729

def access_controlled_venue
  @access_controlled_venue
end

#addressObject

Address of the event.



731
732
733
# File 'lib/stripe/params/order_create_params.rb', line 731

def address
  @address
end

#affiliate_nameObject

Name of associated or partner company for the service.



733
734
735
# File 'lib/stripe/params/order_create_params.rb', line 733

def affiliate_name
  @affiliate_name
end

#ends_atObject

End timestamp of the event.



735
736
737
# File 'lib/stripe/params/order_create_params.rb', line 735

def ends_at
  @ends_at
end

#event_company_nameObject

Company selling the ticket.



737
738
739
# File 'lib/stripe/params/order_create_params.rb', line 737

def event_company_name
  @event_company_name
end

#event_nameObject

Name of the event.



739
740
741
# File 'lib/stripe/params/order_create_params.rb', line 739

def event_name
  @event_name
end

#event_typeObject

Type of the event.



741
742
743
# File 'lib/stripe/params/order_create_params.rb', line 741

def event_type
  @event_type
end

#insurancesObject

List of insurances for this event.



743
744
745
# File 'lib/stripe/params/order_create_params.rb', line 743

def insurances
  @insurances
end

#starts_atObject

Start timestamp of the event.



745
746
747
# File 'lib/stripe/params/order_create_params.rb', line 745

def starts_at
  @starts_at
end

#venue_nameObject

Name of the venue where the event takes place.



747
748
749
# File 'lib/stripe/params/order_create_params.rb', line 747

def venue_name
  @venue_name
end