Class: Stripe::OrderCreateParams::Payment::Settings::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::EventReservationDetail::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderCreateParams::Payment::Settings::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::EventReservationDetail::Address
- Defined in:
- lib/stripe/params/order_create_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 |
# File 'lib/stripe/params/order_create_params.rb', line 720 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
708 709 710 |
# File 'lib/stripe/params/order_create_params.rb', line 708 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
710 711 712 |
# File 'lib/stripe/params/order_create_params.rb', line 710 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
712 713 714 |
# File 'lib/stripe/params/order_create_params.rb', line 712 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
714 715 716 |
# File 'lib/stripe/params/order_create_params.rb', line 714 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
716 717 718 |
# File 'lib/stripe/params/order_create_params.rb', line 716 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
718 719 720 |
# File 'lib/stripe/params/order_create_params.rb', line 718 def street_address2 @street_address2 end |