Class: Stripe::OrderCreateParams::Payment::Settings::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::FerryReservationDetail::Arrival::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderCreateParams::Payment::Settings::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::FerryReservationDetail::Arrival::Address
- Defined in:
- lib/stripe/params/order_create_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 |
# File 'lib/stripe/params/order_create_params.rb', line 790 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
778 779 780 |
# File 'lib/stripe/params/order_create_params.rb', line 778 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
780 781 782 |
# File 'lib/stripe/params/order_create_params.rb', line 780 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
782 783 784 |
# File 'lib/stripe/params/order_create_params.rb', line 782 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
784 785 786 |
# File 'lib/stripe/params/order_create_params.rb', line 784 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
786 787 788 |
# File 'lib/stripe/params/order_create_params.rb', line 786 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
788 789 790 |
# File 'lib/stripe/params/order_create_params.rb', line 788 def street_address2 @street_address2 end |