Class: Stripe::OrderCreateParams::Payment::Settings::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::MarketplaceSeller
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderCreateParams::Payment::Settings::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::MarketplaceSeller
- Defined in:
- lib/stripe/params/order_create_params.rb
Defined Under Namespace
Classes: MarketplaceSellerAddress
Instance Attribute Summary collapse
-
#line_item_references ⇒ Object
The references to line items for purchases with multiple associated sub-sellers.
-
#marketplace_seller_address ⇒ Object
The address of the selling or delivering merchant.
-
#marketplace_seller_name ⇒ Object
The name of the marketplace seller.
-
#marketplace_seller_reference ⇒ Object
The unique identifier for the marketplace seller.
-
#number_of_transactions ⇒ Object
The number of transactions the sub-seller completed in the last 12 months.
-
#product_category ⇒ Object
The category of the product.
-
#seller_last_login_at ⇒ Object
The date when the seller’s account with the marketplace was last logged in.
-
#seller_rating ⇒ Object
The current rating of the marketplace seller.
-
#seller_registered_at ⇒ Object
The date when the seller’s account with the marketplace was created.
-
#seller_updated_at ⇒ Object
The date when the seller’s account with the marketplace was last updated.
-
#shipping_references ⇒ Object
The references to shipping addresses for purchases with multiple associated sub-sellers.
-
#volume_of_transactions ⇒ Object
The accumulated amount of sales transactions made by the sub-merchant or sub-seller within the past 12 months in the payment currency.
Instance Method Summary collapse
-
#initialize(line_item_references: nil, marketplace_seller_address: nil, marketplace_seller_name: nil, marketplace_seller_reference: nil, number_of_transactions: nil, product_category: nil, seller_last_login_at: nil, seller_rating: nil, seller_registered_at: nil, seller_updated_at: nil, shipping_references: nil, volume_of_transactions: nil) ⇒ MarketplaceSeller
constructor
A new instance of MarketplaceSeller.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(line_item_references: nil, marketplace_seller_address: nil, marketplace_seller_name: nil, marketplace_seller_reference: nil, number_of_transactions: nil, product_category: nil, seller_last_login_at: nil, seller_rating: nil, seller_registered_at: nil, seller_updated_at: nil, shipping_references: nil, volume_of_transactions: nil) ⇒ MarketplaceSeller
Returns a new instance of MarketplaceSeller.
1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 |
# File 'lib/stripe/params/order_create_params.rb', line 1017 def initialize( line_item_references: nil, marketplace_seller_address: nil, marketplace_seller_name: nil, marketplace_seller_reference: nil, number_of_transactions: nil, product_category: nil, seller_last_login_at: nil, seller_rating: nil, seller_registered_at: nil, seller_updated_at: nil, shipping_references: nil, volume_of_transactions: nil ) @line_item_references = line_item_references @marketplace_seller_address = marketplace_seller_address @marketplace_seller_name = marketplace_seller_name @marketplace_seller_reference = marketplace_seller_reference @number_of_transactions = number_of_transactions @product_category = product_category @seller_last_login_at = seller_last_login_at @seller_rating = @seller_registered_at = seller_registered_at @seller_updated_at = seller_updated_at @shipping_references = shipping_references @volume_of_transactions = volume_of_transactions end |
Instance Attribute Details
#line_item_references ⇒ Object
The references to line items for purchases with multiple associated sub-sellers.
993 994 995 |
# File 'lib/stripe/params/order_create_params.rb', line 993 def line_item_references @line_item_references end |
#marketplace_seller_address ⇒ Object
The address of the selling or delivering merchant.
995 996 997 |
# File 'lib/stripe/params/order_create_params.rb', line 995 def marketplace_seller_address @marketplace_seller_address end |
#marketplace_seller_name ⇒ Object
The name of the marketplace seller.
997 998 999 |
# File 'lib/stripe/params/order_create_params.rb', line 997 def marketplace_seller_name @marketplace_seller_name end |
#marketplace_seller_reference ⇒ Object
The unique identifier for the marketplace seller.
999 1000 1001 |
# File 'lib/stripe/params/order_create_params.rb', line 999 def marketplace_seller_reference @marketplace_seller_reference end |
#number_of_transactions ⇒ Object
The number of transactions the sub-seller completed in the last 12 months.
1001 1002 1003 |
# File 'lib/stripe/params/order_create_params.rb', line 1001 def number_of_transactions @number_of_transactions end |
#product_category ⇒ Object
The category of the product.
1003 1004 1005 |
# File 'lib/stripe/params/order_create_params.rb', line 1003 def product_category @product_category end |
#seller_last_login_at ⇒ Object
The date when the seller’s account with the marketplace was last logged in.
1005 1006 1007 |
# File 'lib/stripe/params/order_create_params.rb', line 1005 def seller_last_login_at @seller_last_login_at end |
#seller_rating ⇒ Object
The current rating of the marketplace seller. If the marketplace uses numeric ranking, map these to the enum values.
1007 1008 1009 |
# File 'lib/stripe/params/order_create_params.rb', line 1007 def @seller_rating end |
#seller_registered_at ⇒ Object
The date when the seller’s account with the marketplace was created.
1009 1010 1011 |
# File 'lib/stripe/params/order_create_params.rb', line 1009 def seller_registered_at @seller_registered_at end |
#seller_updated_at ⇒ Object
The date when the seller’s account with the marketplace was last updated.
1011 1012 1013 |
# File 'lib/stripe/params/order_create_params.rb', line 1011 def seller_updated_at @seller_updated_at end |
#shipping_references ⇒ Object
The references to shipping addresses for purchases with multiple associated sub-sellers.
1013 1014 1015 |
# File 'lib/stripe/params/order_create_params.rb', line 1013 def shipping_references @shipping_references end |
#volume_of_transactions ⇒ Object
The accumulated amount of sales transactions made by the sub-merchant or sub-seller within the past 12 months in the payment currency. These transactions are in minor currency units.
1015 1016 1017 |
# File 'lib/stripe/params/order_create_params.rb', line 1015 def volume_of_transactions @volume_of_transactions end |