Class: Stripe::OrderCreateParams::Payment::Settings::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::RoundTripReservationDetail::Arrival::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderCreateParams::Payment::Settings::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::RoundTripReservationDetail::Arrival::Address
- Defined in:
- lib/stripe/params/order_create_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 |
# File 'lib/stripe/params/order_create_params.rb', line 1062 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
1050 1051 1052 |
# File 'lib/stripe/params/order_create_params.rb', line 1050 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
1052 1053 1054 |
# File 'lib/stripe/params/order_create_params.rb', line 1052 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
1054 1055 1056 |
# File 'lib/stripe/params/order_create_params.rb', line 1054 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
1056 1057 1058 |
# File 'lib/stripe/params/order_create_params.rb', line 1056 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
1058 1059 1060 |
# File 'lib/stripe/params/order_create_params.rb', line 1058 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
1060 1061 1062 |
# File 'lib/stripe/params/order_create_params.rb', line 1060 def street_address2 @street_address2 end |