Class: Stripe::OrderCreateParams::Payment::Settings::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::TrainReservationDetail::Departure::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderCreateParams::Payment::Settings::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::TrainReservationDetail::Departure::Address
- Defined in:
- lib/stripe/params/order_create_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
1268 1269 1270 1271 1272 1273 1274 1275 1276 1277 1278 1279 1280 1281 1282 |
# File 'lib/stripe/params/order_create_params.rb', line 1268 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
1256 1257 1258 |
# File 'lib/stripe/params/order_create_params.rb', line 1256 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
1258 1259 1260 |
# File 'lib/stripe/params/order_create_params.rb', line 1258 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
1260 1261 1262 |
# File 'lib/stripe/params/order_create_params.rb', line 1260 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
1262 1263 1264 |
# File 'lib/stripe/params/order_create_params.rb', line 1262 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
1264 1265 1266 |
# File 'lib/stripe/params/order_create_params.rb', line 1264 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
1266 1267 1268 |
# File 'lib/stripe/params/order_create_params.rb', line 1266 def street_address2 @street_address2 end |