Class: Stripe::OrderCreateParams::Payment::Settings::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::Voucher
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderCreateParams::Payment::Settings::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::Voucher
- Defined in:
- lib/stripe/params/order_create_params.rb
Instance Attribute Summary collapse
-
#affiliate_name ⇒ Object
Name of associated or partner company for this voucher.
-
#ends_at ⇒ Object
The voucher validity end time.
-
#starts_at ⇒ Object
The voucher validity start time.
-
#voucher_company ⇒ Object
The issuer or provider of this voucher.
-
#voucher_name ⇒ Object
The name or reference to identify the voucher.
-
#voucher_type ⇒ Object
The type of this voucher.
Instance Method Summary collapse
-
#initialize(affiliate_name: nil, ends_at: nil, starts_at: nil, voucher_company: nil, voucher_name: nil, voucher_type: nil) ⇒ Voucher
constructor
A new instance of Voucher.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate_name: nil, ends_at: nil, starts_at: nil, voucher_company: nil, voucher_name: nil, voucher_type: nil) ⇒ Voucher
Returns a new instance of Voucher.
1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 |
# File 'lib/stripe/params/order_create_params.rb', line 1419 def initialize( affiliate_name: nil, ends_at: nil, starts_at: nil, voucher_company: nil, voucher_name: nil, voucher_type: nil ) @affiliate_name = affiliate_name @ends_at = ends_at @starts_at = starts_at @voucher_company = voucher_company @voucher_name = voucher_name @voucher_type = voucher_type end |
Instance Attribute Details
#affiliate_name ⇒ Object
Name of associated or partner company for this voucher.
1407 1408 1409 |
# File 'lib/stripe/params/order_create_params.rb', line 1407 def affiliate_name @affiliate_name end |
#ends_at ⇒ Object
The voucher validity end time.
1409 1410 1411 |
# File 'lib/stripe/params/order_create_params.rb', line 1409 def ends_at @ends_at end |
#starts_at ⇒ Object
The voucher validity start time.
1411 1412 1413 |
# File 'lib/stripe/params/order_create_params.rb', line 1411 def starts_at @starts_at end |
#voucher_company ⇒ Object
The issuer or provider of this voucher.
1413 1414 1415 |
# File 'lib/stripe/params/order_create_params.rb', line 1413 def voucher_company @voucher_company end |
#voucher_name ⇒ Object
The name or reference to identify the voucher.
1415 1416 1417 |
# File 'lib/stripe/params/order_create_params.rb', line 1415 def voucher_name @voucher_name end |
#voucher_type ⇒ Object
The type of this voucher.
1417 1418 1419 |
# File 'lib/stripe/params/order_create_params.rb', line 1417 def voucher_type @voucher_type end |