Class: Stripe::OrderCreateParams::Payment::Settings::PaymentMethodOptions::Paypal::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/order_create_params.rb

Defined Under Namespace

Classes: Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem

Returns a new instance of LineItem.



1580
1581
1582
1583
1584
1585
1586
1587
1588
1589
1590
1591
1592
1593
1594
1595
1596
1597
1598
# File 'lib/stripe/params/order_create_params.rb', line 1580

def initialize(
  category: nil,
  description: nil,
  name: nil,
  quantity: nil,
  sku: nil,
  sold_by: nil,
  tax: nil,
  unit_amount: nil
)
  @category = category
  @description = description
  @name = name
  @quantity = quantity
  @sku = sku
  @sold_by = sold_by
  @tax = tax
  @unit_amount = unit_amount
end

Instance Attribute Details

#categoryObject

Type of the line item.



1564
1565
1566
# File 'lib/stripe/params/order_create_params.rb', line 1564

def category
  @category
end

#descriptionObject

Description of the line item.



1566
1567
1568
# File 'lib/stripe/params/order_create_params.rb', line 1566

def description
  @description
end

#nameObject

Descriptive name of the line item.



1568
1569
1570
# File 'lib/stripe/params/order_create_params.rb', line 1568

def name
  @name
end

#quantityObject

Quantity of the line item. Must be a positive number.



1570
1571
1572
# File 'lib/stripe/params/order_create_params.rb', line 1570

def quantity
  @quantity
end

#skuObject

Client facing stock keeping unit, article number or similar.



1572
1573
1574
# File 'lib/stripe/params/order_create_params.rb', line 1572

def sku
  @sku
end

#sold_byObject

The Stripe account ID of the connected account that sells the item.



1574
1575
1576
# File 'lib/stripe/params/order_create_params.rb', line 1574

def sold_by
  @sold_by
end

#taxObject

The tax information for the line item.



1576
1577
1578
# File 'lib/stripe/params/order_create_params.rb', line 1576

def tax
  @tax
end

#unit_amountObject

Price for a single unit of the line item in minor units. Cannot be a negative number.



1578
1579
1580
# File 'lib/stripe/params/order_create_params.rb', line 1578

def unit_amount
  @unit_amount
end