Class: Stripe::OrderCreateParams::Payment::Settings::PaymentMethodOptions::Paypal::LineItem::Tax
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderCreateParams::Payment::Settings::PaymentMethodOptions::Paypal::LineItem::Tax
- Defined in:
- lib/stripe/params/order_create_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The tax for a single unit of the line item in minor units.
-
#behavior ⇒ Object
The tax behavior for the line item.
Instance Method Summary collapse
-
#initialize(amount: nil, behavior: nil) ⇒ Tax
constructor
A new instance of Tax.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, behavior: nil) ⇒ Tax
Returns a new instance of Tax.
1548 1549 1550 1551 |
# File 'lib/stripe/params/order_create_params.rb', line 1548 def initialize(amount: nil, behavior: nil) @amount = amount @behavior = behavior end |
Instance Attribute Details
#amount ⇒ Object
The tax for a single unit of the line item in minor units. Cannot be a negative number.
1544 1545 1546 |
# File 'lib/stripe/params/order_create_params.rb', line 1544 def amount @amount end |
#behavior ⇒ Object
The tax behavior for the line item.
1546 1547 1548 |
# File 'lib/stripe/params/order_create_params.rb', line 1546 def behavior @behavior end |