Class: Stripe::OrderCreateParams::Payment::Settings::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/order_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



1825
1826
1827
1828
# File 'lib/stripe/params/order_create_params.rb', line 1825

def initialize(amount: nil, destination: nil)
  @amount = amount
  @destination = destination
end

Instance Attribute Details

#amountObject

The amount that will be transferred automatically when the order is paid. If no amount is set, the full amount is transferred. There cannot be any line items with recurring prices when using this field.



1821
1822
1823
# File 'lib/stripe/params/order_create_params.rb', line 1821

def amount
  @amount
end

#destinationObject

ID of the Connected account receiving the transfer.



1823
1824
1825
# File 'lib/stripe/params/order_create_params.rb', line 1823

def destination
  @destination
end