Class: Stripe::OrderCreateParams::ShippingCost::ShippingRateData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/order_create_params.rb

Defined Under Namespace

Classes: DeliveryEstimate, FixedAmount

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(delivery_estimate: nil, display_name: nil, fixed_amount: nil, metadata: nil, tax_behavior: nil, tax_code: nil, type: nil) ⇒ ShippingRateData

Returns a new instance of ShippingRateData.



1914
1915
1916
1917
1918
1919
1920
1921
1922
1923
1924
1925
1926
1927
1928
1929
1930
# File 'lib/stripe/params/order_create_params.rb', line 1914

def initialize(
  delivery_estimate: nil,
  display_name: nil,
  fixed_amount: nil,
  metadata: nil,
  tax_behavior: nil,
  tax_code: nil,
  type: nil
)
  @delivery_estimate = delivery_estimate
  @display_name = display_name
  @fixed_amount = fixed_amount
  @metadata = 
  @tax_behavior = tax_behavior
  @tax_code = tax_code
  @type = type
end

Instance Attribute Details

#delivery_estimateObject

The estimated range for how long shipping will take, meant to be displayable to the customer. This will appear on CheckoutSessions.



1900
1901
1902
# File 'lib/stripe/params/order_create_params.rb', line 1900

def delivery_estimate
  @delivery_estimate
end

#display_nameObject

The name of the shipping rate, meant to be displayable to the customer. This will appear on CheckoutSessions.



1902
1903
1904
# File 'lib/stripe/params/order_create_params.rb', line 1902

def display_name
  @display_name
end

#fixed_amountObject

Describes a fixed amount to charge for shipping. Must be present if type is ‘fixed_amount`.



1904
1905
1906
# File 'lib/stripe/params/order_create_params.rb', line 1904

def fixed_amount
  @fixed_amount
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1906
1907
1908
# File 'lib/stripe/params/order_create_params.rb', line 1906

def 
  @metadata
end

#tax_behaviorObject

Specifies whether the rate is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`.



1908
1909
1910
# File 'lib/stripe/params/order_create_params.rb', line 1908

def tax_behavior
  @tax_behavior
end

#tax_codeObject

A [tax code](docs.stripe.com/tax/tax-categories) ID. The Shipping tax code is ‘txcd_92010001`.



1910
1911
1912
# File 'lib/stripe/params/order_create_params.rb', line 1910

def tax_code
  @tax_code
end

#typeObject

The type of calculation to use on the shipping rate.



1912
1913
1914
# File 'lib/stripe/params/order_create_params.rb', line 1912

def type
  @type
end