Class: Stripe::OrderService::CancelParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderService::CancelParams
- Defined in:
- lib/stripe/services/order_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ CancelParams
constructor
A new instance of CancelParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ CancelParams
Returns a new instance of CancelParams.
2426 2427 2428 |
# File 'lib/stripe/services/order_service.rb', line 2426 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2424 2425 2426 |
# File 'lib/stripe/services/order_service.rb', line 2424 def @expand end |