Class: Stripe::OrderService::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/order_service.rb

Defined Under Namespace

Classes: AutomaticTax, BillingDetails, Discount, LineItem, Payment, ShippingCost, ShippingDetails, TaxDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(automatic_tax: nil, billing_details: nil, currency: nil, customer: nil, description: nil, discounts: nil, expand: nil, ip_address: nil, line_items: nil, metadata: nil, payment: nil, shipping_cost: nil, shipping_details: nil, tax_details: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



1127
1128
1129
1130
1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
# File 'lib/stripe/services/order_service.rb', line 1127

def initialize(
  automatic_tax: nil,
  billing_details: nil,
  currency: nil,
  customer: nil,
  description: nil,
  discounts: nil,
  expand: nil,
  ip_address: nil,
  line_items: nil,
  metadata: nil,
  payment: nil,
  shipping_cost: nil,
  shipping_details: nil,
  tax_details: nil
)
  @automatic_tax = automatic_tax
  @billing_details = billing_details
  @currency = currency
  @customer = customer
  @description = description
  @discounts = discounts
  @expand = expand
  @ip_address = ip_address
  @line_items = line_items
  @metadata = 
  @payment = payment
  @shipping_cost = shipping_cost
  @shipping_details = shipping_details
  @tax_details = tax_details
end

Instance Attribute Details

#automatic_taxObject

Settings for automatic tax calculation for this order.



1099
1100
1101
# File 'lib/stripe/services/order_service.rb', line 1099

def automatic_tax
  @automatic_tax
end

#billing_detailsObject

Billing details for the customer. If a customer is provided, this will be automatically populated with values from that customer if override values are not provided.



1101
1102
1103
# File 'lib/stripe/services/order_service.rb', line 1101

def billing_details
  @billing_details
end

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



1103
1104
1105
# File 'lib/stripe/services/order_service.rb', line 1103

def currency
  @currency
end

#customerObject

The customer associated with this order.



1105
1106
1107
# File 'lib/stripe/services/order_service.rb', line 1105

def customer
  @customer
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



1107
1108
1109
# File 'lib/stripe/services/order_service.rb', line 1107

def description
  @description
end

#discountsObject

The coupons, promotion codes, and/or discounts to apply to the order.



1109
1110
1111
# File 'lib/stripe/services/order_service.rb', line 1109

def discounts
  @discounts
end

#expandObject

Specifies which fields in the response should be expanded.



1111
1112
1113
# File 'lib/stripe/services/order_service.rb', line 1111

def expand
  @expand
end

#ip_addressObject

The IP address of the purchaser for this order.



1113
1114
1115
# File 'lib/stripe/services/order_service.rb', line 1113

def ip_address
  @ip_address
end

#line_itemsObject

A list of line items the customer is ordering. Each line item includes information about the product, the quantity, and the resulting cost.



1115
1116
1117
# File 'lib/stripe/services/order_service.rb', line 1115

def line_items
  @line_items
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1117
1118
1119
# File 'lib/stripe/services/order_service.rb', line 1117

def 
  @metadata
end

#paymentObject

Payment information associated with the order, including payment settings.



1119
1120
1121
# File 'lib/stripe/services/order_service.rb', line 1119

def payment
  @payment
end

#shipping_costObject

Settings for the customer cost of shipping for this order.



1121
1122
1123
# File 'lib/stripe/services/order_service.rb', line 1121

def shipping_cost
  @shipping_cost
end

#shipping_detailsObject

Shipping details for the order.



1123
1124
1125
# File 'lib/stripe/services/order_service.rb', line 1123

def shipping_details
  @shipping_details
end

#tax_detailsObject

Additional tax details about the purchaser to be used for this order.



1125
1126
1127
# File 'lib/stripe/services/order_service.rb', line 1125

def tax_details
  @tax_details
end