Class: Stripe::OrderService::CreateParams::AutomaticTax
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderService::CreateParams::AutomaticTax
- Defined in:
- lib/stripe/services/order_service.rb
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Enable automatic tax calculation which will automatically compute tax rates on this order.
Instance Method Summary collapse
-
#initialize(enabled: nil) ⇒ AutomaticTax
constructor
A new instance of AutomaticTax.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil) ⇒ AutomaticTax
Returns a new instance of AutomaticTax.
45 46 47 |
# File 'lib/stripe/services/order_service.rb', line 45 def initialize(enabled: nil) @enabled = enabled end |
Instance Attribute Details
#enabled ⇒ Object
Enable automatic tax calculation which will automatically compute tax rates on this order.
43 44 45 |
# File 'lib/stripe/services/order_service.rb', line 43 def enabled @enabled end |