Class: Stripe::OrderService::CreateParams::Credit
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderService::CreateParams::Credit
- Defined in:
- lib/stripe/services/order_service.rb
Instance Attribute Summary collapse
-
#gift_card ⇒ Object
The gift card to apply to the order.
-
#type ⇒ Object
The type of credit to apply to the order, only ‘gift_card` currently supported.
Instance Method Summary collapse
-
#initialize(gift_card: nil, type: nil) ⇒ Credit
constructor
A new instance of Credit.
Methods inherited from RequestParams
Constructor Details
#initialize(gift_card: nil, type: nil) ⇒ Credit
Returns a new instance of Credit.
117 118 119 120 |
# File 'lib/stripe/services/order_service.rb', line 117 def initialize(gift_card: nil, type: nil) @gift_card = gift_card @type = type end |
Instance Attribute Details
#gift_card ⇒ Object
The gift card to apply to the order.
112 113 114 |
# File 'lib/stripe/services/order_service.rb', line 112 def gift_card @gift_card end |
#type ⇒ Object
The type of credit to apply to the order, only ‘gift_card` currently supported.
115 116 117 |
# File 'lib/stripe/services/order_service.rb', line 115 def type @type end |