Class: Stripe::OrderService::CreateParams::LineItem::ProductData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderService::CreateParams::LineItem::ProductData
- Defined in:
- lib/stripe/services/order_service.rb
Defined Under Namespace
Classes: PackageDimensions
Instance Attribute Summary collapse
-
#description ⇒ Object
The product’s description, meant to be displayable to the customer.
-
#id ⇒ Object
A unique identifier for this product.
-
#images ⇒ Object
A list of up to 8 URLs of images for this product, meant to be displayable to the customer.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#name ⇒ Object
The product’s name, meant to be displayable to the customer.
-
#package_dimensions ⇒ Object
The dimensions of this product for shipping purposes.
-
#shippable ⇒ Object
Whether this product is shipped (i.e., physical goods).
-
#tax_code ⇒ Object
A [tax code](stripe.com/docs/tax/tax-categories) ID.
-
#url ⇒ Object
A URL of a publicly-accessible webpage for this product.
Instance Method Summary collapse
-
#initialize(description: nil, id: nil, images: nil, metadata: nil, name: nil, package_dimensions: nil, shippable: nil, tax_code: nil, url: nil) ⇒ ProductData
constructor
A new instance of ProductData.
Methods inherited from RequestParams
Constructor Details
#initialize(description: nil, id: nil, images: nil, metadata: nil, name: nil, package_dimensions: nil, shippable: nil, tax_code: nil, url: nil) ⇒ ProductData
Returns a new instance of ProductData.
206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 |
# File 'lib/stripe/services/order_service.rb', line 206 def initialize( description: nil, id: nil, images: nil, metadata: nil, name: nil, package_dimensions: nil, shippable: nil, tax_code: nil, url: nil ) @description = description @id = id @images = images @metadata = @name = name @package_dimensions = package_dimensions @shippable = shippable @tax_code = tax_code @url = url end |
Instance Attribute Details
#description ⇒ Object
The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.
186 187 188 |
# File 'lib/stripe/services/order_service.rb', line 186 def description @description end |
#id ⇒ Object
A unique identifier for this product.
‘product_data` automatically creates a Product with this ID. If a Product with the same ID already exists, then `product_data` re-uses it to avoid duplicates. If any of the fields in the existing Product are different from the values in `product_data`, `product_data` updates the existing Product with the new information. So set `product_data` to the same string every time you sell the same product, but don’t re-use the same string for different products.
190 191 192 |
# File 'lib/stripe/services/order_service.rb', line 190 def id @id end |
#images ⇒ Object
A list of up to 8 URLs of images for this product, meant to be displayable to the customer.
192 193 194 |
# File 'lib/stripe/services/order_service.rb', line 192 def images @images end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
194 195 196 |
# File 'lib/stripe/services/order_service.rb', line 194 def @metadata end |
#name ⇒ Object
The product’s name, meant to be displayable to the customer.
196 197 198 |
# File 'lib/stripe/services/order_service.rb', line 196 def name @name end |
#package_dimensions ⇒ Object
The dimensions of this product for shipping purposes.
198 199 200 |
# File 'lib/stripe/services/order_service.rb', line 198 def package_dimensions @package_dimensions end |
#shippable ⇒ Object
Whether this product is shipped (i.e., physical goods).
200 201 202 |
# File 'lib/stripe/services/order_service.rb', line 200 def shippable @shippable end |
#tax_code ⇒ Object
A [tax code](stripe.com/docs/tax/tax-categories) ID.
202 203 204 |
# File 'lib/stripe/services/order_service.rb', line 202 def tax_code @tax_code end |
#url ⇒ Object
A URL of a publicly-accessible webpage for this product.
204 205 206 |
# File 'lib/stripe/services/order_service.rb', line 204 def url @url end |