Class: Stripe::OrderService::CreateParams::Payment::Settings::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderService::CreateParams::Payment::Settings::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/services/order_service.rb
Defined Under Namespace
Classes: Tax
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#name ⇒ Object
Descriptive name of the line item.
-
#quantity ⇒ Object
Quantity of the line item.
-
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
The tax information for the line item.
-
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
Returns a new instance of LineItem.
668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 |
# File 'lib/stripe/services/order_service.rb', line 668 def initialize( category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil ) @category = category @description = description @name = name @quantity = quantity @sku = sku @sold_by = sold_by @tax = tax @unit_amount = unit_amount end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
652 653 654 |
# File 'lib/stripe/services/order_service.rb', line 652 def category @category end |
#description ⇒ Object
Description of the line item.
654 655 656 |
# File 'lib/stripe/services/order_service.rb', line 654 def description @description end |
#name ⇒ Object
Descriptive name of the line item.
656 657 658 |
# File 'lib/stripe/services/order_service.rb', line 656 def name @name end |
#quantity ⇒ Object
Quantity of the line item. Must be a positive number.
658 659 660 |
# File 'lib/stripe/services/order_service.rb', line 658 def quantity @quantity end |
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
660 661 662 |
# File 'lib/stripe/services/order_service.rb', line 660 def sku @sku end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
662 663 664 |
# File 'lib/stripe/services/order_service.rb', line 662 def sold_by @sold_by end |
#tax ⇒ Object
The tax information for the line item.
664 665 666 |
# File 'lib/stripe/services/order_service.rb', line 664 def tax @tax end |
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units. Cannot be a negative number.
666 667 668 |
# File 'lib/stripe/services/order_service.rb', line 666 def unit_amount @unit_amount end |