Class: Stripe::OrderService::CreateParams::Payment::Settings::PaymentMethodOptions::Paypal::LineItem::Tax
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderService::CreateParams::Payment::Settings::PaymentMethodOptions::Paypal::LineItem::Tax
- Defined in:
- lib/stripe/services/order_service.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The tax for a single unit of the line item in minor units.
-
#behavior ⇒ Object
The tax behavior for the line item.
Instance Method Summary collapse
-
#initialize(amount: nil, behavior: nil) ⇒ Tax
constructor
A new instance of Tax.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, behavior: nil) ⇒ Tax
Returns a new instance of Tax.
646 647 648 649 |
# File 'lib/stripe/services/order_service.rb', line 646 def initialize(amount: nil, behavior: nil) @amount = amount @behavior = behavior end |
Instance Attribute Details
#amount ⇒ Object
The tax for a single unit of the line item in minor units. Cannot be a negative number.
642 643 644 |
# File 'lib/stripe/services/order_service.rb', line 642 def amount @amount end |
#behavior ⇒ Object
The tax behavior for the line item.
644 645 646 |
# File 'lib/stripe/services/order_service.rb', line 644 def behavior @behavior end |