Class: Stripe::OrderService::CreateParams::Payment::Settings::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/order_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



879
880
881
882
# File 'lib/stripe/services/order_service.rb', line 879

def initialize(amount: nil, destination: nil)
  @amount = amount
  @destination = destination
end

Instance Attribute Details

#amountObject

The amount that will be transferred automatically when the order is paid. If no amount is set, the full amount is transferred. There cannot be any line items with recurring prices when using this field.



875
876
877
# File 'lib/stripe/services/order_service.rb', line 875

def amount
  @amount
end

#destinationObject

ID of the Connected account receiving the transfer.



877
878
879
# File 'lib/stripe/services/order_service.rb', line 877

def destination
  @destination
end