Class: Stripe::OrderService::ReopenParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderService::ReopenParams
- Defined in:
- lib/stripe/services/order_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ ReopenParams
constructor
A new instance of ReopenParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ ReopenParams
Returns a new instance of ReopenParams.
2154 2155 2156 |
# File 'lib/stripe/services/order_service.rb', line 2154 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2152 2153 2154 |
# File 'lib/stripe/services/order_service.rb', line 2152 def @expand end |