Class: Stripe::OrderService::UpdateParams::AutomaticTax
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderService::UpdateParams::AutomaticTax
- Defined in:
- lib/stripe/services/order_service.rb
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Enable automatic tax calculation which will automatically compute tax rates on this order.
Instance Method Summary collapse
-
#initialize(enabled: nil) ⇒ AutomaticTax
constructor
A new instance of AutomaticTax.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil) ⇒ AutomaticTax
Returns a new instance of AutomaticTax.
1240 1241 1242 |
# File 'lib/stripe/services/order_service.rb', line 1240 def initialize(enabled: nil) @enabled = enabled end |
Instance Attribute Details
#enabled ⇒ Object
Enable automatic tax calculation which will automatically compute tax rates on this order.
1238 1239 1240 |
# File 'lib/stripe/services/order_service.rb', line 1238 def enabled @enabled end |