Class: Stripe::OrderService::UpdateParams::Credit
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderService::UpdateParams::Credit
- Defined in:
- lib/stripe/services/order_service.rb
Instance Attribute Summary collapse
-
#gift_card ⇒ Object
The gift card to apply to the order.
-
#type ⇒ Object
The type of credit to apply to the order, only ‘gift_card` currently supported.
Instance Method Summary collapse
-
#initialize(gift_card: nil, type: nil) ⇒ Credit
constructor
A new instance of Credit.
Methods inherited from RequestParams
Constructor Details
#initialize(gift_card: nil, type: nil) ⇒ Credit
Returns a new instance of Credit.
1173 1174 1175 1176 |
# File 'lib/stripe/services/order_service.rb', line 1173 def initialize(gift_card: nil, type: nil) @gift_card = gift_card @type = type end |
Instance Attribute Details
#gift_card ⇒ Object
The gift card to apply to the order.
1169 1170 1171 |
# File 'lib/stripe/services/order_service.rb', line 1169 def gift_card @gift_card end |
#type ⇒ Object
The type of credit to apply to the order, only ‘gift_card` currently supported.
1171 1172 1173 |
# File 'lib/stripe/services/order_service.rb', line 1171 def type @type end |