Class: Stripe::OrderService::UpdateParams::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/order_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1187
1188
1189
1190
1191
# File 'lib/stripe/services/order_service.rb', line 1187

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1181
1182
1183
# File 'lib/stripe/services/order_service.rb', line 1181

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1183
1184
1185
# File 'lib/stripe/services/order_service.rb', line 1183

def discount
  @discount
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1185
1186
1187
# File 'lib/stripe/services/order_service.rb', line 1185

def promotion_code
  @promotion_code
end