Class: Stripe::OrderService::UpdateParams::LineItem::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderService::UpdateParams::LineItem::Discount
- Defined in:
- lib/stripe/services/order_service.rb
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil) ⇒ Discount
Returns a new instance of Discount.
1249 1250 1251 1252 |
# File 'lib/stripe/services/order_service.rb', line 1249 def initialize(coupon: nil, discount: nil) @coupon = coupon @discount = discount end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
1245 1246 1247 |
# File 'lib/stripe/services/order_service.rb', line 1245 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
1247 1248 1249 |
# File 'lib/stripe/services/order_service.rb', line 1247 def discount @discount end |