Class: Stripe::OrderService::UpdateParams::LineItem::ProductData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/order_service.rb

Defined Under Namespace

Classes: PackageDimensions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, id: nil, images: nil, metadata: nil, name: nil, package_dimensions: nil, shippable: nil, tax_code: nil, url: nil) ⇒ ProductData

Returns a new instance of ProductData.



1323
1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
1342
1343
# File 'lib/stripe/services/order_service.rb', line 1323

def initialize(
  description: nil,
  id: nil,
  images: nil,
  metadata: nil,
  name: nil,
  package_dimensions: nil,
  shippable: nil,
  tax_code: nil,
  url: nil
)
  @description = description
  @id = id
  @images = images
  @metadata = 
  @name = name
  @package_dimensions = package_dimensions
  @shippable = shippable
  @tax_code = tax_code
  @url = url
end

Instance Attribute Details

#descriptionObject

The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.



1303
1304
1305
# File 'lib/stripe/services/order_service.rb', line 1303

def description
  @description
end

#idObject

A unique identifier for this product.

‘product_data` automatically creates a Product with this ID. If a Product with the same ID already exists, then `product_data` re-uses it to avoid duplicates. If any of the fields in the existing Product are different from the values in `product_data`, `product_data` updates the existing Product with the new information. So set `product_data` to the same string every time you sell the same product, but don’t re-use the same string for different products.



1307
1308
1309
# File 'lib/stripe/services/order_service.rb', line 1307

def id
  @id
end

#imagesObject

A list of up to 8 URLs of images for this product, meant to be displayable to the customer.



1309
1310
1311
# File 'lib/stripe/services/order_service.rb', line 1309

def images
  @images
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1311
1312
1313
# File 'lib/stripe/services/order_service.rb', line 1311

def 
  @metadata
end

#nameObject

The product’s name, meant to be displayable to the customer.



1313
1314
1315
# File 'lib/stripe/services/order_service.rb', line 1313

def name
  @name
end

#package_dimensionsObject

The dimensions of this product for shipping purposes.



1315
1316
1317
# File 'lib/stripe/services/order_service.rb', line 1315

def package_dimensions
  @package_dimensions
end

#shippableObject

Whether this product is shipped (i.e., physical goods).



1317
1318
1319
# File 'lib/stripe/services/order_service.rb', line 1317

def shippable
  @shippable
end

#tax_codeObject



1319
1320
1321
# File 'lib/stripe/services/order_service.rb', line 1319

def tax_code
  @tax_code
end

#urlObject

A URL of a publicly-accessible webpage for this product.



1321
1322
1323
# File 'lib/stripe/services/order_service.rb', line 1321

def url
  @url
end