Class: Stripe::OrderService::UpdateParams::Payment::Settings::PaymentMethodOptions::AcssDebit

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/order_service.rb

Defined Under Namespace

Classes: MandateOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(mandate_options: nil, setup_future_usage: nil, verification_method: nil) ⇒ AcssDebit

Returns a new instance of AcssDebit.



1387
1388
1389
1390
1391
1392
1393
1394
1395
# File 'lib/stripe/services/order_service.rb', line 1387

def initialize(
  mandate_options: nil,
  setup_future_usage: nil,
  verification_method: nil
)
  @mandate_options = mandate_options
  @setup_future_usage = setup_future_usage
  @verification_method = verification_method
end

Instance Attribute Details

#mandate_optionsObject

Additional fields for Mandate creation



1373
1374
1375
# File 'lib/stripe/services/order_service.rb', line 1373

def mandate_options
  @mandate_options
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent’s payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.

If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.

When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).

If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.



1383
1384
1385
# File 'lib/stripe/services/order_service.rb', line 1383

def setup_future_usage
  @setup_future_usage
end

#verification_methodObject

Bank account verification method.



1385
1386
1387
# File 'lib/stripe/services/order_service.rb', line 1385

def verification_method
  @verification_method
end