Class: Stripe::OrderService::UpdateParams::Payment::Settings::PaymentMethodOptions::Klarna::Subscription
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderService::UpdateParams::Payment::Settings::PaymentMethodOptions::Klarna::Subscription
- Defined in:
- lib/stripe/services/order_service.rb
Defined Under Namespace
Classes: NextBilling
Instance Attribute Summary collapse
-
#interval ⇒ Object
Unit of time between subscription charges.
-
#interval_count ⇒ Object
The number of intervals (specified in the ‘interval` attribute) between subscription charges.
-
#name ⇒ Object
Name for subscription.
-
#next_billing ⇒ Object
Describes the upcoming charge for this subscription.
-
#reference ⇒ Object
A non-customer-facing reference to correlate subscription charges in the Klarna app.
Instance Method Summary collapse
-
#initialize(interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil) ⇒ Subscription
constructor
A new instance of Subscription.
Methods inherited from RequestParams
Constructor Details
#initialize(interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil) ⇒ Subscription
Returns a new instance of Subscription.
1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 1664 |
# File 'lib/stripe/services/order_service.rb', line 1652 def initialize( interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil ) @interval = interval @interval_count = interval_count @name = name @next_billing = next_billing @reference = reference end |
Instance Attribute Details
#interval ⇒ Object
Unit of time between subscription charges.
1642 1643 1644 |
# File 'lib/stripe/services/order_service.rb', line 1642 def interval @interval end |
#interval_count ⇒ Object
The number of intervals (specified in the ‘interval` attribute) between subscription charges. For example, `interval=month` and `interval_count=3` charges every 3 months.
1644 1645 1646 |
# File 'lib/stripe/services/order_service.rb', line 1644 def interval_count @interval_count end |
#name ⇒ Object
Name for subscription.
1646 1647 1648 |
# File 'lib/stripe/services/order_service.rb', line 1646 def name @name end |
#next_billing ⇒ Object
Describes the upcoming charge for this subscription.
1648 1649 1650 |
# File 'lib/stripe/services/order_service.rb', line 1648 def next_billing @next_billing end |
#reference ⇒ Object
A non-customer-facing reference to correlate subscription charges in the Klarna app. Use a value that persists across subscription charges.
1650 1651 1652 |
# File 'lib/stripe/services/order_service.rb', line 1650 def reference @reference end |