Class: Stripe::OrderService::UpdateParams::Payment::Settings::PaymentMethodOptions::Klarna::Subscription::NextBilling

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/order_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, date: nil) ⇒ NextBilling

Returns a new instance of NextBilling.



1636
1637
1638
1639
# File 'lib/stripe/services/order_service.rb', line 1636

def initialize(amount: nil, date: nil)
  @amount = amount
  @date = date
end

Instance Attribute Details

#amountObject

The amount of the next charge for the subscription.



1632
1633
1634
# File 'lib/stripe/services/order_service.rb', line 1632

def amount
  @amount
end

#dateObject

The date of the next charge for the subscription in YYYY-MM-DD format.



1634
1635
1636
# File 'lib/stripe/services/order_service.rb', line 1634

def date
  @date
end