Class: Stripe::OrderService::UpdateParams::Payment::Settings::PaymentMethodOptions::Paypal::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/order_service.rb

Defined Under Namespace

Classes: Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem

Returns a new instance of LineItem.



1801
1802
1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
# File 'lib/stripe/services/order_service.rb', line 1801

def initialize(
  category: nil,
  description: nil,
  name: nil,
  quantity: nil,
  sku: nil,
  sold_by: nil,
  tax: nil,
  unit_amount: nil
)
  @category = category
  @description = description
  @name = name
  @quantity = quantity
  @sku = sku
  @sold_by = sold_by
  @tax = tax
  @unit_amount = unit_amount
end

Instance Attribute Details

#categoryObject

Type of the line item.



1785
1786
1787
# File 'lib/stripe/services/order_service.rb', line 1785

def category
  @category
end

#descriptionObject

Description of the line item.



1787
1788
1789
# File 'lib/stripe/services/order_service.rb', line 1787

def description
  @description
end

#nameObject

Descriptive name of the line item.



1789
1790
1791
# File 'lib/stripe/services/order_service.rb', line 1789

def name
  @name
end

#quantityObject

Quantity of the line item. Must be a positive number.



1791
1792
1793
# File 'lib/stripe/services/order_service.rb', line 1791

def quantity
  @quantity
end

#skuObject

Client facing stock keeping unit, article number or similar.



1793
1794
1795
# File 'lib/stripe/services/order_service.rb', line 1793

def sku
  @sku
end

#sold_byObject

The Stripe account ID of the connected account that sells the item.



1795
1796
1797
# File 'lib/stripe/services/order_service.rb', line 1795

def sold_by
  @sold_by
end

#taxObject

The tax information for the line item.



1797
1798
1799
# File 'lib/stripe/services/order_service.rb', line 1797

def tax
  @tax
end

#unit_amountObject

Price for a single unit of the line item in minor units. Cannot be a negative number.



1799
1800
1801
# File 'lib/stripe/services/order_service.rb', line 1799

def unit_amount
  @unit_amount
end