Class: Stripe::OrderService::UpdateParams::Payment::Settings::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/order_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



2012
2013
2014
2015
# File 'lib/stripe/services/order_service.rb', line 2012

def initialize(amount: nil, destination: nil)
  @amount = amount
  @destination = destination
end

Instance Attribute Details

#amountObject

The amount that will be transferred automatically when the order is paid. If no amount is set, the full amount is transferred. There cannot be any line items with recurring prices when using this field.



2008
2009
2010
# File 'lib/stripe/services/order_service.rb', line 2008

def amount
  @amount
end

#destinationObject

ID of the Connected account receiving the transfer.



2010
2011
2012
# File 'lib/stripe/services/order_service.rb', line 2010

def destination
  @destination
end