Class: Stripe::OrderUpdateParams::Discount

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/order_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



71
72
73
74
75
# File 'lib/stripe/params/order_update_params.rb', line 71

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



65
66
67
# File 'lib/stripe/params/order_update_params.rb', line 65

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



67
68
69
# File 'lib/stripe/params/order_update_params.rb', line 67

def discount
  @discount
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



69
70
71
# File 'lib/stripe/params/order_update_params.rb', line 69

def promotion_code
  @promotion_code
end