Class: Stripe::OrderUpdateParams::LineItem::PriceData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderUpdateParams::LineItem::PriceData
- Defined in:
- lib/stripe/params/order_update_params.rb
Instance Attribute Summary collapse
-
#currency ⇒ Object
Three-letter ISO currency code, in lowercase.
- #product ⇒ Object
-
#tax_behavior ⇒ Object
Only required if a default tax behavior was not provided in the Stripe Tax settings.
-
#unit_amount ⇒ Object
A positive integer in cents (or local equivalent) (or 0 for a free price) representing how much to charge.
-
#unit_amount_decimal ⇒ Object
Same as
unit_amount, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(currency: nil, product: nil, tax_behavior: nil, unit_amount: nil, unit_amount_decimal: nil) ⇒ PriceData
constructor
A new instance of PriceData.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(currency: nil, product: nil, tax_behavior: nil, unit_amount: nil, unit_amount_decimal: nil) ⇒ PriceData
Returns a new instance of PriceData.
105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/stripe/params/order_update_params.rb', line 105 def initialize( currency: nil, product: nil, tax_behavior: nil, unit_amount: nil, unit_amount_decimal: nil ) @currency = currency @product = product @tax_behavior = tax_behavior @unit_amount = unit_amount @unit_amount_decimal = unit_amount_decimal end |
Instance Attribute Details
#currency ⇒ Object
Three-letter ISO currency code, in lowercase. Must be a supported currency.
93 94 95 |
# File 'lib/stripe/params/order_update_params.rb', line 93 def currency @currency end |
#product ⇒ Object
97 98 99 |
# File 'lib/stripe/params/order_update_params.rb', line 97 def product @product end |
#tax_behavior ⇒ Object
Only required if a default tax behavior was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One of inclusive, exclusive, or unspecified. Once specified as either inclusive or exclusive, it cannot be changed.
99 100 101 |
# File 'lib/stripe/params/order_update_params.rb', line 99 def tax_behavior @tax_behavior end |
#unit_amount ⇒ Object
A positive integer in cents (or local equivalent) (or 0 for a free price) representing how much to charge.
101 102 103 |
# File 'lib/stripe/params/order_update_params.rb', line 101 def unit_amount @unit_amount end |
#unit_amount_decimal ⇒ Object
Same as unit_amount, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places. Only one of unit_amount and unit_amount_decimal can be set.
103 104 105 |
# File 'lib/stripe/params/order_update_params.rb', line 103 def unit_amount_decimal @unit_amount_decimal end |
Class Method Details
.field_encodings ⇒ Object
119 120 121 |
# File 'lib/stripe/params/order_update_params.rb', line 119 def self.field_encodings @field_encodings = { unit_amount_decimal: :decimal_string } end |