Class: Stripe::OrderUpdateParams::Payment::Settings::PaymentMethodOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderUpdateParams::Payment::Settings::PaymentMethodOptions
- Defined in:
- lib/stripe/params/order_update_params.rb
Defined Under Namespace
Classes: AcssDebit, AfterpayClearpay, Alipay, Bancontact, Card, CustomerBalance, Ideal, Klarna, Link, Oxxo, P24, Paypal, SepaDebit, Sofort, WechatPay
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
If paying by
acss_debit, this sub-hash contains details about the ACSS Debit payment method options to pass to the order's PaymentIntent. -
#afterpay_clearpay ⇒ Object
If paying by
afterpay_clearpay, this sub-hash contains details about the AfterpayClearpay payment method options to pass to the order's PaymentIntent. -
#alipay ⇒ Object
If paying by
alipay, this sub-hash contains details about the Alipay payment method options to pass to the order's PaymentIntent. -
#bancontact ⇒ Object
If paying by
bancontact, this sub-hash contains details about the Bancontact payment method options to pass to the order's PaymentIntent. -
#card ⇒ Object
If paying by
card, this sub-hash contains details about the Card payment method options to pass to the order's PaymentIntent. -
#customer_balance ⇒ Object
If paying by
customer_balance, this sub-hash contains details about the Customer Balance payment method options to pass to the order's PaymentIntent. -
#ideal ⇒ Object
If paying by
ideal, this sub-hash contains details about the iDEAL payment method options to pass to the order's PaymentIntent. -
#klarna ⇒ Object
If paying by
klarna, this sub-hash contains details about the Klarna payment method options to pass to the order's PaymentIntent. -
#link ⇒ Object
If paying by
link, this sub-hash contains details about the Link payment method options to pass to the order's PaymentIntent. -
#oxxo ⇒ Object
If paying by
oxxo, this sub-hash contains details about the OXXO payment method options to pass to the order's PaymentIntent. -
#p24 ⇒ Object
If paying by
p24, this sub-hash contains details about the P24 payment method options to pass to the order's PaymentIntent. -
#paypal ⇒ Object
If paying by
paypal, this sub-hash contains details about the PayPal payment method options to pass to the order's PaymentIntent. -
#sepa_debit ⇒ Object
If paying by
sepa_debit, this sub-hash contains details about the SEPA Debit payment method options to pass to the order's PaymentIntent. -
#sofort ⇒ Object
If paying by
sofort, this sub-hash contains details about the Sofort payment method options to pass to the order's PaymentIntent. -
#wechat_pay ⇒ Object
If paying by
wechat_pay, this sub-hash contains details about the WeChat Pay payment method options to pass to the order's PaymentIntent.
Instance Method Summary collapse
-
#initialize(acss_debit: nil, afterpay_clearpay: nil, alipay: nil, bancontact: nil, card: nil, customer_balance: nil, ideal: nil, klarna: nil, link: nil, oxxo: nil, p24: nil, paypal: nil, sepa_debit: nil, sofort: nil, wechat_pay: nil) ⇒ PaymentMethodOptions
constructor
A new instance of PaymentMethodOptions.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(acss_debit: nil, afterpay_clearpay: nil, alipay: nil, bancontact: nil, card: nil, customer_balance: nil, ideal: nil, klarna: nil, link: nil, oxxo: nil, p24: nil, paypal: nil, sepa_debit: nil, sofort: nil, wechat_pay: nil) ⇒ PaymentMethodOptions
Returns a new instance of PaymentMethodOptions.
1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 1814 1815 1816 1817 1818 1819 1820 |
# File 'lib/stripe/params/order_update_params.rb', line 1788 def initialize( acss_debit: nil, afterpay_clearpay: nil, alipay: nil, bancontact: nil, card: nil, customer_balance: nil, ideal: nil, klarna: nil, link: nil, oxxo: nil, p24: nil, paypal: nil, sepa_debit: nil, sofort: nil, wechat_pay: nil ) @acss_debit = acss_debit @afterpay_clearpay = afterpay_clearpay @alipay = alipay @bancontact = bancontact @card = card @customer_balance = customer_balance @ideal = ideal @klarna = klarna @link = link @oxxo = oxxo @p24 = p24 @paypal = paypal @sepa_debit = sepa_debit @sofort = sofort @wechat_pay = wechat_pay end |
Instance Attribute Details
#acss_debit ⇒ Object
If paying by acss_debit, this sub-hash contains details about the ACSS Debit payment method options to pass to the order's PaymentIntent.
1758 1759 1760 |
# File 'lib/stripe/params/order_update_params.rb', line 1758 def acss_debit @acss_debit end |
#afterpay_clearpay ⇒ Object
If paying by afterpay_clearpay, this sub-hash contains details about the AfterpayClearpay payment method options to pass to the order's PaymentIntent.
1760 1761 1762 |
# File 'lib/stripe/params/order_update_params.rb', line 1760 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object
If paying by alipay, this sub-hash contains details about the Alipay payment method options to pass to the order's PaymentIntent.
1762 1763 1764 |
# File 'lib/stripe/params/order_update_params.rb', line 1762 def alipay @alipay end |
#bancontact ⇒ Object
If paying by bancontact, this sub-hash contains details about the Bancontact payment method options to pass to the order's PaymentIntent.
1764 1765 1766 |
# File 'lib/stripe/params/order_update_params.rb', line 1764 def bancontact @bancontact end |
#card ⇒ Object
If paying by card, this sub-hash contains details about the Card payment method options to pass to the order's PaymentIntent.
1766 1767 1768 |
# File 'lib/stripe/params/order_update_params.rb', line 1766 def card @card end |
#customer_balance ⇒ Object
If paying by customer_balance, this sub-hash contains details about the Customer Balance payment method options to pass to the order's PaymentIntent.
1768 1769 1770 |
# File 'lib/stripe/params/order_update_params.rb', line 1768 def customer_balance @customer_balance end |
#ideal ⇒ Object
If paying by ideal, this sub-hash contains details about the iDEAL payment method options to pass to the order's PaymentIntent.
1770 1771 1772 |
# File 'lib/stripe/params/order_update_params.rb', line 1770 def ideal @ideal end |
#klarna ⇒ Object
If paying by klarna, this sub-hash contains details about the Klarna payment method options to pass to the order's PaymentIntent.
1772 1773 1774 |
# File 'lib/stripe/params/order_update_params.rb', line 1772 def klarna @klarna end |
#link ⇒ Object
If paying by link, this sub-hash contains details about the Link payment method options to pass to the order's PaymentIntent.
1774 1775 1776 |
# File 'lib/stripe/params/order_update_params.rb', line 1774 def link @link end |
#oxxo ⇒ Object
If paying by oxxo, this sub-hash contains details about the OXXO payment method options to pass to the order's PaymentIntent.
1776 1777 1778 |
# File 'lib/stripe/params/order_update_params.rb', line 1776 def oxxo @oxxo end |
#p24 ⇒ Object
If paying by p24, this sub-hash contains details about the P24 payment method options to pass to the order's PaymentIntent.
1778 1779 1780 |
# File 'lib/stripe/params/order_update_params.rb', line 1778 def p24 @p24 end |
#paypal ⇒ Object
If paying by paypal, this sub-hash contains details about the PayPal payment method options to pass to the order's PaymentIntent.
1780 1781 1782 |
# File 'lib/stripe/params/order_update_params.rb', line 1780 def paypal @paypal end |
#sepa_debit ⇒ Object
If paying by sepa_debit, this sub-hash contains details about the SEPA Debit payment method options to pass to the order's PaymentIntent.
1782 1783 1784 |
# File 'lib/stripe/params/order_update_params.rb', line 1782 def sepa_debit @sepa_debit end |
#sofort ⇒ Object
If paying by sofort, this sub-hash contains details about the Sofort payment method options to pass to the order's PaymentIntent.
1784 1785 1786 |
# File 'lib/stripe/params/order_update_params.rb', line 1784 def sofort @sofort end |
#wechat_pay ⇒ Object
If paying by wechat_pay, this sub-hash contains details about the WeChat Pay payment method options to pass to the order's PaymentIntent.
1786 1787 1788 |
# File 'lib/stripe/params/order_update_params.rb', line 1786 def wechat_pay @wechat_pay end |