Class: Stripe::OrderUpdateParams::Payment::Settings::PaymentMethodOptions::AcssDebit::MandateOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderUpdateParams::Payment::Settings::PaymentMethodOptions::AcssDebit::MandateOptions
- Defined in:
- lib/stripe/params/order_update_params.rb
Instance Attribute Summary collapse
-
#custom_mandate_url ⇒ Object
A URL for custom mandate text to render during confirmation step.
-
#interval_description ⇒ Object
Description of the mandate interval.
-
#payment_schedule ⇒ Object
Payment schedule for the mandate.
-
#transaction_type ⇒ Object
Transaction type of the mandate.
Instance Method Summary collapse
-
#initialize(custom_mandate_url: nil, interval_description: nil, payment_schedule: nil, transaction_type: nil) ⇒ MandateOptions
constructor
A new instance of MandateOptions.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(custom_mandate_url: nil, interval_description: nil, payment_schedule: nil, transaction_type: nil) ⇒ MandateOptions
Returns a new instance of MandateOptions.
261 262 263 264 265 266 267 268 269 270 271 |
# File 'lib/stripe/params/order_update_params.rb', line 261 def initialize( custom_mandate_url: nil, interval_description: nil, payment_schedule: nil, transaction_type: nil ) @custom_mandate_url = custom_mandate_url @interval_description = interval_description @payment_schedule = payment_schedule @transaction_type = transaction_type end |
Instance Attribute Details
#custom_mandate_url ⇒ Object
A URL for custom mandate text to render during confirmation step. The URL will be rendered with additional GET parameters ‘payment_intent` and `payment_intent_client_secret` when confirming a Payment Intent, or `setup_intent` and `setup_intent_client_secret` when confirming a Setup Intent.
253 254 255 |
# File 'lib/stripe/params/order_update_params.rb', line 253 def custom_mandate_url @custom_mandate_url end |
#interval_description ⇒ Object
Description of the mandate interval. Only required if ‘payment_schedule’ parameter is ‘interval’ or ‘combined’.
255 256 257 |
# File 'lib/stripe/params/order_update_params.rb', line 255 def interval_description @interval_description end |
#payment_schedule ⇒ Object
Payment schedule for the mandate.
257 258 259 |
# File 'lib/stripe/params/order_update_params.rb', line 257 def payment_schedule @payment_schedule end |
#transaction_type ⇒ Object
Transaction type of the mandate.
259 260 261 |
# File 'lib/stripe/params/order_update_params.rb', line 259 def transaction_type @transaction_type end |