Class: Stripe::OrderUpdateParams::Payment::Settings::PaymentMethodOptions::CustomerBalance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/order_update_params.rb

Defined Under Namespace

Classes: BankTransfer

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(bank_transfer: nil, funding_type: nil, setup_future_usage: nil) ⇒ CustomerBalance

Returns a new instance of CustomerBalance.



423
424
425
426
427
# File 'lib/stripe/params/order_update_params.rb', line 423

def initialize(bank_transfer: nil, funding_type: nil, setup_future_usage: nil)
  @bank_transfer = bank_transfer
  @funding_type = funding_type
  @setup_future_usage = setup_future_usage
end

Instance Attribute Details

#bank_transferObject

Configuration for the bank transfer funding type, if the funding_type is set to bank_transfer.



409
410
411
# File 'lib/stripe/params/order_update_params.rb', line 409

def bank_transfer
  @bank_transfer
end

#funding_typeObject

The funding method type to be used when there are not enough funds in the customer balance. Permitted values include: bank_transfer.



411
412
413
# File 'lib/stripe/params/order_update_params.rb', line 411

def funding_type
  @funding_type
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent's payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.

If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.

When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.

If you've already set setup_future_usage and you're performing a request using a publishable key, you can only update the value from on_session to off_session.



421
422
423
# File 'lib/stripe/params/order_update_params.rb', line 421

def setup_future_usage
  @setup_future_usage
end