Class: Stripe::OrderUpdateParams::Payment::Settings::PaymentMethodOptions::Klarna::Subscription
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderUpdateParams::Payment::Settings::PaymentMethodOptions::Klarna::Subscription
- Defined in:
- lib/stripe/params/order_update_params.rb
Defined Under Namespace
Classes: NextBilling
Instance Attribute Summary collapse
-
#interval ⇒ Object
Unit of time between subscription charges.
-
#interval_count ⇒ Object
The number of intervals (specified in the ‘interval` attribute) between subscription charges.
-
#name ⇒ Object
Name for subscription.
-
#next_billing ⇒ Object
Describes the upcoming charge for this subscription.
-
#reference ⇒ Object
A non-customer-facing reference to correlate subscription charges in the Klarna app.
Instance Method Summary collapse
-
#initialize(interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil) ⇒ Subscription
constructor
A new instance of Subscription.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil) ⇒ Subscription
Returns a new instance of Subscription.
498 499 500 501 502 503 504 505 506 507 508 509 510 |
# File 'lib/stripe/params/order_update_params.rb', line 498 def initialize( interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil ) @interval = interval @interval_count = interval_count @name = name @next_billing = next_billing @reference = reference end |
Instance Attribute Details
#interval ⇒ Object
Unit of time between subscription charges.
488 489 490 |
# File 'lib/stripe/params/order_update_params.rb', line 488 def interval @interval end |
#interval_count ⇒ Object
The number of intervals (specified in the ‘interval` attribute) between subscription charges. For example, `interval=month` and `interval_count=3` charges every 3 months.
490 491 492 |
# File 'lib/stripe/params/order_update_params.rb', line 490 def interval_count @interval_count end |
#name ⇒ Object
Name for subscription.
492 493 494 |
# File 'lib/stripe/params/order_update_params.rb', line 492 def name @name end |
#next_billing ⇒ Object
Describes the upcoming charge for this subscription.
494 495 496 |
# File 'lib/stripe/params/order_update_params.rb', line 494 def next_billing @next_billing end |
#reference ⇒ Object
A non-customer-facing reference to correlate subscription charges in the Klarna app. Use a value that persists across subscription charges.
496 497 498 |
# File 'lib/stripe/params/order_update_params.rb', line 496 def reference @reference end |