Class: Stripe::OrderUpdateParams::Payment::Settings::PaymentMethodOptions::Klarna::Subscription::NextBilling

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/order_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, date: nil) ⇒ NextBilling

Returns a new instance of NextBilling.



513
514
515
516
# File 'lib/stripe/params/order_update_params.rb', line 513

def initialize(amount: nil, date: nil)
  @amount = amount
  @date = date
end

Instance Attribute Details

#amountObject

The amount of the next charge for the subscription.



509
510
511
# File 'lib/stripe/params/order_update_params.rb', line 509

def amount
  @amount
end

#dateObject

The date of the next charge for the subscription in YYYY-MM-DD format.



511
512
513
# File 'lib/stripe/params/order_update_params.rb', line 511

def date
  @date
end