Class: Stripe::OrderUpdateParams::Payment::Settings::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::BusReservationDetail
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderUpdateParams::Payment::Settings::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::BusReservationDetail
- Defined in:
- lib/stripe/params/order_update_params.rb
Defined Under Namespace
Classes: Arrival, Departure, Insurance, Passenger
Instance Attribute Summary collapse
-
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
-
#arrival ⇒ Object
Arrival details.
-
#carrier_name ⇒ Object
Name of transportation company.
-
#currency ⇒ Object
Currency.
-
#departure ⇒ Object
Departure details.
-
#insurances ⇒ Object
List of insurances for this reservation.
-
#passengers ⇒ Object
List of passengers that this reservation applies to.
-
#price ⇒ Object
Price in cents.
-
#ticket_class ⇒ Object
Ticket class.
Instance Method Summary collapse
-
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ BusReservationDetail
constructor
A new instance of BusReservationDetail.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ BusReservationDetail
Returns a new instance of BusReservationDetail.
686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 |
# File 'lib/stripe/params/order_update_params.rb', line 686 def initialize( affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil ) @affiliate_name = affiliate_name @arrival = arrival @carrier_name = carrier_name @currency = currency @departure = departure @insurances = insurances @passengers = passengers @price = price @ticket_class = ticket_class end |
Instance Attribute Details
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
668 669 670 |
# File 'lib/stripe/params/order_update_params.rb', line 668 def affiliate_name @affiliate_name end |
#arrival ⇒ Object
Arrival details.
670 671 672 |
# File 'lib/stripe/params/order_update_params.rb', line 670 def arrival @arrival end |
#carrier_name ⇒ Object
Name of transportation company.
672 673 674 |
# File 'lib/stripe/params/order_update_params.rb', line 672 def carrier_name @carrier_name end |
#currency ⇒ Object
Currency.
674 675 676 |
# File 'lib/stripe/params/order_update_params.rb', line 674 def currency @currency end |
#departure ⇒ Object
Departure details.
676 677 678 |
# File 'lib/stripe/params/order_update_params.rb', line 676 def departure @departure end |
#insurances ⇒ Object
List of insurances for this reservation.
678 679 680 |
# File 'lib/stripe/params/order_update_params.rb', line 678 def insurances @insurances end |
#passengers ⇒ Object
List of passengers that this reservation applies to.
680 681 682 |
# File 'lib/stripe/params/order_update_params.rb', line 680 def passengers @passengers end |
#price ⇒ Object
Price in cents.
682 683 684 |
# File 'lib/stripe/params/order_update_params.rb', line 682 def price @price end |
#ticket_class ⇒ Object
Ticket class.
684 685 686 |
# File 'lib/stripe/params/order_update_params.rb', line 684 def ticket_class @ticket_class end |