Class: Stripe::OrderUpdateParams::Payment::Settings::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::EventReservationDetail::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderUpdateParams::Payment::Settings::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::EventReservationDetail::Address
- Defined in:
- lib/stripe/params/order_update_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 |
# File 'lib/stripe/params/order_update_params.rb', line 683 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
671 672 673 |
# File 'lib/stripe/params/order_update_params.rb', line 671 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
673 674 675 |
# File 'lib/stripe/params/order_update_params.rb', line 673 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
675 676 677 |
# File 'lib/stripe/params/order_update_params.rb', line 675 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
677 678 679 |
# File 'lib/stripe/params/order_update_params.rb', line 677 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
679 680 681 |
# File 'lib/stripe/params/order_update_params.rb', line 679 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
681 682 683 |
# File 'lib/stripe/params/order_update_params.rb', line 681 def street_address2 @street_address2 end |