Class: Stripe::OrderUpdateParams::Payment::Settings::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::FerryReservationDetail
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderUpdateParams::Payment::Settings::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::FerryReservationDetail
- Defined in:
- lib/stripe/params/order_update_params.rb
Defined Under Namespace
Classes: Arrival, Departure, Insurance, Passenger
Instance Attribute Summary collapse
-
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
-
#arrival ⇒ Object
Arrival details.
-
#carrier_name ⇒ Object
Name of transportation company.
-
#currency ⇒ Object
Currency.
-
#departure ⇒ Object
Departure details.
-
#insurances ⇒ Object
List of insurances for this reservation.
-
#passengers ⇒ Object
List of passengers that this reservation applies to.
-
#price ⇒ Object
Price in cents.
-
#ticket_class ⇒ Object
Ticket class.
Instance Method Summary collapse
-
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ FerryReservationDetail
constructor
A new instance of FerryReservationDetail.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ FerryReservationDetail
Returns a new instance of FerryReservationDetail.
919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 |
# File 'lib/stripe/params/order_update_params.rb', line 919 def initialize( affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil ) @affiliate_name = affiliate_name @arrival = arrival @carrier_name = carrier_name @currency = currency @departure = departure @insurances = insurances @passengers = passengers @price = price @ticket_class = ticket_class end |
Instance Attribute Details
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
901 902 903 |
# File 'lib/stripe/params/order_update_params.rb', line 901 def affiliate_name @affiliate_name end |
#arrival ⇒ Object
Arrival details.
903 904 905 |
# File 'lib/stripe/params/order_update_params.rb', line 903 def arrival @arrival end |
#carrier_name ⇒ Object
Name of transportation company.
905 906 907 |
# File 'lib/stripe/params/order_update_params.rb', line 905 def carrier_name @carrier_name end |
#currency ⇒ Object
Currency.
907 908 909 |
# File 'lib/stripe/params/order_update_params.rb', line 907 def currency @currency end |
#departure ⇒ Object
Departure details.
909 910 911 |
# File 'lib/stripe/params/order_update_params.rb', line 909 def departure @departure end |
#insurances ⇒ Object
List of insurances for this reservation.
911 912 913 |
# File 'lib/stripe/params/order_update_params.rb', line 911 def insurances @insurances end |
#passengers ⇒ Object
List of passengers that this reservation applies to.
913 914 915 |
# File 'lib/stripe/params/order_update_params.rb', line 913 def passengers @passengers end |
#price ⇒ Object
Price in cents.
915 916 917 |
# File 'lib/stripe/params/order_update_params.rb', line 915 def price @price end |
#ticket_class ⇒ Object
Ticket class.
917 918 919 |
# File 'lib/stripe/params/order_update_params.rb', line 917 def ticket_class @ticket_class end |