Class: Stripe::OrderUpdateParams::Payment::Settings::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::FerryReservationDetail::Departure::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderUpdateParams::Payment::Settings::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::FerryReservationDetail::Departure::Address
- Defined in:
- lib/stripe/params/order_update_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 |
# File 'lib/stripe/params/order_update_params.rb', line 826 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
814 815 816 |
# File 'lib/stripe/params/order_update_params.rb', line 814 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
816 817 818 |
# File 'lib/stripe/params/order_update_params.rb', line 816 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
818 819 820 |
# File 'lib/stripe/params/order_update_params.rb', line 818 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
820 821 822 |
# File 'lib/stripe/params/order_update_params.rb', line 820 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
822 823 824 |
# File 'lib/stripe/params/order_update_params.rb', line 822 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
824 825 826 |
# File 'lib/stripe/params/order_update_params.rb', line 824 def street_address2 @street_address2 end |