Class: Stripe::OrderUpdateParams::Payment::Settings::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::MarketplaceSeller::MarketplaceSellerAddress
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderUpdateParams::Payment::Settings::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::MarketplaceSeller::MarketplaceSellerAddress
- Defined in:
- lib/stripe/params/order_update_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ MarketplaceSellerAddress
constructor
A new instance of MarketplaceSellerAddress.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ MarketplaceSellerAddress
Returns a new instance of MarketplaceSellerAddress.
1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 |
# File 'lib/stripe/params/order_update_params.rb', line 1011 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
999 1000 1001 |
# File 'lib/stripe/params/order_update_params.rb', line 999 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
1001 1002 1003 |
# File 'lib/stripe/params/order_update_params.rb', line 1001 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
1003 1004 1005 |
# File 'lib/stripe/params/order_update_params.rb', line 1003 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
1005 1006 1007 |
# File 'lib/stripe/params/order_update_params.rb', line 1005 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
1007 1008 1009 |
# File 'lib/stripe/params/order_update_params.rb', line 1007 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
1009 1010 1011 |
# File 'lib/stripe/params/order_update_params.rb', line 1009 def street_address2 @street_address2 end |