Class: Stripe::OrderUpdateParams::Payment::Settings::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::RoundTripReservationDetail
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderUpdateParams::Payment::Settings::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::RoundTripReservationDetail
- Defined in:
- lib/stripe/params/order_update_params.rb
Defined Under Namespace
Classes: Arrival, Departure, Insurance, Passenger
Instance Attribute Summary collapse
-
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
-
#arrival ⇒ Object
Arrival details.
-
#carrier_name ⇒ Object
Name of transportation company.
-
#currency ⇒ Object
Currency.
-
#departure ⇒ Object
Departure details.
-
#insurances ⇒ Object
List of insurances for this reservation.
-
#passengers ⇒ Object
List of passengers that this reservation applies to.
-
#price ⇒ Object
Price in cents.
-
#ticket_class ⇒ Object
Ticket class.
Instance Method Summary collapse
-
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ RoundTripReservationDetail
constructor
A new instance of RoundTripReservationDetail.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ RoundTripReservationDetail
Returns a new instance of RoundTripReservationDetail.
1222 1223 1224 1225 1226 1227 1228 1229 1230 1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 1242 |
# File 'lib/stripe/params/order_update_params.rb', line 1222 def initialize( affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil ) @affiliate_name = affiliate_name @arrival = arrival @carrier_name = carrier_name @currency = currency @departure = departure @insurances = insurances @passengers = passengers @price = price @ticket_class = ticket_class end |
Instance Attribute Details
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
1204 1205 1206 |
# File 'lib/stripe/params/order_update_params.rb', line 1204 def affiliate_name @affiliate_name end |
#arrival ⇒ Object
Arrival details.
1206 1207 1208 |
# File 'lib/stripe/params/order_update_params.rb', line 1206 def arrival @arrival end |
#carrier_name ⇒ Object
Name of transportation company.
1208 1209 1210 |
# File 'lib/stripe/params/order_update_params.rb', line 1208 def carrier_name @carrier_name end |
#currency ⇒ Object
Currency.
1210 1211 1212 |
# File 'lib/stripe/params/order_update_params.rb', line 1210 def currency @currency end |
#departure ⇒ Object
Departure details.
1212 1213 1214 |
# File 'lib/stripe/params/order_update_params.rb', line 1212 def departure @departure end |
#insurances ⇒ Object
List of insurances for this reservation.
1214 1215 1216 |
# File 'lib/stripe/params/order_update_params.rb', line 1214 def insurances @insurances end |
#passengers ⇒ Object
List of passengers that this reservation applies to.
1216 1217 1218 |
# File 'lib/stripe/params/order_update_params.rb', line 1216 def passengers @passengers end |
#price ⇒ Object
Price in cents.
1218 1219 1220 |
# File 'lib/stripe/params/order_update_params.rb', line 1218 def price @price end |
#ticket_class ⇒ Object
Ticket class.
1220 1221 1222 |
# File 'lib/stripe/params/order_update_params.rb', line 1220 def ticket_class @ticket_class end |