Class: Stripe::OrderUpdateParams::Payment::Settings::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::RoundTripReservationDetail::Arrival::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderUpdateParams::Payment::Settings::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::RoundTripReservationDetail::Arrival::Address
- Defined in:
- lib/stripe/params/order_update_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 |
# File 'lib/stripe/params/order_update_params.rb', line 1056 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
1044 1045 1046 |
# File 'lib/stripe/params/order_update_params.rb', line 1044 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
1046 1047 1048 |
# File 'lib/stripe/params/order_update_params.rb', line 1046 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
1048 1049 1050 |
# File 'lib/stripe/params/order_update_params.rb', line 1048 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
1050 1051 1052 |
# File 'lib/stripe/params/order_update_params.rb', line 1050 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
1052 1053 1054 |
# File 'lib/stripe/params/order_update_params.rb', line 1052 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
1054 1055 1056 |
# File 'lib/stripe/params/order_update_params.rb', line 1054 def street_address2 @street_address2 end |