Class: Stripe::OrderUpdateParams::Payment::Settings::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::RoundTripReservationDetail::Departure::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderUpdateParams::Payment::Settings::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::RoundTripReservationDetail::Departure::Address
- Defined in:
- lib/stripe/params/order_update_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 |
# File 'lib/stripe/params/order_update_params.rb', line 1108 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
1096 1097 1098 |
# File 'lib/stripe/params/order_update_params.rb', line 1096 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
1098 1099 1100 |
# File 'lib/stripe/params/order_update_params.rb', line 1098 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
1100 1101 1102 |
# File 'lib/stripe/params/order_update_params.rb', line 1100 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
1102 1103 1104 |
# File 'lib/stripe/params/order_update_params.rb', line 1102 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
1104 1105 1106 |
# File 'lib/stripe/params/order_update_params.rb', line 1104 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
1106 1107 1108 |
# File 'lib/stripe/params/order_update_params.rb', line 1106 def street_address2 @street_address2 end |