Class: Stripe::OrderUpdateParams::Payment::Settings::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::TrainReservationDetail::Arrival::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderUpdateParams::Payment::Settings::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::TrainReservationDetail::Arrival::Address
- Defined in:
- lib/stripe/params/order_update_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
1230 1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 |
# File 'lib/stripe/params/order_update_params.rb', line 1230 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
1218 1219 1220 |
# File 'lib/stripe/params/order_update_params.rb', line 1218 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
1220 1221 1222 |
# File 'lib/stripe/params/order_update_params.rb', line 1220 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
1222 1223 1224 |
# File 'lib/stripe/params/order_update_params.rb', line 1222 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
1224 1225 1226 |
# File 'lib/stripe/params/order_update_params.rb', line 1224 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
1226 1227 1228 |
# File 'lib/stripe/params/order_update_params.rb', line 1226 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
1228 1229 1230 |
# File 'lib/stripe/params/order_update_params.rb', line 1228 def street_address2 @street_address2 end |