Class: Stripe::OrderUpdateParams::Payment::Settings::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::TrainReservationDetail::Departure::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderUpdateParams::Payment::Settings::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::TrainReservationDetail::Departure::Address
- Defined in:
- lib/stripe/params/order_update_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 |
# File 'lib/stripe/params/order_update_params.rb', line 1303 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
1291 1292 1293 |
# File 'lib/stripe/params/order_update_params.rb', line 1291 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
1293 1294 1295 |
# File 'lib/stripe/params/order_update_params.rb', line 1293 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
1295 1296 1297 |
# File 'lib/stripe/params/order_update_params.rb', line 1295 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
1297 1298 1299 |
# File 'lib/stripe/params/order_update_params.rb', line 1297 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
1299 1300 1301 |
# File 'lib/stripe/params/order_update_params.rb', line 1299 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
1301 1302 1303 |
# File 'lib/stripe/params/order_update_params.rb', line 1301 def street_address2 @street_address2 end |