Class: Stripe::OrderUpdateParams::Payment::Settings::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::Voucher
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderUpdateParams::Payment::Settings::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::Voucher
- Defined in:
- lib/stripe/params/order_update_params.rb
Instance Attribute Summary collapse
-
#affiliate_name ⇒ Object
Name of associated or partner company for this voucher.
-
#ends_at ⇒ Object
The voucher validity end time.
-
#starts_at ⇒ Object
The voucher validity start time.
-
#voucher_company ⇒ Object
The issuer or provider of this voucher.
-
#voucher_name ⇒ Object
The name or reference to identify the voucher.
-
#voucher_type ⇒ Object
The type of this voucher.
Instance Method Summary collapse
-
#initialize(affiliate_name: nil, ends_at: nil, starts_at: nil, voucher_company: nil, voucher_name: nil, voucher_type: nil) ⇒ Voucher
constructor
A new instance of Voucher.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate_name: nil, ends_at: nil, starts_at: nil, voucher_company: nil, voucher_name: nil, voucher_type: nil) ⇒ Voucher
Returns a new instance of Voucher.
1392 1393 1394 1395 1396 1397 1398 1399 1400 1401 1402 1403 1404 1405 1406 |
# File 'lib/stripe/params/order_update_params.rb', line 1392 def initialize( affiliate_name: nil, ends_at: nil, starts_at: nil, voucher_company: nil, voucher_name: nil, voucher_type: nil ) @affiliate_name = affiliate_name @ends_at = ends_at @starts_at = starts_at @voucher_company = voucher_company @voucher_name = voucher_name @voucher_type = voucher_type end |
Instance Attribute Details
#affiliate_name ⇒ Object
Name of associated or partner company for this voucher.
1380 1381 1382 |
# File 'lib/stripe/params/order_update_params.rb', line 1380 def affiliate_name @affiliate_name end |
#ends_at ⇒ Object
The voucher validity end time.
1382 1383 1384 |
# File 'lib/stripe/params/order_update_params.rb', line 1382 def ends_at @ends_at end |
#starts_at ⇒ Object
The voucher validity start time.
1384 1385 1386 |
# File 'lib/stripe/params/order_update_params.rb', line 1384 def starts_at @starts_at end |
#voucher_company ⇒ Object
The issuer or provider of this voucher.
1386 1387 1388 |
# File 'lib/stripe/params/order_update_params.rb', line 1386 def voucher_company @voucher_company end |
#voucher_name ⇒ Object
The name or reference to identify the voucher.
1388 1389 1390 |
# File 'lib/stripe/params/order_update_params.rb', line 1388 def voucher_name @voucher_name end |
#voucher_type ⇒ Object
The type of this voucher.
1390 1391 1392 |
# File 'lib/stripe/params/order_update_params.rb', line 1390 def voucher_type @voucher_type end |