Class: Stripe::OrderUpdateParams::Payment::Settings::PaymentMethodOptions::WechatPay

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/order_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(app_id: nil, buyer_id: nil, client: nil, setup_future_usage: nil) ⇒ WechatPay

Returns a new instance of WechatPay.



1750
1751
1752
1753
1754
1755
# File 'lib/stripe/params/order_update_params.rb', line 1750

def initialize(app_id: nil, buyer_id: nil, client: nil, setup_future_usage: nil)
  @app_id = app_id
  @buyer_id = buyer_id
  @client = client
  @setup_future_usage = setup_future_usage
end

Instance Attribute Details

#app_idObject

The app ID registered with WeChat Pay. Only required when client is ios, android, or mini_program.



1734
1735
1736
# File 'lib/stripe/params/order_update_params.rb', line 1734

def app_id
  @app_id
end

#buyer_idObject

The unique buyer ID for the app ID registered with WeChat Pay. Only required when client is mini_program.



1736
1737
1738
# File 'lib/stripe/params/order_update_params.rb', line 1736

def buyer_id
  @buyer_id
end

#clientObject

The client type that the end customer will pay from



1738
1739
1740
# File 'lib/stripe/params/order_update_params.rb', line 1738

def client
  @client
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent's payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.

If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.

When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.

If you've already set setup_future_usage and you're performing a request using a publishable key, you can only update the value from on_session to off_session.



1748
1749
1750
# File 'lib/stripe/params/order_update_params.rb', line 1748

def setup_future_usage
  @setup_future_usage
end