Class: Stripe::OrderUpdateParams::ShippingCost::ShippingRateData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/order_update_params.rb

Defined Under Namespace

Classes: DeliveryEstimate, FixedAmount

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(delivery_estimate: nil, display_name: nil, fixed_amount: nil, metadata: nil, tax_behavior: nil, tax_code: nil, type: nil) ⇒ ShippingRateData

Returns a new instance of ShippingRateData.



1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
1967
1968
# File 'lib/stripe/params/order_update_params.rb', line 1952

def initialize(
  delivery_estimate: nil,
  display_name: nil,
  fixed_amount: nil,
  metadata: nil,
  tax_behavior: nil,
  tax_code: nil,
  type: nil
)
  @delivery_estimate = delivery_estimate
  @display_name = display_name
  @fixed_amount = fixed_amount
  @metadata = 
  @tax_behavior = tax_behavior
  @tax_code = tax_code
  @type = type
end

Instance Attribute Details

#delivery_estimateObject

The estimated range for how long shipping will take, meant to be displayable to the customer. This will appear on CheckoutSessions.



1938
1939
1940
# File 'lib/stripe/params/order_update_params.rb', line 1938

def delivery_estimate
  @delivery_estimate
end

#display_nameObject

The name of the shipping rate, meant to be displayable to the customer. This will appear on CheckoutSessions.



1940
1941
1942
# File 'lib/stripe/params/order_update_params.rb', line 1940

def display_name
  @display_name
end

#fixed_amountObject

Describes a fixed amount to charge for shipping. Must be present if type is fixed_amount.



1942
1943
1944
# File 'lib/stripe/params/order_update_params.rb', line 1942

def fixed_amount
  @fixed_amount
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.



1944
1945
1946
# File 'lib/stripe/params/order_update_params.rb', line 1944

def 
  @metadata
end

#tax_behaviorObject

Specifies whether the rate is considered inclusive of taxes or exclusive of taxes. One of inclusive, exclusive, or unspecified.



1946
1947
1948
# File 'lib/stripe/params/order_update_params.rb', line 1946

def tax_behavior
  @tax_behavior
end

#tax_codeObject

A tax code ID. The Shipping tax code is txcd_92010001.



1948
1949
1950
# File 'lib/stripe/params/order_update_params.rb', line 1948

def tax_code
  @tax_code
end

#typeObject

The type of calculation to use on the shipping rate.



1950
1951
1952
# File 'lib/stripe/params/order_update_params.rb', line 1950

def type
  @type
end