Class: Stripe::OrderUpdateParams::ShippingCost::ShippingRateData::FixedAmount::CurrencyOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/order_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, tax_behavior: nil) ⇒ CurrencyOptions

Returns a new instance of CurrencyOptions.



1916
1917
1918
1919
# File 'lib/stripe/params/order_update_params.rb', line 1916

def initialize(amount: nil, tax_behavior: nil)
  @amount = amount
  @tax_behavior = tax_behavior
end

Instance Attribute Details

#amountObject

A non-negative integer in cents representing how much to charge.



1912
1913
1914
# File 'lib/stripe/params/order_update_params.rb', line 1912

def amount
  @amount
end

#tax_behaviorObject

Specifies whether the rate is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`.



1914
1915
1916
# File 'lib/stripe/params/order_update_params.rb', line 1914

def tax_behavior
  @tax_behavior
end