Class: Stripe::PaymentAttemptRecord::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/payment_attempt_record.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, limit: nil, payment_record: nil) ⇒ ListParams

Returns a new instance of ListParams.



1977
1978
1979
1980
1981
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1977

def initialize(expand: nil, limit: nil, payment_record: nil)
  @expand = expand
  @limit = limit
  @payment_record = payment_record
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



1971
1972
1973
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1971

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



1973
1974
1975
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1973

def limit
  @limit
end

#payment_recordObject

The ID of the Payment Record.



1975
1976
1977
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1975

def payment_record
  @payment_record
end