Class: Stripe::PaymentAttemptRecord::PaymentMethodDetails::BillingDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentAttemptRecord::PaymentMethodDetails::BillingDetails
- Defined in:
- lib/stripe/resources/payment_attempt_record.rb
Defined Under Namespace
Classes: Address
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#address ⇒ Object
readonly
A representation of a physical address.
-
#email ⇒ Object
readonly
The billing email associated with the method of payment.
-
#name ⇒ Object
readonly
The billing name associated with the method of payment.
-
#phone ⇒ Object
readonly
The billing phone number associated with the method of payment.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#address ⇒ Object (readonly)
A representation of a physical address.
248 249 250 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 248 def address @address end |
#email ⇒ Object (readonly)
The billing email associated with the method of payment.
250 251 252 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 250 def email @email end |
#name ⇒ Object (readonly)
The billing name associated with the method of payment.
252 253 254 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 252 def name @name end |
#phone ⇒ Object (readonly)
The billing phone number associated with the method of payment.
254 255 256 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 254 def phone @phone end |