Class: Stripe::PaymentAttemptRecord::PaymentMethodDetails::Card::Checks
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentAttemptRecord::PaymentMethodDetails::Card::Checks
- Defined in:
- lib/stripe/resources/payment_attempt_record.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#address_line1_check ⇒ Object
readonly
If you provide a value for ‘address.line1`, the check result is one of `pass`, `fail`, `unavailable`, or `unchecked`.
-
#address_postal_code_check ⇒ Object
readonly
If you provide a address postal code, the check result is one of ‘pass`, `fail`, `unavailable`, or `unchecked`.
-
#cvc_check ⇒ Object
readonly
If you provide a CVC, the check results is one of ‘pass`, `fail`, `unavailable`, or `unchecked`.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#address_line1_check ⇒ Object (readonly)
If you provide a value for ‘address.line1`, the check result is one of `pass`, `fail`, `unavailable`, or `unchecked`.
490 491 492 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 490 def address_line1_check @address_line1_check end |
#address_postal_code_check ⇒ Object (readonly)
If you provide a address postal code, the check result is one of ‘pass`, `fail`, `unavailable`, or `unchecked`.
492 493 494 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 492 def address_postal_code_check @address_postal_code_check end |
#cvc_check ⇒ Object (readonly)
If you provide a CVC, the check results is one of ‘pass`, `fail`, `unavailable`, or `unchecked`.
494 495 496 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 494 def cvc_check @cvc_check end |
Class Method Details
.field_remappings ⇒ Object
500 501 502 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 500 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
496 497 498 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 496 def self.inner_class_types @inner_class_types = {} end |