Class: Stripe::PaymentAttemptRecord::PaymentMethodDetails::Card::ThreeDSecure
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentAttemptRecord::PaymentMethodDetails::Card::ThreeDSecure
- Defined in:
- lib/stripe/resources/payment_attempt_record.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#authentication_flow ⇒ Object
readonly
For authenticated transactions: Indicates how the issuing bank authenticated the customer.
-
#cryptogram ⇒ Object
readonly
The 3D Secure cryptogram, also known as the “authentication value” (AAV, CAVV or AEVV).
-
#electronic_commerce_indicator ⇒ Object
readonly
The Electronic Commerce Indicator (ECI).
-
#exemption_indicator ⇒ Object
readonly
The exemption requested via 3DS and accepted by the issuer at authentication time.
-
#exemption_indicator_applied ⇒ Object
readonly
Whether Stripe requested the value of ‘exemption_indicator` in the transaction.
-
#result ⇒ Object
readonly
Indicates the outcome of 3D Secure authentication.
-
#result_reason ⇒ Object
readonly
Additional information about why 3D Secure succeeded or failed, based on the ‘result`.
-
#version ⇒ Object
readonly
The version of 3D Secure that was used.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#authentication_flow ⇒ Object (readonly)
For authenticated transactions: Indicates how the issuing bank authenticated the customer.
562 563 564 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 562 def authentication_flow @authentication_flow end |
#cryptogram ⇒ Object (readonly)
The 3D Secure cryptogram, also known as the “authentication value” (AAV, CAVV or AEVV).
564 565 566 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 564 def cryptogram @cryptogram end |
#electronic_commerce_indicator ⇒ Object (readonly)
The Electronic Commerce Indicator (ECI). A protocol-level field indicating what degree of authentication was performed.
566 567 568 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 566 def electronic_commerce_indicator @electronic_commerce_indicator end |
#exemption_indicator ⇒ Object (readonly)
The exemption requested via 3DS and accepted by the issuer at authentication time.
568 569 570 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 568 def exemption_indicator @exemption_indicator end |
#exemption_indicator_applied ⇒ Object (readonly)
Whether Stripe requested the value of ‘exemption_indicator` in the transaction. This will depend on the outcome of Stripe’s internal risk assessment.
570 571 572 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 570 def exemption_indicator_applied @exemption_indicator_applied end |
#result ⇒ Object (readonly)
Indicates the outcome of 3D Secure authentication.
572 573 574 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 572 def result @result end |
#result_reason ⇒ Object (readonly)
Additional information about why 3D Secure succeeded or failed, based on the ‘result`.
574 575 576 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 574 def result_reason @result_reason end |
#version ⇒ Object (readonly)
The version of 3D Secure that was used.
576 577 578 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 576 def version @version end |
Class Method Details
.field_remappings ⇒ Object
582 583 584 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 582 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
578 579 580 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 578 def self.inner_class_types @inner_class_types = {} end |