Class: Stripe::PaymentAttemptRecord::PaymentMethodDetails::Cashapp
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentAttemptRecord::PaymentMethodDetails::Cashapp
- Defined in:
- lib/stripe/resources/payment_attempt_record.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#buyer_id ⇒ Object
readonly
A unique and immutable identifier assigned by Cash App to every buyer.
-
#cashtag ⇒ Object
readonly
A public identifier for buyers using Cash App.
-
#transaction_id ⇒ Object
readonly
A unique and immutable identifier of payments assigned by Cash App.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#buyer_id ⇒ Object (readonly)
A unique and immutable identifier assigned by Cash App to every buyer.
803 804 805 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 803 def buyer_id @buyer_id end |
#cashtag ⇒ Object (readonly)
A public identifier for buyers using Cash App.
805 806 807 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 805 def cashtag @cashtag end |
#transaction_id ⇒ Object (readonly)
A unique and immutable identifier of payments assigned by Cash App.
807 808 809 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 807 def transaction_id @transaction_id end |
Class Method Details
.field_remappings ⇒ Object
813 814 815 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 813 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
809 810 811 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 809 def self.inner_class_types @inner_class_types = {} end |