Class: Stripe::PaymentAttemptRecord::PaymentMethodDetails::Crypto
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentAttemptRecord::PaymentMethodDetails::Crypto
- Defined in:
- lib/stripe/resources/payment_attempt_record.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount_received ⇒ Object
readonly
The amount received for the crypto payment.
-
#amount_requested ⇒ Object
readonly
The amount requested for the crypto payment.
-
#buyer_address ⇒ Object
readonly
The wallet address of the customer.
-
#network ⇒ Object
readonly
The blockchain network that the transaction was sent on.
-
#token_currency ⇒ Object
readonly
The token currency that the transaction was sent with.
-
#transaction_hash ⇒ Object
readonly
The blockchain transaction hash of the crypto payment.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount_received ⇒ Object (readonly)
The amount received for the crypto payment.
873 874 875 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 873 def amount_received @amount_received end |
#amount_requested ⇒ Object (readonly)
The amount requested for the crypto payment.
875 876 877 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 875 def amount_requested @amount_requested end |
#buyer_address ⇒ Object (readonly)
The wallet address of the customer.
877 878 879 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 877 def buyer_address @buyer_address end |
#network ⇒ Object (readonly)
The blockchain network that the transaction was sent on.
879 880 881 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 879 def network @network end |
#token_currency ⇒ Object (readonly)
The token currency that the transaction was sent with.
881 882 883 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 881 def token_currency @token_currency end |
#transaction_hash ⇒ Object (readonly)
The blockchain transaction hash of the crypto payment.
883 884 885 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 883 def transaction_hash @transaction_hash end |
Class Method Details
.field_remappings ⇒ Object
889 890 891 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 889 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
885 886 887 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 885 def self.inner_class_types @inner_class_types = {} end |