Class: Stripe::PaymentAttemptRecord::PaymentMethodDetails::GiftCard

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_attempt_record.rb

Defined Under Namespace

Classes: Balance

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#balanceObject (readonly)

The balance of the gift card after the transaction.



967
968
969
# File 'lib/stripe/resources/payment_attempt_record.rb', line 967

def balance
  @balance
end

#brandObject (readonly)

The brand of the gift card.



969
970
971
# File 'lib/stripe/resources/payment_attempt_record.rb', line 969

def brand
  @brand
end

#exp_monthObject (readonly)

The expiration month of the gift card.



971
972
973
# File 'lib/stripe/resources/payment_attempt_record.rb', line 971

def exp_month
  @exp_month
end

#exp_yearObject (readonly)

The expiration year of the gift card.



973
974
975
# File 'lib/stripe/resources/payment_attempt_record.rb', line 973

def exp_year
  @exp_year
end

#fingerprintObject (readonly)

Uniquely identifies this particular gift card number. You can use this attribute to check whether two transactions were made using the same gift card.



975
976
977
# File 'lib/stripe/resources/payment_attempt_record.rb', line 975

def fingerprint
  @fingerprint
end

#first6Object (readonly)

The first six digits of the gift card number.



977
978
979
# File 'lib/stripe/resources/payment_attempt_record.rb', line 977

def first6
  @first6
end

#last4Object (readonly)

The last four digits of the gift card number.



979
980
981
# File 'lib/stripe/resources/payment_attempt_record.rb', line 979

def last4
  @last4
end

#locationObject (readonly)

ID of the location that this transaction's reader is assigned to.



981
982
983
# File 'lib/stripe/resources/payment_attempt_record.rb', line 981

def location
  @location
end

#readerObject (readonly)

ID of the reader this transaction was made on.



983
984
985
# File 'lib/stripe/resources/payment_attempt_record.rb', line 983

def reader
  @reader
end

#transaction_idObject (readonly)

The transaction ID from the gift card processor.



985
986
987
# File 'lib/stripe/resources/payment_attempt_record.rb', line 985

def transaction_id
  @transaction_id
end

Class Method Details

.field_remappingsObject



991
992
993
# File 'lib/stripe/resources/payment_attempt_record.rb', line 991

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



987
988
989
# File 'lib/stripe/resources/payment_attempt_record.rb', line 987

def self.inner_class_types
  @inner_class_types = { balance: Balance }
end