Class: Stripe::PaymentAttemptRecord::PaymentMethodDetails::SepaCreditTransfer
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentAttemptRecord::PaymentMethodDetails::SepaCreditTransfer
- Defined in:
- lib/stripe/resources/payment_attempt_record.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bank_name ⇒ Object
readonly
Name of the bank associated with the bank account.
-
#bic ⇒ Object
readonly
Bank Identifier Code of the bank associated with the bank account.
-
#iban ⇒ Object
readonly
IBAN of the bank account to transfer funds to.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bank_name ⇒ Object (readonly)
Name of the bank associated with the bank account.
769 770 771 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 769 def bank_name @bank_name end |
#bic ⇒ Object (readonly)
Bank Identifier Code of the bank associated with the bank account.
771 772 773 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 771 def bic @bic end |
#iban ⇒ Object (readonly)
IBAN of the bank account to transfer funds to.
773 774 775 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 773 def iban @iban end |