Class: Stripe::PaymentAttemptRecord::ProcessorDetails

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_attempt_record.rb

Defined Under Namespace

Classes: Custom, FiservValuelink, Givex, Svs

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#customObject (readonly)

Custom processors represent payment processors not modeled directly in the Stripe API. This resource consists of details about the custom processor used for this payment attempt.



2273
2274
2275
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2273

def custom
  @custom
end

Represents the Fiserv ValueLink gift card processor.



2275
2276
2277
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2275

def fiserv_valuelink
  @fiserv_valuelink
end

#givexObject (readonly)

Represents the Givex gift card processor.



2277
2278
2279
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2277

def givex
  @givex
end

#svsObject (readonly)

Represents the SVS gift card processor.



2279
2280
2281
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2279

def svs
  @svs
end

#typeObject (readonly)

The processor used for this payment attempt.



2281
2282
2283
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2281

def type
  @type
end

Class Method Details

.field_remappingsObject



2292
2293
2294
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2292

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2283
2284
2285
2286
2287
2288
2289
2290
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2283

def self.inner_class_types
  @inner_class_types = {
    custom: Custom,
    fiserv_valuelink: FiservValuelink,
    givex: Givex,
    svs: Svs,
  }
end