Class: Stripe::PaymentAttemptRecord::RetrieveParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentAttemptRecord::RetrieveParams
- Defined in:
- lib/stripe/resources/payment_attempt_record.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ RetrieveParams
constructor
A new instance of RetrieveParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ RetrieveParams
Returns a new instance of RetrieveParams.
164 165 166 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 164 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
162 163 164 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 162 def @expand end |