Class: Stripe::PaymentAttemptRecordListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/payment_attempt_record_list_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, limit: nil, payment_record: nil) ⇒ PaymentAttemptRecordListParams

Returns a new instance of PaymentAttemptRecordListParams.



13
14
15
16
17
# File 'lib/stripe/params/payment_attempt_record_list_params.rb', line 13

def initialize(expand: nil, limit: nil, payment_record: nil)
  @expand = expand
  @limit = limit
  @payment_record = payment_record
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



7
8
9
# File 'lib/stripe/params/payment_attempt_record_list_params.rb', line 7

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



9
10
11
# File 'lib/stripe/params/payment_attempt_record_list_params.rb', line 9

def limit
  @limit
end

#payment_recordObject

The ID of the Payment Record.



11
12
13
# File 'lib/stripe/params/payment_attempt_record_list_params.rb', line 11

def payment_record
  @payment_record
end