Class: Stripe::PaymentAttemptRecordReportEarlyFraudWarningParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_attempt_record_report_early_fraud_warning_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(expand: nil, fraud_type: nil, metadata: nil, occurred_at: nil) ⇒ PaymentAttemptRecordReportEarlyFraudWarningParams

Returns a new instance of PaymentAttemptRecordReportEarlyFraudWarningParams.



15
16
17
18
19
20
# File 'lib/stripe/params/payment_attempt_record_report_early_fraud_warning_params.rb', line 15

def initialize(expand: nil, fraud_type: nil, metadata: nil, occurred_at: nil)
  @expand = expand
  @fraud_type = fraud_type
  @metadata = 
  @occurred_at = occurred_at
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



7
8
9
# File 'lib/stripe/params/payment_attempt_record_report_early_fraud_warning_params.rb', line 7

def expand
  @expand
end

#fraud_typeObject

The type of fraud reported in the early fraud warning.



9
10
11
# File 'lib/stripe/params/payment_attempt_record_report_early_fraud_warning_params.rb', line 9

def fraud_type
  @fraud_type
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.



11
12
13
# File 'lib/stripe/params/payment_attempt_record_report_early_fraud_warning_params.rb', line 11

def 
  @metadata
end

#occurred_atObject

The time at which the early fraud warning was received.



13
14
15
# File 'lib/stripe/params/payment_attempt_record_report_early_fraud_warning_params.rb', line 13

def occurred_at
  @occurred_at
end