Class: Stripe::PaymentAttemptRecordReportFailedParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentAttemptRecordReportFailedParams
- Defined in:
- lib/stripe/params/payment_attempt_record_report_failed_params.rb
Defined Under Namespace
Classes: PaymentMethodDetails, ProcessorDetails
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#failed_at ⇒ Object
When the reported payment failed.
-
#failure_code ⇒ Object
The failure code for this payment attempt.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#payment_evaluations ⇒ Object
Payment evaluations associated with this reported payment.
-
#payment_method_details ⇒ Object
Information about the Payment Method debited for this payment.
-
#processor_details ⇒ Object
Processor information for this payment.
Instance Method Summary collapse
-
#initialize(expand: nil, failed_at: nil, failure_code: nil, metadata: nil, payment_evaluations: nil, payment_method_details: nil, processor_details: nil) ⇒ PaymentAttemptRecordReportFailedParams
constructor
A new instance of PaymentAttemptRecordReportFailedParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(expand: nil, failed_at: nil, failure_code: nil, metadata: nil, payment_evaluations: nil, payment_method_details: nil, processor_details: nil) ⇒ PaymentAttemptRecordReportFailedParams
Returns a new instance of PaymentAttemptRecordReportFailedParams.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/stripe/params/payment_attempt_record_report_failed_params.rb', line 77 def initialize( expand: nil, failed_at: nil, failure_code: nil, metadata: nil, payment_evaluations: nil, payment_method_details: nil, processor_details: nil ) @expand = @failed_at = failed_at @failure_code = failure_code @metadata = @payment_evaluations = payment_evaluations @payment_method_details = payment_method_details @processor_details = processor_details end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
63 64 65 |
# File 'lib/stripe/params/payment_attempt_record_report_failed_params.rb', line 63 def @expand end |
#failed_at ⇒ Object
When the reported payment failed. Measured in seconds since the Unix epoch.
65 66 67 |
# File 'lib/stripe/params/payment_attempt_record_report_failed_params.rb', line 65 def failed_at @failed_at end |
#failure_code ⇒ Object
The failure code for this payment attempt. Must be one of payment_method_customer_decline, payment_method_provider_unknown_outcome, authentication_failure, expired_payment_method, incorrect_cvc, incorrect_number, incorrect_postal_code, insufficient_funds, processing_error, or payment_method_restricted.
67 68 69 |
# File 'lib/stripe/params/payment_attempt_record_report_failed_params.rb', line 67 def failure_code @failure_code end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
69 70 71 |
# File 'lib/stripe/params/payment_attempt_record_report_failed_params.rb', line 69 def @metadata end |
#payment_evaluations ⇒ Object
Payment evaluations associated with this reported payment.
71 72 73 |
# File 'lib/stripe/params/payment_attempt_record_report_failed_params.rb', line 71 def payment_evaluations @payment_evaluations end |
#payment_method_details ⇒ Object
Information about the Payment Method debited for this payment.
73 74 75 |
# File 'lib/stripe/params/payment_attempt_record_report_failed_params.rb', line 73 def payment_method_details @payment_method_details end |
#processor_details ⇒ Object
Processor information for this payment.
75 76 77 |
# File 'lib/stripe/params/payment_attempt_record_report_failed_params.rb', line 75 def processor_details @processor_details end |