Class: Stripe::PaymentAttemptRecordReportFailedParams::PaymentMethodDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentAttemptRecordReportFailedParams::PaymentMethodDetails
- Defined in:
- lib/stripe/params/payment_attempt_record_report_failed_params.rb
Defined Under Namespace
Classes: Card
Instance Attribute Summary collapse
-
#card ⇒ Object
Information about the card payment method used to make this payment.
-
#type ⇒ Object
The type of the payment method details.
Instance Method Summary collapse
-
#initialize(card: nil, type: nil) ⇒ PaymentMethodDetails
constructor
A new instance of PaymentMethodDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(card: nil, type: nil) ⇒ PaymentMethodDetails
Returns a new instance of PaymentMethodDetails.
37 38 39 40 |
# File 'lib/stripe/params/payment_attempt_record_report_failed_params.rb', line 37 def initialize(card: nil, type: nil) @card = card @type = type end |
Instance Attribute Details
#card ⇒ Object
Information about the card payment method used to make this payment.
33 34 35 |
# File 'lib/stripe/params/payment_attempt_record_report_failed_params.rb', line 33 def card @card end |
#type ⇒ Object
The type of the payment method details. An additional hash is included on the payment_method_details with a name matching this value. It contains additional information specific to the type.
35 36 37 |
# File 'lib/stripe/params/payment_attempt_record_report_failed_params.rb', line 35 def type @type end |