Class: Stripe::PaymentAttemptRecordReportGuaranteedParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_attempt_record_report_guaranteed_params.rb

Defined Under Namespace

Classes: PaymentMethodDetails, ProcessorDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(expand: nil, guaranteed_at: nil, is_anomalous: nil, metadata: nil, payment_evaluations: nil, payment_method_details: nil, processor_details: nil) ⇒ PaymentAttemptRecordReportGuaranteedParams

Returns a new instance of PaymentAttemptRecordReportGuaranteedParams.



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/stripe/params/payment_attempt_record_report_guaranteed_params.rb', line 74

def initialize(
  expand: nil,
  guaranteed_at: nil,
  is_anomalous: nil,
  metadata: nil,
  payment_evaluations: nil,
  payment_method_details: nil,
  processor_details: nil
)
  @expand = expand
  @guaranteed_at = guaranteed_at
  @is_anomalous = is_anomalous
  @metadata = 
  @payment_evaluations = payment_evaluations
  @payment_method_details = payment_method_details
  @processor_details = processor_details
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



60
61
62
# File 'lib/stripe/params/payment_attempt_record_report_guaranteed_params.rb', line 60

def expand
  @expand
end

#guaranteed_atObject

When the reported payment was guaranteed. Measured in seconds since the Unix epoch.



62
63
64
# File 'lib/stripe/params/payment_attempt_record_report_guaranteed_params.rb', line 62

def guaranteed_at
  @guaranteed_at
end

#is_anomalousObject

Set to true to enable writing an anomalous guaranteed payment to an outdated PaymentAttemptRecord. This parameter defaults to false.



64
65
66
# File 'lib/stripe/params/payment_attempt_record_report_guaranteed_params.rb', line 64

def is_anomalous
  @is_anomalous
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.



66
67
68
# File 'lib/stripe/params/payment_attempt_record_report_guaranteed_params.rb', line 66

def 
  @metadata
end

#payment_evaluationsObject

Payment evaluations associated with this reported payment.



68
69
70
# File 'lib/stripe/params/payment_attempt_record_report_guaranteed_params.rb', line 68

def payment_evaluations
  @payment_evaluations
end

#payment_method_detailsObject

Information about the Payment Method debited for this payment.



70
71
72
# File 'lib/stripe/params/payment_attempt_record_report_guaranteed_params.rb', line 70

def payment_method_details
  @payment_method_details
end

#processor_detailsObject

Processor information for this payment.



72
73
74
# File 'lib/stripe/params/payment_attempt_record_report_guaranteed_params.rb', line 72

def processor_details
  @processor_details
end