Class: Stripe::PaymentAttemptRecordReportRefundParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_attempt_record_report_refund_params.rb

Defined Under Namespace

Classes: Amount, Failed, ProcessorDetails, Refunded

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, expand: nil, failed: nil, initiated_at: nil, metadata: nil, outcome: nil, processor_details: nil, reason: nil, refund_group: nil, refunded: nil) ⇒ PaymentAttemptRecordReportRefundParams

Returns a new instance of PaymentAttemptRecordReportRefundParams.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/stripe/params/payment_attempt_record_report_refund_params.rb', line 79

def initialize(
  amount: nil,
  expand: nil,
  failed: nil,
  initiated_at: nil,
  metadata: nil,
  outcome: nil,
  processor_details: nil,
  reason: nil,
  refund_group: nil,
  refunded: nil
)
  @amount = amount
  @expand = expand
  @failed = failed
  @initiated_at = initiated_at
  @metadata = 
  @outcome = outcome
  @processor_details = processor_details
  @reason = reason
  @refund_group = refund_group
  @refunded = refunded
end

Instance Attribute Details

#amountObject

A positive integer in the smallest currency unit representing how much of this payment to refund. Can refund only up to the remaining, unrefunded amount of the payment.



59
60
61
# File 'lib/stripe/params/payment_attempt_record_report_refund_params.rb', line 59

def amount
  @amount
end

#expandObject

Specifies which fields in the response should be expanded.



61
62
63
# File 'lib/stripe/params/payment_attempt_record_report_refund_params.rb', line 61

def expand
  @expand
end

#failedObject

Information about the refund failure.



63
64
65
# File 'lib/stripe/params/payment_attempt_record_report_refund_params.rb', line 63

def failed
  @failed
end

#initiated_atObject

When the reported refund was initiated. Measured in seconds since the Unix epoch.



65
66
67
# File 'lib/stripe/params/payment_attempt_record_report_refund_params.rb', line 65

def initiated_at
  @initiated_at
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.



67
68
69
# File 'lib/stripe/params/payment_attempt_record_report_refund_params.rb', line 67

def 
  @metadata
end

#outcomeObject

The outcome of the reported refund.



69
70
71
# File 'lib/stripe/params/payment_attempt_record_report_refund_params.rb', line 69

def outcome
  @outcome
end

#processor_detailsObject

Processor information for this refund.



71
72
73
# File 'lib/stripe/params/payment_attempt_record_report_refund_params.rb', line 71

def processor_details
  @processor_details
end

#reasonObject

The reason for the refund. One of duplicate, fraudulent, or requested_by_customer.



73
74
75
# File 'lib/stripe/params/payment_attempt_record_report_refund_params.rb', line 73

def reason
  @reason
end

#refund_groupObject

A key to group refunds together.



75
76
77
# File 'lib/stripe/params/payment_attempt_record_report_refund_params.rb', line 75

def refund_group
  @refund_group
end

#refundedObject

Information about the payment attempt refund.



77
78
79
# File 'lib/stripe/params/payment_attempt_record_report_refund_params.rb', line 77

def refunded
  @refunded
end