Class: Stripe::PaymentAttemptRecordService::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentAttemptRecordService::ListParams
- Defined in:
- lib/stripe/services/payment_attempt_record_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#payment_record ⇒ Object
The ID of the Payment Record.
Instance Method Summary collapse
-
#initialize(expand: nil, limit: nil, payment_record: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, limit: nil, payment_record: nil) ⇒ ListParams
Returns a new instance of ListParams.
14 15 16 17 18 |
# File 'lib/stripe/services/payment_attempt_record_service.rb', line 14 def initialize(expand: nil, limit: nil, payment_record: nil) @expand = @limit = limit @payment_record = payment_record end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
8 9 10 |
# File 'lib/stripe/services/payment_attempt_record_service.rb', line 8 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
10 11 12 |
# File 'lib/stripe/services/payment_attempt_record_service.rb', line 10 def limit @limit end |
#payment_record ⇒ Object
The ID of the Payment Record.
12 13 14 |
# File 'lib/stripe/services/payment_attempt_record_service.rb', line 12 def payment_record @payment_record end |