Class: Stripe::PaymentIntent::AdvancedFeatureDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::AdvancedFeatureDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: DecrementalAuthorization, IncrementalAuthorization, Multicapture, Overcapture, Reauthorization
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#capture_before ⇒ Object
readonly
Timestamp at which the authorization will expire if not captured.
-
#decremental_authorization ⇒ Object
readonly
Attribute for field decremental_authorization.
-
#incremental_authorization ⇒ Object
readonly
Attribute for field incremental_authorization.
-
#multicapture ⇒ Object
readonly
Attribute for field multicapture.
-
#overcapture ⇒ Object
readonly
Attribute for field overcapture.
-
#reauthorization ⇒ Object
readonly
Attribute for field reauthorization.
-
#reauthorize_before ⇒ Object
readonly
Timestamp at which the reauthorization window closes.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#capture_before ⇒ Object (readonly)
Timestamp at which the authorization will expire if not captured.
98 99 100 |
# File 'lib/stripe/resources/payment_intent.rb', line 98 def capture_before @capture_before end |
#decremental_authorization ⇒ Object (readonly)
Attribute for field decremental_authorization
100 101 102 |
# File 'lib/stripe/resources/payment_intent.rb', line 100 def @decremental_authorization end |
#incremental_authorization ⇒ Object (readonly)
Attribute for field incremental_authorization
102 103 104 |
# File 'lib/stripe/resources/payment_intent.rb', line 102 def @incremental_authorization end |
#multicapture ⇒ Object (readonly)
Attribute for field multicapture
104 105 106 |
# File 'lib/stripe/resources/payment_intent.rb', line 104 def multicapture @multicapture end |
#overcapture ⇒ Object (readonly)
Attribute for field overcapture
106 107 108 |
# File 'lib/stripe/resources/payment_intent.rb', line 106 def overcapture @overcapture end |
#reauthorization ⇒ Object (readonly)
Attribute for field reauthorization
108 109 110 |
# File 'lib/stripe/resources/payment_intent.rb', line 108 def @reauthorization end |
#reauthorize_before ⇒ Object (readonly)
Timestamp at which the reauthorization window closes.
110 111 112 |
# File 'lib/stripe/resources/payment_intent.rb', line 110 def @reauthorize_before end |
Class Method Details
.field_remappings ⇒ Object
122 123 124 |
# File 'lib/stripe/resources/payment_intent.rb', line 122 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
112 113 114 115 116 117 118 119 120 |
# File 'lib/stripe/resources/payment_intent.rb', line 112 def self.inner_class_types @inner_class_types = { decremental_authorization: DecrementalAuthorization, incremental_authorization: IncrementalAuthorization, multicapture: Multicapture, overcapture: Overcapture, reauthorization: Reauthorization, } end |