Class: Stripe::PaymentIntent::AmountDetails::Tax
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::AmountDetails::Tax
- Defined in:
- lib/stripe/resources/payment_intent.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#total_tax_amount ⇒ Object
readonly
The total amount of tax on the transaction represented in the smallest currency unit.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#total_tax_amount ⇒ Object (readonly)
The total amount of tax on the transaction represented in the smallest currency unit. Required for L2 rates. An integer greater than or equal to 0.
This field is mutually exclusive with the amount_details[line_items][#][tax][total_tax_amount] field.
211 212 213 |
# File 'lib/stripe/resources/payment_intent.rb', line 211 def total_tax_amount @total_tax_amount end |
Class Method Details
.field_remappings ⇒ Object
217 218 219 |
# File 'lib/stripe/resources/payment_intent.rb', line 217 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
213 214 215 |
# File 'lib/stripe/resources/payment_intent.rb', line 213 def self.inner_class_types @inner_class_types = {} end |