Class: Stripe::PaymentIntent::CancelParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CancelParams
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#cancellation_reason ⇒ Object
Reason for canceling this PaymentIntent.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(cancellation_reason: nil, expand: nil) ⇒ CancelParams
constructor
A new instance of CancelParams.
Methods inherited from RequestParams
Constructor Details
#initialize(cancellation_reason: nil, expand: nil) ⇒ CancelParams
Returns a new instance of CancelParams.
6406 6407 6408 6409 |
# File 'lib/stripe/resources/payment_intent.rb', line 6406 def initialize(cancellation_reason: nil, expand: nil) @cancellation_reason = cancellation_reason @expand = end |
Instance Attribute Details
#cancellation_reason ⇒ Object
Reason for canceling this PaymentIntent. Possible values are: ‘duplicate`, `fraudulent`, `requested_by_customer`, or `abandoned`
6402 6403 6404 |
# File 'lib/stripe/resources/payment_intent.rb', line 6402 def cancellation_reason @cancellation_reason end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
6404 6405 6406 |
# File 'lib/stripe/resources/payment_intent.rb', line 6404 def @expand end |