Class: Stripe::PaymentIntent::CaptureParams::AmountDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: LineItem, Shipping, Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discount_amount: nil, line_items: nil, shipping: nil, tax: nil) ⇒ AmountDetails

Returns a new instance of AmountDetails.



9819
9820
9821
9822
9823
9824
# File 'lib/stripe/resources/payment_intent.rb', line 9819

def initialize(discount_amount: nil, line_items: nil, shipping: nil, tax: nil)
  @discount_amount = discount_amount
  @line_items = line_items
  @shipping = shipping
  @tax = tax
end

Instance Attribute Details

#discount_amountObject

The amount an item was discounted for.



9811
9812
9813
# File 'lib/stripe/resources/payment_intent.rb', line 9811

def discount_amount
  @discount_amount
end

#line_itemsObject

A list of line items, each containing information about a product in the PaymentIntent. There is a maximum of 100 line items.



9813
9814
9815
# File 'lib/stripe/resources/payment_intent.rb', line 9813

def line_items
  @line_items
end

#shippingObject

Contains information about the shipping portion of the amount.



9815
9816
9817
# File 'lib/stripe/resources/payment_intent.rb', line 9815

def shipping
  @shipping
end

#taxObject

Contains information about the tax portion of the amount.



9817
9818
9819
# File 'lib/stripe/resources/payment_intent.rb', line 9817

def tax
  @tax
end