Class: Stripe::PaymentIntent::CaptureParams::AmountDetails::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CaptureParams::AmountDetails::LineItem
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: PaymentMethodOptions, Tax
Instance Attribute Summary collapse
-
#discount_amount ⇒ Object
The amount an item was discounted for.
-
#payment_method_options ⇒ Object
Payment method-specific information for line items.
-
#product_code ⇒ Object
Unique identifier of the product.
-
#product_name ⇒ Object
Name of the product.
-
#quantity ⇒ Object
Number of items of the product.
-
#tax ⇒ Object
Contains information about the tax on the item.
-
#unit_cost ⇒ Object
Cost of the product.
-
#unit_of_measure ⇒ Object
A unit of measure for the line item, such as gallons, feet, meters, etc.
Instance Method Summary collapse
-
#initialize(discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil) ⇒ LineItem
Returns a new instance of LineItem.
9766 9767 9768 9769 9770 9771 9772 9773 9774 9775 9776 9777 9778 9779 9780 9781 9782 9783 9784 |
# File 'lib/stripe/resources/payment_intent.rb', line 9766 def initialize( discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil ) @discount_amount = discount_amount @payment_method_options = @product_code = product_code @product_name = product_name @quantity = quantity @tax = tax @unit_cost = unit_cost @unit_of_measure = unit_of_measure end |
Instance Attribute Details
#discount_amount ⇒ Object
The amount an item was discounted for. Positive integer.
9750 9751 9752 |
# File 'lib/stripe/resources/payment_intent.rb', line 9750 def discount_amount @discount_amount end |
#payment_method_options ⇒ Object
Payment method-specific information for line items.
9752 9753 9754 |
# File 'lib/stripe/resources/payment_intent.rb', line 9752 def @payment_method_options end |
#product_code ⇒ Object
Unique identifier of the product. At most 12 characters long.
9754 9755 9756 |
# File 'lib/stripe/resources/payment_intent.rb', line 9754 def product_code @product_code end |
#product_name ⇒ Object
Name of the product. At most 100 characters long.
9756 9757 9758 |
# File 'lib/stripe/resources/payment_intent.rb', line 9756 def product_name @product_name end |
#quantity ⇒ Object
Number of items of the product. Positive integer.
9758 9759 9760 |
# File 'lib/stripe/resources/payment_intent.rb', line 9758 def quantity @quantity end |
#tax ⇒ Object
Contains information about the tax on the item.
9760 9761 9762 |
# File 'lib/stripe/resources/payment_intent.rb', line 9760 def tax @tax end |
#unit_cost ⇒ Object
Cost of the product. Non-negative integer.
9762 9763 9764 |
# File 'lib/stripe/resources/payment_intent.rb', line 9762 def unit_cost @unit_cost end |
#unit_of_measure ⇒ Object
A unit of measure for the line item, such as gallons, feet, meters, etc.
9764 9765 9766 |
# File 'lib/stripe/resources/payment_intent.rb', line 9764 def unit_of_measure @unit_of_measure end |