Class: Stripe::PaymentIntent::CaptureParams::AmountDetails::LineItem::PaymentMethodOptions::Paypal
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CaptureParams::AmountDetails::LineItem::PaymentMethodOptions::Paypal
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, sold_by: nil) ⇒ Paypal
constructor
A new instance of Paypal.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, description: nil, sold_by: nil) ⇒ Paypal
Returns a new instance of Paypal.
9718 9719 9720 9721 9722 |
# File 'lib/stripe/resources/payment_intent.rb', line 9718 def initialize(category: nil, description: nil, sold_by: nil) @category = category @description = description @sold_by = sold_by end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
9712 9713 9714 |
# File 'lib/stripe/resources/payment_intent.rb', line 9712 def category @category end |
#description ⇒ Object
Description of the line item.
9714 9715 9716 |
# File 'lib/stripe/resources/payment_intent.rb', line 9714 def description @description end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
9716 9717 9718 |
# File 'lib/stripe/resources/payment_intent.rb', line 9716 def sold_by @sold_by end |