Class: Stripe::PaymentIntent::CaptureParams::AmountDetails::Tax
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CaptureParams::AmountDetails::Tax
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#total_tax_amount ⇒ Object
Total portion of the amount that is for tax.
Instance Method Summary collapse
-
#initialize(total_tax_amount: nil) ⇒ Tax
constructor
A new instance of Tax.
Methods inherited from RequestParams
Constructor Details
#initialize(total_tax_amount: nil) ⇒ Tax
Returns a new instance of Tax.
11187 11188 11189 |
# File 'lib/stripe/resources/payment_intent.rb', line 11187 def initialize(total_tax_amount: nil) @total_tax_amount = total_tax_amount end |
Instance Attribute Details
#total_tax_amount ⇒ Object
Total portion of the amount that is for tax.
11185 11186 11187 |
# File 'lib/stripe/resources/payment_intent.rb', line 11185 def total_tax_amount @total_tax_amount end |