Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: CarRental, EventDetails, Flight, Lodging, Subscription

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails

Returns a new instance of PaymentDetails.



10538
10539
10540
10541
10542
10543
10544
10545
10546
10547
10548
10549
10550
10551
10552
10553
10554
# File 'lib/stripe/resources/payment_intent.rb', line 10538

def initialize(
  car_rental: nil,
  customer_reference: nil,
  event_details: nil,
  flight: nil,
  lodging: nil,
  order_reference: nil,
  subscription: nil
)
  @car_rental = car_rental
  @customer_reference = customer_reference
  @event_details = event_details
  @flight = flight
  @lodging = lodging
  @order_reference = order_reference
  @subscription = subscription
end

Instance Attribute Details

#car_rentalObject

Car rental details for this PaymentIntent.



10524
10525
10526
# File 'lib/stripe/resources/payment_intent.rb', line 10524

def car_rental
  @car_rental
end

#customer_referenceObject

Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.



10526
10527
10528
# File 'lib/stripe/resources/payment_intent.rb', line 10526

def customer_reference
  @customer_reference
end

#event_detailsObject

Event details for this PaymentIntent



10528
10529
10530
# File 'lib/stripe/resources/payment_intent.rb', line 10528

def event_details
  @event_details
end

#flightObject

Flight reservation details for this PaymentIntent



10530
10531
10532
# File 'lib/stripe/resources/payment_intent.rb', line 10530

def flight
  @flight
end

#lodgingObject

Lodging reservation details for this PaymentIntent



10532
10533
10534
# File 'lib/stripe/resources/payment_intent.rb', line 10532

def lodging
  @lodging
end

#order_referenceObject

A unique value assigned by the business to identify the transaction.



10534
10535
10536
# File 'lib/stripe/resources/payment_intent.rb', line 10534

def order_reference
  @order_reference
end

#subscriptionObject

Subscription details for this PaymentIntent



10536
10537
10538
# File 'lib/stripe/resources/payment_intent.rb', line 10536

def subscription
  @subscription
end