Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::CarRental::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



9872
9873
9874
9875
9876
# File 'lib/stripe/resources/payment_intent.rb', line 9872

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



9866
9867
9868
# File 'lib/stripe/resources/payment_intent.rb', line 9866

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



9868
9869
9870
# File 'lib/stripe/resources/payment_intent.rb', line 9868

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



9870
9871
9872
# File 'lib/stripe/resources/payment_intent.rb', line 9870

def phone
  @phone
end