Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CaptureParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
11545 11546 11547 11548 11549 11550 11551 11552 11553 11554 11555 11556 11557 11558 11559 11560 11561 11562 11563 11564 11565 |
# File 'lib/stripe/resources/payment_intent.rb', line 11545 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
11527 11528 11529 |
# File 'lib/stripe/resources/payment_intent.rb', line 11527 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
11529 11530 11531 |
# File 'lib/stripe/resources/payment_intent.rb', line 11529 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
11531 11532 11533 |
# File 'lib/stripe/resources/payment_intent.rb', line 11531 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
11533 11534 11535 |
# File 'lib/stripe/resources/payment_intent.rb', line 11533 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
11535 11536 11537 |
# File 'lib/stripe/resources/payment_intent.rb', line 11535 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
11537 11538 11539 |
# File 'lib/stripe/resources/payment_intent.rb', line 11537 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
11539 11540 11541 |
# File 'lib/stripe/resources/payment_intent.rb', line 11539 def genre @genre end |
#name ⇒ Object
The name of the event.
11541 11542 11543 |
# File 'lib/stripe/resources/payment_intent.rb', line 11541 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
11543 11544 11545 |
# File 'lib/stripe/resources/payment_intent.rb', line 11543 def starts_at @starts_at end |