Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::EventDetails::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



10129
10130
10131
10132
10133
# File 'lib/stripe/resources/payment_intent.rb', line 10129

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



10123
10124
10125
# File 'lib/stripe/resources/payment_intent.rb', line 10123

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



10125
10126
10127
# File 'lib/stripe/resources/payment_intent.rb', line 10125

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



10127
10128
10129
# File 'lib/stripe/resources/payment_intent.rb', line 10127

def phone
  @phone
end