Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::Flight
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CaptureParams::PaymentDetails::Flight
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Passenger, Segment
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
-
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#segments ⇒ Object
The individual flight segments associated with the trip.
-
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
Instance Method Summary collapse
-
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
constructor
A new instance of Flight.
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
Returns a new instance of Flight.
10287 10288 10289 10290 10291 10292 10293 10294 10295 10296 10297 10298 10299 10300 10301 10302 10303 10304 10305 |
# File 'lib/stripe/resources/payment_intent.rb', line 10287 def initialize( affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil ) @affiliate = affiliate @agency_number = agency_number @carrier = carrier @delivery = delivery @passenger_name = passenger_name @passengers = passengers @segments = segments @ticket_number = ticket_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
10271 10272 10273 |
# File 'lib/stripe/resources/payment_intent.rb', line 10271 def affiliate @affiliate end |
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
10273 10274 10275 |
# File 'lib/stripe/resources/payment_intent.rb', line 10273 def agency_number @agency_number end |
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
10275 10276 10277 |
# File 'lib/stripe/resources/payment_intent.rb', line 10275 def carrier @carrier end |
#delivery ⇒ Object
Delivery details for this purchase.
10277 10278 10279 |
# File 'lib/stripe/resources/payment_intent.rb', line 10277 def delivery @delivery end |
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
10279 10280 10281 |
# File 'lib/stripe/resources/payment_intent.rb', line 10279 def passenger_name @passenger_name end |
#passengers ⇒ Object
The details of the passengers in the travel reservation.
10281 10282 10283 |
# File 'lib/stripe/resources/payment_intent.rb', line 10281 def passengers @passengers end |
#segments ⇒ Object
The individual flight segments associated with the trip.
10283 10284 10285 |
# File 'lib/stripe/resources/payment_intent.rb', line 10283 def segments @segments end |
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
10285 10286 10287 |
# File 'lib/stripe/resources/payment_intent.rb', line 10285 def ticket_number @ticket_number end |