Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::Flight::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



11587
11588
11589
11590
11591
# File 'lib/stripe/resources/payment_intent.rb', line 11587

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



11581
11582
11583
# File 'lib/stripe/resources/payment_intent.rb', line 11581

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



11583
11584
11585
# File 'lib/stripe/resources/payment_intent.rb', line 11583

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



11585
11586
11587
# File 'lib/stripe/resources/payment_intent.rb', line 11585

def phone
  @phone
end