Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::Flight::Segment
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CaptureParams::PaymentDetails::Flight::Segment
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The flight segment amount.
-
#arrival_airport ⇒ Object
The International Air Transport Association (IATA) airport code for the arrival airport.
-
#arrives_at ⇒ Object
The arrival time for the flight segment.
-
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier operating the flight segment.
-
#departs_at ⇒ Object
The departure time for the flight segment.
-
#departure_airport ⇒ Object
The International Air Transport Association (IATA) airport code for the departure airport.
-
#flight_number ⇒ Object
The flight number associated with the segment.
-
#service_class ⇒ Object
The fare class for the segment.
Instance Method Summary collapse
-
#initialize(amount: nil, arrival_airport: nil, arrives_at: nil, carrier: nil, departs_at: nil, departure_airport: nil, flight_number: nil, service_class: nil) ⇒ Segment
constructor
A new instance of Segment.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, arrival_airport: nil, arrives_at: nil, carrier: nil, departs_at: nil, departure_airport: nil, flight_number: nil, service_class: nil) ⇒ Segment
Returns a new instance of Segment.
10250 10251 10252 10253 10254 10255 10256 10257 10258 10259 10260 10261 10262 10263 10264 10265 10266 10267 10268 |
# File 'lib/stripe/resources/payment_intent.rb', line 10250 def initialize( amount: nil, arrival_airport: nil, arrives_at: nil, carrier: nil, departs_at: nil, departure_airport: nil, flight_number: nil, service_class: nil ) @amount = amount @arrival_airport = arrival_airport @arrives_at = arrives_at @carrier = carrier @departs_at = departs_at @departure_airport = departure_airport @flight_number = flight_number @service_class = service_class end |
Instance Attribute Details
#amount ⇒ Object
The flight segment amount.
10234 10235 10236 |
# File 'lib/stripe/resources/payment_intent.rb', line 10234 def amount @amount end |
#arrival_airport ⇒ Object
The International Air Transport Association (IATA) airport code for the arrival airport.
10236 10237 10238 |
# File 'lib/stripe/resources/payment_intent.rb', line 10236 def arrival_airport @arrival_airport end |
#arrives_at ⇒ Object
The arrival time for the flight segment. Measured in seconds since the Unix epoch.
10238 10239 10240 |
# File 'lib/stripe/resources/payment_intent.rb', line 10238 def arrives_at @arrives_at end |
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier operating the flight segment.
10240 10241 10242 |
# File 'lib/stripe/resources/payment_intent.rb', line 10240 def carrier @carrier end |
#departs_at ⇒ Object
The departure time for the flight segment. Measured in seconds since the Unix epoch.
10242 10243 10244 |
# File 'lib/stripe/resources/payment_intent.rb', line 10242 def departs_at @departs_at end |
#departure_airport ⇒ Object
The International Air Transport Association (IATA) airport code for the departure airport.
10244 10245 10246 |
# File 'lib/stripe/resources/payment_intent.rb', line 10244 def departure_airport @departure_airport end |
#flight_number ⇒ Object
The flight number associated with the segment
10246 10247 10248 |
# File 'lib/stripe/resources/payment_intent.rb', line 10246 def flight_number @flight_number end |
#service_class ⇒ Object
The fare class for the segment.
10248 10249 10250 |
# File 'lib/stripe/resources/payment_intent.rb', line 10248 def service_class @service_class end |