Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::Lodging

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Address, Affiliate, Delivery, Passenger

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging

Returns a new instance of Lodging.



10426
10427
10428
10429
10430
10431
10432
10433
10434
10435
10436
10437
10438
10439
10440
10441
10442
10443
10444
10445
10446
10447
10448
10449
10450
10451
10452
10453
10454
10455
10456
10457
10458
10459
10460
10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
# File 'lib/stripe/resources/payment_intent.rb', line 10426

def initialize(
  address: nil,
  adults: nil,
  affiliate: nil,
  booking_number: nil,
  category: nil,
  checkin_at: nil,
  checkout_at: nil,
  customer_service_phone_number: nil,
  daily_room_rate_amount: nil,
  delivery: nil,
  extra_charges: nil,
  fire_safety_act_compliance: nil,
  name: nil,
  no_show: nil,
  number_of_rooms: nil,
  passengers: nil,
  property_phone_number: nil,
  room_class: nil,
  room_nights: nil,
  total_room_tax_amount: nil,
  total_tax_amount: nil
)
  @address = address
  @adults = adults
  @affiliate = affiliate
  @booking_number = booking_number
  @category = category
  @checkin_at = checkin_at
  @checkout_at = checkout_at
  @customer_service_phone_number = customer_service_phone_number
  @daily_room_rate_amount = daily_room_rate_amount
  @delivery = delivery
  @extra_charges = extra_charges
  @fire_safety_act_compliance = fire_safety_act_compliance
  @name = name
  @no_show = no_show
  @number_of_rooms = number_of_rooms
  @passengers = passengers
  @property_phone_number = property_phone_number
  @room_class = room_class
  @room_nights = room_nights
  @total_room_tax_amount = total_room_tax_amount
  @total_tax_amount = total_tax_amount
end

Instance Attribute Details

#addressObject

The lodging location’s address.



10384
10385
10386
# File 'lib/stripe/resources/payment_intent.rb', line 10384

def address
  @address
end

#adultsObject

The number of adults on the booking



10386
10387
10388
# File 'lib/stripe/resources/payment_intent.rb', line 10386

def adults
  @adults
end

#affiliateObject

Affiliate details for this purchase.



10388
10389
10390
# File 'lib/stripe/resources/payment_intent.rb', line 10388

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the lodging reservation.



10390
10391
10392
# File 'lib/stripe/resources/payment_intent.rb', line 10390

def booking_number
  @booking_number
end

#categoryObject

The lodging category



10392
10393
10394
# File 'lib/stripe/resources/payment_intent.rb', line 10392

def category
  @category
end

#checkin_atObject

Lodging check-in time. Measured in seconds since the Unix epoch.



10394
10395
10396
# File 'lib/stripe/resources/payment_intent.rb', line 10394

def checkin_at
  @checkin_at
end

#checkout_atObject

Lodging check-out time. Measured in seconds since the Unix epoch.



10396
10397
10398
# File 'lib/stripe/resources/payment_intent.rb', line 10396

def checkout_at
  @checkout_at
end

#customer_service_phone_numberObject

The customer service phone number of the lodging company.



10398
10399
10400
# File 'lib/stripe/resources/payment_intent.rb', line 10398

def customer_service_phone_number
  @customer_service_phone_number
end

#daily_room_rate_amountObject

The daily lodging room rate.



10400
10401
10402
# File 'lib/stripe/resources/payment_intent.rb', line 10400

def daily_room_rate_amount
  @daily_room_rate_amount
end

#deliveryObject

Delivery details for this purchase.



10402
10403
10404
# File 'lib/stripe/resources/payment_intent.rb', line 10402

def delivery
  @delivery
end

#extra_chargesObject

List of additional charges being billed.



10404
10405
10406
# File 'lib/stripe/resources/payment_intent.rb', line 10404

def extra_charges
  @extra_charges
end

#fire_safety_act_complianceObject

Indicates whether the lodging location is compliant with the Fire Safety Act.



10406
10407
10408
# File 'lib/stripe/resources/payment_intent.rb', line 10406

def fire_safety_act_compliance
  @fire_safety_act_compliance
end

#nameObject

The name of the lodging location.



10408
10409
10410
# File 'lib/stripe/resources/payment_intent.rb', line 10408

def name
  @name
end

#no_showObject

Indicates if the customer did not keep their booking while failing to cancel the reservation.



10410
10411
10412
# File 'lib/stripe/resources/payment_intent.rb', line 10410

def no_show
  @no_show
end

#number_of_roomsObject

The number of rooms on the booking



10412
10413
10414
# File 'lib/stripe/resources/payment_intent.rb', line 10412

def number_of_rooms
  @number_of_rooms
end

#passengersObject

The details of the passengers in the travel reservation



10414
10415
10416
# File 'lib/stripe/resources/payment_intent.rb', line 10414

def passengers
  @passengers
end

#property_phone_numberObject

The phone number of the lodging location.



10416
10417
10418
# File 'lib/stripe/resources/payment_intent.rb', line 10416

def property_phone_number
  @property_phone_number
end

#room_classObject

The room class for this purchase.



10418
10419
10420
# File 'lib/stripe/resources/payment_intent.rb', line 10418

def room_class
  @room_class
end

#room_nightsObject

The number of room nights



10420
10421
10422
# File 'lib/stripe/resources/payment_intent.rb', line 10420

def room_nights
  @room_nights
end

#total_room_tax_amountObject

The total tax amount associating with the room reservation.



10422
10423
10424
# File 'lib/stripe/resources/payment_intent.rb', line 10422

def total_room_tax_amount
  @total_room_tax_amount
end

#total_tax_amountObject

The total tax amount



10424
10425
10426
# File 'lib/stripe/resources/payment_intent.rb', line 10424

def total_tax_amount
  @total_tax_amount
end