Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::Lodging::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



10358
10359
10360
10361
10362
# File 'lib/stripe/resources/payment_intent.rb', line 10358

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



10352
10353
10354
# File 'lib/stripe/resources/payment_intent.rb', line 10352

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



10354
10355
10356
# File 'lib/stripe/resources/payment_intent.rb', line 10354

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



10356
10357
10358
# File 'lib/stripe/resources/payment_intent.rb', line 10356

def phone
  @phone
end