Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::Subscription::BillingInterval

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(count: nil, interval: nil) ⇒ BillingInterval

Returns a new instance of BillingInterval.



11870
11871
11872
11873
# File 'lib/stripe/resources/payment_intent.rb', line 11870

def initialize(count: nil, interval: nil)
  @count = count
  @interval = interval
end

Instance Attribute Details

#countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



11866
11867
11868
# File 'lib/stripe/resources/payment_intent.rb', line 11866

def count
  @count
end

#intervalObject

Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.



11868
11869
11870
# File 'lib/stripe/resources/payment_intent.rb', line 11868

def interval
  @interval
end