Class: Stripe::PaymentIntent::CaptureParams::TransferData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CaptureParams::TransferData
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount that will be transferred automatically when a charge succeeds.
Instance Method Summary collapse
-
#initialize(amount: nil) ⇒ TransferData
constructor
A new instance of TransferData.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil) ⇒ TransferData
Returns a new instance of TransferData.
6439 6440 6441 |
# File 'lib/stripe/resources/payment_intent.rb', line 6439 def initialize(amount: nil) @amount = amount end |
Instance Attribute Details
#amount ⇒ Object
The amount that will be transferred automatically when a charge succeeds.
6437 6438 6439 |
# File 'lib/stripe/resources/payment_intent.rb', line 6437 def amount @amount end |