Class: Stripe::PaymentIntent::ConfirmParams::AmountDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: LineItem, Shipping, Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discount_amount: nil, line_items: nil, shipping: nil, tax: nil) ⇒ AmountDetails

Returns a new instance of AmountDetails.



10764
10765
10766
10767
10768
10769
# File 'lib/stripe/resources/payment_intent.rb', line 10764

def initialize(discount_amount: nil, line_items: nil, shipping: nil, tax: nil)
  @discount_amount = discount_amount
  @line_items = line_items
  @shipping = shipping
  @tax = tax
end

Instance Attribute Details

#discount_amountObject

The amount an item was discounted for.



10756
10757
10758
# File 'lib/stripe/resources/payment_intent.rb', line 10756

def discount_amount
  @discount_amount
end

#line_itemsObject

A list of line items, each containing information about a product in the PaymentIntent. There is a maximum of 100 line items.



10758
10759
10760
# File 'lib/stripe/resources/payment_intent.rb', line 10758

def line_items
  @line_items
end

#shippingObject

Contains information about the shipping portion of the amount.



10760
10761
10762
# File 'lib/stripe/resources/payment_intent.rb', line 10760

def shipping
  @shipping
end

#taxObject

Contains information about the tax portion of the amount.



10762
10763
10764
# File 'lib/stripe/resources/payment_intent.rb', line 10762

def tax
  @tax
end