Class: Stripe::PaymentIntent::ConfirmParams::AmountDetails::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::AmountDetails::LineItem
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: PaymentMethodOptions, Tax
Instance Attribute Summary collapse
-
#discount_amount ⇒ Object
The amount an item was discounted for.
-
#payment_method_options ⇒ Object
Payment method-specific information for line items.
-
#product_code ⇒ Object
Unique identifier of the product.
-
#product_name ⇒ Object
Name of the product.
-
#quantity ⇒ Object
Number of items of the product.
-
#tax ⇒ Object
Contains information about the tax on the item.
-
#unit_cost ⇒ Object
Cost of the product.
-
#unit_of_measure ⇒ Object
A unit of measure for the line item, such as gallons, feet, meters, etc.
Instance Method Summary collapse
-
#initialize(discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil) ⇒ LineItem
Returns a new instance of LineItem.
10711 10712 10713 10714 10715 10716 10717 10718 10719 10720 10721 10722 10723 10724 10725 10726 10727 10728 10729 |
# File 'lib/stripe/resources/payment_intent.rb', line 10711 def initialize( discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil ) @discount_amount = discount_amount @payment_method_options = @product_code = product_code @product_name = product_name @quantity = quantity @tax = tax @unit_cost = unit_cost @unit_of_measure = unit_of_measure end |
Instance Attribute Details
#discount_amount ⇒ Object
The amount an item was discounted for. Positive integer.
10695 10696 10697 |
# File 'lib/stripe/resources/payment_intent.rb', line 10695 def discount_amount @discount_amount end |
#payment_method_options ⇒ Object
Payment method-specific information for line items.
10697 10698 10699 |
# File 'lib/stripe/resources/payment_intent.rb', line 10697 def @payment_method_options end |
#product_code ⇒ Object
Unique identifier of the product. At most 12 characters long.
10699 10700 10701 |
# File 'lib/stripe/resources/payment_intent.rb', line 10699 def product_code @product_code end |
#product_name ⇒ Object
Name of the product. At most 100 characters long.
10701 10702 10703 |
# File 'lib/stripe/resources/payment_intent.rb', line 10701 def product_name @product_name end |
#quantity ⇒ Object
Number of items of the product. Positive integer.
10703 10704 10705 |
# File 'lib/stripe/resources/payment_intent.rb', line 10703 def quantity @quantity end |
#tax ⇒ Object
Contains information about the tax on the item.
10705 10706 10707 |
# File 'lib/stripe/resources/payment_intent.rb', line 10705 def tax @tax end |
#unit_cost ⇒ Object
Cost of the product. Non-negative integer.
10707 10708 10709 |
# File 'lib/stripe/resources/payment_intent.rb', line 10707 def unit_cost @unit_cost end |
#unit_of_measure ⇒ Object
A unit of measure for the line item, such as gallons, feet, meters, etc.
10709 10710 10711 |
# File 'lib/stripe/resources/payment_intent.rb', line 10709 def unit_of_measure @unit_of_measure end |