Class: Stripe::PaymentIntent::ConfirmParams::AmountDetails::LineItem::PaymentMethodOptions::Paypal
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::AmountDetails::LineItem::PaymentMethodOptions::Paypal
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, sold_by: nil) ⇒ Paypal
constructor
A new instance of Paypal.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, description: nil, sold_by: nil) ⇒ Paypal
Returns a new instance of Paypal.
10663 10664 10665 10666 10667 |
# File 'lib/stripe/resources/payment_intent.rb', line 10663 def initialize(category: nil, description: nil, sold_by: nil) @category = category @description = description @sold_by = sold_by end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
10657 10658 10659 |
# File 'lib/stripe/resources/payment_intent.rb', line 10657 def category @category end |
#description ⇒ Object
Description of the line item.
10659 10660 10661 |
# File 'lib/stripe/resources/payment_intent.rb', line 10659 def description @description end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
10661 10662 10663 |
# File 'lib/stripe/resources/payment_intent.rb', line 10661 def sold_by @sold_by end |