Class: Stripe::PaymentIntent::ConfirmParams::MandateData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::MandateData
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: CustomerAcceptance
Instance Attribute Summary collapse
-
#customer_acceptance ⇒ Object
This hash contains details about the customer acceptance of the Mandate.
Instance Method Summary collapse
-
#initialize(customer_acceptance: nil) ⇒ MandateData
constructor
A new instance of MandateData.
Methods inherited from RequestParams
Constructor Details
#initialize(customer_acceptance: nil) ⇒ MandateData
Returns a new instance of MandateData.
6519 6520 6521 |
# File 'lib/stripe/resources/payment_intent.rb', line 6519 def initialize(customer_acceptance: nil) @customer_acceptance = customer_acceptance end |
Instance Attribute Details
#customer_acceptance ⇒ Object
This hash contains details about the customer acceptance of the Mandate.
6517 6518 6519 |
# File 'lib/stripe/resources/payment_intent.rb', line 6517 def customer_acceptance @customer_acceptance end |