Class: Stripe::PaymentIntent::ConfirmParams::MandateData::CustomerAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Offline, Online

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(accepted_at: nil, offline: nil, online: nil, type: nil) ⇒ CustomerAcceptance

Returns a new instance of CustomerAcceptance.



12202
12203
12204
12205
12206
12207
# File 'lib/stripe/resources/payment_intent.rb', line 12202

def initialize(accepted_at: nil, offline: nil, online: nil, type: nil)
  @accepted_at = accepted_at
  @offline = offline
  @online = online
  @type = type
end

Instance Attribute Details

#accepted_atObject

The time at which the customer accepted the Mandate.



12194
12195
12196
# File 'lib/stripe/resources/payment_intent.rb', line 12194

def accepted_at
  @accepted_at
end

#offlineObject

If this is a Mandate accepted offline, this hash contains details about the offline acceptance.



12196
12197
12198
# File 'lib/stripe/resources/payment_intent.rb', line 12196

def offline
  @offline
end

#onlineObject

If this is a Mandate accepted online, this hash contains details about the online acceptance.



12198
12199
12200
# File 'lib/stripe/resources/payment_intent.rb', line 12198

def online
  @online
end

#typeObject

The type of customer acceptance information included with the Mandate. One of ‘online` or `offline`.



12200
12201
12202
# File 'lib/stripe/resources/payment_intent.rb', line 12200

def type
  @type
end