Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::CarRental

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Affiliate, Delivery, Distance, Driver, PickupAddress, ReturnAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil) ⇒ CarRental

Returns a new instance of CarRental.



12391
12392
12393
12394
12395
12396
12397
12398
12399
12400
12401
12402
12403
12404
12405
12406
12407
12408
12409
12410
12411
12412
12413
12414
12415
12416
12417
12418
12419
12420
12421
12422
12423
12424
12425
12426
12427
12428
12429
12430
12431
12432
12433
12434
12435
12436
12437
12438
12439
12440
12441
# File 'lib/stripe/resources/payment_intent.rb', line 12391

def initialize(
  affiliate: nil,
  booking_number: nil,
  car_class_code: nil,
  car_make: nil,
  car_model: nil,
  company: nil,
  customer_service_phone_number: nil,
  days_rented: nil,
  delivery: nil,
  distance: nil,
  drivers: nil,
  extra_charges: nil,
  no_show: nil,
  pickup_address: nil,
  pickup_at: nil,
  pickup_location_name: nil,
  rate_amount: nil,
  rate_interval: nil,
  renter_name: nil,
  return_address: nil,
  return_at: nil,
  return_location_name: nil,
  tax_exempt: nil,
  vehicle_identification_number: nil
)
  @affiliate = affiliate
  @booking_number = booking_number
  @car_class_code = car_class_code
  @car_make = car_make
  @car_model = car_model
  @company = company
  @customer_service_phone_number = customer_service_phone_number
  @days_rented = days_rented
  @delivery = delivery
  @distance = distance
  @drivers = drivers
  @extra_charges = extra_charges
  @no_show = no_show
  @pickup_address = pickup_address
  @pickup_at = pickup_at
  @pickup_location_name = pickup_location_name
  @rate_amount = rate_amount
  @rate_interval = rate_interval
  @renter_name = renter_name
  @return_address = return_address
  @return_at = return_at
  @return_location_name = return_location_name
  @tax_exempt = tax_exempt
  @vehicle_identification_number = vehicle_identification_number
end

Instance Attribute Details

#affiliateObject

Affiliate details for this purchase.



12343
12344
12345
# File 'lib/stripe/resources/payment_intent.rb', line 12343

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the car rental.



12345
12346
12347
# File 'lib/stripe/resources/payment_intent.rb', line 12345

def booking_number
  @booking_number
end

#car_class_codeObject

Class code of the car.



12347
12348
12349
# File 'lib/stripe/resources/payment_intent.rb', line 12347

def car_class_code
  @car_class_code
end

#car_makeObject

Make of the car.



12349
12350
12351
# File 'lib/stripe/resources/payment_intent.rb', line 12349

def car_make
  @car_make
end

#car_modelObject

Model of the car.



12351
12352
12353
# File 'lib/stripe/resources/payment_intent.rb', line 12351

def car_model
  @car_model
end

#companyObject

The name of the rental car company.



12353
12354
12355
# File 'lib/stripe/resources/payment_intent.rb', line 12353

def company
  @company
end

#customer_service_phone_numberObject

The customer service phone number of the car rental company.



12355
12356
12357
# File 'lib/stripe/resources/payment_intent.rb', line 12355

def customer_service_phone_number
  @customer_service_phone_number
end

#days_rentedObject

Number of days the car is being rented.



12357
12358
12359
# File 'lib/stripe/resources/payment_intent.rb', line 12357

def days_rented
  @days_rented
end

#deliveryObject

Delivery details for this purchase.



12359
12360
12361
# File 'lib/stripe/resources/payment_intent.rb', line 12359

def delivery
  @delivery
end

#distanceObject

The details of the distance traveled during the rental period.



12361
12362
12363
# File 'lib/stripe/resources/payment_intent.rb', line 12361

def distance
  @distance
end

#driversObject

The details of the passengers in the travel reservation



12363
12364
12365
# File 'lib/stripe/resources/payment_intent.rb', line 12363

def drivers
  @drivers
end

#extra_chargesObject

List of additional charges being billed.



12365
12366
12367
# File 'lib/stripe/resources/payment_intent.rb', line 12365

def extra_charges
  @extra_charges
end

#no_showObject

Indicates if the customer did not keep nor cancel their booking.



12367
12368
12369
# File 'lib/stripe/resources/payment_intent.rb', line 12367

def no_show
  @no_show
end

#pickup_addressObject

Car pick-up address.



12369
12370
12371
# File 'lib/stripe/resources/payment_intent.rb', line 12369

def pickup_address
  @pickup_address
end

#pickup_atObject

Car pick-up time. Measured in seconds since the Unix epoch.



12371
12372
12373
# File 'lib/stripe/resources/payment_intent.rb', line 12371

def pickup_at
  @pickup_at
end

#pickup_location_nameObject

Name of the pickup location.



12373
12374
12375
# File 'lib/stripe/resources/payment_intent.rb', line 12373

def pickup_location_name
  @pickup_location_name
end

#rate_amountObject

Rental rate.



12375
12376
12377
# File 'lib/stripe/resources/payment_intent.rb', line 12375

def rate_amount
  @rate_amount
end

#rate_intervalObject

The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`



12377
12378
12379
# File 'lib/stripe/resources/payment_intent.rb', line 12377

def rate_interval
  @rate_interval
end

#renter_nameObject

The name of the person or entity renting the car.



12379
12380
12381
# File 'lib/stripe/resources/payment_intent.rb', line 12379

def renter_name
  @renter_name
end

#return_addressObject

Car return address.



12381
12382
12383
# File 'lib/stripe/resources/payment_intent.rb', line 12381

def return_address
  @return_address
end

#return_atObject

Car return time. Measured in seconds since the Unix epoch.



12383
12384
12385
# File 'lib/stripe/resources/payment_intent.rb', line 12383

def return_at
  @return_at
end

#return_location_nameObject

Name of the return location.



12385
12386
12387
# File 'lib/stripe/resources/payment_intent.rb', line 12385

def return_location_name
  @return_location_name
end

#tax_exemptObject

Indicates whether the goods or services are tax-exempt or tax is not collected.



12387
12388
12389
# File 'lib/stripe/resources/payment_intent.rb', line 12387

def tax_exempt
  @tax_exempt
end

#vehicle_identification_numberObject

The vehicle identification number.



12389
12390
12391
# File 'lib/stripe/resources/payment_intent.rb', line 12389

def vehicle_identification_number
  @vehicle_identification_number
end