Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::CarRental::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



10856
10857
10858
10859
10860
# File 'lib/stripe/resources/payment_intent.rb', line 10856

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



10850
10851
10852
# File 'lib/stripe/resources/payment_intent.rb', line 10850

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



10852
10853
10854
# File 'lib/stripe/resources/payment_intent.rb', line 10852

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



10854
10855
10856
# File 'lib/stripe/resources/payment_intent.rb', line 10854

def phone
  @phone
end