Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
11148 11149 11150 11151 11152 11153 11154 11155 11156 11157 11158 11159 11160 11161 11162 11163 11164 11165 11166 11167 11168 |
# File 'lib/stripe/resources/payment_intent.rb', line 11148 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
11130 11131 11132 |
# File 'lib/stripe/resources/payment_intent.rb', line 11130 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
11132 11133 11134 |
# File 'lib/stripe/resources/payment_intent.rb', line 11132 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
11134 11135 11136 |
# File 'lib/stripe/resources/payment_intent.rb', line 11134 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
11136 11137 11138 |
# File 'lib/stripe/resources/payment_intent.rb', line 11136 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
11138 11139 11140 |
# File 'lib/stripe/resources/payment_intent.rb', line 11138 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
11140 11141 11142 |
# File 'lib/stripe/resources/payment_intent.rb', line 11140 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
11142 11143 11144 |
# File 'lib/stripe/resources/payment_intent.rb', line 11142 def genre @genre end |
#name ⇒ Object
The name of the event.
11144 11145 11146 |
# File 'lib/stripe/resources/payment_intent.rb', line 11144 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
11146 11147 11148 |
# File 'lib/stripe/resources/payment_intent.rb', line 11146 def starts_at @starts_at end |