Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::EventDetails::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



12494
12495
12496
12497
12498
# File 'lib/stripe/resources/payment_intent.rb', line 12494

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



12488
12489
12490
# File 'lib/stripe/resources/payment_intent.rb', line 12488

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



12490
12491
12492
# File 'lib/stripe/resources/payment_intent.rb', line 12490

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



12492
12493
12494
# File 'lib/stripe/resources/payment_intent.rb', line 12492

def phone
  @phone
end