Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::Flight::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



11190
11191
11192
11193
11194
# File 'lib/stripe/resources/payment_intent.rb', line 11190

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



11184
11185
11186
# File 'lib/stripe/resources/payment_intent.rb', line 11184

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



11186
11187
11188
# File 'lib/stripe/resources/payment_intent.rb', line 11186

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



11188
11189
11190
# File 'lib/stripe/resources/payment_intent.rb', line 11188

def phone
  @phone
end