Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::Lodging

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Address, Affiliate, Delivery, Passenger

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging

Returns a new instance of Lodging.



12791
12792
12793
12794
12795
12796
12797
12798
12799
12800
12801
12802
12803
12804
12805
12806
12807
12808
12809
12810
12811
12812
12813
12814
12815
12816
12817
12818
12819
12820
12821
12822
12823
12824
12825
12826
12827
12828
12829
12830
12831
12832
12833
12834
12835
# File 'lib/stripe/resources/payment_intent.rb', line 12791

def initialize(
  address: nil,
  adults: nil,
  affiliate: nil,
  booking_number: nil,
  category: nil,
  checkin_at: nil,
  checkout_at: nil,
  customer_service_phone_number: nil,
  daily_room_rate_amount: nil,
  delivery: nil,
  extra_charges: nil,
  fire_safety_act_compliance: nil,
  name: nil,
  no_show: nil,
  number_of_rooms: nil,
  passengers: nil,
  property_phone_number: nil,
  room_class: nil,
  room_nights: nil,
  total_room_tax_amount: nil,
  total_tax_amount: nil
)
  @address = address
  @adults = adults
  @affiliate = affiliate
  @booking_number = booking_number
  @category = category
  @checkin_at = checkin_at
  @checkout_at = checkout_at
  @customer_service_phone_number = customer_service_phone_number
  @daily_room_rate_amount = daily_room_rate_amount
  @delivery = delivery
  @extra_charges = extra_charges
  @fire_safety_act_compliance = fire_safety_act_compliance
  @name = name
  @no_show = no_show
  @number_of_rooms = number_of_rooms
  @passengers = passengers
  @property_phone_number = property_phone_number
  @room_class = room_class
  @room_nights = room_nights
  @total_room_tax_amount = total_room_tax_amount
  @total_tax_amount = total_tax_amount
end

Instance Attribute Details

#addressObject

The lodging location’s address.



12749
12750
12751
# File 'lib/stripe/resources/payment_intent.rb', line 12749

def address
  @address
end

#adultsObject

The number of adults on the booking



12751
12752
12753
# File 'lib/stripe/resources/payment_intent.rb', line 12751

def adults
  @adults
end

#affiliateObject

Affiliate details for this purchase.



12753
12754
12755
# File 'lib/stripe/resources/payment_intent.rb', line 12753

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the lodging reservation.



12755
12756
12757
# File 'lib/stripe/resources/payment_intent.rb', line 12755

def booking_number
  @booking_number
end

#categoryObject

The lodging category



12757
12758
12759
# File 'lib/stripe/resources/payment_intent.rb', line 12757

def category
  @category
end

#checkin_atObject

Lodging check-in time. Measured in seconds since the Unix epoch.



12759
12760
12761
# File 'lib/stripe/resources/payment_intent.rb', line 12759

def checkin_at
  @checkin_at
end

#checkout_atObject

Lodging check-out time. Measured in seconds since the Unix epoch.



12761
12762
12763
# File 'lib/stripe/resources/payment_intent.rb', line 12761

def checkout_at
  @checkout_at
end

#customer_service_phone_numberObject

The customer service phone number of the lodging company.



12763
12764
12765
# File 'lib/stripe/resources/payment_intent.rb', line 12763

def customer_service_phone_number
  @customer_service_phone_number
end

#daily_room_rate_amountObject

The daily lodging room rate.



12765
12766
12767
# File 'lib/stripe/resources/payment_intent.rb', line 12765

def daily_room_rate_amount
  @daily_room_rate_amount
end

#deliveryObject

Delivery details for this purchase.



12767
12768
12769
# File 'lib/stripe/resources/payment_intent.rb', line 12767

def delivery
  @delivery
end

#extra_chargesObject

List of additional charges being billed.



12769
12770
12771
# File 'lib/stripe/resources/payment_intent.rb', line 12769

def extra_charges
  @extra_charges
end

#fire_safety_act_complianceObject

Indicates whether the lodging location is compliant with the Fire Safety Act.



12771
12772
12773
# File 'lib/stripe/resources/payment_intent.rb', line 12771

def fire_safety_act_compliance
  @fire_safety_act_compliance
end

#nameObject

The name of the lodging location.



12773
12774
12775
# File 'lib/stripe/resources/payment_intent.rb', line 12773

def name
  @name
end

#no_showObject

Indicates if the customer did not keep their booking while failing to cancel the reservation.



12775
12776
12777
# File 'lib/stripe/resources/payment_intent.rb', line 12775

def no_show
  @no_show
end

#number_of_roomsObject

The number of rooms on the booking



12777
12778
12779
# File 'lib/stripe/resources/payment_intent.rb', line 12777

def number_of_rooms
  @number_of_rooms
end

#passengersObject

The details of the passengers in the travel reservation



12779
12780
12781
# File 'lib/stripe/resources/payment_intent.rb', line 12779

def passengers
  @passengers
end

#property_phone_numberObject

The phone number of the lodging location.



12781
12782
12783
# File 'lib/stripe/resources/payment_intent.rb', line 12781

def property_phone_number
  @property_phone_number
end

#room_classObject

The room class for this purchase.



12783
12784
12785
# File 'lib/stripe/resources/payment_intent.rb', line 12783

def room_class
  @room_class
end

#room_nightsObject

The number of room nights



12785
12786
12787
# File 'lib/stripe/resources/payment_intent.rb', line 12785

def room_nights
  @room_nights
end

#total_room_tax_amountObject

The total tax amount associating with the room reservation.



12787
12788
12789
# File 'lib/stripe/resources/payment_intent.rb', line 12787

def total_room_tax_amount
  @total_room_tax_amount
end

#total_tax_amountObject

The total tax amount



12789
12790
12791
# File 'lib/stripe/resources/payment_intent.rb', line 12789

def total_tax_amount
  @total_tax_amount
end