Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::Lodging::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



11342
11343
11344
11345
11346
# File 'lib/stripe/resources/payment_intent.rb', line 11342

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



11336
11337
11338
# File 'lib/stripe/resources/payment_intent.rb', line 11336

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



11338
11339
11340
# File 'lib/stripe/resources/payment_intent.rb', line 11338

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



11340
11341
11342
# File 'lib/stripe/resources/payment_intent.rb', line 11340

def phone
  @phone
end