Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodData::NaverPay
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentMethodData::NaverPay
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#funding ⇒ Object
Whether to use Naver Pay points or a card to fund this transaction.
Instance Method Summary collapse
-
#initialize(funding: nil) ⇒ NaverPay
constructor
A new instance of NaverPay.
Methods inherited from RequestParams
Constructor Details
#initialize(funding: nil) ⇒ NaverPay
Returns a new instance of NaverPay.
11610 11611 11612 |
# File 'lib/stripe/resources/payment_intent.rb', line 11610 def initialize(funding: nil) @funding = funding end |
Instance Attribute Details
#funding ⇒ Object
Whether to use Naver Pay points or a card to fund this transaction. If not provided, this defaults to ‘card`.
11608 11609 11610 |
# File 'lib/stripe/resources/payment_intent.rb', line 11608 def funding @funding end |