Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodData::Sofort
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentMethodData::Sofort
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#country ⇒ Object
Two-letter ISO code representing the country the bank account is located in.
Instance Method Summary collapse
-
#initialize(country: nil) ⇒ Sofort
constructor
A new instance of Sofort.
Methods inherited from RequestParams
Constructor Details
#initialize(country: nil) ⇒ Sofort
Returns a new instance of Sofort.
10342 10343 10344 |
# File 'lib/stripe/resources/payment_intent.rb', line 10342 def initialize(country: nil) @country = country end |
Instance Attribute Details
#country ⇒ Object
Two-letter ISO code representing the country the bank account is located in.
10340 10341 10342 |
# File 'lib/stripe/resources/payment_intent.rb', line 10340 def country @country end |