Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::Billie
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::Billie
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#capture_method ⇒ Object
Controls when the funds are captured from the customer’s account.
Instance Method Summary collapse
-
#initialize(capture_method: nil) ⇒ Billie
constructor
A new instance of Billie.
Methods inherited from RequestParams
Constructor Details
#initialize(capture_method: nil) ⇒ Billie
Returns a new instance of Billie.
13780 13781 13782 |
# File 'lib/stripe/resources/payment_intent.rb', line 13780 def initialize(capture_method: nil) @capture_method = capture_method end |
Instance Attribute Details
#capture_method ⇒ Object
Controls when the funds are captured from the customer’s account.
If provided, this parameter overrides the behavior of the top-level [capture_method](/api/payment_intents/update#update_payment_intent-capture_method) for this payment method type when finalizing the payment with this payment method type.
If ‘capture_method` is already set on the PaymentIntent, providing an empty value for this parameter unsets the stored value for this payment method type.
13778 13779 13780 |
# File 'lib/stripe/resources/payment_intent.rb', line 13778 def capture_method @capture_method end |