Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::Card

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Installments, MandateOptions, StatementDetails, ThreeDSecure

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(capture_method: nil, cvc_token: nil, installments: nil, mandate_options: nil, moto: nil, network: nil, request_decremental_authorization: nil, request_extended_authorization: nil, request_incremental_authorization: nil, request_multicapture: nil, request_overcapture: nil, request_partial_authorization: nil, request_three_d_secure: nil, require_cvc_recollection: nil, setup_future_usage: nil, statement_descriptor_suffix_kana: nil, statement_descriptor_suffix_kanji: nil, statement_details: nil, three_d_secure: nil) ⇒ Card

Returns a new instance of Card.



14071
14072
14073
14074
14075
14076
14077
14078
14079
14080
14081
14082
14083
14084
14085
14086
14087
14088
14089
14090
14091
14092
14093
14094
14095
14096
14097
14098
14099
14100
14101
14102
14103
14104
14105
14106
14107
14108
14109
14110
14111
# File 'lib/stripe/resources/payment_intent.rb', line 14071

def initialize(
  capture_method: nil,
  cvc_token: nil,
  installments: nil,
  mandate_options: nil,
  moto: nil,
  network: nil,
  request_decremental_authorization: nil,
  request_extended_authorization: nil,
  request_incremental_authorization: nil,
  request_multicapture: nil,
  request_overcapture: nil,
  request_partial_authorization: nil,
  request_three_d_secure: nil,
  require_cvc_recollection: nil,
  setup_future_usage: nil,
  statement_descriptor_suffix_kana: nil,
  statement_descriptor_suffix_kanji: nil,
  statement_details: nil,
  three_d_secure: nil
)
  @capture_method = capture_method
  @cvc_token = cvc_token
  @installments = installments
  @mandate_options = mandate_options
  @moto = moto
  @network = network
  @request_decremental_authorization = request_decremental_authorization
  @request_extended_authorization = request_extended_authorization
  @request_incremental_authorization = request_incremental_authorization
  @request_multicapture = request_multicapture
  @request_overcapture = request_overcapture
  @request_partial_authorization = request_partial_authorization
  @request_three_d_secure = request_three_d_secure
  @require_cvc_recollection = require_cvc_recollection
  @setup_future_usage = setup_future_usage
  @statement_descriptor_suffix_kana = statement_descriptor_suffix_kana
  @statement_descriptor_suffix_kanji = statement_descriptor_suffix_kanji
  @statement_details = statement_details
  @three_d_secure = three_d_secure
end

Instance Attribute Details

#capture_methodObject

Controls when the funds are captured from the customer’s account.

If provided, this parameter overrides the behavior of the top-level [capture_method](/api/payment_intents/update#update_payment_intent-capture_method) for this payment method type when finalizing the payment with this payment method type.

If ‘capture_method` is already set on the PaymentIntent, providing an empty value for this parameter unsets the stored value for this payment method type.



14020
14021
14022
# File 'lib/stripe/resources/payment_intent.rb', line 14020

def capture_method
  @capture_method
end

#cvc_tokenObject

A single-use ‘cvc_update` Token that represents a card CVC value. When provided, the CVC value will be verified during the card payment attempt. This parameter can only be provided during confirmation.



14022
14023
14024
# File 'lib/stripe/resources/payment_intent.rb', line 14022

def cvc_token
  @cvc_token
end

#installmentsObject

Installment configuration for payments attempted on this PaymentIntent.

For more information, see the [installments integration guide](stripe.com/docs/payments/installments).



14026
14027
14028
# File 'lib/stripe/resources/payment_intent.rb', line 14026

def installments
  @installments
end

#mandate_optionsObject

Configuration options for setting up an eMandate for cards issued in India.



14028
14029
14030
# File 'lib/stripe/resources/payment_intent.rb', line 14028

def mandate_options
  @mandate_options
end

#motoObject

When specified, this parameter indicates that a transaction will be marked as MOTO (Mail Order Telephone Order) and thus out of scope for SCA. This parameter can only be provided during confirmation.



14032
14033
14034
# File 'lib/stripe/resources/payment_intent.rb', line 14032

def moto
  @moto
end

#networkObject

Selected network to process this PaymentIntent on. Depends on the available networks of the card attached to the PaymentIntent. Can be only set confirm-time.



14034
14035
14036
# File 'lib/stripe/resources/payment_intent.rb', line 14034

def network
  @network
end

#request_decremental_authorizationObject

Request ability to [decrement the authorization](stripe.com/docs/payments/decremental-authorization) for this PaymentIntent.



14036
14037
14038
# File 'lib/stripe/resources/payment_intent.rb', line 14036

def request_decremental_authorization
  @request_decremental_authorization
end

#request_extended_authorizationObject

Request ability to [capture beyond the standard authorization validity window](stripe.com/docs/payments/extended-authorization) for this PaymentIntent.



14038
14039
14040
# File 'lib/stripe/resources/payment_intent.rb', line 14038

def request_extended_authorization
  @request_extended_authorization
end

#request_incremental_authorizationObject

Request ability to [increment the authorization](stripe.com/docs/payments/incremental-authorization) for this PaymentIntent.



14040
14041
14042
# File 'lib/stripe/resources/payment_intent.rb', line 14040

def request_incremental_authorization
  @request_incremental_authorization
end

#request_multicaptureObject

Request ability to make [multiple captures](stripe.com/docs/payments/multicapture) for this PaymentIntent.



14042
14043
14044
# File 'lib/stripe/resources/payment_intent.rb', line 14042

def request_multicapture
  @request_multicapture
end

#request_overcaptureObject

Request ability to [overcapture](stripe.com/docs/payments/overcapture) for this PaymentIntent.



14044
14045
14046
# File 'lib/stripe/resources/payment_intent.rb', line 14044

def request_overcapture
  @request_overcapture
end

#request_partial_authorizationObject

Request partial authorization on this PaymentIntent.



14046
14047
14048
# File 'lib/stripe/resources/payment_intent.rb', line 14046

def request_partial_authorization
  @request_partial_authorization
end

#request_three_d_secureObject

We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and [other requirements](stripe.com/docs/strong-customer-authentication). However, if you wish to request 3D Secure based on logic from your own fraud engine, provide this option. If not provided, this value defaults to ‘automatic`. Read our guide on [manually requesting 3D Secure](stripe.com/docs/payments/3d-secure/authentication-flow#manual-three-ds) for more information on how this configuration interacts with Radar and our SCA Engine.



14048
14049
14050
# File 'lib/stripe/resources/payment_intent.rb', line 14048

def request_three_d_secure
  @request_three_d_secure
end

#require_cvc_recollectionObject

When enabled, using a card that is attached to a customer will require the CVC to be provided again (i.e. using the cvc_token parameter).



14050
14051
14052
# File 'lib/stripe/resources/payment_intent.rb', line 14050

def require_cvc_recollection
  @require_cvc_recollection
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent’s payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.

If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.

When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).

If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.



14060
14061
14062
# File 'lib/stripe/resources/payment_intent.rb', line 14060

def setup_future_usage
  @setup_future_usage
end

#statement_descriptor_suffix_kanaObject

Provides information about a card payment that customers see on their statements. Concatenated with the Kana prefix (shortened Kana descriptor) or Kana statement descriptor that’s set on the account to form the complete statement descriptor. Maximum 22 characters. On card statements, the concatenation of both prefix and suffix (including separators) will appear truncated to 22 characters.



14062
14063
14064
# File 'lib/stripe/resources/payment_intent.rb', line 14062

def statement_descriptor_suffix_kana
  @statement_descriptor_suffix_kana
end

#statement_descriptor_suffix_kanjiObject

Provides information about a card payment that customers see on their statements. Concatenated with the Kanji prefix (shortened Kanji descriptor) or Kanji statement descriptor that’s set on the account to form the complete statement descriptor. Maximum 17 characters. On card statements, the concatenation of both prefix and suffix (including separators) will appear truncated to 17 characters.



14064
14065
14066
# File 'lib/stripe/resources/payment_intent.rb', line 14064

def statement_descriptor_suffix_kanji
  @statement_descriptor_suffix_kanji
end

#statement_detailsObject

Statement details for this payment intent. You can use this to override the merchant details shown on your customers’ statements.



14066
14067
14068
# File 'lib/stripe/resources/payment_intent.rb', line 14066

def statement_details
  @statement_details
end

#three_d_secureObject

If 3D Secure authentication was performed with a third-party provider, the authentication details to use for this payment.



14069
14070
14071
# File 'lib/stripe/resources/payment_intent.rb', line 14069

def three_d_secure
  @three_d_secure
end