Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::Card::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil, interval: nil, interval_count: nil, reference: nil, start_date: nil, supported_types: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



13876
13877
13878
13879
13880
13881
13882
13883
13884
13885
13886
13887
13888
13889
13890
13891
13892
13893
13894
13895
13896
# File 'lib/stripe/resources/payment_intent.rb', line 13876

def initialize(
  amount: nil,
  amount_type: nil,
  description: nil,
  end_date: nil,
  interval: nil,
  interval_count: nil,
  reference: nil,
  start_date: nil,
  supported_types: nil
)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
  @interval = interval
  @interval_count = interval_count
  @reference = reference
  @start_date = start_date
  @supported_types = supported_types
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



13858
13859
13860
# File 'lib/stripe/resources/payment_intent.rb', line 13858

def amount
  @amount
end

#amount_typeObject

One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.



13860
13861
13862
# File 'lib/stripe/resources/payment_intent.rb', line 13860

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



13862
13863
13864
# File 'lib/stripe/resources/payment_intent.rb', line 13862

def description
  @description
end

#end_dateObject

End date of the mandate or subscription. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.



13864
13865
13866
# File 'lib/stripe/resources/payment_intent.rb', line 13864

def end_date
  @end_date
end

#intervalObject

Specifies payment frequency. One of ‘day`, `week`, `month`, `year`, or `sporadic`.



13866
13867
13868
# File 'lib/stripe/resources/payment_intent.rb', line 13866

def interval
  @interval
end

#interval_countObject

The number of intervals between payments. For example, ‘interval=month` and `interval_count=3` indicates one payment every three months. Maximum of one year interval allowed (1 year, 12 months, or 52 weeks). This parameter is optional when `interval=sporadic`.



13868
13869
13870
# File 'lib/stripe/resources/payment_intent.rb', line 13868

def interval_count
  @interval_count
end

#referenceObject

Unique identifier for the mandate or subscription.



13870
13871
13872
# File 'lib/stripe/resources/payment_intent.rb', line 13870

def reference
  @reference
end

#start_dateObject

Start date of the mandate or subscription. Start date should not be lesser than yesterday.



13872
13873
13874
# File 'lib/stripe/resources/payment_intent.rb', line 13872

def start_date
  @start_date
end

#supported_typesObject

Specifies the type of mandates supported. Possible values are ‘india`.



13874
13875
13876
# File 'lib/stripe/resources/payment_intent.rb', line 13874

def supported_types
  @supported_types
end