Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::Card::StatementDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::Card::StatementDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Please pass in an address that is within your Stripe user account country.
-
#phone ⇒ Object
Phone number (e.g., a toll-free number that customers can call).
Instance Method Summary collapse
-
#initialize(address: nil, phone: nil) ⇒ StatementDetails
constructor
A new instance of StatementDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, phone: nil) ⇒ StatementDetails
Returns a new instance of StatementDetails.
11020 11021 11022 11023 |
# File 'lib/stripe/resources/payment_intent.rb', line 11020 def initialize(address: nil, phone: nil) @address = address @phone = phone end |
Instance Attribute Details
#address ⇒ Object
Please pass in an address that is within your Stripe user account country
11016 11017 11018 |
# File 'lib/stripe/resources/payment_intent.rb', line 11016 def address @address end |
#phone ⇒ Object
Phone number (e.g., a toll-free number that customers can call)
11018 11019 11020 |
# File 'lib/stripe/resources/payment_intent.rb', line 11018 def phone @phone end |