Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::Card::ThreeDSecure

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: NetworkOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(ares_trans_status: nil, cryptogram: nil, electronic_commerce_indicator: nil, exemption_indicator: nil, network_options: nil, requestor_challenge_indicator: nil, transaction_id: nil, version: nil) ⇒ ThreeDSecure

Returns a new instance of ThreeDSecure.



12614
12615
12616
12617
12618
12619
12620
12621
12622
12623
12624
12625
12626
12627
12628
12629
12630
12631
12632
# File 'lib/stripe/resources/payment_intent.rb', line 12614

def initialize(
  ares_trans_status: nil,
  cryptogram: nil,
  electronic_commerce_indicator: nil,
  exemption_indicator: nil,
  network_options: nil,
  requestor_challenge_indicator: nil,
  transaction_id: nil,
  version: nil
)
  @ares_trans_status = ares_trans_status
  @cryptogram = cryptogram
  @electronic_commerce_indicator = electronic_commerce_indicator
  @exemption_indicator = exemption_indicator
  @network_options = network_options
  @requestor_challenge_indicator = requestor_challenge_indicator
  @transaction_id = transaction_id
  @version = version
end

Instance Attribute Details

#ares_trans_statusObject

The ‘transStatus` returned from the card Issuer’s ACS in the ARes.



12590
12591
12592
# File 'lib/stripe/resources/payment_intent.rb', line 12590

def ares_trans_status
  @ares_trans_status
end

#cryptogramObject

The cryptogram, also known as the “authentication value” (AAV, CAVV or AEVV). This value is 20 bytes, base64-encoded into a 28-character string. (Most 3D Secure providers will return the base64-encoded version, which is what you should specify here.)



12595
12596
12597
# File 'lib/stripe/resources/payment_intent.rb', line 12595

def cryptogram
  @cryptogram
end

#electronic_commerce_indicatorObject

The Electronic Commerce Indicator (ECI) is returned by your 3D Secure provider and indicates what degree of authentication was performed.



12598
12599
12600
# File 'lib/stripe/resources/payment_intent.rb', line 12598

def electronic_commerce_indicator
  @electronic_commerce_indicator
end

#exemption_indicatorObject

The exemption requested via 3DS and accepted by the issuer at authentication time.



12600
12601
12602
# File 'lib/stripe/resources/payment_intent.rb', line 12600

def exemption_indicator
  @exemption_indicator
end

#network_optionsObject

Network specific 3DS fields. Network specific arguments require an explicit card brand choice. The parameter ‘payment_method_options.card.network“ must be populated accordingly



12604
12605
12606
# File 'lib/stripe/resources/payment_intent.rb', line 12604

def network_options
  @network_options
end

#requestor_challenge_indicatorObject

The challenge indicator (‘threeDSRequestorChallengeInd`) which was requested in the AReq sent to the card Issuer’s ACS. A string containing 2 digits from 01-99.



12607
12608
12609
# File 'lib/stripe/resources/payment_intent.rb', line 12607

def requestor_challenge_indicator
  @requestor_challenge_indicator
end

#transaction_idObject

For 3D Secure 1, the XID. For 3D Secure 2, the Directory Server Transaction ID (dsTransID).



12610
12611
12612
# File 'lib/stripe/resources/payment_intent.rb', line 12610

def transaction_id
  @transaction_id
end

#versionObject

The version of 3D Secure that was performed.



12612
12613
12614
# File 'lib/stripe/resources/payment_intent.rb', line 12612

def version
  @version
end