Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::CustomerBalance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::CustomerBalance
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: BankTransfer
Instance Attribute Summary collapse
-
#bank_transfer ⇒ Object
Configuration for the bank transfer funding type, if the ‘funding_type` is set to `bank_transfer`.
-
#funding_type ⇒ Object
The funding method type to be used when there are not enough funds in the customer balance.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
Instance Method Summary collapse
-
#initialize(bank_transfer: nil, funding_type: nil, setup_future_usage: nil) ⇒ CustomerBalance
constructor
A new instance of CustomerBalance.
Methods inherited from RequestParams
Constructor Details
#initialize(bank_transfer: nil, funding_type: nil, setup_future_usage: nil) ⇒ CustomerBalance
Returns a new instance of CustomerBalance.
11251 11252 11253 11254 11255 |
# File 'lib/stripe/resources/payment_intent.rb', line 11251 def initialize(bank_transfer: nil, funding_type: nil, setup_future_usage: nil) @bank_transfer = bank_transfer @funding_type = funding_type @setup_future_usage = setup_future_usage end |
Instance Attribute Details
#bank_transfer ⇒ Object
Configuration for the bank transfer funding type, if the ‘funding_type` is set to `bank_transfer`.
11237 11238 11239 |
# File 'lib/stripe/resources/payment_intent.rb', line 11237 def bank_transfer @bank_transfer end |
#funding_type ⇒ Object
The funding method type to be used when there are not enough funds in the customer balance. Permitted values include: ‘bank_transfer`.
11239 11240 11241 |
# File 'lib/stripe/resources/payment_intent.rb', line 11239 def funding_type @funding_type end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.
If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.
When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).
If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.
11249 11250 11251 |
# File 'lib/stripe/resources/payment_intent.rb', line 11249 def setup_future_usage @setup_future_usage end |