Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::Klarna::Subscription
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::Klarna::Subscription
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: NextBilling
Instance Attribute Summary collapse
-
#interval ⇒ Object
Unit of time between subscription charges.
-
#interval_count ⇒ Object
The number of intervals (specified in the ‘interval` attribute) between subscription charges.
-
#name ⇒ Object
Name for subscription.
-
#next_billing ⇒ Object
Describes the upcoming charge for this subscription.
-
#reference ⇒ Object
A non-customer-facing reference to correlate subscription charges in the Klarna app.
Instance Method Summary collapse
-
#initialize(interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil) ⇒ Subscription
constructor
A new instance of Subscription.
Methods inherited from RequestParams
Constructor Details
#initialize(interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil) ⇒ Subscription
Returns a new instance of Subscription.
7840 7841 7842 7843 7844 7845 7846 7847 7848 7849 7850 7851 7852 |
# File 'lib/stripe/resources/payment_intent.rb', line 7840 def initialize( interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil ) @interval = interval @interval_count = interval_count @name = name @next_billing = next_billing @reference = reference end |
Instance Attribute Details
#interval ⇒ Object
Unit of time between subscription charges.
7830 7831 7832 |
# File 'lib/stripe/resources/payment_intent.rb', line 7830 def interval @interval end |
#interval_count ⇒ Object
The number of intervals (specified in the ‘interval` attribute) between subscription charges. For example, `interval=month` and `interval_count=3` charges every 3 months.
7832 7833 7834 |
# File 'lib/stripe/resources/payment_intent.rb', line 7832 def interval_count @interval_count end |
#name ⇒ Object
Name for subscription.
7834 7835 7836 |
# File 'lib/stripe/resources/payment_intent.rb', line 7834 def name @name end |
#next_billing ⇒ Object
Describes the upcoming charge for this subscription.
7836 7837 7838 |
# File 'lib/stripe/resources/payment_intent.rb', line 7836 def next_billing @next_billing end |
#reference ⇒ Object
A non-customer-facing reference to correlate subscription charges in the Klarna app. Use a value that persists across subscription charges.
7838 7839 7840 |
# File 'lib/stripe/resources/payment_intent.rb', line 7838 def reference @reference end |