Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::Klarna::Subscription::NextBilling

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, date: nil) ⇒ NextBilling

Returns a new instance of NextBilling.



14413
14414
14415
14416
# File 'lib/stripe/resources/payment_intent.rb', line 14413

def initialize(amount: nil, date: nil)
  @amount = amount
  @date = date
end

Instance Attribute Details

#amountObject

The amount of the next charge for the subscription.



14409
14410
14411
# File 'lib/stripe/resources/payment_intent.rb', line 14409

def amount
  @amount
end

#dateObject

The date of the next charge for the subscription in YYYY-MM-DD format.



14411
14412
14413
# File 'lib/stripe/resources/payment_intent.rb', line 14411

def date
  @date
end