Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::Paypal::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem

Returns a new instance of LineItem.



13386
13387
13388
13389
13390
13391
13392
13393
13394
13395
13396
13397
13398
13399
13400
13401
13402
13403
13404
# File 'lib/stripe/resources/payment_intent.rb', line 13386

def initialize(
  category: nil,
  description: nil,
  name: nil,
  quantity: nil,
  sku: nil,
  sold_by: nil,
  tax: nil,
  unit_amount: nil
)
  @category = category
  @description = description
  @name = name
  @quantity = quantity
  @sku = sku
  @sold_by = sold_by
  @tax = tax
  @unit_amount = unit_amount
end

Instance Attribute Details

#categoryObject

Type of the line item.



13370
13371
13372
# File 'lib/stripe/resources/payment_intent.rb', line 13370

def category
  @category
end

#descriptionObject

Description of the line item.



13372
13373
13374
# File 'lib/stripe/resources/payment_intent.rb', line 13372

def description
  @description
end

#nameObject

Descriptive name of the line item.



13374
13375
13376
# File 'lib/stripe/resources/payment_intent.rb', line 13374

def name
  @name
end

#quantityObject

Quantity of the line item. Must be a positive number.



13376
13377
13378
# File 'lib/stripe/resources/payment_intent.rb', line 13376

def quantity
  @quantity
end

#skuObject

Client facing stock keeping unit, article number or similar.



13378
13379
13380
# File 'lib/stripe/resources/payment_intent.rb', line 13378

def sku
  @sku
end

#sold_byObject

The Stripe account ID of the connected account that sells the item.



13380
13381
13382
# File 'lib/stripe/resources/payment_intent.rb', line 13380

def sold_by
  @sold_by
end

#taxObject

The tax information for the line item.



13382
13383
13384
# File 'lib/stripe/resources/payment_intent.rb', line 13382

def tax
  @tax
end

#unit_amountObject

Price for a single unit of the line item in minor units. Cannot be a negative number.



13384
13385
13386
# File 'lib/stripe/resources/payment_intent.rb', line 13384

def unit_amount
  @unit_amount
end