Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::Payto::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, end_date: nil, payment_schedule: nil, payments_per_period: nil, purpose: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



13467
13468
13469
13470
13471
13472
13473
13474
13475
13476
13477
13478
13479
13480
13481
# File 'lib/stripe/resources/payment_intent.rb', line 13467

def initialize(
  amount: nil,
  amount_type: nil,
  end_date: nil,
  payment_schedule: nil,
  payments_per_period: nil,
  purpose: nil
)
  @amount = amount
  @amount_type = amount_type
  @end_date = end_date
  @payment_schedule = payment_schedule
  @payments_per_period = payments_per_period
  @purpose = purpose
end

Instance Attribute Details

#amountObject

Amount that will be collected. It is required when ‘amount_type` is `fixed`.



13455
13456
13457
# File 'lib/stripe/resources/payment_intent.rb', line 13455

def amount
  @amount
end

#amount_typeObject

The type of amount that will be collected. The amount charged must be exact or up to the value of ‘amount` param for `fixed` or `maximum` type respectively.



13457
13458
13459
# File 'lib/stripe/resources/payment_intent.rb', line 13457

def amount_type
  @amount_type
end

#end_dateObject

Date, in YYYY-MM-DD format, after which payments will not be collected. Defaults to no end date.



13459
13460
13461
# File 'lib/stripe/resources/payment_intent.rb', line 13459

def end_date
  @end_date
end

#payment_scheduleObject

The periodicity at which payments will be collected.



13461
13462
13463
# File 'lib/stripe/resources/payment_intent.rb', line 13461

def payment_schedule
  @payment_schedule
end

#payments_per_periodObject

The number of payments that will be made during a payment period. Defaults to 1 except for when ‘payment_schedule` is `adhoc`. In that case, it defaults to no limit.



13463
13464
13465
# File 'lib/stripe/resources/payment_intent.rb', line 13463

def payments_per_period
  @payments_per_period
end

#purposeObject

The purpose for which payments are made. Defaults to retail.



13465
13466
13467
# File 'lib/stripe/resources/payment_intent.rb', line 13465

def purpose
  @purpose
end