Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::Pix::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, amount_includes_iof: nil, amount_type: nil, currency: nil, end_date: nil, payment_schedule: nil, reference: nil, start_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



14902
14903
14904
14905
14906
14907
14908
14909
14910
14911
14912
14913
14914
14915
14916
14917
14918
14919
14920
# File 'lib/stripe/resources/payment_intent.rb', line 14902

def initialize(
  amount: nil,
  amount_includes_iof: nil,
  amount_type: nil,
  currency: nil,
  end_date: nil,
  payment_schedule: nil,
  reference: nil,
  start_date: nil
)
  @amount = amount
  @amount_includes_iof = amount_includes_iof
  @amount_type = amount_type
  @currency = currency
  @end_date = end_date
  @payment_schedule = payment_schedule
  @reference = reference
  @start_date = start_date
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments. Required when ‘amount_type=fixed`. If not provided for `amount_type=maximum`, defaults to 40000.



14886
14887
14888
# File 'lib/stripe/resources/payment_intent.rb', line 14886

def amount
  @amount
end

#amount_includes_iofObject

Determines if the amount includes the IOF tax. Defaults to ‘never`.



14888
14889
14890
# File 'lib/stripe/resources/payment_intent.rb', line 14888

def amount_includes_iof
  @amount_includes_iof
end

#amount_typeObject

Type of amount. Defaults to ‘maximum`.



14890
14891
14892
# File 'lib/stripe/resources/payment_intent.rb', line 14890

def amount_type
  @amount_type
end

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Only ‘brl` is supported currently.



14892
14893
14894
# File 'lib/stripe/resources/payment_intent.rb', line 14892

def currency
  @currency
end

#end_dateObject

Date when the mandate expires and no further payments will be charged, in ‘YYYY-MM-DD`. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.



14894
14895
14896
# File 'lib/stripe/resources/payment_intent.rb', line 14894

def end_date
  @end_date
end

#payment_scheduleObject

Schedule at which the future payments will be charged. Defaults to ‘weekly`.



14896
14897
14898
# File 'lib/stripe/resources/payment_intent.rb', line 14896

def payment_schedule
  @payment_schedule
end

#referenceObject

Subscription name displayed to buyers in their bank app. Defaults to the displayable business name.



14898
14899
14900
# File 'lib/stripe/resources/payment_intent.rb', line 14898

def reference
  @reference
end

#start_dateObject

Start date of the mandate, in ‘YYYY-MM-DD`. Start date should be at least 3 days in the future. Defaults to 3 days after the current date.



14900
14901
14902
# File 'lib/stripe/resources/payment_intent.rb', line 14900

def start_date
  @start_date
end