Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::UsBankAccount::FinancialConnections

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Filters, ManualEntry

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections

Returns a new instance of FinancialConnections.



15195
15196
15197
15198
15199
15200
15201
15202
15203
15204
15205
15206
15207
# File 'lib/stripe/resources/payment_intent.rb', line 15195

def initialize(
  filters: nil,
  manual_entry: nil,
  permissions: nil,
  prefetch: nil,
  return_url: nil
)
  @filters = filters
  @manual_entry = manual_entry
  @permissions = permissions
  @prefetch = prefetch
  @return_url = return_url
end

Instance Attribute Details

#filtersObject

Provide filters for the linked accounts that the customer can select for the payment method.



15185
15186
15187
# File 'lib/stripe/resources/payment_intent.rb', line 15185

def filters
  @filters
end

#manual_entryObject

Customize manual entry behavior



15187
15188
15189
# File 'lib/stripe/resources/payment_intent.rb', line 15187

def manual_entry
  @manual_entry
end

#permissionsObject

The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.



15189
15190
15191
# File 'lib/stripe/resources/payment_intent.rb', line 15189

def permissions
  @permissions
end

#prefetchObject

List of data features that you would like to retrieve upon account creation.



15191
15192
15193
# File 'lib/stripe/resources/payment_intent.rb', line 15191

def prefetch
  @prefetch
end

#return_urlObject

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



15193
15194
15195
# File 'lib/stripe/resources/payment_intent.rb', line 15193

def return_url
  @return_url
end