Class: Stripe::PaymentIntent::ConfirmParams::RadarOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::RadarOptions
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#session ⇒ Object
A [Radar Session](stripe.com/docs/radar/radar-session) is a snapshot of the browser metadata and device details that help Radar make more accurate predictions on your payments.
Instance Method Summary collapse
-
#initialize(session: nil) ⇒ RadarOptions
constructor
A new instance of RadarOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(session: nil) ⇒ RadarOptions
Returns a new instance of RadarOptions.
13050 13051 13052 |
# File 'lib/stripe/resources/payment_intent.rb', line 13050 def initialize(session: nil) @session = session end |
Instance Attribute Details
#session ⇒ Object
A [Radar Session](stripe.com/docs/radar/radar-session) is a snapshot of the browser metadata and device details that help Radar make more accurate predictions on your payments.
13048 13049 13050 |
# File 'lib/stripe/resources/payment_intent.rb', line 13048 def session @session end |