Class: Stripe::PaymentIntent::ConfirmParams::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



15597
15598
15599
15600
15601
15602
15603
# File 'lib/stripe/resources/payment_intent.rb', line 15597

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



15587
15588
15589
# File 'lib/stripe/resources/payment_intent.rb', line 15587

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



15589
15590
15591
# File 'lib/stripe/resources/payment_intent.rb', line 15589

def carrier
  @carrier
end

#nameObject

Recipient name.



15591
15592
15593
# File 'lib/stripe/resources/payment_intent.rb', line 15591

def name
  @name
end

#phoneObject

Recipient phone (including extension).



15593
15594
15595
# File 'lib/stripe/resources/payment_intent.rb', line 15593

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



15595
15596
15597
# File 'lib/stripe/resources/payment_intent.rb', line 15595

def tracking_number
  @tracking_number
end