Class: Stripe::PaymentIntent::CreateParams::AmountDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: LineItem, Shipping, Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discount_amount: nil, line_items: nil, shipping: nil, tax: nil) ⇒ AmountDetails

Returns a new instance of AmountDetails.



2214
2215
2216
2217
2218
2219
# File 'lib/stripe/resources/payment_intent.rb', line 2214

def initialize(discount_amount: nil, line_items: nil, shipping: nil, tax: nil)
  @discount_amount = discount_amount
  @line_items = line_items
  @shipping = shipping
  @tax = tax
end

Instance Attribute Details

#discount_amountObject

The amount an item was discounted for.



2206
2207
2208
# File 'lib/stripe/resources/payment_intent.rb', line 2206

def discount_amount
  @discount_amount
end

#line_itemsObject

A list of line items, each containing information about a product in the PaymentIntent. There is a maximum of 100 line items.



2208
2209
2210
# File 'lib/stripe/resources/payment_intent.rb', line 2208

def line_items
  @line_items
end

#shippingObject

Contains information about the shipping portion of the amount.



2210
2211
2212
# File 'lib/stripe/resources/payment_intent.rb', line 2210

def shipping
  @shipping
end

#taxObject

Contains information about the tax portion of the amount.



2212
2213
2214
# File 'lib/stripe/resources/payment_intent.rb', line 2212

def tax
  @tax
end