Class: Stripe::PaymentIntent::CreateParams::AmountDetails::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::AmountDetails::LineItem
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: PaymentMethodOptions, Tax
Instance Attribute Summary collapse
-
#discount_amount ⇒ Object
The amount an item was discounted for.
-
#payment_method_options ⇒ Object
Payment method-specific information for line items.
-
#product_code ⇒ Object
Unique identifier of the product.
-
#product_name ⇒ Object
Name of the product.
-
#quantity ⇒ Object
Number of items of the product.
-
#tax ⇒ Object
Contains information about the tax on the item.
-
#unit_cost ⇒ Object
Cost of the product.
-
#unit_of_measure ⇒ Object
A unit of measure for the line item, such as gallons, feet, meters, etc.
Instance Method Summary collapse
-
#initialize(discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil) ⇒ LineItem
Returns a new instance of LineItem.
2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 2178 2179 |
# File 'lib/stripe/resources/payment_intent.rb', line 2161 def initialize( discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil ) @discount_amount = discount_amount @payment_method_options = @product_code = product_code @product_name = product_name @quantity = quantity @tax = tax @unit_cost = unit_cost @unit_of_measure = unit_of_measure end |
Instance Attribute Details
#discount_amount ⇒ Object
The amount an item was discounted for. Positive integer.
2145 2146 2147 |
# File 'lib/stripe/resources/payment_intent.rb', line 2145 def discount_amount @discount_amount end |
#payment_method_options ⇒ Object
Payment method-specific information for line items.
2147 2148 2149 |
# File 'lib/stripe/resources/payment_intent.rb', line 2147 def @payment_method_options end |
#product_code ⇒ Object
Unique identifier of the product. At most 12 characters long.
2149 2150 2151 |
# File 'lib/stripe/resources/payment_intent.rb', line 2149 def product_code @product_code end |
#product_name ⇒ Object
Name of the product. At most 100 characters long.
2151 2152 2153 |
# File 'lib/stripe/resources/payment_intent.rb', line 2151 def product_name @product_name end |
#quantity ⇒ Object
Number of items of the product. Positive integer.
2153 2154 2155 |
# File 'lib/stripe/resources/payment_intent.rb', line 2153 def quantity @quantity end |
#tax ⇒ Object
Contains information about the tax on the item.
2155 2156 2157 |
# File 'lib/stripe/resources/payment_intent.rb', line 2155 def tax @tax end |
#unit_cost ⇒ Object
Cost of the product. Non-negative integer.
2157 2158 2159 |
# File 'lib/stripe/resources/payment_intent.rb', line 2157 def unit_cost @unit_cost end |
#unit_of_measure ⇒ Object
A unit of measure for the line item, such as gallons, feet, meters, etc.
2159 2160 2161 |
# File 'lib/stripe/resources/payment_intent.rb', line 2159 def unit_of_measure @unit_of_measure end |