Class: Stripe::PaymentIntent::CreateParams::AmountDetails::LineItem::PaymentMethodOptions::Paypal
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::AmountDetails::LineItem::PaymentMethodOptions::Paypal
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, sold_by: nil) ⇒ Paypal
constructor
A new instance of Paypal.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, description: nil, sold_by: nil) ⇒ Paypal
Returns a new instance of Paypal.
3494 3495 3496 3497 3498 |
# File 'lib/stripe/resources/payment_intent.rb', line 3494 def initialize(category: nil, description: nil, sold_by: nil) @category = category @description = description @sold_by = sold_by end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
3488 3489 3490 |
# File 'lib/stripe/resources/payment_intent.rb', line 3488 def category @category end |
#description ⇒ Object
Description of the line item.
3490 3491 3492 |
# File 'lib/stripe/resources/payment_intent.rb', line 3490 def description @description end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
3492 3493 3494 |
# File 'lib/stripe/resources/payment_intent.rb', line 3492 def sold_by @sold_by end |