Class: Stripe::PaymentIntent::CreateParams::AmountDetails::Tax
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::AmountDetails::Tax
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#total_tax_amount ⇒ Object
Total portion of the amount that is for tax.
Instance Method Summary collapse
-
#initialize(total_tax_amount: nil) ⇒ Tax
constructor
A new instance of Tax.
Methods inherited from RequestParams
Constructor Details
#initialize(total_tax_amount: nil) ⇒ Tax
Returns a new instance of Tax.
3582 3583 3584 |
# File 'lib/stripe/resources/payment_intent.rb', line 3582 def initialize(total_tax_amount: nil) @total_tax_amount = total_tax_amount end |
Instance Attribute Details
#total_tax_amount ⇒ Object
Total portion of the amount that is for tax.
3580 3581 3582 |
# File 'lib/stripe/resources/payment_intent.rb', line 3580 def total_tax_amount @total_tax_amount end |