Class: Stripe::PaymentIntent::CreateParams::MandateData::CustomerAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Offline, Online

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(accepted_at: nil, offline: nil, online: nil, type: nil) ⇒ CustomerAcceptance

Returns a new instance of CustomerAcceptance.



2285
2286
2287
2288
2289
2290
# File 'lib/stripe/resources/payment_intent.rb', line 2285

def initialize(accepted_at: nil, offline: nil, online: nil, type: nil)
  @accepted_at = accepted_at
  @offline = offline
  @online = online
  @type = type
end

Instance Attribute Details

#accepted_atObject

The time at which the customer accepted the Mandate.



2277
2278
2279
# File 'lib/stripe/resources/payment_intent.rb', line 2277

def accepted_at
  @accepted_at
end

#offlineObject

If this is a Mandate accepted offline, this hash contains details about the offline acceptance.



2279
2280
2281
# File 'lib/stripe/resources/payment_intent.rb', line 2279

def offline
  @offline
end

#onlineObject

If this is a Mandate accepted online, this hash contains details about the online acceptance.



2281
2282
2283
# File 'lib/stripe/resources/payment_intent.rb', line 2281

def online
  @online
end

#typeObject

The type of customer acceptance information included with the Mandate. One of ‘online` or `offline`.



2283
2284
2285
# File 'lib/stripe/resources/payment_intent.rb', line 2283

def type
  @type
end