Class: Stripe::PaymentIntent::CreateParams::PaymentDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::PaymentDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: CarRental, EventDetails, Flight, Lodging, Subscription
Instance Attribute Summary collapse
-
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
-
#customer_reference ⇒ Object
Some customers might be required by their company or organization to provide this information.
-
#event_details ⇒ Object
Event details for this PaymentIntent.
-
#flight ⇒ Object
Flight reservation details for this PaymentIntent.
-
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent.
-
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
-
#subscription ⇒ Object
Subscription details for this PaymentIntent.
Instance Method Summary collapse
-
#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
constructor
A new instance of PaymentDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
Returns a new instance of PaymentDetails.
2986 2987 2988 2989 2990 2991 2992 2993 2994 2995 2996 2997 2998 2999 3000 3001 3002 |
# File 'lib/stripe/resources/payment_intent.rb', line 2986 def initialize( car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil ) @car_rental = car_rental @customer_reference = customer_reference @event_details = event_details @flight = flight @lodging = lodging @order_reference = order_reference @subscription = subscription end |
Instance Attribute Details
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
2972 2973 2974 |
# File 'lib/stripe/resources/payment_intent.rb', line 2972 def car_rental @car_rental end |
#customer_reference ⇒ Object
Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.
2974 2975 2976 |
# File 'lib/stripe/resources/payment_intent.rb', line 2974 def customer_reference @customer_reference end |
#event_details ⇒ Object
Event details for this PaymentIntent
2976 2977 2978 |
# File 'lib/stripe/resources/payment_intent.rb', line 2976 def event_details @event_details end |
#flight ⇒ Object
Flight reservation details for this PaymentIntent
2978 2979 2980 |
# File 'lib/stripe/resources/payment_intent.rb', line 2978 def flight @flight end |
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent
2980 2981 2982 |
# File 'lib/stripe/resources/payment_intent.rb', line 2980 def lodging @lodging end |
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
2982 2983 2984 |
# File 'lib/stripe/resources/payment_intent.rb', line 2982 def order_reference @order_reference end |
#subscription ⇒ Object
Subscription details for this PaymentIntent
2984 2985 2986 |
# File 'lib/stripe/resources/payment_intent.rb', line 2984 def subscription @subscription end |