Class: Stripe::PaymentIntent::CreateParams::PaymentDetails::CarRental::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



2145
2146
2147
2148
2149
# File 'lib/stripe/resources/payment_intent.rb', line 2145

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



2139
2140
2141
# File 'lib/stripe/resources/payment_intent.rb', line 2139

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



2141
2142
2143
# File 'lib/stripe/resources/payment_intent.rb', line 2141

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



2143
2144
2145
# File 'lib/stripe/resources/payment_intent.rb', line 2143

def phone
  @phone
end