Class: Stripe::PaymentIntent::CreateParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
3993 3994 3995 3996 3997 3998 3999 4000 4001 4002 4003 4004 4005 4006 4007 4008 4009 4010 4011 4012 4013 |
# File 'lib/stripe/resources/payment_intent.rb', line 3993 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
3975 3976 3977 |
# File 'lib/stripe/resources/payment_intent.rb', line 3975 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
3977 3978 3979 |
# File 'lib/stripe/resources/payment_intent.rb', line 3977 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
3979 3980 3981 |
# File 'lib/stripe/resources/payment_intent.rb', line 3979 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
3981 3982 3983 |
# File 'lib/stripe/resources/payment_intent.rb', line 3981 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
3983 3984 3985 |
# File 'lib/stripe/resources/payment_intent.rb', line 3983 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
3985 3986 3987 |
# File 'lib/stripe/resources/payment_intent.rb', line 3985 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
3987 3988 3989 |
# File 'lib/stripe/resources/payment_intent.rb', line 3987 def genre @genre end |
#name ⇒ Object
The name of the event.
3989 3990 3991 |
# File 'lib/stripe/resources/payment_intent.rb', line 3989 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
3991 3992 3993 |
# File 'lib/stripe/resources/payment_intent.rb', line 3991 def starts_at @starts_at end |