Class: Stripe::PaymentIntent::CreateParams::PaymentDetails::EventDetails::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::PaymentDetails::EventDetails::Delivery::Recipient
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
2555 2556 2557 2558 2559 |
# File 'lib/stripe/resources/payment_intent.rb', line 2555 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
2549 2550 2551 |
# File 'lib/stripe/resources/payment_intent.rb', line 2549 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
2551 2552 2553 |
# File 'lib/stripe/resources/payment_intent.rb', line 2551 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
2553 2554 2555 |
# File 'lib/stripe/resources/payment_intent.rb', line 2553 def phone @phone end |