Class: Stripe::PaymentIntent::CreateParams::PaymentDetails::Flight::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



4035
4036
4037
4038
4039
# File 'lib/stripe/resources/payment_intent.rb', line 4035

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



4029
4030
4031
# File 'lib/stripe/resources/payment_intent.rb', line 4029

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



4031
4032
4033
# File 'lib/stripe/resources/payment_intent.rb', line 4031

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



4033
4034
4035
# File 'lib/stripe/resources/payment_intent.rb', line 4033

def phone
  @phone
end