Class: Stripe::PaymentIntent::CreateParams::PaymentDetails::Lodging

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Address, Affiliate, Delivery, Passenger

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging

Returns a new instance of Lodging.



2874
2875
2876
2877
2878
2879
2880
2881
2882
2883
2884
2885
2886
2887
2888
2889
2890
2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
2917
2918
# File 'lib/stripe/resources/payment_intent.rb', line 2874

def initialize(
  address: nil,
  adults: nil,
  affiliate: nil,
  booking_number: nil,
  category: nil,
  checkin_at: nil,
  checkout_at: nil,
  customer_service_phone_number: nil,
  daily_room_rate_amount: nil,
  delivery: nil,
  extra_charges: nil,
  fire_safety_act_compliance: nil,
  name: nil,
  no_show: nil,
  number_of_rooms: nil,
  passengers: nil,
  property_phone_number: nil,
  room_class: nil,
  room_nights: nil,
  total_room_tax_amount: nil,
  total_tax_amount: nil
)
  @address = address
  @adults = adults
  @affiliate = affiliate
  @booking_number = booking_number
  @category = category
  @checkin_at = checkin_at
  @checkout_at = checkout_at
  @customer_service_phone_number = customer_service_phone_number
  @daily_room_rate_amount = daily_room_rate_amount
  @delivery = delivery
  @extra_charges = extra_charges
  @fire_safety_act_compliance = fire_safety_act_compliance
  @name = name
  @no_show = no_show
  @number_of_rooms = number_of_rooms
  @passengers = passengers
  @property_phone_number = property_phone_number
  @room_class = room_class
  @room_nights = room_nights
  @total_room_tax_amount = total_room_tax_amount
  @total_tax_amount = total_tax_amount
end

Instance Attribute Details

#addressObject

The lodging location’s address.



2832
2833
2834
# File 'lib/stripe/resources/payment_intent.rb', line 2832

def address
  @address
end

#adultsObject

The number of adults on the booking



2834
2835
2836
# File 'lib/stripe/resources/payment_intent.rb', line 2834

def adults
  @adults
end

#affiliateObject

Affiliate details for this purchase.



2836
2837
2838
# File 'lib/stripe/resources/payment_intent.rb', line 2836

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the lodging reservation.



2838
2839
2840
# File 'lib/stripe/resources/payment_intent.rb', line 2838

def booking_number
  @booking_number
end

#categoryObject

The lodging category



2840
2841
2842
# File 'lib/stripe/resources/payment_intent.rb', line 2840

def category
  @category
end

#checkin_atObject

Lodging check-in time. Measured in seconds since the Unix epoch.



2842
2843
2844
# File 'lib/stripe/resources/payment_intent.rb', line 2842

def checkin_at
  @checkin_at
end

#checkout_atObject

Lodging check-out time. Measured in seconds since the Unix epoch.



2844
2845
2846
# File 'lib/stripe/resources/payment_intent.rb', line 2844

def checkout_at
  @checkout_at
end

#customer_service_phone_numberObject

The customer service phone number of the lodging company.



2846
2847
2848
# File 'lib/stripe/resources/payment_intent.rb', line 2846

def customer_service_phone_number
  @customer_service_phone_number
end

#daily_room_rate_amountObject

The daily lodging room rate.



2848
2849
2850
# File 'lib/stripe/resources/payment_intent.rb', line 2848

def daily_room_rate_amount
  @daily_room_rate_amount
end

#deliveryObject

Delivery details for this purchase.



2850
2851
2852
# File 'lib/stripe/resources/payment_intent.rb', line 2850

def delivery
  @delivery
end

#extra_chargesObject

List of additional charges being billed.



2852
2853
2854
# File 'lib/stripe/resources/payment_intent.rb', line 2852

def extra_charges
  @extra_charges
end

#fire_safety_act_complianceObject

Indicates whether the lodging location is compliant with the Fire Safety Act.



2854
2855
2856
# File 'lib/stripe/resources/payment_intent.rb', line 2854

def fire_safety_act_compliance
  @fire_safety_act_compliance
end

#nameObject

The name of the lodging location.



2856
2857
2858
# File 'lib/stripe/resources/payment_intent.rb', line 2856

def name
  @name
end

#no_showObject

Indicates if the customer did not keep their booking while failing to cancel the reservation.



2858
2859
2860
# File 'lib/stripe/resources/payment_intent.rb', line 2858

def no_show
  @no_show
end

#number_of_roomsObject

The number of rooms on the booking



2860
2861
2862
# File 'lib/stripe/resources/payment_intent.rb', line 2860

def number_of_rooms
  @number_of_rooms
end

#passengersObject

The details of the passengers in the travel reservation



2862
2863
2864
# File 'lib/stripe/resources/payment_intent.rb', line 2862

def passengers
  @passengers
end

#property_phone_numberObject

The phone number of the lodging location.



2864
2865
2866
# File 'lib/stripe/resources/payment_intent.rb', line 2864

def property_phone_number
  @property_phone_number
end

#room_classObject

The room class for this purchase.



2866
2867
2868
# File 'lib/stripe/resources/payment_intent.rb', line 2866

def room_class
  @room_class
end

#room_nightsObject

The number of room nights



2868
2869
2870
# File 'lib/stripe/resources/payment_intent.rb', line 2868

def room_nights
  @room_nights
end

#total_room_tax_amountObject

The total tax amount associating with the room reservation.



2870
2871
2872
# File 'lib/stripe/resources/payment_intent.rb', line 2870

def total_room_tax_amount
  @total_room_tax_amount
end

#total_tax_amountObject

The total tax amount



2872
2873
2874
# File 'lib/stripe/resources/payment_intent.rb', line 2872

def total_tax_amount
  @total_tax_amount
end