Class: Stripe::PaymentIntent::CreateParams::PaymentDetails::Lodging::Affiliate
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::PaymentDetails::Lodging::Affiliate
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#name ⇒ Object
The name of the affiliate that originated the purchase.
Instance Method Summary collapse
-
#initialize(name: nil) ⇒ Affiliate
constructor
A new instance of Affiliate.
Methods inherited from RequestParams
Constructor Details
#initialize(name: nil) ⇒ Affiliate
Returns a new instance of Affiliate.
2792 2793 2794 |
# File 'lib/stripe/resources/payment_intent.rb', line 2792 def initialize(name: nil) @name = name end |
Instance Attribute Details
#name ⇒ Object
The name of the affiliate that originated the purchase.
2790 2791 2792 |
# File 'lib/stripe/resources/payment_intent.rb', line 2790 def name @name end |