Class: Stripe::PaymentIntent::CreateParams::PaymentDetails::Lodging::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::PaymentDetails::Lodging::Delivery::Recipient
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
4187 4188 4189 4190 4191 |
# File 'lib/stripe/resources/payment_intent.rb', line 4187 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
4181 4182 4183 |
# File 'lib/stripe/resources/payment_intent.rb', line 4181 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
4183 4184 4185 |
# File 'lib/stripe/resources/payment_intent.rb', line 4183 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
4185 4186 4187 |
# File 'lib/stripe/resources/payment_intent.rb', line 4185 def phone @phone end |