Class: Stripe::PaymentIntent::CreateParams::PaymentDetails::Subscription::BillingInterval

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(count: nil, interval: nil) ⇒ BillingInterval

Returns a new instance of BillingInterval.



4318
4319
4320
4321
# File 'lib/stripe/resources/payment_intent.rb', line 4318

def initialize(count: nil, interval: nil)
  @count = count
  @interval = interval
end

Instance Attribute Details

#countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



4314
4315
4316
# File 'lib/stripe/resources/payment_intent.rb', line 4314

def count
  @count
end

#intervalObject

Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.



4316
4317
4318
# File 'lib/stripe/resources/payment_intent.rb', line 4316

def interval
  @interval
end