Class: Stripe::PaymentIntent::CreateParams::PaymentMethodData::BacsDebit
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::PaymentMethodData::BacsDebit
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#account_number ⇒ Object
Account number of the bank account that the funds will be debited from.
-
#sort_code ⇒ Object
Sort code of the bank account.
Instance Method Summary collapse
-
#initialize(account_number: nil, sort_code: nil) ⇒ BacsDebit
constructor
A new instance of BacsDebit.
Methods inherited from RequestParams
Constructor Details
#initialize(account_number: nil, sort_code: nil) ⇒ BacsDebit
Returns a new instance of BacsDebit.
2767 2768 2769 2770 |
# File 'lib/stripe/resources/payment_intent.rb', line 2767 def initialize(account_number: nil, sort_code: nil) @account_number = account_number @sort_code = sort_code end |
Instance Attribute Details
#account_number ⇒ Object
Account number of the bank account that the funds will be debited from.
2763 2764 2765 |
# File 'lib/stripe/resources/payment_intent.rb', line 2763 def account_number @account_number end |
#sort_code ⇒ Object
Sort code of the bank account. (e.g., ‘10-20-30`)
2765 2766 2767 |
# File 'lib/stripe/resources/payment_intent.rb', line 2765 def sort_code @sort_code end |