Class: Stripe::PaymentIntent::CreateParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



4600
4601
4602
4603
4604
4605
4606
4607
4608
4609
4610
4611
4612
4613
4614
# File 'lib/stripe/resources/payment_intent.rb', line 4600

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



4588
4589
4590
# File 'lib/stripe/resources/payment_intent.rb', line 4588

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



4590
4591
4592
# File 'lib/stripe/resources/payment_intent.rb', line 4590

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



4592
4593
4594
# File 'lib/stripe/resources/payment_intent.rb', line 4592

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



4594
4595
4596
# File 'lib/stripe/resources/payment_intent.rb', line 4594

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



4596
4597
4598
# File 'lib/stripe/resources/payment_intent.rb', line 4596

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



4598
4599
4600
# File 'lib/stripe/resources/payment_intent.rb', line 4598

def suffix
  @suffix
end