Class: Stripe::PaymentIntent::CreateParams::PaymentMethodData::StripeBalance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::PaymentMethodData::StripeBalance
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#account ⇒ Object
The connected account ID whose Stripe balance to use as the source of payment.
-
#source_type ⇒ Object
The [source_type](docs.stripe.com/api/balance/balance_object#balance_object-available-source_types) of the balance.
Instance Method Summary collapse
-
#initialize(account: nil, source_type: nil) ⇒ StripeBalance
constructor
A new instance of StripeBalance.
Methods inherited from RequestParams
Constructor Details
#initialize(account: nil, source_type: nil) ⇒ StripeBalance
Returns a new instance of StripeBalance.
3311 3312 3313 3314 |
# File 'lib/stripe/resources/payment_intent.rb', line 3311 def initialize(account: nil, source_type: nil) @account = account @source_type = source_type end |
Instance Attribute Details
#account ⇒ Object
The connected account ID whose Stripe balance to use as the source of payment
3307 3308 3309 |
# File 'lib/stripe/resources/payment_intent.rb', line 3307 def account @account end |
#source_type ⇒ Object
The [source_type](docs.stripe.com/api/balance/balance_object#balance_object-available-source_types) of the balance
3309 3310 3311 |
# File 'lib/stripe/resources/payment_intent.rb', line 3309 def source_type @source_type end |