Class: Stripe::PaymentIntent::CreateParams::PaymentMethodData::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::PaymentMethodData::UsBankAccount
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#account_holder_type ⇒ Object
Account holder type: individual or company.
-
#account_number ⇒ Object
Account number of the bank account.
-
#account_type ⇒ Object
Account type: checkings or savings.
-
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
-
#routing_number ⇒ Object
Routing number of the bank account.
Instance Method Summary collapse
-
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
3354 3355 3356 3357 3358 3359 3360 3361 3362 3363 3364 3365 3366 |
# File 'lib/stripe/resources/payment_intent.rb', line 3354 def initialize( account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil ) @account_holder_type = account_holder_type @account_number = account_number @account_type = account_type @financial_connections_account = financial_connections_account @routing_number = routing_number end |
Instance Attribute Details
#account_holder_type ⇒ Object
Account holder type: individual or company.
3344 3345 3346 |
# File 'lib/stripe/resources/payment_intent.rb', line 3344 def account_holder_type @account_holder_type end |
#account_number ⇒ Object
Account number of the bank account.
3346 3347 3348 |
# File 'lib/stripe/resources/payment_intent.rb', line 3346 def account_number @account_number end |
#account_type ⇒ Object
Account type: checkings or savings. Defaults to checking if omitted.
3348 3349 3350 |
# File 'lib/stripe/resources/payment_intent.rb', line 3348 def account_type @account_type end |
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
3350 3351 3352 |
# File 'lib/stripe/resources/payment_intent.rb', line 3350 def financial_connections_account @financial_connections_account end |
#routing_number ⇒ Object
Routing number of the bank account.
3352 3353 3354 |
# File 'lib/stripe/resources/payment_intent.rb', line 3352 def routing_number @routing_number end |