Class: Stripe::PaymentIntent::CreateParams::PaymentMethodOptions::AcssDebit::MandateOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::PaymentMethodOptions::AcssDebit::MandateOptions
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#custom_mandate_url ⇒ Object
A URL for custom mandate text to render during confirmation step.
-
#interval_description ⇒ Object
Description of the mandate interval.
-
#payment_schedule ⇒ Object
Payment schedule for the mandate.
-
#transaction_type ⇒ Object
Transaction type of the mandate.
Instance Method Summary collapse
-
#initialize(custom_mandate_url: nil, interval_description: nil, payment_schedule: nil, transaction_type: nil) ⇒ MandateOptions
constructor
A new instance of MandateOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(custom_mandate_url: nil, interval_description: nil, payment_schedule: nil, transaction_type: nil) ⇒ MandateOptions
Returns a new instance of MandateOptions.
3635 3636 3637 3638 3639 3640 3641 3642 3643 3644 3645 |
# File 'lib/stripe/resources/payment_intent.rb', line 3635 def initialize( custom_mandate_url: nil, interval_description: nil, payment_schedule: nil, transaction_type: nil ) @custom_mandate_url = custom_mandate_url @interval_description = interval_description @payment_schedule = payment_schedule @transaction_type = transaction_type end |
Instance Attribute Details
#custom_mandate_url ⇒ Object
A URL for custom mandate text to render during confirmation step. The URL will be rendered with additional GET parameters ‘payment_intent` and `payment_intent_client_secret` when confirming a Payment Intent, or `setup_intent` and `setup_intent_client_secret` when confirming a Setup Intent.
3627 3628 3629 |
# File 'lib/stripe/resources/payment_intent.rb', line 3627 def custom_mandate_url @custom_mandate_url end |
#interval_description ⇒ Object
Description of the mandate interval. Only required if ‘payment_schedule’ parameter is ‘interval’ or ‘combined’.
3629 3630 3631 |
# File 'lib/stripe/resources/payment_intent.rb', line 3629 def interval_description @interval_description end |
#payment_schedule ⇒ Object
Payment schedule for the mandate.
3631 3632 3633 |
# File 'lib/stripe/resources/payment_intent.rb', line 3631 def payment_schedule @payment_schedule end |
#transaction_type ⇒ Object
Transaction type of the mandate.
3633 3634 3635 |
# File 'lib/stripe/resources/payment_intent.rb', line 3633 def transaction_type @transaction_type end |