Class: Stripe::PaymentIntent::CreateParams::PaymentMethodOptions::Card::Installments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::PaymentMethodOptions::Card::Installments
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Plan
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Setting to true enables installments for this PaymentIntent.
-
#plan ⇒ Object
The selected installment plan to use for this payment attempt.
Instance Method Summary collapse
-
#initialize(enabled: nil, plan: nil) ⇒ Installments
constructor
A new instance of Installments.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, plan: nil) ⇒ Installments
Returns a new instance of Installments.
3758 3759 3760 3761 |
# File 'lib/stripe/resources/payment_intent.rb', line 3758 def initialize(enabled: nil, plan: nil) @enabled = enabled @plan = plan end |
Instance Attribute Details
#enabled ⇒ Object
Setting to true enables installments for this PaymentIntent. This will cause the response to contain a list of available installment plans. Setting to false will prevent any selected plan from applying to a charge.
3753 3754 3755 |
# File 'lib/stripe/resources/payment_intent.rb', line 3753 def enabled @enabled end |
#plan ⇒ Object
The selected installment plan to use for this payment attempt. This parameter can only be provided during confirmation.
3756 3757 3758 |
# File 'lib/stripe/resources/payment_intent.rb', line 3756 def plan @plan end |