Class: Stripe::PaymentIntent::CreateParams::PaymentMethodOptions::Card::ThreeDSecure

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: NetworkOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(ares_trans_status: nil, cryptogram: nil, electronic_commerce_indicator: nil, exemption_indicator: nil, network_options: nil, requestor_challenge_indicator: nil, transaction_id: nil, version: nil) ⇒ ThreeDSecure

Returns a new instance of ThreeDSecure.



4078
4079
4080
4081
4082
4083
4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
4094
4095
4096
# File 'lib/stripe/resources/payment_intent.rb', line 4078

def initialize(
  ares_trans_status: nil,
  cryptogram: nil,
  electronic_commerce_indicator: nil,
  exemption_indicator: nil,
  network_options: nil,
  requestor_challenge_indicator: nil,
  transaction_id: nil,
  version: nil
)
  @ares_trans_status = ares_trans_status
  @cryptogram = cryptogram
  @electronic_commerce_indicator = electronic_commerce_indicator
  @exemption_indicator = exemption_indicator
  @network_options = network_options
  @requestor_challenge_indicator = requestor_challenge_indicator
  @transaction_id = transaction_id
  @version = version
end

Instance Attribute Details

#ares_trans_statusObject

The ‘transStatus` returned from the card Issuer’s ACS in the ARes.



4054
4055
4056
# File 'lib/stripe/resources/payment_intent.rb', line 4054

def ares_trans_status
  @ares_trans_status
end

#cryptogramObject

The cryptogram, also known as the “authentication value” (AAV, CAVV or AEVV). This value is 20 bytes, base64-encoded into a 28-character string. (Most 3D Secure providers will return the base64-encoded version, which is what you should specify here.)



4059
4060
4061
# File 'lib/stripe/resources/payment_intent.rb', line 4059

def cryptogram
  @cryptogram
end

#electronic_commerce_indicatorObject

The Electronic Commerce Indicator (ECI) is returned by your 3D Secure provider and indicates what degree of authentication was performed.



4062
4063
4064
# File 'lib/stripe/resources/payment_intent.rb', line 4062

def electronic_commerce_indicator
  @electronic_commerce_indicator
end

#exemption_indicatorObject

The exemption requested via 3DS and accepted by the issuer at authentication time.



4064
4065
4066
# File 'lib/stripe/resources/payment_intent.rb', line 4064

def exemption_indicator
  @exemption_indicator
end

#network_optionsObject

Network specific 3DS fields. Network specific arguments require an explicit card brand choice. The parameter ‘payment_method_options.card.network“ must be populated accordingly



4068
4069
4070
# File 'lib/stripe/resources/payment_intent.rb', line 4068

def network_options
  @network_options
end

#requestor_challenge_indicatorObject

The challenge indicator (‘threeDSRequestorChallengeInd`) which was requested in the AReq sent to the card Issuer’s ACS. A string containing 2 digits from 01-99.



4071
4072
4073
# File 'lib/stripe/resources/payment_intent.rb', line 4071

def requestor_challenge_indicator
  @requestor_challenge_indicator
end

#transaction_idObject

For 3D Secure 1, the XID. For 3D Secure 2, the Directory Server Transaction ID (dsTransID).



4074
4075
4076
# File 'lib/stripe/resources/payment_intent.rb', line 4074

def transaction_id
  @transaction_id
end

#versionObject

The version of 3D Secure that was performed.



4076
4077
4078
# File 'lib/stripe/resources/payment_intent.rb', line 4076

def version
  @version
end