Class: Stripe::PaymentIntent::CreateParams::PaymentMethodOptions::CardPresent
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::PaymentMethodOptions::CardPresent
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Routing
Instance Attribute Summary collapse
-
#request_extended_authorization ⇒ Object
Request ability to capture this payment beyond the standard [authorization validity window](stripe.com/docs/terminal/features/extended-authorizations#authorization-validity).
-
#request_incremental_authorization_support ⇒ Object
Request ability to [increment](stripe.com/docs/terminal/features/incremental-authorizations) this PaymentIntent if the combination of MCC and card brand is eligible.
-
#routing ⇒ Object
Network routing priority on co-branded EMV cards supporting domestic debit and international card schemes.
Instance Method Summary collapse
-
#initialize(request_extended_authorization: nil, request_incremental_authorization_support: nil, routing: nil) ⇒ CardPresent
constructor
A new instance of CardPresent.
Methods inherited from RequestParams
Constructor Details
#initialize(request_extended_authorization: nil, request_incremental_authorization_support: nil, routing: nil) ⇒ CardPresent
Returns a new instance of CardPresent.
5594 5595 5596 5597 5598 5599 5600 5601 5602 |
# File 'lib/stripe/resources/payment_intent.rb', line 5594 def initialize( request_extended_authorization: nil, request_incremental_authorization_support: nil, routing: nil ) @request_extended_authorization = @request_incremental_authorization_support = @routing = routing end |
Instance Attribute Details
#request_extended_authorization ⇒ Object
Request ability to capture this payment beyond the standard [authorization validity window](stripe.com/docs/terminal/features/extended-authorizations#authorization-validity)
5588 5589 5590 |
# File 'lib/stripe/resources/payment_intent.rb', line 5588 def @request_extended_authorization end |
#request_incremental_authorization_support ⇒ Object
Request ability to [increment](stripe.com/docs/terminal/features/incremental-authorizations) this PaymentIntent if the combination of MCC and card brand is eligible. Check [incremental_authorization_supported](stripe.com/docs/api/charges/object#charge_object-payment_method_details-card_present-incremental_authorization_supported) in the [Confirm](stripe.com/docs/api/payment_intents/confirm) response to verify support.
5590 5591 5592 |
# File 'lib/stripe/resources/payment_intent.rb', line 5590 def @request_incremental_authorization_support end |
#routing ⇒ Object
Network routing priority on co-branded EMV cards supporting domestic debit and international card schemes.
5592 5593 5594 |
# File 'lib/stripe/resources/payment_intent.rb', line 5592 def routing @routing end |