Class: Stripe::PaymentIntent::CreateParams::PaymentMethodOptions::Klarna
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::PaymentMethodOptions::Klarna
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: OnDemand, Subscription
Instance Attribute Summary collapse
-
#capture_method ⇒ Object
Controls when the funds are captured from the customer’s account.
-
#on_demand ⇒ Object
On-demand details if setting up or charging an on-demand payment.
-
#preferred_locale ⇒ Object
Preferred language of the Klarna authorization page that the customer is redirected to.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
-
#subscriptions ⇒ Object
Subscription details if setting up or charging a subscription.
Instance Method Summary collapse
-
#initialize(capture_method: nil, on_demand: nil, preferred_locale: nil, setup_future_usage: nil, subscriptions: nil) ⇒ Klarna
constructor
A new instance of Klarna.
Methods inherited from RequestParams
Constructor Details
#initialize(capture_method: nil, on_demand: nil, preferred_locale: nil, setup_future_usage: nil, subscriptions: nil) ⇒ Klarna
Returns a new instance of Klarna.
3023 3024 3025 3026 3027 3028 3029 3030 3031 3032 3033 3034 3035 |
# File 'lib/stripe/resources/payment_intent.rb', line 3023 def initialize( capture_method: nil, on_demand: nil, preferred_locale: nil, setup_future_usage: nil, subscriptions: nil ) @capture_method = capture_method @on_demand = on_demand @preferred_locale = preferred_locale @setup_future_usage = setup_future_usage @subscriptions = subscriptions end |
Instance Attribute Details
#capture_method ⇒ Object
Controls when the funds are captured from the customer’s account.
If provided, this parameter overrides the behavior of the top-level [capture_method](/api/payment_intents/update#update_payment_intent-capture_method) for this payment method type when finalizing the payment with this payment method type.
If ‘capture_method` is already set on the PaymentIntent, providing an empty value for this parameter unsets the stored value for this payment method type.
3005 3006 3007 |
# File 'lib/stripe/resources/payment_intent.rb', line 3005 def capture_method @capture_method end |
#on_demand ⇒ Object
On-demand details if setting up or charging an on-demand payment.
3007 3008 3009 |
# File 'lib/stripe/resources/payment_intent.rb', line 3007 def on_demand @on_demand end |
#preferred_locale ⇒ Object
Preferred language of the Klarna authorization page that the customer is redirected to
3009 3010 3011 |
# File 'lib/stripe/resources/payment_intent.rb', line 3009 def preferred_locale @preferred_locale end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.
If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.
When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).
If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.
3019 3020 3021 |
# File 'lib/stripe/resources/payment_intent.rb', line 3019 def setup_future_usage @setup_future_usage end |
#subscriptions ⇒ Object
Subscription details if setting up or charging a subscription.
3021 3022 3023 |
# File 'lib/stripe/resources/payment_intent.rb', line 3021 def subscriptions @subscriptions end |