Class: Stripe::PaymentIntent::CreateParams::PaymentMethodOptions::Klarna::OnDemand

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(average_amount: nil, maximum_amount: nil, minimum_amount: nil, purchase_interval: nil, purchase_interval_count: nil) ⇒ OnDemand

Returns a new instance of OnDemand.



5855
5856
5857
5858
5859
5860
5861
5862
5863
5864
5865
5866
5867
# File 'lib/stripe/resources/payment_intent.rb', line 5855

def initialize(
  average_amount: nil,
  maximum_amount: nil,
  minimum_amount: nil,
  purchase_interval: nil,
  purchase_interval_count: nil
)
  @average_amount = average_amount
  @maximum_amount = maximum_amount
  @minimum_amount = minimum_amount
  @purchase_interval = purchase_interval
  @purchase_interval_count = purchase_interval_count
end

Instance Attribute Details

#average_amountObject

Your average amount value. You can use a value across your customer base, or segment based on customer type, country, etc.



5845
5846
5847
# File 'lib/stripe/resources/payment_intent.rb', line 5845

def average_amount
  @average_amount
end

#maximum_amountObject

The maximum value you may charge a customer per purchase. You can use a value across your customer base, or segment based on customer type, country, etc.



5847
5848
5849
# File 'lib/stripe/resources/payment_intent.rb', line 5847

def maximum_amount
  @maximum_amount
end

#minimum_amountObject

The lowest or minimum value you may charge a customer per purchase. You can use a value across your customer base, or segment based on customer type, country, etc.



5849
5850
5851
# File 'lib/stripe/resources/payment_intent.rb', line 5849

def minimum_amount
  @minimum_amount
end

#purchase_intervalObject

Interval at which the customer is making purchases



5851
5852
5853
# File 'lib/stripe/resources/payment_intent.rb', line 5851

def purchase_interval
  @purchase_interval
end

#purchase_interval_countObject

The number of ‘purchase_interval` between charges



5853
5854
5855
# File 'lib/stripe/resources/payment_intent.rb', line 5853

def purchase_interval_count
  @purchase_interval_count
end