Class: Stripe::PaymentIntent::CreateParams::PaymentMethodOptions::Klarna::Subscription::NextBilling

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, date: nil) ⇒ NextBilling

Returns a new instance of NextBilling.



4496
4497
4498
4499
# File 'lib/stripe/resources/payment_intent.rb', line 4496

def initialize(amount: nil, date: nil)
  @amount = amount
  @date = date
end

Instance Attribute Details

#amountObject

The amount of the next charge for the subscription.



4492
4493
4494
# File 'lib/stripe/resources/payment_intent.rb', line 4492

def amount
  @amount
end

#dateObject

The date of the next charge for the subscription in YYYY-MM-DD format.



4494
4495
4496
# File 'lib/stripe/resources/payment_intent.rb', line 4494

def date
  @date
end