Class: Stripe::PaymentIntent::CreateParams::PaymentMethodOptions::Payco

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(capture_method: nil) ⇒ Payco

Returns a new instance of Payco.



3189
3190
3191
# File 'lib/stripe/resources/payment_intent.rb', line 3189

def initialize(capture_method: nil)
  @capture_method = capture_method
end

Instance Attribute Details

#capture_methodObject

Controls when the funds are captured from the customer’s account.

If provided, this parameter overrides the behavior of the top-level [capture_method](/api/payment_intents/update#update_payment_intent-capture_method) for this payment method type when finalizing the payment with this payment method type.

If ‘capture_method` is already set on the PaymentIntent, providing an empty value for this parameter unsets the stored value for this payment method type.



3187
3188
3189
# File 'lib/stripe/resources/payment_intent.rb', line 3187

def capture_method
  @capture_method
end