Class: Stripe::PaymentIntent::CreateParams::PaymentMethodOptions::Paypal::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem

Returns a new instance of LineItem.



6231
6232
6233
6234
6235
6236
6237
6238
6239
6240
6241
6242
6243
6244
6245
6246
6247
6248
6249
# File 'lib/stripe/resources/payment_intent.rb', line 6231

def initialize(
  category: nil,
  description: nil,
  name: nil,
  quantity: nil,
  sku: nil,
  sold_by: nil,
  tax: nil,
  unit_amount: nil
)
  @category = category
  @description = description
  @name = name
  @quantity = quantity
  @sku = sku
  @sold_by = sold_by
  @tax = tax
  @unit_amount = unit_amount
end

Instance Attribute Details

#categoryObject

Type of the line item.



6215
6216
6217
# File 'lib/stripe/resources/payment_intent.rb', line 6215

def category
  @category
end

#descriptionObject

Description of the line item.



6217
6218
6219
# File 'lib/stripe/resources/payment_intent.rb', line 6217

def description
  @description
end

#nameObject

Descriptive name of the line item.



6219
6220
6221
# File 'lib/stripe/resources/payment_intent.rb', line 6219

def name
  @name
end

#quantityObject

Quantity of the line item. Must be a positive number.



6221
6222
6223
# File 'lib/stripe/resources/payment_intent.rb', line 6221

def quantity
  @quantity
end

#skuObject

Client facing stock keeping unit, article number or similar.



6223
6224
6225
# File 'lib/stripe/resources/payment_intent.rb', line 6223

def sku
  @sku
end

#sold_byObject

The Stripe account ID of the connected account that sells the item.



6225
6226
6227
# File 'lib/stripe/resources/payment_intent.rb', line 6225

def sold_by
  @sold_by
end

#taxObject

The tax information for the line item.



6227
6228
6229
# File 'lib/stripe/resources/payment_intent.rb', line 6227

def tax
  @tax
end

#unit_amountObject

Price for a single unit of the line item in minor units. Cannot be a negative number.



6229
6230
6231
# File 'lib/stripe/resources/payment_intent.rb', line 6229

def unit_amount
  @unit_amount
end