Class: Stripe::PaymentIntent::CreateParams::PaymentMethodOptions::Paypal::LineItem::Tax
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::PaymentMethodOptions::Paypal::LineItem::Tax
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The tax for a single unit of the line item in minor units.
-
#behavior ⇒ Object
The tax behavior for the line item.
Instance Method Summary collapse
-
#initialize(amount: nil, behavior: nil) ⇒ Tax
constructor
A new instance of Tax.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, behavior: nil) ⇒ Tax
Returns a new instance of Tax.
4828 4829 4830 4831 |
# File 'lib/stripe/resources/payment_intent.rb', line 4828 def initialize(amount: nil, behavior: nil) @amount = amount @behavior = behavior end |
Instance Attribute Details
#amount ⇒ Object
The tax for a single unit of the line item in minor units. Cannot be a negative number.
4824 4825 4826 |
# File 'lib/stripe/resources/payment_intent.rb', line 4824 def amount @amount end |
#behavior ⇒ Object
The tax behavior for the line item.
4826 4827 4828 |
# File 'lib/stripe/resources/payment_intent.rb', line 4826 def behavior @behavior end |