Class: Stripe::PaymentIntent::CreateParams::PaymentMethodOptions::UsBankAccount::FinancialConnections

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Filters, ManualEntry

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections

Returns a new instance of FinancialConnections.



6659
6660
6661
6662
6663
6664
6665
6666
6667
6668
6669
6670
6671
# File 'lib/stripe/resources/payment_intent.rb', line 6659

def initialize(
  filters: nil,
  manual_entry: nil,
  permissions: nil,
  prefetch: nil,
  return_url: nil
)
  @filters = filters
  @manual_entry = manual_entry
  @permissions = permissions
  @prefetch = prefetch
  @return_url = return_url
end

Instance Attribute Details

#filtersObject

Provide filters for the linked accounts that the customer can select for the payment method.



6649
6650
6651
# File 'lib/stripe/resources/payment_intent.rb', line 6649

def filters
  @filters
end

#manual_entryObject

Customize manual entry behavior



6651
6652
6653
# File 'lib/stripe/resources/payment_intent.rb', line 6651

def manual_entry
  @manual_entry
end

#permissionsObject

The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.



6653
6654
6655
# File 'lib/stripe/resources/payment_intent.rb', line 6653

def permissions
  @permissions
end

#prefetchObject

List of data features that you would like to retrieve upon account creation.



6655
6656
6657
# File 'lib/stripe/resources/payment_intent.rb', line 6655

def prefetch
  @prefetch
end

#return_urlObject

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



6657
6658
6659
# File 'lib/stripe/resources/payment_intent.rb', line 6657

def return_url
  @return_url
end