Class: Stripe::PaymentIntent::CreateParams::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



5680
5681
5682
5683
5684
5685
5686
# File 'lib/stripe/resources/payment_intent.rb', line 5680

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



5670
5671
5672
# File 'lib/stripe/resources/payment_intent.rb', line 5670

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



5672
5673
5674
# File 'lib/stripe/resources/payment_intent.rb', line 5672

def carrier
  @carrier
end

#nameObject

Recipient name.



5674
5675
5676
# File 'lib/stripe/resources/payment_intent.rb', line 5674

def name
  @name
end

#phoneObject

Recipient phone (including extension).



5676
5677
5678
# File 'lib/stripe/resources/payment_intent.rb', line 5676

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



5678
5679
5680
# File 'lib/stripe/resources/payment_intent.rb', line 5678

def tracking_number
  @tracking_number
end