Class: Stripe::PaymentIntent::CreateParams::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



5704
5705
5706
5707
# File 'lib/stripe/resources/payment_intent.rb', line 5704

def initialize(amount: nil, destination: nil)
  @amount = amount
  @destination = destination
end

Instance Attribute Details

#amountObject

The amount that will be transferred automatically when a charge succeeds. The amount is capped at the total transaction amount and if no amount is set, the full amount is transferred.

If you intend to collect a fee and you need a more robust reporting experience, using [application_fee_amount](stripe.com/docs/api/payment_intents/create#create_payment_intent-application_fee_amount) might be a better fit for your integration.



5697
5698
5699
# File 'lib/stripe/resources/payment_intent.rb', line 5697

def amount
  @amount
end

#destinationObject

If specified, successful charges will be attributed to the destination account for tax reporting, and the funds from charges will be transferred to the destination account. The ID of the resulting transfer will be returned on the successful charge’s ‘transfer` field.



5702
5703
5704
# File 'lib/stripe/resources/payment_intent.rb', line 5702

def destination
  @destination
end