Class: Stripe::PaymentIntent::DecrementAuthorizationParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Hooks, TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, application_fee_amount: nil, description: nil, expand: nil, hooks: nil, metadata: nil, transfer_data: nil) ⇒ DecrementAuthorizationParams

Returns a new instance of DecrementAuthorizationParams.



14383
14384
14385
14386
14387
14388
14389
14390
14391
14392
14393
14394
14395
14396
14397
14398
14399
# File 'lib/stripe/resources/payment_intent.rb', line 14383

def initialize(
  amount: nil,
  application_fee_amount: nil,
  description: nil,
  expand: nil,
  hooks: nil,
  metadata: nil,
  transfer_data: nil
)
  @amount = amount
  @application_fee_amount = application_fee_amount
  @description = description
  @expand = expand
  @hooks = hooks
  @metadata = 
  @transfer_data = transfer_data
end

Instance Attribute Details

#amountObject

The updated total amount that you intend to collect from the cardholder. This amount must be smaller than the currently authorized amount and greater than the already captured amount.



14368
14369
14370
# File 'lib/stripe/resources/payment_intent.rb', line 14368

def amount
  @amount
end

#application_fee_amountObject

The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



14370
14371
14372
# File 'lib/stripe/resources/payment_intent.rb', line 14370

def application_fee_amount
  @application_fee_amount
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



14372
14373
14374
# File 'lib/stripe/resources/payment_intent.rb', line 14372

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



14374
14375
14376
# File 'lib/stripe/resources/payment_intent.rb', line 14374

def expand
  @expand
end

#hooksObject

Automations to be run during the PaymentIntent lifecycle



14376
14377
14378
# File 'lib/stripe/resources/payment_intent.rb', line 14376

def hooks
  @hooks
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



14378
14379
14380
# File 'lib/stripe/resources/payment_intent.rb', line 14378

def 
  @metadata
end

#transfer_dataObject

The parameters used to automatically create a transfer after the payment is captured. Learn more about the [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



14381
14382
14383
# File 'lib/stripe/resources/payment_intent.rb', line 14381

def transfer_data
  @transfer_data
end