Class: Stripe::PaymentIntent::IncrementAuthorizationParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: AmountDetails, Hooks, PaymentDetails, PaymentMethodOptions, TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, amount_details: nil, application_fee_amount: nil, description: nil, expand: nil, hooks: nil, metadata: nil, payment_details: nil, payment_method_options: nil, statement_descriptor: nil, transfer_data: nil) ⇒ IncrementAuthorizationParams

Returns a new instance of IncrementAuthorizationParams.



16023
16024
16025
16026
16027
16028
16029
16030
16031
16032
16033
16034
16035
16036
16037
16038
16039
16040
16041
16042
16043
16044
16045
16046
16047
# File 'lib/stripe/resources/payment_intent.rb', line 16023

def initialize(
  amount: nil,
  amount_details: nil,
  application_fee_amount: nil,
  description: nil,
  expand: nil,
  hooks: nil,
  metadata: nil,
  payment_details: nil,
  payment_method_options: nil,
  statement_descriptor: nil,
  transfer_data: nil
)
  @amount = amount
  @amount_details = amount_details
  @application_fee_amount = application_fee_amount
  @description = description
  @expand = expand
  @hooks = hooks
  @metadata = 
  @payment_details = payment_details
  @payment_method_options = payment_method_options
  @statement_descriptor = statement_descriptor
  @transfer_data = transfer_data
end

Instance Attribute Details

#amountObject

The updated total amount that you intend to collect from the cardholder. This amount must be greater than the currently authorized amount.



16000
16001
16002
# File 'lib/stripe/resources/payment_intent.rb', line 16000

def amount
  @amount
end

#amount_detailsObject

Provides industry-specific information about the amount.



16002
16003
16004
# File 'lib/stripe/resources/payment_intent.rb', line 16002

def amount_details
  @amount_details
end

#application_fee_amountObject

The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



16004
16005
16006
# File 'lib/stripe/resources/payment_intent.rb', line 16004

def application_fee_amount
  @application_fee_amount
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



16006
16007
16008
# File 'lib/stripe/resources/payment_intent.rb', line 16006

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



16008
16009
16010
# File 'lib/stripe/resources/payment_intent.rb', line 16008

def expand
  @expand
end

#hooksObject

Automations to be run during the PaymentIntent lifecycle



16010
16011
16012
# File 'lib/stripe/resources/payment_intent.rb', line 16010

def hooks
  @hooks
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



16012
16013
16014
# File 'lib/stripe/resources/payment_intent.rb', line 16012

def 
  @metadata
end

#payment_detailsObject

Provides industry-specific information about the charge.



16014
16015
16016
# File 'lib/stripe/resources/payment_intent.rb', line 16014

def payment_details
  @payment_details
end

#payment_method_optionsObject

Payment method-specific configuration for this PaymentIntent.



16016
16017
16018
# File 'lib/stripe/resources/payment_intent.rb', line 16016

def payment_method_options
  @payment_method_options
end

#statement_descriptorObject

Text that appears on the customer’s statement as the statement descriptor for a non-card or card charge. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).



16018
16019
16020
# File 'lib/stripe/resources/payment_intent.rb', line 16018

def statement_descriptor
  @statement_descriptor
end

#transfer_dataObject

The parameters used to automatically create a transfer after the payment is captured. Learn more about the [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



16021
16022
16023
# File 'lib/stripe/resources/payment_intent.rb', line 16021

def transfer_data
  @transfer_data
end