Class: Stripe::PaymentIntent::IncrementAuthorizationParams::AmountDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::IncrementAuthorizationParams::AmountDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: LineItem, Shipping, Tax
Instance Attribute Summary collapse
-
#discount_amount ⇒ Object
The amount an item was discounted for.
-
#line_items ⇒ Object
A list of line items, each containing information about a product in the PaymentIntent.
-
#shipping ⇒ Object
Contains information about the shipping portion of the amount.
-
#tax ⇒ Object
Contains information about the tax portion of the amount.
Instance Method Summary collapse
-
#initialize(discount_amount: nil, line_items: nil, shipping: nil, tax: nil) ⇒ AmountDetails
constructor
A new instance of AmountDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(discount_amount: nil, line_items: nil, shipping: nil, tax: nil) ⇒ AmountDetails
Returns a new instance of AmountDetails.
14548 14549 14550 14551 14552 14553 |
# File 'lib/stripe/resources/payment_intent.rb', line 14548 def initialize(discount_amount: nil, line_items: nil, shipping: nil, tax: nil) @discount_amount = discount_amount @line_items = line_items @shipping = shipping @tax = tax end |
Instance Attribute Details
#discount_amount ⇒ Object
The amount an item was discounted for.
14540 14541 14542 |
# File 'lib/stripe/resources/payment_intent.rb', line 14540 def discount_amount @discount_amount end |
#line_items ⇒ Object
A list of line items, each containing information about a product in the PaymentIntent. There is a maximum of 100 line items.
14542 14543 14544 |
# File 'lib/stripe/resources/payment_intent.rb', line 14542 def line_items @line_items end |
#shipping ⇒ Object
Contains information about the shipping portion of the amount.
14544 14545 14546 |
# File 'lib/stripe/resources/payment_intent.rb', line 14544 def shipping @shipping end |
#tax ⇒ Object
Contains information about the tax portion of the amount.
14546 14547 14548 |
# File 'lib/stripe/resources/payment_intent.rb', line 14546 def tax @tax end |