Class: Stripe::PaymentIntent::IncrementAuthorizationParams::AmountDetails::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::IncrementAuthorizationParams::AmountDetails::LineItem
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: PaymentMethodOptions, Tax
Instance Attribute Summary collapse
-
#discount_amount ⇒ Object
The amount an item was discounted for.
-
#payment_method_options ⇒ Object
Payment method-specific information for line items.
-
#product_code ⇒ Object
Unique identifier of the product.
-
#product_name ⇒ Object
Name of the product.
-
#quantity ⇒ Object
Number of items of the product.
-
#tax ⇒ Object
Contains information about the tax on the item.
-
#unit_cost ⇒ Object
Cost of the product.
-
#unit_of_measure ⇒ Object
A unit of measure for the line item, such as gallons, feet, meters, etc.
Instance Method Summary collapse
-
#initialize(discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil) ⇒ LineItem
Returns a new instance of LineItem.
15876 15877 15878 15879 15880 15881 15882 15883 15884 15885 15886 15887 15888 15889 15890 15891 15892 15893 15894 |
# File 'lib/stripe/resources/payment_intent.rb', line 15876 def initialize( discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil ) @discount_amount = discount_amount @payment_method_options = @product_code = product_code @product_name = product_name @quantity = quantity @tax = tax @unit_cost = unit_cost @unit_of_measure = unit_of_measure end |
Instance Attribute Details
#discount_amount ⇒ Object
The amount an item was discounted for. Positive integer.
15860 15861 15862 |
# File 'lib/stripe/resources/payment_intent.rb', line 15860 def discount_amount @discount_amount end |
#payment_method_options ⇒ Object
Payment method-specific information for line items.
15862 15863 15864 |
# File 'lib/stripe/resources/payment_intent.rb', line 15862 def @payment_method_options end |
#product_code ⇒ Object
Unique identifier of the product. At most 12 characters long.
15864 15865 15866 |
# File 'lib/stripe/resources/payment_intent.rb', line 15864 def product_code @product_code end |
#product_name ⇒ Object
Name of the product. At most 100 characters long.
15866 15867 15868 |
# File 'lib/stripe/resources/payment_intent.rb', line 15866 def product_name @product_name end |
#quantity ⇒ Object
Number of items of the product. Positive integer.
15868 15869 15870 |
# File 'lib/stripe/resources/payment_intent.rb', line 15868 def quantity @quantity end |
#tax ⇒ Object
Contains information about the tax on the item.
15870 15871 15872 |
# File 'lib/stripe/resources/payment_intent.rb', line 15870 def tax @tax end |
#unit_cost ⇒ Object
Cost of the product. Non-negative integer.
15872 15873 15874 |
# File 'lib/stripe/resources/payment_intent.rb', line 15872 def unit_cost @unit_cost end |
#unit_of_measure ⇒ Object
A unit of measure for the line item, such as gallons, feet, meters, etc.
15874 15875 15876 |
# File 'lib/stripe/resources/payment_intent.rb', line 15874 def unit_of_measure @unit_of_measure end |