Class: Stripe::PaymentIntent::IncrementAuthorizationParams::AmountDetails::LineItem::PaymentMethodOptions::Paypal
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::IncrementAuthorizationParams::AmountDetails::LineItem::PaymentMethodOptions::Paypal
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, sold_by: nil) ⇒ Paypal
constructor
A new instance of Paypal.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, description: nil, sold_by: nil) ⇒ Paypal
Returns a new instance of Paypal.
14447 14448 14449 14450 14451 |
# File 'lib/stripe/resources/payment_intent.rb', line 14447 def initialize(category: nil, description: nil, sold_by: nil) @category = category @description = description @sold_by = sold_by end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
14441 14442 14443 |
# File 'lib/stripe/resources/payment_intent.rb', line 14441 def category @category end |
#description ⇒ Object
Description of the line item.
14443 14444 14445 |
# File 'lib/stripe/resources/payment_intent.rb', line 14443 def description @description end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
14445 14446 14447 |
# File 'lib/stripe/resources/payment_intent.rb', line 14445 def sold_by @sold_by end |