Class: Stripe::PaymentIntent::IncrementAuthorizationParams::PaymentDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(customer_reference: nil, order_reference: nil) ⇒ PaymentDetails

Returns a new instance of PaymentDetails.



15968
15969
15970
15971
# File 'lib/stripe/resources/payment_intent.rb', line 15968

def initialize(customer_reference: nil, order_reference: nil)
  @customer_reference = customer_reference
  @order_reference = order_reference
end

Instance Attribute Details

#customer_referenceObject

Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.



15964
15965
15966
# File 'lib/stripe/resources/payment_intent.rb', line 15964

def customer_reference
  @customer_reference
end

#order_referenceObject

A unique value assigned by the business to identify the transaction.



15966
15967
15968
# File 'lib/stripe/resources/payment_intent.rb', line 15966

def order_reference
  @order_reference
end