Class: Stripe::PaymentIntent::LastPaymentError

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#advice_codeObject (readonly)

For card errors resulting from a card issuer decline, a short string indicating how to proceed with an error if they provide one.



359
360
361
# File 'lib/stripe/resources/payment_intent.rb', line 359

def advice_code
  @advice_code
end

#chargeObject (readonly)

For card errors, the ID of the failed charge.



361
362
363
# File 'lib/stripe/resources/payment_intent.rb', line 361

def charge
  @charge
end

#codeObject (readonly)

For some errors that could be handled programmatically, a short string indicating the error code reported.



363
364
365
# File 'lib/stripe/resources/payment_intent.rb', line 363

def code
  @code
end

#decline_codeObject (readonly)

For card errors resulting from a card issuer decline, a short string indicating the card issuer's reason for the decline if they provide one.



365
366
367
# File 'lib/stripe/resources/payment_intent.rb', line 365

def decline_code
  @decline_code
end

#doc_urlObject (readonly)

A URL to more information about the error code reported.



367
368
369
# File 'lib/stripe/resources/payment_intent.rb', line 367

def doc_url
  @doc_url
end

#gift_card_operationObject (readonly)

A GiftCardOperation represents an operation performed on a third-party gift card, such as activation, reload, cashout, balance check, or void.



370
371
372
# File 'lib/stripe/resources/payment_intent.rb', line 370

def gift_card_operation
  @gift_card_operation
end

#messageObject (readonly)

A human-readable message providing more details about the error. For card errors, these messages can be shown to your users.



372
373
374
# File 'lib/stripe/resources/payment_intent.rb', line 372

def message
  @message
end

#network_advice_codeObject (readonly)

For card errors resulting from a card issuer decline, a 2 digit code which indicates the advice given to merchant by the card network on how to proceed with an error.



374
375
376
# File 'lib/stripe/resources/payment_intent.rb', line 374

def network_advice_code
  @network_advice_code
end

#network_decline_codeObject (readonly)

For payments declined by the network, an alphanumeric code which indicates the reason the payment failed.



376
377
378
# File 'lib/stripe/resources/payment_intent.rb', line 376

def network_decline_code
  @network_decline_code
end

#paramObject (readonly)

If the error is parameter-specific, the parameter related to the error. For example, you can use this to display a message near the correct form field.



378
379
380
# File 'lib/stripe/resources/payment_intent.rb', line 378

def param
  @param
end

#payment_intentObject (readonly)

A PaymentIntent guides you through the process of collecting a payment from your customer. We recommend that you create exactly one PaymentIntent for each order or customer session in your system. You can reference the PaymentIntent later to see the history of payment attempts for a particular session.

A PaymentIntent transitions through multiple statuses throughout its lifetime as it interfaces with Stripe.js to perform authentication flows and ultimately creates at most one successful charge.

Related guide: Payment Intents API



390
391
392
# File 'lib/stripe/resources/payment_intent.rb', line 390

def payment_intent
  @payment_intent
end

#payment_methodObject (readonly)

PaymentMethod objects represent your customer's payment instruments. You can use them with PaymentIntents to collect payments or save them to Customer objects to store instrument details for future payments.

Related guides: Payment Methods and More Payment Scenarios.



396
397
398
# File 'lib/stripe/resources/payment_intent.rb', line 396

def payment_method
  @payment_method
end

#payment_method_typeObject (readonly)

If the error is specific to the type of payment method, the payment method type that had a problem. This field is only populated for invoice-related errors.



398
399
400
# File 'lib/stripe/resources/payment_intent.rb', line 398

def payment_method_type
  @payment_method_type
end

#request_log_urlObject (readonly)

A URL to the request log entry in your dashboard.



400
401
402
# File 'lib/stripe/resources/payment_intent.rb', line 400

def request_log_url
  @request_log_url
end

#setup_intentObject (readonly)

A SetupIntent guides you through the process of setting up and saving a customer's payment credentials for future payments. For example, you can use a SetupIntent to set up and save your customer's card without immediately collecting a payment. Later, you can use PaymentIntents to drive the payment flow.

Create a SetupIntent when you're ready to collect your customer's payment credentials. Don't maintain long-lived, unconfirmed SetupIntents because they might not be valid. The SetupIntent transitions through multiple statuses as it guides you through the setup process.

Successful SetupIntents result in payment credentials that are optimized for future payments. For example, cardholders in certain regions might need to be run through Strong Customer Authentication during payment method collection to streamline later off-session payments. If you use the SetupIntent with a Customer, it automatically attaches the resulting payment method to that Customer after successful setup. We recommend using SetupIntents or setup_future_usage on PaymentIntents to save payment methods to prevent saving invalid or unoptimized payment methods.

By using SetupIntents, you can reduce friction for your customers, even as regulations change over time.

Related guide: Setup Intents API



422
423
424
# File 'lib/stripe/resources/payment_intent.rb', line 422

def setup_intent
  @setup_intent
end

#sourceObject (readonly)

Attribute for field source



424
425
426
# File 'lib/stripe/resources/payment_intent.rb', line 424

def source
  @source
end

#typeObject (readonly)

The type of error returned. One of api_error, card_error, idempotency_error, or invalid_request_error



426
427
428
# File 'lib/stripe/resources/payment_intent.rb', line 426

def type
  @type
end

Class Method Details

.field_remappingsObject



432
433
434
# File 'lib/stripe/resources/payment_intent.rb', line 432

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



428
429
430
# File 'lib/stripe/resources/payment_intent.rb', line 428

def self.inner_class_types
  @inner_class_types = {}
end