Class: Stripe::PaymentIntent::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(created: nil, customer: nil, customer_account: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



3430
3431
3432
3433
3434
3435
3436
3437
3438
3439
3440
3441
3442
3443
3444
3445
3446
# File 'lib/stripe/resources/payment_intent.rb', line 3430

def initialize(
  created: nil,
  customer: nil,
  customer_account: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  starting_after: nil
)
  @created = created
  @customer = customer
  @customer_account = 
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
end

Instance Attribute Details

#createdObject

A filter on the list, based on the object ‘created` field. The value can be a string with an integer Unix timestamp or a dictionary with a number of different query options.



3416
3417
3418
# File 'lib/stripe/resources/payment_intent.rb', line 3416

def created
  @created
end

#customerObject

Only return PaymentIntents for the customer that this customer ID specifies.



3418
3419
3420
# File 'lib/stripe/resources/payment_intent.rb', line 3418

def customer
  @customer
end

#customer_accountObject

Only return PaymentIntents for the account that this ID specifies.



3420
3421
3422
# File 'lib/stripe/resources/payment_intent.rb', line 3420

def 
  @customer_account
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



3422
3423
3424
# File 'lib/stripe/resources/payment_intent.rb', line 3422

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



3424
3425
3426
# File 'lib/stripe/resources/payment_intent.rb', line 3424

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



3426
3427
3428
# File 'lib/stripe/resources/payment_intent.rb', line 3426

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



3428
3429
3430
# File 'lib/stripe/resources/payment_intent.rb', line 3428

def starting_after
  @starting_after
end