Class: Stripe::PaymentIntent::NextAction
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::NextAction
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: AlipayHandleRedirect, BlikAuthorize, BoletoDisplayDetails, CardAwaitNotification, CashappHandleRedirectOrDisplayQrCode, CryptoDisplayDetails, DisplayBankTransferInstructions, KlarnaDisplayQrCode, KonbiniDisplayDetails, MultibancoDisplayDetails, OxxoDisplayDetails, PaynowDisplayQrCode, PixDisplayQrCode, PromptpayDisplayQrCode, RedirectToUrl, SwishHandleRedirectOrDisplayQrCode, UpiHandleRedirectOrDisplayQrCode, VerifyWithMicrodeposits, WechatPayDisplayQrCode, WechatPayHandleAppRedirect, WechatPayRedirectToAndroidApp, WechatPayRedirectToIosApp
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#alipay_handle_redirect ⇒ Object
readonly
Attribute for field alipay_handle_redirect.
-
#blik_authorize ⇒ Object
readonly
Attribute for field blik_authorize.
-
#boleto_display_details ⇒ Object
readonly
Attribute for field boleto_display_details.
-
#card_await_notification ⇒ Object
readonly
Attribute for field card_await_notification.
-
#cashapp_handle_redirect_or_display_qr_code ⇒ Object
readonly
Attribute for field cashapp_handle_redirect_or_display_qr_code.
-
#crypto_display_details ⇒ Object
readonly
Attribute for field crypto_display_details.
-
#display_bank_transfer_instructions ⇒ Object
readonly
Attribute for field display_bank_transfer_instructions.
-
#klarna_display_qr_code ⇒ Object
readonly
Attribute for field klarna_display_qr_code.
-
#konbini_display_details ⇒ Object
readonly
Attribute for field konbini_display_details.
-
#multibanco_display_details ⇒ Object
readonly
Attribute for field multibanco_display_details.
-
#oxxo_display_details ⇒ Object
readonly
Attribute for field oxxo_display_details.
-
#paynow_display_qr_code ⇒ Object
readonly
Attribute for field paynow_display_qr_code.
-
#pix_display_qr_code ⇒ Object
readonly
Attribute for field pix_display_qr_code.
-
#promptpay_display_qr_code ⇒ Object
readonly
Attribute for field promptpay_display_qr_code.
-
#redirect_to_url ⇒ Object
readonly
Attribute for field redirect_to_url.
-
#swish_handle_redirect_or_display_qr_code ⇒ Object
readonly
Attribute for field swish_handle_redirect_or_display_qr_code.
-
#type ⇒ Object
readonly
Type of the next action to perform.
-
#upi_handle_redirect_or_display_qr_code ⇒ Object
readonly
Attribute for field upi_handle_redirect_or_display_qr_code.
-
#use_stripe_sdk ⇒ Object
readonly
When confirming a PaymentIntent with Stripe.js, Stripe.js depends on the contents of this dictionary to invoke authentication flows.
-
#verify_with_microdeposits ⇒ Object
readonly
Attribute for field verify_with_microdeposits.
-
#wechat_pay_display_qr_code ⇒ Object
readonly
Attribute for field wechat_pay_display_qr_code.
-
#wechat_pay_handle_app_redirect ⇒ Object
readonly
Attribute for field wechat_pay_handle_app_redirect.
-
#wechat_pay_redirect_to_android_app ⇒ Object
readonly
Attribute for field wechat_pay_redirect_to_android_app.
-
#wechat_pay_redirect_to_ios_app ⇒ Object
readonly
Attribute for field wechat_pay_redirect_to_ios_app.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#alipay_handle_redirect ⇒ Object (readonly)
Attribute for field alipay_handle_redirect
1610 1611 1612 |
# File 'lib/stripe/resources/payment_intent.rb', line 1610 def alipay_handle_redirect @alipay_handle_redirect end |
#blik_authorize ⇒ Object (readonly)
Attribute for field blik_authorize
1612 1613 1614 |
# File 'lib/stripe/resources/payment_intent.rb', line 1612 def @blik_authorize end |
#boleto_display_details ⇒ Object (readonly)
Attribute for field boleto_display_details
1614 1615 1616 |
# File 'lib/stripe/resources/payment_intent.rb', line 1614 def boleto_display_details @boleto_display_details end |
#card_await_notification ⇒ Object (readonly)
Attribute for field card_await_notification
1616 1617 1618 |
# File 'lib/stripe/resources/payment_intent.rb', line 1616 def card_await_notification @card_await_notification end |
#cashapp_handle_redirect_or_display_qr_code ⇒ Object (readonly)
Attribute for field cashapp_handle_redirect_or_display_qr_code
1618 1619 1620 |
# File 'lib/stripe/resources/payment_intent.rb', line 1618 def cashapp_handle_redirect_or_display_qr_code @cashapp_handle_redirect_or_display_qr_code end |
#crypto_display_details ⇒ Object (readonly)
Attribute for field crypto_display_details
1620 1621 1622 |
# File 'lib/stripe/resources/payment_intent.rb', line 1620 def crypto_display_details @crypto_display_details end |
#display_bank_transfer_instructions ⇒ Object (readonly)
Attribute for field display_bank_transfer_instructions
1622 1623 1624 |
# File 'lib/stripe/resources/payment_intent.rb', line 1622 def display_bank_transfer_instructions @display_bank_transfer_instructions end |
#klarna_display_qr_code ⇒ Object (readonly)
Attribute for field klarna_display_qr_code
1624 1625 1626 |
# File 'lib/stripe/resources/payment_intent.rb', line 1624 def klarna_display_qr_code @klarna_display_qr_code end |
#konbini_display_details ⇒ Object (readonly)
Attribute for field konbini_display_details
1626 1627 1628 |
# File 'lib/stripe/resources/payment_intent.rb', line 1626 def konbini_display_details @konbini_display_details end |
#multibanco_display_details ⇒ Object (readonly)
Attribute for field multibanco_display_details
1628 1629 1630 |
# File 'lib/stripe/resources/payment_intent.rb', line 1628 def multibanco_display_details @multibanco_display_details end |
#oxxo_display_details ⇒ Object (readonly)
Attribute for field oxxo_display_details
1630 1631 1632 |
# File 'lib/stripe/resources/payment_intent.rb', line 1630 def oxxo_display_details @oxxo_display_details end |
#paynow_display_qr_code ⇒ Object (readonly)
Attribute for field paynow_display_qr_code
1632 1633 1634 |
# File 'lib/stripe/resources/payment_intent.rb', line 1632 def paynow_display_qr_code @paynow_display_qr_code end |
#pix_display_qr_code ⇒ Object (readonly)
Attribute for field pix_display_qr_code
1634 1635 1636 |
# File 'lib/stripe/resources/payment_intent.rb', line 1634 def pix_display_qr_code @pix_display_qr_code end |
#promptpay_display_qr_code ⇒ Object (readonly)
Attribute for field promptpay_display_qr_code
1636 1637 1638 |
# File 'lib/stripe/resources/payment_intent.rb', line 1636 def promptpay_display_qr_code @promptpay_display_qr_code end |
#redirect_to_url ⇒ Object (readonly)
Attribute for field redirect_to_url
1638 1639 1640 |
# File 'lib/stripe/resources/payment_intent.rb', line 1638 def redirect_to_url @redirect_to_url end |
#swish_handle_redirect_or_display_qr_code ⇒ Object (readonly)
Attribute for field swish_handle_redirect_or_display_qr_code
1640 1641 1642 |
# File 'lib/stripe/resources/payment_intent.rb', line 1640 def swish_handle_redirect_or_display_qr_code @swish_handle_redirect_or_display_qr_code end |
#type ⇒ Object (readonly)
Type of the next action to perform. Refer to the other child attributes under next_action for available values. Examples include: redirect_to_url, use_stripe_sdk, alipay_handle_redirect, oxxo_display_details, or verify_with_microdeposits.
1642 1643 1644 |
# File 'lib/stripe/resources/payment_intent.rb', line 1642 def type @type end |
#upi_handle_redirect_or_display_qr_code ⇒ Object (readonly)
Attribute for field upi_handle_redirect_or_display_qr_code
1644 1645 1646 |
# File 'lib/stripe/resources/payment_intent.rb', line 1644 def upi_handle_redirect_or_display_qr_code @upi_handle_redirect_or_display_qr_code end |
#use_stripe_sdk ⇒ Object (readonly)
When confirming a PaymentIntent with Stripe.js, Stripe.js depends on the contents of this dictionary to invoke authentication flows. The shape of the contents is subject to change and is only intended to be used by Stripe.js.
1646 1647 1648 |
# File 'lib/stripe/resources/payment_intent.rb', line 1646 def use_stripe_sdk @use_stripe_sdk end |
#verify_with_microdeposits ⇒ Object (readonly)
Attribute for field verify_with_microdeposits
1648 1649 1650 |
# File 'lib/stripe/resources/payment_intent.rb', line 1648 def verify_with_microdeposits @verify_with_microdeposits end |
#wechat_pay_display_qr_code ⇒ Object (readonly)
Attribute for field wechat_pay_display_qr_code
1650 1651 1652 |
# File 'lib/stripe/resources/payment_intent.rb', line 1650 def wechat_pay_display_qr_code @wechat_pay_display_qr_code end |
#wechat_pay_handle_app_redirect ⇒ Object (readonly)
Attribute for field wechat_pay_handle_app_redirect
1652 1653 1654 |
# File 'lib/stripe/resources/payment_intent.rb', line 1652 def wechat_pay_handle_app_redirect @wechat_pay_handle_app_redirect end |
#wechat_pay_redirect_to_android_app ⇒ Object (readonly)
Attribute for field wechat_pay_redirect_to_android_app
1654 1655 1656 |
# File 'lib/stripe/resources/payment_intent.rb', line 1654 def wechat_pay_redirect_to_android_app @wechat_pay_redirect_to_android_app end |
#wechat_pay_redirect_to_ios_app ⇒ Object (readonly)
Attribute for field wechat_pay_redirect_to_ios_app
1656 1657 1658 |
# File 'lib/stripe/resources/payment_intent.rb', line 1656 def wechat_pay_redirect_to_ios_app @wechat_pay_redirect_to_ios_app end |
Class Method Details
.field_remappings ⇒ Object
1685 1686 1687 |
# File 'lib/stripe/resources/payment_intent.rb', line 1685 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1658 1659 1660 1661 1662 1663 1664 1665 1666 1667 1668 1669 1670 1671 1672 1673 1674 1675 1676 1677 1678 1679 1680 1681 1682 1683 |
# File 'lib/stripe/resources/payment_intent.rb', line 1658 def self.inner_class_types @inner_class_types = { alipay_handle_redirect: AlipayHandleRedirect, blik_authorize: BlikAuthorize, boleto_display_details: BoletoDisplayDetails, card_await_notification: CardAwaitNotification, cashapp_handle_redirect_or_display_qr_code: CashappHandleRedirectOrDisplayQrCode, crypto_display_details: CryptoDisplayDetails, display_bank_transfer_instructions: DisplayBankTransferInstructions, klarna_display_qr_code: KlarnaDisplayQrCode, konbini_display_details: KonbiniDisplayDetails, multibanco_display_details: MultibancoDisplayDetails, oxxo_display_details: OxxoDisplayDetails, paynow_display_qr_code: PaynowDisplayQrCode, pix_display_qr_code: PixDisplayQrCode, promptpay_display_qr_code: PromptpayDisplayQrCode, redirect_to_url: RedirectToUrl, swish_handle_redirect_or_display_qr_code: SwishHandleRedirectOrDisplayQrCode, upi_handle_redirect_or_display_qr_code: UpiHandleRedirectOrDisplayQrCode, verify_with_microdeposits: VerifyWithMicrodeposits, wechat_pay_display_qr_code: WechatPayDisplayQrCode, wechat_pay_handle_app_redirect: WechatPayHandleAppRedirect, wechat_pay_redirect_to_android_app: WechatPayRedirectToAndroidApp, wechat_pay_redirect_to_ios_app: WechatPayRedirectToIosApp, } end |