Class: Stripe::PaymentIntent::NextAction::AlipayHandleRedirect

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#native_dataObject (readonly)

The native data to be used with Alipay SDK you must redirect your customer to in order to authenticate the payment in an Android App.



311
312
313
# File 'lib/stripe/resources/payment_intent.rb', line 311

def native_data
  @native_data
end

#native_urlObject (readonly)

The native URL you must redirect your customer to in order to authenticate the payment in an iOS App.



313
314
315
# File 'lib/stripe/resources/payment_intent.rb', line 313

def native_url
  @native_url
end

#return_urlObject (readonly)

If the customer does not exit their browser while authenticating, they will be redirected to this specified URL after completion.



315
316
317
# File 'lib/stripe/resources/payment_intent.rb', line 315

def return_url
  @return_url
end

#urlObject (readonly)

The URL you must redirect your customer to in order to authenticate the payment.



317
318
319
# File 'lib/stripe/resources/payment_intent.rb', line 317

def url
  @url
end

Class Method Details

.field_remappingsObject



323
324
325
# File 'lib/stripe/resources/payment_intent.rb', line 323

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



319
320
321
# File 'lib/stripe/resources/payment_intent.rb', line 319

def self.inner_class_types
  @inner_class_types = {}
end