Class: Stripe::PaymentIntent::NextAction::BoletoDisplayDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::NextAction::BoletoDisplayDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#expires_at ⇒ Object
readonly
The timestamp after which the boleto expires.
-
#hosted_voucher_url ⇒ Object
readonly
The URL to the hosted boleto voucher page, which allows customers to view the boleto voucher.
-
#number ⇒ Object
readonly
The boleto number.
-
#pdf ⇒ Object
readonly
The URL to the downloadable boleto voucher PDF.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#expires_at ⇒ Object (readonly)
The timestamp after which the boleto expires.
330 331 332 |
# File 'lib/stripe/resources/payment_intent.rb', line 330 def expires_at @expires_at end |
#hosted_voucher_url ⇒ Object (readonly)
The URL to the hosted boleto voucher page, which allows customers to view the boleto voucher.
332 333 334 |
# File 'lib/stripe/resources/payment_intent.rb', line 332 def hosted_voucher_url @hosted_voucher_url end |
#number ⇒ Object (readonly)
The boleto number.
334 335 336 |
# File 'lib/stripe/resources/payment_intent.rb', line 334 def number @number end |
#pdf ⇒ Object (readonly)
The URL to the downloadable boleto voucher PDF.
336 337 338 |
# File 'lib/stripe/resources/payment_intent.rb', line 336 def pdf @pdf end |
Class Method Details
.field_remappings ⇒ Object
342 343 344 |
# File 'lib/stripe/resources/payment_intent.rb', line 342 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
338 339 340 |
# File 'lib/stripe/resources/payment_intent.rb', line 338 def self.inner_class_types @inner_class_types = {} end |