Class: Stripe::PaymentIntent::NextAction::CashappHandleRedirectOrDisplayQrCode
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::NextAction::CashappHandleRedirectOrDisplayQrCode
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: QrCode
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#hosted_instructions_url ⇒ Object
readonly
The URL to the hosted Cash App Pay instructions page, which allows customers to view the QR code, and supports QR code refreshing on expiration.
-
#mobile_auth_url ⇒ Object
readonly
The url for mobile redirect based auth.
-
#qr_code ⇒ Object
readonly
Attribute for field qr_code.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#hosted_instructions_url ⇒ Object (readonly)
The URL to the hosted Cash App Pay instructions page, which allows customers to view the QR code, and supports QR code refreshing on expiration.
218 219 220 |
# File 'lib/stripe/resources/payment_intent.rb', line 218 def hosted_instructions_url @hosted_instructions_url end |
#mobile_auth_url ⇒ Object (readonly)
The url for mobile redirect based auth
220 221 222 |
# File 'lib/stripe/resources/payment_intent.rb', line 220 def mobile_auth_url @mobile_auth_url end |
#qr_code ⇒ Object (readonly)
Attribute for field qr_code
222 223 224 |
# File 'lib/stripe/resources/payment_intent.rb', line 222 def qr_code @qr_code end |
Class Method Details
.field_remappings ⇒ Object
228 229 230 |
# File 'lib/stripe/resources/payment_intent.rb', line 228 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
224 225 226 |
# File 'lib/stripe/resources/payment_intent.rb', line 224 def self.inner_class_types @inner_class_types = { qr_code: QrCode } end |