Class: Stripe::PaymentIntent::NextAction::CryptoDisplayDetails::DepositAddresses::Tempo::SupportedToken
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::NextAction::CryptoDisplayDetails::DepositAddresses::Tempo::SupportedToken
- Defined in:
- lib/stripe/resources/payment_intent.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#token_contract_address ⇒ Object
readonly
The on-chain contract address for the supported token currency on this specific network.
-
#token_currency ⇒ Object
readonly
The supported token currency.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#token_contract_address ⇒ Object (readonly)
The on-chain contract address for the supported token currency on this specific network.
607 608 609 |
# File 'lib/stripe/resources/payment_intent.rb', line 607 def token_contract_address @token_contract_address end |
#token_currency ⇒ Object (readonly)
The supported token currency. Supported token currencies include: ‘usdc`.
609 610 611 |
# File 'lib/stripe/resources/payment_intent.rb', line 609 def token_currency @token_currency end |
Class Method Details
.field_remappings ⇒ Object
615 616 617 |
# File 'lib/stripe/resources/payment_intent.rb', line 615 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
611 612 613 |
# File 'lib/stripe/resources/payment_intent.rb', line 611 def self.inner_class_types @inner_class_types = {} end |