Class: Stripe::PaymentIntent::NextAction::DisplayBankTransferInstructions
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::NextAction::DisplayBankTransferInstructions
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: FinancialAddress
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount_remaining ⇒ Object
readonly
The remaining amount that needs to be transferred to complete the payment.
-
#currency ⇒ Object
readonly
Three-letter ISO currency code, in lowercase.
-
#financial_addresses ⇒ Object
readonly
A list of financial addresses that can be used to fund the customer balance.
-
#hosted_instructions_url ⇒ Object
readonly
A link to a hosted page that guides your customer through completing the transfer.
-
#reference ⇒ Object
readonly
A string identifying this payment.
-
#type ⇒ Object
readonly
Type of bank transfer.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount_remaining ⇒ Object (readonly)
The remaining amount that needs to be transferred to complete the payment.
1208 1209 1210 |
# File 'lib/stripe/resources/payment_intent.rb', line 1208 def amount_remaining @amount_remaining end |
#currency ⇒ Object (readonly)
Three-letter ISO currency code, in lowercase. Must be a supported currency.
1210 1211 1212 |
# File 'lib/stripe/resources/payment_intent.rb', line 1210 def currency @currency end |
#financial_addresses ⇒ Object (readonly)
A list of financial addresses that can be used to fund the customer balance
1212 1213 1214 |
# File 'lib/stripe/resources/payment_intent.rb', line 1212 def financial_addresses @financial_addresses end |
#hosted_instructions_url ⇒ Object (readonly)
A link to a hosted page that guides your customer through completing the transfer.
1214 1215 1216 |
# File 'lib/stripe/resources/payment_intent.rb', line 1214 def hosted_instructions_url @hosted_instructions_url end |
#reference ⇒ Object (readonly)
A string identifying this payment. Instruct your customer to include this code in the reference or memo field of their bank transfer.
1216 1217 1218 |
# File 'lib/stripe/resources/payment_intent.rb', line 1216 def reference @reference end |
#type ⇒ Object (readonly)
Type of bank transfer
1218 1219 1220 |
# File 'lib/stripe/resources/payment_intent.rb', line 1218 def type @type end |
Class Method Details
.field_remappings ⇒ Object
1224 1225 1226 |
# File 'lib/stripe/resources/payment_intent.rb', line 1224 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1220 1221 1222 |
# File 'lib/stripe/resources/payment_intent.rb', line 1220 def self.inner_class_types @inner_class_types = { financial_addresses: FinancialAddress } end |