Class: Stripe::PaymentIntent::NextAction::DisplayBankTransferInstructions::FinancialAddress

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Aba, Iban, SortCode, Spei, Swift, Zengin

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#abaObject (readonly)

ABA Records contain U.S. bank account details per the ABA format.



1176
1177
1178
# File 'lib/stripe/resources/payment_intent.rb', line 1176

def aba
  @aba
end

#ibanObject (readonly)

Iban Records contain E.U. bank account details per the SEPA format.



1178
1179
1180
# File 'lib/stripe/resources/payment_intent.rb', line 1178

def iban
  @iban
end

#sort_codeObject (readonly)

Sort Code Records contain U.K. bank account details per the sort code format.



1180
1181
1182
# File 'lib/stripe/resources/payment_intent.rb', line 1180

def sort_code
  @sort_code
end

#speiObject (readonly)

SPEI Records contain Mexico bank account details per the SPEI format.



1182
1183
1184
# File 'lib/stripe/resources/payment_intent.rb', line 1182

def spei
  @spei
end

#supported_networksObject (readonly)

The payment networks supported by this FinancialAddress



1184
1185
1186
# File 'lib/stripe/resources/payment_intent.rb', line 1184

def supported_networks
  @supported_networks
end

#swiftObject (readonly)

SWIFT Records contain U.S. bank account details per the SWIFT format.



1186
1187
1188
# File 'lib/stripe/resources/payment_intent.rb', line 1186

def swift
  @swift
end

#typeObject (readonly)

The type of financial address



1188
1189
1190
# File 'lib/stripe/resources/payment_intent.rb', line 1188

def type
  @type
end

#zenginObject (readonly)

Zengin Records contain Japan bank account details per the Zengin format.



1190
1191
1192
# File 'lib/stripe/resources/payment_intent.rb', line 1190

def zengin
  @zengin
end

Class Method Details

.field_remappingsObject



1203
1204
1205
# File 'lib/stripe/resources/payment_intent.rb', line 1203

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1192
1193
1194
1195
1196
1197
1198
1199
1200
1201
# File 'lib/stripe/resources/payment_intent.rb', line 1192

def self.inner_class_types
  @inner_class_types = {
    aba: Aba,
    iban: Iban,
    sort_code: SortCode,
    spei: Spei,
    swift: Swift,
    zengin: Zengin,
  }
end