Class: Stripe::PaymentIntent::NextAction::DisplayBankTransferInstructions::FinancialAddress::Iban
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::NextAction::DisplayBankTransferInstructions::FinancialAddress::Iban
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: AccountHolderAddress, BankAddress
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_holder_address ⇒ Object
readonly
Attribute for field account_holder_address.
-
#account_holder_name ⇒ Object
readonly
The name of the person or business that owns the bank account.
-
#bank_address ⇒ Object
readonly
Attribute for field bank_address.
-
#bic ⇒ Object
readonly
The BIC/SWIFT code of the account.
-
#country ⇒ Object
readonly
Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
-
#iban ⇒ Object
readonly
The IBAN of the account.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_holder_address ⇒ Object (readonly)
Attribute for field account_holder_address
541 542 543 |
# File 'lib/stripe/resources/payment_intent.rb', line 541 def account_holder_address @account_holder_address end |
#account_holder_name ⇒ Object (readonly)
The name of the person or business that owns the bank account
543 544 545 |
# File 'lib/stripe/resources/payment_intent.rb', line 543 def account_holder_name @account_holder_name end |
#bank_address ⇒ Object (readonly)
Attribute for field bank_address
545 546 547 |
# File 'lib/stripe/resources/payment_intent.rb', line 545 def bank_address @bank_address end |
#bic ⇒ Object (readonly)
The BIC/SWIFT code of the account.
547 548 549 |
# File 'lib/stripe/resources/payment_intent.rb', line 547 def bic @bic end |
#country ⇒ Object (readonly)
Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
549 550 551 |
# File 'lib/stripe/resources/payment_intent.rb', line 549 def country @country end |
#iban ⇒ Object (readonly)
The IBAN of the account.
551 552 553 |
# File 'lib/stripe/resources/payment_intent.rb', line 551 def iban @iban end |
Class Method Details
.field_remappings ⇒ Object
560 561 562 |
# File 'lib/stripe/resources/payment_intent.rb', line 560 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
553 554 555 556 557 558 |
# File 'lib/stripe/resources/payment_intent.rb', line 553 def self.inner_class_types @inner_class_types = { account_holder_address: AccountHolderAddress, bank_address: BankAddress, } end |