Class: Stripe::PaymentIntent::NextAction::DisplayBankTransferInstructions::FinancialAddress::SortCode
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::NextAction::DisplayBankTransferInstructions::FinancialAddress::SortCode
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: AccountHolderAddress, BankAddress
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_holder_address ⇒ Object
readonly
Attribute for field account_holder_address.
-
#account_holder_name ⇒ Object
readonly
The name of the person or business that owns the bank account.
-
#account_number ⇒ Object
readonly
The account number.
-
#bank_address ⇒ Object
readonly
Attribute for field bank_address.
-
#sort_code ⇒ Object
readonly
The six-digit sort code.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_holder_address ⇒ Object (readonly)
Attribute for field account_holder_address
612 613 614 |
# File 'lib/stripe/resources/payment_intent.rb', line 612 def account_holder_address @account_holder_address end |
#account_holder_name ⇒ Object (readonly)
The name of the person or business that owns the bank account
614 615 616 |
# File 'lib/stripe/resources/payment_intent.rb', line 614 def account_holder_name @account_holder_name end |
#account_number ⇒ Object (readonly)
The account number
616 617 618 |
# File 'lib/stripe/resources/payment_intent.rb', line 616 def account_number @account_number end |
#bank_address ⇒ Object (readonly)
Attribute for field bank_address
618 619 620 |
# File 'lib/stripe/resources/payment_intent.rb', line 618 def bank_address @bank_address end |
#sort_code ⇒ Object (readonly)
The six-digit sort code
620 621 622 |
# File 'lib/stripe/resources/payment_intent.rb', line 620 def sort_code @sort_code end |
Class Method Details
.field_remappings ⇒ Object
629 630 631 |
# File 'lib/stripe/resources/payment_intent.rb', line 629 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
622 623 624 625 626 627 |
# File 'lib/stripe/resources/payment_intent.rb', line 622 def self.inner_class_types @inner_class_types = { account_holder_address: AccountHolderAddress, bank_address: BankAddress, } end |