Class: Stripe::PaymentIntent::NextAction::KonbiniDisplayDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::NextAction::KonbiniDisplayDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Stores
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#expires_at ⇒ Object
readonly
The timestamp at which the pending Konbini payment expires.
-
#hosted_voucher_url ⇒ Object
readonly
The URL for the Konbini payment instructions page, which allows customers to view and print a Konbini voucher.
-
#stores ⇒ Object
readonly
Attribute for field stores.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#expires_at ⇒ Object (readonly)
The timestamp at which the pending Konbini payment expires.
1011 1012 1013 |
# File 'lib/stripe/resources/payment_intent.rb', line 1011 def expires_at @expires_at end |
#hosted_voucher_url ⇒ Object (readonly)
The URL for the Konbini payment instructions page, which allows customers to view and print a Konbini voucher.
1013 1014 1015 |
# File 'lib/stripe/resources/payment_intent.rb', line 1013 def hosted_voucher_url @hosted_voucher_url end |
#stores ⇒ Object (readonly)
Attribute for field stores
1015 1016 1017 |
# File 'lib/stripe/resources/payment_intent.rb', line 1015 def stores @stores end |
Class Method Details
.field_remappings ⇒ Object
1021 1022 1023 |
# File 'lib/stripe/resources/payment_intent.rb', line 1021 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1017 1018 1019 |
# File 'lib/stripe/resources/payment_intent.rb', line 1017 def self.inner_class_types @inner_class_types = { stores: Stores } end |