Class: Stripe::PaymentIntent::NextAction::MultibancoDisplayDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::NextAction::MultibancoDisplayDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#entity ⇒ Object
readonly
Entity number associated with this Multibanco payment.
-
#expires_at ⇒ Object
readonly
The timestamp at which the Multibanco voucher expires.
-
#hosted_voucher_url ⇒ Object
readonly
The URL for the hosted Multibanco voucher page, which allows customers to view a Multibanco voucher.
-
#reference ⇒ Object
readonly
Reference number associated with this Multibanco payment.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#entity ⇒ Object (readonly)
Entity number associated with this Multibanco payment.
1028 1029 1030 |
# File 'lib/stripe/resources/payment_intent.rb', line 1028 def entity @entity end |
#expires_at ⇒ Object (readonly)
The timestamp at which the Multibanco voucher expires.
1030 1031 1032 |
# File 'lib/stripe/resources/payment_intent.rb', line 1030 def expires_at @expires_at end |
#hosted_voucher_url ⇒ Object (readonly)
The URL for the hosted Multibanco voucher page, which allows customers to view a Multibanco voucher.
1032 1033 1034 |
# File 'lib/stripe/resources/payment_intent.rb', line 1032 def hosted_voucher_url @hosted_voucher_url end |
#reference ⇒ Object (readonly)
Reference number associated with this Multibanco payment.
1034 1035 1036 |
# File 'lib/stripe/resources/payment_intent.rb', line 1034 def reference @reference end |
Class Method Details
.field_remappings ⇒ Object
1040 1041 1042 |
# File 'lib/stripe/resources/payment_intent.rb', line 1040 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1036 1037 1038 |
# File 'lib/stripe/resources/payment_intent.rb', line 1036 def self.inner_class_types @inner_class_types = {} end |