Class: Stripe::PaymentIntent::NextAction::OxxoDisplayDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::NextAction::OxxoDisplayDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#expires_after ⇒ Object
readonly
The timestamp after which the OXXO voucher expires.
-
#hosted_voucher_url ⇒ Object
readonly
The URL for the hosted OXXO voucher page, which allows customers to view and print an OXXO voucher.
-
#number ⇒ Object
readonly
OXXO reference number.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#expires_after ⇒ Object (readonly)
The timestamp after which the OXXO voucher expires.
1037 1038 1039 |
# File 'lib/stripe/resources/payment_intent.rb', line 1037 def expires_after @expires_after end |
#hosted_voucher_url ⇒ Object (readonly)
The URL for the hosted OXXO voucher page, which allows customers to view and print an OXXO voucher.
1039 1040 1041 |
# File 'lib/stripe/resources/payment_intent.rb', line 1039 def hosted_voucher_url @hosted_voucher_url end |
#number ⇒ Object (readonly)
OXXO reference number.
1041 1042 1043 |
# File 'lib/stripe/resources/payment_intent.rb', line 1041 def number @number end |
Class Method Details
.field_remappings ⇒ Object
1047 1048 1049 |
# File 'lib/stripe/resources/payment_intent.rb', line 1047 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1043 1044 1045 |
# File 'lib/stripe/resources/payment_intent.rb', line 1043 def self.inner_class_types @inner_class_types = {} end |