Class: Stripe::PaymentIntent::NextAction::PaynowDisplayQrCode

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#dataObject (readonly)

The raw data string used to generate QR code, it should be used together with QR code library.



1054
1055
1056
# File 'lib/stripe/resources/payment_intent.rb', line 1054

def data
  @data
end

#hosted_instructions_urlObject (readonly)

The URL to the hosted PayNow instructions page, which allows customers to view the PayNow QR code.



1056
1057
1058
# File 'lib/stripe/resources/payment_intent.rb', line 1056

def hosted_instructions_url
  @hosted_instructions_url
end

#image_url_pngObject (readonly)

The image_url_png string used to render QR code



1058
1059
1060
# File 'lib/stripe/resources/payment_intent.rb', line 1058

def image_url_png
  @image_url_png
end

#image_url_svgObject (readonly)

The image_url_svg string used to render QR code



1060
1061
1062
# File 'lib/stripe/resources/payment_intent.rb', line 1060

def image_url_svg
  @image_url_svg
end

Class Method Details

.field_remappingsObject



1066
1067
1068
# File 'lib/stripe/resources/payment_intent.rb', line 1066

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1062
1063
1064
# File 'lib/stripe/resources/payment_intent.rb', line 1062

def self.inner_class_types
  @inner_class_types = {}
end