Class: Stripe::PaymentIntent::NextAction::PixDisplayQrCode

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#dataObject (readonly)

The raw data string used to generate QR code, it should be used together with QR code library.



1197
1198
1199
# File 'lib/stripe/resources/payment_intent.rb', line 1197

def data
  @data
end

#expires_atObject (readonly)

The date (unix timestamp) when the PIX expires.



1199
1200
1201
# File 'lib/stripe/resources/payment_intent.rb', line 1199

def expires_at
  @expires_at
end

#hosted_instructions_urlObject (readonly)

The URL to the hosted pix instructions page, which allows customers to view the pix QR code.



1201
1202
1203
# File 'lib/stripe/resources/payment_intent.rb', line 1201

def hosted_instructions_url
  @hosted_instructions_url
end

#image_url_pngObject (readonly)

The image_url_png string used to render png QR code



1203
1204
1205
# File 'lib/stripe/resources/payment_intent.rb', line 1203

def image_url_png
  @image_url_png
end

#image_url_svgObject (readonly)

The image_url_svg string used to render svg QR code



1205
1206
1207
# File 'lib/stripe/resources/payment_intent.rb', line 1205

def image_url_svg
  @image_url_svg
end

Class Method Details

.field_remappingsObject



1211
1212
1213
# File 'lib/stripe/resources/payment_intent.rb', line 1211

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1207
1208
1209
# File 'lib/stripe/resources/payment_intent.rb', line 1207

def self.inner_class_types
  @inner_class_types = {}
end