Class: Stripe::PaymentIntent::NextAction::RedirectToUrl

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#return_urlObject (readonly)

If the customer does not exit their browser while authenticating, they will be redirected to this specified URL after completion.



1123
1124
1125
# File 'lib/stripe/resources/payment_intent.rb', line 1123

def return_url
  @return_url
end

#urlObject (readonly)

The URL you must redirect your customer to in order to authenticate the payment.



1125
1126
1127
# File 'lib/stripe/resources/payment_intent.rb', line 1125

def url
  @url
end

Class Method Details

.field_remappingsObject



1131
1132
1133
# File 'lib/stripe/resources/payment_intent.rb', line 1131

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1127
1128
1129
# File 'lib/stripe/resources/payment_intent.rb', line 1127

def self.inner_class_types
  @inner_class_types = {}
end