Class: Stripe::PaymentIntent::NextAction::SwishHandleRedirectOrDisplayQrCode
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::NextAction::SwishHandleRedirectOrDisplayQrCode
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: QrCode
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#hosted_instructions_url ⇒ Object
readonly
The URL to the hosted Swish instructions page, which allows customers to view the QR code.
-
#mobile_auth_url ⇒ Object
readonly
The url for mobile redirect based auth (for internal use only and not typically available in standard API requests).
-
#qr_code ⇒ Object
readonly
Attribute for field qr_code.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#hosted_instructions_url ⇒ Object (readonly)
The URL to the hosted Swish instructions page, which allows customers to view the QR code.
1144 1145 1146 |
# File 'lib/stripe/resources/payment_intent.rb', line 1144 def hosted_instructions_url @hosted_instructions_url end |
#mobile_auth_url ⇒ Object (readonly)
The url for mobile redirect based auth (for internal use only and not typically available in standard API requests).
1146 1147 1148 |
# File 'lib/stripe/resources/payment_intent.rb', line 1146 def mobile_auth_url @mobile_auth_url end |
#qr_code ⇒ Object (readonly)
Attribute for field qr_code
1148 1149 1150 |
# File 'lib/stripe/resources/payment_intent.rb', line 1148 def qr_code @qr_code end |
Class Method Details
.field_remappings ⇒ Object
1154 1155 1156 |
# File 'lib/stripe/resources/payment_intent.rb', line 1154 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1150 1151 1152 |
# File 'lib/stripe/resources/payment_intent.rb', line 1150 def self.inner_class_types @inner_class_types = { qr_code: QrCode } end |