Class: Stripe::PaymentIntent::NextAction::VerifyWithMicrodeposits
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::NextAction::VerifyWithMicrodeposits
- Defined in:
- lib/stripe/resources/payment_intent.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#arrival_date ⇒ Object
readonly
The timestamp when the microdeposits are expected to land.
-
#hosted_verification_url ⇒ Object
readonly
The URL for the hosted verification page, which allows customers to verify their bank account.
-
#microdeposit_type ⇒ Object
readonly
The type of the microdeposit sent to the customer.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#arrival_date ⇒ Object (readonly)
The timestamp when the microdeposits are expected to land.
966 967 968 |
# File 'lib/stripe/resources/payment_intent.rb', line 966 def arrival_date @arrival_date end |
#hosted_verification_url ⇒ Object (readonly)
The URL for the hosted verification page, which allows customers to verify their bank account.
968 969 970 |
# File 'lib/stripe/resources/payment_intent.rb', line 968 def hosted_verification_url @hosted_verification_url end |
#microdeposit_type ⇒ Object (readonly)
The type of the microdeposit sent to the customer. Used to distinguish between different verification methods.
970 971 972 |
# File 'lib/stripe/resources/payment_intent.rb', line 970 def microdeposit_type @microdeposit_type end |
Class Method Details
.field_remappings ⇒ Object
976 977 978 |
# File 'lib/stripe/resources/payment_intent.rb', line 976 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
972 973 974 |
# File 'lib/stripe/resources/payment_intent.rb', line 972 def self.inner_class_types @inner_class_types = {} end |