Class: Stripe::PaymentIntent::PaymentDetails

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Benefit, CarRental, CarRentalDatum, EventDetails, FleetDatum, FlightDatum, LodgingDatum, MoneyServices, Subscription

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#benefitObject (readonly)

Attribute for field benefit



3108
3109
3110
# File 'lib/stripe/resources/payment_intent.rb', line 3108

def benefit
  @benefit
end

#car_rentalObject (readonly)

Attribute for field car_rental



3110
3111
3112
# File 'lib/stripe/resources/payment_intent.rb', line 3110

def car_rental
  @car_rental
end

#car_rental_dataObject (readonly)

Attribute for field car_rental_data



3112
3113
3114
# File 'lib/stripe/resources/payment_intent.rb', line 3112

def car_rental_data
  @car_rental_data
end

#customer_referenceObject (readonly)

A unique value to identify the customer. This field is available only for card payments.

This field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks.



3116
3117
3118
# File 'lib/stripe/resources/payment_intent.rb', line 3116

def customer_reference
  @customer_reference
end

#event_detailsObject (readonly)

Attribute for field event_details



3118
3119
3120
# File 'lib/stripe/resources/payment_intent.rb', line 3118

def event_details
  @event_details
end

#fleet_dataObject (readonly)

Fleet data for this PaymentIntent.



3120
3121
3122
# File 'lib/stripe/resources/payment_intent.rb', line 3120

def fleet_data
  @fleet_data
end

#flight_dataObject (readonly)

Attribute for field flight_data



3122
3123
3124
# File 'lib/stripe/resources/payment_intent.rb', line 3122

def flight_data
  @flight_data
end

#locationObject (readonly)

The Payment Location associated with this PaymentIntent.



3124
3125
3126
# File 'lib/stripe/resources/payment_intent.rb', line 3124

def location
  @location
end

#lodging_dataObject (readonly)

Attribute for field lodging_data



3126
3127
3128
# File 'lib/stripe/resources/payment_intent.rb', line 3126

def lodging_data
  @lodging_data
end

#money_servicesObject (readonly)

Attribute for field money_services



3128
3129
3130
# File 'lib/stripe/resources/payment_intent.rb', line 3128

def money_services
  @money_services
end

#order_referenceObject (readonly)

A unique value assigned by the business to identify the transaction. Required for L2 and L3 rates.

For Cards, this field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks. For Klarna, this field is truncated to 255 characters and is visible to customers when they view the order in the Klarna app.



3132
3133
3134
# File 'lib/stripe/resources/payment_intent.rb', line 3132

def order_reference
  @order_reference
end

#subscriptionObject (readonly)

Attribute for field subscription



3134
3135
3136
# File 'lib/stripe/resources/payment_intent.rb', line 3134

def subscription
  @subscription
end

Class Method Details

.field_remappingsObject



3150
3151
3152
# File 'lib/stripe/resources/payment_intent.rb', line 3150

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



3136
3137
3138
3139
3140
3141
3142
3143
3144
3145
3146
3147
3148
# File 'lib/stripe/resources/payment_intent.rb', line 3136

def self.inner_class_types
  @inner_class_types = {
    benefit: Benefit,
    car_rental: CarRental,
    car_rental_data: CarRentalDatum,
    event_details: EventDetails,
    fleet_data: FleetDatum,
    flight_data: FlightDatum,
    lodging_data: LodgingDatum,
    money_services: MoneyServices,
    subscription: Subscription,
  }
end