Class: Stripe::PaymentIntent::PaymentDetails::Benefit::FrMealVoucher
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentDetails::Benefit::FrMealVoucher
- Defined in:
- lib/stripe/resources/payment_intent.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#enabled ⇒ Object
readonly
Whether meal voucher benefit is enabled for this payment.
-
#siret ⇒ Object
readonly
The 14-digit SIRET of the meal voucher acceptor.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#enabled ⇒ Object (readonly)
Whether meal voucher benefit is enabled for this payment.
1597 1598 1599 |
# File 'lib/stripe/resources/payment_intent.rb', line 1597 def enabled @enabled end |
#siret ⇒ Object (readonly)
The 14-digit SIRET of the meal voucher acceptor.
1599 1600 1601 |
# File 'lib/stripe/resources/payment_intent.rb', line 1599 def siret @siret end |
Class Method Details
.field_remappings ⇒ Object
1605 1606 1607 |
# File 'lib/stripe/resources/payment_intent.rb', line 1605 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1601 1602 1603 |
# File 'lib/stripe/resources/payment_intent.rb', line 1601 def self.inner_class_types @inner_class_types = {} end |