Class: Stripe::PaymentIntent::PaymentDetails::CarRental

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Affiliate, Delivery, Distance, Driver, PickupAddress, ReturnAddress

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#affiliateObject (readonly)

Attribute for field affiliate



1841
1842
1843
# File 'lib/stripe/resources/payment_intent.rb', line 1841

def affiliate
  @affiliate
end

#booking_numberObject (readonly)

The booking number associated with the car rental.



1843
1844
1845
# File 'lib/stripe/resources/payment_intent.rb', line 1843

def booking_number
  @booking_number
end

#car_class_codeObject (readonly)

Class code of the car.



1845
1846
1847
# File 'lib/stripe/resources/payment_intent.rb', line 1845

def car_class_code
  @car_class_code
end

#car_makeObject (readonly)

Make of the car.



1847
1848
1849
# File 'lib/stripe/resources/payment_intent.rb', line 1847

def car_make
  @car_make
end

#car_modelObject (readonly)

Model of the car.



1849
1850
1851
# File 'lib/stripe/resources/payment_intent.rb', line 1849

def car_model
  @car_model
end

#companyObject (readonly)

The name of the rental car company.



1851
1852
1853
# File 'lib/stripe/resources/payment_intent.rb', line 1851

def company
  @company
end

#customer_service_phone_numberObject (readonly)

The customer service phone number of the car rental company.



1853
1854
1855
# File 'lib/stripe/resources/payment_intent.rb', line 1853

def customer_service_phone_number
  @customer_service_phone_number
end

#days_rentedObject (readonly)

Number of days the car is being rented.



1855
1856
1857
# File 'lib/stripe/resources/payment_intent.rb', line 1855

def days_rented
  @days_rented
end

#deliveryObject (readonly)

Attribute for field delivery



1857
1858
1859
# File 'lib/stripe/resources/payment_intent.rb', line 1857

def delivery
  @delivery
end

#distanceObject (readonly)

Attribute for field distance



1859
1860
1861
# File 'lib/stripe/resources/payment_intent.rb', line 1859

def distance
  @distance
end

#driversObject (readonly)

The details of the drivers associated with the trip.



1861
1862
1863
# File 'lib/stripe/resources/payment_intent.rb', line 1861

def drivers
  @drivers
end

#extra_chargesObject (readonly)

List of additional charges being billed.



1863
1864
1865
# File 'lib/stripe/resources/payment_intent.rb', line 1863

def extra_charges
  @extra_charges
end

#no_showObject (readonly)

Indicates if the customer did not keep nor cancel their booking.



1865
1866
1867
# File 'lib/stripe/resources/payment_intent.rb', line 1865

def no_show
  @no_show
end

#pickup_addressObject (readonly)

Attribute for field pickup_address



1867
1868
1869
# File 'lib/stripe/resources/payment_intent.rb', line 1867

def pickup_address
  @pickup_address
end

#pickup_atObject (readonly)

Car pick-up time. Measured in seconds since the Unix epoch.



1869
1870
1871
# File 'lib/stripe/resources/payment_intent.rb', line 1869

def pickup_at
  @pickup_at
end

#pickup_location_nameObject (readonly)

Name of the pickup location.



1871
1872
1873
# File 'lib/stripe/resources/payment_intent.rb', line 1871

def pickup_location_name
  @pickup_location_name
end

#rate_amountObject (readonly)

Rental rate.



1873
1874
1875
# File 'lib/stripe/resources/payment_intent.rb', line 1873

def rate_amount
  @rate_amount
end

#rate_intervalObject (readonly)

The frequency at which the rate amount is applied. One of day, week or month



1875
1876
1877
# File 'lib/stripe/resources/payment_intent.rb', line 1875

def rate_interval
  @rate_interval
end

#renter_nameObject (readonly)

The full name of the person or entity renting the car.



1877
1878
1879
# File 'lib/stripe/resources/payment_intent.rb', line 1877

def renter_name
  @renter_name
end

#return_addressObject (readonly)

Attribute for field return_address



1879
1880
1881
# File 'lib/stripe/resources/payment_intent.rb', line 1879

def return_address
  @return_address
end

#return_atObject (readonly)

Car return time. Measured in seconds since the Unix epoch.



1881
1882
1883
# File 'lib/stripe/resources/payment_intent.rb', line 1881

def return_at
  @return_at
end

#return_location_nameObject (readonly)

Name of the return location.



1883
1884
1885
# File 'lib/stripe/resources/payment_intent.rb', line 1883

def return_location_name
  @return_location_name
end

#tax_exemptObject (readonly)

Indicates whether the goods or services are tax-exempt or tax is not collected.



1885
1886
1887
# File 'lib/stripe/resources/payment_intent.rb', line 1885

def tax_exempt
  @tax_exempt
end

#vehicle_identification_numberObject (readonly)

The vehicle identification number of the car.



1887
1888
1889
# File 'lib/stripe/resources/payment_intent.rb', line 1887

def vehicle_identification_number
  @vehicle_identification_number
end

Class Method Details

.field_remappingsObject



1900
1901
1902
# File 'lib/stripe/resources/payment_intent.rb', line 1900

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1889
1890
1891
1892
1893
1894
1895
1896
1897
1898
# File 'lib/stripe/resources/payment_intent.rb', line 1889

def self.inner_class_types
  @inner_class_types = {
    affiliate: Affiliate,
    delivery: Delivery,
    distance: Distance,
    drivers: Driver,
    pickup_address: PickupAddress,
    return_address: ReturnAddress,
  }
end