Class: Stripe::PaymentIntent::PaymentDetails::CarRentalDatum

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Affiliate, Distance, Driver, DropOff, Insurance, Pickup, Total, Vehicle

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#affiliateObject (readonly)

Attribute for field affiliate



2178
2179
2180
# File 'lib/stripe/resources/payment_intent.rb', line 2178

def affiliate
  @affiliate
end

#booking_numberObject (readonly)

The booking number associated with the car rental.



2180
2181
2182
# File 'lib/stripe/resources/payment_intent.rb', line 2180

def booking_number
  @booking_number
end

#carrier_nameObject (readonly)

The name of the car rental company.



2182
2183
2184
# File 'lib/stripe/resources/payment_intent.rb', line 2182

def carrier_name
  @carrier_name
end

#customer_service_phone_numberObject (readonly)

The customer service phone number of the car rental company.



2184
2185
2186
# File 'lib/stripe/resources/payment_intent.rb', line 2184

def customer_service_phone_number
  @customer_service_phone_number
end

#days_rentedObject (readonly)

Number of days the car is being rented.



2186
2187
2188
# File 'lib/stripe/resources/payment_intent.rb', line 2186

def days_rented
  @days_rented
end

#distanceObject (readonly)

Attribute for field distance



2188
2189
2190
# File 'lib/stripe/resources/payment_intent.rb', line 2188

def distance
  @distance
end

#driversObject (readonly)

The details of the drivers associated with the rental.



2190
2191
2192
# File 'lib/stripe/resources/payment_intent.rb', line 2190

def drivers
  @drivers
end

#drop_offObject (readonly)

Attribute for field drop_off



2192
2193
2194
# File 'lib/stripe/resources/payment_intent.rb', line 2192

def drop_off
  @drop_off
end

#insurancesObject (readonly)

Insurance details for the car rental.



2194
2195
2196
# File 'lib/stripe/resources/payment_intent.rb', line 2194

def insurances
  @insurances
end

#no_show_indicatorObject (readonly)

Indicates if the customer did not keep nor cancel their booking.



2196
2197
2198
# File 'lib/stripe/resources/payment_intent.rb', line 2196

def no_show_indicator
  @no_show_indicator
end

#pickupObject (readonly)

Attribute for field pickup



2198
2199
2200
# File 'lib/stripe/resources/payment_intent.rb', line 2198

def pickup
  @pickup
end

#renter_nameObject (readonly)

Name of the person renting the vehicle.



2200
2201
2202
# File 'lib/stripe/resources/payment_intent.rb', line 2200

def renter_name
  @renter_name
end

#totalObject (readonly)

Attribute for field total



2202
2203
2204
# File 'lib/stripe/resources/payment_intent.rb', line 2202

def total
  @total
end

#vehicleObject (readonly)

Attribute for field vehicle



2204
2205
2206
# File 'lib/stripe/resources/payment_intent.rb', line 2204

def vehicle
  @vehicle
end

Class Method Details

.field_remappingsObject



2219
2220
2221
# File 'lib/stripe/resources/payment_intent.rb', line 2219

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2206
2207
2208
2209
2210
2211
2212
2213
2214
2215
2216
2217
# File 'lib/stripe/resources/payment_intent.rb', line 2206

def self.inner_class_types
  @inner_class_types = {
    affiliate: Affiliate,
    distance: Distance,
    drivers: Driver,
    drop_off: DropOff,
    insurances: Insurance,
    pickup: Pickup,
    total: Total,
    vehicle: Vehicle,
  }
end