Class: Stripe::PaymentIntent::PaymentDetails::EventDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
readonly
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
readonly
Attribute for field address.
-
#affiliate ⇒ Object
readonly
Attribute for field affiliate.
-
#company ⇒ Object
readonly
The name of the company.
-
#delivery ⇒ Object
readonly
Attribute for field delivery.
-
#ends_at ⇒ Object
readonly
Event end time.
-
#genre ⇒ Object
readonly
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
readonly
The name of the event.
-
#starts_at ⇒ Object
readonly
Event start time.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#access_controlled_venue ⇒ Object (readonly)
Indicates if the tickets are digitally checked when entering the venue.
2292 2293 2294 |
# File 'lib/stripe/resources/payment_intent.rb', line 2292 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object (readonly)
Attribute for field address
2294 2295 2296 |
# File 'lib/stripe/resources/payment_intent.rb', line 2294 def address @address end |
#affiliate ⇒ Object (readonly)
Attribute for field affiliate
2296 2297 2298 |
# File 'lib/stripe/resources/payment_intent.rb', line 2296 def affiliate @affiliate end |
#company ⇒ Object (readonly)
The name of the company
2298 2299 2300 |
# File 'lib/stripe/resources/payment_intent.rb', line 2298 def company @company end |
#delivery ⇒ Object (readonly)
Attribute for field delivery
2300 2301 2302 |
# File 'lib/stripe/resources/payment_intent.rb', line 2300 def delivery @delivery end |
#ends_at ⇒ Object (readonly)
Event end time. Measured in seconds since the Unix epoch.
2302 2303 2304 |
# File 'lib/stripe/resources/payment_intent.rb', line 2302 def ends_at @ends_at end |
#genre ⇒ Object (readonly)
Type of the event entertainment (concert, sports event etc)
2304 2305 2306 |
# File 'lib/stripe/resources/payment_intent.rb', line 2304 def genre @genre end |
#name ⇒ Object (readonly)
The name of the event.
2306 2307 2308 |
# File 'lib/stripe/resources/payment_intent.rb', line 2306 def name @name end |
#starts_at ⇒ Object (readonly)
Event start time. Measured in seconds since the Unix epoch.
2308 2309 2310 |
# File 'lib/stripe/resources/payment_intent.rb', line 2308 def starts_at @starts_at end |
Class Method Details
.field_remappings ⇒ Object
2314 2315 2316 |
# File 'lib/stripe/resources/payment_intent.rb', line 2314 def self.field_remappings @field_remappings = {} end |