Class: Stripe::PaymentIntent::PaymentDetails::EventDetails::Delivery::Recipient

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#emailObject (readonly)

The email of the recipient the ticket is delivered to.



1884
1885
1886
# File 'lib/stripe/resources/payment_intent.rb', line 1884

def email
  @email
end

#nameObject (readonly)

The name of the recipient the ticket is delivered to.



1886
1887
1888
# File 'lib/stripe/resources/payment_intent.rb', line 1886

def name
  @name
end

#phoneObject (readonly)

The phone number of the recipient the ticket is delivered to.



1888
1889
1890
# File 'lib/stripe/resources/payment_intent.rb', line 1888

def phone
  @phone
end

Class Method Details

.field_remappingsObject



1894
1895
1896
# File 'lib/stripe/resources/payment_intent.rb', line 1894

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1890
1891
1892
# File 'lib/stripe/resources/payment_intent.rb', line 1890

def self.inner_class_types
  @inner_class_types = {}
end