Class: Stripe::PaymentIntent::PaymentDetails::FlightDatum
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentDetails::FlightDatum
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Affiliate, Insurance, Passenger, Segment, Total
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
readonly
Attribute for field affiliate.
-
#booking_number ⇒ Object
readonly
The booking number associated with the flight reservation.
-
#computerized_reservation_system ⇒ Object
readonly
The computerized reservation system used to make the reservation and purchase the ticket.
-
#endorsements_and_restrictions ⇒ Object
readonly
Ticket restrictions.
-
#insurances ⇒ Object
readonly
Insurance details for the flight.
-
#passengers ⇒ Object
readonly
The list of passengers for this flight.
-
#segments ⇒ Object
readonly
The list of flight segments for this reservation.
-
#ticket_electronically_issued_indicator ⇒ Object
readonly
Electronic ticket indicator.
-
#total ⇒ Object
readonly
Attribute for field total.
-
#transaction_type ⇒ Object
readonly
Type of flight transaction.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#affiliate ⇒ Object (readonly)
Attribute for field affiliate
2516 2517 2518 |
# File 'lib/stripe/resources/payment_intent.rb', line 2516 def affiliate @affiliate end |
#booking_number ⇒ Object (readonly)
The booking number associated with the flight reservation.
2518 2519 2520 |
# File 'lib/stripe/resources/payment_intent.rb', line 2518 def booking_number @booking_number end |
#computerized_reservation_system ⇒ Object (readonly)
The computerized reservation system used to make the reservation and purchase the ticket.
2520 2521 2522 |
# File 'lib/stripe/resources/payment_intent.rb', line 2520 def computerized_reservation_system @computerized_reservation_system end |
#endorsements_and_restrictions ⇒ Object (readonly)
Ticket restrictions.
2522 2523 2524 |
# File 'lib/stripe/resources/payment_intent.rb', line 2522 def endorsements_and_restrictions @endorsements_and_restrictions end |
#insurances ⇒ Object (readonly)
Insurance details for the flight.
2524 2525 2526 |
# File 'lib/stripe/resources/payment_intent.rb', line 2524 def insurances @insurances end |
#passengers ⇒ Object (readonly)
The list of passengers for this flight.
2526 2527 2528 |
# File 'lib/stripe/resources/payment_intent.rb', line 2526 def passengers @passengers end |
#segments ⇒ Object (readonly)
The list of flight segments for this reservation.
2528 2529 2530 |
# File 'lib/stripe/resources/payment_intent.rb', line 2528 def segments @segments end |
#ticket_electronically_issued_indicator ⇒ Object (readonly)
Electronic ticket indicator.
2530 2531 2532 |
# File 'lib/stripe/resources/payment_intent.rb', line 2530 def ticket_electronically_issued_indicator @ticket_electronically_issued_indicator end |
#total ⇒ Object (readonly)
Attribute for field total
2532 2533 2534 |
# File 'lib/stripe/resources/payment_intent.rb', line 2532 def total @total end |
#transaction_type ⇒ Object (readonly)
Type of flight transaction.
2534 2535 2536 |
# File 'lib/stripe/resources/payment_intent.rb', line 2534 def transaction_type @transaction_type end |
Class Method Details
.field_remappings ⇒ Object
2546 2547 2548 |
# File 'lib/stripe/resources/payment_intent.rb', line 2546 def self.field_remappings @field_remappings = {} end |