Class: Stripe::PaymentIntent::PaymentDetails::FlightDatum::Affiliate
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentDetails::FlightDatum::Affiliate
- Defined in:
- lib/stripe/resources/payment_intent.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#code ⇒ Object
readonly
Affiliate code.
-
#name ⇒ Object
readonly
Affiliate name.
-
#travel_authorization_code ⇒ Object
readonly
Code provided by the company to a travel agent authorizing ticket issuance.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#code ⇒ Object (readonly)
Affiliate code.
1942 1943 1944 |
# File 'lib/stripe/resources/payment_intent.rb', line 1942 def code @code end |
#name ⇒ Object (readonly)
Affiliate name.
1944 1945 1946 |
# File 'lib/stripe/resources/payment_intent.rb', line 1944 def name @name end |
#travel_authorization_code ⇒ Object (readonly)
Code provided by the company to a travel agent authorizing ticket issuance.
1946 1947 1948 |
# File 'lib/stripe/resources/payment_intent.rb', line 1946 def @travel_authorization_code end |
Class Method Details
.field_remappings ⇒ Object
1952 1953 1954 |
# File 'lib/stripe/resources/payment_intent.rb', line 1952 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1948 1949 1950 |
# File 'lib/stripe/resources/payment_intent.rb', line 1948 def self.inner_class_types @inner_class_types = {} end |