Class: Stripe::PaymentIntent::PaymentDetails::LodgingDatum
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentDetails::LodgingDatum
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Accommodation, Affiliate, Guest, Host, Insurance, Total
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#accommodation ⇒ Object
readonly
Attribute for field accommodation.
-
#affiliate ⇒ Object
readonly
Attribute for field affiliate.
-
#booking_number ⇒ Object
readonly
Booking confirmation number for the lodging.
-
#checkin_at ⇒ Object
readonly
Check-in date.
-
#checkout_at ⇒ Object
readonly
Check-out date.
-
#customer_service_phone_number ⇒ Object
readonly
Customer service phone number for the lodging company.
-
#fire_safety_act_compliance_indicator ⇒ Object
readonly
Whether the lodging is compliant with any hotel fire safety regulations.
-
#guests ⇒ Object
readonly
List of guests for the lodging.
-
#host ⇒ Object
readonly
Attribute for field host.
-
#insurances ⇒ Object
readonly
List of insurances for the lodging.
-
#no_show_indicator ⇒ Object
readonly
Whether the renter is a no-show.
-
#renter_id_number ⇒ Object
readonly
Renter ID number for the lodging.
-
#renter_name ⇒ Object
readonly
Renter name for the lodging.
-
#total ⇒ Object
readonly
Attribute for field total.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#accommodation ⇒ Object (readonly)
Attribute for field accommodation
2855 2856 2857 |
# File 'lib/stripe/resources/payment_intent.rb', line 2855 def accommodation @accommodation end |
#affiliate ⇒ Object (readonly)
Attribute for field affiliate
2857 2858 2859 |
# File 'lib/stripe/resources/payment_intent.rb', line 2857 def affiliate @affiliate end |
#booking_number ⇒ Object (readonly)
Booking confirmation number for the lodging.
2859 2860 2861 |
# File 'lib/stripe/resources/payment_intent.rb', line 2859 def booking_number @booking_number end |
#checkin_at ⇒ Object (readonly)
Check-in date.
2861 2862 2863 |
# File 'lib/stripe/resources/payment_intent.rb', line 2861 def checkin_at @checkin_at end |
#checkout_at ⇒ Object (readonly)
Check-out date.
2863 2864 2865 |
# File 'lib/stripe/resources/payment_intent.rb', line 2863 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object (readonly)
Customer service phone number for the lodging company.
2865 2866 2867 |
# File 'lib/stripe/resources/payment_intent.rb', line 2865 def customer_service_phone_number @customer_service_phone_number end |
#fire_safety_act_compliance_indicator ⇒ Object (readonly)
Whether the lodging is compliant with any hotel fire safety regulations.
2867 2868 2869 |
# File 'lib/stripe/resources/payment_intent.rb', line 2867 def fire_safety_act_compliance_indicator @fire_safety_act_compliance_indicator end |
#guests ⇒ Object (readonly)
List of guests for the lodging.
2869 2870 2871 |
# File 'lib/stripe/resources/payment_intent.rb', line 2869 def guests @guests end |
#host ⇒ Object (readonly)
Attribute for field host
2871 2872 2873 |
# File 'lib/stripe/resources/payment_intent.rb', line 2871 def host @host end |
#insurances ⇒ Object (readonly)
List of insurances for the lodging.
2873 2874 2875 |
# File 'lib/stripe/resources/payment_intent.rb', line 2873 def insurances @insurances end |
#no_show_indicator ⇒ Object (readonly)
Whether the renter is a no-show.
2875 2876 2877 |
# File 'lib/stripe/resources/payment_intent.rb', line 2875 def no_show_indicator @no_show_indicator end |
#renter_id_number ⇒ Object (readonly)
Renter ID number for the lodging.
2877 2878 2879 |
# File 'lib/stripe/resources/payment_intent.rb', line 2877 def renter_id_number @renter_id_number end |
#renter_name ⇒ Object (readonly)
Renter name for the lodging.
2879 2880 2881 |
# File 'lib/stripe/resources/payment_intent.rb', line 2879 def renter_name @renter_name end |
#total ⇒ Object (readonly)
Attribute for field total
2881 2882 2883 |
# File 'lib/stripe/resources/payment_intent.rb', line 2881 def total @total end |
Class Method Details
.field_remappings ⇒ Object
2894 2895 2896 |
# File 'lib/stripe/resources/payment_intent.rb', line 2894 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 |
# File 'lib/stripe/resources/payment_intent.rb', line 2883 def self.inner_class_types @inner_class_types = { accommodation: Accommodation, affiliate: Affiliate, guests: Guest, host: Host, insurances: Insurance, total: Total, } end |