Class: Stripe::PaymentIntent::PaymentDetails::MoneyServices::AccountFunding

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: BeneficiaryDetails, SenderDetails

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#beneficiary_accountObject (readonly)

ID of the Account representing the beneficiary in this account funding transaction.



2924
2925
2926
# File 'lib/stripe/resources/payment_intent.rb', line 2924

def 
  @beneficiary_account
end

#beneficiary_detailsObject (readonly)

Attribute for field beneficiary_details



2926
2927
2928
# File 'lib/stripe/resources/payment_intent.rb', line 2926

def beneficiary_details
  @beneficiary_details
end

#sender_accountObject (readonly)

ID of the Account representing the sender in this account funding transaction.



2928
2929
2930
# File 'lib/stripe/resources/payment_intent.rb', line 2928

def 
  @sender_account
end

#sender_detailsObject (readonly)

Attribute for field sender_details



2930
2931
2932
# File 'lib/stripe/resources/payment_intent.rb', line 2930

def sender_details
  @sender_details
end

Class Method Details

.field_remappingsObject



2939
2940
2941
# File 'lib/stripe/resources/payment_intent.rb', line 2939

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2932
2933
2934
2935
2936
2937
# File 'lib/stripe/resources/payment_intent.rb', line 2932

def self.inner_class_types
  @inner_class_types = {
    beneficiary_details: BeneficiaryDetails,
    sender_details: SenderDetails,
  }
end