Class: Stripe::PaymentIntent::PaymentDetails::Subscription
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentDetails::Subscription
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Affiliate, BillingInterval
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
readonly
Attribute for field affiliate.
-
#auto_renewal ⇒ Object
readonly
Info whether the subscription will be auto renewed upon expiry.
-
#billing_interval ⇒ Object
readonly
Attribute for field billing_interval.
-
#ends_at ⇒ Object
readonly
Subscription end time.
-
#name ⇒ Object
readonly
Name of the product on subscription.
-
#starts_at ⇒ Object
readonly
Subscription start time.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#affiliate ⇒ Object (readonly)
Attribute for field affiliate
3087 3088 3089 |
# File 'lib/stripe/resources/payment_intent.rb', line 3087 def affiliate @affiliate end |
#auto_renewal ⇒ Object (readonly)
Info whether the subscription will be auto renewed upon expiry.
3089 3090 3091 |
# File 'lib/stripe/resources/payment_intent.rb', line 3089 def auto_renewal @auto_renewal end |
#billing_interval ⇒ Object (readonly)
Attribute for field billing_interval
3091 3092 3093 |
# File 'lib/stripe/resources/payment_intent.rb', line 3091 def billing_interval @billing_interval end |
#ends_at ⇒ Object (readonly)
Subscription end time. Measured in seconds since the Unix epoch.
3093 3094 3095 |
# File 'lib/stripe/resources/payment_intent.rb', line 3093 def ends_at @ends_at end |
#name ⇒ Object (readonly)
Name of the product on subscription. e.g. Apple Music Subscription.
3095 3096 3097 |
# File 'lib/stripe/resources/payment_intent.rb', line 3095 def name @name end |
#starts_at ⇒ Object (readonly)
Subscription start time. Measured in seconds since the Unix epoch.
3097 3098 3099 |
# File 'lib/stripe/resources/payment_intent.rb', line 3097 def starts_at @starts_at end |
Class Method Details
.field_remappings ⇒ Object
3103 3104 3105 |
# File 'lib/stripe/resources/payment_intent.rb', line 3103 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
3099 3100 3101 |
# File 'lib/stripe/resources/payment_intent.rb', line 3099 def self.inner_class_types @inner_class_types = { affiliate: Affiliate, billing_interval: BillingInterval } end |