Class: Stripe::PaymentIntent::PaymentDetails::Subscription::BillingInterval

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#countObject (readonly)

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



1561
1562
1563
# File 'lib/stripe/resources/payment_intent.rb', line 1561

def count
  @count
end

#intervalObject (readonly)

Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.



1563
1564
1565
# File 'lib/stripe/resources/payment_intent.rb', line 1563

def interval
  @interval
end

Class Method Details

.field_remappingsObject



1569
1570
1571
# File 'lib/stripe/resources/payment_intent.rb', line 1569

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1565
1566
1567
# File 'lib/stripe/resources/payment_intent.rb', line 1565

def self.inner_class_types
  @inner_class_types = {}
end