Class: Stripe::PaymentIntent::PaymentMethodOptions::Card::Installments
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentMethodOptions::Card::Installments
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: AvailablePlan, Plan
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#available_plans ⇒ Object
readonly
Installment plans that may be selected for this PaymentIntent.
-
#enabled ⇒ Object
readonly
Whether Installments are enabled for this PaymentIntent.
-
#plan ⇒ Object
readonly
Installment plan selected for this PaymentIntent.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#available_plans ⇒ Object (readonly)
Installment plans that may be selected for this PaymentIntent.
2845 2846 2847 |
# File 'lib/stripe/resources/payment_intent.rb', line 2845 def available_plans @available_plans end |
#enabled ⇒ Object (readonly)
Whether Installments are enabled for this PaymentIntent.
2847 2848 2849 |
# File 'lib/stripe/resources/payment_intent.rb', line 2847 def enabled @enabled end |
#plan ⇒ Object (readonly)
Installment plan selected for this PaymentIntent.
2849 2850 2851 |
# File 'lib/stripe/resources/payment_intent.rb', line 2849 def plan @plan end |
Class Method Details
.field_remappings ⇒ Object
2855 2856 2857 |
# File 'lib/stripe/resources/payment_intent.rb', line 2855 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2851 2852 2853 |
# File 'lib/stripe/resources/payment_intent.rb', line 2851 def self.inner_class_types @inner_class_types = { available_plans: AvailablePlan, plan: Plan } end |