Class: Stripe::PaymentIntent::PaymentMethodOptions::Card::Installments::Plan

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#countObject (readonly)

For ‘fixed_count` installment plans, this is the number of installment payments your customer will make to their credit card.



3056
3057
3058
# File 'lib/stripe/resources/payment_intent.rb', line 3056

def count
  @count
end

#intervalObject (readonly)

For ‘fixed_count` installment plans, this is the interval between installment payments your customer will make to their credit card. One of `month`.



3059
3060
3061
# File 'lib/stripe/resources/payment_intent.rb', line 3059

def interval
  @interval
end

#typeObject (readonly)

Type of installment plan, one of ‘fixed_count`, `bonus`, or `revolving`.



3061
3062
3063
# File 'lib/stripe/resources/payment_intent.rb', line 3061

def type
  @type
end

Class Method Details

.field_remappingsObject



3067
3068
3069
# File 'lib/stripe/resources/payment_intent.rb', line 3067

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



3063
3064
3065
# File 'lib/stripe/resources/payment_intent.rb', line 3063

def self.inner_class_types
  @inner_class_types = {}
end