Class: Stripe::PaymentIntent::PaymentMethodOptions::CardPresent

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Routing

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#capture_method ⇒ Object (readonly)

Controls when the funds will be captured from the customer's account.



1807
1808
1809
# File 'lib/stripe/resources/payment_intent.rb', line 1807

def capture_method
  @capture_method
end

#request_extended_authorization ⇒ Object (readonly)

Request ability to capture this payment beyond the standard authorization validity window



1809
1810
1811
# File 'lib/stripe/resources/payment_intent.rb', line 1809

def request_extended_authorization
  @request_extended_authorization
end

#request_incremental_authorization_support ⇒ Object (readonly)

Request ability to increment this PaymentIntent if the combination of MCC and card brand is eligible. Check incremental_authorization_supported in the Confirm response to verify support.



1811
1812
1813
# File 'lib/stripe/resources/payment_intent.rb', line 1811

def request_incremental_authorization_support
  @request_incremental_authorization_support
end

#routing ⇒ Object (readonly)

Attribute for field routing



1813
1814
1815
# File 'lib/stripe/resources/payment_intent.rb', line 1813

def routing
  @routing
end

Class Method Details

.field_remappings ⇒ Object



1819
1820
1821
# File 'lib/stripe/resources/payment_intent.rb', line 1819

def self.field_remappings
  @field_remappings = {}
end

.inner_class_types ⇒ Object



1815
1816
1817
# File 'lib/stripe/resources/payment_intent.rb', line 1815

def self.inner_class_types
  @inner_class_types = { routing: Routing }
end