Class: Stripe::PaymentIntent::PaymentMethodOptions::CardPresent::AadeData
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentMethodOptions::CardPresent::AadeData
- Defined in:
- lib/stripe/resources/payment_intent.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#mark_data ⇒ Object
readonly
The canonical string that was signed by the e-invoicing provider to produce
signed_mark, formatted per Appendix A of A.1155/2023. -
#mode ⇒ Object
readonly
The e-invoicing mode under which the mark was generated.
-
#provider_id ⇒ Object
readonly
The AADE-assigned approval number of the e-invoicing provider that generated the mark.
-
#signed_mark ⇒ Object
readonly
The cryptographic signature returned by the e-invoicing provider for this transaction, hex-encoded.
-
#unbound_pos ⇒ Object
readonly
The reason for entering autonomous mode.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#mark_data ⇒ Object (readonly)
The canonical string that was signed by the e-invoicing provider to produce signed_mark, formatted per Appendix A of A.1155/2023. Required when mode is standard.
3657 3658 3659 |
# File 'lib/stripe/resources/payment_intent.rb', line 3657 def mark_data @mark_data end |
#mode ⇒ Object (readonly)
The e-invoicing mode under which the mark was generated.
3659 3660 3661 |
# File 'lib/stripe/resources/payment_intent.rb', line 3659 def mode @mode end |
#provider_id ⇒ Object (readonly)
The AADE-assigned approval number of the e-invoicing provider that generated the mark. Required when mode is standard.
3661 3662 3663 |
# File 'lib/stripe/resources/payment_intent.rb', line 3661 def provider_id @provider_id end |
#signed_mark ⇒ Object (readonly)
The cryptographic signature returned by the e-invoicing provider for this transaction, hex-encoded. Required when mode is standard.
3663 3664 3665 |
# File 'lib/stripe/resources/payment_intent.rb', line 3663 def signed_mark @signed_mark end |
#unbound_pos ⇒ Object (readonly)
The reason for entering autonomous mode. Required when mode is autonomous.
3665 3666 3667 |
# File 'lib/stripe/resources/payment_intent.rb', line 3665 def unbound_pos @unbound_pos end |
Class Method Details
.field_remappings ⇒ Object
3671 3672 3673 |
# File 'lib/stripe/resources/payment_intent.rb', line 3671 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
3667 3668 3669 |
# File 'lib/stripe/resources/payment_intent.rb', line 3667 def self.inner_class_types @inner_class_types = {} end |