Class: Stripe::PaymentIntent::PaymentMethodOptions::CustomerBalance::BankTransfer

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: EuBankTransfer

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#eu_bank_transferObject (readonly)

Attribute for field eu_bank_transfer



2174
2175
2176
# File 'lib/stripe/resources/payment_intent.rb', line 2174

def eu_bank_transfer
  @eu_bank_transfer
end

#requested_address_typesObject (readonly)

List of address types that should be returned in the financial_addresses response. If not specified, all valid types will be returned.

Permitted values include: ‘sort_code`, `zengin`, `iban`, or `spei`.



2178
2179
2180
# File 'lib/stripe/resources/payment_intent.rb', line 2178

def requested_address_types
  @requested_address_types
end

#typeObject (readonly)

The bank transfer type that this PaymentIntent is allowed to use for funding Permitted values include: ‘eu_bank_transfer`, `gb_bank_transfer`, `jp_bank_transfer`, `mx_bank_transfer`, or `us_bank_transfer`.



2180
2181
2182
# File 'lib/stripe/resources/payment_intent.rb', line 2180

def type
  @type
end

Class Method Details

.field_remappingsObject



2186
2187
2188
# File 'lib/stripe/resources/payment_intent.rb', line 2186

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2182
2183
2184
# File 'lib/stripe/resources/payment_intent.rb', line 2182

def self.inner_class_types
  @inner_class_types = { eu_bank_transfer: EuBankTransfer }
end