Class: Stripe::PaymentIntent::PaymentMethodOptions::CustomerBalance::BankTransfer::EuBankTransfer
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentMethodOptions::CustomerBalance::BankTransfer::EuBankTransfer
- Defined in:
- lib/stripe/resources/payment_intent.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#country ⇒ Object
readonly
The desired country code of the bank account information.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#country ⇒ Object (readonly)
The desired country code of the bank account information. Permitted values include: ‘DE`, `FR`, `IE`, or `NL`.
3054 3055 3056 |
# File 'lib/stripe/resources/payment_intent.rb', line 3054 def country @country end |
Class Method Details
.field_remappings ⇒ Object
3060 3061 3062 |
# File 'lib/stripe/resources/payment_intent.rb', line 3060 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
3056 3057 3058 |
# File 'lib/stripe/resources/payment_intent.rb', line 3056 def self.inner_class_types @inner_class_types = {} end |