Class: Stripe::PaymentIntent::PaymentMethodOptions::IdBankTransfer

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#expires_afterObject (readonly)

The UNIX timestamp until which the virtual bank account is valid. Permitted range is from now till 2678400 seconds (31 days) from now.



3998
3999
4000
# File 'lib/stripe/resources/payment_intent.rb', line 3998

def expires_after
  @expires_after
end

#expires_atObject (readonly)

The UNIX timestamp until which the virtual bank account is valid. Permitted range is from now until 30 days from now. If unset, it defaults to 1 days from now.



4000
4001
4002
# File 'lib/stripe/resources/payment_intent.rb', line 4000

def expires_at
  @expires_at
end

#setup_future_usageObject (readonly)

Indicates that you intend to make future payments with this PaymentIntent's payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.

If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.

When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.



4008
4009
4010
# File 'lib/stripe/resources/payment_intent.rb', line 4008

def setup_future_usage
  @setup_future_usage
end

Class Method Details

.field_remappingsObject



4014
4015
4016
# File 'lib/stripe/resources/payment_intent.rb', line 4014

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



4010
4011
4012
# File 'lib/stripe/resources/payment_intent.rb', line 4010

def self.inner_class_types
  @inner_class_types = {}
end