Class: Stripe::PaymentIntent::PaymentMethodOptions::Oxxo
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentMethodOptions::Oxxo
- Defined in:
- lib/stripe/resources/payment_intent.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#expires_after_days ⇒ Object
readonly
The number of calendar days before an OXXO invoice expires.
-
#setup_future_usage ⇒ Object
readonly
Indicates that you intend to make future payments with this PaymentIntent's payment method.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#expires_after_days ⇒ Object (readonly)
The number of calendar days before an OXXO invoice expires. For example, if you create an OXXO invoice on Monday and you set expires_after_days to 2, the OXXO invoice will expire on Wednesday at 23:59 America/Mexico_City time.
4266 4267 4268 |
# File 'lib/stripe/resources/payment_intent.rb', line 4266 def expires_after_days @expires_after_days end |
#setup_future_usage ⇒ Object (readonly)
Indicates that you intend to make future payments with this PaymentIntent's payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.
If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.
When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.
4274 4275 4276 |
# File 'lib/stripe/resources/payment_intent.rb', line 4274 def setup_future_usage @setup_future_usage end |
Class Method Details
.field_remappings ⇒ Object
4280 4281 4282 |
# File 'lib/stripe/resources/payment_intent.rb', line 4280 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
4276 4277 4278 |
# File 'lib/stripe/resources/payment_intent.rb', line 4276 def self.inner_class_types @inner_class_types = {} end |