Class: Stripe::PaymentIntent::PaymentMethodOptions::Paypal

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: LineItem

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#capture_methodObject (readonly)

Controls when the funds will be captured from the customer's account.



4396
4397
4398
# File 'lib/stripe/resources/payment_intent.rb', line 4396

def capture_method
  @capture_method
end

#line_itemsObject (readonly)

The line items purchased by the customer.



4398
4399
4400
# File 'lib/stripe/resources/payment_intent.rb', line 4398

def line_items
  @line_items
end

#preferred_localeObject (readonly)

Preferred locale of the PayPal checkout page that the customer is redirected to.



4400
4401
4402
# File 'lib/stripe/resources/payment_intent.rb', line 4400

def preferred_locale
  @preferred_locale
end

#referenceObject (readonly)

A reference of the PayPal transaction visible to customer which is mapped to PayPal's invoice ID. This must be a globally unique ID if you have configured in your PayPal settings to block multiple payments per invoice ID.



4402
4403
4404
# File 'lib/stripe/resources/payment_intent.rb', line 4402

def reference
  @reference
end

#reference_idObject (readonly)

A reference of the PayPal transaction visible to customer which is mapped to PayPal's invoice ID. This must be a globally unique ID if you have configured in your PayPal settings to block multiple payments per invoice ID.



4404
4405
4406
# File 'lib/stripe/resources/payment_intent.rb', line 4404

def reference_id
  @reference_id
end

#setup_future_usageObject (readonly)

Indicates that you intend to make future payments with this PaymentIntent's payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.

If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.

When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.



4412
4413
4414
# File 'lib/stripe/resources/payment_intent.rb', line 4412

def setup_future_usage
  @setup_future_usage
end

#subsellersObject (readonly)

The Stripe connected account IDs of the sellers on the platform for this transaction (optional). Only allowed when separate charges and transfers are used.



4414
4415
4416
# File 'lib/stripe/resources/payment_intent.rb', line 4414

def subsellers
  @subsellers
end

Class Method Details

.field_remappingsObject



4420
4421
4422
# File 'lib/stripe/resources/payment_intent.rb', line 4420

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



4416
4417
4418
# File 'lib/stripe/resources/payment_intent.rb', line 4416

def self.inner_class_types
  @inner_class_types = { line_items: LineItem }
end