Class: Stripe::PaymentIntent::PaymentMethodOptions::Paypal::LineItem

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Tax

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#categoryObject (readonly)

Type of the line item.



3596
3597
3598
# File 'lib/stripe/resources/payment_intent.rb', line 3596

def category
  @category
end

#descriptionObject (readonly)

Description of the line item.



3598
3599
3600
# File 'lib/stripe/resources/payment_intent.rb', line 3598

def description
  @description
end

#nameObject (readonly)

Descriptive name of the line item.



3600
3601
3602
# File 'lib/stripe/resources/payment_intent.rb', line 3600

def name
  @name
end

#quantityObject (readonly)

Quantity of the line item. Cannot be a negative number.



3602
3603
3604
# File 'lib/stripe/resources/payment_intent.rb', line 3602

def quantity
  @quantity
end

#skuObject (readonly)

Client facing stock keeping unit, article number or similar.



3604
3605
3606
# File 'lib/stripe/resources/payment_intent.rb', line 3604

def sku
  @sku
end

#sold_byObject (readonly)

The Stripe account ID of the connected account that sells the item. This is only needed when using Separate Charges and Transfers.



3606
3607
3608
# File 'lib/stripe/resources/payment_intent.rb', line 3606

def sold_by
  @sold_by
end

#taxObject (readonly)

Attribute for field tax



3608
3609
3610
# File 'lib/stripe/resources/payment_intent.rb', line 3608

def tax
  @tax
end

#unit_amountObject (readonly)

Price for a single unit of the line item in minor units. Cannot be a negative number.



3610
3611
3612
# File 'lib/stripe/resources/payment_intent.rb', line 3610

def unit_amount
  @unit_amount
end

Class Method Details

.field_remappingsObject



3616
3617
3618
# File 'lib/stripe/resources/payment_intent.rb', line 3616

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



3612
3613
3614
# File 'lib/stripe/resources/payment_intent.rb', line 3612

def self.inner_class_types
  @inner_class_types = { tax: Tax }
end