Class: Stripe::PaymentIntent::PaymentMethodOptions::Paypal::LineItem::Tax
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentMethodOptions::Paypal::LineItem::Tax
- Defined in:
- lib/stripe/resources/payment_intent.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The tax for a single unit of the line item in minor units.
-
#behavior ⇒ Object
readonly
The tax behavior for the line item.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The tax for a single unit of the line item in minor units. Cannot be a negative number.
4135 4136 4137 |
# File 'lib/stripe/resources/payment_intent.rb', line 4135 def amount @amount end |
#behavior ⇒ Object (readonly)
The tax behavior for the line item.
4137 4138 4139 |
# File 'lib/stripe/resources/payment_intent.rb', line 4137 def behavior @behavior end |
Class Method Details
.field_remappings ⇒ Object
4143 4144 4145 |
# File 'lib/stripe/resources/payment_intent.rb', line 4143 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
4139 4140 4141 |
# File 'lib/stripe/resources/payment_intent.rb', line 4139 def self.inner_class_types @inner_class_types = {} end |