Class: Stripe::PaymentIntent::PaymentMethodOptions::Pix

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: MandateOptions

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amount_includes_iofObject (readonly)

Determines if the amount includes the IOF tax.



4515
4516
4517
# File 'lib/stripe/resources/payment_intent.rb', line 4515

def amount_includes_iof
  @amount_includes_iof
end

#expires_after_secondsObject (readonly)

The number of seconds (between 10 and 1209600) after which Pix payment will expire.



4517
4518
4519
# File 'lib/stripe/resources/payment_intent.rb', line 4517

def expires_after_seconds
  @expires_after_seconds
end

#expires_atObject (readonly)

The timestamp at which the Pix expires.



4519
4520
4521
# File 'lib/stripe/resources/payment_intent.rb', line 4519

def expires_at
  @expires_at
end

#mandate_optionsObject (readonly)

Attribute for field mandate_options



4521
4522
4523
# File 'lib/stripe/resources/payment_intent.rb', line 4521

def mandate_options
  @mandate_options
end

#setup_future_usageObject (readonly)

Indicates that you intend to make future payments with this PaymentIntent's payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.

If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.

When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.



4529
4530
4531
# File 'lib/stripe/resources/payment_intent.rb', line 4529

def setup_future_usage
  @setup_future_usage
end

Class Method Details

.field_remappingsObject



4535
4536
4537
# File 'lib/stripe/resources/payment_intent.rb', line 4535

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



4531
4532
4533
# File 'lib/stripe/resources/payment_intent.rb', line 4531

def self.inner_class_types
  @inner_class_types = { mandate_options: MandateOptions }
end