Class: Stripe::PaymentIntent::PaymentMethodOptions::Pix::MandateOptions
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentMethodOptions::Pix::MandateOptions
- Defined in:
- lib/stripe/resources/payment_intent.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
Amount to be charged for future payments.
-
#amount_includes_iof ⇒ Object
readonly
Determines if the amount includes the IOF tax.
-
#amount_type ⇒ Object
readonly
Type of amount.
-
#currency ⇒ Object
readonly
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#end_date ⇒ Object
readonly
Date when the mandate expires and no further payments will be charged, in ‘YYYY-MM-DD`.
-
#payment_schedule ⇒ Object
readonly
Schedule at which the future payments will be charged.
-
#reference ⇒ Object
readonly
Subscription name displayed to buyers in their bank app.
-
#start_date ⇒ Object
readonly
Start date of the mandate, in ‘YYYY-MM-DD`.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
Amount to be charged for future payments.
4258 4259 4260 |
# File 'lib/stripe/resources/payment_intent.rb', line 4258 def amount @amount end |
#amount_includes_iof ⇒ Object (readonly)
Determines if the amount includes the IOF tax.
4260 4261 4262 |
# File 'lib/stripe/resources/payment_intent.rb', line 4260 def amount_includes_iof @amount_includes_iof end |
#amount_type ⇒ Object (readonly)
Type of amount.
4262 4263 4264 |
# File 'lib/stripe/resources/payment_intent.rb', line 4262 def amount_type @amount_type end |
#currency ⇒ Object (readonly)
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
4264 4265 4266 |
# File 'lib/stripe/resources/payment_intent.rb', line 4264 def currency @currency end |
#end_date ⇒ Object (readonly)
Date when the mandate expires and no further payments will be charged, in ‘YYYY-MM-DD`.
4266 4267 4268 |
# File 'lib/stripe/resources/payment_intent.rb', line 4266 def end_date @end_date end |
#payment_schedule ⇒ Object (readonly)
Schedule at which the future payments will be charged.
4268 4269 4270 |
# File 'lib/stripe/resources/payment_intent.rb', line 4268 def payment_schedule @payment_schedule end |
#reference ⇒ Object (readonly)
Subscription name displayed to buyers in their bank app.
4270 4271 4272 |
# File 'lib/stripe/resources/payment_intent.rb', line 4270 def reference @reference end |
#start_date ⇒ Object (readonly)
Start date of the mandate, in ‘YYYY-MM-DD`.
4272 4273 4274 |
# File 'lib/stripe/resources/payment_intent.rb', line 4272 def start_date @start_date end |
Class Method Details
.field_remappings ⇒ Object
4278 4279 4280 |
# File 'lib/stripe/resources/payment_intent.rb', line 4278 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
4274 4275 4276 |
# File 'lib/stripe/resources/payment_intent.rb', line 4274 def self.inner_class_types @inner_class_types = {} end |