Class: Stripe::PaymentIntent::PaymentMethodOptions::UsBankAccount::FinancialConnections
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentMethodOptions::UsBankAccount::FinancialConnections
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Filters
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#filters ⇒ Object
readonly
Attribute for field filters.
-
#permissions ⇒ Object
readonly
The list of permissions to request.
-
#prefetch ⇒ Object
readonly
Data features requested to be retrieved upon account creation.
-
#return_url ⇒ Object
readonly
For webview integrations only.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#filters ⇒ Object (readonly)
Attribute for field filters
2631 2632 2633 |
# File 'lib/stripe/resources/payment_intent.rb', line 2631 def filters @filters end |
#permissions ⇒ Object (readonly)
The list of permissions to request. The payment_method permission must be included.
2633 2634 2635 |
# File 'lib/stripe/resources/payment_intent.rb', line 2633 def @permissions end |
#prefetch ⇒ Object (readonly)
Data features requested to be retrieved upon account creation.
2635 2636 2637 |
# File 'lib/stripe/resources/payment_intent.rb', line 2635 def prefetch @prefetch end |
#return_url ⇒ Object (readonly)
For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.
2637 2638 2639 |
# File 'lib/stripe/resources/payment_intent.rb', line 2637 def return_url @return_url end |
Class Method Details
.field_remappings ⇒ Object
2643 2644 2645 |
# File 'lib/stripe/resources/payment_intent.rb', line 2643 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2639 2640 2641 |
# File 'lib/stripe/resources/payment_intent.rb', line 2639 def self.inner_class_types @inner_class_types = { filters: Filters } end |