Class: Stripe::PaymentIntent::PaymentMethodOptions::Vipps::PaymentDetails::MoneyServices::AccountFunding
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentMethodOptions::Vipps::PaymentDetails::MoneyServices::AccountFunding
- Defined in:
- lib/stripe/resources/payment_intent.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#digital_asset_category ⇒ Object
readonly
The category of digital asset being acquired through this account funding transaction.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#digital_asset_category ⇒ Object (readonly)
The category of digital asset being acquired through this account funding transaction.
4970 4971 4972 |
# File 'lib/stripe/resources/payment_intent.rb', line 4970 def digital_asset_category @digital_asset_category end |
Class Method Details
.field_remappings ⇒ Object
4976 4977 4978 |
# File 'lib/stripe/resources/payment_intent.rb', line 4976 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
4972 4973 4974 |
# File 'lib/stripe/resources/payment_intent.rb', line 4972 def self.inner_class_types @inner_class_types = {} end |