Class: Stripe::PaymentIntent::Processing
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::Processing
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Card
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#card ⇒ Object
readonly
Attribute for field card.
-
#type ⇒ Object
readonly
Type of the payment method for which payment is in ‘processing` state, one of `card`.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#card ⇒ Object (readonly)
Attribute for field card
4382 4383 4384 |
# File 'lib/stripe/resources/payment_intent.rb', line 4382 def card @card end |
#type ⇒ Object (readonly)
Type of the payment method for which payment is in ‘processing` state, one of `card`.
4384 4385 4386 |
# File 'lib/stripe/resources/payment_intent.rb', line 4384 def type @type end |
Class Method Details
.field_remappings ⇒ Object
4390 4391 4392 |
# File 'lib/stripe/resources/payment_intent.rb', line 4390 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
4386 4387 4388 |
# File 'lib/stripe/resources/payment_intent.rb', line 4386 def self.inner_class_types @inner_class_types = { card: Card } end |