Class: Stripe::PaymentIntent::RetrieveParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(client_secret: nil, expand: nil) ⇒ RetrieveParams

Returns a new instance of RetrieveParams.



5297
5298
5299
5300
# File 'lib/stripe/resources/payment_intent.rb', line 5297

def initialize(client_secret: nil, expand: nil)
  @client_secret = client_secret
  @expand = expand
end

Instance Attribute Details

#client_secretObject

The client secret of the PaymentIntent. We require it if you use a publishable key to retrieve the source.



5293
5294
5295
# File 'lib/stripe/resources/payment_intent.rb', line 5293

def client_secret
  @client_secret
end

#expandObject

Specifies which fields in the response should be expanded.



5295
5296
5297
# File 'lib/stripe/resources/payment_intent.rb', line 5295

def expand
  @expand
end