Class: Stripe::PaymentIntent::SearchParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, limit: nil, page: nil, query: nil) ⇒ SearchParams

Returns a new instance of SearchParams.



9634
9635
9636
9637
9638
9639
# File 'lib/stripe/resources/payment_intent.rb', line 9634

def initialize(expand: nil, limit: nil, page: nil, query: nil)
  @expand = expand
  @limit = limit
  @page = page
  @query = query
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



9626
9627
9628
# File 'lib/stripe/resources/payment_intent.rb', line 9626

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



9628
9629
9630
# File 'lib/stripe/resources/payment_intent.rb', line 9628

def limit
  @limit
end

#pageObject

A cursor for pagination across multiple pages of results. Don’t include this parameter on the first call. Use the next_page value returned in a previous response to request subsequent results.



9630
9631
9632
# File 'lib/stripe/resources/payment_intent.rb', line 9630

def page
  @page
end

#queryObject

The search query string. See [search query language](stripe.com/docs/search#search-query-language) and the list of supported [query fields for payment intents](stripe.com/docs/search#query-fields-for-payment-intents).



9632
9633
9634
# File 'lib/stripe/resources/payment_intent.rb', line 9632

def query
  @query
end