Class: Stripe::PaymentIntent::Shipping

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Address

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#address ⇒ Object (readonly)

Attribute for field address



3092
3093
3094
# File 'lib/stripe/resources/payment_intent.rb', line 3092

def address
  @address
end

#carrier ⇒ Object (readonly)

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



3094
3095
3096
# File 'lib/stripe/resources/payment_intent.rb', line 3094

def carrier
  @carrier
end

#name ⇒ Object (readonly)

Recipient name.



3096
3097
3098
# File 'lib/stripe/resources/payment_intent.rb', line 3096

def name
  @name
end

#phone ⇒ Object (readonly)

Recipient phone (including extension).



3098
3099
3100
# File 'lib/stripe/resources/payment_intent.rb', line 3098

def phone
  @phone
end

#tracking_number ⇒ Object (readonly)

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



3100
3101
3102
# File 'lib/stripe/resources/payment_intent.rb', line 3100

def tracking_number
  @tracking_number
end

Class Method Details

.field_remappings ⇒ Object



3106
3107
3108
# File 'lib/stripe/resources/payment_intent.rb', line 3106

def self.field_remappings
  @field_remappings = {}
end

.inner_class_types ⇒ Object



3102
3103
3104
# File 'lib/stripe/resources/payment_intent.rb', line 3102

def self.inner_class_types
  @inner_class_types = { address: Address }
end