Class: Stripe::PaymentIntent::TransferData

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: PaymentData

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amount ⇒ Object (readonly)

The amount transferred to the destination account. This transfer will occur automatically after the payment succeeds. If no amount is specified, by default the entire payment amount is transferred to the destination account. The amount must be less than or equal to the amount, and must be a positive integer representing how much to transfer in the smallest currency unit (e.g., 100 cents to charge $1.00).



3129
3130
3131
# File 'lib/stripe/resources/payment_intent.rb', line 3129

def amount
  @amount
end

#description ⇒ Object (readonly)

An arbitrary string attached to the transfer. Often useful for displaying to users.



3131
3132
3133
# File 'lib/stripe/resources/payment_intent.rb', line 3131

def description
  @description
end

#destination ⇒ Object (readonly)

The account (if any) that the payment is attributed to for tax reporting, and where funds from the payment are transferred to after payment success.



3133
3134
3135
# File 'lib/stripe/resources/payment_intent.rb', line 3133

def destination
  @destination
end

#metadata ⇒ Object (readonly)

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



3135
3136
3137
# File 'lib/stripe/resources/payment_intent.rb', line 3135

def 
  
end

#payment_data ⇒ Object (readonly)

Attribute for field payment_data



3137
3138
3139
# File 'lib/stripe/resources/payment_intent.rb', line 3137

def payment_data
  @payment_data
end

Class Method Details

.field_remappings ⇒ Object



3143
3144
3145
# File 'lib/stripe/resources/payment_intent.rb', line 3143

def self.field_remappings
  @field_remappings = {}
end

.inner_class_types ⇒ Object



3139
3140
3141
# File 'lib/stripe/resources/payment_intent.rb', line 3139

def self.inner_class_types
  @inner_class_types = { payment_data: PaymentData }
end