Class: Stripe::PaymentIntent::TransferData::PaymentData

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#descriptionObject (readonly)

An arbitrary string attached to the destination payment. Often useful for displaying to users.



4502
4503
4504
# File 'lib/stripe/resources/payment_intent.rb', line 4502

def description
  @description
end

#metadataObject (readonly)

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



4504
4505
4506
# File 'lib/stripe/resources/payment_intent.rb', line 4504

def 
  @metadata
end

Class Method Details

.field_remappingsObject



4510
4511
4512
# File 'lib/stripe/resources/payment_intent.rb', line 4510

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



4506
4507
4508
# File 'lib/stripe/resources/payment_intent.rb', line 4506

def self.inner_class_types
  @inner_class_types = {}
end