Class: Stripe::PaymentIntent::TriggerActionParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::TriggerActionParams
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: ScanQrCode
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#scan_qr_code ⇒ Object
True to simulate success, false to simulate failure.
-
#type ⇒ Object
The type of action to be simulated.
Instance Method Summary collapse
-
#initialize(expand: nil, scan_qr_code: nil, type: nil) ⇒ TriggerActionParams
constructor
A new instance of TriggerActionParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, scan_qr_code: nil, type: nil) ⇒ TriggerActionParams
Returns a new instance of TriggerActionParams.
16081 16082 16083 16084 16085 |
# File 'lib/stripe/resources/payment_intent.rb', line 16081 def initialize(expand: nil, scan_qr_code: nil, type: nil) @expand = @scan_qr_code = scan_qr_code @type = type end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
16075 16076 16077 |
# File 'lib/stripe/resources/payment_intent.rb', line 16075 def @expand end |
#scan_qr_code ⇒ Object
True to simulate success, false to simulate failure.
16077 16078 16079 |
# File 'lib/stripe/resources/payment_intent.rb', line 16077 def scan_qr_code @scan_qr_code end |
#type ⇒ Object
The type of action to be simulated.
16079 16080 16081 |
# File 'lib/stripe/resources/payment_intent.rb', line 16079 def type @type end |