Class: Stripe::PaymentIntent::UpdateParams::AmountDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: LineItem, Shipping, Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discount_amount: nil, line_items: nil, shipping: nil, tax: nil) ⇒ AmountDetails

Returns a new instance of AmountDetails.



7423
7424
7425
7426
7427
7428
# File 'lib/stripe/resources/payment_intent.rb', line 7423

def initialize(discount_amount: nil, line_items: nil, shipping: nil, tax: nil)
  @discount_amount = discount_amount
  @line_items = line_items
  @shipping = shipping
  @tax = tax
end

Instance Attribute Details

#discount_amountObject

The amount an item was discounted for.



7415
7416
7417
# File 'lib/stripe/resources/payment_intent.rb', line 7415

def discount_amount
  @discount_amount
end

#line_itemsObject

A list of line items, each containing information about a product in the PaymentIntent. There is a maximum of 100 line items.



7417
7418
7419
# File 'lib/stripe/resources/payment_intent.rb', line 7417

def line_items
  @line_items
end

#shippingObject

Contains information about the shipping portion of the amount.



7419
7420
7421
# File 'lib/stripe/resources/payment_intent.rb', line 7419

def shipping
  @shipping
end

#taxObject

Contains information about the tax portion of the amount.



7421
7422
7423
# File 'lib/stripe/resources/payment_intent.rb', line 7421

def tax
  @tax
end