Class: Stripe::PaymentIntent::UpdateParams::AmountDetails::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::AmountDetails::LineItem
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: PaymentMethodOptions, Tax
Instance Attribute Summary collapse
-
#discount_amount ⇒ Object
The amount an item was discounted for.
-
#payment_method_options ⇒ Object
Payment method-specific information for line items.
-
#product_code ⇒ Object
Unique identifier of the product.
-
#product_name ⇒ Object
Name of the product.
-
#quantity ⇒ Object
Number of items of the product.
-
#tax ⇒ Object
Contains information about the tax on the item.
-
#unit_cost ⇒ Object
Cost of the product.
-
#unit_of_measure ⇒ Object
A unit of measure for the line item, such as gallons, feet, meters, etc.
Instance Method Summary collapse
-
#initialize(discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil) ⇒ LineItem
Returns a new instance of LineItem.
5989 5990 5991 5992 5993 5994 5995 5996 5997 5998 5999 6000 6001 6002 6003 6004 6005 6006 6007 |
# File 'lib/stripe/resources/payment_intent.rb', line 5989 def initialize( discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil ) @discount_amount = discount_amount @payment_method_options = @product_code = product_code @product_name = product_name @quantity = quantity @tax = tax @unit_cost = unit_cost @unit_of_measure = unit_of_measure end |
Instance Attribute Details
#discount_amount ⇒ Object
The amount an item was discounted for. Positive integer.
5973 5974 5975 |
# File 'lib/stripe/resources/payment_intent.rb', line 5973 def discount_amount @discount_amount end |
#payment_method_options ⇒ Object
Payment method-specific information for line items.
5975 5976 5977 |
# File 'lib/stripe/resources/payment_intent.rb', line 5975 def @payment_method_options end |
#product_code ⇒ Object
Unique identifier of the product. At most 12 characters long.
5977 5978 5979 |
# File 'lib/stripe/resources/payment_intent.rb', line 5977 def product_code @product_code end |
#product_name ⇒ Object
Name of the product. At most 100 characters long.
5979 5980 5981 |
# File 'lib/stripe/resources/payment_intent.rb', line 5979 def product_name @product_name end |
#quantity ⇒ Object
Number of items of the product. Positive integer.
5981 5982 5983 |
# File 'lib/stripe/resources/payment_intent.rb', line 5981 def quantity @quantity end |
#tax ⇒ Object
Contains information about the tax on the item.
5983 5984 5985 |
# File 'lib/stripe/resources/payment_intent.rb', line 5983 def tax @tax end |
#unit_cost ⇒ Object
Cost of the product. Non-negative integer.
5985 5986 5987 |
# File 'lib/stripe/resources/payment_intent.rb', line 5985 def unit_cost @unit_cost end |
#unit_of_measure ⇒ Object
A unit of measure for the line item, such as gallons, feet, meters, etc.
5987 5988 5989 |
# File 'lib/stripe/resources/payment_intent.rb', line 5987 def unit_of_measure @unit_of_measure end |