Class: Stripe::PaymentIntent::UpdateParams::AmountDetails::LineItem::PaymentMethodOptions::Card
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::AmountDetails::LineItem::PaymentMethodOptions::Card
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#commodity_code ⇒ Object
Identifier that categorizes the items being purchased using a standardized commodity scheme such as (but not limited to) UNSPSC, NAICS, NAPCS, etc.
Instance Method Summary collapse
-
#initialize(commodity_code: nil) ⇒ Card
constructor
A new instance of Card.
Methods inherited from RequestParams
Constructor Details
#initialize(commodity_code: nil) ⇒ Card
Returns a new instance of Card.
7285 7286 7287 |
# File 'lib/stripe/resources/payment_intent.rb', line 7285 def initialize(commodity_code: nil) @commodity_code = commodity_code end |
Instance Attribute Details
#commodity_code ⇒ Object
Identifier that categorizes the items being purchased using a standardized commodity scheme such as (but not limited to) UNSPSC, NAICS, NAPCS, etc.
7283 7284 7285 |
# File 'lib/stripe/resources/payment_intent.rb', line 7283 def commodity_code @commodity_code end |