Class: Stripe::PaymentIntent::UpdateParams::MandateData::CustomerAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Online

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(online: nil, type: nil) ⇒ CustomerAcceptance

Returns a new instance of CustomerAcceptance.



7474
7475
7476
7477
# File 'lib/stripe/resources/payment_intent.rb', line 7474

def initialize(online: nil, type: nil)
  @online = online
  @type = type
end

Instance Attribute Details

#onlineObject

If this is a Mandate accepted online, this hash contains details about the online acceptance.



7470
7471
7472
# File 'lib/stripe/resources/payment_intent.rb', line 7470

def online
  @online
end

#typeObject

The type of customer acceptance information included with the Mandate.



7472
7473
7474
# File 'lib/stripe/resources/payment_intent.rb', line 7472

def type
  @type
end