Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::CarRental::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



6126
6127
6128
6129
6130
# File 'lib/stripe/resources/payment_intent.rb', line 6126

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



6120
6121
6122
# File 'lib/stripe/resources/payment_intent.rb', line 6120

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



6122
6123
6124
# File 'lib/stripe/resources/payment_intent.rb', line 6122

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



6124
6125
6126
# File 'lib/stripe/resources/payment_intent.rb', line 6124

def phone
  @phone
end