Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
6418 6419 6420 6421 6422 6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 6437 6438 |
# File 'lib/stripe/resources/payment_intent.rb', line 6418 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
6400 6401 6402 |
# File 'lib/stripe/resources/payment_intent.rb', line 6400 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
6402 6403 6404 |
# File 'lib/stripe/resources/payment_intent.rb', line 6402 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
6404 6405 6406 |
# File 'lib/stripe/resources/payment_intent.rb', line 6404 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
6406 6407 6408 |
# File 'lib/stripe/resources/payment_intent.rb', line 6406 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
6408 6409 6410 |
# File 'lib/stripe/resources/payment_intent.rb', line 6408 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
6410 6411 6412 |
# File 'lib/stripe/resources/payment_intent.rb', line 6410 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
6412 6413 6414 |
# File 'lib/stripe/resources/payment_intent.rb', line 6412 def genre @genre end |
#name ⇒ Object
The name of the event.
6414 6415 6416 |
# File 'lib/stripe/resources/payment_intent.rb', line 6414 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
6416 6417 6418 |
# File 'lib/stripe/resources/payment_intent.rb', line 6416 def starts_at @starts_at end |