Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::EventDetails::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



6383
6384
6385
6386
6387
# File 'lib/stripe/resources/payment_intent.rb', line 6383

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



6377
6378
6379
# File 'lib/stripe/resources/payment_intent.rb', line 6377

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



6379
6380
6381
# File 'lib/stripe/resources/payment_intent.rb', line 6379

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



6381
6382
6383
# File 'lib/stripe/resources/payment_intent.rb', line 6381

def phone
  @phone
end