Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::Flight
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentDetails::Flight
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Passenger, Segment
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
-
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#segments ⇒ Object
The individual flight segments associated with the trip.
-
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
Instance Method Summary collapse
-
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
constructor
A new instance of Flight.
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
Returns a new instance of Flight.
7922 7923 7924 7925 7926 7927 7928 7929 7930 7931 7932 7933 7934 7935 7936 7937 7938 7939 7940 |
# File 'lib/stripe/resources/payment_intent.rb', line 7922 def initialize( affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil ) @affiliate = affiliate @agency_number = agency_number @carrier = carrier @delivery = delivery @passenger_name = passenger_name @passengers = passengers @segments = segments @ticket_number = ticket_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
7906 7907 7908 |
# File 'lib/stripe/resources/payment_intent.rb', line 7906 def affiliate @affiliate end |
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
7908 7909 7910 |
# File 'lib/stripe/resources/payment_intent.rb', line 7908 def agency_number @agency_number end |
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
7910 7911 7912 |
# File 'lib/stripe/resources/payment_intent.rb', line 7910 def carrier @carrier end |
#delivery ⇒ Object
Delivery details for this purchase.
7912 7913 7914 |
# File 'lib/stripe/resources/payment_intent.rb', line 7912 def delivery @delivery end |
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
7914 7915 7916 |
# File 'lib/stripe/resources/payment_intent.rb', line 7914 def passenger_name @passenger_name end |
#passengers ⇒ Object
The details of the passengers in the travel reservation.
7916 7917 7918 |
# File 'lib/stripe/resources/payment_intent.rb', line 7916 def passengers @passengers end |
#segments ⇒ Object
The individual flight segments associated with the trip.
7918 7919 7920 |
# File 'lib/stripe/resources/payment_intent.rb', line 7918 def segments @segments end |
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
7920 7921 7922 |
# File 'lib/stripe/resources/payment_intent.rb', line 7920 def ticket_number @ticket_number end |