Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::Flight::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



6460
6461
6462
6463
6464
# File 'lib/stripe/resources/payment_intent.rb', line 6460

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



6454
6455
6456
# File 'lib/stripe/resources/payment_intent.rb', line 6454

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



6456
6457
6458
# File 'lib/stripe/resources/payment_intent.rb', line 6456

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



6458
6459
6460
# File 'lib/stripe/resources/payment_intent.rb', line 6458

def phone
  @phone
end