Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::Lodging

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Address, Affiliate, Delivery, Passenger

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging

Returns a new instance of Lodging.



6680
6681
6682
6683
6684
6685
6686
6687
6688
6689
6690
6691
6692
6693
6694
6695
6696
6697
6698
6699
6700
6701
6702
6703
6704
6705
6706
6707
6708
6709
6710
6711
6712
6713
6714
6715
6716
6717
6718
6719
6720
6721
6722
6723
6724
# File 'lib/stripe/resources/payment_intent.rb', line 6680

def initialize(
  address: nil,
  adults: nil,
  affiliate: nil,
  booking_number: nil,
  category: nil,
  checkin_at: nil,
  checkout_at: nil,
  customer_service_phone_number: nil,
  daily_room_rate_amount: nil,
  delivery: nil,
  extra_charges: nil,
  fire_safety_act_compliance: nil,
  name: nil,
  no_show: nil,
  number_of_rooms: nil,
  passengers: nil,
  property_phone_number: nil,
  room_class: nil,
  room_nights: nil,
  total_room_tax_amount: nil,
  total_tax_amount: nil
)
  @address = address
  @adults = adults
  @affiliate = affiliate
  @booking_number = booking_number
  @category = category
  @checkin_at = checkin_at
  @checkout_at = checkout_at
  @customer_service_phone_number = customer_service_phone_number
  @daily_room_rate_amount = daily_room_rate_amount
  @delivery = delivery
  @extra_charges = extra_charges
  @fire_safety_act_compliance = fire_safety_act_compliance
  @name = name
  @no_show = no_show
  @number_of_rooms = number_of_rooms
  @passengers = passengers
  @property_phone_number = property_phone_number
  @room_class = room_class
  @room_nights = room_nights
  @total_room_tax_amount = total_room_tax_amount
  @total_tax_amount = total_tax_amount
end

Instance Attribute Details

#addressObject

The lodging location’s address.



6638
6639
6640
# File 'lib/stripe/resources/payment_intent.rb', line 6638

def address
  @address
end

#adultsObject

The number of adults on the booking



6640
6641
6642
# File 'lib/stripe/resources/payment_intent.rb', line 6640

def adults
  @adults
end

#affiliateObject

Affiliate details for this purchase.



6642
6643
6644
# File 'lib/stripe/resources/payment_intent.rb', line 6642

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the lodging reservation.



6644
6645
6646
# File 'lib/stripe/resources/payment_intent.rb', line 6644

def booking_number
  @booking_number
end

#categoryObject

The lodging category



6646
6647
6648
# File 'lib/stripe/resources/payment_intent.rb', line 6646

def category
  @category
end

#checkin_atObject

Lodging check-in time. Measured in seconds since the Unix epoch.



6648
6649
6650
# File 'lib/stripe/resources/payment_intent.rb', line 6648

def checkin_at
  @checkin_at
end

#checkout_atObject

Lodging check-out time. Measured in seconds since the Unix epoch.



6650
6651
6652
# File 'lib/stripe/resources/payment_intent.rb', line 6650

def checkout_at
  @checkout_at
end

#customer_service_phone_numberObject

The customer service phone number of the lodging company.



6652
6653
6654
# File 'lib/stripe/resources/payment_intent.rb', line 6652

def customer_service_phone_number
  @customer_service_phone_number
end

#daily_room_rate_amountObject

The daily lodging room rate.



6654
6655
6656
# File 'lib/stripe/resources/payment_intent.rb', line 6654

def daily_room_rate_amount
  @daily_room_rate_amount
end

#deliveryObject

Delivery details for this purchase.



6656
6657
6658
# File 'lib/stripe/resources/payment_intent.rb', line 6656

def delivery
  @delivery
end

#extra_chargesObject

List of additional charges being billed.



6658
6659
6660
# File 'lib/stripe/resources/payment_intent.rb', line 6658

def extra_charges
  @extra_charges
end

#fire_safety_act_complianceObject

Indicates whether the lodging location is compliant with the Fire Safety Act.



6660
6661
6662
# File 'lib/stripe/resources/payment_intent.rb', line 6660

def fire_safety_act_compliance
  @fire_safety_act_compliance
end

#nameObject

The name of the lodging location.



6662
6663
6664
# File 'lib/stripe/resources/payment_intent.rb', line 6662

def name
  @name
end

#no_showObject

Indicates if the customer did not keep their booking while failing to cancel the reservation.



6664
6665
6666
# File 'lib/stripe/resources/payment_intent.rb', line 6664

def no_show
  @no_show
end

#number_of_roomsObject

The number of rooms on the booking



6666
6667
6668
# File 'lib/stripe/resources/payment_intent.rb', line 6666

def number_of_rooms
  @number_of_rooms
end

#passengersObject

The details of the passengers in the travel reservation



6668
6669
6670
# File 'lib/stripe/resources/payment_intent.rb', line 6668

def passengers
  @passengers
end

#property_phone_numberObject

The phone number of the lodging location.



6670
6671
6672
# File 'lib/stripe/resources/payment_intent.rb', line 6670

def property_phone_number
  @property_phone_number
end

#room_classObject

The room class for this purchase.



6672
6673
6674
# File 'lib/stripe/resources/payment_intent.rb', line 6672

def room_class
  @room_class
end

#room_nightsObject

The number of room nights



6674
6675
6676
# File 'lib/stripe/resources/payment_intent.rb', line 6674

def room_nights
  @room_nights
end

#total_room_tax_amountObject

The total tax amount associating with the room reservation.



6676
6677
6678
# File 'lib/stripe/resources/payment_intent.rb', line 6676

def total_room_tax_amount
  @total_room_tax_amount
end

#total_tax_amountObject

The total tax amount



6678
6679
6680
# File 'lib/stripe/resources/payment_intent.rb', line 6678

def total_tax_amount
  @total_tax_amount
end