Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::Lodging::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentDetails::Lodging::Delivery::Recipient
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
6612 6613 6614 6615 6616 |
# File 'lib/stripe/resources/payment_intent.rb', line 6612 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
6606 6607 6608 |
# File 'lib/stripe/resources/payment_intent.rb', line 6606 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
6608 6609 6610 |
# File 'lib/stripe/resources/payment_intent.rb', line 6608 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
6610 6611 6612 |
# File 'lib/stripe/resources/payment_intent.rb', line 6610 def phone @phone end |