Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::Subscription::BillingInterval

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(count: nil, interval: nil) ⇒ BillingInterval

Returns a new instance of BillingInterval.



8124
8125
8126
8127
# File 'lib/stripe/resources/payment_intent.rb', line 8124

def initialize(count: nil, interval: nil)
  @count = count
  @interval = interval
end

Instance Attribute Details

#countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



8120
8121
8122
# File 'lib/stripe/resources/payment_intent.rb', line 8120

def count
  @count
end

#intervalObject

Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.



8122
8123
8124
# File 'lib/stripe/resources/payment_intent.rb', line 8122

def interval
  @interval
end