Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodData::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentMethodData::UsBankAccount
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#account_holder_type ⇒ Object
Account holder type: individual or company.
-
#account_number ⇒ Object
Account number of the bank account.
-
#account_type ⇒ Object
Account type: checkings or savings.
-
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
-
#routing_number ⇒ Object
Routing number of the bank account.
Instance Method Summary collapse
-
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
7160 7161 7162 7163 7164 7165 7166 7167 7168 7169 7170 7171 7172 |
# File 'lib/stripe/resources/payment_intent.rb', line 7160 def initialize( account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil ) @account_holder_type = account_holder_type @account_number = account_number @account_type = account_type @financial_connections_account = financial_connections_account @routing_number = routing_number end |
Instance Attribute Details
#account_holder_type ⇒ Object
Account holder type: individual or company.
7150 7151 7152 |
# File 'lib/stripe/resources/payment_intent.rb', line 7150 def account_holder_type @account_holder_type end |
#account_number ⇒ Object
Account number of the bank account.
7152 7153 7154 |
# File 'lib/stripe/resources/payment_intent.rb', line 7152 def account_number @account_number end |
#account_type ⇒ Object
Account type: checkings or savings. Defaults to checking if omitted.
7154 7155 7156 |
# File 'lib/stripe/resources/payment_intent.rb', line 7154 def account_type @account_type end |
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
7156 7157 7158 |
# File 'lib/stripe/resources/payment_intent.rb', line 7156 def financial_connections_account @financial_connections_account end |
#routing_number ⇒ Object
Routing number of the bank account.
7158 7159 7160 |
# File 'lib/stripe/resources/payment_intent.rb', line 7158 def routing_number @routing_number end |