Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::AcssDebit::MandateOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::AcssDebit::MandateOptions
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#custom_mandate_url ⇒ Object
A URL for custom mandate text to render during confirmation step.
-
#interval_description ⇒ Object
Description of the mandate interval.
-
#payment_schedule ⇒ Object
Payment schedule for the mandate.
-
#transaction_type ⇒ Object
Transaction type of the mandate.
Instance Method Summary collapse
-
#initialize(custom_mandate_url: nil, interval_description: nil, payment_schedule: nil, transaction_type: nil) ⇒ MandateOptions
constructor
A new instance of MandateOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(custom_mandate_url: nil, interval_description: nil, payment_schedule: nil, transaction_type: nil) ⇒ MandateOptions
Returns a new instance of MandateOptions.
7055 7056 7057 7058 7059 7060 7061 7062 7063 7064 7065 |
# File 'lib/stripe/resources/payment_intent.rb', line 7055 def initialize( custom_mandate_url: nil, interval_description: nil, payment_schedule: nil, transaction_type: nil ) @custom_mandate_url = custom_mandate_url @interval_description = interval_description @payment_schedule = payment_schedule @transaction_type = transaction_type end |
Instance Attribute Details
#custom_mandate_url ⇒ Object
A URL for custom mandate text to render during confirmation step. The URL will be rendered with additional GET parameters ‘payment_intent` and `payment_intent_client_secret` when confirming a Payment Intent, or `setup_intent` and `setup_intent_client_secret` when confirming a Setup Intent.
7047 7048 7049 |
# File 'lib/stripe/resources/payment_intent.rb', line 7047 def custom_mandate_url @custom_mandate_url end |
#interval_description ⇒ Object
Description of the mandate interval. Only required if ‘payment_schedule’ parameter is ‘interval’ or ‘combined’.
7049 7050 7051 |
# File 'lib/stripe/resources/payment_intent.rb', line 7049 def interval_description @interval_description end |
#payment_schedule ⇒ Object
Payment schedule for the mandate.
7051 7052 7053 |
# File 'lib/stripe/resources/payment_intent.rb', line 7051 def payment_schedule @payment_schedule end |
#transaction_type ⇒ Object
Transaction type of the mandate.
7053 7054 7055 |
# File 'lib/stripe/resources/payment_intent.rb', line 7053 def transaction_type @transaction_type end |