Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::Card::Installments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Plan

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(enabled: nil, plan: nil) ⇒ Installments

Returns a new instance of Installments.



9120
9121
9122
9123
# File 'lib/stripe/resources/payment_intent.rb', line 9120

def initialize(enabled: nil, plan: nil)
  @enabled = enabled
  @plan = plan
end

Instance Attribute Details

#enabledObject

Setting to true enables installments for this PaymentIntent. This will cause the response to contain a list of available installment plans. Setting to false will prevent any selected plan from applying to a charge.



9115
9116
9117
# File 'lib/stripe/resources/payment_intent.rb', line 9115

def enabled
  @enabled
end

#planObject

The selected installment plan to use for this payment attempt. This parameter can only be provided during confirmation.



9118
9119
9120
# File 'lib/stripe/resources/payment_intent.rb', line 9118

def plan
  @plan
end