Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::Card::StatementDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::Card::StatementDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Please pass in an address that is within your Stripe user account country.
-
#phone ⇒ Object
Phone number (e.g., a toll-free number that customers can call).
Instance Method Summary collapse
-
#initialize(address: nil, phone: nil) ⇒ StatementDetails
constructor
A new instance of StatementDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, phone: nil) ⇒ StatementDetails
Returns a new instance of StatementDetails.
7438 7439 7440 7441 |
# File 'lib/stripe/resources/payment_intent.rb', line 7438 def initialize(address: nil, phone: nil) @address = address @phone = phone end |
Instance Attribute Details
#address ⇒ Object
Please pass in an address that is within your Stripe user account country
7434 7435 7436 |
# File 'lib/stripe/resources/payment_intent.rb', line 7434 def address @address end |
#phone ⇒ Object
Phone number (e.g., a toll-free number that customers can call)
7436 7437 7438 |
# File 'lib/stripe/resources/payment_intent.rb', line 7436 def phone @phone end |