Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::Klarna::OnDemand

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(average_amount: nil, maximum_amount: nil, minimum_amount: nil, purchase_interval: nil, purchase_interval_count: nil) ⇒ OnDemand

Returns a new instance of OnDemand.



9661
9662
9663
9664
9665
9666
9667
9668
9669
9670
9671
9672
9673
# File 'lib/stripe/resources/payment_intent.rb', line 9661

def initialize(
  average_amount: nil,
  maximum_amount: nil,
  minimum_amount: nil,
  purchase_interval: nil,
  purchase_interval_count: nil
)
  @average_amount = average_amount
  @maximum_amount = maximum_amount
  @minimum_amount = minimum_amount
  @purchase_interval = purchase_interval
  @purchase_interval_count = purchase_interval_count
end

Instance Attribute Details

#average_amountObject

Your average amount value. You can use a value across your customer base, or segment based on customer type, country, etc.



9651
9652
9653
# File 'lib/stripe/resources/payment_intent.rb', line 9651

def average_amount
  @average_amount
end

#maximum_amountObject

The maximum value you may charge a customer per purchase. You can use a value across your customer base, or segment based on customer type, country, etc.



9653
9654
9655
# File 'lib/stripe/resources/payment_intent.rb', line 9653

def maximum_amount
  @maximum_amount
end

#minimum_amountObject

The lowest or minimum value you may charge a customer per purchase. You can use a value across your customer base, or segment based on customer type, country, etc.



9655
9656
9657
# File 'lib/stripe/resources/payment_intent.rb', line 9655

def minimum_amount
  @minimum_amount
end

#purchase_intervalObject

Interval at which the customer is making purchases



9657
9658
9659
# File 'lib/stripe/resources/payment_intent.rb', line 9657

def purchase_interval
  @purchase_interval
end

#purchase_interval_countObject

The number of ‘purchase_interval` between charges



9659
9660
9661
# File 'lib/stripe/resources/payment_intent.rb', line 9659

def purchase_interval_count
  @purchase_interval_count
end