Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::Klarna::Subscription
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::Klarna::Subscription
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: NextBilling
Instance Attribute Summary collapse
-
#interval ⇒ Object
Unit of time between subscription charges.
-
#interval_count ⇒ Object
The number of intervals (specified in the ‘interval` attribute) between subscription charges.
-
#name ⇒ Object
Name for subscription.
-
#next_billing ⇒ Object
Describes the upcoming charge for this subscription.
-
#reference ⇒ Object
A non-customer-facing reference to correlate subscription charges in the Klarna app.
Instance Method Summary collapse
-
#initialize(interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil) ⇒ Subscription
constructor
A new instance of Subscription.
Methods inherited from RequestParams
Constructor Details
#initialize(interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil) ⇒ Subscription
Returns a new instance of Subscription.
8318 8319 8320 8321 8322 8323 8324 8325 8326 8327 8328 8329 8330 |
# File 'lib/stripe/resources/payment_intent.rb', line 8318 def initialize( interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil ) @interval = interval @interval_count = interval_count @name = name @next_billing = next_billing @reference = reference end |
Instance Attribute Details
#interval ⇒ Object
Unit of time between subscription charges.
8308 8309 8310 |
# File 'lib/stripe/resources/payment_intent.rb', line 8308 def interval @interval end |
#interval_count ⇒ Object
The number of intervals (specified in the ‘interval` attribute) between subscription charges. For example, `interval=month` and `interval_count=3` charges every 3 months.
8310 8311 8312 |
# File 'lib/stripe/resources/payment_intent.rb', line 8310 def interval_count @interval_count end |
#name ⇒ Object
Name for subscription.
8312 8313 8314 |
# File 'lib/stripe/resources/payment_intent.rb', line 8312 def name @name end |
#next_billing ⇒ Object
Describes the upcoming charge for this subscription.
8314 8315 8316 |
# File 'lib/stripe/resources/payment_intent.rb', line 8314 def next_billing @next_billing end |
#reference ⇒ Object
A non-customer-facing reference to correlate subscription charges in the Klarna app. Use a value that persists across subscription charges.
8316 8317 8318 |
# File 'lib/stripe/resources/payment_intent.rb', line 8316 def reference @reference end |