Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::Klarna::Subscription::NextBilling

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, date: nil) ⇒ NextBilling

Returns a new instance of NextBilling.



9683
9684
9685
9686
# File 'lib/stripe/resources/payment_intent.rb', line 9683

def initialize(amount: nil, date: nil)
  @amount = amount
  @date = date
end

Instance Attribute Details

#amountObject

The amount of the next charge for the subscription.



9679
9680
9681
# File 'lib/stripe/resources/payment_intent.rb', line 9679

def amount
  @amount
end

#dateObject

The date of the next charge for the subscription in YYYY-MM-DD format.



9681
9682
9683
# File 'lib/stripe/resources/payment_intent.rb', line 9681

def date
  @date
end