Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Tax
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#name ⇒ Object
Descriptive name of the line item.
-
#quantity ⇒ Object
Quantity of the line item.
-
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
The tax information for the line item.
-
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
Returns a new instance of LineItem.
10037 10038 10039 10040 10041 10042 10043 10044 10045 10046 10047 10048 10049 10050 10051 10052 10053 10054 10055 |
# File 'lib/stripe/resources/payment_intent.rb', line 10037 def initialize( category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil ) @category = category @description = description @name = name @quantity = quantity @sku = sku @sold_by = sold_by @tax = tax @unit_amount = unit_amount end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
10021 10022 10023 |
# File 'lib/stripe/resources/payment_intent.rb', line 10021 def category @category end |
#description ⇒ Object
Description of the line item.
10023 10024 10025 |
# File 'lib/stripe/resources/payment_intent.rb', line 10023 def description @description end |
#name ⇒ Object
Descriptive name of the line item.
10025 10026 10027 |
# File 'lib/stripe/resources/payment_intent.rb', line 10025 def name @name end |
#quantity ⇒ Object
Quantity of the line item. Must be a positive number.
10027 10028 10029 |
# File 'lib/stripe/resources/payment_intent.rb', line 10027 def quantity @quantity end |
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
10029 10030 10031 |
# File 'lib/stripe/resources/payment_intent.rb', line 10029 def sku @sku end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
10031 10032 10033 |
# File 'lib/stripe/resources/payment_intent.rb', line 10031 def sold_by @sold_by end |
#tax ⇒ Object
The tax information for the line item.
10033 10034 10035 |
# File 'lib/stripe/resources/payment_intent.rb', line 10033 def tax @tax end |
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units. Cannot be a negative number.
10035 10036 10037 |
# File 'lib/stripe/resources/payment_intent.rb', line 10035 def unit_amount @unit_amount end |