Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::Paypal::LineItem::Tax
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::Paypal::LineItem::Tax
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The tax for a single unit of the line item in minor units.
-
#behavior ⇒ Object
The tax behavior for the line item.
Instance Method Summary collapse
-
#initialize(amount: nil, behavior: nil) ⇒ Tax
constructor
A new instance of Tax.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, behavior: nil) ⇒ Tax
Returns a new instance of Tax.
8248 8249 8250 8251 |
# File 'lib/stripe/resources/payment_intent.rb', line 8248 def initialize(amount: nil, behavior: nil) @amount = amount @behavior = behavior end |
Instance Attribute Details
#amount ⇒ Object
The tax for a single unit of the line item in minor units. Cannot be a negative number.
8244 8245 8246 |
# File 'lib/stripe/resources/payment_intent.rb', line 8244 def amount @amount end |
#behavior ⇒ Object
The tax behavior for the line item.
8246 8247 8248 |
# File 'lib/stripe/resources/payment_intent.rb', line 8246 def behavior @behavior end |