Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::Payto::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, end_date: nil, payment_schedule: nil, payments_per_period: nil, purpose: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



10118
10119
10120
10121
10122
10123
10124
10125
10126
10127
10128
10129
10130
10131
10132
# File 'lib/stripe/resources/payment_intent.rb', line 10118

def initialize(
  amount: nil,
  amount_type: nil,
  end_date: nil,
  payment_schedule: nil,
  payments_per_period: nil,
  purpose: nil
)
  @amount = amount
  @amount_type = amount_type
  @end_date = end_date
  @payment_schedule = payment_schedule
  @payments_per_period = payments_per_period
  @purpose = purpose
end

Instance Attribute Details

#amountObject

Amount that will be collected. It is required when ‘amount_type` is `fixed`.



10106
10107
10108
# File 'lib/stripe/resources/payment_intent.rb', line 10106

def amount
  @amount
end

#amount_typeObject

The type of amount that will be collected. The amount charged must be exact or up to the value of ‘amount` param for `fixed` or `maximum` type respectively.



10108
10109
10110
# File 'lib/stripe/resources/payment_intent.rb', line 10108

def amount_type
  @amount_type
end

#end_dateObject

Date, in YYYY-MM-DD format, after which payments will not be collected. Defaults to no end date.



10110
10111
10112
# File 'lib/stripe/resources/payment_intent.rb', line 10110

def end_date
  @end_date
end

#payment_scheduleObject

The periodicity at which payments will be collected.



10112
10113
10114
# File 'lib/stripe/resources/payment_intent.rb', line 10112

def payment_schedule
  @payment_schedule
end

#payments_per_periodObject

The number of payments that will be made during a payment period. Defaults to 1 except for when ‘payment_schedule` is `adhoc`. In that case, it defaults to no limit.



10114
10115
10116
# File 'lib/stripe/resources/payment_intent.rb', line 10114

def payments_per_period
  @payments_per_period
end

#purposeObject

The purpose for which payments are made. Defaults to retail.



10116
10117
10118
# File 'lib/stripe/resources/payment_intent.rb', line 10116

def purpose
  @purpose
end