Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::UsBankAccount::FinancialConnections

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Filters

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(filters: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections

Returns a new instance of FinancialConnections.



5912
5913
5914
5915
5916
5917
# File 'lib/stripe/resources/payment_intent.rb', line 5912

def initialize(filters: nil, permissions: nil, prefetch: nil, return_url: nil)
  @filters = filters
  @permissions = permissions
  @prefetch = prefetch
  @return_url = return_url
end

Instance Attribute Details

#filtersObject

Provide filters for the linked accounts that the customer can select for the payment method.



5904
5905
5906
# File 'lib/stripe/resources/payment_intent.rb', line 5904

def filters
  @filters
end

#permissionsObject

The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.



5906
5907
5908
# File 'lib/stripe/resources/payment_intent.rb', line 5906

def permissions
  @permissions
end

#prefetchObject

List of data features that you would like to retrieve upon account creation.



5908
5909
5910
# File 'lib/stripe/resources/payment_intent.rb', line 5908

def prefetch
  @prefetch
end

#return_urlObject

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



5910
5911
5912
# File 'lib/stripe/resources/payment_intent.rb', line 5910

def return_url
  @return_url
end