Class: Stripe::PaymentIntent::UpdateParams::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



10858
10859
10860
10861
10862
10863
10864
# File 'lib/stripe/resources/payment_intent.rb', line 10858

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



10848
10849
10850
# File 'lib/stripe/resources/payment_intent.rb', line 10848

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



10850
10851
10852
# File 'lib/stripe/resources/payment_intent.rb', line 10850

def carrier
  @carrier
end

#nameObject

Recipient name.



10852
10853
10854
# File 'lib/stripe/resources/payment_intent.rb', line 10852

def name
  @name
end

#phoneObject

Recipient phone (including extension).



10854
10855
10856
# File 'lib/stripe/resources/payment_intent.rb', line 10854

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



10856
10857
10858
# File 'lib/stripe/resources/payment_intent.rb', line 10856

def tracking_number
  @tracking_number
end