Class: Stripe::PaymentIntent::VerifyMicrodepositsParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amounts: nil, descriptor_code: nil, expand: nil) ⇒ VerifyMicrodepositsParams

Returns a new instance of VerifyMicrodepositsParams.



16058
16059
16060
16061
16062
# File 'lib/stripe/resources/payment_intent.rb', line 16058

def initialize(amounts: nil, descriptor_code: nil, expand: nil)
  @amounts = amounts
  @descriptor_code = descriptor_code
  @expand = expand
end

Instance Attribute Details

#amountsObject

Two positive integers, in cents, equal to the values of the microdeposits sent to the bank account.



16052
16053
16054
# File 'lib/stripe/resources/payment_intent.rb', line 16052

def amounts
  @amounts
end

#descriptor_codeObject

A six-character code starting with SM present in the microdeposit sent to the bank account.



16054
16055
16056
# File 'lib/stripe/resources/payment_intent.rb', line 16054

def descriptor_code
  @descriptor_code
end

#expandObject

Specifies which fields in the response should be expanded.



16056
16057
16058
# File 'lib/stripe/resources/payment_intent.rb', line 16056

def expand
  @expand
end