Class: Stripe::PaymentIntentAmountDetailsLineItem

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/payment_intent_amount_details_line_item.rb

Defined Under Namespace

Classes: PaymentMethodOptions, Tax

Constant Summary collapse

OBJECT_NAME =
"payment_intent_amount_details_line_item"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#discount_amountObject (readonly)

The discount applied on this line item represented in the smallest currency unit. An integer greater than 0.

This field is mutually exclusive with the amount_details[discount_amount] field.



153
154
155
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 153

def discount_amount
  @discount_amount
end

#idObject (readonly)

Unique identifier for the object.



155
156
157
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 155

def id
  @id
end

#objectObject (readonly)

String representing the object's type. Objects of the same type share the same value.



157
158
159
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 157

def object
  @object
end

#payment_method_optionsObject (readonly)

Payment method-specific information for line items.



159
160
161
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 159

def payment_method_options
  @payment_method_options
end

#product_codeObject (readonly)

The product code of the line item, such as an SKU. Required for L3 rates. At most 12 characters long.



161
162
163
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 161

def product_code
  @product_code
end

#product_nameObject (readonly)

The product name of the line item. Required for L3 rates. At most 1024 characters long.

For Cards, this field is truncated to 26 alphanumeric characters before being sent to the card networks. For PayPal, this field is truncated to 127 characters.



165
166
167
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 165

def product_name
  @product_name
end

#quantityObject (readonly)

The quantity of items. Required for L3 rates. An integer greater than 0.



167
168
169
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 167

def quantity
  @quantity
end

#quantity_precisionObject (readonly)

The number of decimal places implied in the quantity. For example, if quantity is 10000 and quantity_precision is 2, the actual quantity is 100.00. Defaults to 0 if not provided.



169
170
171
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 169

def quantity_precision
  @quantity_precision
end

#taxObject (readonly)

Contains information about the tax on the item.



171
172
173
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 171

def tax
  @tax
end

#unit_costObject (readonly)

The unit cost of the line item represented in the smallest currency unit. Required for L3 rates. An integer greater than or equal to 0.



173
174
175
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 173

def unit_cost
  @unit_cost
end

#unit_of_measureObject (readonly)

A unit of measure for the line item, such as gallons, feet, meters, etc. Required for L3 rates. At most 12 alphanumeric characters long.



175
176
177
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 175

def unit_of_measure
  @unit_of_measure
end

Class Method Details

.field_remappingsObject



181
182
183
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 181

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



177
178
179
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 177

def self.inner_class_types
  @inner_class_types = { payment_method_options: PaymentMethodOptions, tax: Tax }
end

.object_nameObject



7
8
9
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 7

def self.object_name
  "payment_intent_amount_details_line_item"
end