Class: Stripe::PaymentIntentAmountDetailsLineItem::PaymentMethodOptions::Paypal
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntentAmountDetailsLineItem::PaymentMethodOptions::Paypal
- Defined in:
- lib/stripe/resources/payment_intent_amount_details_line_item.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#category ⇒ Object
readonly
Type of the line item.
-
#description ⇒ Object
readonly
Description of the line item.
-
#sold_by ⇒ Object
readonly
The Stripe account ID of the connected account that sells the item.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#category ⇒ Object (readonly)
Type of the line item.
26 27 28 |
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 26 def category @category end |
#description ⇒ Object (readonly)
Description of the line item.
28 29 30 |
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 28 def description @description end |
#sold_by ⇒ Object (readonly)
The Stripe account ID of the connected account that sells the item. This is only needed when using [Separate Charges and Transfers](docs.stripe.com/connect/separate-charges-and-transfers).
30 31 32 |
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 30 def sold_by @sold_by end |