Class: Stripe::PaymentIntentCaptureParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/payment_intent_capture_params.rb

Defined Under Namespace

Classes: AmountDetails, Hooks, PaymentDetails, TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount_details: nil, amount_to_capture: nil, application_fee_amount: nil, expand: nil, final_capture: nil, hooks: nil, metadata: nil, payment_details: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil) ⇒ PaymentIntentCaptureParams

Returns a new instance of PaymentIntentCaptureParams.



2077
2078
2079
2080
2081
2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
2101
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 2077

def initialize(
  amount_details: nil,
  amount_to_capture: nil,
  application_fee_amount: nil,
  expand: nil,
  final_capture: nil,
  hooks: nil,
  metadata: nil,
  payment_details: nil,
  statement_descriptor: nil,
  statement_descriptor_suffix: nil,
  transfer_data: nil
)
  @amount_details = amount_details
  @amount_to_capture = amount_to_capture
  @application_fee_amount = application_fee_amount
  @expand = expand
  @final_capture = final_capture
  @hooks = hooks
  @metadata = 
  @payment_details = payment_details
  @statement_descriptor = statement_descriptor
  @statement_descriptor_suffix = statement_descriptor_suffix
  @transfer_data = transfer_data
end

Instance Attribute Details

#amount_detailsObject

Provides industry-specific information about the amount.



2052
2053
2054
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 2052

def amount_details
  @amount_details
end

#amount_to_captureObject

The amount to capture from the PaymentIntent, which must be less than or equal to the original amount. Defaults to the full amount_capturable if it's not provided.



2054
2055
2056
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 2054

def amount_to_capture
  @amount_to_capture
end

#application_fee_amountObject

The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner's Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents use case for connected accounts.



2056
2057
2058
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 2056

def application_fee_amount
  @application_fee_amount
end

#expandObject

Specifies which fields in the response should be expanded.



2058
2059
2060
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 2058

def expand
  @expand
end

#final_captureObject

Defaults to true. When capturing a PaymentIntent, setting final_capture to false notifies Stripe to not release the remaining uncaptured funds to make sure that they're captured in future requests. You can only use this setting when multicapture is available for PaymentIntents.



2060
2061
2062
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 2060

def final_capture
  @final_capture
end

#hooksObject

Automations to be run during the PaymentIntent lifecycle



2062
2063
2064
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 2062

def hooks
  @hooks
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.



2064
2065
2066
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 2064

def 
  @metadata
end

#payment_detailsObject

Provides industry-specific information about the charge.



2066
2067
2068
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 2066

def payment_details
  @payment_details
end

#statement_descriptorObject

Text that appears on the customer's statement as the statement descriptor for a non-card charge. This value overrides the account's default statement descriptor. For information about requirements, including the 22-character limit, see the Statement Descriptor docs.

Setting this value for a card charge returns an error. For card charges, set the statement_descriptor_suffix instead.



2070
2071
2072
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 2070

def statement_descriptor
  @statement_descriptor
end

#statement_descriptor_suffixObject

Provides information about a card charge. Concatenated to the account's statement descriptor prefix to form the complete statement descriptor that appears on the customer's statement.



2072
2073
2074
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 2072

def statement_descriptor_suffix
  @statement_descriptor_suffix
end

#transfer_dataObject

The parameters that you can use to automatically create a transfer after the payment is captured. Learn more about the use case for connected accounts.



2075
2076
2077
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 2075

def transfer_data
  @transfer_data
end