Class: Stripe::PaymentIntentCaptureParams::AmountDetails::LineItem::PaymentMethodOptions::Paypal
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCaptureParams::AmountDetails::LineItem::PaymentMethodOptions::Paypal
- Defined in:
- lib/stripe/params/payment_intent_capture_params.rb
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, sold_by: nil) ⇒ Paypal
constructor
A new instance of Paypal.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(category: nil, description: nil, sold_by: nil) ⇒ Paypal
Returns a new instance of Paypal.
72 73 74 75 76 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 72 def initialize(category: nil, description: nil, sold_by: nil) @category = category @description = description @sold_by = sold_by end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
66 67 68 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 66 def category @category end |
#description ⇒ Object
Description of the line item.
68 69 70 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 68 def description @description end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
70 71 72 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 70 def sold_by @sold_by end |