Class: Stripe::PaymentIntentCaptureParams::AmountDetails::Shipping
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCaptureParams::AmountDetails::Shipping
- Defined in:
- lib/stripe/params/payment_intent_capture_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
If a physical good is being shipped, the cost of shipping represented in the smallest currency unit.
-
#from_postal_code ⇒ Object
If a physical good is being shipped, the postal code of where it is being shipped from.
-
#to_postal_code ⇒ Object
If a physical good is being shipped, the postal code of where it is being shipped to.
Instance Method Summary collapse
-
#initialize(amount: nil, from_postal_code: nil, to_postal_code: nil) ⇒ Shipping
constructor
A new instance of Shipping.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, from_postal_code: nil, to_postal_code: nil) ⇒ Shipping
Returns a new instance of Shipping.
201 202 203 204 205 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 201 def initialize(amount: nil, from_postal_code: nil, to_postal_code: nil) @amount = amount @from_postal_code = from_postal_code @to_postal_code = to_postal_code end |
Instance Attribute Details
#amount ⇒ Object
If a physical good is being shipped, the cost of shipping represented in the smallest currency unit. An integer greater than or equal to 0.
195 196 197 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 195 def amount @amount end |
#from_postal_code ⇒ Object
If a physical good is being shipped, the postal code of where it is being shipped from. At most 10 alphanumeric characters long, hyphens and spaces are allowed.
197 198 199 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 197 def from_postal_code @from_postal_code end |
#to_postal_code ⇒ Object
If a physical good is being shipped, the postal code of where it is being shipped to. At most 10 alphanumeric characters long, hyphens and spaces are allowed.
199 200 201 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 199 def to_postal_code @to_postal_code end |