Class: Stripe::PaymentIntentCaptureParams::AmountDetails::Surcharge
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCaptureParams::AmountDetails::Surcharge
- Defined in:
- lib/stripe/params/payment_intent_capture_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
Portion of the amount that corresponds to a surcharge.
-
#enforce_validation ⇒ Object
Indicate whether to enforce validations on the surcharge amount.
Instance Method Summary collapse
-
#initialize(amount: nil, enforce_validation: nil) ⇒ Surcharge
constructor
A new instance of Surcharge.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, enforce_validation: nil) ⇒ Surcharge
Returns a new instance of Surcharge.
214 215 216 217 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 214 def initialize(amount: nil, enforce_validation: nil) @amount = amount @enforce_validation = enforce_validation end |
Instance Attribute Details
#amount ⇒ Object
Portion of the amount that corresponds to a surcharge.
210 211 212 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 210 def amount @amount end |
#enforce_validation ⇒ Object
Indicate whether to enforce validations on the surcharge amount.
212 213 214 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 212 def enforce_validation @enforce_validation end |