Class: Stripe::PaymentIntentCaptureParams::PaymentDetails::CarRental::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_capture_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



251
252
253
254
255
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 251

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



245
246
247
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 245

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



247
248
249
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 247

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



249
250
251
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 249

def phone
  @phone
end