Class: Stripe::PaymentIntentCaptureParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCaptureParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/params/payment_intent_capture_params.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 901 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
883 884 885 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 883 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
885 886 887 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 885 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
887 888 889 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 887 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
889 890 891 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 889 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
891 892 893 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 891 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
893 894 895 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 893 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
895 896 897 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 895 def genre @genre end |
#name ⇒ Object
The name of the event.
897 898 899 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 897 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
899 900 901 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 899 def starts_at @starts_at end |