Class: Stripe::PaymentIntentCaptureParams::PaymentDetails::EventDetails::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_capture_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



866
867
868
869
870
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 866

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



860
861
862
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 860

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



862
863
864
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 862

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



864
865
866
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 864

def phone
  @phone
end