Class: Stripe::PaymentIntentCaptureParams::PaymentDetails::Flight
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCaptureParams::PaymentDetails::Flight
- Defined in:
- lib/stripe/params/payment_intent_capture_params.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Passenger, Segment
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
-
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#segments ⇒ Object
The individual flight segments associated with the trip.
-
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
Instance Method Summary collapse
-
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
constructor
A new instance of Flight.
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
Returns a new instance of Flight.
1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1008 def initialize( affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil ) @affiliate = affiliate @agency_number = agency_number @carrier = carrier @delivery = delivery @passenger_name = passenger_name @passengers = passengers @segments = segments @ticket_number = ticket_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
992 993 994 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 992 def affiliate @affiliate end |
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
994 995 996 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 994 def agency_number @agency_number end |
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
996 997 998 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 996 def carrier @carrier end |
#delivery ⇒ Object
Delivery details for this purchase.
998 999 1000 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 998 def delivery @delivery end |
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
1000 1001 1002 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1000 def passenger_name @passenger_name end |
#passengers ⇒ Object
The details of the passengers in the travel reservation.
1002 1003 1004 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1002 def passengers @passengers end |
#segments ⇒ Object
The individual flight segments associated with the trip.
1004 1005 1006 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1004 def segments @segments end |
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
1006 1007 1008 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1006 def ticket_number @ticket_number end |