Class: Stripe::PaymentIntentCaptureParams::PaymentDetails::Flight::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_capture_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



1054
1055
1056
1057
1058
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1054

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



1048
1049
1050
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1048

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



1050
1051
1052
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1050

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



1052
1053
1054
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1052

def phone
  @phone
end