Class: Stripe::PaymentIntentCaptureParams::PaymentDetails::Flight::Passenger
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCaptureParams::PaymentDetails::Flight::Passenger
- Defined in:
- lib/stripe/params/payment_intent_capture_params.rb
Instance Attribute Summary collapse
-
#name ⇒ Object
Full name of the person or entity on the flight reservation.
Instance Method Summary collapse
-
#initialize(name: nil) ⇒ Passenger
constructor
A new instance of Passenger.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(name: nil) ⇒ Passenger
Returns a new instance of Passenger.
964 965 966 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 964 def initialize(name: nil) @name = name end |
Instance Attribute Details
#name ⇒ Object
Full name of the person or entity on the flight reservation.
962 963 964 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 962 def name @name end |