Class: Stripe::PaymentIntentCaptureParams::PaymentDetails::FlightDatum
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCaptureParams::PaymentDetails::FlightDatum
- Defined in:
- lib/stripe/params/payment_intent_capture_params.rb
Defined Under Namespace
Classes: Affiliate, Insurance, Passenger, Segment, Total
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details if applicable.
-
#booking_number ⇒ Object
Reservation reference.
-
#computerized_reservation_system ⇒ Object
Computerized reservation system used to make the reservation and purchase the ticket.
-
#endorsements_and_restrictions ⇒ Object
Ticket restrictions.
-
#insurances ⇒ Object
List of insurances.
-
#passengers ⇒ Object
List of passengers.
-
#segments ⇒ Object
List of flight segments.
-
#ticket_electronically_issued_indicator ⇒ Object
Electronic ticket indicator.
-
#total ⇒ Object
Total cost breakdown.
-
#transaction_type ⇒ Object
Type of flight transaction.
Instance Method Summary collapse
-
#initialize(affiliate: nil, booking_number: nil, computerized_reservation_system: nil, endorsements_and_restrictions: nil, insurances: nil, passengers: nil, segments: nil, ticket_electronically_issued_indicator: nil, total: nil, transaction_type: nil) ⇒ FlightDatum
constructor
A new instance of FlightDatum.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate: nil, booking_number: nil, computerized_reservation_system: nil, endorsements_and_restrictions: nil, insurances: nil, passengers: nil, segments: nil, ticket_electronically_issued_indicator: nil, total: nil, transaction_type: nil) ⇒ FlightDatum
Returns a new instance of FlightDatum.
1289 1290 1291 1292 1293 1294 1295 1296 1297 1298 1299 1300 1301 1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1289 def initialize( affiliate: nil, booking_number: nil, computerized_reservation_system: nil, endorsements_and_restrictions: nil, insurances: nil, passengers: nil, segments: nil, ticket_electronically_issued_indicator: nil, total: nil, transaction_type: nil ) @affiliate = affiliate @booking_number = booking_number @computerized_reservation_system = computerized_reservation_system @endorsements_and_restrictions = endorsements_and_restrictions @insurances = insurances @passengers = passengers @segments = segments @ticket_electronically_issued_indicator = ticket_electronically_issued_indicator @total = total @transaction_type = transaction_type end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details if applicable.
1269 1270 1271 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1269 def affiliate @affiliate end |
#booking_number ⇒ Object
Reservation reference.
1271 1272 1273 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1271 def booking_number @booking_number end |
#computerized_reservation_system ⇒ Object
Computerized reservation system used to make the reservation and purchase the ticket.
1273 1274 1275 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1273 def computerized_reservation_system @computerized_reservation_system end |
#endorsements_and_restrictions ⇒ Object
Ticket restrictions.
1275 1276 1277 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1275 def endorsements_and_restrictions @endorsements_and_restrictions end |
#insurances ⇒ Object
List of insurances.
1277 1278 1279 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1277 def insurances @insurances end |
#passengers ⇒ Object
List of passengers.
1279 1280 1281 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1279 def passengers @passengers end |
#segments ⇒ Object
List of flight segments.
1281 1282 1283 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1281 def segments @segments end |
#ticket_electronically_issued_indicator ⇒ Object
Electronic ticket indicator.
1283 1284 1285 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1283 def ticket_electronically_issued_indicator @ticket_electronically_issued_indicator end |
#total ⇒ Object
Total cost breakdown.
1285 1286 1287 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1285 def total @total end |
#transaction_type ⇒ Object
Type of flight transaction.
1287 1288 1289 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1287 def transaction_type @transaction_type end |