Class: Stripe::PaymentIntentCaptureParams::PaymentDetails::FlightDatum::Affiliate
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCaptureParams::PaymentDetails::FlightDatum::Affiliate
- Defined in:
- lib/stripe/params/payment_intent_capture_params.rb
Instance Attribute Summary collapse
-
#code ⇒ Object
Affiliate partner code.
-
#name ⇒ Object
Name of affiliate partner.
-
#travel_authorization_code ⇒ Object
Code provided by the company to a travel agent authorizing ticket issuance.
Instance Method Summary collapse
-
#initialize(code: nil, name: nil, travel_authorization_code: nil) ⇒ Affiliate
constructor
A new instance of Affiliate.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(code: nil, name: nil, travel_authorization_code: nil) ⇒ Affiliate
Returns a new instance of Affiliate.
1054 1055 1056 1057 1058 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1054 def initialize(code: nil, name: nil, travel_authorization_code: nil) @code = code @name = name @travel_authorization_code = end |
Instance Attribute Details
#code ⇒ Object
Affiliate partner code.
1048 1049 1050 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1048 def code @code end |
#name ⇒ Object
Name of affiliate partner.
1050 1051 1052 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1050 def name @name end |
#travel_authorization_code ⇒ Object
Code provided by the company to a travel agent authorizing ticket issuance.
1052 1053 1054 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1052 def @travel_authorization_code end |