Class: Stripe::PaymentIntentCaptureParams::PaymentDetails::Lodging

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_capture_params.rb

Defined Under Namespace

Classes: Address, Affiliate, Delivery, Passenger

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging

Returns a new instance of Lodging.



1543
1544
1545
1546
1547
1548
1549
1550
1551
1552
1553
1554
1555
1556
1557
1558
1559
1560
1561
1562
1563
1564
1565
1566
1567
1568
1569
1570
1571
1572
1573
1574
1575
1576
1577
1578
1579
1580
1581
1582
1583
1584
1585
1586
1587
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1543

def initialize(
  address: nil,
  adults: nil,
  affiliate: nil,
  booking_number: nil,
  category: nil,
  checkin_at: nil,
  checkout_at: nil,
  customer_service_phone_number: nil,
  daily_room_rate_amount: nil,
  delivery: nil,
  extra_charges: nil,
  fire_safety_act_compliance: nil,
  name: nil,
  no_show: nil,
  number_of_rooms: nil,
  passengers: nil,
  property_phone_number: nil,
  room_class: nil,
  room_nights: nil,
  total_room_tax_amount: nil,
  total_tax_amount: nil
)
  @address = address
  @adults = adults
  @affiliate = affiliate
  @booking_number = booking_number
  @category = category
  @checkin_at = checkin_at
  @checkout_at = checkout_at
  @customer_service_phone_number = customer_service_phone_number
  @daily_room_rate_amount = daily_room_rate_amount
  @delivery = delivery
  @extra_charges = extra_charges
  @fire_safety_act_compliance = fire_safety_act_compliance
  @name = name
  @no_show = no_show
  @number_of_rooms = number_of_rooms
  @passengers = passengers
  @property_phone_number = property_phone_number
  @room_class = room_class
  @room_nights = room_nights
  @total_room_tax_amount = total_room_tax_amount
  @total_tax_amount = total_tax_amount
end

Instance Attribute Details

#addressObject

The lodging location’s address.



1501
1502
1503
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1501

def address
  @address
end

#adultsObject

The number of adults on the booking



1503
1504
1505
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1503

def adults
  @adults
end

#affiliateObject

Affiliate details for this purchase.



1505
1506
1507
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1505

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the lodging reservation.



1507
1508
1509
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1507

def booking_number
  @booking_number
end

#categoryObject

The lodging category



1509
1510
1511
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1509

def category
  @category
end

#checkin_atObject

Lodging check-in time. Measured in seconds since the Unix epoch.



1511
1512
1513
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1511

def checkin_at
  @checkin_at
end

#checkout_atObject

Lodging check-out time. Measured in seconds since the Unix epoch.



1513
1514
1515
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1513

def checkout_at
  @checkout_at
end

#customer_service_phone_numberObject

The customer service phone number of the lodging company.



1515
1516
1517
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1515

def customer_service_phone_number
  @customer_service_phone_number
end

#daily_room_rate_amountObject

The daily lodging room rate.



1517
1518
1519
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1517

def daily_room_rate_amount
  @daily_room_rate_amount
end

#deliveryObject

Delivery details for this purchase.



1519
1520
1521
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1519

def delivery
  @delivery
end

#extra_chargesObject

List of additional charges being billed.



1521
1522
1523
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1521

def extra_charges
  @extra_charges
end

#fire_safety_act_complianceObject

Indicates whether the lodging location is compliant with the Fire Safety Act.



1523
1524
1525
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1523

def fire_safety_act_compliance
  @fire_safety_act_compliance
end

#nameObject

The name of the lodging location.



1525
1526
1527
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1525

def name
  @name
end

#no_showObject

Indicates if the customer did not keep their booking while failing to cancel the reservation.



1527
1528
1529
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1527

def no_show
  @no_show
end

#number_of_roomsObject

The number of rooms on the booking



1529
1530
1531
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1529

def number_of_rooms
  @number_of_rooms
end

#passengersObject

The details of the passengers in the travel reservation



1531
1532
1533
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1531

def passengers
  @passengers
end

#property_phone_numberObject

The phone number of the lodging location.



1533
1534
1535
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1533

def property_phone_number
  @property_phone_number
end

#room_classObject

The room class for this purchase.



1535
1536
1537
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1535

def room_class
  @room_class
end

#room_nightsObject

The number of room nights



1537
1538
1539
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1537

def room_nights
  @room_nights
end

#total_room_tax_amountObject

The total tax amount associating with the room reservation.



1539
1540
1541
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1539

def total_room_tax_amount
  @total_room_tax_amount
end

#total_tax_amountObject

The total tax amount



1541
1542
1543
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1541

def total_tax_amount
  @total_tax_amount
end