Class: Stripe::PaymentIntentCaptureParams::PaymentDetails::Lodging::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCaptureParams::PaymentDetails::Lodging::Delivery::Recipient
- Defined in:
- lib/stripe/params/payment_intent_capture_params.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
1475 1476 1477 1478 1479 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1475 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
1469 1470 1471 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1469 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
1471 1472 1473 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1471 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
1473 1474 1475 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1473 def phone @phone end |