Class: Stripe::PaymentIntentCaptureParams::PaymentDetails::Lodging::Passenger
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCaptureParams::PaymentDetails::Lodging::Passenger
- Defined in:
- lib/stripe/params/payment_intent_capture_params.rb
Instance Attribute Summary collapse
-
#name ⇒ Object
Full name of the person or entity on the lodging reservation.
Instance Method Summary collapse
-
#initialize(name: nil) ⇒ Passenger
constructor
A new instance of Passenger.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(name: nil) ⇒ Passenger
Returns a new instance of Passenger.
1385 1386 1387 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1385 def initialize(name: nil) @name = name end |
Instance Attribute Details
#name ⇒ Object
Full name of the person or entity on the lodging reservation.
1383 1384 1385 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1383 def name @name end |