Class: Stripe::PaymentIntentCaptureParams::PaymentDetails::LodgingDatum
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCaptureParams::PaymentDetails::LodgingDatum
- Defined in:
- lib/stripe/params/payment_intent_capture_params.rb
Defined Under Namespace
Classes: Accommodation, Affiliate, Guest, Host, Insurance, Total
Instance Attribute Summary collapse
-
#accommodation ⇒ Object
Accommodation details for the lodging.
-
#affiliate ⇒ Object
Affiliate details if applicable.
-
#booking_number ⇒ Object
Booking confirmation number for the lodging.
-
#checkin_at ⇒ Object
Check-in date.
-
#checkout_at ⇒ Object
Check-out date.
-
#customer_service_phone_number ⇒ Object
Customer service phone number for the lodging company.
-
#fire_safety_act_compliance_indicator ⇒ Object
Whether the lodging is compliant with any hotel fire safety regulations.
-
#guests ⇒ Object
List of guests for the lodging.
-
#host ⇒ Object
Host details for the lodging.
-
#insurances ⇒ Object
List of insurances for the lodging.
-
#no_show_indicator ⇒ Object
Whether the renter is a no-show.
-
#renter_id_number ⇒ Object
Renter ID number for the lodging.
-
#renter_name ⇒ Object
Renter name for the lodging.
-
#total ⇒ Object
Total details for the lodging.
Instance Method Summary collapse
-
#initialize(accommodation: nil, affiliate: nil, booking_number: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, fire_safety_act_compliance_indicator: nil, guests: nil, host: nil, insurances: nil, no_show_indicator: nil, renter_id_number: nil, renter_name: nil, total: nil) ⇒ LodgingDatum
constructor
A new instance of LodgingDatum.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(accommodation: nil, affiliate: nil, booking_number: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, fire_safety_act_compliance_indicator: nil, guests: nil, host: nil, insurances: nil, no_show_indicator: nil, renter_id_number: nil, renter_name: nil, total: nil) ⇒ LodgingDatum
Returns a new instance of LodgingDatum.
1851 1852 1853 1854 1855 1856 1857 1858 1859 1860 1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1851 def initialize( accommodation: nil, affiliate: nil, booking_number: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, fire_safety_act_compliance_indicator: nil, guests: nil, host: nil, insurances: nil, no_show_indicator: nil, renter_id_number: nil, renter_name: nil, total: nil ) @accommodation = accommodation @affiliate = affiliate @booking_number = booking_number @checkin_at = checkin_at @checkout_at = checkout_at @customer_service_phone_number = customer_service_phone_number @fire_safety_act_compliance_indicator = fire_safety_act_compliance_indicator @guests = guests @host = host @insurances = insurances @no_show_indicator = no_show_indicator @renter_id_number = renter_id_number @renter_name = renter_name @total = total end |
Instance Attribute Details
#accommodation ⇒ Object
Accommodation details for the lodging.
1823 1824 1825 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1823 def accommodation @accommodation end |
#affiliate ⇒ Object
Affiliate details if applicable.
1825 1826 1827 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1825 def affiliate @affiliate end |
#booking_number ⇒ Object
Booking confirmation number for the lodging.
1827 1828 1829 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1827 def booking_number @booking_number end |
#checkin_at ⇒ Object
Check-in date.
1829 1830 1831 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1829 def checkin_at @checkin_at end |
#checkout_at ⇒ Object
Check-out date.
1831 1832 1833 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1831 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object
Customer service phone number for the lodging company.
1833 1834 1835 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1833 def customer_service_phone_number @customer_service_phone_number end |
#fire_safety_act_compliance_indicator ⇒ Object
Whether the lodging is compliant with any hotel fire safety regulations.
1835 1836 1837 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1835 def fire_safety_act_compliance_indicator @fire_safety_act_compliance_indicator end |
#guests ⇒ Object
List of guests for the lodging.
1837 1838 1839 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1837 def guests @guests end |
#host ⇒ Object
Host details for the lodging.
1839 1840 1841 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1839 def host @host end |
#insurances ⇒ Object
List of insurances for the lodging.
1841 1842 1843 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1841 def insurances @insurances end |
#no_show_indicator ⇒ Object
Whether the renter is a no-show.
1843 1844 1845 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1843 def no_show_indicator @no_show_indicator end |
#renter_id_number ⇒ Object
Renter ID number for the lodging.
1845 1846 1847 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1845 def renter_id_number @renter_id_number end |
#renter_name ⇒ Object
Renter name for the lodging.
1847 1848 1849 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1847 def renter_name @renter_name end |
#total ⇒ Object
Total details for the lodging.
1849 1850 1851 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1849 def total @total end |