Class: Stripe::PaymentIntentCaptureParams::PaymentDetails::MoneyServices
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCaptureParams::PaymentDetails::MoneyServices
- Defined in:
- lib/stripe/params/payment_intent_capture_params.rb
Defined Under Namespace
Classes: AccountFunding
Instance Attribute Summary collapse
-
#account_funding ⇒ Object
Account funding transaction details including sender and beneficiary information.
-
#transaction_type ⇒ Object
The type of money services transaction.
Instance Method Summary collapse
-
#initialize(account_funding: nil, transaction_type: nil) ⇒ MoneyServices
constructor
A new instance of MoneyServices.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(account_funding: nil, transaction_type: nil) ⇒ MoneyServices
Returns a new instance of MoneyServices.
2043 2044 2045 2046 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 2043 def initialize(account_funding: nil, transaction_type: nil) @account_funding = account_funding @transaction_type = transaction_type end |
Instance Attribute Details
#account_funding ⇒ Object
Account funding transaction details including sender and beneficiary information.
2039 2040 2041 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 2039 def account_funding @account_funding end |
#transaction_type ⇒ Object
The type of money services transaction.
2041 2042 2043 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 2041 def transaction_type @transaction_type end |