Class: Stripe::PaymentIntentCaptureParams::PaymentDetails::Subscription::Affiliate
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCaptureParams::PaymentDetails::Subscription::Affiliate
- Defined in:
- lib/stripe/params/payment_intent_capture_params.rb
Instance Attribute Summary collapse
-
#name ⇒ Object
The name of the affiliate that originated the purchase.
Instance Method Summary collapse
-
#initialize(name: nil) ⇒ Affiliate
constructor
A new instance of Affiliate.
Methods inherited from RequestParams
Constructor Details
#initialize(name: nil) ⇒ Affiliate
Returns a new instance of Affiliate.
1749 1750 1751 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1749 def initialize(name: nil) @name = name end |
Instance Attribute Details
#name ⇒ Object
The name of the affiliate that originated the purchase.
1747 1748 1749 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1747 def name @name end |