Class: Stripe::PaymentIntentCaptureParams::PaymentDetails::Subscription::BillingInterval
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCaptureParams::PaymentDetails::Subscription::BillingInterval
- Defined in:
- lib/stripe/params/payment_intent_capture_params.rb
Instance Attribute Summary collapse
-
#count ⇒ Object
The number of intervals, as an whole number greater than 0.
-
#interval ⇒ Object
Specifies a type of interval unit.
Instance Method Summary collapse
-
#initialize(count: nil, interval: nil) ⇒ BillingInterval
constructor
A new instance of BillingInterval.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(count: nil, interval: nil) ⇒ BillingInterval
Returns a new instance of BillingInterval.
1955 1956 1957 1958 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1955 def initialize(count: nil, interval: nil) @count = count @interval = interval end |
Instance Attribute Details
#count ⇒ Object
The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.
1951 1952 1953 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1951 def count @count end |
#interval ⇒ Object
Specifies a type of interval unit. Either day, week, month or year.
1953 1954 1955 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1953 def interval @interval end |