Class: Stripe::PaymentIntentCaptureParams::TransferData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCaptureParams::TransferData
- Defined in:
- lib/stripe/params/payment_intent_capture_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount that will be transferred automatically when a charge succeeds.
Instance Method Summary collapse
-
#initialize(amount: nil) ⇒ TransferData
constructor
A new instance of TransferData.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil) ⇒ TransferData
Returns a new instance of TransferData.
235 236 237 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 235 def initialize(amount: nil) @amount = amount end |
Instance Attribute Details
#amount ⇒ Object
The amount that will be transferred automatically when a charge succeeds.
233 234 235 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 233 def amount @amount end |