Class: Stripe::PaymentIntentConfirmParams::AllocatedFunds
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::AllocatedFunds
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Whether Allocated Funds creation is enabled for this PaymentIntent.
Instance Method Summary collapse
-
#initialize(enabled: nil) ⇒ AllocatedFunds
constructor
A new instance of AllocatedFunds.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(enabled: nil) ⇒ AllocatedFunds
Returns a new instance of AllocatedFunds.
10 11 12 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 10 def initialize(enabled: nil) @enabled = enabled end |
Instance Attribute Details
#enabled ⇒ Object
Whether Allocated Funds creation is enabled for this PaymentIntent.
8 9 10 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 8 def enabled @enabled end |