Class: Stripe::PaymentIntentConfirmParams::AmountDetails::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::AmountDetails::LineItem
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Defined Under Namespace
Classes: PaymentMethodOptions, Tax
Instance Attribute Summary collapse
-
#discount_amount ⇒ Object
The amount an item was discounted for.
-
#payment_method_options ⇒ Object
Payment method-specific information for line items.
-
#product_code ⇒ Object
Unique identifier of the product.
-
#product_name ⇒ Object
Name of the product.
-
#quantity ⇒ Object
Number of items of the product.
-
#tax ⇒ Object
Contains information about the tax on the item.
-
#unit_cost ⇒ Object
Cost of the product.
-
#unit_of_measure ⇒ Object
A unit of measure for the line item, such as gallons, feet, meters, etc.
Instance Method Summary collapse
-
#initialize(discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil) ⇒ LineItem
Returns a new instance of LineItem.
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 98 def initialize( discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil ) @discount_amount = discount_amount @payment_method_options = @product_code = product_code @product_name = product_name @quantity = quantity @tax = tax @unit_cost = unit_cost @unit_of_measure = unit_of_measure end |
Instance Attribute Details
#discount_amount ⇒ Object
The amount an item was discounted for. Positive integer.
82 83 84 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 82 def discount_amount @discount_amount end |
#payment_method_options ⇒ Object
Payment method-specific information for line items.
84 85 86 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 84 def @payment_method_options end |
#product_code ⇒ Object
Unique identifier of the product. At most 12 characters long.
86 87 88 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 86 def product_code @product_code end |
#product_name ⇒ Object
Name of the product. At most 100 characters long.
88 89 90 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 88 def product_name @product_name end |
#quantity ⇒ Object
Number of items of the product. Positive integer.
90 91 92 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 90 def quantity @quantity end |
#tax ⇒ Object
Contains information about the tax on the item.
92 93 94 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 92 def tax @tax end |
#unit_cost ⇒ Object
Cost of the product. Non-negative integer.
94 95 96 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 94 def unit_cost @unit_cost end |
#unit_of_measure ⇒ Object
A unit of measure for the line item, such as gallons, feet, meters, etc.
96 97 98 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 96 def unit_of_measure @unit_of_measure end |