Class: Stripe::PaymentIntentConfirmParams::AmountDetails::LineItem::PaymentMethodOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::AmountDetails::LineItem::PaymentMethodOptions
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Defined Under Namespace
Classes: Card, CardPresent, Klarna, Paypal
Instance Attribute Summary collapse
-
#card ⇒ Object
This sub-hash contains line item details that are specific to the ‘card` payment method.
-
#card_present ⇒ Object
This sub-hash contains line item details that are specific to the ‘card_present` payment method.
-
#klarna ⇒ Object
This sub-hash contains line item details that are specific to the ‘klarna` payment method.
-
#paypal ⇒ Object
This sub-hash contains line item details that are specific to the ‘paypal` payment method.
Instance Method Summary collapse
-
#initialize(card: nil, card_present: nil, klarna: nil, paypal: nil) ⇒ PaymentMethodOptions
constructor
A new instance of PaymentMethodOptions.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(card: nil, card_present: nil, klarna: nil, paypal: nil) ⇒ PaymentMethodOptions
Returns a new instance of PaymentMethodOptions.
96 97 98 99 100 101 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 96 def initialize(card: nil, card_present: nil, klarna: nil, paypal: nil) @card = card @card_present = card_present @klarna = klarna @paypal = paypal end |
Instance Attribute Details
#card ⇒ Object
This sub-hash contains line item details that are specific to the ‘card` payment method.
88 89 90 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 88 def card @card end |
#card_present ⇒ Object
This sub-hash contains line item details that are specific to the ‘card_present` payment method.
90 91 92 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 90 def card_present @card_present end |
#klarna ⇒ Object
This sub-hash contains line item details that are specific to the ‘klarna` payment method.
92 93 94 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 92 def klarna @klarna end |
#paypal ⇒ Object
This sub-hash contains line item details that are specific to the ‘paypal` payment method.
94 95 96 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 94 def paypal @paypal end |