Class: Stripe::PaymentIntentConfirmParams::AmountDetails::LineItem::PaymentMethodOptions::Card
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::AmountDetails::LineItem::PaymentMethodOptions::Card
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Defined Under Namespace
Classes: EvCharging, FleetData
Instance Attribute Summary collapse
-
#commodity_code ⇒ Object
Identifier that categorizes the items being purchased using a standardized commodity scheme such as (but not limited to) UNSPSC, NAICS, NAPCS, and so on.
-
#ev_charging ⇒ Object
EV charging data for this line item.
-
#fleet_data ⇒ Object
Fleet data for this line item.
Instance Method Summary collapse
-
#initialize(commodity_code: nil, ev_charging: nil, fleet_data: nil) ⇒ Card
constructor
A new instance of Card.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(commodity_code: nil, ev_charging: nil, fleet_data: nil) ⇒ Card
Returns a new instance of Card.
76 77 78 79 80 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 76 def initialize(commodity_code: nil, ev_charging: nil, fleet_data: nil) @commodity_code = commodity_code @ev_charging = ev_charging @fleet_data = fleet_data end |
Instance Attribute Details
#commodity_code ⇒ Object
Identifier that categorizes the items being purchased using a standardized commodity scheme such as (but not limited to) UNSPSC, NAICS, NAPCS, and so on.
70 71 72 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 70 def commodity_code @commodity_code end |
#ev_charging ⇒ Object
EV charging data for this line item.
72 73 74 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 72 def ev_charging @ev_charging end |
#fleet_data ⇒ Object
Fleet data for this line item.
74 75 76 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 74 def fleet_data @fleet_data end |