Class: Stripe::PaymentIntentConfirmParams::AmountDetails::LineItem::PaymentMethodOptions::Klarna
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::AmountDetails::LineItem::PaymentMethodOptions::Klarna
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Instance Attribute Summary collapse
-
#image_url ⇒ Object
URL to an image for the product.
-
#product_url ⇒ Object
URL to the product page.
-
#reference ⇒ Object
Unique reference for this line item to correlate it with your system’s internal records.
-
#subscription_reference ⇒ Object
Reference for the subscription this line item is for.
Instance Method Summary collapse
-
#initialize(image_url: nil, product_url: nil, reference: nil, subscription_reference: nil) ⇒ Klarna
constructor
A new instance of Klarna.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(image_url: nil, product_url: nil, reference: nil, subscription_reference: nil) ⇒ Klarna
Returns a new instance of Klarna.
60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 60 def initialize( image_url: nil, product_url: nil, reference: nil, subscription_reference: nil ) @image_url = image_url @product_url = product_url @reference = reference @subscription_reference = subscription_reference end |
Instance Attribute Details
#image_url ⇒ Object
URL to an image for the product. Max length, 4096 characters.
52 53 54 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 52 def image_url @image_url end |
#product_url ⇒ Object
URL to the product page. Max length, 4096 characters.
54 55 56 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 54 def product_url @product_url end |
#reference ⇒ Object
Unique reference for this line item to correlate it with your system’s internal records. The field is displayed in the Klarna Consumer App if passed.
56 57 58 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 56 def reference @reference end |
#subscription_reference ⇒ Object
Reference for the subscription this line item is for.
58 59 60 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 58 def subscription_reference @subscription_reference end |