Class: Stripe::PaymentIntentConfirmParams::AmountDetails::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, from_postal_code: nil, to_postal_code: nil) ⇒ Shipping

Returns a new instance of Shipping.



210
211
212
213
214
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 210

def initialize(amount: nil, from_postal_code: nil, to_postal_code: nil)
  @amount = amount
  @from_postal_code = from_postal_code
  @to_postal_code = to_postal_code
end

Instance Attribute Details

#amountObject

If a physical good is being shipped, the cost of shipping represented in the smallest currency unit. An integer greater than or equal to 0.



204
205
206
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 204

def amount
  @amount
end

#from_postal_codeObject

If a physical good is being shipped, the postal code of where it is being shipped from. At most 10 alphanumeric characters long, hyphens and spaces are allowed.



206
207
208
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 206

def from_postal_code
  @from_postal_code
end

#to_postal_codeObject

If a physical good is being shipped, the postal code of where it is being shipped to. At most 10 alphanumeric characters long, hyphens and spaces are allowed.



208
209
210
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 208

def to_postal_code
  @to_postal_code
end