Class: Stripe::PaymentIntentConfirmParams::AmountDetails::Surcharge

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, enforce_validation: nil) ⇒ Surcharge

Returns a new instance of Surcharge.



223
224
225
226
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 223

def initialize(amount: nil, enforce_validation: nil)
  @amount = amount
  @enforce_validation = enforce_validation
end

Instance Attribute Details

#amountObject

Portion of the amount that corresponds to a surcharge.



219
220
221
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 219

def amount
  @amount
end

#enforce_validationObject

Indicate whether to enforce validations on the surcharge amount.



221
222
223
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 221

def enforce_validation
  @enforce_validation
end