Class: Stripe::PaymentIntentConfirmParams::MandateData::CustomerAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Defined Under Namespace

Classes: Offline, Online

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(accepted_at: nil, offline: nil, online: nil, type: nil) ⇒ CustomerAcceptance

Returns a new instance of CustomerAcceptance.



255
256
257
258
259
260
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 255

def initialize(accepted_at: nil, offline: nil, online: nil, type: nil)
  @accepted_at = accepted_at
  @offline = offline
  @online = online
  @type = type
end

Instance Attribute Details

#accepted_atObject

The time at which the customer accepted the Mandate.



247
248
249
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 247

def accepted_at
  @accepted_at
end

#offlineObject

If this is a Mandate accepted offline, this hash contains details about the offline acceptance.



249
250
251
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 249

def offline
  @offline
end

#onlineObject

If this is a Mandate accepted online, this hash contains details about the online acceptance.



251
252
253
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 251

def online
  @online
end

#typeObject

The type of customer acceptance information included with the Mandate. One of ‘online` or `offline`.



253
254
255
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 253

def type
  @type
end