Class: Stripe::PaymentIntentConfirmParams::MandateData::CustomerAcceptance::Online

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(ip_address: nil, user_agent: nil) ⇒ Online

Returns a new instance of Online.



241
242
243
244
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 241

def initialize(ip_address: nil, user_agent: nil)
  @ip_address = ip_address
  @user_agent = user_agent
end

Instance Attribute Details

#ip_addressObject

The IP address from which the Mandate was accepted by the customer.



237
238
239
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 237

def ip_address
  @ip_address
end

#user_agentObject

The user agent of the browser from which the Mandate was accepted by the customer.



239
240
241
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 239

def user_agent
  @user_agent
end