Class: Stripe::PaymentIntentConfirmParams::PaymentDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Defined Under Namespace

Classes: Benefit, CarRental, CarRentalDatum, EventDetails, FleetDatum, Flight, FlightDatum, Lodging, LodgingDatum, MoneyServices, Subscription

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(benefit: nil, car_rental: nil, car_rental_data: nil, customer_reference: nil, event_details: nil, fleet_data: nil, flight: nil, flight_data: nil, location: nil, lodging: nil, lodging_data: nil, money_services: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails

Returns a new instance of PaymentDetails.



2268
2269
2270
2271
2272
2273
2274
2275
2276
2277
2278
2279
2280
2281
2282
2283
2284
2285
2286
2287
2288
2289
2290
2291
2292
2293
2294
2295
2296
2297
2298
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2268

def initialize(
  benefit: nil,
  car_rental: nil,
  car_rental_data: nil,
  customer_reference: nil,
  event_details: nil,
  fleet_data: nil,
  flight: nil,
  flight_data: nil,
  location: nil,
  lodging: nil,
  lodging_data: nil,
  money_services: nil,
  order_reference: nil,
  subscription: nil
)
  @benefit = benefit
  @car_rental = car_rental
  @car_rental_data = car_rental_data
  @customer_reference = customer_reference
  @event_details = event_details
  @fleet_data = fleet_data
  @flight = flight
  @flight_data = flight_data
  @location = location
  @lodging = lodging
  @lodging_data = lodging_data
  @money_services = money_services
  @order_reference = order_reference
  @subscription = subscription
end

Instance Attribute Details

#benefitObject

Benefit details for this PaymentIntent



2236
2237
2238
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2236

def benefit
  @benefit
end

#car_rentalObject

Car rental details for this PaymentIntent.



2238
2239
2240
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2238

def car_rental
  @car_rental
end

#car_rental_dataObject

Car rental data for this PaymentIntent.



2240
2241
2242
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2240

def car_rental_data
  @car_rental_data
end

#customer_referenceObject

A unique value to identify the customer. This field is available only for card payments.

This field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks.



2244
2245
2246
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2244

def customer_reference
  @customer_reference
end

#event_detailsObject

Event details for this PaymentIntent



2246
2247
2248
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2246

def event_details
  @event_details
end

#fleet_dataObject

Fleet data for this PaymentIntent.



2248
2249
2250
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2248

def fleet_data
  @fleet_data
end

#flightObject

Flight reservation details for this PaymentIntent



2250
2251
2252
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2250

def flight
  @flight
end

#flight_dataObject

Flight data for this PaymentIntent.



2252
2253
2254
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2252

def flight_data
  @flight_data
end

#locationObject

The ID of the Payment Location for this PaymentIntent.



2254
2255
2256
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2254

def location
  @location
end

#lodgingObject

Lodging reservation details for this PaymentIntent



2256
2257
2258
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2256

def lodging
  @lodging
end

#lodging_dataObject

Lodging data for this PaymentIntent.



2258
2259
2260
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2258

def lodging_data
  @lodging_data
end

#money_servicesObject

Money services details for this PaymentIntent.



2260
2261
2262
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2260

def money_services
  @money_services
end

#order_referenceObject

A unique value assigned by the business to identify the transaction. Required for L2 and L3 rates.

For Cards, this field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks. For Klarna, this field is truncated to 255 characters and is visible to customers when they view the order in the Klarna app.



2264
2265
2266
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2264

def order_reference
  @order_reference
end

#subscriptionObject

Subscription details for this PaymentIntent



2266
2267
2268
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2266

def subscription
  @subscription
end