Class: Stripe::PaymentIntentConfirmParams::PaymentDetails::Benefit::FrMealVoucher
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentDetails::Benefit::FrMealVoucher
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Whether to enable meal voucher benefit for this payment.
-
#siret ⇒ Object
The 14-digit SIRET of the meal voucher acceptor.
Instance Method Summary collapse
-
#initialize(enabled: nil, siret: nil) ⇒ FrMealVoucher
constructor
A new instance of FrMealVoucher.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(enabled: nil, siret: nil) ⇒ FrMealVoucher
Returns a new instance of FrMealVoucher.
305 306 307 308 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 305 def initialize(enabled: nil, siret: nil) @enabled = enabled @siret = siret end |
Instance Attribute Details
#enabled ⇒ Object
Whether to enable meal voucher benefit for this payment.
301 302 303 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 301 def enabled @enabled end |
#siret ⇒ Object
The 14-digit SIRET of the meal voucher acceptor.
303 304 305 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 303 def siret @siret end |