Class: Stripe::PaymentIntentConfirmParams::PaymentDetails::CarRental::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



392
393
394
395
396
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 392

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



386
387
388
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 386

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



388
389
390
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 388

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



390
391
392
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 390

def phone
  @phone
end