Class: Stripe::PaymentIntentConfirmParams::PaymentDetails::CarRentalDatum
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentDetails::CarRentalDatum
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Defined Under Namespace
Classes: Affiliate, Distance, Driver, DropOff, Insurance, Pickup, Total, Vehicle
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate (such as travel agency) details for the rental.
-
#booking_number ⇒ Object
Booking confirmation number for the car rental.
-
#carrier_name ⇒ Object
Name of the car rental company.
-
#customer_service_phone_number ⇒ Object
Customer service phone number for the car rental company.
-
#days_rented ⇒ Object
Number of days the car is being rented.
-
#distance ⇒ Object
Distance details for the rental.
-
#drivers ⇒ Object
List of drivers for the rental.
-
#drop_off ⇒ Object
Drop-off location details.
-
#insurances ⇒ Object
Insurance details for the rental.
-
#no_show_indicator ⇒ Object
Indicates if the customer was a no-show.
-
#pickup ⇒ Object
Pickup location details.
-
#renter_name ⇒ Object
Name of the person renting the vehicle.
-
#total ⇒ Object
Total cost breakdown for the rental.
-
#vehicle ⇒ Object
Vehicle details for the rental.
Instance Method Summary collapse
-
#initialize(affiliate: nil, booking_number: nil, carrier_name: nil, customer_service_phone_number: nil, days_rented: nil, distance: nil, drivers: nil, drop_off: nil, insurances: nil, no_show_indicator: nil, pickup: nil, renter_name: nil, total: nil, vehicle: nil) ⇒ CarRentalDatum
constructor
A new instance of CarRentalDatum.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate: nil, booking_number: nil, carrier_name: nil, customer_service_phone_number: nil, days_rented: nil, distance: nil, drivers: nil, drop_off: nil, insurances: nil, no_show_indicator: nil, pickup: nil, renter_name: nil, total: nil, vehicle: nil) ⇒ CarRentalDatum
Returns a new instance of CarRentalDatum.
924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 924 def initialize( affiliate: nil, booking_number: nil, carrier_name: nil, customer_service_phone_number: nil, days_rented: nil, distance: nil, drivers: nil, drop_off: nil, insurances: nil, no_show_indicator: nil, pickup: nil, renter_name: nil, total: nil, vehicle: nil ) @affiliate = affiliate @booking_number = booking_number @carrier_name = carrier_name @customer_service_phone_number = customer_service_phone_number @days_rented = days_rented @distance = distance @drivers = drivers @drop_off = drop_off @insurances = insurances @no_show_indicator = no_show_indicator @pickup = pickup @renter_name = renter_name @total = total @vehicle = vehicle end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate (such as travel agency) details for the rental.
896 897 898 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 896 def affiliate @affiliate end |
#booking_number ⇒ Object
Booking confirmation number for the car rental.
898 899 900 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 898 def booking_number @booking_number end |
#carrier_name ⇒ Object
Name of the car rental company.
900 901 902 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 900 def carrier_name @carrier_name end |
#customer_service_phone_number ⇒ Object
Customer service phone number for the car rental company.
902 903 904 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 902 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object
Number of days the car is being rented.
904 905 906 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 904 def days_rented @days_rented end |
#distance ⇒ Object
Distance details for the rental.
906 907 908 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 906 def distance @distance end |
#drivers ⇒ Object
List of drivers for the rental.
908 909 910 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 908 def drivers @drivers end |
#drop_off ⇒ Object
Drop-off location details.
910 911 912 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 910 def drop_off @drop_off end |
#insurances ⇒ Object
Insurance details for the rental.
912 913 914 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 912 def insurances @insurances end |
#no_show_indicator ⇒ Object
Indicates if the customer was a no-show.
914 915 916 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 914 def no_show_indicator @no_show_indicator end |
#pickup ⇒ Object
Pickup location details.
916 917 918 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 916 def pickup @pickup end |
#renter_name ⇒ Object
Name of the person renting the vehicle.
918 919 920 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 918 def renter_name @renter_name end |
#total ⇒ Object
Total cost breakdown for the rental.
920 921 922 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 920 def total @total end |
#vehicle ⇒ Object
Vehicle details for the rental.
922 923 924 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 922 def vehicle @vehicle end |