Class: Stripe::PaymentIntentConfirmParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 955 956 957 958 959 960 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 940 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
922 923 924 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 922 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
924 925 926 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 924 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
926 927 928 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 926 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
928 929 930 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 928 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
930 931 932 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 930 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
932 933 934 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 932 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
934 935 936 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 934 def genre @genre end |
#name ⇒ Object
The name of the event.
936 937 938 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 936 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
938 939 940 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 938 def starts_at @starts_at end |