Class: Stripe::PaymentIntentConfirmParams::PaymentDetails::Flight::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



1177
1178
1179
1180
1181
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1177

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



1171
1172
1173
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1171

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



1173
1174
1175
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1173

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



1175
1176
1177
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1175

def phone
  @phone
end