Class: Stripe::PaymentIntentConfirmParams::PaymentDetails::FlightDatum
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentDetails::FlightDatum
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Defined Under Namespace
Classes: Affiliate, Insurance, Passenger, Segment, Total
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details if applicable.
-
#booking_number ⇒ Object
Reservation reference.
-
#computerized_reservation_system ⇒ Object
Computerized reservation system used to make the reservation and purchase the ticket.
-
#endorsements_and_restrictions ⇒ Object
Ticket restrictions.
-
#insurances ⇒ Object
List of insurances.
-
#passengers ⇒ Object
List of passengers.
-
#segments ⇒ Object
List of flight segments.
-
#ticket_electronically_issued_indicator ⇒ Object
Electronic ticket indicator.
-
#total ⇒ Object
Total cost breakdown.
-
#transaction_type ⇒ Object
Type of flight transaction.
Instance Method Summary collapse
-
#initialize(affiliate: nil, booking_number: nil, computerized_reservation_system: nil, endorsements_and_restrictions: nil, insurances: nil, passengers: nil, segments: nil, ticket_electronically_issued_indicator: nil, total: nil, transaction_type: nil) ⇒ FlightDatum
constructor
A new instance of FlightDatum.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate: nil, booking_number: nil, computerized_reservation_system: nil, endorsements_and_restrictions: nil, insurances: nil, passengers: nil, segments: nil, ticket_electronically_issued_indicator: nil, total: nil, transaction_type: nil) ⇒ FlightDatum
Returns a new instance of FlightDatum.
1468 1469 1470 1471 1472 1473 1474 1475 1476 1477 1478 1479 1480 1481 1482 1483 1484 1485 1486 1487 1488 1489 1490 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1468 def initialize( affiliate: nil, booking_number: nil, computerized_reservation_system: nil, endorsements_and_restrictions: nil, insurances: nil, passengers: nil, segments: nil, ticket_electronically_issued_indicator: nil, total: nil, transaction_type: nil ) @affiliate = affiliate @booking_number = booking_number @computerized_reservation_system = computerized_reservation_system @endorsements_and_restrictions = endorsements_and_restrictions @insurances = insurances @passengers = passengers @segments = segments @ticket_electronically_issued_indicator = ticket_electronically_issued_indicator @total = total @transaction_type = transaction_type end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details if applicable.
1448 1449 1450 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1448 def affiliate @affiliate end |
#booking_number ⇒ Object
Reservation reference.
1450 1451 1452 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1450 def booking_number @booking_number end |
#computerized_reservation_system ⇒ Object
Computerized reservation system used to make the reservation and purchase the ticket.
1452 1453 1454 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1452 def computerized_reservation_system @computerized_reservation_system end |
#endorsements_and_restrictions ⇒ Object
Ticket restrictions.
1454 1455 1456 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1454 def endorsements_and_restrictions @endorsements_and_restrictions end |
#insurances ⇒ Object
List of insurances.
1456 1457 1458 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1456 def insurances @insurances end |
#passengers ⇒ Object
List of passengers.
1458 1459 1460 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1458 def passengers @passengers end |
#segments ⇒ Object
List of flight segments.
1460 1461 1462 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1460 def segments @segments end |
#ticket_electronically_issued_indicator ⇒ Object
Electronic ticket indicator.
1462 1463 1464 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1462 def ticket_electronically_issued_indicator @ticket_electronically_issued_indicator end |
#total ⇒ Object
Total cost breakdown.
1464 1465 1466 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1464 def total @total end |
#transaction_type ⇒ Object
Type of flight transaction.
1466 1467 1468 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1466 def transaction_type @transaction_type end |