Class: Stripe::PaymentIntentConfirmParams::PaymentDetails::Lodging::Affiliate
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentDetails::Lodging::Affiliate
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Instance Attribute Summary collapse
-
#name ⇒ Object
The name of the affiliate that originated the purchase.
Instance Method Summary collapse
-
#initialize(name: nil) ⇒ Affiliate
constructor
A new instance of Affiliate.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(name: nil) ⇒ Affiliate
Returns a new instance of Affiliate.
1389 1390 1391 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1389 def initialize(name: nil) @name = name end |
Instance Attribute Details
#name ⇒ Object
The name of the affiliate that originated the purchase.
1387 1388 1389 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1387 def name @name end |