Class: Stripe::PaymentIntentConfirmParams::PaymentDetails::Lodging::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentDetails::Lodging::Delivery::Recipient
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
1598 1599 1600 1601 1602 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1598 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
1592 1593 1594 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1592 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
1594 1595 1596 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1594 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
1596 1597 1598 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1596 def phone @phone end |