Class: Stripe::PaymentIntentConfirmParams::PaymentDetails::MoneyServices
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentDetails::MoneyServices
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Defined Under Namespace
Classes: AccountFunding, BeneficiaryDetails
Instance Attribute Summary collapse
-
#account_funding ⇒ Object
Account funding transaction details including sender information.
-
#beneficiary_details ⇒ Object
Inline identity details for the beneficiary of this transaction.
-
#transaction_type ⇒ Object
The type of money services transaction.
Instance Method Summary collapse
-
#initialize(account_funding: nil, beneficiary_details: nil, transaction_type: nil) ⇒ MoneyServices
constructor
A new instance of MoneyServices.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(account_funding: nil, beneficiary_details: nil, transaction_type: nil) ⇒ MoneyServices
Returns a new instance of MoneyServices.
2178 2179 2180 2181 2182 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2178 def initialize(account_funding: nil, beneficiary_details: nil, transaction_type: nil) @account_funding = account_funding @beneficiary_details = beneficiary_details @transaction_type = transaction_type end |
Instance Attribute Details
#account_funding ⇒ Object
Account funding transaction details including sender information.
2172 2173 2174 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2172 def account_funding @account_funding end |
#beneficiary_details ⇒ Object
Inline identity details for the beneficiary of this transaction.
2174 2175 2176 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2174 def beneficiary_details @beneficiary_details end |
#transaction_type ⇒ Object
The type of money services transaction.
2176 2177 2178 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2176 def transaction_type @transaction_type end |