Class: Stripe::PaymentIntentConfirmParams::PaymentDetails::MoneyServices::AccountFunding
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentDetails::MoneyServices::AccountFunding
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Defined Under Namespace
Classes: SenderDetails
Instance Attribute Summary collapse
-
#sender_details ⇒ Object
Inline identity details for the sender of this account funding transaction.
Instance Method Summary collapse
-
#initialize(sender_details: nil) ⇒ AccountFunding
constructor
A new instance of AccountFunding.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(sender_details: nil) ⇒ AccountFunding
Returns a new instance of AccountFunding.
2087 2088 2089 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2087 def initialize(sender_details: nil) @sender_details = sender_details end |
Instance Attribute Details
#sender_details ⇒ Object
Inline identity details for the sender of this account funding transaction.
2085 2086 2087 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2085 def sender_details @sender_details end |