Class: Stripe::PaymentIntentConfirmParams::PaymentDetails::Subscription::BillingInterval

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(count: nil, interval: nil) ⇒ BillingInterval

Returns a new instance of BillingInterval.



2133
2134
2135
2136
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2133

def initialize(count: nil, interval: nil)
  @count = count
  @interval = interval
end

Instance Attribute Details

#countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



2129
2130
2131
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2129

def count
  @count
end

#intervalObject

Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.



2131
2132
2133
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2131

def interval
  @interval
end