Class: Stripe::PaymentIntentConfirmParams::PaymentMethodData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Defined Under Namespace

Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, BillingDetails, Bizum, Blik, Boleto, Cashapp, Crypto, CustomerBalance, Eps, Fpx, Giropay, Grabpay, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Payto, Pix, Promptpay, RadarOptions, RevolutPay, SamsungPay, Satispay, Scalapay, SepaDebit, Sofort, Sunbit, Swish, Twint, Upi, UsBankAccount, WechatPay, Zip

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, allow_redisplay: nil, alma: nil, amazon_pay: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, billie: nil, billing_details: nil, bizum: nil, blik: nil, boleto: nil, cashapp: nil, crypto: nil, customer_balance: nil, eps: nil, fpx: nil, giropay: nil, grabpay: nil, ideal: nil, interac_present: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, mb_way: nil, metadata: nil, mobilepay: nil, multibanco: nil, naver_pay: nil, nz_bank_account: nil, oxxo: nil, p24: nil, pay_by_bank: nil, payco: nil, paynow: nil, paypal: nil, payto: nil, pix: nil, promptpay: nil, radar_options: nil, revolut_pay: nil, samsung_pay: nil, satispay: nil, scalapay: nil, sepa_debit: nil, sofort: nil, sunbit: nil, swish: nil, twint: nil, type: nil, upi: nil, us_bank_account: nil, wechat_pay: nil, zip: nil) ⇒ PaymentMethodData

Returns a new instance of PaymentMethodData.



736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
841
842
843
844
845
846
847
848
849
850
851
852
853
854
855
856
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 736

def initialize(
  acss_debit: nil,
  affirm: nil,
  afterpay_clearpay: nil,
  alipay: nil,
  allow_redisplay: nil,
  alma: nil,
  amazon_pay: nil,
  au_becs_debit: nil,
  bacs_debit: nil,
  bancontact: nil,
  billie: nil,
  billing_details: nil,
  bizum: nil,
  blik: nil,
  boleto: nil,
  cashapp: nil,
  crypto: nil,
  customer_balance: nil,
  eps: nil,
  fpx: nil,
  giropay: nil,
  grabpay: nil,
  ideal: nil,
  interac_present: nil,
  kakao_pay: nil,
  klarna: nil,
  konbini: nil,
  kr_card: nil,
  link: nil,
  mb_way: nil,
  metadata: nil,
  mobilepay: nil,
  multibanco: nil,
  naver_pay: nil,
  nz_bank_account: nil,
  oxxo: nil,
  p24: nil,
  pay_by_bank: nil,
  payco: nil,
  paynow: nil,
  paypal: nil,
  payto: nil,
  pix: nil,
  promptpay: nil,
  radar_options: nil,
  revolut_pay: nil,
  samsung_pay: nil,
  satispay: nil,
  scalapay: nil,
  sepa_debit: nil,
  sofort: nil,
  sunbit: nil,
  swish: nil,
  twint: nil,
  type: nil,
  upi: nil,
  us_bank_account: nil,
  wechat_pay: nil,
  zip: nil
)
  @acss_debit = acss_debit
  @affirm = affirm
  @afterpay_clearpay = afterpay_clearpay
  @alipay = alipay
  @allow_redisplay = allow_redisplay
  @alma = alma
  @amazon_pay = amazon_pay
  @au_becs_debit = au_becs_debit
  @bacs_debit = bacs_debit
  @bancontact = bancontact
  @billie = billie
  @billing_details = billing_details
  @bizum = bizum
  @blik = blik
  @boleto = boleto
  @cashapp = cashapp
  @crypto = crypto
  @customer_balance = customer_balance
  @eps = eps
  @fpx = fpx
  @giropay = giropay
  @grabpay = grabpay
  @ideal = ideal
  @interac_present = interac_present
  @kakao_pay = kakao_pay
  @klarna = klarna
  @konbini = konbini
  @kr_card = kr_card
  @link = link
  @mb_way = mb_way
  @metadata = 
  @mobilepay = mobilepay
  @multibanco = multibanco
  @naver_pay = naver_pay
  @nz_bank_account = 
  @oxxo = oxxo
  @p24 = p24
  @pay_by_bank = pay_by_bank
  @payco = payco
  @paynow = paynow
  @paypal = paypal
  @payto = payto
  @pix = pix
  @promptpay = promptpay
  @radar_options = radar_options
  @revolut_pay = revolut_pay
  @samsung_pay = samsung_pay
  @satispay = satispay
  @scalapay = scalapay
  @sepa_debit = sepa_debit
  @sofort = sofort
  @sunbit = sunbit
  @swish = swish
  @twint = twint
  @type = type
  @upi = upi
  @us_bank_account = 
  @wechat_pay = wechat_pay
  @zip = zip
end

Instance Attribute Details

#acss_debitObject

If this is an ‘acss_debit` PaymentMethod, this hash contains details about the ACSS Debit payment method.



618
619
620
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 618

def acss_debit
  @acss_debit
end

#affirmObject

If this is an ‘affirm` PaymentMethod, this hash contains details about the Affirm payment method.



620
621
622
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 620

def affirm
  @affirm
end

#afterpay_clearpayObject

If this is an ‘AfterpayClearpay` PaymentMethod, this hash contains details about the AfterpayClearpay payment method.



622
623
624
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 622

def afterpay_clearpay
  @afterpay_clearpay
end

#alipayObject

If this is an ‘Alipay` PaymentMethod, this hash contains details about the Alipay payment method.



624
625
626
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 624

def alipay
  @alipay
end

#allow_redisplayObject

This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. The field defaults to ‘unspecified`.



626
627
628
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 626

def allow_redisplay
  @allow_redisplay
end

#almaObject

If this is a Alma PaymentMethod, this hash contains details about the Alma payment method.



628
629
630
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 628

def alma
  @alma
end

#amazon_payObject

If this is a AmazonPay PaymentMethod, this hash contains details about the AmazonPay payment method.



630
631
632
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 630

def amazon_pay
  @amazon_pay
end

#au_becs_debitObject

If this is an ‘au_becs_debit` PaymentMethod, this hash contains details about the bank account.



632
633
634
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 632

def au_becs_debit
  @au_becs_debit
end

#bacs_debitObject

If this is a ‘bacs_debit` PaymentMethod, this hash contains details about the Bacs Direct Debit bank account.



634
635
636
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 634

def bacs_debit
  @bacs_debit
end

#bancontactObject

If this is a ‘bancontact` PaymentMethod, this hash contains details about the Bancontact payment method.



636
637
638
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 636

def bancontact
  @bancontact
end

#billieObject

If this is a ‘billie` PaymentMethod, this hash contains details about the Billie payment method.



638
639
640
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 638

def billie
  @billie
end

#billing_detailsObject

Billing information associated with the PaymentMethod that may be used or required by particular types of payment methods.



640
641
642
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 640

def billing_details
  @billing_details
end

#bizumObject

If this is a ‘bizum` PaymentMethod, this hash contains details about the Bizum payment method.



642
643
644
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 642

def bizum
  @bizum
end

#blikObject

If this is a ‘blik` PaymentMethod, this hash contains details about the BLIK payment method.



644
645
646
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 644

def blik
  @blik
end

#boletoObject

If this is a ‘boleto` PaymentMethod, this hash contains details about the Boleto payment method.



646
647
648
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 646

def boleto
  @boleto
end

#cashappObject

If this is a ‘cashapp` PaymentMethod, this hash contains details about the Cash App Pay payment method.



648
649
650
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 648

def cashapp
  @cashapp
end

#cryptoObject

If this is a Crypto PaymentMethod, this hash contains details about the Crypto payment method.



650
651
652
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 650

def crypto
  @crypto
end

#customer_balanceObject

If this is a ‘customer_balance` PaymentMethod, this hash contains details about the CustomerBalance payment method.



652
653
654
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 652

def customer_balance
  @customer_balance
end

#epsObject

If this is an ‘eps` PaymentMethod, this hash contains details about the EPS payment method.



654
655
656
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 654

def eps
  @eps
end

#fpxObject

If this is an ‘fpx` PaymentMethod, this hash contains details about the FPX payment method.



656
657
658
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 656

def fpx
  @fpx
end

#giropayObject

If this is a ‘giropay` PaymentMethod, this hash contains details about the Giropay payment method.



658
659
660
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 658

def giropay
  @giropay
end

#grabpayObject

If this is a ‘grabpay` PaymentMethod, this hash contains details about the GrabPay payment method.



660
661
662
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 660

def grabpay
  @grabpay
end

#idealObject

If this is an ‘ideal` PaymentMethod, this hash contains details about the iDEAL payment method.



662
663
664
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 662

def ideal
  @ideal
end

#interac_presentObject

If this is an ‘interac_present` PaymentMethod, this hash contains details about the Interac Present payment method.



664
665
666
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 664

def interac_present
  @interac_present
end

#kakao_payObject

If this is a ‘kakao_pay` PaymentMethod, this hash contains details about the Kakao Pay payment method.



666
667
668
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 666

def kakao_pay
  @kakao_pay
end

#klarnaObject

If this is a ‘klarna` PaymentMethod, this hash contains details about the Klarna payment method.



668
669
670
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 668

def klarna
  @klarna
end

#konbiniObject

If this is a ‘konbini` PaymentMethod, this hash contains details about the Konbini payment method.



670
671
672
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 670

def konbini
  @konbini
end

#kr_cardObject

If this is a ‘kr_card` PaymentMethod, this hash contains details about the Korean Card payment method.



672
673
674
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 672

def kr_card
  @kr_card
end

If this is an ‘Link` PaymentMethod, this hash contains details about the Link payment method (Link is also known as Onelink in the UK).



674
675
676
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 674

def link
  @link
end

#mb_wayObject

If this is a MB WAY PaymentMethod, this hash contains details about the MB WAY payment method.



676
677
678
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 676

def mb_way
  @mb_way
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



678
679
680
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 678

def 
  @metadata
end

#mobilepayObject

If this is a ‘mobilepay` PaymentMethod, this hash contains details about the MobilePay payment method.



680
681
682
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 680

def mobilepay
  @mobilepay
end

#multibancoObject

If this is a ‘multibanco` PaymentMethod, this hash contains details about the Multibanco payment method.



682
683
684
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 682

def multibanco
  @multibanco
end

If this is a ‘naver_pay` PaymentMethod, this hash contains details about the Naver Pay payment method.



684
685
686
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 684

def naver_pay
  @naver_pay
end

#nz_bank_accountObject

If this is an nz_bank_account PaymentMethod, this hash contains details about the nz_bank_account payment method.



686
687
688
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 686

def 
  @nz_bank_account
end

#oxxoObject

If this is an ‘oxxo` PaymentMethod, this hash contains details about the OXXO payment method.



688
689
690
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 688

def oxxo
  @oxxo
end

#p24Object

If this is a ‘p24` PaymentMethod, this hash contains details about the P24 payment method.



690
691
692
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 690

def p24
  @p24
end

#pay_by_bankObject

If this is a ‘pay_by_bank` PaymentMethod, this hash contains details about the PayByBank payment method.



692
693
694
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 692

def pay_by_bank
  @pay_by_bank
end

#paycoObject

If this is a ‘payco` PaymentMethod, this hash contains details about the PAYCO payment method.



694
695
696
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 694

def payco
  @payco
end

#paynowObject

If this is a ‘paynow` PaymentMethod, this hash contains details about the PayNow payment method.



696
697
698
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 696

def paynow
  @paynow
end

#paypalObject

If this is a ‘paypal` PaymentMethod, this hash contains details about the PayPal payment method.



698
699
700
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 698

def paypal
  @paypal
end

#paytoObject

If this is a ‘payto` PaymentMethod, this hash contains details about the PayTo payment method.



700
701
702
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 700

def payto
  @payto
end

#pixObject

If this is a ‘pix` PaymentMethod, this hash contains details about the Pix payment method.



702
703
704
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 702

def pix
  @pix
end

#promptpayObject

If this is a ‘promptpay` PaymentMethod, this hash contains details about the PromptPay payment method.



704
705
706
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 704

def promptpay
  @promptpay
end

#radar_optionsObject

Options to configure Radar. See [Radar Session](docs.stripe.com/radar/radar-session) for more information.



706
707
708
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 706

def radar_options
  @radar_options
end

#revolut_payObject

If this is a ‘revolut_pay` PaymentMethod, this hash contains details about the Revolut Pay payment method.



708
709
710
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 708

def revolut_pay
  @revolut_pay
end

#samsung_payObject

If this is a ‘samsung_pay` PaymentMethod, this hash contains details about the SamsungPay payment method.



710
711
712
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 710

def samsung_pay
  @samsung_pay
end

#satispayObject

If this is a ‘satispay` PaymentMethod, this hash contains details about the Satispay payment method.



712
713
714
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 712

def satispay
  @satispay
end

#scalapayObject

If this is a Scalapay PaymentMethod, this hash contains details about the Scalapay payment method.



714
715
716
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 714

def scalapay
  @scalapay
end

#sepa_debitObject

If this is a ‘sepa_debit` PaymentMethod, this hash contains details about the SEPA debit bank account.



716
717
718
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 716

def sepa_debit
  @sepa_debit
end

#sofortObject

If this is a ‘sofort` PaymentMethod, this hash contains details about the SOFORT payment method.



718
719
720
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 718

def sofort
  @sofort
end

#sunbitObject

If this is a Sunbit PaymentMethod, this hash contains details about the Sunbit payment method.



720
721
722
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 720

def sunbit
  @sunbit
end

#swishObject

If this is a ‘swish` PaymentMethod, this hash contains details about the Swish payment method.



722
723
724
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 722

def swish
  @swish
end

#twintObject

If this is a TWINT PaymentMethod, this hash contains details about the TWINT payment method.



724
725
726
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 724

def twint
  @twint
end

#typeObject

The type of the PaymentMethod. An additional hash is included on the PaymentMethod with a name matching this value. It contains additional information specific to the PaymentMethod type.



726
727
728
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 726

def type
  @type
end

#upiObject

If this is a ‘upi` PaymentMethod, this hash contains details about the UPI payment method.



728
729
730
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 728

def upi
  @upi
end

#us_bank_accountObject

If this is an ‘us_bank_account` PaymentMethod, this hash contains details about the US bank account payment method.



730
731
732
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 730

def 
  @us_bank_account
end

#wechat_payObject

If this is an ‘wechat_pay` PaymentMethod, this hash contains details about the wechat_pay payment method.



732
733
734
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 732

def wechat_pay
  @wechat_pay
end

#zipObject

If this is a ‘zip` PaymentMethod, this hash contains details about the Zip payment method.



734
735
736
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 734

def zip
  @zip
end