Class: Stripe::PaymentIntentConfirmParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



2525
2526
2527
2528
2529
2530
2531
2532
2533
2534
2535
2536
2537
2538
2539
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2525

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



2513
2514
2515
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2513

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



2515
2516
2517
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2515

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account's bank.



2517
2518
2519
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2517

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account's bank branch.



2519
2520
2521
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2519

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



2521
2522
2523
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2521

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



2523
2524
2525
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2523

def suffix
  @suffix
end