Class: Stripe::PaymentIntentConfirmParams::PaymentMethodData::StripeBalance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodData::StripeBalance
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Instance Attribute Summary collapse
-
#account ⇒ Object
The connected account ID whose Stripe balance to use as the source of payment.
Instance Method Summary collapse
-
#initialize(account: nil) ⇒ StripeBalance
constructor
A new instance of StripeBalance.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(account: nil) ⇒ StripeBalance
Returns a new instance of StripeBalance.
2562 2563 2564 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2562 def initialize(account: nil) @account = account end |
Instance Attribute Details
#account ⇒ Object
The connected account ID whose Stripe balance to use as the source of payment
2560 2561 2562 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2560 def account @account end |