Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Defined Under Namespace

Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, Bizum, Blik, Boleto, Card, CardPresent, Cashapp, Crypto, CustomerBalance, Eps, Fpx, GiftCard, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Paypay, Payto, Pix, Promptpay, Qris, Rechnung, RevolutPay, SamsungPay, Satispay, Scalapay, SepaDebit, Shopeepay, Sofort, StripeBalance, Sunbit, Swish, Twint, Upi, UsBankAccount, Vipps, WechatPay, Zip

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, alma: nil, amazon_pay: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, billie: nil, bizum: nil, blik: nil, boleto: nil, card: nil, card_present: nil, cashapp: nil, crypto: nil, customer_balance: nil, eps: nil, fpx: nil, gift_card: nil, giropay: nil, gopay: nil, grabpay: nil, id_bank_transfer: nil, ideal: nil, interac_present: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, mb_way: nil, mobilepay: nil, multibanco: nil, naver_pay: nil, nz_bank_account: nil, oxxo: nil, p24: nil, pay_by_bank: nil, payco: nil, paynow: nil, paypal: nil, paypay: nil, payto: nil, pix: nil, promptpay: nil, qris: nil, rechnung: nil, revolut_pay: nil, samsung_pay: nil, satispay: nil, scalapay: nil, sepa_debit: nil, shopeepay: nil, sofort: nil, stripe_balance: nil, sunbit: nil, swish: nil, twint: nil, upi: nil, us_bank_account: nil, vipps: nil, wechat_pay: nil, zip: nil) ⇒ PaymentMethodOptions

Returns a new instance of PaymentMethodOptions.



6202
6203
6204
6205
6206
6207
6208
6209
6210
6211
6212
6213
6214
6215
6216
6217
6218
6219
6220
6221
6222
6223
6224
6225
6226
6227
6228
6229
6230
6231
6232
6233
6234
6235
6236
6237
6238
6239
6240
6241
6242
6243
6244
6245
6246
6247
6248
6249
6250
6251
6252
6253
6254
6255
6256
6257
6258
6259
6260
6261
6262
6263
6264
6265
6266
6267
6268
6269
6270
6271
6272
6273
6274
6275
6276
6277
6278
6279
6280
6281
6282
6283
6284
6285
6286
6287
6288
6289
6290
6291
6292
6293
6294
6295
6296
6297
6298
6299
6300
6301
6302
6303
6304
6305
6306
6307
6308
6309
6310
6311
6312
6313
6314
6315
6316
6317
6318
6319
6320
6321
6322
6323
6324
6325
6326
6327
6328
6329
6330
6331
6332
6333
6334
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6202

def initialize(
  acss_debit: nil,
  affirm: nil,
  afterpay_clearpay: nil,
  alipay: nil,
  alma: nil,
  amazon_pay: nil,
  au_becs_debit: nil,
  bacs_debit: nil,
  bancontact: nil,
  billie: nil,
  bizum: nil,
  blik: nil,
  boleto: nil,
  card: nil,
  card_present: nil,
  cashapp: nil,
  crypto: nil,
  customer_balance: nil,
  eps: nil,
  fpx: nil,
  gift_card: nil,
  giropay: nil,
  gopay: nil,
  grabpay: nil,
  id_bank_transfer: nil,
  ideal: nil,
  interac_present: nil,
  kakao_pay: nil,
  klarna: nil,
  konbini: nil,
  kr_card: nil,
  link: nil,
  mb_way: nil,
  mobilepay: nil,
  multibanco: nil,
  naver_pay: nil,
  nz_bank_account: nil,
  oxxo: nil,
  p24: nil,
  pay_by_bank: nil,
  payco: nil,
  paynow: nil,
  paypal: nil,
  paypay: nil,
  payto: nil,
  pix: nil,
  promptpay: nil,
  qris: nil,
  rechnung: nil,
  revolut_pay: nil,
  samsung_pay: nil,
  satispay: nil,
  scalapay: nil,
  sepa_debit: nil,
  shopeepay: nil,
  sofort: nil,
  stripe_balance: nil,
  sunbit: nil,
  swish: nil,
  twint: nil,
  upi: nil,
  us_bank_account: nil,
  vipps: nil,
  wechat_pay: nil,
  zip: nil
)
  @acss_debit = acss_debit
  @affirm = affirm
  @afterpay_clearpay = afterpay_clearpay
  @alipay = alipay
  @alma = alma
  @amazon_pay = amazon_pay
  @au_becs_debit = au_becs_debit
  @bacs_debit = bacs_debit
  @bancontact = bancontact
  @billie = billie
  @bizum = bizum
  @blik = blik
  @boleto = boleto
  @card = card
  @card_present = card_present
  @cashapp = cashapp
  @crypto = crypto
  @customer_balance = customer_balance
  @eps = eps
  @fpx = fpx
  @gift_card = gift_card
  @giropay = giropay
  @gopay = gopay
  @grabpay = grabpay
  @id_bank_transfer = id_bank_transfer
  @ideal = ideal
  @interac_present = interac_present
  @kakao_pay = kakao_pay
  @klarna = klarna
  @konbini = konbini
  @kr_card = kr_card
  @link = link
  @mb_way = mb_way
  @mobilepay = mobilepay
  @multibanco = multibanco
  @naver_pay = naver_pay
  @nz_bank_account = 
  @oxxo = oxxo
  @p24 = p24
  @pay_by_bank = pay_by_bank
  @payco = payco
  @paynow = paynow
  @paypal = paypal
  @paypay = paypay
  @payto = payto
  @pix = pix
  @promptpay = promptpay
  @qris = qris
  @rechnung = rechnung
  @revolut_pay = revolut_pay
  @samsung_pay = samsung_pay
  @satispay = satispay
  @scalapay = scalapay
  @sepa_debit = sepa_debit
  @shopeepay = shopeepay
  @sofort = sofort
  @stripe_balance = stripe_balance
  @sunbit = sunbit
  @swish = swish
  @twint = twint
  @upi = upi
  @us_bank_account = 
  @vipps = vipps
  @wechat_pay = wechat_pay
  @zip = zip
end

Instance Attribute Details

#acss_debitObject

If this is a acss_debit PaymentMethod, this sub-hash contains details about the ACSS Debit payment method options.



6072
6073
6074
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6072

def acss_debit
  @acss_debit
end

#affirmObject

If this is an affirm PaymentMethod, this sub-hash contains details about the Affirm payment method options.



6074
6075
6076
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6074

def affirm
  @affirm
end

#afterpay_clearpayObject

If this is a afterpay_clearpay PaymentMethod, this sub-hash contains details about the Afterpay Clearpay payment method options.



6076
6077
6078
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6076

def afterpay_clearpay
  @afterpay_clearpay
end

#alipayObject

If this is a alipay PaymentMethod, this sub-hash contains details about the Alipay payment method options.



6078
6079
6080
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6078

def alipay
  @alipay
end

#almaObject

If this is a alma PaymentMethod, this sub-hash contains details about the Alma payment method options.



6080
6081
6082
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6080

def alma
  @alma
end

#amazon_payObject

If this is a amazon_pay PaymentMethod, this sub-hash contains details about the Amazon Pay payment method options.



6082
6083
6084
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6082

def amazon_pay
  @amazon_pay
end

#au_becs_debitObject

If this is a au_becs_debit PaymentMethod, this sub-hash contains details about the AU BECS Direct Debit payment method options.



6084
6085
6086
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6084

def au_becs_debit
  @au_becs_debit
end

#bacs_debitObject

If this is a bacs_debit PaymentMethod, this sub-hash contains details about the BACS Debit payment method options.



6086
6087
6088
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6086

def bacs_debit
  @bacs_debit
end

#bancontactObject

If this is a bancontact PaymentMethod, this sub-hash contains details about the Bancontact payment method options.



6088
6089
6090
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6088

def bancontact
  @bancontact
end

#billieObject

If this is a billie PaymentMethod, this sub-hash contains details about the Billie payment method options.



6090
6091
6092
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6090

def billie
  @billie
end

#bizumObject

If this is a bizum PaymentMethod, this sub-hash contains details about the Bizum payment method options.



6092
6093
6094
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6092

def bizum
  @bizum
end

#blikObject

If this is a blik PaymentMethod, this sub-hash contains details about the BLIK payment method options.



6094
6095
6096
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6094

def blik
  @blik
end

#boletoObject

If this is a boleto PaymentMethod, this sub-hash contains details about the Boleto payment method options.



6096
6097
6098
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6096

def boleto
  @boleto
end

#cardObject

Configuration for any card payments attempted on this PaymentIntent.



6098
6099
6100
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6098

def card
  @card
end

#card_presentObject

If this is a card_present PaymentMethod, this sub-hash contains details about the Card Present payment method options.



6100
6101
6102
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6100

def card_present
  @card_present
end

#cashappObject

If this is a cashapp PaymentMethod, this sub-hash contains details about the Cash App Pay payment method options.



6102
6103
6104
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6102

def cashapp
  @cashapp
end

#cryptoObject

If this is a crypto PaymentMethod, this sub-hash contains details about the Crypto payment method options.



6104
6105
6106
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6104

def crypto
  @crypto
end

#customer_balanceObject

If this is a customer balance PaymentMethod, this sub-hash contains details about the customer balance payment method options.



6106
6107
6108
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6106

def customer_balance
  @customer_balance
end

#epsObject

If this is a eps PaymentMethod, this sub-hash contains details about the EPS payment method options.



6108
6109
6110
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6108

def eps
  @eps
end

#fpxObject

If this is a fpx PaymentMethod, this sub-hash contains details about the FPX payment method options.



6110
6111
6112
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6110

def fpx
  @fpx
end

#gift_cardObject

If this is a gift_card PaymentMethod, this sub-hash contains details about the gift card payment method options.



6112
6113
6114
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6112

def gift_card
  @gift_card
end

#giropayObject

If this is a giropay PaymentMethod, this sub-hash contains details about the Giropay payment method options.



6114
6115
6116
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6114

def giropay
  @giropay
end

#gopayObject

If this is a gopay PaymentMethod, this sub-hash contains details about the Gopay payment method options.



6116
6117
6118
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6116

def gopay
  @gopay
end

#grabpayObject

If this is a grabpay PaymentMethod, this sub-hash contains details about the Grabpay payment method options.



6118
6119
6120
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6118

def grabpay
  @grabpay
end

#id_bank_transferObject

If this is a id_bank_transfer PaymentMethod, this sub-hash contains details about the Indonesia Bank Transfer payment method options.



6120
6121
6122
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6120

def id_bank_transfer
  @id_bank_transfer
end

#idealObject

If this is a ideal PaymentMethod, this sub-hash contains details about the Ideal payment method options.



6122
6123
6124
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6122

def ideal
  @ideal
end

#interac_presentObject

If this is a interac_present PaymentMethod, this sub-hash contains details about the Card Present payment method options.



6124
6125
6126
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6124

def interac_present
  @interac_present
end

#kakao_payObject

If this is a kakao_pay PaymentMethod, this sub-hash contains details about the Kakao Pay payment method options.



6126
6127
6128
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6126

def kakao_pay
  @kakao_pay
end

#klarnaObject

If this is a klarna PaymentMethod, this sub-hash contains details about the Klarna payment method options.



6128
6129
6130
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6128

def klarna
  @klarna
end

#konbiniObject

If this is a konbini PaymentMethod, this sub-hash contains details about the Konbini payment method options.



6130
6131
6132
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6130

def konbini
  @konbini
end

#kr_cardObject

If this is a kr_card PaymentMethod, this sub-hash contains details about the KR Card payment method options.



6132
6133
6134
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6132

def kr_card
  @kr_card
end

If this is a link PaymentMethod, this sub-hash contains details about the Link payment method options (Link is also known as Onelink in the UK).



6134
6135
6136
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6134

def link
  @link
end

#mb_wayObject

If this is a mb_way PaymentMethod, this sub-hash contains details about the MB WAY payment method options.



6136
6137
6138
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6136

def mb_way
  @mb_way
end

#mobilepayObject

If this is a MobilePay PaymentMethod, this sub-hash contains details about the MobilePay payment method options.



6138
6139
6140
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6138

def mobilepay
  @mobilepay
end

#multibancoObject

If this is a multibanco PaymentMethod, this sub-hash contains details about the Multibanco payment method options.



6140
6141
6142
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6140

def multibanco
  @multibanco
end

If this is a naver_pay PaymentMethod, this sub-hash contains details about the Naver Pay payment method options.



6142
6143
6144
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6142

def naver_pay
  @naver_pay
end

#nz_bank_accountObject

If this is a nz_bank_account PaymentMethod, this sub-hash contains details about the NZ BECS Direct Debit payment method options.



6144
6145
6146
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6144

def 
  @nz_bank_account
end

#oxxoObject

If this is a oxxo PaymentMethod, this sub-hash contains details about the OXXO payment method options.



6146
6147
6148
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6146

def oxxo
  @oxxo
end

#p24Object

If this is a p24 PaymentMethod, this sub-hash contains details about the Przelewy24 payment method options.



6148
6149
6150
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6148

def p24
  @p24
end

#pay_by_bankObject

If this is a pay_by_bank PaymentMethod, this sub-hash contains details about the PayByBank payment method options.



6150
6151
6152
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6150

def pay_by_bank
  @pay_by_bank
end

#paycoObject

If this is a payco PaymentMethod, this sub-hash contains details about the PAYCO payment method options.



6152
6153
6154
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6152

def payco
  @payco
end

#paynowObject

If this is a paynow PaymentMethod, this sub-hash contains details about the PayNow payment method options.



6154
6155
6156
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6154

def paynow
  @paynow
end

#paypalObject

If this is a paypal PaymentMethod, this sub-hash contains details about the PayPal payment method options.



6156
6157
6158
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6156

def paypal
  @paypal
end

#paypayObject

If this is a paypay PaymentMethod, this sub-hash contains details about the PayPay payment method options.



6158
6159
6160
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6158

def paypay
  @paypay
end

#paytoObject

If this is a payto PaymentMethod, this sub-hash contains details about the PayTo payment method options.



6160
6161
6162
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6160

def payto
  @payto
end

#pixObject

If this is a pix PaymentMethod, this sub-hash contains details about the Pix payment method options.



6162
6163
6164
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6162

def pix
  @pix
end

#promptpayObject

If this is a promptpay PaymentMethod, this sub-hash contains details about the PromptPay payment method options.



6164
6165
6166
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6164

def promptpay
  @promptpay
end

#qrisObject

If this is a qris PaymentMethod, this sub-hash contains details about the QRIS payment method options.



6166
6167
6168
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6166

def qris
  @qris
end

#rechnungObject

If this is a rechnung PaymentMethod, this sub-hash contains details about the Rechnung payment method options.



6168
6169
6170
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6168

def rechnung
  @rechnung
end

#revolut_payObject

If this is a revolut_pay PaymentMethod, this sub-hash contains details about the Revolut Pay payment method options.



6170
6171
6172
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6170

def revolut_pay
  @revolut_pay
end

#samsung_payObject

If this is a samsung_pay PaymentMethod, this sub-hash contains details about the Samsung Pay payment method options.



6172
6173
6174
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6172

def samsung_pay
  @samsung_pay
end

#satispayObject

If this is a satispay PaymentMethod, this sub-hash contains details about the Satispay payment method options.



6174
6175
6176
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6174

def satispay
  @satispay
end

#scalapayObject

If this is a scalapay PaymentMethod, this sub-hash contains details about the ScalaPay payment method options.



6176
6177
6178
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6176

def scalapay
  @scalapay
end

#sepa_debitObject

If this is a sepa_debit PaymentIntent, this sub-hash contains details about the SEPA Debit payment method options.



6178
6179
6180
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6178

def sepa_debit
  @sepa_debit
end

#shopeepayObject

If this is a shopeepay PaymentMethod, this sub-hash contains details about the ShopeePay payment method options.



6180
6181
6182
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6180

def shopeepay
  @shopeepay
end

#sofortObject

If this is a sofort PaymentMethod, this sub-hash contains details about the SOFORT payment method options.



6182
6183
6184
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6182

def sofort
  @sofort
end

#stripe_balanceObject

If this is a stripe_balance PaymentMethod, this sub-hash contains details about the Stripe Balance payment method options.



6184
6185
6186
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6184

def stripe_balance
  @stripe_balance
end

#sunbitObject

If this is a sunbit PaymentMethod, this sub-hash contains details about the Sunbit payment method options.



6186
6187
6188
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6186

def sunbit
  @sunbit
end

#swishObject

If this is a Swish PaymentMethod, this sub-hash contains details about the Swish payment method options.



6188
6189
6190
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6188

def swish
  @swish
end

#twintObject

If this is a twint PaymentMethod, this sub-hash contains details about the TWINT payment method options.



6190
6191
6192
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6190

def twint
  @twint
end

#upiObject

If this is a upi PaymentIntent, this sub-hash contains details about the UPI payment method options.



6192
6193
6194
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6192

def upi
  @upi
end

#us_bank_accountObject

If this is a us_bank_account PaymentMethod, this sub-hash contains details about the US bank account payment method options.



6194
6195
6196
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6194

def 
  @us_bank_account
end

#vippsObject

If this is a Vipps PaymentMethod, this sub-hash contains details about the Vipps payment method options.



6196
6197
6198
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6196

def vipps
  @vipps
end

#wechat_payObject

If this is a wechat_pay PaymentMethod, this sub-hash contains details about the WeChat Pay payment method options.



6198
6199
6200
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6198

def wechat_pay
  @wechat_pay
end

#zipObject

If this is a zip PaymentMethod, this sub-hash contains details about the Zip payment method options.



6200
6201
6202
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6200

def zip
  @zip
end