Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Affirm
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Affirm
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Instance Attribute Summary collapse
-
#capture_method ⇒ Object
Controls when the funds are captured from the customer's account.
-
#preferred_locale ⇒ Object
Preferred language of the Affirm authorization page that the customer is redirected to.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent's payment method.
Instance Method Summary collapse
-
#initialize(capture_method: nil, preferred_locale: nil, setup_future_usage: nil) ⇒ Affirm
constructor
A new instance of Affirm.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(capture_method: nil, preferred_locale: nil, setup_future_usage: nil) ⇒ Affirm
Returns a new instance of Affirm.
3067 3068 3069 3070 3071 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3067 def initialize(capture_method: nil, preferred_locale: nil, setup_future_usage: nil) @capture_method = capture_method @preferred_locale = preferred_locale @setup_future_usage = setup_future_usage end |
Instance Attribute Details
#capture_method ⇒ Object
Controls when the funds are captured from the customer's account.
If provided, this parameter overrides the behavior of the top-level capture_method for this payment method type when finalizing the payment with this payment method type.
If capture_method is already set on the PaymentIntent, providing an empty value for this parameter unsets the stored value for this payment method type.
3053 3054 3055 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3053 def capture_method @capture_method end |
#preferred_locale ⇒ Object
Preferred language of the Affirm authorization page that the customer is redirected to.
3055 3056 3057 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3055 def preferred_locale @preferred_locale end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent's payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.
If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.
When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.
If you've already set setup_future_usage and you're performing a request using a publishable key, you can only update the value from on_session to off_session.
3065 3066 3067 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3065 def setup_future_usage @setup_future_usage end |