Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Billie::CompanyDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Defined Under Namespace

Classes: RegisteredAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h

Constructor Details

#initialize(registered_address: nil, registered_name: nil, registration_number: nil, registration_type: nil, vat: nil) ⇒ CompanyDetails

Returns a new instance of CompanyDetails.



1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1147

def initialize(
  registered_address: nil,
  registered_name: nil,
  registration_number: nil,
  registration_type: nil,
  vat: nil
)
  @registered_address = registered_address
  @registered_name = registered_name
  @registration_number = registration_number
  @registration_type = registration_type
  @vat = vat
end

Instance Attribute Details

#registered_address ⇒ Object

The address the company or entity is registered with.



1137
1138
1139
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1137

def registered_address
  @registered_address
end

#registered_name ⇒ Object

Company or entity name.



1139
1140
1141
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1139

def registered_name
  @registered_name
end

#registration_number ⇒ Object

The official registration number for the given registration type.



1141
1142
1143
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1141

def registration_number
  @registration_number
end

#registration_type ⇒ Object

Type of registration the company or entity holds in their registered country.



1143
1144
1145
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1143

def registration_type
  @registration_type
end

#vat ⇒ Object

VAT id number



1145
1146
1147
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1145

def vat
  @vat
end