Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Card::Installments::Plan

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(count: nil, interval: nil, type: nil) ⇒ Plan

Returns a new instance of Plan.



3303
3304
3305
3306
3307
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3303

def initialize(count: nil, interval: nil, type: nil)
  @count = count
  @interval = interval
  @type = type
end

Instance Attribute Details

#countObject

For fixed_count installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.



3296
3297
3298
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3296

def count
  @count
end

#intervalObject

For fixed_count installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of month.



3299
3300
3301
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3299

def interval
  @interval
end

#typeObject

Type of installment plan, one of fixed_count, bonus, or revolving.



3301
3302
3303
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3301

def type
  @type
end