Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Card::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil, interval: nil, interval_count: nil, reference: nil, start_date: nil, supported_types: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



3343
3344
3345
3346
3347
3348
3349
3350
3351
3352
3353
3354
3355
3356
3357
3358
3359
3360
3361
3362
3363
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3343

def initialize(
  amount: nil,
  amount_type: nil,
  description: nil,
  end_date: nil,
  interval: nil,
  interval_count: nil,
  reference: nil,
  start_date: nil,
  supported_types: nil
)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
  @interval = interval
  @interval_count = interval_count
  @reference = reference
  @start_date = start_date
  @supported_types = supported_types
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments, specified in the presentment currency.



3325
3326
3327
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3325

def amount
  @amount
end

#amount_typeObject

One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.



3327
3328
3329
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3327

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



3329
3330
3331
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3329

def description
  @description
end

#end_dateObject

End date of the mandate or subscription. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.



3331
3332
3333
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3331

def end_date
  @end_date
end

#intervalObject

Specifies payment frequency. One of day, week, month, year, or sporadic.



3333
3334
3335
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3333

def interval
  @interval
end

#interval_countObject

The number of intervals between payments. For example, interval=month and interval_count=3 indicates one payment every three months. Maximum of one year interval allowed (1 year, 12 months, or 52 weeks). This parameter is optional when interval=sporadic.



3335
3336
3337
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3335

def interval_count
  @interval_count
end

#referenceObject

Unique identifier for the mandate or subscription.



3337
3338
3339
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3337

def reference
  @reference
end

#start_dateObject

Start date of the mandate or subscription. Start date should not be lesser than yesterday.



3339
3340
3341
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3339

def start_date
  @start_date
end

#supported_typesObject

Specifies the type of mandates supported. Possible values are india.



3341
3342
3343
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3341

def supported_types
  @supported_types
end