Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Card::StatementDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Card::StatementDetails
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Please pass in an address that is within your Stripe user account country.
-
#phone ⇒ Object
Phone number (e.g., a toll-free number that customers can call).
Instance Method Summary collapse
-
#initialize(address: nil, phone: nil) ⇒ StatementDetails
constructor
A new instance of StatementDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, phone: nil) ⇒ StatementDetails
Returns a new instance of StatementDetails.
1975 1976 1977 1978 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1975 def initialize(address: nil, phone: nil) @address = address @phone = phone end |
Instance Attribute Details
#address ⇒ Object
Please pass in an address that is within your Stripe user account country
1971 1972 1973 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1971 def address @address end |
#phone ⇒ Object
Phone number (e.g., a toll-free number that customers can call)
1973 1974 1975 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1973 def phone @phone end |