Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::CardPresent::PaymentDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::CardPresent::PaymentDetails
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Defined Under Namespace
Classes: MoneyServices
Instance Attribute Summary collapse
-
#money_services ⇒ Object
Money services details for payment method specific funding fields.
Instance Method Summary collapse
-
#initialize(money_services: nil) ⇒ PaymentDetails
constructor
A new instance of PaymentDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(money_services: nil) ⇒ PaymentDetails
Returns a new instance of PaymentDetails.
3651 3652 3653 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3651 def initialize(money_services: nil) @money_services = money_services end |
Instance Attribute Details
#money_services ⇒ Object
Money services details for payment method specific funding fields.
3649 3650 3651 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3649 def money_services @money_services end |