Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::GiftCard

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(ignore_application_fee: nil, ignore_transfer_data: nil, request_partial_authorization: nil) ⇒ GiftCard

Returns a new instance of GiftCard.



3902
3903
3904
3905
3906
3907
3908
3909
3910
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3902

def initialize(
  ignore_application_fee: nil,
  ignore_transfer_data: nil,
  request_partial_authorization: nil
)
  @ignore_application_fee = ignore_application_fee
  @ignore_transfer_data = ignore_transfer_data
  @request_partial_authorization = request_partial_authorization
end

Instance Attribute Details

#ignore_application_feeObject

Set to yes to ignore the application fee on the PaymentIntent when redeeming this gift card.



3896
3897
3898
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3896

def ignore_application_fee
  @ignore_application_fee
end

#ignore_transfer_dataObject

Set to yes to ignore transfer data on the PaymentIntent when redeeming this gift card.



3898
3899
3900
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3898

def ignore_transfer_data
  @ignore_transfer_data
end

#request_partial_authorizationObject

Request partial authorization on this PaymentIntent.



3900
3901
3902
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3900

def request_partial_authorization
  @request_partial_authorization
end