Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::Subscription
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::Subscription
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Defined Under Namespace
Classes: NextBilling
Instance Attribute Summary collapse
-
#interval ⇒ Object
Unit of time between subscription charges.
-
#interval_count ⇒ Object
The number of intervals (specified in the ‘interval` attribute) between subscription charges.
-
#name ⇒ Object
Name for subscription.
-
#next_billing ⇒ Object
Describes the upcoming charge for this subscription.
-
#reference ⇒ Object
A non-customer-facing reference to correlate subscription charges in the Klarna app.
Instance Method Summary collapse
-
#initialize(interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil) ⇒ Subscription
constructor
A new instance of Subscription.
Methods inherited from RequestParams
Constructor Details
#initialize(interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil) ⇒ Subscription
Returns a new instance of Subscription.
2461 2462 2463 2464 2465 2466 2467 2468 2469 2470 2471 2472 2473 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2461 def initialize( interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil ) @interval = interval @interval_count = interval_count @name = name @next_billing = next_billing @reference = reference end |
Instance Attribute Details
#interval ⇒ Object
Unit of time between subscription charges.
2451 2452 2453 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2451 def interval @interval end |
#interval_count ⇒ Object
The number of intervals (specified in the ‘interval` attribute) between subscription charges. For example, `interval=month` and `interval_count=3` charges every 3 months.
2453 2454 2455 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2453 def interval_count @interval_count end |
#name ⇒ Object
Name for subscription.
2455 2456 2457 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2455 def name @name end |
#next_billing ⇒ Object
Describes the upcoming charge for this subscription.
2457 2458 2459 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2457 def next_billing @next_billing end |
#reference ⇒ Object
A non-customer-facing reference to correlate subscription charges in the Klarna app. Use a value that persists across subscription charges.
2459 2460 2461 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2459 def reference @reference end |