Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::Subscription::NextBilling

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, date: nil) ⇒ NextBilling

Returns a new instance of NextBilling.



4007
4008
4009
4010
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4007

def initialize(amount: nil, date: nil)
  @amount = amount
  @date = date
end

Instance Attribute Details

#amountObject

The amount of the next charge for the subscription.



4003
4004
4005
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4003

def amount
  @amount
end

#dateObject

The date of the next charge for the subscription in YYYY-MM-DD format.



4005
4006
4007
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4005

def date
  @date
end