Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::BusReservationDetail
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::BusReservationDetail
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Defined Under Namespace
Classes: Arrival, Departure, Insurance, Passenger
Instance Attribute Summary collapse
-
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
-
#arrival ⇒ Object
Arrival details.
-
#carrier_name ⇒ Object
Name of transportation company.
-
#currency ⇒ Object
Currency.
-
#departure ⇒ Object
Departure details.
-
#insurances ⇒ Object
List of insurances for this reservation.
-
#passengers ⇒ Object
List of passengers that this reservation applies to.
-
#price ⇒ Object
Price in cents.
-
#ticket_class ⇒ Object
Ticket class.
Instance Method Summary collapse
-
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ BusReservationDetail
constructor
A new instance of BusReservationDetail.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ BusReservationDetail
Returns a new instance of BusReservationDetail.
4236 4237 4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 4248 4249 4250 4251 4252 4253 4254 4255 4256 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4236 def initialize( affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil ) @affiliate_name = affiliate_name @arrival = arrival @carrier_name = carrier_name @currency = currency @departure = departure @insurances = insurances @passengers = passengers @price = price @ticket_class = ticket_class end |
Instance Attribute Details
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
4218 4219 4220 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4218 def affiliate_name @affiliate_name end |
#arrival ⇒ Object
Arrival details.
4220 4221 4222 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4220 def arrival @arrival end |
#carrier_name ⇒ Object
Name of transportation company.
4222 4223 4224 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4222 def carrier_name @carrier_name end |
#currency ⇒ Object
Currency.
4224 4225 4226 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4224 def currency @currency end |
#departure ⇒ Object
Departure details.
4226 4227 4228 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4226 def departure @departure end |
#insurances ⇒ Object
List of insurances for this reservation.
4228 4229 4230 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4228 def insurances @insurances end |
#passengers ⇒ Object
List of passengers that this reservation applies to.
4230 4231 4232 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4230 def passengers @passengers end |
#price ⇒ Object
Price in cents.
4232 4233 4234 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4232 def price @price end |
#ticket_class ⇒ Object
Ticket class.
4234 4235 4236 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4234 def ticket_class @ticket_class end |