Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::BusReservationDetail::Arrival::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::BusReservationDetail::Arrival::Address
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
4012 4013 4014 4015 4016 4017 4018 4019 4020 4021 4022 4023 4024 4025 4026 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4012 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
4000 4001 4002 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4000 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
4002 4003 4004 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4002 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
4004 4005 4006 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4004 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
4006 4007 4008 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4006 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
4008 4009 4010 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4008 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
4010 4011 4012 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4010 def street_address2 @street_address2 end |