Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::BusReservationDetail::Departure::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::BusReservationDetail::Departure::Address
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
3542 3543 3544 3545 3546 3547 3548 3549 3550 3551 3552 3553 3554 3555 3556 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3542 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
3530 3531 3532 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3530 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
3532 3533 3534 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3532 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
3534 3535 3536 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3534 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
3536 3537 3538 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3536 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
3538 3539 3540 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3538 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
3540 3541 3542 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3540 def street_address2 @street_address2 end |