Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::EventReservationDetail

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Defined Under Namespace

Classes: Address, Insurance

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(access_controlled_venue: nil, address: nil, affiliate_name: nil, ends_at: nil, event_company_name: nil, event_name: nil, event_type: nil, insurances: nil, starts_at: nil, venue_name: nil) ⇒ EventReservationDetail

Returns a new instance of EventReservationDetail.



4278
4279
4280
4281
4282
4283
4284
4285
4286
4287
4288
4289
4290
4291
4292
4293
4294
4295
4296
4297
4298
4299
4300
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4278

def initialize(
  access_controlled_venue: nil,
  address: nil,
  affiliate_name: nil,
  ends_at: nil,
  event_company_name: nil,
  event_name: nil,
  event_type: nil,
  insurances: nil,
  starts_at: nil,
  venue_name: nil
)
  @access_controlled_venue = access_controlled_venue
  @address = address
  @affiliate_name = affiliate_name
  @ends_at = ends_at
  @event_company_name = event_company_name
  @event_name = event_name
  @event_type = event_type
  @insurances = insurances
  @starts_at = starts_at
  @venue_name = venue_name
end

Instance Attribute Details

#access_controlled_venueObject

Indicates if the tickets are digitally checked when entering the venue.



4258
4259
4260
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4258

def access_controlled_venue
  @access_controlled_venue
end

#addressObject

Address of the event.



4260
4261
4262
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4260

def address
  @address
end

#affiliate_nameObject

Name of associated or partner company for the service.



4262
4263
4264
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4262

def affiliate_name
  @affiliate_name
end

#ends_atObject

End timestamp of the event.



4264
4265
4266
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4264

def ends_at
  @ends_at
end

#event_company_nameObject

Company selling the ticket.



4266
4267
4268
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4266

def event_company_name
  @event_company_name
end

#event_nameObject

Name of the event.



4268
4269
4270
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4268

def event_name
  @event_name
end

#event_typeObject

Type of the event.



4270
4271
4272
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4270

def event_type
  @event_type
end

#insurancesObject

List of insurances for this event.



4272
4273
4274
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4272

def insurances
  @insurances
end

#starts_atObject

Start timestamp of the event.



4274
4275
4276
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4274

def starts_at
  @starts_at
end

#venue_nameObject

Name of the venue where the event takes place.



4276
4277
4278
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4276

def venue_name
  @venue_name
end