Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::EventReservationDetail::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::EventReservationDetail::Address
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
4195 4196 4197 4198 4199 4200 4201 4202 4203 4204 4205 4206 4207 4208 4209 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4195 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
4183 4184 4185 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4183 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
4185 4186 4187 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4185 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
4187 4188 4189 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4187 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
4189 4190 4191 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4189 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
4191 4192 4193 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4191 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
4193 4194 4195 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4193 def street_address2 @street_address2 end |