Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::FerryReservationDetail
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::FerryReservationDetail
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Defined Under Namespace
Classes: Arrival, Departure, Insurance, Passenger
Instance Attribute Summary collapse
-
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
-
#arrival ⇒ Object
Arrival details.
-
#carrier_name ⇒ Object
Name of transportation company.
-
#currency ⇒ Object
Currency.
-
#departure ⇒ Object
Departure details.
-
#insurances ⇒ Object
List of insurances for this reservation.
-
#passengers ⇒ Object
List of passengers that this reservation applies to.
-
#price ⇒ Object
Price in cents.
-
#ticket_class ⇒ Object
Ticket class.
Instance Method Summary collapse
-
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ FerryReservationDetail
constructor
A new instance of FerryReservationDetail.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ FerryReservationDetail
Returns a new instance of FerryReservationDetail.
4392 4393 4394 4395 4396 4397 4398 4399 4400 4401 4402 4403 4404 4405 4406 4407 4408 4409 4410 4411 4412 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4392 def initialize( affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil ) @affiliate_name = affiliate_name @arrival = arrival @carrier_name = carrier_name @currency = currency @departure = departure @insurances = insurances @passengers = passengers @price = price @ticket_class = ticket_class end |
Instance Attribute Details
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
4374 4375 4376 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4374 def affiliate_name @affiliate_name end |
#arrival ⇒ Object
Arrival details.
4376 4377 4378 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4376 def arrival @arrival end |
#carrier_name ⇒ Object
Name of transportation company.
4378 4379 4380 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4378 def carrier_name @carrier_name end |
#currency ⇒ Object
Currency.
4380 4381 4382 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4380 def currency @currency end |
#departure ⇒ Object
Departure details.
4382 4383 4384 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4382 def departure @departure end |
#insurances ⇒ Object
List of insurances for this reservation.
4384 4385 4386 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4384 def insurances @insurances end |
#passengers ⇒ Object
List of passengers that this reservation applies to.
4386 4387 4388 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4386 def passengers @passengers end |
#price ⇒ Object
Price in cents.
4388 4389 4390 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4388 def price @price end |
#ticket_class ⇒ Object
Ticket class.
4390 4391 4392 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4390 def ticket_class @ticket_class end |