Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::MarketplaceSeller

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Defined Under Namespace

Classes: MarketplaceSellerAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(line_item_references: nil, marketplace_seller_address: nil, marketplace_seller_name: nil, marketplace_seller_reference: nil, number_of_transactions: nil, product_category: nil, seller_last_login_at: nil, seller_rating: nil, seller_registered_at: nil, seller_updated_at: nil, shipping_references: nil, volume_of_transactions: nil) ⇒ MarketplaceSeller

Returns a new instance of MarketplaceSeller.



4602
4603
4604
4605
4606
4607
4608
4609
4610
4611
4612
4613
4614
4615
4616
4617
4618
4619
4620
4621
4622
4623
4624
4625
4626
4627
4628
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4602

def initialize(
  line_item_references: nil,
  marketplace_seller_address: nil,
  marketplace_seller_name: nil,
  marketplace_seller_reference: nil,
  number_of_transactions: nil,
  product_category: nil,
  seller_last_login_at: nil,
  seller_rating: nil,
  seller_registered_at: nil,
  seller_updated_at: nil,
  shipping_references: nil,
  volume_of_transactions: nil
)
  @line_item_references = line_item_references
  @marketplace_seller_address = marketplace_seller_address
  @marketplace_seller_name = marketplace_seller_name
  @marketplace_seller_reference = marketplace_seller_reference
  @number_of_transactions = number_of_transactions
  @product_category = product_category
  @seller_last_login_at = 
  @seller_rating = seller_rating
  @seller_registered_at = seller_registered_at
  @seller_updated_at = seller_updated_at
  @shipping_references = shipping_references
  @volume_of_transactions = volume_of_transactions
end

Instance Attribute Details

#line_item_referencesObject

The references to line items for purchases with multiple associated sub-sellers.



4578
4579
4580
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4578

def line_item_references
  @line_item_references
end

#marketplace_seller_addressObject

The address of the selling or delivering merchant.



4580
4581
4582
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4580

def marketplace_seller_address
  @marketplace_seller_address
end

#marketplace_seller_nameObject

The name of the marketplace seller.



4582
4583
4584
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4582

def marketplace_seller_name
  @marketplace_seller_name
end

#marketplace_seller_referenceObject

The unique identifier for the marketplace seller.



4584
4585
4586
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4584

def marketplace_seller_reference
  @marketplace_seller_reference
end

#number_of_transactionsObject

The number of transactions the sub-seller completed in the last 12 months.



4586
4587
4588
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4586

def number_of_transactions
  @number_of_transactions
end

#product_categoryObject

The category of the product.



4588
4589
4590
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4588

def product_category
  @product_category
end

#seller_last_login_atObject

The date when the seller's account with the marketplace was last logged in.



4590
4591
4592
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4590

def 
  @seller_last_login_at
end

#seller_ratingObject

The current rating of the marketplace seller. If the marketplace uses numeric ranking, map these to the enum values.



4592
4593
4594
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4592

def seller_rating
  @seller_rating
end

#seller_registered_atObject

The date when the seller's account with the marketplace was created.



4594
4595
4596
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4594

def seller_registered_at
  @seller_registered_at
end

#seller_updated_atObject

The date when the seller's account with the marketplace was last updated.



4596
4597
4598
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4596

def seller_updated_at
  @seller_updated_at
end

#shipping_referencesObject

The references to shipping addresses for purchases with multiple associated sub-sellers.



4598
4599
4600
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4598

def shipping_references
  @shipping_references
end

#volume_of_transactionsObject

The accumulated amount of sales transactions made by the sub-merchant or sub-seller within the past 12 months in the payment currency. These transactions are in minor currency units.



4600
4601
4602
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4600

def volume_of_transactions
  @volume_of_transactions
end