Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::MarketplaceSeller::MarketplaceSellerAddress
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::MarketplaceSeller::MarketplaceSellerAddress
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ MarketplaceSellerAddress
constructor
A new instance of MarketplaceSellerAddress.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ MarketplaceSellerAddress
Returns a new instance of MarketplaceSellerAddress.
4505 4506 4507 4508 4509 4510 4511 4512 4513 4514 4515 4516 4517 4518 4519 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4505 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
4493 4494 4495 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4493 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
4495 4496 4497 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4495 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
4497 4498 4499 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4497 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
4499 4500 4501 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4499 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
4501 4502 4503 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4501 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
4503 4504 4505 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4503 def street_address2 @street_address2 end |