Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::RoundTripReservationDetail::Arrival::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::RoundTripReservationDetail::Arrival::Address
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
4548 4549 4550 4551 4552 4553 4554 4555 4556 4557 4558 4559 4560 4561 4562 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4548 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
4536 4537 4538 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4536 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
4538 4539 4540 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4538 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
4540 4541 4542 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4540 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
4542 4543 4544 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4542 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
4544 4545 4546 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4544 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
4546 4547 4548 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4546 def street_address2 @street_address2 end |