Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::TrainReservationDetail
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::TrainReservationDetail
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Defined Under Namespace
Classes: Arrival, Departure, Insurance, Passenger
Instance Attribute Summary collapse
-
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
-
#arrival ⇒ Object
Arrival details.
-
#carrier_name ⇒ Object
Name of transportation company.
-
#currency ⇒ Object
Currency.
-
#departure ⇒ Object
Departure details.
-
#insurances ⇒ Object
List of insurances for this reservation.
-
#passengers ⇒ Object
List of passengers that this reservation applies to.
-
#price ⇒ Object
Price in cents.
-
#ticket_class ⇒ Object
Ticket class.
Instance Method Summary collapse
-
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ TrainReservationDetail
constructor
A new instance of TrainReservationDetail.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ TrainReservationDetail
Returns a new instance of TrainReservationDetail.
4936 4937 4938 4939 4940 4941 4942 4943 4944 4945 4946 4947 4948 4949 4950 4951 4952 4953 4954 4955 4956 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4936 def initialize( affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil ) @affiliate_name = affiliate_name @arrival = arrival @carrier_name = carrier_name @currency = currency @departure = departure @insurances = insurances @passengers = passengers @price = price @ticket_class = ticket_class end |
Instance Attribute Details
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
4918 4919 4920 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4918 def affiliate_name @affiliate_name end |
#arrival ⇒ Object
Arrival details.
4920 4921 4922 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4920 def arrival @arrival end |
#carrier_name ⇒ Object
Name of transportation company.
4922 4923 4924 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4922 def carrier_name @carrier_name end |
#currency ⇒ Object
Currency.
4924 4925 4926 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4924 def currency @currency end |
#departure ⇒ Object
Departure details.
4926 4927 4928 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4926 def departure @departure end |
#insurances ⇒ Object
List of insurances for this reservation.
4928 4929 4930 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4928 def insurances @insurances end |
#passengers ⇒ Object
List of passengers that this reservation applies to.
4930 4931 4932 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4930 def passengers @passengers end |
#price ⇒ Object
Price in cents.
4932 4933 4934 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4932 def price @price end |
#ticket_class ⇒ Object
Ticket class.
4934 4935 4936 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4934 def ticket_class @ticket_class end |