Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::TrainReservationDetail::Arrival::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::TrainReservationDetail::Arrival::Address
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
4755 4756 4757 4758 4759 4760 4761 4762 4763 4764 4765 4766 4767 4768 4769 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4755 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
4743 4744 4745 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4743 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
4745 4746 4747 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4745 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
4747 4748 4749 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4747 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
4749 4750 4751 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4749 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
4751 4752 4753 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4751 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
4753 4754 4755 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4753 def street_address2 @street_address2 end |