Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::TrainReservationDetail::Departure::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::TrainReservationDetail::Departure::Address
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 4867 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4853 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
4841 4842 4843 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4841 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
4843 4844 4845 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4843 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
4845 4846 4847 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4845 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
4847 4848 4849 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4847 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
4849 4850 4851 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4849 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
4851 4852 4853 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4851 def street_address2 @street_address2 end |