Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Defined Under Namespace
Classes: Tax
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#name ⇒ Object
Descriptive name of the line item.
-
#quantity ⇒ Object
Quantity of the line item.
-
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
The tax information for the line item.
-
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
Returns a new instance of LineItem.
5363 5364 5365 5366 5367 5368 5369 5370 5371 5372 5373 5374 5375 5376 5377 5378 5379 5380 5381 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5363 def initialize( category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil ) @category = category @description = description @name = name @quantity = quantity @sku = sku @sold_by = sold_by @tax = tax @unit_amount = unit_amount end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
5347 5348 5349 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5347 def category @category end |
#description ⇒ Object
Description of the line item.
5349 5350 5351 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5349 def description @description end |
#name ⇒ Object
Descriptive name of the line item.
5351 5352 5353 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5351 def name @name end |
#quantity ⇒ Object
Quantity of the line item. Must be a positive number.
5353 5354 5355 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5353 def quantity @quantity end |
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
5355 5356 5357 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5355 def sku @sku end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
5357 5358 5359 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5357 def sold_by @sold_by end |
#tax ⇒ Object
The tax information for the line item.
5359 5360 5361 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5359 def tax @tax end |
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units. Cannot be a negative number.
5361 5362 5363 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5361 def unit_amount @unit_amount end |