Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Paypal::LineItem::Tax
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Paypal::LineItem::Tax
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The tax for a single unit of the line item in minor units.
-
#behavior ⇒ Object
The tax behavior for the line item.
Instance Method Summary collapse
-
#initialize(amount: nil, behavior: nil) ⇒ Tax
constructor
A new instance of Tax.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, behavior: nil) ⇒ Tax
Returns a new instance of Tax.
4721 4722 4723 4724 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4721 def initialize(amount: nil, behavior: nil) @amount = amount @behavior = behavior end |
Instance Attribute Details
#amount ⇒ Object
The tax for a single unit of the line item in minor units. Cannot be a negative number.
4717 4718 4719 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4717 def amount @amount end |
#behavior ⇒ Object
The tax behavior for the line item.
4719 4720 4721 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4719 def behavior @behavior end |