Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Upi::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



5853
5854
5855
5856
5857
5858
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5853

def initialize(amount: nil, amount_type: nil, description: nil, end_date: nil)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



5845
5846
5847
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5845

def amount
  @amount
end

#amount_typeObject

One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.



5847
5848
5849
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5847

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



5849
5850
5851
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5849

def description
  @description
end

#end_dateObject

End date of the mandate or subscription.



5851
5852
5853
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5851

def end_date
  @end_date
end