Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::UsBankAccount
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Defined Under Namespace
Classes: FinancialConnections, MandateOptions, Networks
Instance Attribute Summary collapse
-
#financial_connections ⇒ Object
Additional fields for Financial Connections Session creation.
-
#mandate_options ⇒ Object
Additional fields for Mandate creation.
-
#networks ⇒ Object
Additional fields for network related functions.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent's payment method.
-
#target_date ⇒ Object
Controls when Stripe will attempt to debit the funds from the customer's account.
-
#transaction_purpose ⇒ Object
The purpose of the transaction.
-
#verification_method ⇒ Object
Bank account verification method.
Instance Method Summary collapse
-
#initialize(financial_connections: nil, mandate_options: nil, networks: nil, setup_future_usage: nil, target_date: nil, transaction_purpose: nil, verification_method: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(financial_connections: nil, mandate_options: nil, networks: nil, setup_future_usage: nil, target_date: nil, transaction_purpose: nil, verification_method: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
5959 5960 5961 5962 5963 5964 5965 5966 5967 5968 5969 5970 5971 5972 5973 5974 5975 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5959 def initialize( financial_connections: nil, mandate_options: nil, networks: nil, setup_future_usage: nil, target_date: nil, transaction_purpose: nil, verification_method: nil ) @financial_connections = financial_connections @mandate_options = @networks = networks @setup_future_usage = setup_future_usage @target_date = target_date @transaction_purpose = transaction_purpose @verification_method = verification_method end |
Instance Attribute Details
#financial_connections ⇒ Object
Additional fields for Financial Connections Session creation
5937 5938 5939 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5937 def financial_connections @financial_connections end |
#mandate_options ⇒ Object
Additional fields for Mandate creation
5939 5940 5941 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5939 def @mandate_options end |
#networks ⇒ Object
Additional fields for network related functions
5941 5942 5943 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5941 def networks @networks end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent's payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.
If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.
When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.
If you've already set setup_future_usage and you're performing a request using a publishable key, you can only update the value from on_session to off_session.
5951 5952 5953 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5951 def setup_future_usage @setup_future_usage end |
#target_date ⇒ Object
Controls when Stripe will attempt to debit the funds from the customer's account. The date must be a string in YYYY-MM-DD format. The date must be in the future and between 3 and 15 calendar days from now.
5953 5954 5955 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5953 def target_date @target_date end |
#transaction_purpose ⇒ Object
The purpose of the transaction.
5955 5956 5957 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5955 def transaction_purpose @transaction_purpose end |
#verification_method ⇒ Object
Bank account verification method. The default value is automatic.
5957 5958 5959 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5957 def verification_method @verification_method end |