Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::UsBankAccount::FinancialConnections

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Defined Under Namespace

Classes: Filters, ManualEntry

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections

Returns a new instance of FinancialConnections.



5904
5905
5906
5907
5908
5909
5910
5911
5912
5913
5914
5915
5916
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5904

def initialize(
  filters: nil,
  manual_entry: nil,
  permissions: nil,
  prefetch: nil,
  return_url: nil
)
  @filters = filters
  @manual_entry = manual_entry
  @permissions = permissions
  @prefetch = prefetch
  @return_url = return_url
end

Instance Attribute Details

#filtersObject

Provide filters for the linked accounts that the customer can select for the payment method.



5894
5895
5896
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5894

def filters
  @filters
end

#manual_entryObject

Customize manual entry behavior



5896
5897
5898
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5896

def manual_entry
  @manual_entry
end

#permissionsObject

The list of permissions to request. If this parameter is passed, the payment_method permission must be included. Valid permissions include: balances, ownership, payment_method, and transactions.



5898
5899
5900
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5898

def permissions
  @permissions
end

#prefetchObject

List of data features that you would like to retrieve upon account creation.



5900
5901
5902
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5900

def prefetch
  @prefetch
end

#return_urlObject

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



5902
5903
5904
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5902

def return_url
  @return_url
end