Class: Stripe::PaymentIntentConfirmParams::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



6391
6392
6393
6394
6395
6396
6397
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6391

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



6381
6382
6383
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6381

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



6383
6384
6385
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6383

def carrier
  @carrier
end

#nameObject

Recipient name.



6385
6386
6387
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6385

def name
  @name
end

#phoneObject

Recipient phone (including extension).



6387
6388
6389
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6387

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



6389
6390
6391
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6389

def tracking_number
  @tracking_number
end