Class: Stripe::PaymentIntentCreateParams::AmountDetails::LineItem::PaymentMethodOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Defined Under Namespace

Classes: Card, CardPresent, Klarna, Paypal

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(card: nil, card_present: nil, klarna: nil, paypal: nil) ⇒ PaymentMethodOptions

Returns a new instance of PaymentMethodOptions.



138
139
140
141
142
143
# File 'lib/stripe/params/payment_intent_create_params.rb', line 138

def initialize(card: nil, card_present: nil, klarna: nil, paypal: nil)
  @card = card
  @card_present = card_present
  @klarna = klarna
  @paypal = paypal
end

Instance Attribute Details

#cardObject

This sub-hash contains line item details that are specific to the card payment method.



130
131
132
# File 'lib/stripe/params/payment_intent_create_params.rb', line 130

def card
  @card
end

#card_presentObject

This sub-hash contains line item details that are specific to the card_present payment method.



132
133
134
# File 'lib/stripe/params/payment_intent_create_params.rb', line 132

def card_present
  @card_present
end

#klarnaObject

This sub-hash contains line item details that are specific to the klarna payment method.



134
135
136
# File 'lib/stripe/params/payment_intent_create_params.rb', line 134

def klarna
  @klarna
end

#paypalObject

This sub-hash contains line item details that are specific to the paypal payment method.



136
137
138
# File 'lib/stripe/params/payment_intent_create_params.rb', line 136

def paypal
  @paypal
end