Class: Stripe::PaymentIntentCreateParams::AmountDetails::LineItem::PaymentMethodOptions::Card::EvCharging
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::AmountDetails::LineItem::PaymentMethodOptions::Card::EvCharging
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Instance Attribute Summary collapse
-
#carbon_footprint_avoided_grams_co2 ⇒ Object
The carbon footprint avoided by the charging session, in grams of CO2.
-
#charging_ended_at ⇒ Object
The time the charging session ended, measured in seconds since the Unix epoch.
-
#charging_power_output_capacity_kw ⇒ Object
The power output capacity of the charging station, in kilowatts (kW).
-
#charging_started_at ⇒ Object
The time the charging session started, measured in seconds since the Unix epoch.
-
#connector_type ⇒ Object
The type of connector used for the charging session.
-
#estimated_range_added ⇒ Object
The estimated distance in kilometers or miles added to the vehicle during the charging session.
-
#estimated_range_left ⇒ Object
The estimated distance in kilometers or miles remaining in the vehicle after the charging session.
-
#maximum_power_dispensed_kw ⇒ Object
The maximum power dispensed during the charging session, in kilowatts (kW).
Instance Method Summary collapse
-
#initialize(carbon_footprint_avoided_grams_co2: nil, charging_ended_at: nil, charging_power_output_capacity_kw: nil, charging_started_at: nil, connector_type: nil, estimated_range_added: nil, estimated_range_left: nil, maximum_power_dispensed_kw: nil) ⇒ EvCharging
constructor
A new instance of EvCharging.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(carbon_footprint_avoided_grams_co2: nil, charging_ended_at: nil, charging_power_output_capacity_kw: nil, charging_started_at: nil, connector_type: nil, estimated_range_added: nil, estimated_range_left: nil, maximum_power_dispensed_kw: nil) ⇒ EvCharging
Returns a new instance of EvCharging.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 37 def initialize( carbon_footprint_avoided_grams_co2: nil, charging_ended_at: nil, charging_power_output_capacity_kw: nil, charging_started_at: nil, connector_type: nil, estimated_range_added: nil, estimated_range_left: nil, maximum_power_dispensed_kw: nil ) @carbon_footprint_avoided_grams_co2 = carbon_footprint_avoided_grams_co2 @charging_ended_at = charging_ended_at @charging_power_output_capacity_kw = charging_power_output_capacity_kw @charging_started_at = charging_started_at @connector_type = connector_type @estimated_range_added = estimated_range_added @estimated_range_left = estimated_range_left @maximum_power_dispensed_kw = maximum_power_dispensed_kw end |
Instance Attribute Details
#carbon_footprint_avoided_grams_co2 ⇒ Object
The carbon footprint avoided by the charging session, in grams of CO2.
21 22 23 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 21 def carbon_footprint_avoided_grams_co2 @carbon_footprint_avoided_grams_co2 end |
#charging_ended_at ⇒ Object
The time the charging session ended, measured in seconds since the Unix epoch.
23 24 25 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 23 def charging_ended_at @charging_ended_at end |
#charging_power_output_capacity_kw ⇒ Object
The power output capacity of the charging station, in kilowatts (kW).
25 26 27 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 25 def charging_power_output_capacity_kw @charging_power_output_capacity_kw end |
#charging_started_at ⇒ Object
The time the charging session started, measured in seconds since the Unix epoch.
27 28 29 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 27 def charging_started_at @charging_started_at end |
#connector_type ⇒ Object
The type of connector used for the charging session.
29 30 31 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 29 def connector_type @connector_type end |
#estimated_range_added ⇒ Object
The estimated distance in kilometers or miles added to the vehicle during the charging session.
31 32 33 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 31 def estimated_range_added @estimated_range_added end |
#estimated_range_left ⇒ Object
The estimated distance in kilometers or miles remaining in the vehicle after the charging session.
33 34 35 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 33 def estimated_range_left @estimated_range_left end |
#maximum_power_dispensed_kw ⇒ Object
The maximum power dispensed during the charging session, in kilowatts (kW).
35 36 37 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 35 def maximum_power_dispensed_kw @maximum_power_dispensed_kw end |