Class: Stripe::PaymentIntentCreateParams::AmountDetails::LineItem::PaymentMethodOptions::Card::FleetData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(product_type: nil, service_type: nil) ⇒ FleetData

Returns a new instance of FleetData.



25
26
27
28
# File 'lib/stripe/params/payment_intent_create_params.rb', line 25

def initialize(product_type: nil, service_type: nil)
  @product_type = product_type
  @service_type = service_type
end

Instance Attribute Details

#product_typeObject

The type of product being purchased at this line item.



21
22
23
# File 'lib/stripe/params/payment_intent_create_params.rb', line 21

def product_type
  @product_type
end

#service_typeObject

The type of service received at the acceptor location.



23
24
25
# File 'lib/stripe/params/payment_intent_create_params.rb', line 23

def service_type
  @service_type
end