Class: Stripe::PaymentIntentCreateParams::AmountDetails::LineItem::PaymentMethodOptions::Klarna

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(image_url: nil, product_url: nil, reference: nil, subscription_reference: nil) ⇒ Klarna

Returns a new instance of Klarna.



46
47
48
49
50
51
52
53
54
55
56
# File 'lib/stripe/params/payment_intent_create_params.rb', line 46

def initialize(
  image_url: nil,
  product_url: nil,
  reference: nil,
  subscription_reference: nil
)
  @image_url = image_url
  @product_url = product_url
  @reference = reference
  @subscription_reference = subscription_reference
end

Instance Attribute Details

#image_urlObject

URL to an image for the product. Max length, 4096 characters.



38
39
40
# File 'lib/stripe/params/payment_intent_create_params.rb', line 38

def image_url
  @image_url
end

#product_urlObject

URL to the product page. Max length, 4096 characters.



40
41
42
# File 'lib/stripe/params/payment_intent_create_params.rb', line 40

def product_url
  @product_url
end

#referenceObject

Unique reference for this line item to correlate it with your system’s internal records. The field is displayed in the Klarna Consumer App if passed.



42
43
44
# File 'lib/stripe/params/payment_intent_create_params.rb', line 42

def reference
  @reference
end

#subscription_referenceObject

Reference for the subscription this line item is for.



44
45
46
# File 'lib/stripe/params/payment_intent_create_params.rb', line 44

def subscription_reference
  @subscription_reference
end