Class: Stripe::PaymentIntentCreateParams::AmountDetails::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, from_postal_code: nil, to_postal_code: nil) ⇒ Shipping

Returns a new instance of Shipping.



168
169
170
171
172
# File 'lib/stripe/params/payment_intent_create_params.rb', line 168

def initialize(amount: nil, from_postal_code: nil, to_postal_code: nil)
  @amount = amount
  @from_postal_code = from_postal_code
  @to_postal_code = to_postal_code
end

Instance Attribute Details

#amountObject

If a physical good is being shipped, the cost of shipping represented in the [smallest currency unit](docs.stripe.com/currencies#zero-decimal). An integer greater than or equal to 0.



162
163
164
# File 'lib/stripe/params/payment_intent_create_params.rb', line 162

def amount
  @amount
end

#from_postal_codeObject

If a physical good is being shipped, the postal code of where it is being shipped from. At most 10 alphanumeric characters long, hyphens are allowed.



164
165
166
# File 'lib/stripe/params/payment_intent_create_params.rb', line 164

def from_postal_code
  @from_postal_code
end

#to_postal_codeObject

If a physical good is being shipped, the postal code of where it is being shipped to. At most 10 alphanumeric characters long, hyphens are allowed.



166
167
168
# File 'lib/stripe/params/payment_intent_create_params.rb', line 166

def to_postal_code
  @to_postal_code
end