Class: Stripe::PaymentIntentCreateParams::AmountDetails::Surcharge

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, enforce_validation: nil) ⇒ Surcharge

Returns a new instance of Surcharge.



154
155
156
157
# File 'lib/stripe/params/payment_intent_create_params.rb', line 154

def initialize(amount: nil, enforce_validation: nil)
  @amount = amount
  @enforce_validation = enforce_validation
end

Instance Attribute Details

#amountObject

Portion of the amount that corresponds to a surcharge.



150
151
152
# File 'lib/stripe/params/payment_intent_create_params.rb', line 150

def amount
  @amount
end

#enforce_validationObject

Indicate whether to enforce validations on the surcharge amount.



152
153
154
# File 'lib/stripe/params/payment_intent_create_params.rb', line 152

def enforce_validation
  @enforce_validation
end