Class: Stripe::PaymentIntentCreateParams::AutomaticPaymentMethods

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(allow_redirects: nil, enabled: nil) ⇒ AutomaticPaymentMethods

Returns a new instance of AutomaticPaymentMethods.



214
215
216
217
# File 'lib/stripe/params/payment_intent_create_params.rb', line 214

def initialize(allow_redirects: nil, enabled: nil)
  @allow_redirects = allow_redirects
  @enabled = enabled
end

Instance Attribute Details

#allow_redirectsObject

Controls whether this PaymentIntent will accept redirect-based payment methods.

Redirect-based payment methods may require your customer to be redirected to a payment method’s app or site for authentication or additional steps. To [confirm](docs.stripe.com/api/payment_intents/confirm) this PaymentIntent, you may be required to provide a ‘return_url` to redirect customers back to your site after they authenticate or complete the payment.



210
211
212
# File 'lib/stripe/params/payment_intent_create_params.rb', line 210

def allow_redirects
  @allow_redirects
end

#enabledObject

Whether this feature is enabled.



212
213
214
# File 'lib/stripe/params/payment_intent_create_params.rb', line 212

def enabled
  @enabled
end