Class: Stripe::PaymentIntentCreateParams::MandateData::CustomerAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Defined Under Namespace

Classes: Offline, Online

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(accepted_at: nil, offline: nil, online: nil, type: nil) ⇒ CustomerAcceptance

Returns a new instance of CustomerAcceptance.



296
297
298
299
300
301
# File 'lib/stripe/params/payment_intent_create_params.rb', line 296

def initialize(accepted_at: nil, offline: nil, online: nil, type: nil)
  @accepted_at = accepted_at
  @offline = offline
  @online = online
  @type = type
end

Instance Attribute Details

#accepted_atObject

The time at which the customer accepted the Mandate.



288
289
290
# File 'lib/stripe/params/payment_intent_create_params.rb', line 288

def accepted_at
  @accepted_at
end

#offlineObject

If this is a Mandate accepted offline, this hash contains details about the offline acceptance.



290
291
292
# File 'lib/stripe/params/payment_intent_create_params.rb', line 290

def offline
  @offline
end

#onlineObject

If this is a Mandate accepted online, this hash contains details about the online acceptance.



292
293
294
# File 'lib/stripe/params/payment_intent_create_params.rb', line 292

def online
  @online
end

#typeObject

The type of customer acceptance information included with the Mandate. One of ‘online` or `offline`.



294
295
296
# File 'lib/stripe/params/payment_intent_create_params.rb', line 294

def type
  @type
end