Class: Stripe::PaymentIntentCreateParams::PaymentDetails::Benefit::FrMealVoucher
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentDetails::Benefit::FrMealVoucher
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Whether to enable meal voucher benefit for this payment.
-
#siret ⇒ Object
The 14-digit SIRET of the meal voucher acceptor.
Instance Method Summary collapse
-
#initialize(enabled: nil, siret: nil) ⇒ FrMealVoucher
constructor
A new instance of FrMealVoucher.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(enabled: nil, siret: nil) ⇒ FrMealVoucher
Returns a new instance of FrMealVoucher.
319 320 321 322 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 319 def initialize(enabled: nil, siret: nil) @enabled = enabled @siret = siret end |
Instance Attribute Details
#enabled ⇒ Object
Whether to enable meal voucher benefit for this payment.
315 316 317 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 315 def enabled @enabled end |
#siret ⇒ Object
The 14-digit SIRET of the meal voucher acceptor.
317 318 319 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 317 def siret @siret end |