Class: Stripe::PaymentIntentCreateParams::PaymentDetails::CarRental

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Defined Under Namespace

Classes: Affiliate, Delivery, Distance, Driver, PickupAddress, ReturnAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil) ⇒ CarRental

Returns a new instance of CarRental.



560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
# File 'lib/stripe/params/payment_intent_create_params.rb', line 560

def initialize(
  affiliate: nil,
  booking_number: nil,
  car_class_code: nil,
  car_make: nil,
  car_model: nil,
  company: nil,
  customer_service_phone_number: nil,
  days_rented: nil,
  delivery: nil,
  distance: nil,
  drivers: nil,
  extra_charges: nil,
  no_show: nil,
  pickup_address: nil,
  pickup_at: nil,
  pickup_location_name: nil,
  rate_amount: nil,
  rate_interval: nil,
  renter_name: nil,
  return_address: nil,
  return_at: nil,
  return_location_name: nil,
  tax_exempt: nil,
  vehicle_identification_number: nil
)
  @affiliate = affiliate
  @booking_number = booking_number
  @car_class_code = car_class_code
  @car_make = car_make
  @car_model = car_model
  @company = company
  @customer_service_phone_number = customer_service_phone_number
  @days_rented = days_rented
  @delivery = delivery
  @distance = distance
  @drivers = drivers
  @extra_charges = extra_charges
  @no_show = no_show
  @pickup_address = pickup_address
  @pickup_at = pickup_at
  @pickup_location_name = pickup_location_name
  @rate_amount = rate_amount
  @rate_interval = rate_interval
  @renter_name = renter_name
  @return_address = return_address
  @return_at = return_at
  @return_location_name = return_location_name
  @tax_exempt = tax_exempt
  @vehicle_identification_number = vehicle_identification_number
end

Instance Attribute Details

#affiliateObject

Affiliate details for this purchase.



512
513
514
# File 'lib/stripe/params/payment_intent_create_params.rb', line 512

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the car rental.



514
515
516
# File 'lib/stripe/params/payment_intent_create_params.rb', line 514

def booking_number
  @booking_number
end

#car_class_codeObject

Class code of the car.



516
517
518
# File 'lib/stripe/params/payment_intent_create_params.rb', line 516

def car_class_code
  @car_class_code
end

#car_makeObject

Make of the car.



518
519
520
# File 'lib/stripe/params/payment_intent_create_params.rb', line 518

def car_make
  @car_make
end

#car_modelObject

Model of the car.



520
521
522
# File 'lib/stripe/params/payment_intent_create_params.rb', line 520

def car_model
  @car_model
end

#companyObject

The name of the rental car company.



522
523
524
# File 'lib/stripe/params/payment_intent_create_params.rb', line 522

def company
  @company
end

#customer_service_phone_numberObject

The customer service phone number of the car rental company.



524
525
526
# File 'lib/stripe/params/payment_intent_create_params.rb', line 524

def customer_service_phone_number
  @customer_service_phone_number
end

#days_rentedObject

Number of days the car is being rented.



526
527
528
# File 'lib/stripe/params/payment_intent_create_params.rb', line 526

def days_rented
  @days_rented
end

#deliveryObject

Delivery details for this purchase.



528
529
530
# File 'lib/stripe/params/payment_intent_create_params.rb', line 528

def delivery
  @delivery
end

#distanceObject

The details of the distance traveled during the rental period.



530
531
532
# File 'lib/stripe/params/payment_intent_create_params.rb', line 530

def distance
  @distance
end

#driversObject

The details of the passengers in the travel reservation



532
533
534
# File 'lib/stripe/params/payment_intent_create_params.rb', line 532

def drivers
  @drivers
end

#extra_chargesObject

List of additional charges being billed.



534
535
536
# File 'lib/stripe/params/payment_intent_create_params.rb', line 534

def extra_charges
  @extra_charges
end

#no_showObject

Indicates if the customer did not keep nor cancel their booking.



536
537
538
# File 'lib/stripe/params/payment_intent_create_params.rb', line 536

def no_show
  @no_show
end

#pickup_addressObject

Car pick-up address.



538
539
540
# File 'lib/stripe/params/payment_intent_create_params.rb', line 538

def pickup_address
  @pickup_address
end

#pickup_atObject

Car pick-up time. Measured in seconds since the Unix epoch.



540
541
542
# File 'lib/stripe/params/payment_intent_create_params.rb', line 540

def pickup_at
  @pickup_at
end

#pickup_location_nameObject

Name of the pickup location.



542
543
544
# File 'lib/stripe/params/payment_intent_create_params.rb', line 542

def pickup_location_name
  @pickup_location_name
end

#rate_amountObject

Rental rate.



544
545
546
# File 'lib/stripe/params/payment_intent_create_params.rb', line 544

def rate_amount
  @rate_amount
end

#rate_intervalObject

The frequency at which the rate amount is applied. One of day, week or month



546
547
548
# File 'lib/stripe/params/payment_intent_create_params.rb', line 546

def rate_interval
  @rate_interval
end

#renter_nameObject

The name of the person or entity renting the car.



548
549
550
# File 'lib/stripe/params/payment_intent_create_params.rb', line 548

def renter_name
  @renter_name
end

#return_addressObject

Car return address.



550
551
552
# File 'lib/stripe/params/payment_intent_create_params.rb', line 550

def return_address
  @return_address
end

#return_atObject

Car return time. Measured in seconds since the Unix epoch.



552
553
554
# File 'lib/stripe/params/payment_intent_create_params.rb', line 552

def return_at
  @return_at
end

#return_location_nameObject

Name of the return location.



554
555
556
# File 'lib/stripe/params/payment_intent_create_params.rb', line 554

def return_location_name
  @return_location_name
end

#tax_exemptObject

Indicates whether the goods or services are tax-exempt or tax is not collected.



556
557
558
# File 'lib/stripe/params/payment_intent_create_params.rb', line 556

def tax_exempt
  @tax_exempt
end

#vehicle_identification_numberObject

The vehicle identification number.



558
559
560
# File 'lib/stripe/params/payment_intent_create_params.rb', line 558

def vehicle_identification_number
  @vehicle_identification_number
end