Class: Stripe::PaymentIntentCreateParams::PaymentDetails::CarRental::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



406
407
408
409
410
# File 'lib/stripe/params/payment_intent_create_params.rb', line 406

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



400
401
402
# File 'lib/stripe/params/payment_intent_create_params.rb', line 400

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



402
403
404
# File 'lib/stripe/params/payment_intent_create_params.rb', line 402

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



404
405
406
# File 'lib/stripe/params/payment_intent_create_params.rb', line 404

def phone
  @phone
end