Class: Stripe::PaymentIntentCreateParams::PaymentDetails::CarRentalDatum
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentDetails::CarRentalDatum
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: Affiliate, Distance, Driver, DropOff, Insurance, Pickup, Total, Vehicle
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate (such as travel agency) details for the rental.
-
#booking_number ⇒ Object
Booking confirmation number for the car rental.
-
#carrier_name ⇒ Object
Name of the car rental company.
-
#customer_service_phone_number ⇒ Object
Customer service phone number for the car rental company.
-
#days_rented ⇒ Object
Number of days the car is being rented.
-
#distance ⇒ Object
Distance details for the rental.
-
#drivers ⇒ Object
List of drivers for the rental.
-
#drop_off ⇒ Object
Drop-off location details.
-
#insurances ⇒ Object
Insurance details for the rental.
-
#no_show_indicator ⇒ Object
Indicates if the customer was a no-show.
-
#pickup ⇒ Object
Pickup location details.
-
#renter_name ⇒ Object
Name of the person renting the vehicle.
-
#total ⇒ Object
Total cost breakdown for the rental.
-
#vehicle ⇒ Object
Vehicle details for the rental.
Instance Method Summary collapse
-
#initialize(affiliate: nil, booking_number: nil, carrier_name: nil, customer_service_phone_number: nil, days_rented: nil, distance: nil, drivers: nil, drop_off: nil, insurances: nil, no_show_indicator: nil, pickup: nil, renter_name: nil, total: nil, vehicle: nil) ⇒ CarRentalDatum
constructor
A new instance of CarRentalDatum.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate: nil, booking_number: nil, carrier_name: nil, customer_service_phone_number: nil, days_rented: nil, distance: nil, drivers: nil, drop_off: nil, insurances: nil, no_show_indicator: nil, pickup: nil, renter_name: nil, total: nil, vehicle: nil) ⇒ CarRentalDatum
Returns a new instance of CarRentalDatum.
883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 883 def initialize( affiliate: nil, booking_number: nil, carrier_name: nil, customer_service_phone_number: nil, days_rented: nil, distance: nil, drivers: nil, drop_off: nil, insurances: nil, no_show_indicator: nil, pickup: nil, renter_name: nil, total: nil, vehicle: nil ) @affiliate = affiliate @booking_number = booking_number @carrier_name = carrier_name @customer_service_phone_number = customer_service_phone_number @days_rented = days_rented @distance = distance @drivers = drivers @drop_off = drop_off @insurances = insurances @no_show_indicator = no_show_indicator @pickup = pickup @renter_name = renter_name @total = total @vehicle = vehicle end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate (such as travel agency) details for the rental.
855 856 857 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 855 def affiliate @affiliate end |
#booking_number ⇒ Object
Booking confirmation number for the car rental.
857 858 859 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 857 def booking_number @booking_number end |
#carrier_name ⇒ Object
Name of the car rental company.
859 860 861 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 859 def carrier_name @carrier_name end |
#customer_service_phone_number ⇒ Object
Customer service phone number for the car rental company.
861 862 863 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 861 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object
Number of days the car is being rented.
863 864 865 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 863 def days_rented @days_rented end |
#distance ⇒ Object
Distance details for the rental.
865 866 867 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 865 def distance @distance end |
#drivers ⇒ Object
List of drivers for the rental.
867 868 869 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 867 def drivers @drivers end |
#drop_off ⇒ Object
Drop-off location details.
869 870 871 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 869 def drop_off @drop_off end |
#insurances ⇒ Object
Insurance details for the rental.
871 872 873 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 871 def insurances @insurances end |
#no_show_indicator ⇒ Object
Indicates if the customer was a no-show.
873 874 875 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 873 def no_show_indicator @no_show_indicator end |
#pickup ⇒ Object
Pickup location details.
875 876 877 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 875 def pickup @pickup end |
#renter_name ⇒ Object
Name of the person renting the vehicle.
877 878 879 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 877 def renter_name @renter_name end |
#total ⇒ Object
Total cost breakdown for the rental.
879 880 881 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 879 def total @total end |
#vehicle ⇒ Object
Vehicle details for the rental.
881 882 883 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 881 def vehicle @vehicle end |