Class: Stripe::PaymentIntentCreateParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location's address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1056 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
1038 1039 1040 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1038 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location's address.
1040 1041 1042 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1040 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
1042 1043 1044 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1042 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
1044 1045 1046 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1044 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
1046 1047 1048 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1046 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
1048 1049 1050 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1048 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
1050 1051 1052 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1050 def genre @genre end |
#name ⇒ Object
The name of the event.
1052 1053 1054 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1052 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
1054 1055 1056 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1054 def starts_at @starts_at end |