Class: Stripe::PaymentIntentCreateParams::PaymentDetails::EventDetails::Affiliate
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentDetails::EventDetails::Affiliate
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Instance Attribute Summary collapse
-
#name ⇒ Object
The name of the affiliate that originated the purchase.
Instance Method Summary collapse
-
#initialize(name: nil) ⇒ Affiliate
constructor
A new instance of Affiliate.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(name: nil) ⇒ Affiliate
Returns a new instance of Affiliate.
1007 1008 1009 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1007 def initialize(name: nil) @name = name end |
Instance Attribute Details
#name ⇒ Object
The name of the affiliate that originated the purchase.
1005 1006 1007 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1005 def name @name end |