Class: Stripe::PaymentIntentCreateParams::PaymentDetails::Flight
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentDetails::Flight
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Passenger, Segment
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
-
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#segments ⇒ Object
The individual flight segments associated with the trip.
-
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
Instance Method Summary collapse
-
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
constructor
A new instance of Flight.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
Returns a new instance of Flight.
1272 1273 1274 1275 1276 1277 1278 1279 1280 1281 1282 1283 1284 1285 1286 1287 1288 1289 1290 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1272 def initialize( affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil ) @affiliate = affiliate @agency_number = agency_number @carrier = carrier @delivery = delivery @passenger_name = passenger_name @passengers = passengers @segments = segments @ticket_number = ticket_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
1256 1257 1258 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1256 def affiliate @affiliate end |
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
1258 1259 1260 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1258 def agency_number @agency_number end |
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
1260 1261 1262 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1260 def carrier @carrier end |
#delivery ⇒ Object
Delivery details for this purchase.
1262 1263 1264 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1262 def delivery @delivery end |
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
1264 1265 1266 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1264 def passenger_name @passenger_name end |
#passengers ⇒ Object
The details of the passengers in the travel reservation.
1266 1267 1268 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1266 def passengers @passengers end |
#segments ⇒ Object
The individual flight segments associated with the trip.
1268 1269 1270 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1268 def segments @segments end |
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
1270 1271 1272 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1270 def ticket_number @ticket_number end |