Class: Stripe::PaymentIntentCreateParams::PaymentDetails::Flight::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



1191
1192
1193
1194
1195
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1191

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



1185
1186
1187
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1185

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



1187
1188
1189
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1187

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



1189
1190
1191
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1189

def phone
  @phone
end