Class: Stripe::PaymentIntentCreateParams::PaymentDetails::Lodging::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



1612
1613
1614
1615
1616
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1612

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



1606
1607
1608
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1606

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



1608
1609
1610
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1608

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



1610
1611
1612
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1610

def phone
  @phone
end