Class: Stripe::PaymentIntentCreateParams::PaymentDetails::MoneyServices
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentDetails::MoneyServices
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: AccountFunding, BeneficiaryDetails
Instance Attribute Summary collapse
-
#account_funding ⇒ Object
Account funding transaction details including sender information.
-
#beneficiary_details ⇒ Object
Inline identity details for the beneficiary of this transaction.
-
#transaction_type ⇒ Object
The type of money services transaction.
Instance Method Summary collapse
-
#initialize(account_funding: nil, beneficiary_details: nil, transaction_type: nil) ⇒ MoneyServices
constructor
A new instance of MoneyServices.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(account_funding: nil, beneficiary_details: nil, transaction_type: nil) ⇒ MoneyServices
Returns a new instance of MoneyServices.
2192 2193 2194 2195 2196 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2192 def initialize(account_funding: nil, beneficiary_details: nil, transaction_type: nil) @account_funding = account_funding @beneficiary_details = beneficiary_details @transaction_type = transaction_type end |
Instance Attribute Details
#account_funding ⇒ Object
Account funding transaction details including sender information.
2186 2187 2188 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2186 def account_funding @account_funding end |
#beneficiary_details ⇒ Object
Inline identity details for the beneficiary of this transaction.
2188 2189 2190 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2188 def beneficiary_details @beneficiary_details end |
#transaction_type ⇒ Object
The type of money services transaction.
2190 2191 2192 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2190 def transaction_type @transaction_type end |