Class: Stripe::PaymentIntentCreateParams::PaymentDetails::MoneyServices::AccountFunding

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Defined Under Namespace

Classes: BeneficiaryDetails, SenderDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(beneficiary_account: nil, beneficiary_details: nil, sender_account: nil, sender_details: nil) ⇒ AccountFunding

Returns a new instance of AccountFunding.



2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2108

def initialize(
  beneficiary_account: nil,
  beneficiary_details: nil,
  sender_account: nil,
  sender_details: nil
)
  @beneficiary_account = 
  @beneficiary_details = beneficiary_details
  @sender_account = 
  @sender_details = sender_details
end

Instance Attribute Details

#beneficiary_accountObject

ID of the Account representing the beneficiary in this account funding transaction.



2100
2101
2102
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2100

def 
  @beneficiary_account
end

#beneficiary_detailsObject

Inline identity details for the beneficiary of this account funding transaction.



2102
2103
2104
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2102

def beneficiary_details
  @beneficiary_details
end

#sender_accountObject

ID of the Account representing the sender in this account funding transaction.



2104
2105
2106
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2104

def 
  @sender_account
end

#sender_detailsObject

Inline identity details for the sender of this account funding transaction.



2106
2107
2108
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2106

def sender_details
  @sender_details
end