Class: Stripe::PaymentIntentCreateParams::PaymentMethodData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Defined Under Namespace

Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, BillingDetails, Bizum, Blik, Boleto, Cashapp, Crypto, CustomerBalance, Eps, Fpx, GiftCard, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Paypay, Payto, Pix, Promptpay, Qris, RadarOptions, Rechnung, RevolutPay, SamsungPay, Satispay, Scalapay, SepaDebit, Shopeepay, Sofort, StripeBalance, Sunbit, Swish, Twint, Upi, UsBankAccount, WechatPay, Zip

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, allow_redisplay: nil, alma: nil, amazon_pay: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, billie: nil, billing_details: nil, bizum: nil, blik: nil, boleto: nil, cashapp: nil, crypto: nil, customer_balance: nil, eps: nil, fpx: nil, gift_card: nil, giropay: nil, gopay: nil, grabpay: nil, id_bank_transfer: nil, ideal: nil, interac_present: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, mb_way: nil, metadata: nil, mobilepay: nil, multibanco: nil, naver_pay: nil, nz_bank_account: nil, oxxo: nil, p24: nil, pay_by_bank: nil, payco: nil, paynow: nil, paypal: nil, paypay: nil, payto: nil, pix: nil, promptpay: nil, qris: nil, radar_options: nil, rechnung: nil, revolut_pay: nil, samsung_pay: nil, satispay: nil, scalapay: nil, sepa_debit: nil, shared_payment_granted_token: nil, shopeepay: nil, sofort: nil, stripe_balance: nil, sunbit: nil, swish: nil, twint: nil, type: nil, upi: nil, us_bank_account: nil, wechat_pay: nil, zip: nil) ⇒ PaymentMethodData

Returns a new instance of PaymentMethodData.



2786
2787
2788
2789
2790
2791
2792
2793
2794
2795
2796
2797
2798
2799
2800
2801
2802
2803
2804
2805
2806
2807
2808
2809
2810
2811
2812
2813
2814
2815
2816
2817
2818
2819
2820
2821
2822
2823
2824
2825
2826
2827
2828
2829
2830
2831
2832
2833
2834
2835
2836
2837
2838
2839
2840
2841
2842
2843
2844
2845
2846
2847
2848
2849
2850
2851
2852
2853
2854
2855
2856
2857
2858
2859
2860
2861
2862
2863
2864
2865
2866
2867
2868
2869
2870
2871
2872
2873
2874
2875
2876
2877
2878
2879
2880
2881
2882
2883
2884
2885
2886
2887
2888
2889
2890
2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
2917
2918
2919
2920
2921
2922
2923
2924
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2786

def initialize(
  acss_debit: nil,
  affirm: nil,
  afterpay_clearpay: nil,
  alipay: nil,
  allow_redisplay: nil,
  alma: nil,
  amazon_pay: nil,
  au_becs_debit: nil,
  bacs_debit: nil,
  bancontact: nil,
  billie: nil,
  billing_details: nil,
  bizum: nil,
  blik: nil,
  boleto: nil,
  cashapp: nil,
  crypto: nil,
  customer_balance: nil,
  eps: nil,
  fpx: nil,
  gift_card: nil,
  giropay: nil,
  gopay: nil,
  grabpay: nil,
  id_bank_transfer: nil,
  ideal: nil,
  interac_present: nil,
  kakao_pay: nil,
  klarna: nil,
  konbini: nil,
  kr_card: nil,
  link: nil,
  mb_way: nil,
  metadata: nil,
  mobilepay: nil,
  multibanco: nil,
  naver_pay: nil,
  nz_bank_account: nil,
  oxxo: nil,
  p24: nil,
  pay_by_bank: nil,
  payco: nil,
  paynow: nil,
  paypal: nil,
  paypay: nil,
  payto: nil,
  pix: nil,
  promptpay: nil,
  qris: nil,
  radar_options: nil,
  rechnung: nil,
  revolut_pay: nil,
  samsung_pay: nil,
  satispay: nil,
  scalapay: nil,
  sepa_debit: nil,
  shared_payment_granted_token: nil,
  shopeepay: nil,
  sofort: nil,
  stripe_balance: nil,
  sunbit: nil,
  swish: nil,
  twint: nil,
  type: nil,
  upi: nil,
  us_bank_account: nil,
  wechat_pay: nil,
  zip: nil
)
  @acss_debit = acss_debit
  @affirm = affirm
  @afterpay_clearpay = afterpay_clearpay
  @alipay = alipay
  @allow_redisplay = allow_redisplay
  @alma = alma
  @amazon_pay = amazon_pay
  @au_becs_debit = au_becs_debit
  @bacs_debit = bacs_debit
  @bancontact = bancontact
  @billie = billie
  @billing_details = billing_details
  @bizum = bizum
  @blik = blik
  @boleto = boleto
  @cashapp = cashapp
  @crypto = crypto
  @customer_balance = customer_balance
  @eps = eps
  @fpx = fpx
  @gift_card = gift_card
  @giropay = giropay
  @gopay = gopay
  @grabpay = grabpay
  @id_bank_transfer = id_bank_transfer
  @ideal = ideal
  @interac_present = interac_present
  @kakao_pay = kakao_pay
  @klarna = klarna
  @konbini = konbini
  @kr_card = kr_card
  @link = link
  @mb_way = mb_way
  @metadata = 
  @mobilepay = mobilepay
  @multibanco = multibanco
  @naver_pay = naver_pay
  @nz_bank_account = 
  @oxxo = oxxo
  @p24 = p24
  @pay_by_bank = pay_by_bank
  @payco = payco
  @paynow = paynow
  @paypal = paypal
  @paypay = paypay
  @payto = payto
  @pix = pix
  @promptpay = promptpay
  @qris = qris
  @radar_options = radar_options
  @rechnung = rechnung
  @revolut_pay = revolut_pay
  @samsung_pay = samsung_pay
  @satispay = satispay
  @scalapay = scalapay
  @sepa_debit = sepa_debit
  @shared_payment_granted_token = shared_payment_granted_token
  @shopeepay = shopeepay
  @sofort = sofort
  @stripe_balance = stripe_balance
  @sunbit = sunbit
  @swish = swish
  @twint = twint
  @type = type
  @upi = upi
  @us_bank_account = 
  @wechat_pay = wechat_pay
  @zip = zip
end

Instance Attribute Details

#acss_debitObject

If this is an ‘acss_debit` PaymentMethod, this hash contains details about the ACSS Debit payment method.



2650
2651
2652
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2650

def acss_debit
  @acss_debit
end

#affirmObject

If this is an ‘affirm` PaymentMethod, this hash contains details about the Affirm payment method.



2652
2653
2654
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2652

def affirm
  @affirm
end

#afterpay_clearpayObject

If this is an ‘AfterpayClearpay` PaymentMethod, this hash contains details about the AfterpayClearpay payment method.



2654
2655
2656
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2654

def afterpay_clearpay
  @afterpay_clearpay
end

#alipayObject

If this is an ‘Alipay` PaymentMethod, this hash contains details about the Alipay payment method.



2656
2657
2658
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2656

def alipay
  @alipay
end

#allow_redisplayObject

This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. The field defaults to ‘unspecified`.



2658
2659
2660
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2658

def allow_redisplay
  @allow_redisplay
end

#almaObject

If this is a Alma PaymentMethod, this hash contains details about the Alma payment method.



2660
2661
2662
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2660

def alma
  @alma
end

#amazon_payObject

If this is a AmazonPay PaymentMethod, this hash contains details about the AmazonPay payment method.



2662
2663
2664
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2662

def amazon_pay
  @amazon_pay
end

#au_becs_debitObject

If this is an ‘au_becs_debit` PaymentMethod, this hash contains details about the bank account.



2664
2665
2666
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2664

def au_becs_debit
  @au_becs_debit
end

#bacs_debitObject

If this is a ‘bacs_debit` PaymentMethod, this hash contains details about the Bacs Direct Debit bank account.



2666
2667
2668
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2666

def bacs_debit
  @bacs_debit
end

#bancontactObject

If this is a ‘bancontact` PaymentMethod, this hash contains details about the Bancontact payment method.



2668
2669
2670
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2668

def bancontact
  @bancontact
end

#billieObject

If this is a ‘billie` PaymentMethod, this hash contains details about the Billie payment method.



2670
2671
2672
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2670

def billie
  @billie
end

#billing_detailsObject

Billing information associated with the PaymentMethod that may be used or required by particular types of payment methods.



2672
2673
2674
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2672

def billing_details
  @billing_details
end

#bizumObject

If this is a ‘bizum` PaymentMethod, this hash contains details about the Bizum payment method.



2674
2675
2676
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2674

def bizum
  @bizum
end

#blikObject

If this is a ‘blik` PaymentMethod, this hash contains details about the BLIK payment method.



2676
2677
2678
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2676

def blik
  @blik
end

#boletoObject

If this is a ‘boleto` PaymentMethod, this hash contains details about the Boleto payment method.



2678
2679
2680
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2678

def boleto
  @boleto
end

#cashappObject

If this is a ‘cashapp` PaymentMethod, this hash contains details about the Cash App Pay payment method.



2680
2681
2682
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2680

def cashapp
  @cashapp
end

#cryptoObject

If this is a Crypto PaymentMethod, this hash contains details about the Crypto payment method.



2682
2683
2684
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2682

def crypto
  @crypto
end

#customer_balanceObject

If this is a ‘customer_balance` PaymentMethod, this hash contains details about the CustomerBalance payment method.



2684
2685
2686
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2684

def customer_balance
  @customer_balance
end

#epsObject

If this is an ‘eps` PaymentMethod, this hash contains details about the EPS payment method.



2686
2687
2688
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2686

def eps
  @eps
end

#fpxObject

If this is an ‘fpx` PaymentMethod, this hash contains details about the FPX payment method.



2688
2689
2690
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2688

def fpx
  @fpx
end

#gift_cardObject

If this is a ‘gift_card` PaymentMethod, this hash contains details about the gift card payment method.



2690
2691
2692
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2690

def gift_card
  @gift_card
end

#giropayObject

If this is a ‘giropay` PaymentMethod, this hash contains details about the Giropay payment method.



2692
2693
2694
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2692

def giropay
  @giropay
end

#gopayObject

If this is a Gopay PaymentMethod, this hash contains details about the Gopay payment method.



2694
2695
2696
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2694

def gopay
  @gopay
end

#grabpayObject

If this is a ‘grabpay` PaymentMethod, this hash contains details about the GrabPay payment method.



2696
2697
2698
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2696

def grabpay
  @grabpay
end

#id_bank_transferObject

If this is an ‘IdBankTransfer` PaymentMethod, this hash contains details about the IdBankTransfer payment method.



2698
2699
2700
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2698

def id_bank_transfer
  @id_bank_transfer
end

#idealObject

If this is an ‘ideal` PaymentMethod, this hash contains details about the iDEAL payment method.



2700
2701
2702
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2700

def ideal
  @ideal
end

#interac_presentObject

If this is an ‘interac_present` PaymentMethod, this hash contains details about the Interac Present payment method.



2702
2703
2704
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2702

def interac_present
  @interac_present
end

#kakao_payObject

If this is a ‘kakao_pay` PaymentMethod, this hash contains details about the Kakao Pay payment method.



2704
2705
2706
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2704

def kakao_pay
  @kakao_pay
end

#klarnaObject

If this is a ‘klarna` PaymentMethod, this hash contains details about the Klarna payment method.



2706
2707
2708
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2706

def klarna
  @klarna
end

#konbiniObject

If this is a ‘konbini` PaymentMethod, this hash contains details about the Konbini payment method.



2708
2709
2710
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2708

def konbini
  @konbini
end

#kr_cardObject

If this is a ‘kr_card` PaymentMethod, this hash contains details about the Korean Card payment method.



2710
2711
2712
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2710

def kr_card
  @kr_card
end

If this is an ‘Link` PaymentMethod, this hash contains details about the Link payment method (Link is also known as Onelink in the UK).



2712
2713
2714
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2712

def link
  @link
end

#mb_wayObject

If this is a MB WAY PaymentMethod, this hash contains details about the MB WAY payment method.



2714
2715
2716
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2714

def mb_way
  @mb_way
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2716
2717
2718
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2716

def 
  @metadata
end

#mobilepayObject

If this is a ‘mobilepay` PaymentMethod, this hash contains details about the MobilePay payment method.



2718
2719
2720
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2718

def mobilepay
  @mobilepay
end

#multibancoObject

If this is a ‘multibanco` PaymentMethod, this hash contains details about the Multibanco payment method.



2720
2721
2722
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2720

def multibanco
  @multibanco
end

If this is a ‘naver_pay` PaymentMethod, this hash contains details about the Naver Pay payment method.



2722
2723
2724
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2722

def naver_pay
  @naver_pay
end

#nz_bank_accountObject

If this is an nz_bank_account PaymentMethod, this hash contains details about the nz_bank_account payment method.



2724
2725
2726
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2724

def 
  @nz_bank_account
end

#oxxoObject

If this is an ‘oxxo` PaymentMethod, this hash contains details about the OXXO payment method.



2726
2727
2728
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2726

def oxxo
  @oxxo
end

#p24Object

If this is a ‘p24` PaymentMethod, this hash contains details about the P24 payment method.



2728
2729
2730
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2728

def p24
  @p24
end

#pay_by_bankObject

If this is a ‘pay_by_bank` PaymentMethod, this hash contains details about the PayByBank payment method.



2730
2731
2732
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2730

def pay_by_bank
  @pay_by_bank
end

#paycoObject

If this is a ‘payco` PaymentMethod, this hash contains details about the PAYCO payment method.



2732
2733
2734
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2732

def payco
  @payco
end

#paynowObject

If this is a ‘paynow` PaymentMethod, this hash contains details about the PayNow payment method.



2734
2735
2736
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2734

def paynow
  @paynow
end

#paypalObject

If this is a ‘paypal` PaymentMethod, this hash contains details about the PayPal payment method.



2736
2737
2738
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2736

def paypal
  @paypal
end

#paypayObject

If this is a ‘paypay` PaymentMethod, this hash contains details about the PayPay payment method.



2738
2739
2740
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2738

def paypay
  @paypay
end

#paytoObject

If this is a ‘payto` PaymentMethod, this hash contains details about the PayTo payment method.



2740
2741
2742
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2740

def payto
  @payto
end

#pixObject

If this is a ‘pix` PaymentMethod, this hash contains details about the Pix payment method.



2742
2743
2744
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2742

def pix
  @pix
end

#promptpayObject

If this is a ‘promptpay` PaymentMethod, this hash contains details about the PromptPay payment method.



2744
2745
2746
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2744

def promptpay
  @promptpay
end

#qrisObject

If this is a ‘qris` PaymentMethod, this hash contains details about the QRIS payment method.



2746
2747
2748
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2746

def qris
  @qris
end

#radar_optionsObject

Options to configure Radar. See [Radar Session](docs.stripe.com/radar/radar-session) for more information.



2748
2749
2750
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2748

def radar_options
  @radar_options
end

#rechnungObject

If this is a ‘rechnung` PaymentMethod, this hash contains details about the Rechnung payment method.



2750
2751
2752
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2750

def rechnung
  @rechnung
end

#revolut_payObject

If this is a ‘revolut_pay` PaymentMethod, this hash contains details about the Revolut Pay payment method.



2752
2753
2754
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2752

def revolut_pay
  @revolut_pay
end

#samsung_payObject

If this is a ‘samsung_pay` PaymentMethod, this hash contains details about the SamsungPay payment method.



2754
2755
2756
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2754

def samsung_pay
  @samsung_pay
end

#satispayObject

If this is a ‘satispay` PaymentMethod, this hash contains details about the Satispay payment method.



2756
2757
2758
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2756

def satispay
  @satispay
end

#scalapayObject

If this is a Scalapay PaymentMethod, this hash contains details about the Scalapay payment method.



2758
2759
2760
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2758

def scalapay
  @scalapay
end

#sepa_debitObject

If this is a ‘sepa_debit` PaymentMethod, this hash contains details about the SEPA debit bank account.



2760
2761
2762
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2760

def sepa_debit
  @sepa_debit
end

#shared_payment_granted_tokenObject

ID of the SharedPaymentGrantedToken used to confirm this PaymentIntent.



2762
2763
2764
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2762

def shared_payment_granted_token
  @shared_payment_granted_token
end

#shopeepayObject

If this is a Shopeepay PaymentMethod, this hash contains details about the Shopeepay payment method.



2764
2765
2766
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2764

def shopeepay
  @shopeepay
end

#sofortObject

If this is a ‘sofort` PaymentMethod, this hash contains details about the SOFORT payment method.



2766
2767
2768
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2766

def sofort
  @sofort
end

#stripe_balanceObject

This hash contains details about the Stripe balance payment method.



2768
2769
2770
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2768

def stripe_balance
  @stripe_balance
end

#sunbitObject

If this is a Sunbit PaymentMethod, this hash contains details about the Sunbit payment method.



2770
2771
2772
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2770

def sunbit
  @sunbit
end

#swishObject

If this is a ‘swish` PaymentMethod, this hash contains details about the Swish payment method.



2772
2773
2774
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2772

def swish
  @swish
end

#twintObject

If this is a TWINT PaymentMethod, this hash contains details about the TWINT payment method.



2774
2775
2776
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2774

def twint
  @twint
end

#typeObject

The type of the PaymentMethod. An additional hash is included on the PaymentMethod with a name matching this value. It contains additional information specific to the PaymentMethod type.



2776
2777
2778
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2776

def type
  @type
end

#upiObject

If this is a ‘upi` PaymentMethod, this hash contains details about the UPI payment method.



2778
2779
2780
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2778

def upi
  @upi
end

#us_bank_accountObject

If this is an ‘us_bank_account` PaymentMethod, this hash contains details about the US bank account payment method.



2780
2781
2782
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2780

def 
  @us_bank_account
end

#wechat_payObject

If this is an ‘wechat_pay` PaymentMethod, this hash contains details about the wechat_pay payment method.



2782
2783
2784
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2782

def wechat_pay
  @wechat_pay
end

#zipObject

If this is a ‘zip` PaymentMethod, this hash contains details about the Zip payment method.



2784
2785
2786
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2784

def zip
  @zip
end