Class: Stripe::PaymentIntentCreateParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



2539
2540
2541
2542
2543
2544
2545
2546
2547
2548
2549
2550
2551
2552
2553
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2539

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



2527
2528
2529
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2527

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



2529
2530
2531
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2529

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account's bank.



2531
2532
2533
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2531

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account's bank branch.



2533
2534
2535
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2533

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



2535
2536
2537
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2535

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



2537
2538
2539
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2537

def suffix
  @suffix
end