Class: Stripe::PaymentIntentCreateParams::PaymentMethodData::Upi::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



2674
2675
2676
2677
2678
2679
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2674

def initialize(amount: nil, amount_type: nil, description: nil, end_date: nil)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



2666
2667
2668
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2666

def amount
  @amount
end

#amount_typeObject

One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.



2668
2669
2670
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2668

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



2670
2671
2672
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2670

def description
  @description
end

#end_dateObject

End date of the mandate or subscription.



2672
2673
2674
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2672

def end_date
  @end_date
end