Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::AcssDebit
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::AcssDebit
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: MandateOptions
Instance Attribute Summary collapse
-
#mandate_options ⇒ Object
Additional fields for Mandate creation.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
-
#target_date ⇒ Object
Controls when Stripe will attempt to debit the funds from the customer’s account.
-
#verification_method ⇒ Object
Bank account verification method.
Instance Method Summary collapse
-
#initialize(mandate_options: nil, setup_future_usage: nil, target_date: nil, verification_method: nil) ⇒ AcssDebit
constructor
A new instance of AcssDebit.
Methods inherited from RequestParams
Constructor Details
#initialize(mandate_options: nil, setup_future_usage: nil, target_date: nil, verification_method: nil) ⇒ AcssDebit
Returns a new instance of AcssDebit.
873 874 875 876 877 878 879 880 881 882 883 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 873 def initialize( mandate_options: nil, setup_future_usage: nil, target_date: nil, verification_method: nil ) = @setup_future_usage = setup_future_usage @target_date = target_date @verification_method = verification_method end |
Instance Attribute Details
#mandate_options ⇒ Object
Additional fields for Mandate creation
857 858 859 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 857 def end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.
If the payment method is card_present and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.
When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).
If you’ve already set setup_future_usage and you’re performing a request using a publishable key, you can only update the value from on_session to off_session.
867 868 869 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 867 def setup_future_usage @setup_future_usage end |
#target_date ⇒ Object
Controls when Stripe will attempt to debit the funds from the customer’s account. The date must be a string in YYYY-MM-DD format. The date must be in the future and between 3 and 15 calendar days from now.
869 870 871 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 869 def target_date @target_date end |
#verification_method ⇒ Object
Bank account verification method.
871 872 873 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 871 def verification_method @verification_method end |