Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::AfterpayClearpay

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(capture_method: nil, reference: nil, setup_future_usage: nil) ⇒ AfterpayClearpay

Returns a new instance of AfterpayClearpay.



2697
2698
2699
2700
2701
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2697

def initialize(capture_method: nil, reference: nil, setup_future_usage: nil)
  @capture_method = capture_method
  @reference = reference
  @setup_future_usage = setup_future_usage
end

Instance Attribute Details

#capture_methodObject

Controls when the funds are captured from the customer's account.

If provided, this parameter overrides the behavior of the top-level capture_method for this payment method type when finalizing the payment with this payment method type.

If capture_method is already set on the PaymentIntent, providing an empty value for this parameter unsets the stored value for this payment method type.



2682
2683
2684
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2682

def capture_method
  @capture_method
end

#referenceObject

An internal identifier or reference that this payment corresponds to. You must limit the identifier to 128 characters, and it can only contain letters, numbers, underscores, backslashes, and dashes. This field differs from the statement descriptor and item name.



2685
2686
2687
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2685

def reference
  @reference
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent's payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.

If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.

When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.

If you've already set setup_future_usage and you're performing a request using a publishable key, you can only update the value from on_session to off_session.



2695
2696
2697
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2695

def setup_future_usage
  @setup_future_usage
end