Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::BacsDebit

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Defined Under Namespace

Classes: MandateOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(mandate_options: nil, setup_future_usage: nil, target_date: nil) ⇒ BacsDebit

Returns a new instance of BacsDebit.



3212
3213
3214
3215
3216
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3212

def initialize(mandate_options: nil, setup_future_usage: nil, target_date: nil)
  @mandate_options = mandate_options
  @setup_future_usage = setup_future_usage
  @target_date = target_date
end

Instance Attribute Details

#mandate_optionsObject

Additional fields for Mandate creation



3198
3199
3200
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3198

def mandate_options
  @mandate_options
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent's payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.

If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.

When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.

If you've already set setup_future_usage and you're performing a request using a publishable key, you can only update the value from on_session to off_session.



3208
3209
3210
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3208

def setup_future_usage
  @setup_future_usage
end

#target_dateObject

Controls when Stripe will attempt to debit the funds from the customer's account. The date must be a string in YYYY-MM-DD format. The date must be in the future and between 3 and 15 calendar days from now.



3210
3211
3212
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3210

def target_date
  @target_date
end