Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Bancontact
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Bancontact
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Instance Attribute Summary collapse
-
#preferred_language ⇒ Object
Preferred language of the Bancontact authorization page that the customer is redirected to.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent's payment method.
Instance Method Summary collapse
-
#initialize(preferred_language: nil, setup_future_usage: nil) ⇒ Bancontact
constructor
A new instance of Bancontact.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(preferred_language: nil, setup_future_usage: nil) ⇒ Bancontact
Returns a new instance of Bancontact.
2821 2822 2823 2824 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2821 def initialize(preferred_language: nil, setup_future_usage: nil) @preferred_language = preferred_language @setup_future_usage = setup_future_usage end |
Instance Attribute Details
#preferred_language ⇒ Object
Preferred language of the Bancontact authorization page that the customer is redirected to.
2809 2810 2811 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2809 def preferred_language @preferred_language end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent's payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.
If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.
When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.
If you've already set setup_future_usage and you're performing a request using a publishable key, you can only update the value from on_session to off_session.
2819 2820 2821 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2819 def setup_future_usage @setup_future_usage end |