Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Billie::CompanyDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Defined Under Namespace

Classes: RegisteredAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h

Constructor Details

#initialize(registered_address: nil, registered_name: nil, registration_number: nil, registration_type: nil, vat: nil) ⇒ CompanyDetails

Returns a new instance of CompanyDetails.



1161
1162
1163
1164
1165
1166
1167
1168
1169
1170
1171
1172
1173
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1161

def initialize(
  registered_address: nil,
  registered_name: nil,
  registration_number: nil,
  registration_type: nil,
  vat: nil
)
  @registered_address = registered_address
  @registered_name = registered_name
  @registration_number = registration_number
  @registration_type = registration_type
  @vat = vat
end

Instance Attribute Details

#registered_address ⇒ Object

The address the company or entity is registered with.



1151
1152
1153
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1151

def registered_address
  @registered_address
end

#registered_name ⇒ Object

Company or entity name.



1153
1154
1155
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1153

def registered_name
  @registered_name
end

#registration_number ⇒ Object

The official registration number for the given registration type.



1155
1156
1157
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1155

def registration_number
  @registration_number
end

#registration_type ⇒ Object

Type of registration the company or entity holds in their registered country.



1157
1158
1159
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1157

def registration_type
  @registration_type
end

#vat ⇒ Object

VAT id number



1159
1160
1161
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1159

def vat
  @vat
end