Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Boleto

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(expires_after_days: nil, setup_future_usage: nil) ⇒ Boleto

Returns a new instance of Boleto.



1139
1140
1141
1142
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1139

def initialize(expires_after_days: nil, setup_future_usage: nil)
  @expires_after_days = expires_after_days
  @setup_future_usage = setup_future_usage
end

Instance Attribute Details

#expires_after_daysObject

The number of calendar days before a Boleto voucher expires. For example, if you create a Boleto voucher on Monday and you set expires_after_days to 2, the Boleto invoice will expire on Wednesday at 23:59 America/Sao_Paulo time.



1127
1128
1129
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1127

def expires_after_days
  @expires_after_days
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent’s payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.

If the payment method is card_present and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.

When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).

If you’ve already set setup_future_usage and you’re performing a request using a publishable key, you can only update the value from on_session to off_session.



1137
1138
1139
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1137

def setup_future_usage
  @setup_future_usage
end