Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Card::Installments::Plan

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(count: nil, interval: nil, type: nil) ⇒ Plan

Returns a new instance of Plan.



3317
3318
3319
3320
3321
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3317

def initialize(count: nil, interval: nil, type: nil)
  @count = count
  @interval = interval
  @type = type
end

Instance Attribute Details

#countObject

For fixed_count installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.



3310
3311
3312
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3310

def count
  @count
end

#intervalObject

For fixed_count installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of month.



3313
3314
3315
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3313

def interval
  @interval
end

#typeObject

Type of installment plan, one of fixed_count, bonus, or revolving.



3315
3316
3317
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3315

def type
  @type
end