Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Card::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil, interval: nil, interval_count: nil, reference: nil, start_date: nil, supported_types: nil) ⇒ MandateOptions



1196
1197
1198
1199
1200
1201
1202
1203
1204
1205
1206
1207
1208
1209
1210
1211
1212
1213
1214
1215
1216
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1196

def initialize(
  amount: nil,
  amount_type: nil,
  description: nil,
  end_date: nil,
  interval: nil,
  interval_count: nil,
  reference: nil,
  start_date: nil,
  supported_types: nil
)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
  @interval = interval
  @interval_count = interval_count
  @reference = reference
  @start_date = start_date
  @supported_types = supported_types
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments, specified in the presentment currency.



1178
1179
1180
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1178

def amount
  @amount
end

#amount_typeObject

One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.



1180
1181
1182
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1180

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



1182
1183
1184
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1182

def description
  @description
end

#end_dateObject

End date of the mandate or subscription. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.



1184
1185
1186
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1184

def end_date
  @end_date
end

#intervalObject

Specifies payment frequency. One of day, week, month, year, or sporadic.



1186
1187
1188
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1186

def interval
  @interval
end

#interval_countObject

The number of intervals between payments. For example, ‘interval=month` and `interval_count=3` indicates one payment every three months. Maximum of one year interval allowed (1 year, 12 months, or 52 weeks). This parameter is optional when `interval=sporadic`.



1188
1189
1190
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1188

def interval_count
  @interval_count
end

#referenceObject

Unique identifier for the mandate or subscription.



1190
1191
1192
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1190

def reference
  @reference
end

#start_dateObject

Start date of the mandate or subscription. Start date should not be lesser than yesterday.



1192
1193
1194
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1192

def start_date
  @start_date
end

#supported_typesObject

Specifies the type of mandates supported. Possible values are india.



1194
1195
1196
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1194

def supported_types
  @supported_types
end