Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Card::StatementDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Card::StatementDetails
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Please pass in an address that is within your Stripe user account country.
-
#phone ⇒ Object
Phone number (e.g., a toll-free number that customers can call).
Instance Method Summary collapse
-
#initialize(address: nil, phone: nil) ⇒ StatementDetails
constructor
A new instance of StatementDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(address: nil, phone: nil) ⇒ StatementDetails
Returns a new instance of StatementDetails.
3391 3392 3393 3394 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3391 def initialize(address: nil, phone: nil) @address = address @phone = phone end |
Instance Attribute Details
#address ⇒ Object
Please pass in an address that is within your Stripe user account country
3387 3388 3389 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3387 def address @address end |
#phone ⇒ Object
Phone number (e.g., a toll-free number that customers can call)
3389 3390 3391 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3389 def phone @phone end |