Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Crypto
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Crypto
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: AmountReconciliation, DepositOptions, TransactionVerificationOptions
Instance Attribute Summary collapse
-
#amount_reconciliation ⇒ Object
Controls how crypto funding amounts are reconciled for this PaymentIntent.
-
#deposit_options ⇒ Object
Specific configuration for this PaymentIntent when the mode is
deposit. -
#mode ⇒ Object
The mode of the crypto payment.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent's payment method.
-
#transaction_verification_options ⇒ Object
Specific configuration for this PaymentIntent when the mode is
transaction_verification.
Instance Method Summary collapse
-
#initialize(amount_reconciliation: nil, deposit_options: nil, mode: nil, setup_future_usage: nil, transaction_verification_options: nil) ⇒ Crypto
constructor
A new instance of Crypto.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount_reconciliation: nil, deposit_options: nil, mode: nil, setup_future_usage: nil, transaction_verification_options: nil) ⇒ Crypto
Returns a new instance of Crypto.
3812 3813 3814 3815 3816 3817 3818 3819 3820 3821 3822 3823 3824 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3812 def initialize( amount_reconciliation: nil, deposit_options: nil, mode: nil, setup_future_usage: nil, transaction_verification_options: nil ) @amount_reconciliation = amount_reconciliation @deposit_options = @mode = mode @setup_future_usage = setup_future_usage @transaction_verification_options = end |
Instance Attribute Details
#amount_reconciliation ⇒ Object
Controls how crypto funding amounts are reconciled for this PaymentIntent.
3794 3795 3796 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3794 def amount_reconciliation @amount_reconciliation end |
#deposit_options ⇒ Object
Specific configuration for this PaymentIntent when the mode is deposit.
3796 3797 3798 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3796 def @deposit_options end |
#mode ⇒ Object
The mode of the crypto payment.
3798 3799 3800 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3798 def mode @mode end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent's payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.
If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.
When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.
If you've already set setup_future_usage and you're performing a request using a publishable key, you can only update the value from on_session to off_session.
3808 3809 3810 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3808 def setup_future_usage @setup_future_usage end |
#transaction_verification_options ⇒ Object
Specific configuration for this PaymentIntent when the mode is transaction_verification.
3810 3811 3812 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3810 def @transaction_verification_options end |