Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Crypto::AmountReconciliation
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Crypto::AmountReconciliation
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Instance Attribute Summary collapse
-
#type ⇒ Object
Controls how crypto funding amounts are reconciled for the PaymentIntent.
Instance Method Summary collapse
-
#initialize(type: nil) ⇒ AmountReconciliation
constructor
A new instance of AmountReconciliation.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(type: nil) ⇒ AmountReconciliation
Returns a new instance of AmountReconciliation.
3765 3766 3767 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3765 def initialize(type: nil) @type = type end |
Instance Attribute Details
#type ⇒ Object
Controls how crypto funding amounts are reconciled for the PaymentIntent.
3763 3764 3765 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3763 def type @type end |