Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::CustomerBalance::BankTransfer

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Defined Under Namespace

Classes: EuBankTransfer

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(eu_bank_transfer: nil, requested_address_types: nil, type: nil) ⇒ BankTransfer

Returns a new instance of BankTransfer.



3846
3847
3848
3849
3850
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3846

def initialize(eu_bank_transfer: nil, requested_address_types: nil, type: nil)
  @eu_bank_transfer = eu_bank_transfer
  @requested_address_types = requested_address_types
  @type = type
end

Instance Attribute Details

#eu_bank_transferObject

Configuration for the eu_bank_transfer funding type.



3838
3839
3840
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3838

def eu_bank_transfer
  @eu_bank_transfer
end

#requested_address_typesObject

List of address types that should be returned in the financial_addresses response. If not specified, all valid types will be returned.

Permitted values include: sort_code, zengin, iban, or spei.



3842
3843
3844
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3842

def requested_address_types
  @requested_address_types
end

#typeObject

The list of bank transfer types that this PaymentIntent is allowed to use for funding Permitted values include: eu_bank_transfer, gb_bank_transfer, jp_bank_transfer, mx_bank_transfer, or us_bank_transfer.



3844
3845
3846
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3844

def type
  @type
end