Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::OnDemand

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(average_amount: nil, maximum_amount: nil, minimum_amount: nil, purchase_interval: nil, purchase_interval_count: nil) ⇒ OnDemand

Returns a new instance of OnDemand.



4055
4056
4057
4058
4059
4060
4061
4062
4063
4064
4065
4066
4067
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4055

def initialize(
  average_amount: nil,
  maximum_amount: nil,
  minimum_amount: nil,
  purchase_interval: nil,
  purchase_interval_count: nil
)
  @average_amount = average_amount
  @maximum_amount = maximum_amount
  @minimum_amount = minimum_amount
  @purchase_interval = purchase_interval
  @purchase_interval_count = purchase_interval_count
end

Instance Attribute Details

#average_amountObject

Your average amount value. You can use a value across your customer base, or segment based on customer type, country, etc.



4045
4046
4047
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4045

def average_amount
  @average_amount
end

#maximum_amountObject

The maximum value you may charge a customer per purchase. You can use a value across your customer base, or segment based on customer type, country, etc.



4047
4048
4049
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4047

def maximum_amount
  @maximum_amount
end

#minimum_amountObject

The lowest or minimum value you may charge a customer per purchase. You can use a value across your customer base, or segment based on customer type, country, etc.



4049
4050
4051
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4049

def minimum_amount
  @minimum_amount
end

#purchase_intervalObject

Interval at which the customer is making purchases



4051
4052
4053
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4051

def purchase_interval
  @purchase_interval
end

#purchase_interval_countObject

The number of purchase_interval between charges



4053
4054
4055
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4053

def purchase_interval_count
  @purchase_interval_count
end