Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::Subscription
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::Subscription
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: NextBilling
Instance Attribute Summary collapse
-
#interval ⇒ Object
Unit of time between subscription charges.
-
#interval_count ⇒ Object
The number of intervals (specified in the ‘interval` attribute) between subscription charges.
-
#name ⇒ Object
Name for subscription.
-
#next_billing ⇒ Object
Describes the upcoming charge for this subscription.
-
#reference ⇒ Object
A non-customer-facing reference to correlate subscription charges in the Klarna app.
Instance Method Summary collapse
-
#initialize(interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil) ⇒ Subscription
constructor
A new instance of Subscription.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil) ⇒ Subscription
Returns a new instance of Subscription.
4028 4029 4030 4031 4032 4033 4034 4035 4036 4037 4038 4039 4040 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4028 def initialize( interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil ) @interval = interval @interval_count = interval_count @name = name @next_billing = next_billing @reference = reference end |
Instance Attribute Details
#interval ⇒ Object
Unit of time between subscription charges.
4018 4019 4020 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4018 def interval @interval end |
#interval_count ⇒ Object
The number of intervals (specified in the ‘interval` attribute) between subscription charges. For example, `interval=month` and `interval_count=3` charges every 3 months.
4020 4021 4022 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4020 def interval_count @interval_count end |
#name ⇒ Object
Name for subscription.
4022 4023 4024 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4022 def name @name end |
#next_billing ⇒ Object
Describes the upcoming charge for this subscription.
4024 4025 4026 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4024 def next_billing @next_billing end |
#reference ⇒ Object
A non-customer-facing reference to correlate subscription charges in the Klarna app. Use a value that persists across subscription charges.
4026 4027 4028 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4026 def reference @reference end |