Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::Subscription::NextBilling

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, date: nil) ⇒ NextBilling

Returns a new instance of NextBilling.



4021
4022
4023
4024
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4021

def initialize(amount: nil, date: nil)
  @amount = amount
  @date = date
end

Instance Attribute Details

#amountObject

The amount of the next charge for the subscription.



4017
4018
4019
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4017

def amount
  @amount
end

#dateObject

The date of the next charge for the subscription in YYYY-MM-DD format.



4019
4020
4021
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4019

def date
  @date
end