Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: BusReservationDetail, EventReservationDetail, FerryReservationDetail, Insurance, MarketplaceSeller, RoundTripReservationDetail, TrainReservationDetail, Voucher
Instance Attribute Summary collapse
-
#bus_reservation_details ⇒ Object
Supplementary bus reservation details.
-
#event_reservation_details ⇒ Object
Supplementary event reservation details.
-
#ferry_reservation_details ⇒ Object
Supplementary ferry reservation details.
-
#insurances ⇒ Object
Supplementary insurance details.
-
#marketplace_sellers ⇒ Object
Supplementary marketplace seller details.
-
#round_trip_reservation_details ⇒ Object
Supplementary round trip reservation details.
-
#train_reservation_details ⇒ Object
Supplementary train reservation details.
-
#vouchers ⇒ Object
Voucher details, such as a gift card or discount code.
Instance Method Summary collapse
-
#initialize(bus_reservation_details: nil, event_reservation_details: nil, ferry_reservation_details: nil, insurances: nil, marketplace_sellers: nil, round_trip_reservation_details: nil, train_reservation_details: nil, vouchers: nil) ⇒ SupplementaryPurchaseData
constructor
A new instance of SupplementaryPurchaseData.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(bus_reservation_details: nil, event_reservation_details: nil, ferry_reservation_details: nil, insurances: nil, marketplace_sellers: nil, round_trip_reservation_details: nil, train_reservation_details: nil, vouchers: nil) ⇒ SupplementaryPurchaseData
Returns a new instance of SupplementaryPurchaseData.
5020 5021 5022 5023 5024 5025 5026 5027 5028 5029 5030 5031 5032 5033 5034 5035 5036 5037 5038 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5020 def initialize( bus_reservation_details: nil, event_reservation_details: nil, ferry_reservation_details: nil, insurances: nil, marketplace_sellers: nil, round_trip_reservation_details: nil, train_reservation_details: nil, vouchers: nil ) @bus_reservation_details = bus_reservation_details @event_reservation_details = event_reservation_details @ferry_reservation_details = ferry_reservation_details @insurances = insurances @marketplace_sellers = marketplace_sellers @round_trip_reservation_details = round_trip_reservation_details @train_reservation_details = train_reservation_details @vouchers = vouchers end |
Instance Attribute Details
#bus_reservation_details ⇒ Object
Supplementary bus reservation details.
5004 5005 5006 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5004 def bus_reservation_details @bus_reservation_details end |
#event_reservation_details ⇒ Object
Supplementary event reservation details.
5006 5007 5008 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5006 def event_reservation_details @event_reservation_details end |
#ferry_reservation_details ⇒ Object
Supplementary ferry reservation details.
5008 5009 5010 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5008 def ferry_reservation_details @ferry_reservation_details end |
#insurances ⇒ Object
Supplementary insurance details.
5010 5011 5012 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5010 def insurances @insurances end |
#marketplace_sellers ⇒ Object
Supplementary marketplace seller details.
5012 5013 5014 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5012 def marketplace_sellers @marketplace_sellers end |
#round_trip_reservation_details ⇒ Object
Supplementary round trip reservation details.
5014 5015 5016 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5014 def round_trip_reservation_details @round_trip_reservation_details end |
#train_reservation_details ⇒ Object
Supplementary train reservation details.
5016 5017 5018 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5016 def train_reservation_details @train_reservation_details end |
#vouchers ⇒ Object
Voucher details, such as a gift card or discount code.
5018 5019 5020 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5018 def vouchers @vouchers end |