Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::BusReservationDetail
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::BusReservationDetail
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: Arrival, Departure, Insurance, Passenger
Instance Attribute Summary collapse
-
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
-
#arrival ⇒ Object
Arrival details.
-
#carrier_name ⇒ Object
Name of transportation company.
-
#currency ⇒ Object
Currency.
-
#departure ⇒ Object
Departure details.
-
#insurances ⇒ Object
List of insurances for this reservation.
-
#passengers ⇒ Object
List of passengers that this reservation applies to.
-
#price ⇒ Object
Price in cents.
-
#ticket_class ⇒ Object
Ticket class.
Instance Method Summary collapse
-
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ BusReservationDetail
constructor
A new instance of BusReservationDetail.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ BusReservationDetail
Returns a new instance of BusReservationDetail.
4194 4195 4196 4197 4198 4199 4200 4201 4202 4203 4204 4205 4206 4207 4208 4209 4210 4211 4212 4213 4214 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4194 def initialize( affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil ) @affiliate_name = affiliate_name @arrival = arrival @carrier_name = carrier_name @currency = currency @departure = departure @insurances = insurances @passengers = passengers @price = price @ticket_class = ticket_class end |
Instance Attribute Details
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
4176 4177 4178 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4176 def affiliate_name @affiliate_name end |
#arrival ⇒ Object
Arrival details.
4178 4179 4180 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4178 def arrival @arrival end |
#carrier_name ⇒ Object
Name of transportation company.
4180 4181 4182 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4180 def carrier_name @carrier_name end |
#currency ⇒ Object
Currency.
4182 4183 4184 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4182 def currency @currency end |
#departure ⇒ Object
Departure details.
4184 4185 4186 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4184 def departure @departure end |
#insurances ⇒ Object
List of insurances for this reservation.
4186 4187 4188 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4186 def insurances @insurances end |
#passengers ⇒ Object
List of passengers that this reservation applies to.
4188 4189 4190 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4188 def passengers @passengers end |
#price ⇒ Object
Price in cents.
4190 4191 4192 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4190 def price @price end |
#ticket_class ⇒ Object
Ticket class.
4192 4193 4194 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4192 def ticket_class @ticket_class end |