Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::EventReservationDetail

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Defined Under Namespace

Classes: Address, Insurance

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(access_controlled_venue: nil, address: nil, affiliate_name: nil, ends_at: nil, event_company_name: nil, event_name: nil, event_type: nil, insurances: nil, starts_at: nil, venue_name: nil) ⇒ EventReservationDetail

Returns a new instance of EventReservationDetail.



4348
4349
4350
4351
4352
4353
4354
4355
4356
4357
4358
4359
4360
4361
4362
4363
4364
4365
4366
4367
4368
4369
4370
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4348

def initialize(
  access_controlled_venue: nil,
  address: nil,
  affiliate_name: nil,
  ends_at: nil,
  event_company_name: nil,
  event_name: nil,
  event_type: nil,
  insurances: nil,
  starts_at: nil,
  venue_name: nil
)
  @access_controlled_venue = access_controlled_venue
  @address = address
  @affiliate_name = affiliate_name
  @ends_at = ends_at
  @event_company_name = event_company_name
  @event_name = event_name
  @event_type = event_type
  @insurances = insurances
  @starts_at = starts_at
  @venue_name = venue_name
end

Instance Attribute Details

#access_controlled_venueObject

Indicates if the tickets are digitally checked when entering the venue.



4328
4329
4330
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4328

def access_controlled_venue
  @access_controlled_venue
end

#addressObject

Address of the event.



4330
4331
4332
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4330

def address
  @address
end

#affiliate_nameObject

Name of associated or partner company for the service.



4332
4333
4334
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4332

def affiliate_name
  @affiliate_name
end

#ends_atObject

End timestamp of the event.



4334
4335
4336
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4334

def ends_at
  @ends_at
end

#event_company_nameObject

Company selling the ticket.



4336
4337
4338
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4336

def event_company_name
  @event_company_name
end

#event_nameObject

Name of the event.



4338
4339
4340
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4338

def event_name
  @event_name
end

#event_typeObject

Type of the event.



4340
4341
4342
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4340

def event_type
  @event_type
end

#insurancesObject

List of insurances for this event.



4342
4343
4344
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4342

def insurances
  @insurances
end

#starts_atObject

Start timestamp of the event.



4344
4345
4346
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4344

def starts_at
  @starts_at
end

#venue_nameObject

Name of the venue where the event takes place.



4346
4347
4348
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4346

def venue_name
  @venue_name
end