Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::EventReservationDetail::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::EventReservationDetail::Address
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
4180 4181 4182 4183 4184 4185 4186 4187 4188 4189 4190 4191 4192 4193 4194 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4180 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
4168 4169 4170 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4168 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
4170 4171 4172 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4170 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
4172 4173 4174 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4172 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
4174 4175 4176 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4174 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
4176 4177 4178 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4176 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
4178 4179 4180 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4178 def street_address2 @street_address2 end |