Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::FerryReservationDetail
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::FerryReservationDetail
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: Arrival, Departure, Insurance, Passenger
Instance Attribute Summary collapse
-
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
-
#arrival ⇒ Object
Arrival details.
-
#carrier_name ⇒ Object
Name of transportation company.
-
#currency ⇒ Object
Currency.
-
#departure ⇒ Object
Departure details.
-
#insurances ⇒ Object
List of insurances for this reservation.
-
#passengers ⇒ Object
List of passengers that this reservation applies to.
-
#price ⇒ Object
Price in cents.
-
#ticket_class ⇒ Object
Ticket class.
Instance Method Summary collapse
-
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ FerryReservationDetail
constructor
A new instance of FerryReservationDetail.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ FerryReservationDetail
Returns a new instance of FerryReservationDetail.
3915 3916 3917 3918 3919 3920 3921 3922 3923 3924 3925 3926 3927 3928 3929 3930 3931 3932 3933 3934 3935 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3915 def initialize( affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil ) @affiliate_name = affiliate_name @arrival = arrival @carrier_name = carrier_name @currency = currency @departure = departure @insurances = insurances @passengers = passengers @price = price @ticket_class = ticket_class end |
Instance Attribute Details
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
3897 3898 3899 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3897 def affiliate_name @affiliate_name end |
#arrival ⇒ Object
Arrival details.
3899 3900 3901 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3899 def arrival @arrival end |
#carrier_name ⇒ Object
Name of transportation company.
3901 3902 3903 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3901 def carrier_name @carrier_name end |
#currency ⇒ Object
Currency.
3903 3904 3905 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3903 def currency @currency end |
#departure ⇒ Object
Departure details.
3905 3906 3907 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3905 def departure @departure end |
#insurances ⇒ Object
List of insurances for this reservation.
3907 3908 3909 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3907 def insurances @insurances end |
#passengers ⇒ Object
List of passengers that this reservation applies to.
3909 3910 3911 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3909 def passengers @passengers end |
#price ⇒ Object
Price in cents.
3911 3912 3913 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3911 def price @price end |
#ticket_class ⇒ Object
Ticket class.
3913 3914 3915 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3913 def ticket_class @ticket_class end |