Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::FerryReservationDetail::Arrival::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::FerryReservationDetail::Arrival::Address
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
4389 4390 4391 4392 4393 4394 4395 4396 4397 4398 4399 4400 4401 4402 4403 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4389 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
4377 4378 4379 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4377 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
4379 4380 4381 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4379 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
4381 4382 4383 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4381 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
4383 4384 4385 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4383 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
4385 4386 4387 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4385 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
4387 4388 4389 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4387 def street_address2 @street_address2 end |