Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::MarketplaceSeller::MarketplaceSellerAddress
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::MarketplaceSeller::MarketplaceSellerAddress
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ MarketplaceSellerAddress
constructor
A new instance of MarketplaceSellerAddress.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ MarketplaceSellerAddress
Returns a new instance of MarketplaceSellerAddress.
4519 4520 4521 4522 4523 4524 4525 4526 4527 4528 4529 4530 4531 4532 4533 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4519 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
4507 4508 4509 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4507 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
4509 4510 4511 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4509 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
4511 4512 4513 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4511 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
4513 4514 4515 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4513 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
4515 4516 4517 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4515 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
4517 4518 4519 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4517 def street_address2 @street_address2 end |