Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::RoundTripReservationDetail
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::RoundTripReservationDetail
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: Arrival, Departure, Insurance, Passenger
Instance Attribute Summary collapse
-
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
-
#arrival ⇒ Object
Arrival details.
-
#carrier_name ⇒ Object
Name of transportation company.
-
#currency ⇒ Object
Currency.
-
#departure ⇒ Object
Departure details.
-
#insurances ⇒ Object
List of insurances for this reservation.
-
#passengers ⇒ Object
List of passengers that this reservation applies to.
-
#price ⇒ Object
Price in cents.
-
#ticket_class ⇒ Object
Ticket class.
Instance Method Summary collapse
-
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ RoundTripReservationDetail
constructor
A new instance of RoundTripReservationDetail.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ RoundTripReservationDetail
Returns a new instance of RoundTripReservationDetail.
4730 4731 4732 4733 4734 4735 4736 4737 4738 4739 4740 4741 4742 4743 4744 4745 4746 4747 4748 4749 4750 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4730 def initialize( affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil ) @affiliate_name = affiliate_name @arrival = arrival @carrier_name = carrier_name @currency = currency @departure = departure @insurances = insurances @passengers = passengers @price = price @ticket_class = ticket_class end |
Instance Attribute Details
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
4712 4713 4714 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4712 def affiliate_name @affiliate_name end |
#arrival ⇒ Object
Arrival details.
4714 4715 4716 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4714 def arrival @arrival end |
#carrier_name ⇒ Object
Name of transportation company.
4716 4717 4718 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4716 def carrier_name @carrier_name end |
#currency ⇒ Object
Currency.
4718 4719 4720 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4718 def currency @currency end |
#departure ⇒ Object
Departure details.
4720 4721 4722 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4720 def departure @departure end |
#insurances ⇒ Object
List of insurances for this reservation.
4722 4723 4724 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4722 def insurances @insurances end |
#passengers ⇒ Object
List of passengers that this reservation applies to.
4724 4725 4726 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4724 def passengers @passengers end |
#price ⇒ Object
Price in cents.
4726 4727 4728 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4726 def price @price end |
#ticket_class ⇒ Object
Ticket class.
4728 4729 4730 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4728 def ticket_class @ticket_class end |