Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::RoundTripReservationDetail::Arrival::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::RoundTripReservationDetail::Arrival::Address
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
4661 4662 4663 4664 4665 4666 4667 4668 4669 4670 4671 4672 4673 4674 4675 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4661 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
4649 4650 4651 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4649 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
4651 4652 4653 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4651 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
4653 4654 4655 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4653 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
4655 4656 4657 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4655 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
4657 4658 4659 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4657 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
4659 4660 4661 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4659 def street_address2 @street_address2 end |