Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::RoundTripReservationDetail::Departure::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::RoundTripReservationDetail::Departure::Address
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 4114 4115 4116 4117 4118 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4104 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
4092 4093 4094 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4092 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
4094 4095 4096 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4094 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
4096 4097 4098 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4096 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
4098 4099 4100 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4098 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
4100 4101 4102 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4100 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
4102 4103 4104 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4102 def street_address2 @street_address2 end |