Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::TrainReservationDetail
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::TrainReservationDetail
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: Arrival, Departure, Insurance, Passenger
Instance Attribute Summary collapse
-
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
-
#arrival ⇒ Object
Arrival details.
-
#carrier_name ⇒ Object
Name of transportation company.
-
#currency ⇒ Object
Currency.
-
#departure ⇒ Object
Departure details.
-
#insurances ⇒ Object
List of insurances for this reservation.
-
#passengers ⇒ Object
List of passengers that this reservation applies to.
-
#price ⇒ Object
Price in cents.
-
#ticket_class ⇒ Object
Ticket class.
Instance Method Summary collapse
-
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ TrainReservationDetail
constructor
A new instance of TrainReservationDetail.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ TrainReservationDetail
Returns a new instance of TrainReservationDetail.
4894 4895 4896 4897 4898 4899 4900 4901 4902 4903 4904 4905 4906 4907 4908 4909 4910 4911 4912 4913 4914 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4894 def initialize( affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil ) @affiliate_name = affiliate_name @arrival = arrival @carrier_name = carrier_name @currency = currency @departure = departure @insurances = insurances @passengers = passengers @price = price @ticket_class = ticket_class end |
Instance Attribute Details
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
4876 4877 4878 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4876 def affiliate_name @affiliate_name end |
#arrival ⇒ Object
Arrival details.
4878 4879 4880 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4878 def arrival @arrival end |
#carrier_name ⇒ Object
Name of transportation company.
4880 4881 4882 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4880 def carrier_name @carrier_name end |
#currency ⇒ Object
Currency.
4882 4883 4884 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4882 def currency @currency end |
#departure ⇒ Object
Departure details.
4884 4885 4886 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4884 def departure @departure end |
#insurances ⇒ Object
List of insurances for this reservation.
4886 4887 4888 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4886 def insurances @insurances end |
#passengers ⇒ Object
List of passengers that this reservation applies to.
4888 4889 4890 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4888 def passengers @passengers end |
#price ⇒ Object
Price in cents.
4890 4891 4892 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4890 def price @price end |
#ticket_class ⇒ Object
Ticket class.
4892 4893 4894 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4892 def ticket_class @ticket_class end |