Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::TrainReservationDetail::Arrival::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::TrainReservationDetail::Arrival::Address
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
4214 4215 4216 4217 4218 4219 4220 4221 4222 4223 4224 4225 4226 4227 4228 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4214 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
4202 4203 4204 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4202 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
4204 4205 4206 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4204 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
4206 4207 4208 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4206 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
4208 4209 4210 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4208 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
4210 4211 4212 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4210 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
4212 4213 4214 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4212 def street_address2 @street_address2 end |