Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::KrCard
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::KrCard
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Instance Attribute Summary collapse
-
#capture_method ⇒ Object
Controls when the funds are captured from the customer's account.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent's payment method.
Instance Method Summary collapse
-
#initialize(capture_method: nil, setup_future_usage: nil) ⇒ KrCard
constructor
A new instance of KrCard.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(capture_method: nil, setup_future_usage: nil) ⇒ KrCard
Returns a new instance of KrCard.
4534 4535 4536 4537 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4534 def initialize(capture_method: nil, setup_future_usage: nil) @capture_method = capture_method @setup_future_usage = setup_future_usage end |
Instance Attribute Details
#capture_method ⇒ Object
Controls when the funds are captured from the customer's account.
If provided, this parameter overrides the behavior of the top-level capture_method for this payment method type when finalizing the payment with this payment method type.
If capture_method is already set on the PaymentIntent, providing an empty value for this parameter unsets the stored value for this payment method type.
4524 4525 4526 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4524 def capture_method @capture_method end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent's payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.
If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.
When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.
4532 4533 4534 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4532 def setup_future_usage @setup_future_usage end |