Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::NaverPay
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::NaverPay
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Instance Attribute Summary collapse
-
#capture_method ⇒ Object
Controls when the funds are captured from the customer's account.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent's payment method.
Instance Method Summary collapse
-
#initialize(capture_method: nil, setup_future_usage: nil) ⇒ NaverPay
constructor
A new instance of NaverPay.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(capture_method: nil, setup_future_usage: nil) ⇒ NaverPay
Returns a new instance of NaverPay.
5240 5241 5242 5243 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5240 def initialize(capture_method: nil, setup_future_usage: nil) @capture_method = capture_method @setup_future_usage = setup_future_usage end |
Instance Attribute Details
#capture_method ⇒ Object
Controls when the funds are captured from the customer's account.
If provided, this parameter overrides the behavior of the top-level capture_method for this payment method type when finalizing the payment with this payment method type.
If capture_method is already set on the PaymentIntent, providing an empty value for this parameter unsets the stored value for this payment method type.
5230 5231 5232 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5230 def capture_method @capture_method end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent's payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.
If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.
When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.
5238 5239 5240 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5238 def setup_future_usage @setup_future_usage end |