Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Paypal::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Defined Under Namespace

Classes: Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem

Returns a new instance of LineItem.



5377
5378
5379
5380
5381
5382
5383
5384
5385
5386
5387
5388
5389
5390
5391
5392
5393
5394
5395
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5377

def initialize(
  category: nil,
  description: nil,
  name: nil,
  quantity: nil,
  sku: nil,
  sold_by: nil,
  tax: nil,
  unit_amount: nil
)
  @category = category
  @description = description
  @name = name
  @quantity = quantity
  @sku = sku
  @sold_by = sold_by
  @tax = tax
  @unit_amount = unit_amount
end

Instance Attribute Details

#categoryObject

Type of the line item.



5361
5362
5363
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5361

def category
  @category
end

#descriptionObject

Description of the line item.



5363
5364
5365
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5363

def description
  @description
end

#nameObject

Descriptive name of the line item.



5365
5366
5367
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5365

def name
  @name
end

#quantityObject

Quantity of the line item. Must be a positive number.



5367
5368
5369
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5367

def quantity
  @quantity
end

#skuObject

Client facing stock keeping unit, article number or similar.



5369
5370
5371
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5369

def sku
  @sku
end

#sold_byObject

The Stripe account ID of the connected account that sells the item.



5371
5372
5373
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5371

def sold_by
  @sold_by
end

#taxObject

The tax information for the line item.



5373
5374
5375
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5373

def tax
  @tax
end

#unit_amountObject

Price for a single unit of the line item in minor units. Cannot be a negative number.



5375
5376
5377
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5375

def unit_amount
  @unit_amount
end