Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Paypay

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(capture_method: nil) ⇒ Paypay

Returns a new instance of Paypay.



4831
4832
4833
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4831

def initialize(capture_method: nil)
  @capture_method = capture_method
end

Instance Attribute Details

#capture_methodObject

Controls when the funds are captured from the customer’s account.

If provided, this parameter overrides the behavior of the top-level [capture_method](/api/payment_intents/update#update_payment_intent-capture_method) for this payment method type when finalizing the payment with this payment method type.

If ‘capture_method` is already set on the PaymentIntent, providing an empty value for this parameter unsets the stored value for this payment method type.



4829
4830
4831
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4829

def capture_method
  @capture_method
end