Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Payto
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Payto
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: MandateOptions
Instance Attribute Summary collapse
-
#mandate_options ⇒ Object
Additional fields for Mandate creation.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent's payment method.
Instance Method Summary collapse
-
#initialize(mandate_options: nil, setup_future_usage: nil) ⇒ Payto
constructor
A new instance of Payto.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(mandate_options: nil, setup_future_usage: nil) ⇒ Payto
Returns a new instance of Payto.
2076 2077 2078 2079 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2076 def initialize(mandate_options: nil, setup_future_usage: nil) @mandate_options = @setup_future_usage = setup_future_usage end |
Instance Attribute Details
#mandate_options ⇒ Object
Additional fields for Mandate creation. Only purpose field is configurable for PayTo PaymentIntent with setup_future_usage=none. Other fields are only applicable to PayTo PaymentIntent with setup_future_usage=off_session
2064 2065 2066 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2064 def @mandate_options end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent's payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.
If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.
When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.
If you've already set setup_future_usage and you're performing a request using a publishable key, you can only update the value from on_session to off_session.
2074 2075 2076 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2074 def setup_future_usage @setup_future_usage end |