Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Payto::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, end_date: nil, payment_schedule: nil, payments_per_period: nil, purpose: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



5480
5481
5482
5483
5484
5485
5486
5487
5488
5489
5490
5491
5492
5493
5494
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5480

def initialize(
  amount: nil,
  amount_type: nil,
  end_date: nil,
  payment_schedule: nil,
  payments_per_period: nil,
  purpose: nil
)
  @amount = amount
  @amount_type = amount_type
  @end_date = end_date
  @payment_schedule = payment_schedule
  @payments_per_period = payments_per_period
  @purpose = purpose
end

Instance Attribute Details

#amountObject

Amount that will be collected. It is required when amount_type is fixed.



5468
5469
5470
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5468

def amount
  @amount
end

#amount_typeObject

The type of amount that will be collected. The amount charged must be exact or up to the value of amount param for fixed or maximum type respectively. Defaults to maximum.



5470
5471
5472
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5470

def amount_type
  @amount_type
end

#end_dateObject

Date, in YYYY-MM-DD format, after which payments will not be collected. Defaults to no end date.



5472
5473
5474
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5472

def end_date
  @end_date
end

#payment_scheduleObject

The periodicity at which payments will be collected. Defaults to adhoc.



5474
5475
5476
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5474

def payment_schedule
  @payment_schedule
end

#payments_per_periodObject

The number of payments that will be made during a payment period. Defaults to 1 except for when payment_schedule is adhoc. In that case, it defaults to no limit.



5476
5477
5478
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5476

def payments_per_period
  @payments_per_period
end

#purposeObject

The purpose for which payments are made. Has a default value based on your merchant category code.



5478
5479
5480
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5478

def purpose
  @purpose
end