Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Pix::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_includes_iof: nil, amount_type: nil, currency: nil, end_date: nil, payment_schedule: nil, reference: nil, start_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



5534
5535
5536
5537
5538
5539
5540
5541
5542
5543
5544
5545
5546
5547
5548
5549
5550
5551
5552
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5534

def initialize(
  amount: nil,
  amount_includes_iof: nil,
  amount_type: nil,
  currency: nil,
  end_date: nil,
  payment_schedule: nil,
  reference: nil,
  start_date: nil
)
  @amount = amount
  @amount_includes_iof = amount_includes_iof
  @amount_type = amount_type
  @currency = currency
  @end_date = end_date
  @payment_schedule = payment_schedule
  @reference = reference
  @start_date = start_date
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments. Required when amount_type=fixed. If not provided for amount_type=maximum, defaults to 40000.



5518
5519
5520
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5518

def amount
  @amount
end

#amount_includes_iofObject

Determines if the amount includes the IOF tax. Defaults to never.



5520
5521
5522
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5520

def amount_includes_iof
  @amount_includes_iof
end

#amount_typeObject

Type of amount. Defaults to maximum.



5522
5523
5524
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5522

def amount_type
  @amount_type
end

#currencyObject

Three-letter ISO currency code, in lowercase. Only brl is supported currently.



5524
5525
5526
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5524

def currency
  @currency
end

#end_dateObject

Date when the mandate expires and no further payments will be charged, in YYYY-MM-DD. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.



5526
5527
5528
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5526

def end_date
  @end_date
end

#payment_scheduleObject

Schedule at which the future payments will be charged. Defaults to monthly.



5528
5529
5530
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5528

def payment_schedule
  @payment_schedule
end

#referenceObject

Subscription name displayed to buyers in their bank app. Defaults to the displayable business name.



5530
5531
5532
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5530

def reference
  @reference
end

#start_dateObject

Start date of the mandate, in YYYY-MM-DD. Start date should be at least 3 days in the future. Defaults to 3 days after the current date.



5532
5533
5534
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5532

def start_date
  @start_date
end