Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Swish
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Swish
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Instance Attribute Summary collapse
-
#reference ⇒ Object
A reference for this payment to be displayed in the Swish app.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent's payment method.
Instance Method Summary collapse
-
#initialize(reference: nil, setup_future_usage: nil) ⇒ Swish
constructor
A new instance of Swish.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(reference: nil, setup_future_usage: nil) ⇒ Swish
Returns a new instance of Swish.
5833 5834 5835 5836 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5833 def initialize(reference: nil, setup_future_usage: nil) @reference = reference @setup_future_usage = setup_future_usage end |
Instance Attribute Details
#reference ⇒ Object
A reference for this payment to be displayed in the Swish app.
5821 5822 5823 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5821 def reference @reference end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent's payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.
If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.
When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.
If you've already set setup_future_usage and you're performing a request using a publishable key, you can only update the value from on_session to off_session.
5831 5832 5833 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5831 def setup_future_usage @setup_future_usage end |