Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Upi::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



5867
5868
5869
5870
5871
5872
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5867

def initialize(amount: nil, amount_type: nil, description: nil, end_date: nil)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



5859
5860
5861
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5859

def amount
  @amount
end

#amount_typeObject

One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.



5861
5862
5863
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5861

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



5863
5864
5865
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5863

def description
  @description
end

#end_dateObject

End date of the mandate or subscription.



5865
5866
5867
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5865

def end_date
  @end_date
end