Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::UsBankAccount::FinancialConnections

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Defined Under Namespace

Classes: Filters, ManualEntry

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections

Returns a new instance of FinancialConnections.



5918
5919
5920
5921
5922
5923
5924
5925
5926
5927
5928
5929
5930
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5918

def initialize(
  filters: nil,
  manual_entry: nil,
  permissions: nil,
  prefetch: nil,
  return_url: nil
)
  @filters = filters
  @manual_entry = manual_entry
  @permissions = permissions
  @prefetch = prefetch
  @return_url = return_url
end

Instance Attribute Details

#filtersObject

Provide filters for the linked accounts that the customer can select for the payment method.



5908
5909
5910
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5908

def filters
  @filters
end

#manual_entryObject

Customize manual entry behavior



5910
5911
5912
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5910

def manual_entry
  @manual_entry
end

#permissionsObject

The list of permissions to request. If this parameter is passed, the payment_method permission must be included. Valid permissions include: balances, ownership, payment_method, and transactions.



5912
5913
5914
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5912

def permissions
  @permissions
end

#prefetchObject

List of data features that you would like to retrieve upon account creation.



5914
5915
5916
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5914

def prefetch
  @prefetch
end

#return_urlObject

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



5916
5917
5918
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5916

def return_url
  @return_url
end