Class: Stripe::PaymentIntentCreateParams::RadarOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(session: nil) ⇒ RadarOptions

Returns a new instance of RadarOptions.



2559
2560
2561
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2559

def initialize(session: nil)
  @session = session
end

Instance Attribute Details

#sessionObject

A [Radar Session](docs.stripe.com/radar/radar-session) is a snapshot of the browser metadata and device details that help Radar make more accurate predictions on your payments.



2557
2558
2559
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2557

def session
  @session
end