Class: Stripe::PaymentIntentDecrementAuthorizationParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_decrement_authorization_params.rb

Defined Under Namespace

Classes: AmountDetails, Hooks, PaymentDetails, TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_details: nil, application_fee_amount: nil, description: nil, expand: nil, hooks: nil, metadata: nil, payment_details: nil, transfer_data: nil) ⇒ PaymentIntentDecrementAuthorizationParams

Returns a new instance of PaymentIntentDecrementAuthorizationParams.



348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
# File 'lib/stripe/params/payment_intent_decrement_authorization_params.rb', line 348

def initialize(
  amount: nil,
  amount_details: nil,
  application_fee_amount: nil,
  description: nil,
  expand: nil,
  hooks: nil,
  metadata: nil,
  payment_details: nil,
  transfer_data: nil
)
  @amount = amount
  @amount_details = amount_details
  @application_fee_amount = application_fee_amount
  @description = description
  @expand = expand
  @hooks = hooks
  @metadata = 
  @payment_details = payment_details
  @transfer_data = transfer_data
end

Instance Attribute Details

#amountObject

The updated total amount that you intend to collect from the cardholder. This amount must be smaller than the currently authorized amount and greater than the already captured amount.



329
330
331
# File 'lib/stripe/params/payment_intent_decrement_authorization_params.rb', line 329

def amount
  @amount
end

#amount_detailsObject

Provides industry-specific information about the amount.



331
332
333
# File 'lib/stripe/params/payment_intent_decrement_authorization_params.rb', line 331

def amount_details
  @amount_details
end

#application_fee_amountObject

The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner's Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents use case for connected accounts.



333
334
335
# File 'lib/stripe/params/payment_intent_decrement_authorization_params.rb', line 333

def application_fee_amount
  @application_fee_amount
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



335
336
337
# File 'lib/stripe/params/payment_intent_decrement_authorization_params.rb', line 335

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



337
338
339
# File 'lib/stripe/params/payment_intent_decrement_authorization_params.rb', line 337

def expand
  @expand
end

#hooksObject

Automations to be run during the PaymentIntent lifecycle



339
340
341
# File 'lib/stripe/params/payment_intent_decrement_authorization_params.rb', line 339

def hooks
  @hooks
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.



341
342
343
# File 'lib/stripe/params/payment_intent_decrement_authorization_params.rb', line 341

def 
  @metadata
end

#payment_detailsObject

Provides industry-specific information about the charge.



343
344
345
# File 'lib/stripe/params/payment_intent_decrement_authorization_params.rb', line 343

def payment_details
  @payment_details
end

#transfer_dataObject

The parameters used to automatically create a transfer after the payment is captured. Learn more about the use case for connected accounts.



346
347
348
# File 'lib/stripe/params/payment_intent_decrement_authorization_params.rb', line 346

def transfer_data
  @transfer_data
end