Class: Stripe::PaymentIntentDecrementAuthorizationParams::AmountDetails::LineItem::PaymentMethodOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_decrement_authorization_params.rb

Defined Under Namespace

Classes: Card, CardPresent, Klarna, Paypal

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(card: nil, card_present: nil, klarna: nil, paypal: nil) ⇒ PaymentMethodOptions

Returns a new instance of PaymentMethodOptions.



87
88
89
90
91
92
# File 'lib/stripe/params/payment_intent_decrement_authorization_params.rb', line 87

def initialize(card: nil, card_present: nil, klarna: nil, paypal: nil)
  @card = card
  @card_present = card_present
  @klarna = klarna
  @paypal = paypal
end

Instance Attribute Details

#cardObject

This sub-hash contains line item details that are specific to the ‘card` payment method.



79
80
81
# File 'lib/stripe/params/payment_intent_decrement_authorization_params.rb', line 79

def card
  @card
end

#card_presentObject

This sub-hash contains line item details that are specific to the ‘card_present` payment method.



81
82
83
# File 'lib/stripe/params/payment_intent_decrement_authorization_params.rb', line 81

def card_present
  @card_present
end

#klarnaObject

This sub-hash contains line item details that are specific to the ‘klarna` payment method.



83
84
85
# File 'lib/stripe/params/payment_intent_decrement_authorization_params.rb', line 83

def klarna
  @klarna
end

#paypalObject

This sub-hash contains line item details that are specific to the ‘paypal` payment method.



85
86
87
# File 'lib/stripe/params/payment_intent_decrement_authorization_params.rb', line 85

def paypal
  @paypal
end