Class: Stripe::PaymentIntentDecrementAuthorizationParams::AmountDetails::LineItem::PaymentMethodOptions::Card::FleetData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentDecrementAuthorizationParams::AmountDetails::LineItem::PaymentMethodOptions::Card::FleetData
- Defined in:
- lib/stripe/params/payment_intent_decrement_authorization_params.rb
Instance Attribute Summary collapse
-
#product_type ⇒ Object
The type of product being purchased at this line item.
-
#service_type ⇒ Object
The type of service received at the acceptor location.
Instance Method Summary collapse
-
#initialize(product_type: nil, service_type: nil) ⇒ FleetData
constructor
A new instance of FleetData.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(product_type: nil, service_type: nil) ⇒ FleetData
Returns a new instance of FleetData.
16 17 18 19 |
# File 'lib/stripe/params/payment_intent_decrement_authorization_params.rb', line 16 def initialize(product_type: nil, service_type: nil) @product_type = product_type @service_type = service_type end |
Instance Attribute Details
#product_type ⇒ Object
The type of product being purchased at this line item.
12 13 14 |
# File 'lib/stripe/params/payment_intent_decrement_authorization_params.rb', line 12 def product_type @product_type end |
#service_type ⇒ Object
The type of service received at the acceptor location.
14 15 16 |
# File 'lib/stripe/params/payment_intent_decrement_authorization_params.rb', line 14 def service_type @service_type end |