Class: Stripe::PaymentIntentIncrementAuthorizationParams::AmountDetails::LineItem::PaymentMethodOptions::Card::EvCharging

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_increment_authorization_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(carbon_footprint_avoided_grams_co2: nil, charging_ended_at: nil, charging_power_output_capacity_kw: nil, charging_started_at: nil, connector_type: nil, estimated_range_added: nil, estimated_range_left: nil, maximum_power_dispensed_kw: nil) ⇒ EvCharging

Returns a new instance of EvCharging.



28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 28

def initialize(
  carbon_footprint_avoided_grams_co2: nil,
  charging_ended_at: nil,
  charging_power_output_capacity_kw: nil,
  charging_started_at: nil,
  connector_type: nil,
  estimated_range_added: nil,
  estimated_range_left: nil,
  maximum_power_dispensed_kw: nil
)
  @carbon_footprint_avoided_grams_co2 = carbon_footprint_avoided_grams_co2
  @charging_ended_at = charging_ended_at
  @charging_power_output_capacity_kw = charging_power_output_capacity_kw
  @charging_started_at = charging_started_at
  @connector_type = connector_type
  @estimated_range_added = estimated_range_added
  @estimated_range_left = estimated_range_left
  @maximum_power_dispensed_kw = maximum_power_dispensed_kw
end

Instance Attribute Details

#carbon_footprint_avoided_grams_co2Object

The carbon footprint avoided by the charging session, in grams of CO2.



12
13
14
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 12

def carbon_footprint_avoided_grams_co2
  @carbon_footprint_avoided_grams_co2
end

#charging_ended_atObject

The time the charging session ended, measured in seconds since the Unix epoch.



14
15
16
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 14

def charging_ended_at
  @charging_ended_at
end

#charging_power_output_capacity_kwObject

The power output capacity of the charging station, in kilowatts (kW).



16
17
18
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 16

def charging_power_output_capacity_kw
  @charging_power_output_capacity_kw
end

#charging_started_atObject

The time the charging session started, measured in seconds since the Unix epoch.



18
19
20
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 18

def charging_started_at
  @charging_started_at
end

#connector_typeObject

The type of connector used for the charging session.



20
21
22
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 20

def connector_type
  @connector_type
end

#estimated_range_addedObject

The estimated distance in kilometers or miles added to the vehicle during the charging session.



22
23
24
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 22

def estimated_range_added
  @estimated_range_added
end

#estimated_range_leftObject

The estimated distance in kilometers or miles remaining in the vehicle after the charging session.



24
25
26
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 24

def estimated_range_left
  @estimated_range_left
end

#maximum_power_dispensed_kwObject

The maximum power dispensed during the charging session, in kilowatts (kW).



26
27
28
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 26

def maximum_power_dispensed_kw
  @maximum_power_dispensed_kw
end