Class: Stripe::PaymentIntentIncrementAuthorizationParams::AmountDetails::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_increment_authorization_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, from_postal_code: nil, to_postal_code: nil) ⇒ Shipping

Returns a new instance of Shipping.



159
160
161
162
163
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 159

def initialize(amount: nil, from_postal_code: nil, to_postal_code: nil)
  @amount = amount
  @from_postal_code = from_postal_code
  @to_postal_code = to_postal_code
end

Instance Attribute Details

#amountObject

If a physical good is being shipped, the cost of shipping represented in the [smallest currency unit](docs.stripe.com/currencies#zero-decimal). An integer greater than or equal to 0.



153
154
155
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 153

def amount
  @amount
end

#from_postal_codeObject

If a physical good is being shipped, the postal code of where it is being shipped from. At most 10 alphanumeric characters long, hyphens and spaces are allowed.



155
156
157
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 155

def from_postal_code
  @from_postal_code
end

#to_postal_codeObject

If a physical good is being shipped, the postal code of where it is being shipped to. At most 10 alphanumeric characters long, hyphens and spaces are allowed.



157
158
159
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 157

def to_postal_code
  @to_postal_code
end