Class: Stripe::PaymentIntentIncrementAuthorizationParams::AmountDetails::Tip
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentIncrementAuthorizationParams::AmountDetails::Tip
- Defined in:
- lib/stripe/params/payment_intent_increment_authorization_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
Portion of the amount that corresponds to a tip.
Instance Method Summary collapse
-
#initialize(amount: nil) ⇒ Tip
constructor
A new instance of Tip.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil) ⇒ Tip
Returns a new instance of Tip.
235 236 237 |
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 235 def initialize(amount: nil) @amount = amount end |
Instance Attribute Details
#amount ⇒ Object
Portion of the amount that corresponds to a tip.
233 234 235 |
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 233 def amount @amount end |