Class: Stripe::PaymentIntentIncrementAuthorizationParams::PaymentMethodOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentIncrementAuthorizationParams::PaymentMethodOptions
- Defined in:
- lib/stripe/params/payment_intent_increment_authorization_params.rb
Defined Under Namespace
Classes: Card
Instance Attribute Summary collapse
-
#card ⇒ Object
Configuration for any card payments attempted on this PaymentIntent.
Instance Method Summary collapse
-
#initialize(card: nil) ⇒ PaymentMethodOptions
constructor
A new instance of PaymentMethodOptions.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(card: nil) ⇒ PaymentMethodOptions
Returns a new instance of PaymentMethodOptions.
259 260 261 |
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 259 def initialize(card: nil) @card = card end |
Instance Attribute Details
#card ⇒ Object
Configuration for any card payments attempted on this PaymentIntent.
257 258 259 |
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 257 def card @card end |