Class: Stripe::PaymentIntentService::CaptureParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: AmountDetails, Hooks, PaymentDetails, TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_details: nil, amount_to_capture: nil, application_fee_amount: nil, expand: nil, final_capture: nil, hooks: nil, metadata: nil, payment_details: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil) ⇒ CaptureParams

Returns a new instance of CaptureParams.



8600
8601
8602
8603
8604
8605
8606
8607
8608
8609
8610
8611
8612
8613
8614
8615
8616
8617
8618
8619
8620
8621
8622
8623
8624
# File 'lib/stripe/services/payment_intent_service.rb', line 8600

def initialize(
  amount_details: nil,
  amount_to_capture: nil,
  application_fee_amount: nil,
  expand: nil,
  final_capture: nil,
  hooks: nil,
  metadata: nil,
  payment_details: nil,
  statement_descriptor: nil,
  statement_descriptor_suffix: nil,
  transfer_data: nil
)
  @amount_details = amount_details
  @amount_to_capture = amount_to_capture
  @application_fee_amount = application_fee_amount
  @expand = expand
  @final_capture = final_capture
  @hooks = hooks
  @metadata = 
  @payment_details = payment_details
  @statement_descriptor = statement_descriptor
  @statement_descriptor_suffix = statement_descriptor_suffix
  @transfer_data = transfer_data
end

Instance Attribute Details

#amount_detailsObject

Provides industry-specific information about the amount.



8575
8576
8577
# File 'lib/stripe/services/payment_intent_service.rb', line 8575

def amount_details
  @amount_details
end

#amount_to_captureObject

The amount to capture from the PaymentIntent, which must be less than or equal to the original amount. Defaults to the full ‘amount_capturable` if it’s not provided.



8577
8578
8579
# File 'lib/stripe/services/payment_intent_service.rb', line 8577

def amount_to_capture
  @amount_to_capture
end

#application_fee_amountObject

The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



8579
8580
8581
# File 'lib/stripe/services/payment_intent_service.rb', line 8579

def application_fee_amount
  @application_fee_amount
end

#expandObject

Specifies which fields in the response should be expanded.



8581
8582
8583
# File 'lib/stripe/services/payment_intent_service.rb', line 8581

def expand
  @expand
end

#final_captureObject

Defaults to ‘true`. When capturing a PaymentIntent, setting `final_capture` to `false` notifies Stripe to not release the remaining uncaptured funds to make sure that they’re captured in future requests. You can only use this setting when [multicapture](stripe.com/docs/payments/multicapture) is available for PaymentIntents.



8583
8584
8585
# File 'lib/stripe/services/payment_intent_service.rb', line 8583

def final_capture
  @final_capture
end

#hooksObject

Automations to be run during the PaymentIntent lifecycle



8585
8586
8587
# File 'lib/stripe/services/payment_intent_service.rb', line 8585

def hooks
  @hooks
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



8587
8588
8589
# File 'lib/stripe/services/payment_intent_service.rb', line 8587

def 
  @metadata
end

#payment_detailsObject

Provides industry-specific information about the charge.



8589
8590
8591
# File 'lib/stripe/services/payment_intent_service.rb', line 8589

def payment_details
  @payment_details
end

#statement_descriptorObject

Text that appears on the customer’s statement as the statement descriptor for a non-card charge. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).

Setting this value for a card charge returns an error. For card charges, set the [statement_descriptor_suffix](docs.stripe.com/get-started/account/statement-descriptors#dynamic) instead.



8593
8594
8595
# File 'lib/stripe/services/payment_intent_service.rb', line 8593

def statement_descriptor
  @statement_descriptor
end

#statement_descriptor_suffixObject

Provides information about a card charge. Concatenated to the account’s [statement descriptor prefix](docs.stripe.com/get-started/account/statement-descriptors#static) to form the complete statement descriptor that appears on the customer’s statement.



8595
8596
8597
# File 'lib/stripe/services/payment_intent_service.rb', line 8595

def statement_descriptor_suffix
  @statement_descriptor_suffix
end

#transfer_dataObject

The parameters that you can use to automatically create a transfer after the payment is captured. Learn more about the [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



8598
8599
8600
# File 'lib/stripe/services/payment_intent_service.rb', line 8598

def transfer_data
  @transfer_data
end