Class: Stripe::PaymentIntentService::CaptureParams::AmountDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: LineItem, Shipping, Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discount_amount: nil, line_items: nil, shipping: nil, tax: nil) ⇒ AmountDetails

Returns a new instance of AmountDetails.



7828
7829
7830
7831
7832
7833
# File 'lib/stripe/services/payment_intent_service.rb', line 7828

def initialize(discount_amount: nil, line_items: nil, shipping: nil, tax: nil)
  @discount_amount = discount_amount
  @line_items = line_items
  @shipping = shipping
  @tax = tax
end

Instance Attribute Details

#discount_amountObject

The amount an item was discounted for.



7820
7821
7822
# File 'lib/stripe/services/payment_intent_service.rb', line 7820

def discount_amount
  @discount_amount
end

#line_itemsObject

A list of line items, each containing information about a product in the PaymentIntent. There is a maximum of 100 line items.



7822
7823
7824
# File 'lib/stripe/services/payment_intent_service.rb', line 7822

def line_items
  @line_items
end

#shippingObject

Contains information about the shipping portion of the amount.



7824
7825
7826
# File 'lib/stripe/services/payment_intent_service.rb', line 7824

def shipping
  @shipping
end

#taxObject

Contains information about the tax portion of the amount.



7826
7827
7828
# File 'lib/stripe/services/payment_intent_service.rb', line 7826

def tax
  @tax
end