Class: Stripe::PaymentIntentService::CaptureParams::AmountDetails::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CaptureParams::AmountDetails::LineItem
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: PaymentMethodOptions, Tax
Instance Attribute Summary collapse
-
#discount_amount ⇒ Object
The amount an item was discounted for.
-
#payment_method_options ⇒ Object
Payment method-specific information for line items.
-
#product_code ⇒ Object
Unique identifier of the product.
-
#product_name ⇒ Object
Name of the product.
-
#quantity ⇒ Object
Number of items of the product.
-
#tax ⇒ Object
Contains information about the tax on the item.
-
#unit_cost ⇒ Object
Cost of the product.
-
#unit_of_measure ⇒ Object
A unit of measure for the line item, such as gallons, feet, meters, etc.
Instance Method Summary collapse
-
#initialize(discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil) ⇒ LineItem
Returns a new instance of LineItem.
7775 7776 7777 7778 7779 7780 7781 7782 7783 7784 7785 7786 7787 7788 7789 7790 7791 7792 7793 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7775 def initialize( discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil ) @discount_amount = discount_amount @payment_method_options = @product_code = product_code @product_name = product_name @quantity = quantity @tax = tax @unit_cost = unit_cost @unit_of_measure = unit_of_measure end |
Instance Attribute Details
#discount_amount ⇒ Object
The amount an item was discounted for. Positive integer.
7759 7760 7761 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7759 def discount_amount @discount_amount end |
#payment_method_options ⇒ Object
Payment method-specific information for line items.
7761 7762 7763 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7761 def @payment_method_options end |
#product_code ⇒ Object
Unique identifier of the product. At most 12 characters long.
7763 7764 7765 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7763 def product_code @product_code end |
#product_name ⇒ Object
Name of the product. At most 100 characters long.
7765 7766 7767 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7765 def product_name @product_name end |
#quantity ⇒ Object
Number of items of the product. Positive integer.
7767 7768 7769 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7767 def quantity @quantity end |
#tax ⇒ Object
Contains information about the tax on the item.
7769 7770 7771 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7769 def tax @tax end |
#unit_cost ⇒ Object
Cost of the product. Non-negative integer.
7771 7772 7773 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7771 def unit_cost @unit_cost end |
#unit_of_measure ⇒ Object
A unit of measure for the line item, such as gallons, feet, meters, etc.
7773 7774 7775 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7773 def unit_of_measure @unit_of_measure end |