Class: Stripe::PaymentIntentService::CaptureParams::AmountDetails::LineItem::PaymentMethodOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Card, CardPresent, Klarna, Paypal

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(card: nil, card_present: nil, klarna: nil, paypal: nil) ⇒ PaymentMethodOptions

Returns a new instance of PaymentMethodOptions.



7638
7639
7640
7641
7642
7643
# File 'lib/stripe/services/payment_intent_service.rb', line 7638

def initialize(card: nil, card_present: nil, klarna: nil, paypal: nil)
  @card = card
  @card_present = card_present
  @klarna = klarna
  @paypal = paypal
end

Instance Attribute Details

#cardObject

This sub-hash contains line item details that are specific to ‘card` payment method.“



7630
7631
7632
# File 'lib/stripe/services/payment_intent_service.rb', line 7630

def card
  @card
end

#card_presentObject

This sub-hash contains line item details that are specific to ‘card_present` payment method.“



7632
7633
7634
# File 'lib/stripe/services/payment_intent_service.rb', line 7632

def card_present
  @card_present
end

#klarnaObject

This sub-hash contains line item details that are specific to ‘klarna` payment method.“



7634
7635
7636
# File 'lib/stripe/services/payment_intent_service.rb', line 7634

def klarna
  @klarna
end

#paypalObject

This sub-hash contains line item details that are specific to ‘paypal` payment method.“



7636
7637
7638
# File 'lib/stripe/services/payment_intent_service.rb', line 7636

def paypal
  @paypal
end