Class: Stripe::PaymentIntentService::CaptureParams::AmountDetails::LineItem::PaymentMethodOptions::Paypal
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CaptureParams::AmountDetails::LineItem::PaymentMethodOptions::Paypal
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, sold_by: nil) ⇒ Paypal
constructor
A new instance of Paypal.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, description: nil, sold_by: nil) ⇒ Paypal
Returns a new instance of Paypal.
7727 7728 7729 7730 7731 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7727 def initialize(category: nil, description: nil, sold_by: nil) @category = category @description = description @sold_by = sold_by end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
7721 7722 7723 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7721 def category @category end |
#description ⇒ Object
Description of the line item.
7723 7724 7725 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7723 def description @description end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
7725 7726 7727 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7725 def sold_by @sold_by end |