Class: Stripe::PaymentIntentService::CaptureParams::PaymentDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CaptureParams::PaymentDetails
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: CarRental, EventDetails, Flight, Lodging, Subscription
Instance Attribute Summary collapse
-
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
-
#customer_reference ⇒ Object
Some customers might be required by their company or organization to provide this information.
-
#event_details ⇒ Object
Event details for this PaymentIntent.
-
#flight ⇒ Object
Flight reservation details for this PaymentIntent.
-
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent.
-
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
-
#subscription ⇒ Object
Subscription details for this PaymentIntent.
Instance Method Summary collapse
-
#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
constructor
A new instance of PaymentDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
Returns a new instance of PaymentDetails.
8547 8548 8549 8550 8551 8552 8553 8554 8555 8556 8557 8558 8559 8560 8561 8562 8563 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8547 def initialize( car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil ) @car_rental = car_rental @customer_reference = customer_reference @event_details = event_details @flight = flight @lodging = lodging @order_reference = order_reference @subscription = subscription end |
Instance Attribute Details
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
8533 8534 8535 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8533 def car_rental @car_rental end |
#customer_reference ⇒ Object
Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.
8535 8536 8537 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8535 def customer_reference @customer_reference end |
#event_details ⇒ Object
Event details for this PaymentIntent
8537 8538 8539 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8537 def event_details @event_details end |
#flight ⇒ Object
Flight reservation details for this PaymentIntent
8539 8540 8541 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8539 def flight @flight end |
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent
8541 8542 8543 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8541 def lodging @lodging end |
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
8543 8544 8545 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8543 def order_reference @order_reference end |
#subscription ⇒ Object
Subscription details for this PaymentIntent
8545 8546 8547 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8545 def subscription @subscription end |