Class: Stripe::PaymentIntentService::CaptureParams::PaymentDetails::CarRental

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Affiliate, Delivery, Distance, Driver, PickupAddress, ReturnAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil) ⇒ CarRental

Returns a new instance of CarRental.



8035
8036
8037
8038
8039
8040
8041
8042
8043
8044
8045
8046
8047
8048
8049
8050
8051
8052
8053
8054
8055
8056
8057
8058
8059
8060
8061
8062
8063
8064
8065
8066
8067
8068
8069
8070
8071
8072
8073
8074
8075
8076
8077
8078
8079
8080
8081
8082
8083
8084
8085
# File 'lib/stripe/services/payment_intent_service.rb', line 8035

def initialize(
  affiliate: nil,
  booking_number: nil,
  car_class_code: nil,
  car_make: nil,
  car_model: nil,
  company: nil,
  customer_service_phone_number: nil,
  days_rented: nil,
  delivery: nil,
  distance: nil,
  drivers: nil,
  extra_charges: nil,
  no_show: nil,
  pickup_address: nil,
  pickup_at: nil,
  pickup_location_name: nil,
  rate_amount: nil,
  rate_interval: nil,
  renter_name: nil,
  return_address: nil,
  return_at: nil,
  return_location_name: nil,
  tax_exempt: nil,
  vehicle_identification_number: nil
)
  @affiliate = affiliate
  @booking_number = booking_number
  @car_class_code = car_class_code
  @car_make = car_make
  @car_model = car_model
  @company = company
  @customer_service_phone_number = customer_service_phone_number
  @days_rented = days_rented
  @delivery = delivery
  @distance = distance
  @drivers = drivers
  @extra_charges = extra_charges
  @no_show = no_show
  @pickup_address = pickup_address
  @pickup_at = pickup_at
  @pickup_location_name = pickup_location_name
  @rate_amount = rate_amount
  @rate_interval = rate_interval
  @renter_name = renter_name
  @return_address = return_address
  @return_at = return_at
  @return_location_name = return_location_name
  @tax_exempt = tax_exempt
  @vehicle_identification_number = vehicle_identification_number
end

Instance Attribute Details

#affiliateObject

Affiliate details for this purchase.



7987
7988
7989
# File 'lib/stripe/services/payment_intent_service.rb', line 7987

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the car rental.



7989
7990
7991
# File 'lib/stripe/services/payment_intent_service.rb', line 7989

def booking_number
  @booking_number
end

#car_class_codeObject

Class code of the car.



7991
7992
7993
# File 'lib/stripe/services/payment_intent_service.rb', line 7991

def car_class_code
  @car_class_code
end

#car_makeObject

Make of the car.



7993
7994
7995
# File 'lib/stripe/services/payment_intent_service.rb', line 7993

def car_make
  @car_make
end

#car_modelObject

Model of the car.



7995
7996
7997
# File 'lib/stripe/services/payment_intent_service.rb', line 7995

def car_model
  @car_model
end

#companyObject

The name of the rental car company.



7997
7998
7999
# File 'lib/stripe/services/payment_intent_service.rb', line 7997

def company
  @company
end

#customer_service_phone_numberObject

The customer service phone number of the car rental company.



7999
8000
8001
# File 'lib/stripe/services/payment_intent_service.rb', line 7999

def customer_service_phone_number
  @customer_service_phone_number
end

#days_rentedObject

Number of days the car is being rented.



8001
8002
8003
# File 'lib/stripe/services/payment_intent_service.rb', line 8001

def days_rented
  @days_rented
end

#deliveryObject

Delivery details for this purchase.



8003
8004
8005
# File 'lib/stripe/services/payment_intent_service.rb', line 8003

def delivery
  @delivery
end

#distanceObject

The details of the distance traveled during the rental period.



8005
8006
8007
# File 'lib/stripe/services/payment_intent_service.rb', line 8005

def distance
  @distance
end

#driversObject

The details of the passengers in the travel reservation



8007
8008
8009
# File 'lib/stripe/services/payment_intent_service.rb', line 8007

def drivers
  @drivers
end

#extra_chargesObject

List of additional charges being billed.



8009
8010
8011
# File 'lib/stripe/services/payment_intent_service.rb', line 8009

def extra_charges
  @extra_charges
end

#no_showObject

Indicates if the customer did not keep nor cancel their booking.



8011
8012
8013
# File 'lib/stripe/services/payment_intent_service.rb', line 8011

def no_show
  @no_show
end

#pickup_addressObject

Car pick-up address.



8013
8014
8015
# File 'lib/stripe/services/payment_intent_service.rb', line 8013

def pickup_address
  @pickup_address
end

#pickup_atObject

Car pick-up time. Measured in seconds since the Unix epoch.



8015
8016
8017
# File 'lib/stripe/services/payment_intent_service.rb', line 8015

def pickup_at
  @pickup_at
end

#pickup_location_nameObject

Name of the pickup location.



8017
8018
8019
# File 'lib/stripe/services/payment_intent_service.rb', line 8017

def pickup_location_name
  @pickup_location_name
end

#rate_amountObject

Rental rate.



8019
8020
8021
# File 'lib/stripe/services/payment_intent_service.rb', line 8019

def rate_amount
  @rate_amount
end

#rate_intervalObject

The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`



8021
8022
8023
# File 'lib/stripe/services/payment_intent_service.rb', line 8021

def rate_interval
  @rate_interval
end

#renter_nameObject

The name of the person or entity renting the car.



8023
8024
8025
# File 'lib/stripe/services/payment_intent_service.rb', line 8023

def renter_name
  @renter_name
end

#return_addressObject

Car return address.



8025
8026
8027
# File 'lib/stripe/services/payment_intent_service.rb', line 8025

def return_address
  @return_address
end

#return_atObject

Car return time. Measured in seconds since the Unix epoch.



8027
8028
8029
# File 'lib/stripe/services/payment_intent_service.rb', line 8027

def return_at
  @return_at
end

#return_location_nameObject

Name of the return location.



8029
8030
8031
# File 'lib/stripe/services/payment_intent_service.rb', line 8029

def return_location_name
  @return_location_name
end

#tax_exemptObject

Indicates whether the goods or services are tax-exempt or tax is not collected.



8031
8032
8033
# File 'lib/stripe/services/payment_intent_service.rb', line 8031

def tax_exempt
  @tax_exempt
end

#vehicle_identification_numberObject

The vehicle identification number.



8033
8034
8035
# File 'lib/stripe/services/payment_intent_service.rb', line 8033

def vehicle_identification_number
  @vehicle_identification_number
end