Class: Stripe::PaymentIntentService::CaptureParams::PaymentDetails::CarRental::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



7881
7882
7883
7884
7885
# File 'lib/stripe/services/payment_intent_service.rb', line 7881

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



7875
7876
7877
# File 'lib/stripe/services/payment_intent_service.rb', line 7875

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



7877
7878
7879
# File 'lib/stripe/services/payment_intent_service.rb', line 7877

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



7879
7880
7881
# File 'lib/stripe/services/payment_intent_service.rb', line 7879

def phone
  @phone
end