Class: Stripe::PaymentIntentService::CaptureParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CaptureParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
7602 7603 7604 7605 7606 7607 7608 7609 7610 7611 7612 7613 7614 7615 7616 7617 7618 7619 7620 7621 7622 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7602 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
7584 7585 7586 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7584 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
7586 7587 7588 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7586 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
7588 7589 7590 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7588 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
7590 7591 7592 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7590 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
7592 7593 7594 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7592 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
7594 7595 7596 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7594 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
7596 7597 7598 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7596 def genre @genre end |
#name ⇒ Object
The name of the event.
7598 7599 7600 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7598 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
7600 7601 7602 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7600 def starts_at @starts_at end |