Class: Stripe::PaymentIntentService::CaptureParams::PaymentDetails::EventDetails::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



8138
8139
8140
8141
8142
# File 'lib/stripe/services/payment_intent_service.rb', line 8138

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



8132
8133
8134
# File 'lib/stripe/services/payment_intent_service.rb', line 8132

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



8134
8135
8136
# File 'lib/stripe/services/payment_intent_service.rb', line 8134

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



8136
8137
8138
# File 'lib/stripe/services/payment_intent_service.rb', line 8136

def phone
  @phone
end