Class: Stripe::PaymentIntentService::CaptureParams::PaymentDetails::Flight
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CaptureParams::PaymentDetails::Flight
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Passenger, Segment
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
-
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#segments ⇒ Object
The individual flight segments associated with the trip.
-
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
Instance Method Summary collapse
-
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
constructor
A new instance of Flight.
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
Returns a new instance of Flight.
8192 8193 8194 8195 8196 8197 8198 8199 8200 8201 8202 8203 8204 8205 8206 8207 8208 8209 8210 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8192 def initialize( affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil ) @affiliate = affiliate @agency_number = agency_number @carrier = carrier @delivery = delivery @passenger_name = passenger_name @passengers = passengers @segments = segments @ticket_number = ticket_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
8176 8177 8178 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8176 def affiliate @affiliate end |
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
8178 8179 8180 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8178 def agency_number @agency_number end |
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
8180 8181 8182 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8180 def carrier @carrier end |
#delivery ⇒ Object
Delivery details for this purchase.
8182 8183 8184 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8182 def delivery @delivery end |
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
8184 8185 8186 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8184 def passenger_name @passenger_name end |
#passengers ⇒ Object
The details of the passengers in the travel reservation.
8186 8187 8188 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8186 def passengers @passengers end |
#segments ⇒ Object
The individual flight segments associated with the trip.
8188 8189 8190 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8188 def segments @segments end |
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
8190 8191 8192 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8190 def ticket_number @ticket_number end |