Class: Stripe::PaymentIntentService::CaptureParams::PaymentDetails::Flight::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CaptureParams::PaymentDetails::Flight::Delivery::Recipient
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
8215 8216 8217 8218 8219 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8215 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
8209 8210 8211 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8209 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
8211 8212 8213 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8211 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
8213 8214 8215 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8213 def phone @phone end |