Class: Stripe::PaymentIntentService::CaptureParams::PaymentDetails::Lodging::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



8367
8368
8369
8370
8371
# File 'lib/stripe/services/payment_intent_service.rb', line 8367

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



8361
8362
8363
# File 'lib/stripe/services/payment_intent_service.rb', line 8361

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



8363
8364
8365
# File 'lib/stripe/services/payment_intent_service.rb', line 8363

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



8365
8366
8367
# File 'lib/stripe/services/payment_intent_service.rb', line 8365

def phone
  @phone
end