Class: Stripe::PaymentIntentService::CaptureParams::PaymentDetails::Subscription
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CaptureParams::PaymentDetails::Subscription
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Affiliate, BillingInterval
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#auto_renewal ⇒ Object
Info whether the subscription will be auto renewed upon expiry.
-
#billing_interval ⇒ Object
Subscription billing details for this purchase.
-
#ends_at ⇒ Object
Subscription end time.
-
#name ⇒ Object
Name of the product on subscription.
-
#starts_at ⇒ Object
Subscription start time.
Instance Method Summary collapse
-
#initialize(affiliate: nil, auto_renewal: nil, billing_interval: nil, ends_at: nil, name: nil, starts_at: nil) ⇒ Subscription
constructor
A new instance of Subscription.
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, auto_renewal: nil, billing_interval: nil, ends_at: nil, name: nil, starts_at: nil) ⇒ Subscription
Returns a new instance of Subscription.
8516 8517 8518 8519 8520 8521 8522 8523 8524 8525 8526 8527 8528 8529 8530 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8516 def initialize( affiliate: nil, auto_renewal: nil, billing_interval: nil, ends_at: nil, name: nil, starts_at: nil ) @affiliate = affiliate @auto_renewal = auto_renewal @billing_interval = billing_interval @ends_at = ends_at @name = name @starts_at = starts_at end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
8504 8505 8506 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8504 def affiliate @affiliate end |
#auto_renewal ⇒ Object
Info whether the subscription will be auto renewed upon expiry.
8506 8507 8508 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8506 def auto_renewal @auto_renewal end |
#billing_interval ⇒ Object
Subscription billing details for this purchase.
8508 8509 8510 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8508 def billing_interval @billing_interval end |
#ends_at ⇒ Object
Subscription end time. Measured in seconds since the Unix epoch.
8510 8511 8512 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8510 def ends_at @ends_at end |
#name ⇒ Object
Name of the product on subscription. e.g. Apple Music Subscription
8512 8513 8514 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8512 def name @name end |
#starts_at ⇒ Object
Subscription start time. Measured in seconds since the Unix epoch.
8514 8515 8516 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8514 def starts_at @starts_at end |