Class: Stripe::PaymentIntentService::CaptureParams::PaymentDetails::Subscription::BillingInterval

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(count: nil, interval: nil) ⇒ BillingInterval

Returns a new instance of BillingInterval.



8498
8499
8500
8501
# File 'lib/stripe/services/payment_intent_service.rb', line 8498

def initialize(count: nil, interval: nil)
  @count = count
  @interval = interval
end

Instance Attribute Details

#countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



8494
8495
8496
# File 'lib/stripe/services/payment_intent_service.rb', line 8494

def count
  @count
end

#intervalObject

Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.



8496
8497
8498
# File 'lib/stripe/services/payment_intent_service.rb', line 8496

def interval
  @interval
end