Class: Stripe::PaymentIntentService::CaptureParams::TransferData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CaptureParams::TransferData
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount that will be transferred automatically when a charge succeeds.
Instance Method Summary collapse
-
#initialize(amount: nil) ⇒ TransferData
constructor
A new instance of TransferData.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil) ⇒ TransferData
Returns a new instance of TransferData.
4889 4890 4891 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4889 def initialize(amount: nil) @amount = amount end |
Instance Attribute Details
#amount ⇒ Object
The amount that will be transferred automatically when a charge succeeds.
4887 4888 4889 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4887 def amount @amount end |