Class: Stripe::PaymentIntentService::ConfirmParams::AmountDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: LineItem, Shipping, Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discount_amount: nil, line_items: nil, shipping: nil, tax: nil) ⇒ AmountDetails

Returns a new instance of AmountDetails.



8773
8774
8775
8776
8777
8778
# File 'lib/stripe/services/payment_intent_service.rb', line 8773

def initialize(discount_amount: nil, line_items: nil, shipping: nil, tax: nil)
  @discount_amount = discount_amount
  @line_items = line_items
  @shipping = shipping
  @tax = tax
end

Instance Attribute Details

#discount_amountObject

The amount an item was discounted for.



8765
8766
8767
# File 'lib/stripe/services/payment_intent_service.rb', line 8765

def discount_amount
  @discount_amount
end

#line_itemsObject

A list of line items, each containing information about a product in the PaymentIntent. There is a maximum of 100 line items.



8767
8768
8769
# File 'lib/stripe/services/payment_intent_service.rb', line 8767

def line_items
  @line_items
end

#shippingObject

Contains information about the shipping portion of the amount.



8769
8770
8771
# File 'lib/stripe/services/payment_intent_service.rb', line 8769

def shipping
  @shipping
end

#taxObject

Contains information about the tax portion of the amount.



8771
8772
8773
# File 'lib/stripe/services/payment_intent_service.rb', line 8771

def tax
  @tax
end