Class: Stripe::PaymentIntentService::ConfirmParams::AmountDetails::LineItem::PaymentMethodOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::AmountDetails::LineItem::PaymentMethodOptions
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Card, CardPresent, Klarna, Paypal
Instance Attribute Summary collapse
-
#card ⇒ Object
This sub-hash contains line item details that are specific to ‘card` payment method.“.
-
#card_present ⇒ Object
This sub-hash contains line item details that are specific to ‘card_present` payment method.“.
-
#klarna ⇒ Object
This sub-hash contains line item details that are specific to ‘klarna` payment method.“.
-
#paypal ⇒ Object
This sub-hash contains line item details that are specific to ‘paypal` payment method.“.
Instance Method Summary collapse
-
#initialize(card: nil, card_present: nil, klarna: nil, paypal: nil) ⇒ PaymentMethodOptions
constructor
A new instance of PaymentMethodOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(card: nil, card_present: nil, klarna: nil, paypal: nil) ⇒ PaymentMethodOptions
Returns a new instance of PaymentMethodOptions.
8687 8688 8689 8690 8691 8692 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8687 def initialize(card: nil, card_present: nil, klarna: nil, paypal: nil) @card = card @card_present = card_present @klarna = klarna @paypal = paypal end |
Instance Attribute Details
#card ⇒ Object
This sub-hash contains line item details that are specific to ‘card` payment method.“
8679 8680 8681 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8679 def card @card end |
#card_present ⇒ Object
This sub-hash contains line item details that are specific to ‘card_present` payment method.“
8681 8682 8683 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8681 def card_present @card_present end |
#klarna ⇒ Object
This sub-hash contains line item details that are specific to ‘klarna` payment method.“
8683 8684 8685 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8683 def klarna @klarna end |
#paypal ⇒ Object
This sub-hash contains line item details that are specific to ‘paypal` payment method.“
8685 8686 8687 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8685 def paypal @paypal end |