Class: Stripe::PaymentIntentService::ConfirmParams::AmountDetails::LineItem::PaymentMethodOptions::Card
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::AmountDetails::LineItem::PaymentMethodOptions::Card
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#commodity_code ⇒ Object
Identifier that categorizes the items being purchased using a standardized commodity scheme such as (but not limited to) UNSPSC, NAICS, NAPCS, etc.
Instance Method Summary collapse
-
#initialize(commodity_code: nil) ⇒ Card
constructor
A new instance of Card.
Methods inherited from RequestParams
Constructor Details
#initialize(commodity_code: nil) ⇒ Card
Returns a new instance of Card.
8635 8636 8637 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8635 def initialize(commodity_code: nil) @commodity_code = commodity_code end |
Instance Attribute Details
#commodity_code ⇒ Object
Identifier that categorizes the items being purchased using a standardized commodity scheme such as (but not limited to) UNSPSC, NAICS, NAPCS, etc.
8633 8634 8635 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8633 def commodity_code @commodity_code end |