Class: Stripe::PaymentIntentService::ConfirmParams::AmountDetails::LineItem::PaymentMethodOptions::Paypal
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::AmountDetails::LineItem::PaymentMethodOptions::Paypal
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, sold_by: nil) ⇒ Paypal
constructor
A new instance of Paypal.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, description: nil, sold_by: nil) ⇒ Paypal
Returns a new instance of Paypal.
8672 8673 8674 8675 8676 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8672 def initialize(category: nil, description: nil, sold_by: nil) @category = category @description = description @sold_by = sold_by end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
8666 8667 8668 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8666 def category @category end |
#description ⇒ Object
Description of the line item.
8668 8669 8670 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8668 def description @description end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
8670 8671 8672 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8670 def sold_by @sold_by end |