Class: Stripe::PaymentIntentService::ConfirmParams::MandateData::CustomerAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Offline, Online

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(accepted_at: nil, offline: nil, online: nil, type: nil) ⇒ CustomerAcceptance

Returns a new instance of CustomerAcceptance.



8726
8727
8728
8729
8730
8731
# File 'lib/stripe/services/payment_intent_service.rb', line 8726

def initialize(accepted_at: nil, offline: nil, online: nil, type: nil)
  @accepted_at = accepted_at
  @offline = offline
  @online = online
  @type = type
end

Instance Attribute Details

#accepted_atObject

The time at which the customer accepted the Mandate.



8718
8719
8720
# File 'lib/stripe/services/payment_intent_service.rb', line 8718

def accepted_at
  @accepted_at
end

#offlineObject

If this is a Mandate accepted offline, this hash contains details about the offline acceptance.



8720
8721
8722
# File 'lib/stripe/services/payment_intent_service.rb', line 8720

def offline
  @offline
end

#onlineObject

If this is a Mandate accepted online, this hash contains details about the online acceptance.



8722
8723
8724
# File 'lib/stripe/services/payment_intent_service.rb', line 8722

def online
  @online
end

#typeObject

The type of customer acceptance information included with the Mandate. One of ‘online` or `offline`.



8724
8725
8726
# File 'lib/stripe/services/payment_intent_service.rb', line 8724

def type
  @type
end