Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentDetails
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: CarRental, EventDetails, Flight, Lodging, Subscription
Instance Attribute Summary collapse
-
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
-
#customer_reference ⇒ Object
Some customers might be required by their company or organization to provide this information.
-
#event_details ⇒ Object
Event details for this PaymentIntent.
-
#flight ⇒ Object
Flight reservation details for this PaymentIntent.
-
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent.
-
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
-
#subscription ⇒ Object
Subscription details for this PaymentIntent.
Instance Method Summary collapse
-
#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
constructor
A new instance of PaymentDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
Returns a new instance of PaymentDetails.
9531 9532 9533 9534 9535 9536 9537 9538 9539 9540 9541 9542 9543 9544 9545 9546 9547 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9531 def initialize( car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil ) @car_rental = car_rental @customer_reference = customer_reference @event_details = event_details @flight = flight @lodging = lodging @order_reference = order_reference @subscription = subscription end |
Instance Attribute Details
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
9517 9518 9519 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9517 def car_rental @car_rental end |
#customer_reference ⇒ Object
Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.
9519 9520 9521 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9519 def customer_reference @customer_reference end |
#event_details ⇒ Object
Event details for this PaymentIntent
9521 9522 9523 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9521 def event_details @event_details end |
#flight ⇒ Object
Flight reservation details for this PaymentIntent
9523 9524 9525 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9523 def flight @flight end |
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent
9525 9526 9527 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9525 def lodging @lodging end |
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
9527 9528 9529 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9527 def order_reference @order_reference end |
#subscription ⇒ Object
Subscription details for this PaymentIntent
9529 9530 9531 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9529 def subscription @subscription end |