Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::CarRental

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Affiliate, Delivery, Distance, Driver, PickupAddress, ReturnAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil) ⇒ CarRental

Returns a new instance of CarRental.



9019
9020
9021
9022
9023
9024
9025
9026
9027
9028
9029
9030
9031
9032
9033
9034
9035
9036
9037
9038
9039
9040
9041
9042
9043
9044
9045
9046
9047
9048
9049
9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
9063
9064
9065
9066
9067
9068
9069
# File 'lib/stripe/services/payment_intent_service.rb', line 9019

def initialize(
  affiliate: nil,
  booking_number: nil,
  car_class_code: nil,
  car_make: nil,
  car_model: nil,
  company: nil,
  customer_service_phone_number: nil,
  days_rented: nil,
  delivery: nil,
  distance: nil,
  drivers: nil,
  extra_charges: nil,
  no_show: nil,
  pickup_address: nil,
  pickup_at: nil,
  pickup_location_name: nil,
  rate_amount: nil,
  rate_interval: nil,
  renter_name: nil,
  return_address: nil,
  return_at: nil,
  return_location_name: nil,
  tax_exempt: nil,
  vehicle_identification_number: nil
)
  @affiliate = affiliate
  @booking_number = booking_number
  @car_class_code = car_class_code
  @car_make = car_make
  @car_model = car_model
  @company = company
  @customer_service_phone_number = customer_service_phone_number
  @days_rented = days_rented
  @delivery = delivery
  @distance = distance
  @drivers = drivers
  @extra_charges = extra_charges
  @no_show = no_show
  @pickup_address = pickup_address
  @pickup_at = pickup_at
  @pickup_location_name = pickup_location_name
  @rate_amount = rate_amount
  @rate_interval = rate_interval
  @renter_name = renter_name
  @return_address = return_address
  @return_at = return_at
  @return_location_name = return_location_name
  @tax_exempt = tax_exempt
  @vehicle_identification_number = vehicle_identification_number
end

Instance Attribute Details

#affiliateObject

Affiliate details for this purchase.



8971
8972
8973
# File 'lib/stripe/services/payment_intent_service.rb', line 8971

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the car rental.



8973
8974
8975
# File 'lib/stripe/services/payment_intent_service.rb', line 8973

def booking_number
  @booking_number
end

#car_class_codeObject

Class code of the car.



8975
8976
8977
# File 'lib/stripe/services/payment_intent_service.rb', line 8975

def car_class_code
  @car_class_code
end

#car_makeObject

Make of the car.



8977
8978
8979
# File 'lib/stripe/services/payment_intent_service.rb', line 8977

def car_make
  @car_make
end

#car_modelObject

Model of the car.



8979
8980
8981
# File 'lib/stripe/services/payment_intent_service.rb', line 8979

def car_model
  @car_model
end

#companyObject

The name of the rental car company.



8981
8982
8983
# File 'lib/stripe/services/payment_intent_service.rb', line 8981

def company
  @company
end

#customer_service_phone_numberObject

The customer service phone number of the car rental company.



8983
8984
8985
# File 'lib/stripe/services/payment_intent_service.rb', line 8983

def customer_service_phone_number
  @customer_service_phone_number
end

#days_rentedObject

Number of days the car is being rented.



8985
8986
8987
# File 'lib/stripe/services/payment_intent_service.rb', line 8985

def days_rented
  @days_rented
end

#deliveryObject

Delivery details for this purchase.



8987
8988
8989
# File 'lib/stripe/services/payment_intent_service.rb', line 8987

def delivery
  @delivery
end

#distanceObject

The details of the distance traveled during the rental period.



8989
8990
8991
# File 'lib/stripe/services/payment_intent_service.rb', line 8989

def distance
  @distance
end

#driversObject

The details of the passengers in the travel reservation



8991
8992
8993
# File 'lib/stripe/services/payment_intent_service.rb', line 8991

def drivers
  @drivers
end

#extra_chargesObject

List of additional charges being billed.



8993
8994
8995
# File 'lib/stripe/services/payment_intent_service.rb', line 8993

def extra_charges
  @extra_charges
end

#no_showObject

Indicates if the customer did not keep nor cancel their booking.



8995
8996
8997
# File 'lib/stripe/services/payment_intent_service.rb', line 8995

def no_show
  @no_show
end

#pickup_addressObject

Car pick-up address.



8997
8998
8999
# File 'lib/stripe/services/payment_intent_service.rb', line 8997

def pickup_address
  @pickup_address
end

#pickup_atObject

Car pick-up time. Measured in seconds since the Unix epoch.



8999
9000
9001
# File 'lib/stripe/services/payment_intent_service.rb', line 8999

def pickup_at
  @pickup_at
end

#pickup_location_nameObject

Name of the pickup location.



9001
9002
9003
# File 'lib/stripe/services/payment_intent_service.rb', line 9001

def pickup_location_name
  @pickup_location_name
end

#rate_amountObject

Rental rate.



9003
9004
9005
# File 'lib/stripe/services/payment_intent_service.rb', line 9003

def rate_amount
  @rate_amount
end

#rate_intervalObject

The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`



9005
9006
9007
# File 'lib/stripe/services/payment_intent_service.rb', line 9005

def rate_interval
  @rate_interval
end

#renter_nameObject

The name of the person or entity renting the car.



9007
9008
9009
# File 'lib/stripe/services/payment_intent_service.rb', line 9007

def renter_name
  @renter_name
end

#return_addressObject

Car return address.



9009
9010
9011
# File 'lib/stripe/services/payment_intent_service.rb', line 9009

def return_address
  @return_address
end

#return_atObject

Car return time. Measured in seconds since the Unix epoch.



9011
9012
9013
# File 'lib/stripe/services/payment_intent_service.rb', line 9011

def return_at
  @return_at
end

#return_location_nameObject

Name of the return location.



9013
9014
9015
# File 'lib/stripe/services/payment_intent_service.rb', line 9013

def return_location_name
  @return_location_name
end

#tax_exemptObject

Indicates whether the goods or services are tax-exempt or tax is not collected.



9015
9016
9017
# File 'lib/stripe/services/payment_intent_service.rb', line 9015

def tax_exempt
  @tax_exempt
end

#vehicle_identification_numberObject

The vehicle identification number.



9017
9018
9019
# File 'lib/stripe/services/payment_intent_service.rb', line 9017

def vehicle_identification_number
  @vehicle_identification_number
end