Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::CarRental::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::CarRental::Delivery::Recipient
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
8865 8866 8867 8868 8869 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8865 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
8859 8860 8861 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8859 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
8861 8862 8863 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8861 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
8863 8864 8865 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8863 def phone @phone end |