Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
9157 9158 9159 9160 9161 9162 9163 9164 9165 9166 9167 9168 9169 9170 9171 9172 9173 9174 9175 9176 9177 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9157 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
9139 9140 9141 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9139 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
9141 9142 9143 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9141 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
9143 9144 9145 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9143 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
9145 9146 9147 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9145 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
9147 9148 9149 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9147 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
9149 9150 9151 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9149 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
9151 9152 9153 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9151 def genre @genre end |
#name ⇒ Object
The name of the event.
9153 9154 9155 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9153 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
9155 9156 9157 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9155 def starts_at @starts_at end |