Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::EventDetails::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::EventDetails::Delivery::Recipient
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
9122 9123 9124 9125 9126 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9122 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
9116 9117 9118 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9116 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
9118 9119 9120 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9118 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
9120 9121 9122 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9120 def phone @phone end |