Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::Flight
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::Flight
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Passenger, Segment
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
-
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#segments ⇒ Object
The individual flight segments associated with the trip.
-
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
Instance Method Summary collapse
-
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
constructor
A new instance of Flight.
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
Returns a new instance of Flight.
9280 9281 9282 9283 9284 9285 9286 9287 9288 9289 9290 9291 9292 9293 9294 9295 9296 9297 9298 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9280 def initialize( affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil ) @affiliate = affiliate @agency_number = agency_number @carrier = carrier @delivery = delivery @passenger_name = passenger_name @passengers = passengers @segments = segments @ticket_number = ticket_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
9264 9265 9266 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9264 def affiliate @affiliate end |
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
9266 9267 9268 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9266 def agency_number @agency_number end |
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
9268 9269 9270 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9268 def carrier @carrier end |
#delivery ⇒ Object
Delivery details for this purchase.
9270 9271 9272 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9270 def delivery @delivery end |
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
9272 9273 9274 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9272 def passenger_name @passenger_name end |
#passengers ⇒ Object
The details of the passengers in the travel reservation.
9274 9275 9276 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9274 def passengers @passengers end |
#segments ⇒ Object
The individual flight segments associated with the trip.
9276 9277 9278 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9276 def segments @segments end |
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
9278 9279 9280 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9278 def ticket_number @ticket_number end |