Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::Lodging::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



9351
9352
9353
9354
9355
# File 'lib/stripe/services/payment_intent_service.rb', line 9351

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



9345
9346
9347
# File 'lib/stripe/services/payment_intent_service.rb', line 9345

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



9347
9348
9349
# File 'lib/stripe/services/payment_intent_service.rb', line 9347

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



9349
9350
9351
# File 'lib/stripe/services/payment_intent_service.rb', line 9349

def phone
  @phone
end