Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::Subscription::BillingInterval

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(count: nil, interval: nil) ⇒ BillingInterval

Returns a new instance of BillingInterval.



8550
8551
8552
8553
# File 'lib/stripe/services/payment_intent_service.rb', line 8550

def initialize(count: nil, interval: nil)
  @count = count
  @interval = interval
end

Instance Attribute Details

#countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



8546
8547
8548
# File 'lib/stripe/services/payment_intent_service.rb', line 8546

def count
  @count
end

#intervalObject

Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.



8548
8549
8550
# File 'lib/stripe/services/payment_intent_service.rb', line 8548

def interval
  @interval
end