Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



9764
9765
9766
9767
9768
9769
9770
9771
9772
9773
9774
9775
9776
9777
9778
# File 'lib/stripe/services/payment_intent_service.rb', line 9764

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



9752
9753
9754
# File 'lib/stripe/services/payment_intent_service.rb', line 9752

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



9754
9755
9756
# File 'lib/stripe/services/payment_intent_service.rb', line 9754

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



9756
9757
9758
# File 'lib/stripe/services/payment_intent_service.rb', line 9756

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



9758
9759
9760
# File 'lib/stripe/services/payment_intent_service.rb', line 9758

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



9760
9761
9762
# File 'lib/stripe/services/payment_intent_service.rb', line 9760

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



9762
9763
9764
# File 'lib/stripe/services/payment_intent_service.rb', line 9762

def suffix
  @suffix
end