Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodData::RadarOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentMethodData::RadarOptions
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#session ⇒ Object
A [Radar Session](stripe.com/docs/radar/radar-session) is a snapshot of the browser metadata and device details that help Radar make more accurate predictions on your payments.
Instance Method Summary collapse
-
#initialize(session: nil) ⇒ RadarOptions
constructor
A new instance of RadarOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(session: nil) ⇒ RadarOptions
Returns a new instance of RadarOptions.
9716 9717 9718 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9716 def initialize(session: nil) @session = session end |
Instance Attribute Details
#session ⇒ Object
A [Radar Session](stripe.com/docs/radar/radar-session) is a snapshot of the browser metadata and device details that help Radar make more accurate predictions on your payments.
9714 9715 9716 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9714 def session @session end |