Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodData::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentMethodData::UsBankAccount
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#account_holder_type ⇒ Object
Account holder type: individual or company.
-
#account_number ⇒ Object
Account number of the bank account.
-
#account_type ⇒ Object
Account type: checkings or savings.
-
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
-
#routing_number ⇒ Object
Routing number of the bank account.
Instance Method Summary collapse
-
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
9899 9900 9901 9902 9903 9904 9905 9906 9907 9908 9909 9910 9911 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9899 def initialize( account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil ) @account_holder_type = account_holder_type @account_number = account_number @account_type = account_type @financial_connections_account = financial_connections_account @routing_number = routing_number end |
Instance Attribute Details
#account_holder_type ⇒ Object
Account holder type: individual or company.
9889 9890 9891 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9889 def account_holder_type @account_holder_type end |
#account_number ⇒ Object
Account number of the bank account.
9891 9892 9893 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9891 def account_number @account_number end |
#account_type ⇒ Object
Account type: checkings or savings. Defaults to checking if omitted.
9893 9894 9895 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9893 def account_type @account_type end |
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
9895 9896 9897 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9895 def financial_connections_account @financial_connections_account end |
#routing_number ⇒ Object
Routing number of the bank account.
9897 9898 9899 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9897 def routing_number @routing_number end |