Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::Card::Installments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::Card::Installments
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Plan
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Setting to true enables installments for this PaymentIntent.
-
#plan ⇒ Object
The selected installment plan to use for this payment attempt.
Instance Method Summary collapse
-
#initialize(enabled: nil, plan: nil) ⇒ Installments
constructor
A new instance of Installments.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, plan: nil) ⇒ Installments
Returns a new instance of Installments.
10478 10479 10480 10481 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10478 def initialize(enabled: nil, plan: nil) @enabled = enabled @plan = plan end |
Instance Attribute Details
#enabled ⇒ Object
Setting to true enables installments for this PaymentIntent. This will cause the response to contain a list of available installment plans. Setting to false will prevent any selected plan from applying to a charge.
10473 10474 10475 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10473 def enabled @enabled end |
#plan ⇒ Object
The selected installment plan to use for this payment attempt. This parameter can only be provided during confirmation.
10476 10477 10478 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10476 def plan @plan end |