Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::Card::Installments::Plan

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(count: nil, interval: nil, type: nil) ⇒ Plan

Returns a new instance of Plan.



5791
5792
5793
5794
5795
# File 'lib/stripe/services/payment_intent_service.rb', line 5791

def initialize(count: nil, interval: nil, type: nil)
  @count = count
  @interval = interval
  @type = type
end

Instance Attribute Details

#countObject

For ‘fixed_count` installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.



5784
5785
5786
# File 'lib/stripe/services/payment_intent_service.rb', line 5784

def count
  @count
end

#intervalObject

For ‘fixed_count` installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of `month`.



5787
5788
5789
# File 'lib/stripe/services/payment_intent_service.rb', line 5787

def interval
  @interval
end

#typeObject

Type of installment plan, one of ‘fixed_count`, `bonus`, or `revolving`.



5789
5790
5791
# File 'lib/stripe/services/payment_intent_service.rb', line 5789

def type
  @type
end