Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::Card::StatementDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::Card::StatementDetails
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Please pass in an address that is within your Stripe user account country.
-
#phone ⇒ Object
Phone number (e.g., a toll-free number that customers can call).
Instance Method Summary collapse
-
#initialize(address: nil, phone: nil) ⇒ StatementDetails
constructor
A new instance of StatementDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, phone: nil) ⇒ StatementDetails
Returns a new instance of StatementDetails.
9626 9627 9628 9629 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9626 def initialize(address: nil, phone: nil) @address = address @phone = phone end |
Instance Attribute Details
#address ⇒ Object
Please pass in an address that is within your Stripe user account country
9622 9623 9624 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9622 def address @address end |
#phone ⇒ Object
Phone number (e.g., a toll-free number that customers can call)
9624 9625 9626 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9624 def phone @phone end |