Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::CardPresent
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::CardPresent
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Routing
Instance Attribute Summary collapse
-
#request_extended_authorization ⇒ Object
Request ability to capture this payment beyond the standard [authorization validity window](stripe.com/docs/terminal/features/extended-authorizations#authorization-validity).
-
#request_incremental_authorization_support ⇒ Object
Request ability to [increment](stripe.com/docs/terminal/features/incremental-authorizations) this PaymentIntent if the combination of MCC and card brand is eligible.
-
#routing ⇒ Object
Network routing priority on co-branded EMV cards supporting domestic debit and international card schemes.
Instance Method Summary collapse
-
#initialize(request_extended_authorization: nil, request_incremental_authorization_support: nil, routing: nil) ⇒ CardPresent
constructor
A new instance of CardPresent.
Methods inherited from RequestParams
Constructor Details
#initialize(request_extended_authorization: nil, request_incremental_authorization_support: nil, routing: nil) ⇒ CardPresent
Returns a new instance of CardPresent.
10473 10474 10475 10476 10477 10478 10479 10480 10481 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10473 def initialize( request_extended_authorization: nil, request_incremental_authorization_support: nil, routing: nil ) @request_extended_authorization = @request_incremental_authorization_support = @routing = routing end |
Instance Attribute Details
#request_extended_authorization ⇒ Object
Request ability to capture this payment beyond the standard [authorization validity window](stripe.com/docs/terminal/features/extended-authorizations#authorization-validity)
10465 10466 10467 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10465 def @request_extended_authorization end |
#request_incremental_authorization_support ⇒ Object
Request ability to [increment](stripe.com/docs/terminal/features/incremental-authorizations) this PaymentIntent if the combination of MCC and card brand is eligible. Check [incremental_authorization_supported](stripe.com/docs/api/charges/object#charge_object-payment_method_details-card_present-incremental_authorization_supported) in the [Confirm](stripe.com/docs/api/payment_intents/confirm) response to verify support.
10468 10469 10470 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10468 def @request_incremental_authorization_support end |
#routing ⇒ Object
Network routing priority on co-branded EMV cards supporting domestic debit and international card schemes.
10471 10472 10473 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10471 def routing @routing end |