Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::Klarna::OnDemand

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(average_amount: nil, maximum_amount: nil, minimum_amount: nil, purchase_interval: nil, purchase_interval_count: nil) ⇒ OnDemand

Returns a new instance of OnDemand.



6252
6253
6254
6255
6256
6257
6258
6259
6260
6261
6262
6263
6264
# File 'lib/stripe/services/payment_intent_service.rb', line 6252

def initialize(
  average_amount: nil,
  maximum_amount: nil,
  minimum_amount: nil,
  purchase_interval: nil,
  purchase_interval_count: nil
)
  @average_amount = average_amount
  @maximum_amount = maximum_amount
  @minimum_amount = minimum_amount
  @purchase_interval = purchase_interval
  @purchase_interval_count = purchase_interval_count
end

Instance Attribute Details

#average_amountObject

Your average amount value. You can use a value across your customer base, or segment based on customer type, country, etc.



6242
6243
6244
# File 'lib/stripe/services/payment_intent_service.rb', line 6242

def average_amount
  @average_amount
end

#maximum_amountObject

The maximum value you may charge a customer per purchase. You can use a value across your customer base, or segment based on customer type, country, etc.



6244
6245
6246
# File 'lib/stripe/services/payment_intent_service.rb', line 6244

def maximum_amount
  @maximum_amount
end

#minimum_amountObject

The lowest or minimum value you may charge a customer per purchase. You can use a value across your customer base, or segment based on customer type, country, etc.



6246
6247
6248
# File 'lib/stripe/services/payment_intent_service.rb', line 6246

def minimum_amount
  @minimum_amount
end

#purchase_intervalObject

Interval at which the customer is making purchases



6248
6249
6250
# File 'lib/stripe/services/payment_intent_service.rb', line 6248

def purchase_interval
  @purchase_interval
end

#purchase_interval_countObject

The number of ‘purchase_interval` between charges



6250
6251
6252
# File 'lib/stripe/services/payment_intent_service.rb', line 6250

def purchase_interval_count
  @purchase_interval_count
end