Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::Klarna::Subscription
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::Klarna::Subscription
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: NextBilling
Instance Attribute Summary collapse
-
#interval ⇒ Object
Unit of time between subscription charges.
-
#interval_count ⇒ Object
The number of intervals (specified in the ‘interval` attribute) between subscription charges.
-
#name ⇒ Object
Name for subscription.
-
#next_billing ⇒ Object
Describes the upcoming charge for this subscription.
-
#reference ⇒ Object
A non-customer-facing reference to correlate subscription charges in the Klarna app.
Instance Method Summary collapse
-
#initialize(interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil) ⇒ Subscription
constructor
A new instance of Subscription.
Methods inherited from RequestParams
Constructor Details
#initialize(interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil) ⇒ Subscription
Returns a new instance of Subscription.
11057 11058 11059 11060 11061 11062 11063 11064 11065 11066 11067 11068 11069 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11057 def initialize( interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil ) @interval = interval @interval_count = interval_count @name = name @next_billing = next_billing @reference = reference end |
Instance Attribute Details
#interval ⇒ Object
Unit of time between subscription charges.
11047 11048 11049 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11047 def interval @interval end |
#interval_count ⇒ Object
The number of intervals (specified in the ‘interval` attribute) between subscription charges. For example, `interval=month` and `interval_count=3` charges every 3 months.
11049 11050 11051 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11049 def interval_count @interval_count end |
#name ⇒ Object
Name for subscription.
11051 11052 11053 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11051 def name @name end |
#next_billing ⇒ Object
Describes the upcoming charge for this subscription.
11053 11054 11055 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11053 def next_billing @next_billing end |
#reference ⇒ Object
A non-customer-facing reference to correlate subscription charges in the Klarna app. Use a value that persists across subscription charges.
11055 11056 11057 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11055 def reference @reference end |