Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::Klarna::Subscription::NextBilling

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, date: nil) ⇒ NextBilling

Returns a new instance of NextBilling.



6274
6275
6276
6277
# File 'lib/stripe/services/payment_intent_service.rb', line 6274

def initialize(amount: nil, date: nil)
  @amount = amount
  @date = date
end

Instance Attribute Details

#amountObject

The amount of the next charge for the subscription.



6270
6271
6272
# File 'lib/stripe/services/payment_intent_service.rb', line 6270

def amount
  @amount
end

#dateObject

The date of the next charge for the subscription in YYYY-MM-DD format.



6272
6273
6274
# File 'lib/stripe/services/payment_intent_service.rb', line 6272

def date
  @date
end