Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::Paypal
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::Paypal
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#capture_method ⇒ Object
Controls when the funds will be captured from the customer’s account.
-
#preferred_locale ⇒ Object
[Preferred locale](stripe.com/docs/payments/paypal/supported-locales) of the PayPal checkout page that the customer is redirected to.
-
#reference ⇒ Object
A reference of the PayPal transaction visible to customer which is mapped to PayPal’s invoice ID.
-
#risk_correlation_id ⇒ Object
The risk correlation ID for an on-session payment using a saved PayPal payment method.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
Instance Method Summary collapse
-
#initialize(capture_method: nil, preferred_locale: nil, reference: nil, risk_correlation_id: nil, setup_future_usage: nil) ⇒ Paypal
constructor
A new instance of Paypal.
Methods inherited from RequestParams
Constructor Details
#initialize(capture_method: nil, preferred_locale: nil, reference: nil, risk_correlation_id: nil, setup_future_usage: nil) ⇒ Paypal
Returns a new instance of Paypal.
6601 6602 6603 6604 6605 6606 6607 6608 6609 6610 6611 6612 6613 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6601 def initialize( capture_method: nil, preferred_locale: nil, reference: nil, risk_correlation_id: nil, setup_future_usage: nil ) @capture_method = capture_method @preferred_locale = preferred_locale @reference = reference @risk_correlation_id = risk_correlation_id @setup_future_usage = setup_future_usage end |
Instance Attribute Details
#capture_method ⇒ Object
Controls when the funds will be captured from the customer’s account.
6583 6584 6585 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6583 def capture_method @capture_method end |
#preferred_locale ⇒ Object
[Preferred locale](stripe.com/docs/payments/paypal/supported-locales) of the PayPal checkout page that the customer is redirected to.
6585 6586 6587 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6585 def preferred_locale @preferred_locale end |
#reference ⇒ Object
A reference of the PayPal transaction visible to customer which is mapped to PayPal’s invoice ID. This must be a globally unique ID if you have configured in your PayPal settings to block multiple payments per invoice ID.
6587 6588 6589 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6587 def reference @reference end |
#risk_correlation_id ⇒ Object
The risk correlation ID for an on-session payment using a saved PayPal payment method.
6589 6590 6591 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6589 def risk_correlation_id @risk_correlation_id end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.
If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.
When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).
If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.
6599 6600 6601 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6599 def setup_future_usage @setup_future_usage end |