Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::Paypal::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem

Returns a new instance of LineItem.



11395
11396
11397
11398
11399
11400
11401
11402
11403
11404
11405
11406
11407
11408
11409
11410
11411
11412
11413
# File 'lib/stripe/services/payment_intent_service.rb', line 11395

def initialize(
  category: nil,
  description: nil,
  name: nil,
  quantity: nil,
  sku: nil,
  sold_by: nil,
  tax: nil,
  unit_amount: nil
)
  @category = category
  @description = description
  @name = name
  @quantity = quantity
  @sku = sku
  @sold_by = sold_by
  @tax = tax
  @unit_amount = unit_amount
end

Instance Attribute Details

#categoryObject

Type of the line item.



11379
11380
11381
# File 'lib/stripe/services/payment_intent_service.rb', line 11379

def category
  @category
end

#descriptionObject

Description of the line item.



11381
11382
11383
# File 'lib/stripe/services/payment_intent_service.rb', line 11381

def description
  @description
end

#nameObject

Descriptive name of the line item.



11383
11384
11385
# File 'lib/stripe/services/payment_intent_service.rb', line 11383

def name
  @name
end

#quantityObject

Quantity of the line item. Must be a positive number.



11385
11386
11387
# File 'lib/stripe/services/payment_intent_service.rb', line 11385

def quantity
  @quantity
end

#skuObject

Client facing stock keeping unit, article number or similar.



11387
11388
11389
# File 'lib/stripe/services/payment_intent_service.rb', line 11387

def sku
  @sku
end

#sold_byObject

The Stripe account ID of the connected account that sells the item.



11389
11390
11391
# File 'lib/stripe/services/payment_intent_service.rb', line 11389

def sold_by
  @sold_by
end

#taxObject

The tax information for the line item.



11391
11392
11393
# File 'lib/stripe/services/payment_intent_service.rb', line 11391

def tax
  @tax
end

#unit_amountObject

Price for a single unit of the line item in minor units. Cannot be a negative number.



11393
11394
11395
# File 'lib/stripe/services/payment_intent_service.rb', line 11393

def unit_amount
  @unit_amount
end