Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::Payto::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, end_date: nil, payment_schedule: nil, payments_per_period: nil, purpose: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



10748
10749
10750
10751
10752
10753
10754
10755
10756
10757
10758
10759
10760
10761
10762
# File 'lib/stripe/services/payment_intent_service.rb', line 10748

def initialize(
  amount: nil,
  amount_type: nil,
  end_date: nil,
  payment_schedule: nil,
  payments_per_period: nil,
  purpose: nil
)
  @amount = amount
  @amount_type = amount_type
  @end_date = end_date
  @payment_schedule = payment_schedule
  @payments_per_period = payments_per_period
  @purpose = purpose
end

Instance Attribute Details

#amountObject

Amount that will be collected. It is required when ‘amount_type` is `fixed`.



10736
10737
10738
# File 'lib/stripe/services/payment_intent_service.rb', line 10736

def amount
  @amount
end

#amount_typeObject

The type of amount that will be collected. The amount charged must be exact or up to the value of ‘amount` param for `fixed` or `maximum` type respectively.



10738
10739
10740
# File 'lib/stripe/services/payment_intent_service.rb', line 10738

def amount_type
  @amount_type
end

#end_dateObject

Date, in YYYY-MM-DD format, after which payments will not be collected. Defaults to no end date.



10740
10741
10742
# File 'lib/stripe/services/payment_intent_service.rb', line 10740

def end_date
  @end_date
end

#payment_scheduleObject

The periodicity at which payments will be collected.



10742
10743
10744
# File 'lib/stripe/services/payment_intent_service.rb', line 10742

def payment_schedule
  @payment_schedule
end

#payments_per_periodObject

The number of payments that will be made during a payment period. Defaults to 1 except for when ‘payment_schedule` is `adhoc`. In that case, it defaults to no limit.



10744
10745
10746
# File 'lib/stripe/services/payment_intent_service.rb', line 10744

def payments_per_period
  @payments_per_period
end

#purposeObject

The purpose for which payments are made. Defaults to retail.



10746
10747
10748
# File 'lib/stripe/services/payment_intent_service.rb', line 10746

def purpose
  @purpose
end