Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::Pix::MandateOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::Pix::MandateOptions
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount to be charged for future payments.
-
#amount_includes_iof ⇒ Object
Determines if the amount includes the IOF tax.
-
#amount_type ⇒ Object
Type of amount.
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#end_date ⇒ Object
Date when the mandate expires and no further payments will be charged, in ‘YYYY-MM-DD`.
-
#payment_schedule ⇒ Object
Schedule at which the future payments will be charged.
-
#reference ⇒ Object
Subscription name displayed to buyers in their bank app.
-
#start_date ⇒ Object
Start date of the mandate, in ‘YYYY-MM-DD`.
Instance Method Summary collapse
-
#initialize(amount: nil, amount_includes_iof: nil, amount_type: nil, currency: nil, end_date: nil, payment_schedule: nil, reference: nil, start_date: nil) ⇒ MandateOptions
constructor
A new instance of MandateOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, amount_includes_iof: nil, amount_type: nil, currency: nil, end_date: nil, payment_schedule: nil, reference: nil, start_date: nil) ⇒ MandateOptions
Returns a new instance of MandateOptions.
11530 11531 11532 11533 11534 11535 11536 11537 11538 11539 11540 11541 11542 11543 11544 11545 11546 11547 11548 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11530 def initialize( amount: nil, amount_includes_iof: nil, amount_type: nil, currency: nil, end_date: nil, payment_schedule: nil, reference: nil, start_date: nil ) @amount = amount @amount_includes_iof = amount_includes_iof @amount_type = amount_type @currency = currency @end_date = end_date @payment_schedule = payment_schedule @reference = reference @start_date = start_date end |
Instance Attribute Details
#amount ⇒ Object
Amount to be charged for future payments. Required when ‘amount_type=fixed`. If not provided for `amount_type=maximum`, defaults to 40000.
11514 11515 11516 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11514 def amount @amount end |
#amount_includes_iof ⇒ Object
Determines if the amount includes the IOF tax. Defaults to ‘never`.
11516 11517 11518 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11516 def amount_includes_iof @amount_includes_iof end |
#amount_type ⇒ Object
Type of amount. Defaults to ‘maximum`.
11518 11519 11520 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11518 def amount_type @amount_type end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Only ‘brl` is supported currently.
11520 11521 11522 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11520 def currency @currency end |
#end_date ⇒ Object
Date when the mandate expires and no further payments will be charged, in ‘YYYY-MM-DD`. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.
11522 11523 11524 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11522 def end_date @end_date end |
#payment_schedule ⇒ Object
Schedule at which the future payments will be charged. Defaults to ‘weekly`.
11524 11525 11526 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11524 def payment_schedule @payment_schedule end |
#reference ⇒ Object
Subscription name displayed to buyers in their bank app. Defaults to the displayable business name.
11526 11527 11528 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11526 def reference @reference end |
#start_date ⇒ Object
Start date of the mandate, in ‘YYYY-MM-DD`. Start date should be at least 3 days in the future. Defaults to 3 days after the current date.
11528 11529 11530 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11528 def start_date @start_date end |