Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::UsBankAccount
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: FinancialConnections, MandateOptions, Networks
Instance Attribute Summary collapse
-
#financial_connections ⇒ Object
Additional fields for Financial Connections Session creation.
-
#mandate_options ⇒ Object
Additional fields for Mandate creation.
-
#networks ⇒ Object
Additional fields for network related functions.
-
#preferred_settlement_speed ⇒ Object
Preferred transaction settlement speed.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
-
#target_date ⇒ Object
Controls when Stripe will attempt to debit the funds from the customer’s account.
-
#verification_method ⇒ Object
Bank account verification method.
Instance Method Summary collapse
-
#initialize(financial_connections: nil, mandate_options: nil, networks: nil, preferred_settlement_speed: nil, setup_future_usage: nil, target_date: nil, verification_method: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(financial_connections: nil, mandate_options: nil, networks: nil, preferred_settlement_speed: nil, setup_future_usage: nil, target_date: nil, verification_method: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
6867 6868 6869 6870 6871 6872 6873 6874 6875 6876 6877 6878 6879 6880 6881 6882 6883 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6867 def initialize( financial_connections: nil, mandate_options: nil, networks: nil, preferred_settlement_speed: nil, setup_future_usage: nil, target_date: nil, verification_method: nil ) @financial_connections = financial_connections @mandate_options = @networks = networks @preferred_settlement_speed = preferred_settlement_speed @setup_future_usage = setup_future_usage @target_date = target_date @verification_method = verification_method end |
Instance Attribute Details
#financial_connections ⇒ Object
Additional fields for Financial Connections Session creation
6845 6846 6847 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6845 def financial_connections @financial_connections end |
#mandate_options ⇒ Object
Additional fields for Mandate creation
6847 6848 6849 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6847 def @mandate_options end |
#networks ⇒ Object
Additional fields for network related functions
6849 6850 6851 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6849 def networks @networks end |
#preferred_settlement_speed ⇒ Object
Preferred transaction settlement speed
6851 6852 6853 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6851 def preferred_settlement_speed @preferred_settlement_speed end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.
If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.
When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).
If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.
6861 6862 6863 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6861 def setup_future_usage @setup_future_usage end |
#target_date ⇒ Object
Controls when Stripe will attempt to debit the funds from the customer’s account. The date must be a string in YYYY-MM-DD format. The date must be in the future and between 3 and 15 calendar days from now.
6863 6864 6865 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6863 def target_date @target_date end |
#verification_method ⇒ Object
Bank account verification method.
6865 6866 6867 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6865 def verification_method @verification_method end |