Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::UsBankAccount::FinancialConnections
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::UsBankAccount::FinancialConnections
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Filters, ManualEntry
Instance Attribute Summary collapse
-
#filters ⇒ Object
Provide filters for the linked accounts that the customer can select for the payment method.
-
#manual_entry ⇒ Object
Customize manual entry behavior.
-
#permissions ⇒ Object
The list of permissions to request.
-
#prefetch ⇒ Object
List of data features that you would like to retrieve upon account creation.
-
#return_url ⇒ Object
For webview integrations only.
Instance Method Summary collapse
-
#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections
constructor
A new instance of FinancialConnections.
Methods inherited from RequestParams
Constructor Details
#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections
Returns a new instance of FinancialConnections.
11669 11670 11671 11672 11673 11674 11675 11676 11677 11678 11679 11680 11681 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11669 def initialize( filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil ) @filters = filters @manual_entry = manual_entry @permissions = @prefetch = prefetch @return_url = return_url end |
Instance Attribute Details
#filters ⇒ Object
Provide filters for the linked accounts that the customer can select for the payment method.
11659 11660 11661 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11659 def filters @filters end |
#manual_entry ⇒ Object
Customize manual entry behavior
11661 11662 11663 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11661 def manual_entry @manual_entry end |
#permissions ⇒ Object
The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.
11663 11664 11665 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11663 def @permissions end |
#prefetch ⇒ Object
List of data features that you would like to retrieve upon account creation.
11665 11666 11667 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11665 def prefetch @prefetch end |
#return_url ⇒ Object
For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.
11667 11668 11669 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11667 def return_url @return_url end |