Class: Stripe::PaymentIntentService::ConfirmParams::RadarOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::RadarOptions
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#session ⇒ Object
A [Radar Session](stripe.com/docs/radar/radar-session) is a snapshot of the browser metadata and device details that help Radar make more accurate predictions on your payments.
Instance Method Summary collapse
-
#initialize(session: nil) ⇒ RadarOptions
constructor
A new instance of RadarOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(session: nil) ⇒ RadarOptions
Returns a new instance of RadarOptions.
7107 7108 7109 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7107 def initialize(session: nil) @session = session end |
Instance Attribute Details
#session ⇒ Object
A [Radar Session](stripe.com/docs/radar/radar-session) is a snapshot of the browser metadata and device details that help Radar make more accurate predictions on your payments.
7105 7106 7107 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7105 def session @session end |