Class: Stripe::PaymentIntentService::CreateParams::AmountDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: LineItem, Shipping, Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discount_amount: nil, line_items: nil, shipping: nil, tax: nil) ⇒ AmountDetails

Returns a new instance of AmountDetails.



211
212
213
214
215
216
# File 'lib/stripe/services/payment_intent_service.rb', line 211

def initialize(discount_amount: nil, line_items: nil, shipping: nil, tax: nil)
  @discount_amount = discount_amount
  @line_items = line_items
  @shipping = shipping
  @tax = tax
end

Instance Attribute Details

#discount_amountObject

The amount an item was discounted for.



203
204
205
# File 'lib/stripe/services/payment_intent_service.rb', line 203

def discount_amount
  @discount_amount
end

#line_itemsObject

A list of line items, each containing information about a product in the PaymentIntent. There is a maximum of 100 line items.



205
206
207
# File 'lib/stripe/services/payment_intent_service.rb', line 205

def line_items
  @line_items
end

#shippingObject

Contains information about the shipping portion of the amount.



207
208
209
# File 'lib/stripe/services/payment_intent_service.rb', line 207

def shipping
  @shipping
end

#taxObject

Contains information about the tax portion of the amount.



209
210
211
# File 'lib/stripe/services/payment_intent_service.rb', line 209

def tax
  @tax
end