Class: Stripe::PaymentIntentService::CreateParams::AmountDetails::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CreateParams::AmountDetails::LineItem
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: PaymentMethodOptions, Tax
Instance Attribute Summary collapse
-
#discount_amount ⇒ Object
The amount an item was discounted for.
-
#payment_method_options ⇒ Object
Payment method-specific information for line items.
-
#product_code ⇒ Object
Unique identifier of the product.
-
#product_name ⇒ Object
Name of the product.
-
#quantity ⇒ Object
Number of items of the product.
-
#tax ⇒ Object
Contains information about the tax on the item.
-
#unit_cost ⇒ Object
Cost of the product.
-
#unit_of_measure ⇒ Object
A unit of measure for the line item, such as gallons, feet, meters, etc.
Instance Method Summary collapse
-
#initialize(discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil) ⇒ LineItem
Returns a new instance of LineItem.
158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/stripe/services/payment_intent_service.rb', line 158 def initialize( discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil ) @discount_amount = discount_amount @payment_method_options = @product_code = product_code @product_name = product_name @quantity = quantity @tax = tax @unit_cost = unit_cost @unit_of_measure = unit_of_measure end |
Instance Attribute Details
#discount_amount ⇒ Object
The amount an item was discounted for. Positive integer.
142 143 144 |
# File 'lib/stripe/services/payment_intent_service.rb', line 142 def discount_amount @discount_amount end |
#payment_method_options ⇒ Object
Payment method-specific information for line items.
144 145 146 |
# File 'lib/stripe/services/payment_intent_service.rb', line 144 def @payment_method_options end |
#product_code ⇒ Object
Unique identifier of the product. At most 12 characters long.
146 147 148 |
# File 'lib/stripe/services/payment_intent_service.rb', line 146 def product_code @product_code end |
#product_name ⇒ Object
Name of the product. At most 100 characters long.
148 149 150 |
# File 'lib/stripe/services/payment_intent_service.rb', line 148 def product_name @product_name end |
#quantity ⇒ Object
Number of items of the product. Positive integer.
150 151 152 |
# File 'lib/stripe/services/payment_intent_service.rb', line 150 def quantity @quantity end |
#tax ⇒ Object
Contains information about the tax on the item.
152 153 154 |
# File 'lib/stripe/services/payment_intent_service.rb', line 152 def tax @tax end |
#unit_cost ⇒ Object
Cost of the product. Non-negative integer.
154 155 156 |
# File 'lib/stripe/services/payment_intent_service.rb', line 154 def unit_cost @unit_cost end |
#unit_of_measure ⇒ Object
A unit of measure for the line item, such as gallons, feet, meters, etc.
156 157 158 |
# File 'lib/stripe/services/payment_intent_service.rb', line 156 def unit_of_measure @unit_of_measure end |