Class: Stripe::PaymentIntentService::CreateParams::AmountDetails::LineItem::PaymentMethodOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CreateParams::AmountDetails::LineItem::PaymentMethodOptions
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Card, CardPresent, Klarna, Paypal
Instance Attribute Summary collapse
-
#card ⇒ Object
This sub-hash contains line item details that are specific to ‘card` payment method.“.
-
#card_present ⇒ Object
This sub-hash contains line item details that are specific to ‘card_present` payment method.“.
-
#klarna ⇒ Object
This sub-hash contains line item details that are specific to ‘klarna` payment method.“.
-
#paypal ⇒ Object
This sub-hash contains line item details that are specific to ‘paypal` payment method.“.
Instance Method Summary collapse
-
#initialize(card: nil, card_present: nil, klarna: nil, paypal: nil) ⇒ PaymentMethodOptions
constructor
A new instance of PaymentMethodOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(card: nil, card_present: nil, klarna: nil, paypal: nil) ⇒ PaymentMethodOptions
Returns a new instance of PaymentMethodOptions.
125 126 127 128 129 130 |
# File 'lib/stripe/services/payment_intent_service.rb', line 125 def initialize(card: nil, card_present: nil, klarna: nil, paypal: nil) @card = card @card_present = card_present @klarna = klarna @paypal = paypal end |
Instance Attribute Details
#card ⇒ Object
This sub-hash contains line item details that are specific to ‘card` payment method.“
117 118 119 |
# File 'lib/stripe/services/payment_intent_service.rb', line 117 def card @card end |
#card_present ⇒ Object
This sub-hash contains line item details that are specific to ‘card_present` payment method.“
119 120 121 |
# File 'lib/stripe/services/payment_intent_service.rb', line 119 def card_present @card_present end |
#klarna ⇒ Object
This sub-hash contains line item details that are specific to ‘klarna` payment method.“
121 122 123 |
# File 'lib/stripe/services/payment_intent_service.rb', line 121 def klarna @klarna end |
#paypal ⇒ Object
This sub-hash contains line item details that are specific to ‘paypal` payment method.“
123 124 125 |
# File 'lib/stripe/services/payment_intent_service.rb', line 123 def paypal @paypal end |