Class: Stripe::PaymentIntentService::CreateParams::AmountDetails::LineItem::PaymentMethodOptions::Paypal
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CreateParams::AmountDetails::LineItem::PaymentMethodOptions::Paypal
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, sold_by: nil) ⇒ Paypal
constructor
A new instance of Paypal.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, description: nil, sold_by: nil) ⇒ Paypal
Returns a new instance of Paypal.
110 111 112 113 114 |
# File 'lib/stripe/services/payment_intent_service.rb', line 110 def initialize(category: nil, description: nil, sold_by: nil) @category = category @description = description @sold_by = sold_by end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
104 105 106 |
# File 'lib/stripe/services/payment_intent_service.rb', line 104 def category @category end |
#description ⇒ Object
Description of the line item.
106 107 108 |
# File 'lib/stripe/services/payment_intent_service.rb', line 106 def description @description end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
108 109 110 |
# File 'lib/stripe/services/payment_intent_service.rb', line 108 def sold_by @sold_by end |