Class: Stripe::PaymentIntentService::CreateParams::MandateData::CustomerAcceptance::Online

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(ip_address: nil, user_agent: nil) ⇒ Online

Returns a new instance of Online.



115
116
117
118
# File 'lib/stripe/services/payment_intent_service.rb', line 115

def initialize(ip_address: nil, user_agent: nil)
  @ip_address = ip_address
  @user_agent = user_agent
end

Instance Attribute Details

#ip_addressObject

The IP address from which the Mandate was accepted by the customer.



111
112
113
# File 'lib/stripe/services/payment_intent_service.rb', line 111

def ip_address
  @ip_address
end

#user_agentObject

The user agent of the browser from which the Mandate was accepted by the customer.



113
114
115
# File 'lib/stripe/services/payment_intent_service.rb', line 113

def user_agent
  @user_agent
end