Class: Stripe::PaymentIntentService::CreateParams::PaymentDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: CarRental, EventDetails, Flight, Lodging, Subscription

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails

Returns a new instance of PaymentDetails.



983
984
985
986
987
988
989
990
991
992
993
994
995
996
997
998
999
# File 'lib/stripe/services/payment_intent_service.rb', line 983

def initialize(
  car_rental: nil,
  customer_reference: nil,
  event_details: nil,
  flight: nil,
  lodging: nil,
  order_reference: nil,
  subscription: nil
)
  @car_rental = car_rental
  @customer_reference = customer_reference
  @event_details = event_details
  @flight = flight
  @lodging = lodging
  @order_reference = order_reference
  @subscription = subscription
end

Instance Attribute Details

#car_rentalObject

Car rental details for this PaymentIntent.



969
970
971
# File 'lib/stripe/services/payment_intent_service.rb', line 969

def car_rental
  @car_rental
end

#customer_referenceObject

Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.



971
972
973
# File 'lib/stripe/services/payment_intent_service.rb', line 971

def customer_reference
  @customer_reference
end

#event_detailsObject

Event details for this PaymentIntent



973
974
975
# File 'lib/stripe/services/payment_intent_service.rb', line 973

def event_details
  @event_details
end

#flightObject

Flight reservation details for this PaymentIntent



975
976
977
# File 'lib/stripe/services/payment_intent_service.rb', line 975

def flight
  @flight
end

#lodgingObject

Lodging reservation details for this PaymentIntent



977
978
979
# File 'lib/stripe/services/payment_intent_service.rb', line 977

def lodging
  @lodging
end

#order_referenceObject

A unique value assigned by the business to identify the transaction.



979
980
981
# File 'lib/stripe/services/payment_intent_service.rb', line 979

def order_reference
  @order_reference
end

#subscriptionObject

Subscription details for this PaymentIntent



981
982
983
# File 'lib/stripe/services/payment_intent_service.rb', line 981

def subscription
  @subscription
end