Class: Stripe::PaymentIntentService::CreateParams::PaymentDetails::CarRental
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CreateParams::PaymentDetails::CarRental
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Distance, Driver, PickupAddress, ReturnAddress
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the car rental.
-
#car_class_code ⇒ Object
Class code of the car.
-
#car_make ⇒ Object
Make of the car.
-
#car_model ⇒ Object
Model of the car.
-
#company ⇒ Object
The name of the rental car company.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
-
#days_rented ⇒ Object
Number of days the car is being rented.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#distance ⇒ Object
The details of the distance traveled during the rental period.
-
#drivers ⇒ Object
The details of the passengers in the travel reservation.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
-
#pickup_address ⇒ Object
Car pick-up address.
-
#pickup_at ⇒ Object
Car pick-up time.
-
#pickup_location_name ⇒ Object
Name of the pickup location.
-
#rate_amount ⇒ Object
Rental rate.
-
#rate_interval ⇒ Object
The frequency at which the rate amount is applied.
-
#renter_name ⇒ Object
The name of the person or entity renting the car.
-
#return_address ⇒ Object
Car return address.
-
#return_at ⇒ Object
Car return time.
-
#return_location_name ⇒ Object
Name of the return location.
-
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
-
#vehicle_identification_number ⇒ Object
The vehicle identification number.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil) ⇒ CarRental
Returns a new instance of CarRental.
318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 |
# File 'lib/stripe/services/payment_intent_service.rb', line 318 def initialize( affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil ) @affiliate = affiliate @booking_number = booking_number @car_class_code = car_class_code @car_make = car_make @car_model = car_model @company = company @customer_service_phone_number = customer_service_phone_number @days_rented = days_rented @delivery = delivery @distance = distance @drivers = drivers @extra_charges = extra_charges @no_show = no_show @pickup_address = pickup_address @pickup_at = pickup_at @pickup_location_name = pickup_location_name @rate_amount = rate_amount @rate_interval = rate_interval @renter_name = renter_name @return_address = return_address @return_at = return_at @return_location_name = return_location_name @tax_exempt = tax_exempt @vehicle_identification_number = vehicle_identification_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
270 271 272 |
# File 'lib/stripe/services/payment_intent_service.rb', line 270 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the car rental.
272 273 274 |
# File 'lib/stripe/services/payment_intent_service.rb', line 272 def booking_number @booking_number end |
#car_class_code ⇒ Object
Class code of the car.
274 275 276 |
# File 'lib/stripe/services/payment_intent_service.rb', line 274 def car_class_code @car_class_code end |
#car_make ⇒ Object
Make of the car.
276 277 278 |
# File 'lib/stripe/services/payment_intent_service.rb', line 276 def car_make @car_make end |
#car_model ⇒ Object
Model of the car.
278 279 280 |
# File 'lib/stripe/services/payment_intent_service.rb', line 278 def car_model @car_model end |
#company ⇒ Object
The name of the rental car company.
280 281 282 |
# File 'lib/stripe/services/payment_intent_service.rb', line 280 def company @company end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
282 283 284 |
# File 'lib/stripe/services/payment_intent_service.rb', line 282 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object
Number of days the car is being rented.
284 285 286 |
# File 'lib/stripe/services/payment_intent_service.rb', line 284 def days_rented @days_rented end |
#delivery ⇒ Object
Delivery details for this purchase.
286 287 288 |
# File 'lib/stripe/services/payment_intent_service.rb', line 286 def delivery @delivery end |
#distance ⇒ Object
The details of the distance traveled during the rental period.
288 289 290 |
# File 'lib/stripe/services/payment_intent_service.rb', line 288 def distance @distance end |
#drivers ⇒ Object
The details of the passengers in the travel reservation
290 291 292 |
# File 'lib/stripe/services/payment_intent_service.rb', line 290 def drivers @drivers end |
#extra_charges ⇒ Object
List of additional charges being billed.
292 293 294 |
# File 'lib/stripe/services/payment_intent_service.rb', line 292 def extra_charges @extra_charges end |
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
294 295 296 |
# File 'lib/stripe/services/payment_intent_service.rb', line 294 def no_show @no_show end |
#pickup_address ⇒ Object
Car pick-up address.
296 297 298 |
# File 'lib/stripe/services/payment_intent_service.rb', line 296 def pickup_address @pickup_address end |
#pickup_at ⇒ Object
Car pick-up time. Measured in seconds since the Unix epoch.
298 299 300 |
# File 'lib/stripe/services/payment_intent_service.rb', line 298 def pickup_at @pickup_at end |
#pickup_location_name ⇒ Object
Name of the pickup location.
300 301 302 |
# File 'lib/stripe/services/payment_intent_service.rb', line 300 def pickup_location_name @pickup_location_name end |
#rate_amount ⇒ Object
Rental rate.
302 303 304 |
# File 'lib/stripe/services/payment_intent_service.rb', line 302 def rate_amount @rate_amount end |
#rate_interval ⇒ Object
The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`
304 305 306 |
# File 'lib/stripe/services/payment_intent_service.rb', line 304 def rate_interval @rate_interval end |
#renter_name ⇒ Object
The name of the person or entity renting the car.
306 307 308 |
# File 'lib/stripe/services/payment_intent_service.rb', line 306 def renter_name @renter_name end |
#return_address ⇒ Object
Car return address.
308 309 310 |
# File 'lib/stripe/services/payment_intent_service.rb', line 308 def return_address @return_address end |
#return_at ⇒ Object
Car return time. Measured in seconds since the Unix epoch.
310 311 312 |
# File 'lib/stripe/services/payment_intent_service.rb', line 310 def return_at @return_at end |
#return_location_name ⇒ Object
Name of the return location.
312 313 314 |
# File 'lib/stripe/services/payment_intent_service.rb', line 312 def return_location_name @return_location_name end |
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
314 315 316 |
# File 'lib/stripe/services/payment_intent_service.rb', line 314 def tax_exempt @tax_exempt end |
#vehicle_identification_number ⇒ Object
The vehicle identification number.
316 317 318 |
# File 'lib/stripe/services/payment_intent_service.rb', line 316 def vehicle_identification_number @vehicle_identification_number end |