Class: Stripe::PaymentIntentService::CreateParams::PaymentDetails::CarRental::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CreateParams::PaymentDetails::CarRental::Delivery::Recipient
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
317 318 319 320 321 |
# File 'lib/stripe/services/payment_intent_service.rb', line 317 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
311 312 313 |
# File 'lib/stripe/services/payment_intent_service.rb', line 311 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
313 314 315 |
# File 'lib/stripe/services/payment_intent_service.rb', line 313 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
315 316 317 |
# File 'lib/stripe/services/payment_intent_service.rb', line 315 def phone @phone end |