Class: Stripe::PaymentIntentService::CreateParams::PaymentDetails::EventDetails::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CreateParams::PaymentDetails::EventDetails::Delivery::Recipient
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
574 575 576 577 578 |
# File 'lib/stripe/services/payment_intent_service.rb', line 574 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
568 569 570 |
# File 'lib/stripe/services/payment_intent_service.rb', line 568 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
570 571 572 |
# File 'lib/stripe/services/payment_intent_service.rb', line 570 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
572 573 574 |
# File 'lib/stripe/services/payment_intent_service.rb', line 572 def phone @phone end |