Class: Stripe::PaymentIntentService::CreateParams::PaymentDetails::Flight
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CreateParams::PaymentDetails::Flight
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Passenger, Segment
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
-
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#segments ⇒ Object
The individual flight segments associated with the trip.
-
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
Instance Method Summary collapse
-
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
constructor
A new instance of Flight.
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
Returns a new instance of Flight.
579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 |
# File 'lib/stripe/services/payment_intent_service.rb', line 579 def initialize( affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil ) @affiliate = affiliate @agency_number = agency_number @carrier = carrier @delivery = delivery @passenger_name = passenger_name @passengers = passengers @segments = segments @ticket_number = ticket_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
563 564 565 |
# File 'lib/stripe/services/payment_intent_service.rb', line 563 def affiliate @affiliate end |
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
565 566 567 |
# File 'lib/stripe/services/payment_intent_service.rb', line 565 def agency_number @agency_number end |
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
567 568 569 |
# File 'lib/stripe/services/payment_intent_service.rb', line 567 def carrier @carrier end |
#delivery ⇒ Object
Delivery details for this purchase.
569 570 571 |
# File 'lib/stripe/services/payment_intent_service.rb', line 569 def delivery @delivery end |
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
571 572 573 |
# File 'lib/stripe/services/payment_intent_service.rb', line 571 def passenger_name @passenger_name end |
#passengers ⇒ Object
The details of the passengers in the travel reservation.
573 574 575 |
# File 'lib/stripe/services/payment_intent_service.rb', line 573 def passengers @passengers end |
#segments ⇒ Object
The individual flight segments associated with the trip.
575 576 577 |
# File 'lib/stripe/services/payment_intent_service.rb', line 575 def segments @segments end |
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
577 578 579 |
# File 'lib/stripe/services/payment_intent_service.rb', line 577 def ticket_number @ticket_number end |