Class: Stripe::PaymentIntentService::CreateParams::PaymentDetails::Flight::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



651
652
653
654
655
# File 'lib/stripe/services/payment_intent_service.rb', line 651

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



645
646
647
# File 'lib/stripe/services/payment_intent_service.rb', line 645

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



647
648
649
# File 'lib/stripe/services/payment_intent_service.rb', line 647

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



649
650
651
# File 'lib/stripe/services/payment_intent_service.rb', line 649

def phone
  @phone
end