Class: Stripe::PaymentIntentService::CreateParams::PaymentDetails::Lodging::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



803
804
805
806
807
# File 'lib/stripe/services/payment_intent_service.rb', line 803

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



797
798
799
# File 'lib/stripe/services/payment_intent_service.rb', line 797

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



799
800
801
# File 'lib/stripe/services/payment_intent_service.rb', line 799

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



801
802
803
# File 'lib/stripe/services/payment_intent_service.rb', line 801

def phone
  @phone
end