Class: Stripe::PaymentIntentService::CreateParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



1216
1217
1218
1219
1220
1221
1222
1223
1224
1225
1226
1227
1228
1229
1230
# File 'lib/stripe/services/payment_intent_service.rb', line 1216

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



1204
1205
1206
# File 'lib/stripe/services/payment_intent_service.rb', line 1204

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



1206
1207
1208
# File 'lib/stripe/services/payment_intent_service.rb', line 1206

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



1208
1209
1210
# File 'lib/stripe/services/payment_intent_service.rb', line 1208

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



1210
1211
1212
# File 'lib/stripe/services/payment_intent_service.rb', line 1210

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



1212
1213
1214
# File 'lib/stripe/services/payment_intent_service.rb', line 1212

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



1214
1215
1216
# File 'lib/stripe/services/payment_intent_service.rb', line 1214

def suffix
  @suffix
end