Class: Stripe::PaymentIntentService::CreateParams::PaymentMethodOptions::AcssDebit::MandateOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CreateParams::PaymentMethodOptions::AcssDebit::MandateOptions
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#custom_mandate_url ⇒ Object
A URL for custom mandate text to render during confirmation step.
-
#interval_description ⇒ Object
Description of the mandate interval.
-
#payment_schedule ⇒ Object
Payment schedule for the mandate.
-
#transaction_type ⇒ Object
Transaction type of the mandate.
Instance Method Summary collapse
-
#initialize(custom_mandate_url: nil, interval_description: nil, payment_schedule: nil, transaction_type: nil) ⇒ MandateOptions
constructor
A new instance of MandateOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(custom_mandate_url: nil, interval_description: nil, payment_schedule: nil, transaction_type: nil) ⇒ MandateOptions
Returns a new instance of MandateOptions.
1483 1484 1485 1486 1487 1488 1489 1490 1491 1492 1493 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1483 def initialize( custom_mandate_url: nil, interval_description: nil, payment_schedule: nil, transaction_type: nil ) @custom_mandate_url = custom_mandate_url @interval_description = interval_description @payment_schedule = payment_schedule @transaction_type = transaction_type end |
Instance Attribute Details
#custom_mandate_url ⇒ Object
A URL for custom mandate text to render during confirmation step. The URL will be rendered with additional GET parameters ‘payment_intent` and `payment_intent_client_secret` when confirming a Payment Intent, or `setup_intent` and `setup_intent_client_secret` when confirming a Setup Intent.
1475 1476 1477 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1475 def custom_mandate_url @custom_mandate_url end |
#interval_description ⇒ Object
Description of the mandate interval. Only required if ‘payment_schedule’ parameter is ‘interval’ or ‘combined’.
1477 1478 1479 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1477 def interval_description @interval_description end |
#payment_schedule ⇒ Object
Payment schedule for the mandate.
1479 1480 1481 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1479 def payment_schedule @payment_schedule end |
#transaction_type ⇒ Object
Transaction type of the mandate.
1481 1482 1483 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1481 def transaction_type @transaction_type end |