Class: Stripe::PaymentIntentService::CreateParams::PaymentMethodOptions::Card::Installments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Plan

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(enabled: nil, plan: nil) ⇒ Installments

Returns a new instance of Installments.



1781
1782
1783
1784
# File 'lib/stripe/services/payment_intent_service.rb', line 1781

def initialize(enabled: nil, plan: nil)
  @enabled = enabled
  @plan = plan
end

Instance Attribute Details

#enabledObject

Setting to true enables installments for this PaymentIntent. This will cause the response to contain a list of available installment plans. Setting to false will prevent any selected plan from applying to a charge.



1776
1777
1778
# File 'lib/stripe/services/payment_intent_service.rb', line 1776

def enabled
  @enabled
end

#planObject

The selected installment plan to use for this payment attempt. This parameter can only be provided during confirmation.



1779
1780
1781
# File 'lib/stripe/services/payment_intent_service.rb', line 1779

def plan
  @plan
end