Class: Stripe::PaymentIntentService::CreateParams::PaymentMethodOptions::Card::Installments::Plan

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(count: nil, interval: nil, type: nil) ⇒ Plan

Returns a new instance of Plan.



1916
1917
1918
1919
1920
# File 'lib/stripe/services/payment_intent_service.rb', line 1916

def initialize(count: nil, interval: nil, type: nil)
  @count = count
  @interval = interval
  @type = type
end

Instance Attribute Details

#countObject

For ‘fixed_count` installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.



1909
1910
1911
# File 'lib/stripe/services/payment_intent_service.rb', line 1909

def count
  @count
end

#intervalObject

For ‘fixed_count` installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of `month`.



1912
1913
1914
# File 'lib/stripe/services/payment_intent_service.rb', line 1912

def interval
  @interval
end

#typeObject

Type of installment plan, one of ‘fixed_count`, `bonus`, or `revolving`.



1914
1915
1916
# File 'lib/stripe/services/payment_intent_service.rb', line 1914

def type
  @type
end