Class: Stripe::PaymentIntentService::CreateParams::PaymentMethodOptions::Klarna::OnDemand

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(average_amount: nil, maximum_amount: nil, minimum_amount: nil, purchase_interval: nil, purchase_interval_count: nil) ⇒ OnDemand

Returns a new instance of OnDemand.



2471
2472
2473
2474
2475
2476
2477
2478
2479
2480
2481
2482
2483
# File 'lib/stripe/services/payment_intent_service.rb', line 2471

def initialize(
  average_amount: nil,
  maximum_amount: nil,
  minimum_amount: nil,
  purchase_interval: nil,
  purchase_interval_count: nil
)
  @average_amount = average_amount
  @maximum_amount = maximum_amount
  @minimum_amount = minimum_amount
  @purchase_interval = purchase_interval
  @purchase_interval_count = purchase_interval_count
end

Instance Attribute Details

#average_amountObject

Your average amount value. You can use a value across your customer base, or segment based on customer type, country, etc.



2461
2462
2463
# File 'lib/stripe/services/payment_intent_service.rb', line 2461

def average_amount
  @average_amount
end

#maximum_amountObject

The maximum value you may charge a customer per purchase. You can use a value across your customer base, or segment based on customer type, country, etc.



2463
2464
2465
# File 'lib/stripe/services/payment_intent_service.rb', line 2463

def maximum_amount
  @maximum_amount
end

#minimum_amountObject

The lowest or minimum value you may charge a customer per purchase. You can use a value across your customer base, or segment based on customer type, country, etc.



2465
2466
2467
# File 'lib/stripe/services/payment_intent_service.rb', line 2465

def minimum_amount
  @minimum_amount
end

#purchase_intervalObject

Interval at which the customer is making purchases



2467
2468
2469
# File 'lib/stripe/services/payment_intent_service.rb', line 2467

def purchase_interval
  @purchase_interval
end

#purchase_interval_countObject

The number of ‘purchase_interval` between charges



2469
2470
2471
# File 'lib/stripe/services/payment_intent_service.rb', line 2469

def purchase_interval_count
  @purchase_interval_count
end