Class: Stripe::PaymentIntentService::CreateParams::PaymentMethodOptions::Klarna::Subscription::NextBilling

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, date: nil) ⇒ NextBilling

Returns a new instance of NextBilling.



2493
2494
2495
2496
# File 'lib/stripe/services/payment_intent_service.rb', line 2493

def initialize(amount: nil, date: nil)
  @amount = amount
  @date = date
end

Instance Attribute Details

#amountObject

The amount of the next charge for the subscription.



2489
2490
2491
# File 'lib/stripe/services/payment_intent_service.rb', line 2489

def amount
  @amount
end

#dateObject

The date of the next charge for the subscription in YYYY-MM-DD format.



2491
2492
2493
# File 'lib/stripe/services/payment_intent_service.rb', line 2491

def date
  @date
end