Class: Stripe::PaymentIntentService::CreateParams::PaymentMethodOptions::Paypal

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: LineItem

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(capture_method: nil, line_items: nil, preferred_locale: nil, reference: nil, reference_id: nil, risk_correlation_id: nil, setup_future_usage: nil, subsellers: nil) ⇒ Paypal

Returns a new instance of Paypal.



2641
2642
2643
2644
2645
2646
2647
2648
2649
2650
2651
2652
2653
2654
2655
2656
2657
2658
2659
# File 'lib/stripe/services/payment_intent_service.rb', line 2641

def initialize(
  capture_method: nil,
  line_items: nil,
  preferred_locale: nil,
  reference: nil,
  reference_id: nil,
  risk_correlation_id: nil,
  setup_future_usage: nil,
  subsellers: nil
)
  @capture_method = capture_method
  @line_items = line_items
  @preferred_locale = preferred_locale
  @reference = reference
  @reference_id = reference_id
  @risk_correlation_id = risk_correlation_id
  @setup_future_usage = setup_future_usage
  @subsellers = subsellers
end

Instance Attribute Details

#capture_methodObject

Controls when the funds will be captured from the customer’s account.



2617
2618
2619
# File 'lib/stripe/services/payment_intent_service.rb', line 2617

def capture_method
  @capture_method
end

#line_itemsObject

The line items purchased by the customer.



2619
2620
2621
# File 'lib/stripe/services/payment_intent_service.rb', line 2619

def line_items
  @line_items
end

#preferred_localeObject

[Preferred locale](stripe.com/docs/payments/paypal/supported-locales) of the PayPal checkout page that the customer is redirected to.



2621
2622
2623
# File 'lib/stripe/services/payment_intent_service.rb', line 2621

def preferred_locale
  @preferred_locale
end

#referenceObject

A reference of the PayPal transaction visible to customer which is mapped to PayPal’s invoice ID. This must be a globally unique ID if you have configured in your PayPal settings to block multiple payments per invoice ID.



2623
2624
2625
# File 'lib/stripe/services/payment_intent_service.rb', line 2623

def reference
  @reference
end

#reference_idObject

A reference of the PayPal transaction visible to customer which is mapped to PayPal’s invoice ID. This must be a globally unique ID if you have configured in your PayPal settings to block multiple payments per invoice ID.



2625
2626
2627
# File 'lib/stripe/services/payment_intent_service.rb', line 2625

def reference_id
  @reference_id
end

#risk_correlation_idObject

The risk correlation ID for an on-session payment using a saved PayPal payment method.



2627
2628
2629
# File 'lib/stripe/services/payment_intent_service.rb', line 2627

def risk_correlation_id
  @risk_correlation_id
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent’s payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.

If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.

When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).

If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.



2637
2638
2639
# File 'lib/stripe/services/payment_intent_service.rb', line 2637

def setup_future_usage
  @setup_future_usage
end

#subsellersObject

The Stripe connected account IDs of the sellers on the platform for this transaction (optional). Only allowed when [separate charges and transfers](stripe.com/docs/connect/separate-charges-and-transfers) are used.



2639
2640
2641
# File 'lib/stripe/services/payment_intent_service.rb', line 2639

def subsellers
  @subsellers
end