Class: Stripe::PaymentIntentService::CreateParams::PaymentMethodOptions::Paypal::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem

Returns a new instance of LineItem.



2847
2848
2849
2850
2851
2852
2853
2854
2855
2856
2857
2858
2859
2860
2861
2862
2863
2864
2865
# File 'lib/stripe/services/payment_intent_service.rb', line 2847

def initialize(
  category: nil,
  description: nil,
  name: nil,
  quantity: nil,
  sku: nil,
  sold_by: nil,
  tax: nil,
  unit_amount: nil
)
  @category = category
  @description = description
  @name = name
  @quantity = quantity
  @sku = sku
  @sold_by = sold_by
  @tax = tax
  @unit_amount = unit_amount
end

Instance Attribute Details

#categoryObject

Type of the line item.



2831
2832
2833
# File 'lib/stripe/services/payment_intent_service.rb', line 2831

def category
  @category
end

#descriptionObject

Description of the line item.



2833
2834
2835
# File 'lib/stripe/services/payment_intent_service.rb', line 2833

def description
  @description
end

#nameObject

Descriptive name of the line item.



2835
2836
2837
# File 'lib/stripe/services/payment_intent_service.rb', line 2835

def name
  @name
end

#quantityObject

Quantity of the line item. Must be a positive number.



2837
2838
2839
# File 'lib/stripe/services/payment_intent_service.rb', line 2837

def quantity
  @quantity
end

#skuObject

Client facing stock keeping unit, article number or similar.



2839
2840
2841
# File 'lib/stripe/services/payment_intent_service.rb', line 2839

def sku
  @sku
end

#sold_byObject

The Stripe account ID of the connected account that sells the item.



2841
2842
2843
# File 'lib/stripe/services/payment_intent_service.rb', line 2841

def sold_by
  @sold_by
end

#taxObject

The tax information for the line item.



2843
2844
2845
# File 'lib/stripe/services/payment_intent_service.rb', line 2843

def tax
  @tax
end

#unit_amountObject

Price for a single unit of the line item in minor units. Cannot be a negative number.



2845
2846
2847
# File 'lib/stripe/services/payment_intent_service.rb', line 2845

def unit_amount
  @unit_amount
end