Class: Stripe::PaymentIntentService::CreateParams::PaymentMethodOptions::Paypal::LineItem::Tax
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CreateParams::PaymentMethodOptions::Paypal::LineItem::Tax
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The tax for a single unit of the line item in minor units.
-
#behavior ⇒ Object
The tax behavior for the line item.
Instance Method Summary collapse
-
#initialize(amount: nil, behavior: nil) ⇒ Tax
constructor
A new instance of Tax.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, behavior: nil) ⇒ Tax
Returns a new instance of Tax.
2672 2673 2674 2675 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2672 def initialize(amount: nil, behavior: nil) @amount = amount @behavior = behavior end |
Instance Attribute Details
#amount ⇒ Object
The tax for a single unit of the line item in minor units. Cannot be a negative number.
2668 2669 2670 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2668 def amount @amount end |
#behavior ⇒ Object
The tax behavior for the line item.
2670 2671 2672 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2670 def behavior @behavior end |