Class: Stripe::PaymentIntentService::CreateParams::PaymentMethodOptions::Pix::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, amount_includes_iof: nil, amount_type: nil, currency: nil, end_date: nil, payment_schedule: nil, reference: nil, start_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



2982
2983
2984
2985
2986
2987
2988
2989
2990
2991
2992
2993
2994
2995
2996
2997
2998
2999
3000
# File 'lib/stripe/services/payment_intent_service.rb', line 2982

def initialize(
  amount: nil,
  amount_includes_iof: nil,
  amount_type: nil,
  currency: nil,
  end_date: nil,
  payment_schedule: nil,
  reference: nil,
  start_date: nil
)
  @amount = amount
  @amount_includes_iof = amount_includes_iof
  @amount_type = amount_type
  @currency = currency
  @end_date = end_date
  @payment_schedule = payment_schedule
  @reference = reference
  @start_date = start_date
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments. Required when ‘amount_type=fixed`. If not provided for `amount_type=maximum`, defaults to 40000.



2966
2967
2968
# File 'lib/stripe/services/payment_intent_service.rb', line 2966

def amount
  @amount
end

#amount_includes_iofObject

Determines if the amount includes the IOF tax. Defaults to ‘never`.



2968
2969
2970
# File 'lib/stripe/services/payment_intent_service.rb', line 2968

def amount_includes_iof
  @amount_includes_iof
end

#amount_typeObject

Type of amount. Defaults to ‘maximum`.



2970
2971
2972
# File 'lib/stripe/services/payment_intent_service.rb', line 2970

def amount_type
  @amount_type
end

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Only ‘brl` is supported currently.



2972
2973
2974
# File 'lib/stripe/services/payment_intent_service.rb', line 2972

def currency
  @currency
end

#end_dateObject

Date when the mandate expires and no further payments will be charged, in ‘YYYY-MM-DD`. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.



2974
2975
2976
# File 'lib/stripe/services/payment_intent_service.rb', line 2974

def end_date
  @end_date
end

#payment_scheduleObject

Schedule at which the future payments will be charged. Defaults to ‘weekly`.



2976
2977
2978
# File 'lib/stripe/services/payment_intent_service.rb', line 2976

def payment_schedule
  @payment_schedule
end

#referenceObject

Subscription name displayed to buyers in their bank app. Defaults to the displayable business name.



2978
2979
2980
# File 'lib/stripe/services/payment_intent_service.rb', line 2978

def reference
  @reference
end

#start_dateObject

Start date of the mandate, in ‘YYYY-MM-DD`. Start date should be at least 3 days in the future. Defaults to 3 days after the current date.



2980
2981
2982
# File 'lib/stripe/services/payment_intent_service.rb', line 2980

def start_date
  @start_date
end