Class: Stripe::PaymentIntentService::CreateParams::PaymentMethodOptions::UsBankAccount::FinancialConnections

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Filters, ManualEntry

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections

Returns a new instance of FinancialConnections.



3275
3276
3277
3278
3279
3280
3281
3282
3283
3284
3285
3286
3287
# File 'lib/stripe/services/payment_intent_service.rb', line 3275

def initialize(
  filters: nil,
  manual_entry: nil,
  permissions: nil,
  prefetch: nil,
  return_url: nil
)
  @filters = filters
  @manual_entry = manual_entry
  @permissions = permissions
  @prefetch = prefetch
  @return_url = return_url
end

Instance Attribute Details

#filtersObject

Provide filters for the linked accounts that the customer can select for the payment method.



3265
3266
3267
# File 'lib/stripe/services/payment_intent_service.rb', line 3265

def filters
  @filters
end

#manual_entryObject

Customize manual entry behavior



3267
3268
3269
# File 'lib/stripe/services/payment_intent_service.rb', line 3267

def manual_entry
  @manual_entry
end

#permissionsObject

The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.



3269
3270
3271
# File 'lib/stripe/services/payment_intent_service.rb', line 3269

def permissions
  @permissions
end

#prefetchObject

List of data features that you would like to retrieve upon account creation.



3271
3272
3273
# File 'lib/stripe/services/payment_intent_service.rb', line 3271

def prefetch
  @prefetch
end

#return_urlObject

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



3273
3274
3275
# File 'lib/stripe/services/payment_intent_service.rb', line 3273

def return_url
  @return_url
end