Class: Stripe::PaymentIntentService::IncrementAuthorizationParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: AmountDetails, Hooks, PaymentDetails, PaymentMethodOptions, TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, amount_details: nil, application_fee_amount: nil, description: nil, expand: nil, hooks: nil, metadata: nil, payment_details: nil, payment_method_options: nil, statement_descriptor: nil, transfer_data: nil) ⇒ IncrementAuthorizationParams

Returns a new instance of IncrementAuthorizationParams.



12651
12652
12653
12654
12655
12656
12657
12658
12659
12660
12661
12662
12663
12664
12665
12666
12667
12668
12669
12670
12671
12672
12673
12674
12675
# File 'lib/stripe/services/payment_intent_service.rb', line 12651

def initialize(
  amount: nil,
  amount_details: nil,
  application_fee_amount: nil,
  description: nil,
  expand: nil,
  hooks: nil,
  metadata: nil,
  payment_details: nil,
  payment_method_options: nil,
  statement_descriptor: nil,
  transfer_data: nil
)
  @amount = amount
  @amount_details = amount_details
  @application_fee_amount = application_fee_amount
  @description = description
  @expand = expand
  @hooks = hooks
  @metadata = 
  @payment_details = payment_details
  @payment_method_options = payment_method_options
  @statement_descriptor = statement_descriptor
  @transfer_data = transfer_data
end

Instance Attribute Details

#amountObject

The updated total amount that you intend to collect from the cardholder. This amount must be greater than the currently authorized amount.



12628
12629
12630
# File 'lib/stripe/services/payment_intent_service.rb', line 12628

def amount
  @amount
end

#amount_detailsObject

Provides industry-specific information about the amount.



12630
12631
12632
# File 'lib/stripe/services/payment_intent_service.rb', line 12630

def amount_details
  @amount_details
end

#application_fee_amountObject

The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



12632
12633
12634
# File 'lib/stripe/services/payment_intent_service.rb', line 12632

def application_fee_amount
  @application_fee_amount
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



12634
12635
12636
# File 'lib/stripe/services/payment_intent_service.rb', line 12634

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



12636
12637
12638
# File 'lib/stripe/services/payment_intent_service.rb', line 12636

def expand
  @expand
end

#hooksObject

Automations to be run during the PaymentIntent lifecycle



12638
12639
12640
# File 'lib/stripe/services/payment_intent_service.rb', line 12638

def hooks
  @hooks
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



12640
12641
12642
# File 'lib/stripe/services/payment_intent_service.rb', line 12640

def 
  @metadata
end

#payment_detailsObject

Provides industry-specific information about the charge.



12642
12643
12644
# File 'lib/stripe/services/payment_intent_service.rb', line 12642

def payment_details
  @payment_details
end

#payment_method_optionsObject

Payment method-specific configuration for this PaymentIntent.



12644
12645
12646
# File 'lib/stripe/services/payment_intent_service.rb', line 12644

def payment_method_options
  @payment_method_options
end

#statement_descriptorObject

Text that appears on the customer’s statement as the statement descriptor for a non-card or card charge. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).



12646
12647
12648
# File 'lib/stripe/services/payment_intent_service.rb', line 12646

def statement_descriptor
  @statement_descriptor
end

#transfer_dataObject

The parameters used to automatically create a transfer after the payment is captured. Learn more about the [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



12649
12650
12651
# File 'lib/stripe/services/payment_intent_service.rb', line 12649

def transfer_data
  @transfer_data
end