Class: Stripe::PaymentIntentService::IncrementAuthorizationParams::AmountDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: LineItem, Shipping, Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discount_amount: nil, line_items: nil, shipping: nil, tax: nil) ⇒ AmountDetails

Returns a new instance of AmountDetails.



12557
12558
12559
12560
12561
12562
# File 'lib/stripe/services/payment_intent_service.rb', line 12557

def initialize(discount_amount: nil, line_items: nil, shipping: nil, tax: nil)
  @discount_amount = discount_amount
  @line_items = line_items
  @shipping = shipping
  @tax = tax
end

Instance Attribute Details

#discount_amountObject

The amount an item was discounted for.



12549
12550
12551
# File 'lib/stripe/services/payment_intent_service.rb', line 12549

def discount_amount
  @discount_amount
end

#line_itemsObject

A list of line items, each containing information about a product in the PaymentIntent. There is a maximum of 100 line items.



12551
12552
12553
# File 'lib/stripe/services/payment_intent_service.rb', line 12551

def line_items
  @line_items
end

#shippingObject

Contains information about the shipping portion of the amount.



12553
12554
12555
# File 'lib/stripe/services/payment_intent_service.rb', line 12553

def shipping
  @shipping
end

#taxObject

Contains information about the tax portion of the amount.



12555
12556
12557
# File 'lib/stripe/services/payment_intent_service.rb', line 12555

def tax
  @tax
end