Class: Stripe::PaymentIntentService::IncrementAuthorizationParams::AmountDetails::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::IncrementAuthorizationParams::AmountDetails::LineItem
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: PaymentMethodOptions, Tax
Instance Attribute Summary collapse
-
#discount_amount ⇒ Object
The amount an item was discounted for.
-
#payment_method_options ⇒ Object
Payment method-specific information for line items.
-
#product_code ⇒ Object
Unique identifier of the product.
-
#product_name ⇒ Object
Name of the product.
-
#quantity ⇒ Object
Number of items of the product.
-
#tax ⇒ Object
Contains information about the tax on the item.
-
#unit_cost ⇒ Object
Cost of the product.
-
#unit_of_measure ⇒ Object
A unit of measure for the line item, such as gallons, feet, meters, etc.
Instance Method Summary collapse
-
#initialize(discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil) ⇒ LineItem
Returns a new instance of LineItem.
12504 12505 12506 12507 12508 12509 12510 12511 12512 12513 12514 12515 12516 12517 12518 12519 12520 12521 12522 |
# File 'lib/stripe/services/payment_intent_service.rb', line 12504 def initialize( discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil ) @discount_amount = discount_amount @payment_method_options = @product_code = product_code @product_name = product_name @quantity = quantity @tax = tax @unit_cost = unit_cost @unit_of_measure = unit_of_measure end |
Instance Attribute Details
#discount_amount ⇒ Object
The amount an item was discounted for. Positive integer.
12488 12489 12490 |
# File 'lib/stripe/services/payment_intent_service.rb', line 12488 def discount_amount @discount_amount end |
#payment_method_options ⇒ Object
Payment method-specific information for line items.
12490 12491 12492 |
# File 'lib/stripe/services/payment_intent_service.rb', line 12490 def @payment_method_options end |
#product_code ⇒ Object
Unique identifier of the product. At most 12 characters long.
12492 12493 12494 |
# File 'lib/stripe/services/payment_intent_service.rb', line 12492 def product_code @product_code end |
#product_name ⇒ Object
Name of the product. At most 100 characters long.
12494 12495 12496 |
# File 'lib/stripe/services/payment_intent_service.rb', line 12494 def product_name @product_name end |
#quantity ⇒ Object
Number of items of the product. Positive integer.
12496 12497 12498 |
# File 'lib/stripe/services/payment_intent_service.rb', line 12496 def quantity @quantity end |
#tax ⇒ Object
Contains information about the tax on the item.
12498 12499 12500 |
# File 'lib/stripe/services/payment_intent_service.rb', line 12498 def tax @tax end |
#unit_cost ⇒ Object
Cost of the product. Non-negative integer.
12500 12501 12502 |
# File 'lib/stripe/services/payment_intent_service.rb', line 12500 def unit_cost @unit_cost end |
#unit_of_measure ⇒ Object
A unit of measure for the line item, such as gallons, feet, meters, etc.
12502 12503 12504 |
# File 'lib/stripe/services/payment_intent_service.rb', line 12502 def unit_of_measure @unit_of_measure end |