Class: Stripe::PaymentIntentService::IncrementAuthorizationParams::AmountDetails::LineItem::PaymentMethodOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Card, CardPresent, Klarna, Paypal

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(card: nil, card_present: nil, klarna: nil, paypal: nil) ⇒ PaymentMethodOptions

Returns a new instance of PaymentMethodOptions.



12471
12472
12473
12474
12475
12476
# File 'lib/stripe/services/payment_intent_service.rb', line 12471

def initialize(card: nil, card_present: nil, klarna: nil, paypal: nil)
  @card = card
  @card_present = card_present
  @klarna = klarna
  @paypal = paypal
end

Instance Attribute Details

#cardObject

This sub-hash contains line item details that are specific to ‘card` payment method.“



12463
12464
12465
# File 'lib/stripe/services/payment_intent_service.rb', line 12463

def card
  @card
end

#card_presentObject

This sub-hash contains line item details that are specific to ‘card_present` payment method.“



12465
12466
12467
# File 'lib/stripe/services/payment_intent_service.rb', line 12465

def card_present
  @card_present
end

#klarnaObject

This sub-hash contains line item details that are specific to ‘klarna` payment method.“



12467
12468
12469
# File 'lib/stripe/services/payment_intent_service.rb', line 12467

def klarna
  @klarna
end

#paypalObject

This sub-hash contains line item details that are specific to ‘paypal` payment method.“



12469
12470
12471
# File 'lib/stripe/services/payment_intent_service.rb', line 12469

def paypal
  @paypal
end