Class: Stripe::PaymentIntentService::IncrementAuthorizationParams::AmountDetails::Tax
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::IncrementAuthorizationParams::AmountDetails::Tax
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#total_tax_amount ⇒ Object
Total portion of the amount that is for tax.
Instance Method Summary collapse
-
#initialize(total_tax_amount: nil) ⇒ Tax
constructor
A new instance of Tax.
Methods inherited from RequestParams
Constructor Details
#initialize(total_tax_amount: nil) ⇒ Tax
Returns a new instance of Tax.
12544 12545 12546 |
# File 'lib/stripe/services/payment_intent_service.rb', line 12544 def initialize(total_tax_amount: nil) @total_tax_amount = total_tax_amount end |
Instance Attribute Details
#total_tax_amount ⇒ Object
Total portion of the amount that is for tax.
12542 12543 12544 |
# File 'lib/stripe/services/payment_intent_service.rb', line 12542 def total_tax_amount @total_tax_amount end |