Class: Stripe::PaymentIntentService::IncrementAuthorizationParams::PaymentDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(customer_reference: nil, order_reference: nil) ⇒ PaymentDetails

Returns a new instance of PaymentDetails.



12596
12597
12598
12599
# File 'lib/stripe/services/payment_intent_service.rb', line 12596

def initialize(customer_reference: nil, order_reference: nil)
  @customer_reference = customer_reference
  @order_reference = order_reference
end

Instance Attribute Details

#customer_referenceObject

Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.



12592
12593
12594
# File 'lib/stripe/services/payment_intent_service.rb', line 12592

def customer_reference
  @customer_reference
end

#order_referenceObject

A unique value assigned by the business to identify the transaction.



12594
12595
12596
# File 'lib/stripe/services/payment_intent_service.rb', line 12594

def order_reference
  @order_reference
end