Class: Stripe::PaymentIntentService::IncrementAuthorizationParams::PaymentMethodOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::IncrementAuthorizationParams::PaymentMethodOptions
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Card
Instance Attribute Summary collapse
-
#card ⇒ Object
Configuration for any card payments attempted on this PaymentIntent.
Instance Method Summary collapse
-
#initialize(card: nil) ⇒ PaymentMethodOptions
constructor
A new instance of PaymentMethodOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(card: nil) ⇒ PaymentMethodOptions
Returns a new instance of PaymentMethodOptions.
12460 12461 12462 |
# File 'lib/stripe/services/payment_intent_service.rb', line 12460 def initialize(card: nil) @card = card end |
Instance Attribute Details
#card ⇒ Object
Configuration for any card payments attempted on this PaymentIntent.
12458 12459 12460 |
# File 'lib/stripe/services/payment_intent_service.rb', line 12458 def card @card end |