Class: Stripe::PaymentIntentService::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(created: nil, customer: nil, customer_account: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
# File 'lib/stripe/services/payment_intent_service.rb', line 39

def initialize(
  created: nil,
  customer: nil,
  customer_account: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  starting_after: nil
)
  @created = created
  @customer = customer
  @customer_account = 
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
end

Instance Attribute Details

#createdObject

A filter on the list, based on the object ‘created` field. The value can be a string with an integer Unix timestamp or a dictionary with a number of different query options.



25
26
27
# File 'lib/stripe/services/payment_intent_service.rb', line 25

def created
  @created
end

#customerObject

Only return PaymentIntents for the customer that this customer ID specifies.



27
28
29
# File 'lib/stripe/services/payment_intent_service.rb', line 27

def customer
  @customer
end

#customer_accountObject

Only return PaymentIntents for the account that this ID specifies.



29
30
31
# File 'lib/stripe/services/payment_intent_service.rb', line 29

def 
  @customer_account
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



31
32
33
# File 'lib/stripe/services/payment_intent_service.rb', line 31

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



33
34
35
# File 'lib/stripe/services/payment_intent_service.rb', line 33

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



35
36
37
# File 'lib/stripe/services/payment_intent_service.rb', line 35

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



37
38
39
# File 'lib/stripe/services/payment_intent_service.rb', line 37

def starting_after
  @starting_after
end