Class: Stripe::PaymentIntentService::RetrieveParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(client_secret: nil, expand: nil) ⇒ RetrieveParams

Returns a new instance of RetrieveParams.



2510
2511
2512
2513
# File 'lib/stripe/services/payment_intent_service.rb', line 2510

def initialize(client_secret: nil, expand: nil)
  @client_secret = client_secret
  @expand = expand
end

Instance Attribute Details

#client_secretObject

The client secret of the PaymentIntent. We require it if you use a publishable key to retrieve the source.



2506
2507
2508
# File 'lib/stripe/services/payment_intent_service.rb', line 2506

def client_secret
  @client_secret
end

#expandObject

Specifies which fields in the response should be expanded.



2508
2509
2510
# File 'lib/stripe/services/payment_intent_service.rb', line 2508

def expand
  @expand
end