Class: Stripe::PaymentIntentService::SearchParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::SearchParams
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#page ⇒ Object
A cursor for pagination across multiple pages of results.
-
#query ⇒ Object
The search query string.
Instance Method Summary collapse
-
#initialize(expand: nil, limit: nil, page: nil, query: nil) ⇒ SearchParams
constructor
A new instance of SearchParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, limit: nil, page: nil, query: nil) ⇒ SearchParams
Returns a new instance of SearchParams.
7643 7644 7645 7646 7647 7648 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7643 def initialize(expand: nil, limit: nil, page: nil, query: nil) @expand = @limit = limit @page = page @query = query end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
7635 7636 7637 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7635 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
7637 7638 7639 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7637 def limit @limit end |
#page ⇒ Object
A cursor for pagination across multiple pages of results. Don’t include this parameter on the first call. Use the next_page value returned in a previous response to request subsequent results.
7639 7640 7641 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7639 def page @page end |
#query ⇒ Object
The search query string. See [search query language](stripe.com/docs/search#search-query-language) and the list of supported [query fields for payment intents](stripe.com/docs/search#query-fields-for-payment-intents).
7641 7642 7643 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7641 def query @query end |