Class: Stripe::PaymentIntentService::TriggerActionParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::TriggerActionParams
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: ScanQrCode
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#scan_qr_code ⇒ Object
True to simulate success, false to simulate failure.
-
#type ⇒ Object
The type of action to be simulated.
Instance Method Summary collapse
-
#initialize(expand: nil, scan_qr_code: nil, type: nil) ⇒ TriggerActionParams
constructor
A new instance of TriggerActionParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, scan_qr_code: nil, type: nil) ⇒ TriggerActionParams
Returns a new instance of TriggerActionParams.
12709 12710 12711 12712 12713 |
# File 'lib/stripe/services/payment_intent_service.rb', line 12709 def initialize(expand: nil, scan_qr_code: nil, type: nil) @expand = @scan_qr_code = scan_qr_code @type = type end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
12703 12704 12705 |
# File 'lib/stripe/services/payment_intent_service.rb', line 12703 def @expand end |
#scan_qr_code ⇒ Object
True to simulate success, false to simulate failure.
12705 12706 12707 |
# File 'lib/stripe/services/payment_intent_service.rb', line 12705 def scan_qr_code @scan_qr_code end |
#type ⇒ Object
The type of action to be simulated.
12707 12708 12709 |
# File 'lib/stripe/services/payment_intent_service.rb', line 12707 def type @type end |