Class: Stripe::PaymentIntentService::UpdateParams::AmountDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: LineItem, Shipping, Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discount_amount: nil, line_items: nil, shipping: nil, tax: nil) ⇒ AmountDetails

Returns a new instance of AmountDetails.



3997
3998
3999
4000
4001
4002
# File 'lib/stripe/services/payment_intent_service.rb', line 3997

def initialize(discount_amount: nil, line_items: nil, shipping: nil, tax: nil)
  @discount_amount = discount_amount
  @line_items = line_items
  @shipping = shipping
  @tax = tax
end

Instance Attribute Details

#discount_amountObject

The amount an item was discounted for.



3989
3990
3991
# File 'lib/stripe/services/payment_intent_service.rb', line 3989

def discount_amount
  @discount_amount
end

#line_itemsObject

A list of line items, each containing information about a product in the PaymentIntent. There is a maximum of 100 line items.



3991
3992
3993
# File 'lib/stripe/services/payment_intent_service.rb', line 3991

def line_items
  @line_items
end

#shippingObject

Contains information about the shipping portion of the amount.



3993
3994
3995
# File 'lib/stripe/services/payment_intent_service.rb', line 3993

def shipping
  @shipping
end

#taxObject

Contains information about the tax portion of the amount.



3995
3996
3997
# File 'lib/stripe/services/payment_intent_service.rb', line 3995

def tax
  @tax
end