Class: Stripe::PaymentIntentService::UpdateParams::AmountDetails::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::AmountDetails::LineItem
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: PaymentMethodOptions, Tax
Instance Attribute Summary collapse
-
#discount_amount ⇒ Object
The amount an item was discounted for.
-
#payment_method_options ⇒ Object
Payment method-specific information for line items.
-
#product_code ⇒ Object
Unique identifier of the product.
-
#product_name ⇒ Object
Name of the product.
-
#quantity ⇒ Object
Number of items of the product.
-
#tax ⇒ Object
Contains information about the tax on the item.
-
#unit_cost ⇒ Object
Cost of the product.
-
#unit_of_measure ⇒ Object
A unit of measure for the line item, such as gallons, feet, meters, etc.
Instance Method Summary collapse
-
#initialize(discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil) ⇒ LineItem
Returns a new instance of LineItem.
3998 3999 4000 4001 4002 4003 4004 4005 4006 4007 4008 4009 4010 4011 4012 4013 4014 4015 4016 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3998 def initialize( discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil ) @discount_amount = discount_amount @payment_method_options = @product_code = product_code @product_name = product_name @quantity = quantity @tax = tax @unit_cost = unit_cost @unit_of_measure = unit_of_measure end |
Instance Attribute Details
#discount_amount ⇒ Object
The amount an item was discounted for. Positive integer.
3982 3983 3984 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3982 def discount_amount @discount_amount end |
#payment_method_options ⇒ Object
Payment method-specific information for line items.
3984 3985 3986 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3984 def @payment_method_options end |
#product_code ⇒ Object
Unique identifier of the product. At most 12 characters long.
3986 3987 3988 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3986 def product_code @product_code end |
#product_name ⇒ Object
Name of the product. At most 100 characters long.
3988 3989 3990 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3988 def product_name @product_name end |
#quantity ⇒ Object
Number of items of the product. Positive integer.
3990 3991 3992 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3990 def quantity @quantity end |
#tax ⇒ Object
Contains information about the tax on the item.
3992 3993 3994 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3992 def tax @tax end |
#unit_cost ⇒ Object
Cost of the product. Non-negative integer.
3994 3995 3996 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3994 def unit_cost @unit_cost end |
#unit_of_measure ⇒ Object
A unit of measure for the line item, such as gallons, feet, meters, etc.
3996 3997 3998 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3996 def unit_of_measure @unit_of_measure end |