Class: Stripe::PaymentIntentService::UpdateParams::AmountDetails::LineItem::PaymentMethodOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Card, CardPresent, Klarna, Paypal

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(card: nil, card_present: nil, klarna: nil, paypal: nil) ⇒ PaymentMethodOptions

Returns a new instance of PaymentMethodOptions.



3965
3966
3967
3968
3969
3970
# File 'lib/stripe/services/payment_intent_service.rb', line 3965

def initialize(card: nil, card_present: nil, klarna: nil, paypal: nil)
  @card = card
  @card_present = card_present
  @klarna = klarna
  @paypal = paypal
end

Instance Attribute Details

#cardObject

This sub-hash contains line item details that are specific to ‘card` payment method.“



3957
3958
3959
# File 'lib/stripe/services/payment_intent_service.rb', line 3957

def card
  @card
end

#card_presentObject

This sub-hash contains line item details that are specific to ‘card_present` payment method.“



3959
3960
3961
# File 'lib/stripe/services/payment_intent_service.rb', line 3959

def card_present
  @card_present
end

#klarnaObject

This sub-hash contains line item details that are specific to ‘klarna` payment method.“



3961
3962
3963
# File 'lib/stripe/services/payment_intent_service.rb', line 3961

def klarna
  @klarna
end

#paypalObject

This sub-hash contains line item details that are specific to ‘paypal` payment method.“



3963
3964
3965
# File 'lib/stripe/services/payment_intent_service.rb', line 3963

def paypal
  @paypal
end