Class: Stripe::PaymentIntentService::UpdateParams::MandateData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::MandateData
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: CustomerAcceptance
Instance Attribute Summary collapse
-
#customer_acceptance ⇒ Object
This hash contains details about the customer acceptance of the Mandate.
Instance Method Summary collapse
-
#initialize(customer_acceptance: nil) ⇒ MandateData
constructor
A new instance of MandateData.
Methods inherited from RequestParams
Constructor Details
#initialize(customer_acceptance: nil) ⇒ MandateData
Returns a new instance of MandateData.
3746 3747 3748 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3746 def initialize(customer_acceptance: nil) @customer_acceptance = customer_acceptance end |
Instance Attribute Details
#customer_acceptance ⇒ Object
This hash contains details about the customer acceptance of the Mandate.
3744 3745 3746 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3744 def customer_acceptance @customer_acceptance end |