Class: Stripe::PaymentIntentService::UpdateParams::PaymentDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: CarRental, EventDetails, Flight, Lodging, Subscription

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails

Returns a new instance of PaymentDetails.



4801
4802
4803
4804
4805
4806
4807
4808
4809
4810
4811
4812
4813
4814
4815
4816
4817
# File 'lib/stripe/services/payment_intent_service.rb', line 4801

def initialize(
  car_rental: nil,
  customer_reference: nil,
  event_details: nil,
  flight: nil,
  lodging: nil,
  order_reference: nil,
  subscription: nil
)
  @car_rental = car_rental
  @customer_reference = customer_reference
  @event_details = event_details
  @flight = flight
  @lodging = lodging
  @order_reference = order_reference
  @subscription = subscription
end

Instance Attribute Details

#car_rentalObject

Car rental details for this PaymentIntent.



4787
4788
4789
# File 'lib/stripe/services/payment_intent_service.rb', line 4787

def car_rental
  @car_rental
end

#customer_referenceObject

Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.



4789
4790
4791
# File 'lib/stripe/services/payment_intent_service.rb', line 4789

def customer_reference
  @customer_reference
end

#event_detailsObject

Event details for this PaymentIntent



4791
4792
4793
# File 'lib/stripe/services/payment_intent_service.rb', line 4791

def event_details
  @event_details
end

#flightObject

Flight reservation details for this PaymentIntent



4793
4794
4795
# File 'lib/stripe/services/payment_intent_service.rb', line 4793

def flight
  @flight
end

#lodgingObject

Lodging reservation details for this PaymentIntent



4795
4796
4797
# File 'lib/stripe/services/payment_intent_service.rb', line 4795

def lodging
  @lodging
end

#order_referenceObject

A unique value assigned by the business to identify the transaction.



4797
4798
4799
# File 'lib/stripe/services/payment_intent_service.rb', line 4797

def order_reference
  @order_reference
end

#subscriptionObject

Subscription details for this PaymentIntent



4799
4800
4801
# File 'lib/stripe/services/payment_intent_service.rb', line 4799

def subscription
  @subscription
end