Class: Stripe::PaymentIntentService::UpdateParams::PaymentDetails::CarRental

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Affiliate, Delivery, Distance, Driver, PickupAddress, ReturnAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil) ⇒ CarRental

Returns a new instance of CarRental.



4289
4290
4291
4292
4293
4294
4295
4296
4297
4298
4299
4300
4301
4302
4303
4304
4305
4306
4307
4308
4309
4310
4311
4312
4313
4314
4315
4316
4317
4318
4319
4320
4321
4322
4323
4324
4325
4326
4327
4328
4329
4330
4331
4332
4333
4334
4335
4336
4337
4338
4339
# File 'lib/stripe/services/payment_intent_service.rb', line 4289

def initialize(
  affiliate: nil,
  booking_number: nil,
  car_class_code: nil,
  car_make: nil,
  car_model: nil,
  company: nil,
  customer_service_phone_number: nil,
  days_rented: nil,
  delivery: nil,
  distance: nil,
  drivers: nil,
  extra_charges: nil,
  no_show: nil,
  pickup_address: nil,
  pickup_at: nil,
  pickup_location_name: nil,
  rate_amount: nil,
  rate_interval: nil,
  renter_name: nil,
  return_address: nil,
  return_at: nil,
  return_location_name: nil,
  tax_exempt: nil,
  vehicle_identification_number: nil
)
  @affiliate = affiliate
  @booking_number = booking_number
  @car_class_code = car_class_code
  @car_make = car_make
  @car_model = car_model
  @company = company
  @customer_service_phone_number = customer_service_phone_number
  @days_rented = days_rented
  @delivery = delivery
  @distance = distance
  @drivers = drivers
  @extra_charges = extra_charges
  @no_show = no_show
  @pickup_address = pickup_address
  @pickup_at = pickup_at
  @pickup_location_name = pickup_location_name
  @rate_amount = rate_amount
  @rate_interval = rate_interval
  @renter_name = renter_name
  @return_address = return_address
  @return_at = return_at
  @return_location_name = return_location_name
  @tax_exempt = tax_exempt
  @vehicle_identification_number = vehicle_identification_number
end

Instance Attribute Details

#affiliateObject

Affiliate details for this purchase.



4241
4242
4243
# File 'lib/stripe/services/payment_intent_service.rb', line 4241

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the car rental.



4243
4244
4245
# File 'lib/stripe/services/payment_intent_service.rb', line 4243

def booking_number
  @booking_number
end

#car_class_codeObject

Class code of the car.



4245
4246
4247
# File 'lib/stripe/services/payment_intent_service.rb', line 4245

def car_class_code
  @car_class_code
end

#car_makeObject

Make of the car.



4247
4248
4249
# File 'lib/stripe/services/payment_intent_service.rb', line 4247

def car_make
  @car_make
end

#car_modelObject

Model of the car.



4249
4250
4251
# File 'lib/stripe/services/payment_intent_service.rb', line 4249

def car_model
  @car_model
end

#companyObject

The name of the rental car company.



4251
4252
4253
# File 'lib/stripe/services/payment_intent_service.rb', line 4251

def company
  @company
end

#customer_service_phone_numberObject

The customer service phone number of the car rental company.



4253
4254
4255
# File 'lib/stripe/services/payment_intent_service.rb', line 4253

def customer_service_phone_number
  @customer_service_phone_number
end

#days_rentedObject

Number of days the car is being rented.



4255
4256
4257
# File 'lib/stripe/services/payment_intent_service.rb', line 4255

def days_rented
  @days_rented
end

#deliveryObject

Delivery details for this purchase.



4257
4258
4259
# File 'lib/stripe/services/payment_intent_service.rb', line 4257

def delivery
  @delivery
end

#distanceObject

The details of the distance traveled during the rental period.



4259
4260
4261
# File 'lib/stripe/services/payment_intent_service.rb', line 4259

def distance
  @distance
end

#driversObject

The details of the passengers in the travel reservation



4261
4262
4263
# File 'lib/stripe/services/payment_intent_service.rb', line 4261

def drivers
  @drivers
end

#extra_chargesObject

List of additional charges being billed.



4263
4264
4265
# File 'lib/stripe/services/payment_intent_service.rb', line 4263

def extra_charges
  @extra_charges
end

#no_showObject

Indicates if the customer did not keep nor cancel their booking.



4265
4266
4267
# File 'lib/stripe/services/payment_intent_service.rb', line 4265

def no_show
  @no_show
end

#pickup_addressObject

Car pick-up address.



4267
4268
4269
# File 'lib/stripe/services/payment_intent_service.rb', line 4267

def pickup_address
  @pickup_address
end

#pickup_atObject

Car pick-up time. Measured in seconds since the Unix epoch.



4269
4270
4271
# File 'lib/stripe/services/payment_intent_service.rb', line 4269

def pickup_at
  @pickup_at
end

#pickup_location_nameObject

Name of the pickup location.



4271
4272
4273
# File 'lib/stripe/services/payment_intent_service.rb', line 4271

def pickup_location_name
  @pickup_location_name
end

#rate_amountObject

Rental rate.



4273
4274
4275
# File 'lib/stripe/services/payment_intent_service.rb', line 4273

def rate_amount
  @rate_amount
end

#rate_intervalObject

The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`



4275
4276
4277
# File 'lib/stripe/services/payment_intent_service.rb', line 4275

def rate_interval
  @rate_interval
end

#renter_nameObject

The name of the person or entity renting the car.



4277
4278
4279
# File 'lib/stripe/services/payment_intent_service.rb', line 4277

def renter_name
  @renter_name
end

#return_addressObject

Car return address.



4279
4280
4281
# File 'lib/stripe/services/payment_intent_service.rb', line 4279

def return_address
  @return_address
end

#return_atObject

Car return time. Measured in seconds since the Unix epoch.



4281
4282
4283
# File 'lib/stripe/services/payment_intent_service.rb', line 4281

def return_at
  @return_at
end

#return_location_nameObject

Name of the return location.



4283
4284
4285
# File 'lib/stripe/services/payment_intent_service.rb', line 4283

def return_location_name
  @return_location_name
end

#tax_exemptObject

Indicates whether the goods or services are tax-exempt or tax is not collected.



4285
4286
4287
# File 'lib/stripe/services/payment_intent_service.rb', line 4285

def tax_exempt
  @tax_exempt
end

#vehicle_identification_numberObject

The vehicle identification number.



4287
4288
4289
# File 'lib/stripe/services/payment_intent_service.rb', line 4287

def vehicle_identification_number
  @vehicle_identification_number
end