Class: Stripe::PaymentIntentService::UpdateParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
4427 4428 4429 4430 4431 4432 4433 4434 4435 4436 4437 4438 4439 4440 4441 4442 4443 4444 4445 4446 4447 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4427 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
4409 4410 4411 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4409 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
4411 4412 4413 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4411 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
4413 4414 4415 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4413 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
4415 4416 4417 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4415 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
4417 4418 4419 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4417 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
4419 4420 4421 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4419 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
4421 4422 4423 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4421 def genre @genre end |
#name ⇒ Object
The name of the event.
4423 4424 4425 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4423 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
4425 4426 4427 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4425 def starts_at @starts_at end |