Class: Stripe::PaymentIntentService::UpdateParams::PaymentDetails::EventDetails::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



4392
4393
4394
4395
4396
# File 'lib/stripe/services/payment_intent_service.rb', line 4392

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



4386
4387
4388
# File 'lib/stripe/services/payment_intent_service.rb', line 4386

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



4388
4389
4390
# File 'lib/stripe/services/payment_intent_service.rb', line 4388

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



4390
4391
4392
# File 'lib/stripe/services/payment_intent_service.rb', line 4390

def phone
  @phone
end