Class: Stripe::PaymentIntentService::UpdateParams::PaymentDetails::Flight
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentDetails::Flight
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Passenger, Segment
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
-
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#segments ⇒ Object
The individual flight segments associated with the trip.
-
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
Instance Method Summary collapse
-
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
constructor
A new instance of Flight.
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
Returns a new instance of Flight.
4496 4497 4498 4499 4500 4501 4502 4503 4504 4505 4506 4507 4508 4509 4510 4511 4512 4513 4514 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4496 def initialize( affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil ) @affiliate = affiliate @agency_number = agency_number @carrier = carrier @delivery = delivery @passenger_name = passenger_name @passengers = passengers @segments = segments @ticket_number = ticket_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
4480 4481 4482 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4480 def affiliate @affiliate end |
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
4482 4483 4484 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4482 def agency_number @agency_number end |
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
4484 4485 4486 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4484 def carrier @carrier end |
#delivery ⇒ Object
Delivery details for this purchase.
4486 4487 4488 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4486 def delivery @delivery end |
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
4488 4489 4490 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4488 def passenger_name @passenger_name end |
#passengers ⇒ Object
The details of the passengers in the travel reservation.
4490 4491 4492 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4490 def passengers @passengers end |
#segments ⇒ Object
The individual flight segments associated with the trip.
4492 4493 4494 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4492 def segments @segments end |
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
4494 4495 4496 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4494 def ticket_number @ticket_number end |