Class: Stripe::PaymentIntentService::UpdateParams::PaymentDetails::Flight::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



4469
4470
4471
4472
4473
# File 'lib/stripe/services/payment_intent_service.rb', line 4469

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



4463
4464
4465
# File 'lib/stripe/services/payment_intent_service.rb', line 4463

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



4465
4466
4467
# File 'lib/stripe/services/payment_intent_service.rb', line 4465

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



4467
4468
4469
# File 'lib/stripe/services/payment_intent_service.rb', line 4467

def phone
  @phone
end