Class: Stripe::PaymentIntentService::UpdateParams::PaymentDetails::Lodging::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



4257
4258
4259
4260
4261
# File 'lib/stripe/services/payment_intent_service.rb', line 4257

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



4251
4252
4253
# File 'lib/stripe/services/payment_intent_service.rb', line 4251

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



4253
4254
4255
# File 'lib/stripe/services/payment_intent_service.rb', line 4253

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



4255
4256
4257
# File 'lib/stripe/services/payment_intent_service.rb', line 4255

def phone
  @phone
end