Class: Stripe::PaymentIntentService::UpdateParams::PaymentDetails::Subscription::BillingInterval

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(count: nil, interval: nil) ⇒ BillingInterval

Returns a new instance of BillingInterval.



4752
4753
4754
4755
# File 'lib/stripe/services/payment_intent_service.rb', line 4752

def initialize(count: nil, interval: nil)
  @count = count
  @interval = interval
end

Instance Attribute Details

#countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



4748
4749
4750
# File 'lib/stripe/services/payment_intent_service.rb', line 4748

def count
  @count
end

#intervalObject

Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.



4750
4751
4752
# File 'lib/stripe/services/payment_intent_service.rb', line 4750

def interval
  @interval
end