Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodData::NaverPay
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentMethodData::NaverPay
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#funding ⇒ Object
Whether to use Naver Pay points or a card to fund this transaction.
Instance Method Summary collapse
-
#initialize(funding: nil) ⇒ NaverPay
constructor
A new instance of NaverPay.
Methods inherited from RequestParams
Constructor Details
#initialize(funding: nil) ⇒ NaverPay
Returns a new instance of NaverPay.
2701 2702 2703 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2701 def initialize(funding: nil) @funding = funding end |
Instance Attribute Details
#funding ⇒ Object
Whether to use Naver Pay points or a card to fund this transaction. If not provided, this defaults to ‘card`.
2699 2700 2701 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2699 def funding @funding end |