Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



5034
5035
5036
5037
5038
5039
5040
5041
5042
5043
5044
5045
5046
5047
5048
# File 'lib/stripe/services/payment_intent_service.rb', line 5034

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



5022
5023
5024
# File 'lib/stripe/services/payment_intent_service.rb', line 5022

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



5024
5025
5026
# File 'lib/stripe/services/payment_intent_service.rb', line 5024

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



5026
5027
5028
# File 'lib/stripe/services/payment_intent_service.rb', line 5026

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



5028
5029
5030
# File 'lib/stripe/services/payment_intent_service.rb', line 5028

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



5030
5031
5032
# File 'lib/stripe/services/payment_intent_service.rb', line 5030

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



5032
5033
5034
# File 'lib/stripe/services/payment_intent_service.rb', line 5032

def suffix
  @suffix
end