Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions::Card::Installments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Plan

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(enabled: nil, plan: nil) ⇒ Installments

Returns a new instance of Installments.



3348
3349
3350
3351
# File 'lib/stripe/services/payment_intent_service.rb', line 3348

def initialize(enabled: nil, plan: nil)
  @enabled = enabled
  @plan = plan
end

Instance Attribute Details

#enabledObject

Setting to true enables installments for this PaymentIntent. This will cause the response to contain a list of available installment plans. Setting to false will prevent any selected plan from applying to a charge.



3343
3344
3345
# File 'lib/stripe/services/payment_intent_service.rb', line 3343

def enabled
  @enabled
end

#planObject

The selected installment plan to use for this payment attempt. This parameter can only be provided during confirmation.



3346
3347
3348
# File 'lib/stripe/services/payment_intent_service.rb', line 3346

def plan
  @plan
end