Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions::Card::Installments::Plan

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(count: nil, interval: nil, type: nil) ⇒ Plan

Returns a new instance of Plan.



3334
3335
3336
3337
3338
# File 'lib/stripe/services/payment_intent_service.rb', line 3334

def initialize(count: nil, interval: nil, type: nil)
  @count = count
  @interval = interval
  @type = type
end

Instance Attribute Details

#countObject

For ‘fixed_count` installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.



3327
3328
3329
# File 'lib/stripe/services/payment_intent_service.rb', line 3327

def count
  @count
end

#intervalObject

For ‘fixed_count` installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of `month`.



3330
3331
3332
# File 'lib/stripe/services/payment_intent_service.rb', line 3330

def interval
  @interval
end

#typeObject

Type of installment plan, one of ‘fixed_count`, `bonus`, or `revolving`.



3332
3333
3334
# File 'lib/stripe/services/payment_intent_service.rb', line 3332

def type
  @type
end