Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions::Card::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil, interval: nil, interval_count: nil, reference: nil, start_date: nil, supported_types: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



5774
5775
5776
5777
5778
5779
5780
5781
5782
5783
5784
5785
5786
5787
5788
5789
5790
5791
5792
5793
5794
# File 'lib/stripe/services/payment_intent_service.rb', line 5774

def initialize(
  amount: nil,
  amount_type: nil,
  description: nil,
  end_date: nil,
  interval: nil,
  interval_count: nil,
  reference: nil,
  start_date: nil,
  supported_types: nil
)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
  @interval = interval
  @interval_count = interval_count
  @reference = reference
  @start_date = start_date
  @supported_types = supported_types
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



5756
5757
5758
# File 'lib/stripe/services/payment_intent_service.rb', line 5756

def amount
  @amount
end

#amount_typeObject

One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.



5758
5759
5760
# File 'lib/stripe/services/payment_intent_service.rb', line 5758

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



5760
5761
5762
# File 'lib/stripe/services/payment_intent_service.rb', line 5760

def description
  @description
end

#end_dateObject

End date of the mandate or subscription. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.



5762
5763
5764
# File 'lib/stripe/services/payment_intent_service.rb', line 5762

def end_date
  @end_date
end

#intervalObject

Specifies payment frequency. One of ‘day`, `week`, `month`, `year`, or `sporadic`.



5764
5765
5766
# File 'lib/stripe/services/payment_intent_service.rb', line 5764

def interval
  @interval
end

#interval_countObject

The number of intervals between payments. For example, ‘interval=month` and `interval_count=3` indicates one payment every three months. Maximum of one year interval allowed (1 year, 12 months, or 52 weeks). This parameter is optional when `interval=sporadic`.



5766
5767
5768
# File 'lib/stripe/services/payment_intent_service.rb', line 5766

def interval_count
  @interval_count
end

#referenceObject

Unique identifier for the mandate or subscription.



5768
5769
5770
# File 'lib/stripe/services/payment_intent_service.rb', line 5768

def reference
  @reference
end

#start_dateObject

Start date of the mandate or subscription. Start date should not be lesser than yesterday.



5770
5771
5772
# File 'lib/stripe/services/payment_intent_service.rb', line 5770

def start_date
  @start_date
end

#supported_typesObject

Specifies the type of mandates supported. Possible values are ‘india`.



5772
5773
5774
# File 'lib/stripe/services/payment_intent_service.rb', line 5772

def supported_types
  @supported_types
end