Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions::Card::StatementDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions::Card::StatementDetails
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Please pass in an address that is within your Stripe user account country.
-
#phone ⇒ Object
Phone number (e.g., a toll-free number that customers can call).
Instance Method Summary collapse
-
#initialize(address: nil, phone: nil) ⇒ StatementDetails
constructor
A new instance of StatementDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, phone: nil) ⇒ StatementDetails
Returns a new instance of StatementDetails.
5833 5834 5835 5836 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5833 def initialize(address: nil, phone: nil) @address = address @phone = phone end |
Instance Attribute Details
#address ⇒ Object
Please pass in an address that is within your Stripe user account country
5829 5830 5831 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5829 def address @address end |
#phone ⇒ Object
Phone number (e.g., a toll-free number that customers can call)
5831 5832 5833 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5831 def phone @phone end |