Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions::Klarna

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: OnDemand, Subscription

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(capture_method: nil, on_demand: nil, preferred_locale: nil, setup_future_usage: nil, subscriptions: nil) ⇒ Klarna

Returns a new instance of Klarna.



6000
6001
6002
6003
6004
6005
6006
6007
6008
6009
6010
6011
6012
# File 'lib/stripe/services/payment_intent_service.rb', line 6000

def initialize(
  capture_method: nil,
  on_demand: nil,
  preferred_locale: nil,
  setup_future_usage: nil,
  subscriptions: nil
)
  @capture_method = capture_method
  @on_demand = on_demand
  @preferred_locale = preferred_locale
  @setup_future_usage = setup_future_usage
  @subscriptions = subscriptions
end

Instance Attribute Details

#capture_methodObject

Controls when the funds are captured from the customer’s account.

If provided, this parameter overrides the behavior of the top-level [capture_method](/api/payment_intents/update#update_payment_intent-capture_method) for this payment method type when finalizing the payment with this payment method type.

If ‘capture_method` is already set on the PaymentIntent, providing an empty value for this parameter unsets the stored value for this payment method type.



5982
5983
5984
# File 'lib/stripe/services/payment_intent_service.rb', line 5982

def capture_method
  @capture_method
end

#on_demandObject

On-demand details if setting up or charging an on-demand payment.



5984
5985
5986
# File 'lib/stripe/services/payment_intent_service.rb', line 5984

def on_demand
  @on_demand
end

#preferred_localeObject

Preferred language of the Klarna authorization page that the customer is redirected to



5986
5987
5988
# File 'lib/stripe/services/payment_intent_service.rb', line 5986

def preferred_locale
  @preferred_locale
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent’s payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.

If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.

When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).

If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.



5996
5997
5998
# File 'lib/stripe/services/payment_intent_service.rb', line 5996

def setup_future_usage
  @setup_future_usage
end

#subscriptionsObject

Subscription details if setting up or charging a subscription.



5998
5999
6000
# File 'lib/stripe/services/payment_intent_service.rb', line 5998

def subscriptions
  @subscriptions
end