Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions::Klarna::OnDemand

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(average_amount: nil, maximum_amount: nil, minimum_amount: nil, purchase_interval: nil, purchase_interval_count: nil) ⇒ OnDemand

Returns a new instance of OnDemand.



6289
6290
6291
6292
6293
6294
6295
6296
6297
6298
6299
6300
6301
# File 'lib/stripe/services/payment_intent_service.rb', line 6289

def initialize(
  average_amount: nil,
  maximum_amount: nil,
  minimum_amount: nil,
  purchase_interval: nil,
  purchase_interval_count: nil
)
  @average_amount = average_amount
  @maximum_amount = maximum_amount
  @minimum_amount = minimum_amount
  @purchase_interval = purchase_interval
  @purchase_interval_count = purchase_interval_count
end

Instance Attribute Details

#average_amountObject

Your average amount value. You can use a value across your customer base, or segment based on customer type, country, etc.



6279
6280
6281
# File 'lib/stripe/services/payment_intent_service.rb', line 6279

def average_amount
  @average_amount
end

#maximum_amountObject

The maximum value you may charge a customer per purchase. You can use a value across your customer base, or segment based on customer type, country, etc.



6281
6282
6283
# File 'lib/stripe/services/payment_intent_service.rb', line 6281

def maximum_amount
  @maximum_amount
end

#minimum_amountObject

The lowest or minimum value you may charge a customer per purchase. You can use a value across your customer base, or segment based on customer type, country, etc.



6283
6284
6285
# File 'lib/stripe/services/payment_intent_service.rb', line 6283

def minimum_amount
  @minimum_amount
end

#purchase_intervalObject

Interval at which the customer is making purchases



6285
6286
6287
# File 'lib/stripe/services/payment_intent_service.rb', line 6285

def purchase_interval
  @purchase_interval
end

#purchase_interval_countObject

The number of ‘purchase_interval` between charges



6287
6288
6289
# File 'lib/stripe/services/payment_intent_service.rb', line 6287

def purchase_interval_count
  @purchase_interval_count
end