Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions::Klarna::Subscription
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions::Klarna::Subscription
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: NextBilling
Instance Attribute Summary collapse
-
#interval ⇒ Object
Unit of time between subscription charges.
-
#interval_count ⇒ Object
The number of intervals (specified in the ‘interval` attribute) between subscription charges.
-
#name ⇒ Object
Name for subscription.
-
#next_billing ⇒ Object
Describes the upcoming charge for this subscription.
-
#reference ⇒ Object
A non-customer-facing reference to correlate subscription charges in the Klarna app.
Instance Method Summary collapse
-
#initialize(interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil) ⇒ Subscription
constructor
A new instance of Subscription.
Methods inherited from RequestParams
Constructor Details
#initialize(interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil) ⇒ Subscription
Returns a new instance of Subscription.
6327 6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 6339 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6327 def initialize( interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil ) @interval = interval @interval_count = interval_count @name = name @next_billing = next_billing @reference = reference end |
Instance Attribute Details
#interval ⇒ Object
Unit of time between subscription charges.
6317 6318 6319 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6317 def interval @interval end |
#interval_count ⇒ Object
The number of intervals (specified in the ‘interval` attribute) between subscription charges. For example, `interval=month` and `interval_count=3` charges every 3 months.
6319 6320 6321 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6319 def interval_count @interval_count end |
#name ⇒ Object
Name for subscription.
6321 6322 6323 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6321 def name @name end |
#next_billing ⇒ Object
Describes the upcoming charge for this subscription.
6323 6324 6325 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6323 def next_billing @next_billing end |
#reference ⇒ Object
A non-customer-facing reference to correlate subscription charges in the Klarna app. Use a value that persists across subscription charges.
6325 6326 6327 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6325 def reference @reference end |