Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions::Klarna::Subscription::NextBilling

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, date: nil) ⇒ NextBilling

Returns a new instance of NextBilling.



6311
6312
6313
6314
# File 'lib/stripe/services/payment_intent_service.rb', line 6311

def initialize(amount: nil, date: nil)
  @amount = amount
  @date = date
end

Instance Attribute Details

#amountObject

The amount of the next charge for the subscription.



6307
6308
6309
# File 'lib/stripe/services/payment_intent_service.rb', line 6307

def amount
  @amount
end

#dateObject

The date of the next charge for the subscription in YYYY-MM-DD format.



6309
6310
6311
# File 'lib/stripe/services/payment_intent_service.rb', line 6309

def date
  @date
end