Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Tax
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#name ⇒ Object
Descriptive name of the line item.
-
#quantity ⇒ Object
Quantity of the line item.
-
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
The tax information for the line item.
-
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
Returns a new instance of LineItem.
6665 6666 6667 6668 6669 6670 6671 6672 6673 6674 6675 6676 6677 6678 6679 6680 6681 6682 6683 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6665 def initialize( category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil ) @category = category @description = description @name = name @quantity = quantity @sku = sku @sold_by = sold_by @tax = tax @unit_amount = unit_amount end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
6649 6650 6651 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6649 def category @category end |
#description ⇒ Object
Description of the line item.
6651 6652 6653 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6651 def description @description end |
#name ⇒ Object
Descriptive name of the line item.
6653 6654 6655 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6653 def name @name end |
#quantity ⇒ Object
Quantity of the line item. Must be a positive number.
6655 6656 6657 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6655 def quantity @quantity end |
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
6657 6658 6659 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6657 def sku @sku end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
6659 6660 6661 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6659 def sold_by @sold_by end |
#tax ⇒ Object
The tax information for the line item.
6661 6662 6663 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6661 def tax @tax end |
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units. Cannot be a negative number.
6663 6664 6665 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6663 def unit_amount @unit_amount end |