Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions::Payto::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, end_date: nil, payment_schedule: nil, payments_per_period: nil, purpose: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



6746
6747
6748
6749
6750
6751
6752
6753
6754
6755
6756
6757
6758
6759
6760
# File 'lib/stripe/services/payment_intent_service.rb', line 6746

def initialize(
  amount: nil,
  amount_type: nil,
  end_date: nil,
  payment_schedule: nil,
  payments_per_period: nil,
  purpose: nil
)
  @amount = amount
  @amount_type = amount_type
  @end_date = end_date
  @payment_schedule = payment_schedule
  @payments_per_period = payments_per_period
  @purpose = purpose
end

Instance Attribute Details

#amountObject

Amount that will be collected. It is required when ‘amount_type` is `fixed`.



6734
6735
6736
# File 'lib/stripe/services/payment_intent_service.rb', line 6734

def amount
  @amount
end

#amount_typeObject

The type of amount that will be collected. The amount charged must be exact or up to the value of ‘amount` param for `fixed` or `maximum` type respectively.



6736
6737
6738
# File 'lib/stripe/services/payment_intent_service.rb', line 6736

def amount_type
  @amount_type
end

#end_dateObject

Date, in YYYY-MM-DD format, after which payments will not be collected. Defaults to no end date.



6738
6739
6740
# File 'lib/stripe/services/payment_intent_service.rb', line 6738

def end_date
  @end_date
end

#payment_scheduleObject

The periodicity at which payments will be collected.



6740
6741
6742
# File 'lib/stripe/services/payment_intent_service.rb', line 6740

def payment_schedule
  @payment_schedule
end

#payments_per_periodObject

The number of payments that will be made during a payment period. Defaults to 1 except for when ‘payment_schedule` is `adhoc`. In that case, it defaults to no limit.



6742
6743
6744
# File 'lib/stripe/services/payment_intent_service.rb', line 6742

def payments_per_period
  @payments_per_period
end

#purposeObject

The purpose for which payments are made. Defaults to retail.



6744
6745
6746
# File 'lib/stripe/services/payment_intent_service.rb', line 6744

def purpose
  @purpose
end