Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions::Pix::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, amount_includes_iof: nil, amount_type: nil, currency: nil, end_date: nil, payment_schedule: nil, reference: nil, start_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



6800
6801
6802
6803
6804
6805
6806
6807
6808
6809
6810
6811
6812
6813
6814
6815
6816
6817
6818
# File 'lib/stripe/services/payment_intent_service.rb', line 6800

def initialize(
  amount: nil,
  amount_includes_iof: nil,
  amount_type: nil,
  currency: nil,
  end_date: nil,
  payment_schedule: nil,
  reference: nil,
  start_date: nil
)
  @amount = amount
  @amount_includes_iof = amount_includes_iof
  @amount_type = amount_type
  @currency = currency
  @end_date = end_date
  @payment_schedule = payment_schedule
  @reference = reference
  @start_date = start_date
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments. Required when ‘amount_type=fixed`. If not provided for `amount_type=maximum`, defaults to 40000.



6784
6785
6786
# File 'lib/stripe/services/payment_intent_service.rb', line 6784

def amount
  @amount
end

#amount_includes_iofObject

Determines if the amount includes the IOF tax. Defaults to ‘never`.



6786
6787
6788
# File 'lib/stripe/services/payment_intent_service.rb', line 6786

def amount_includes_iof
  @amount_includes_iof
end

#amount_typeObject

Type of amount. Defaults to ‘maximum`.



6788
6789
6790
# File 'lib/stripe/services/payment_intent_service.rb', line 6788

def amount_type
  @amount_type
end

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Only ‘brl` is supported currently.



6790
6791
6792
# File 'lib/stripe/services/payment_intent_service.rb', line 6790

def currency
  @currency
end

#end_dateObject

Date when the mandate expires and no further payments will be charged, in ‘YYYY-MM-DD`. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.



6792
6793
6794
# File 'lib/stripe/services/payment_intent_service.rb', line 6792

def end_date
  @end_date
end

#payment_scheduleObject

Schedule at which the future payments will be charged. Defaults to ‘weekly`.



6794
6795
6796
# File 'lib/stripe/services/payment_intent_service.rb', line 6794

def payment_schedule
  @payment_schedule
end

#referenceObject

Subscription name displayed to buyers in their bank app. Defaults to the displayable business name.



6796
6797
6798
# File 'lib/stripe/services/payment_intent_service.rb', line 6796

def reference
  @reference
end

#start_dateObject

Start date of the mandate, in ‘YYYY-MM-DD`. Start date should be at least 3 days in the future. Defaults to 3 days after the current date.



6798
6799
6800
# File 'lib/stripe/services/payment_intent_service.rb', line 6798

def start_date
  @start_date
end