Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions::UsBankAccount::FinancialConnections

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Filters, ManualEntry

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections

Returns a new instance of FinancialConnections.



7093
7094
7095
7096
7097
7098
7099
7100
7101
7102
7103
7104
7105
# File 'lib/stripe/services/payment_intent_service.rb', line 7093

def initialize(
  filters: nil,
  manual_entry: nil,
  permissions: nil,
  prefetch: nil,
  return_url: nil
)
  @filters = filters
  @manual_entry = manual_entry
  @permissions = permissions
  @prefetch = prefetch
  @return_url = return_url
end

Instance Attribute Details

#filtersObject

Provide filters for the linked accounts that the customer can select for the payment method.



7083
7084
7085
# File 'lib/stripe/services/payment_intent_service.rb', line 7083

def filters
  @filters
end

#manual_entryObject

Customize manual entry behavior



7085
7086
7087
# File 'lib/stripe/services/payment_intent_service.rb', line 7085

def manual_entry
  @manual_entry
end

#permissionsObject

The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.



7087
7088
7089
# File 'lib/stripe/services/payment_intent_service.rb', line 7087

def permissions
  @permissions
end

#prefetchObject

List of data features that you would like to retrieve upon account creation.



7089
7090
7091
# File 'lib/stripe/services/payment_intent_service.rb', line 7089

def prefetch
  @prefetch
end

#return_urlObject

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



7091
7092
7093
# File 'lib/stripe/services/payment_intent_service.rb', line 7091

def return_url
  @return_url
end