Class: Stripe::PaymentIntentService::UpdateParams::Shipping
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::Shipping
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Shipping address.
-
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
-
#name ⇒ Object
Recipient name.
-
#phone ⇒ Object
Recipient phone (including extension).
-
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service.
Instance Method Summary collapse
-
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
constructor
A new instance of Shipping.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
Returns a new instance of Shipping.
7382 7383 7384 7385 7386 7387 7388 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7382 def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) @address = address @carrier = carrier @name = name @phone = phone @tracking_number = tracking_number end |
Instance Attribute Details
#address ⇒ Object
Shipping address.
7372 7373 7374 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7372 def address @address end |
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
7374 7375 7376 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7374 def carrier @carrier end |
#name ⇒ Object
Recipient name.
7376 7377 7378 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7376 def name @name end |
#phone ⇒ Object
Recipient phone (including extension).
7378 7379 7380 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7378 def phone @phone end |
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
7380 7381 7382 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7380 def tracking_number @tracking_number end |