Class: Stripe::PaymentIntentSimulateCryptoDepositParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_simulate_crypto_deposit_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(buyer_wallet: nil, expand: nil, network: nil, token_currency: nil, transaction_hash: nil) ⇒ PaymentIntentSimulateCryptoDepositParams

Returns a new instance of PaymentIntentSimulateCryptoDepositParams.



17
18
19
20
21
22
23
24
25
26
27
28
29
# File 'lib/stripe/params/payment_intent_simulate_crypto_deposit_params.rb', line 17

def initialize(
  buyer_wallet: nil,
  expand: nil,
  network: nil,
  token_currency: nil,
  transaction_hash: nil
)
  @buyer_wallet = buyer_wallet
  @expand = expand
  @network = network
  @token_currency = token_currency
  @transaction_hash = transaction_hash
end

Instance Attribute Details

#buyer_walletObject

The buyer’s wallet address from which the crypto deposit is originating.



7
8
9
# File 'lib/stripe/params/payment_intent_simulate_crypto_deposit_params.rb', line 7

def buyer_wallet
  @buyer_wallet
end

#expandObject

Specifies which fields in the response should be expanded.



9
10
11
# File 'lib/stripe/params/payment_intent_simulate_crypto_deposit_params.rb', line 9

def expand
  @expand
end

#networkObject

The blockchain network of the simulated crypto deposit.



11
12
13
# File 'lib/stripe/params/payment_intent_simulate_crypto_deposit_params.rb', line 11

def network
  @network
end

#token_currencyObject

The token currency of the simulated crypto deposit.



13
14
15
# File 'lib/stripe/params/payment_intent_simulate_crypto_deposit_params.rb', line 13

def token_currency
  @token_currency
end

#transaction_hashObject

A testmode transaction hash that determines the outcome of the simulated deposit.



15
16
17
# File 'lib/stripe/params/payment_intent_simulate_crypto_deposit_params.rb', line 15

def transaction_hash
  @transaction_hash
end