Class: Stripe::PaymentIntentTriggerActionParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentTriggerActionParams
- Defined in:
- lib/stripe/params/payment_intent_trigger_action_params.rb
Defined Under Namespace
Classes: ScanQrCode
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#scan_qr_code ⇒ Object
True to simulate success, false to simulate failure.
-
#type ⇒ Object
The type of action to be simulated.
Instance Method Summary collapse
-
#initialize(expand: nil, scan_qr_code: nil, type: nil) ⇒ PaymentIntentTriggerActionParams
constructor
A new instance of PaymentIntentTriggerActionParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(expand: nil, scan_qr_code: nil, type: nil) ⇒ PaymentIntentTriggerActionParams
Returns a new instance of PaymentIntentTriggerActionParams.
21 22 23 24 25 |
# File 'lib/stripe/params/payment_intent_trigger_action_params.rb', line 21 def initialize(expand: nil, scan_qr_code: nil, type: nil) @expand = @scan_qr_code = scan_qr_code @type = type end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
15 16 17 |
# File 'lib/stripe/params/payment_intent_trigger_action_params.rb', line 15 def @expand end |
#scan_qr_code ⇒ Object
True to simulate success, false to simulate failure.
17 18 19 |
# File 'lib/stripe/params/payment_intent_trigger_action_params.rb', line 17 def scan_qr_code @scan_qr_code end |
#type ⇒ Object
The type of action to be simulated.
19 20 21 |
# File 'lib/stripe/params/payment_intent_trigger_action_params.rb', line 19 def type @type end |