Class: Stripe::PaymentIntentUpdateParams::AmountDetails::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Defined Under Namespace

Classes: PaymentMethodOptions, Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, quantity_precision: nil, tax: nil, unit_cost: nil, unit_of_measure: nil) ⇒ LineItem

Returns a new instance of LineItem.



179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
# File 'lib/stripe/params/payment_intent_update_params.rb', line 179

def initialize(
  discount_amount: nil,
  payment_method_options: nil,
  product_code: nil,
  product_name: nil,
  quantity: nil,
  quantity_precision: nil,
  tax: nil,
  unit_cost: nil,
  unit_of_measure: nil
)
  @discount_amount = discount_amount
  @payment_method_options = payment_method_options
  @product_code = product_code
  @product_name = product_name
  @quantity = quantity
  @quantity_precision = quantity_precision
  @tax = tax
  @unit_cost = unit_cost
  @unit_of_measure = unit_of_measure
end

Instance Attribute Details

#discount_amountObject

The discount applied on this line item represented in the smallest currency unit. An integer greater than 0.

This field is mutually exclusive with the amount_details[discount_amount] field.



159
160
161
# File 'lib/stripe/params/payment_intent_update_params.rb', line 159

def discount_amount
  @discount_amount
end

#payment_method_optionsObject

Payment method-specific information for line items.



161
162
163
# File 'lib/stripe/params/payment_intent_update_params.rb', line 161

def payment_method_options
  @payment_method_options
end

#product_codeObject

The product code of the line item, such as an SKU. Required for L3 rates. At most 12 characters long.



163
164
165
# File 'lib/stripe/params/payment_intent_update_params.rb', line 163

def product_code
  @product_code
end

#product_nameObject

The product name of the line item. Required for L3 rates. At most 1024 characters long.

For Cards, this field is truncated to 26 alphanumeric characters before being sent to the card networks. For PayPal, this field is truncated to 127 characters.



167
168
169
# File 'lib/stripe/params/payment_intent_update_params.rb', line 167

def product_name
  @product_name
end

#quantityObject

The quantity of items. Required for L3 rates. An integer greater than 0.



169
170
171
# File 'lib/stripe/params/payment_intent_update_params.rb', line 169

def quantity
  @quantity
end

#quantity_precisionObject

The number of decimal places implied in the quantity. For example, if quantity is 10000 and quantity_precision is 2, the actual quantity is 100.00. Defaults to 0 if not provided.



171
172
173
# File 'lib/stripe/params/payment_intent_update_params.rb', line 171

def quantity_precision
  @quantity_precision
end

#taxObject

Contains information about the tax on the item.



173
174
175
# File 'lib/stripe/params/payment_intent_update_params.rb', line 173

def tax
  @tax
end

#unit_costObject

The unit cost of the line item represented in the smallest currency unit. Required for L3 rates. An integer greater than or equal to 0.



175
176
177
# File 'lib/stripe/params/payment_intent_update_params.rb', line 175

def unit_cost
  @unit_cost
end

#unit_of_measureObject

A unit of measure for the line item, such as gallons, feet, meters, etc.



177
178
179
# File 'lib/stripe/params/payment_intent_update_params.rb', line 177

def unit_of_measure
  @unit_of_measure
end