Class: Stripe::PaymentIntentUpdateParams::AmountDetails::LineItem::PaymentMethodOptions::Paypal
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::AmountDetails::LineItem::PaymentMethodOptions::Paypal
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, sold_by: nil) ⇒ Paypal
constructor
A new instance of Paypal.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, description: nil, sold_by: nil) ⇒ Paypal
Returns a new instance of Paypal.
67 68 69 70 71 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 67 def initialize(category: nil, description: nil, sold_by: nil) @category = category @description = description @sold_by = sold_by end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
61 62 63 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 61 def category @category end |
#description ⇒ Object
Description of the line item.
63 64 65 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 63 def description @description end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
65 66 67 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 65 def sold_by @sold_by end |