Class: Stripe::PaymentIntentUpdateParams::AmountDetails::Tax
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::AmountDetails::Tax
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Instance Attribute Summary collapse
-
#total_tax_amount ⇒ Object
The total amount of tax on the transaction represented in the smallest currency unit.
Instance Method Summary collapse
-
#initialize(total_tax_amount: nil) ⇒ Tax
constructor
A new instance of Tax.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(total_tax_amount: nil) ⇒ Tax
Returns a new instance of Tax.
235 236 237 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 235 def initialize(total_tax_amount: nil) @total_tax_amount = total_tax_amount end |
Instance Attribute Details
#total_tax_amount ⇒ Object
The total amount of tax on the transaction represented in the smallest currency unit. Required for L2 rates. An integer greater than or equal to 0.
This field is mutually exclusive with the amount_details[line_items][#][tax][total_tax_amount] field.
233 234 235 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 233 def total_tax_amount @total_tax_amount end |