Class: Stripe::PaymentIntentUpdateParams::MandateData::CustomerAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Defined Under Namespace

Classes: Online

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(online: nil, type: nil) ⇒ CustomerAcceptance

Returns a new instance of CustomerAcceptance.



249
250
251
252
# File 'lib/stripe/params/payment_intent_update_params.rb', line 249

def initialize(online: nil, type: nil)
  @online = online
  @type = type
end

Instance Attribute Details

#onlineObject

If this is a Mandate accepted online, this hash contains details about the online acceptance.



245
246
247
# File 'lib/stripe/params/payment_intent_update_params.rb', line 245

def online
  @online
end

#typeObject

The type of customer acceptance information included with the Mandate.



247
248
249
# File 'lib/stripe/params/payment_intent_update_params.rb', line 247

def type
  @type
end