Class: Stripe::PaymentIntentUpdateParams::PaymentDetails::Benefit::FrMealVoucher
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentDetails::Benefit::FrMealVoucher
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Whether to enable meal voucher benefit for this payment.
-
#siret ⇒ Object
The 14-digit SIRET of the meal voucher acceptor.
Instance Method Summary collapse
-
#initialize(enabled: nil, siret: nil) ⇒ FrMealVoucher
constructor
A new instance of FrMealVoucher.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(enabled: nil, siret: nil) ⇒ FrMealVoucher
Returns a new instance of FrMealVoucher.
297 298 299 300 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 297 def initialize(enabled: nil, siret: nil) @enabled = enabled @siret = siret end |
Instance Attribute Details
#enabled ⇒ Object
Whether to enable meal voucher benefit for this payment.
293 294 295 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 293 def enabled @enabled end |
#siret ⇒ Object
The 14-digit SIRET of the meal voucher acceptor.
295 296 297 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 295 def siret @siret end |