Class: Stripe::PaymentIntentUpdateParams::PaymentDetails::CarRental::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentDetails::CarRental::Delivery::Recipient
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
384 385 386 387 388 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 384 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
378 379 380 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 378 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
380 381 382 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 380 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
382 383 384 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 382 def phone @phone end |