Class: Stripe::PaymentIntentUpdateParams::PaymentDetails::CarRental::Driver
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentDetails::CarRental::Driver
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Instance Attribute Summary collapse
-
#driver_identification_number ⇒ Object
Driver’s identification number.
-
#driver_tax_number ⇒ Object
Driver’s tax number.
-
#name ⇒ Object
Full name of the person or entity on the car reservation.
Instance Method Summary collapse
-
#initialize(driver_identification_number: nil, driver_tax_number: nil, name: nil) ⇒ Driver
constructor
A new instance of Driver.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(driver_identification_number: nil, driver_tax_number: nil, name: nil) ⇒ Driver
Returns a new instance of Driver.
366 367 368 369 370 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 366 def initialize(driver_identification_number: nil, driver_tax_number: nil, name: nil) @driver_identification_number = driver_identification_number @driver_tax_number = driver_tax_number @name = name end |
Instance Attribute Details
#driver_identification_number ⇒ Object
Driver’s identification number.
360 361 362 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 360 def driver_identification_number @driver_identification_number end |
#driver_tax_number ⇒ Object
Driver’s tax number.
362 363 364 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 362 def driver_tax_number @driver_tax_number end |
#name ⇒ Object
Full name of the person or entity on the car reservation.
364 365 366 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 364 def name @name end |