Class: Stripe::PaymentIntentUpdateParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location's address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1034 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
1016 1017 1018 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1016 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location's address.
1018 1019 1020 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1018 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
1020 1021 1022 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1020 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
1022 1023 1024 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1022 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
1024 1025 1026 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1024 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
1026 1027 1028 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1026 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
1028 1029 1030 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1028 def genre @genre end |
#name ⇒ Object
The name of the event.
1030 1031 1032 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1030 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
1032 1033 1034 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1032 def starts_at @starts_at end |