Class: Stripe::PaymentIntentUpdateParams::PaymentDetails::EventDetails::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



944
945
946
947
948
# File 'lib/stripe/params/payment_intent_update_params.rb', line 944

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



938
939
940
# File 'lib/stripe/params/payment_intent_update_params.rb', line 938

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



940
941
942
# File 'lib/stripe/params/payment_intent_update_params.rb', line 940

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



942
943
944
# File 'lib/stripe/params/payment_intent_update_params.rb', line 942

def phone
  @phone
end