Class: Stripe::PaymentIntentUpdateParams::PaymentDetails::Flight
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentDetails::Flight
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Passenger, Segment
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
-
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#segments ⇒ Object
The individual flight segments associated with the trip.
-
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
Instance Method Summary collapse
-
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
constructor
A new instance of Flight.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
Returns a new instance of Flight.
1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1192 def initialize( affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil ) @affiliate = affiliate @agency_number = agency_number @carrier = carrier @delivery = delivery @passenger_name = passenger_name @passengers = passengers @segments = segments @ticket_number = ticket_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
1176 1177 1178 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1176 def affiliate @affiliate end |
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
1178 1179 1180 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1178 def agency_number @agency_number end |
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
1180 1181 1182 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1180 def carrier @carrier end |
#delivery ⇒ Object
Delivery details for this purchase.
1182 1183 1184 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1182 def delivery @delivery end |
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
1184 1185 1186 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1184 def passenger_name @passenger_name end |
#passengers ⇒ Object
The details of the passengers in the travel reservation.
1186 1187 1188 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1186 def passengers @passengers end |
#segments ⇒ Object
The individual flight segments associated with the trip.
1188 1189 1190 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1188 def segments @segments end |
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
1190 1191 1192 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1190 def ticket_number @ticket_number end |