Class: Stripe::PaymentIntentUpdateParams::PaymentDetails::Flight::Affiliate
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentDetails::Flight::Affiliate
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Instance Attribute Summary collapse
-
#name ⇒ Object
The name of the affiliate that originated the purchase.
Instance Method Summary collapse
-
#initialize(name: nil) ⇒ Affiliate
constructor
A new instance of Affiliate.
Methods inherited from RequestParams
Constructor Details
#initialize(name: nil) ⇒ Affiliate
Returns a new instance of Affiliate.
944 945 946 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 944 def initialize(name: nil) @name = name end |
Instance Attribute Details
#name ⇒ Object
The name of the affiliate that originated the purchase.
942 943 944 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 942 def name @name end |