Class: Stripe::PaymentIntentUpdateParams::PaymentDetails::Flight::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



1114
1115
1116
1117
1118
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1114

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



1108
1109
1110
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1108

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



1110
1111
1112
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1110

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



1112
1113
1114
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1112

def phone
  @phone
end