Class: Stripe::PaymentIntentUpdateParams::PaymentDetails::FlightDatum
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentDetails::FlightDatum
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Defined Under Namespace
Classes: Affiliate, Insurance, Passenger, Segment, Total
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details if applicable.
-
#booking_number ⇒ Object
Reservation reference.
-
#computerized_reservation_system ⇒ Object
Computerized reservation system used to make the reservation and purchase the ticket.
-
#endorsements_and_restrictions ⇒ Object
Ticket restrictions.
-
#insurances ⇒ Object
List of insurances.
-
#passengers ⇒ Object
List of passengers.
-
#segments ⇒ Object
List of flight segments.
-
#ticket_electronically_issued_indicator ⇒ Object
Electronic ticket indicator.
-
#total ⇒ Object
Total cost breakdown.
-
#transaction_type ⇒ Object
Type of flight transaction.
Instance Method Summary collapse
-
#initialize(affiliate: nil, booking_number: nil, computerized_reservation_system: nil, endorsements_and_restrictions: nil, insurances: nil, passengers: nil, segments: nil, ticket_electronically_issued_indicator: nil, total: nil, transaction_type: nil) ⇒ FlightDatum
constructor
A new instance of FlightDatum.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate: nil, booking_number: nil, computerized_reservation_system: nil, endorsements_and_restrictions: nil, insurances: nil, passengers: nil, segments: nil, ticket_electronically_issued_indicator: nil, total: nil, transaction_type: nil) ⇒ FlightDatum
Returns a new instance of FlightDatum.
1515 1516 1517 1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1515 def initialize( affiliate: nil, booking_number: nil, computerized_reservation_system: nil, endorsements_and_restrictions: nil, insurances: nil, passengers: nil, segments: nil, ticket_electronically_issued_indicator: nil, total: nil, transaction_type: nil ) @affiliate = affiliate @booking_number = booking_number @computerized_reservation_system = computerized_reservation_system @endorsements_and_restrictions = endorsements_and_restrictions @insurances = insurances @passengers = passengers @segments = segments @ticket_electronically_issued_indicator = ticket_electronically_issued_indicator @total = total @transaction_type = transaction_type end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details if applicable.
1495 1496 1497 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1495 def affiliate @affiliate end |
#booking_number ⇒ Object
Reservation reference.
1497 1498 1499 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1497 def booking_number @booking_number end |
#computerized_reservation_system ⇒ Object
Computerized reservation system used to make the reservation and purchase the ticket.
1499 1500 1501 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1499 def computerized_reservation_system @computerized_reservation_system end |
#endorsements_and_restrictions ⇒ Object
Ticket restrictions.
1501 1502 1503 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1501 def endorsements_and_restrictions @endorsements_and_restrictions end |
#insurances ⇒ Object
List of insurances.
1503 1504 1505 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1503 def insurances @insurances end |
#passengers ⇒ Object
List of passengers.
1505 1506 1507 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1505 def passengers @passengers end |
#segments ⇒ Object
List of flight segments.
1507 1508 1509 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1507 def segments @segments end |
#ticket_electronically_issued_indicator ⇒ Object
Electronic ticket indicator.
1509 1510 1511 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1509 def ticket_electronically_issued_indicator @ticket_electronically_issued_indicator end |
#total ⇒ Object
Total cost breakdown.
1511 1512 1513 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1511 def total @total end |
#transaction_type ⇒ Object
Type of flight transaction.
1513 1514 1515 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1513 def transaction_type @transaction_type end |