Class: Stripe::PaymentIntentUpdateParams::PaymentDetails::Lodging

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Defined Under Namespace

Classes: Address, Affiliate, Delivery, Passenger

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging

Returns a new instance of Lodging.



1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
1669
1670
1671
1672
1673
1674
1675
1676
1677
1678
1679
1680
1681
1682
1683
1684
1685
1686
1687
1688
1689
1690
1691
1692
1693
1694
1695
1696
1697
1698
1699
1700
1701
1702
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1658

def initialize(
  address: nil,
  adults: nil,
  affiliate: nil,
  booking_number: nil,
  category: nil,
  checkin_at: nil,
  checkout_at: nil,
  customer_service_phone_number: nil,
  daily_room_rate_amount: nil,
  delivery: nil,
  extra_charges: nil,
  fire_safety_act_compliance: nil,
  name: nil,
  no_show: nil,
  number_of_rooms: nil,
  passengers: nil,
  property_phone_number: nil,
  room_class: nil,
  room_nights: nil,
  total_room_tax_amount: nil,
  total_tax_amount: nil
)
  @address = address
  @adults = adults
  @affiliate = affiliate
  @booking_number = booking_number
  @category = category
  @checkin_at = checkin_at
  @checkout_at = checkout_at
  @customer_service_phone_number = customer_service_phone_number
  @daily_room_rate_amount = daily_room_rate_amount
  @delivery = delivery
  @extra_charges = extra_charges
  @fire_safety_act_compliance = fire_safety_act_compliance
  @name = name
  @no_show = no_show
  @number_of_rooms = number_of_rooms
  @passengers = passengers
  @property_phone_number = property_phone_number
  @room_class = room_class
  @room_nights = room_nights
  @total_room_tax_amount = total_room_tax_amount
  @total_tax_amount = total_tax_amount
end

Instance Attribute Details

#addressObject

The lodging location's address.



1616
1617
1618
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1616

def address
  @address
end

#adultsObject

The number of adults on the booking



1618
1619
1620
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1618

def adults
  @adults
end

#affiliateObject

Affiliate details for this purchase.



1620
1621
1622
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1620

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the lodging reservation.



1622
1623
1624
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1622

def booking_number
  @booking_number
end

#categoryObject

The lodging category



1624
1625
1626
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1624

def category
  @category
end

#checkin_atObject

Lodging check-in time. Measured in seconds since the Unix epoch.



1626
1627
1628
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1626

def checkin_at
  @checkin_at
end

#checkout_atObject

Lodging check-out time. Measured in seconds since the Unix epoch.



1628
1629
1630
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1628

def checkout_at
  @checkout_at
end

#customer_service_phone_numberObject

The customer service phone number of the lodging company.



1630
1631
1632
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1630

def customer_service_phone_number
  @customer_service_phone_number
end

#daily_room_rate_amountObject

The daily lodging room rate.



1632
1633
1634
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1632

def daily_room_rate_amount
  @daily_room_rate_amount
end

#deliveryObject

Delivery details for this purchase.



1634
1635
1636
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1634

def delivery
  @delivery
end

#extra_chargesObject

List of additional charges being billed.



1636
1637
1638
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1636

def extra_charges
  @extra_charges
end

#fire_safety_act_complianceObject

Indicates whether the lodging location is compliant with the Fire Safety Act.



1638
1639
1640
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1638

def fire_safety_act_compliance
  @fire_safety_act_compliance
end

#nameObject

The name of the lodging location.



1640
1641
1642
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1640

def name
  @name
end

#no_showObject

Indicates if the customer did not keep their booking while failing to cancel the reservation.



1642
1643
1644
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1642

def no_show
  @no_show
end

#number_of_roomsObject

The number of rooms on the booking



1644
1645
1646
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1644

def number_of_rooms
  @number_of_rooms
end

#passengersObject

The details of the passengers in the travel reservation



1646
1647
1648
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1646

def passengers
  @passengers
end

#property_phone_numberObject

The phone number of the lodging location.



1648
1649
1650
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1648

def property_phone_number
  @property_phone_number
end

#room_classObject

The room class for this purchase.



1650
1651
1652
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1650

def room_class
  @room_class
end

#room_nightsObject

The number of room nights



1652
1653
1654
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1652

def room_nights
  @room_nights
end

#total_room_tax_amountObject

The total tax amount associating with the room reservation.



1654
1655
1656
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1654

def total_room_tax_amount
  @total_room_tax_amount
end

#total_tax_amountObject

The total tax amount



1656
1657
1658
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1656

def total_tax_amount
  @total_tax_amount
end