Class: Stripe::PaymentIntentUpdateParams::PaymentDetails::Lodging::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



1535
1536
1537
1538
1539
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1535

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



1529
1530
1531
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1529

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



1531
1532
1533
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1531

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



1533
1534
1535
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1533

def phone
  @phone
end