Class: Stripe::PaymentIntentUpdateParams::PaymentDetails::LodgingDatum
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentDetails::LodgingDatum
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Defined Under Namespace
Classes: Accommodation, Affiliate, Guest, Host, Insurance, Total
Instance Attribute Summary collapse
-
#accommodation ⇒ Object
Accommodation details for the lodging.
-
#affiliate ⇒ Object
Affiliate details if applicable.
-
#booking_number ⇒ Object
Booking confirmation number for the lodging.
-
#checkin_at ⇒ Object
Check-in date.
-
#checkout_at ⇒ Object
Check-out date.
-
#customer_service_phone_number ⇒ Object
Customer service phone number for the lodging company.
-
#fire_safety_act_compliance_indicator ⇒ Object
Whether the lodging is compliant with any hotel fire safety regulations.
-
#guests ⇒ Object
List of guests for the lodging.
-
#host ⇒ Object
Host details for the lodging.
-
#insurances ⇒ Object
List of insurances for the lodging.
-
#no_show_indicator ⇒ Object
Whether the renter is a no-show.
-
#renter_id_number ⇒ Object
Renter ID number for the lodging.
-
#renter_name ⇒ Object
Renter name for the lodging.
-
#total ⇒ Object
Total details for the lodging.
Instance Method Summary collapse
-
#initialize(accommodation: nil, affiliate: nil, booking_number: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, fire_safety_act_compliance_indicator: nil, guests: nil, host: nil, insurances: nil, no_show_indicator: nil, renter_id_number: nil, renter_name: nil, total: nil) ⇒ LodgingDatum
constructor
A new instance of LodgingDatum.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(accommodation: nil, affiliate: nil, booking_number: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, fire_safety_act_compliance_indicator: nil, guests: nil, host: nil, insurances: nil, no_show_indicator: nil, renter_id_number: nil, renter_name: nil, total: nil) ⇒ LodgingDatum
Returns a new instance of LodgingDatum.
1966 1967 1968 1969 1970 1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 1989 1990 1991 1992 1993 1994 1995 1996 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1966 def initialize( accommodation: nil, affiliate: nil, booking_number: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, fire_safety_act_compliance_indicator: nil, guests: nil, host: nil, insurances: nil, no_show_indicator: nil, renter_id_number: nil, renter_name: nil, total: nil ) @accommodation = accommodation @affiliate = affiliate @booking_number = booking_number @checkin_at = checkin_at @checkout_at = checkout_at @customer_service_phone_number = customer_service_phone_number @fire_safety_act_compliance_indicator = fire_safety_act_compliance_indicator @guests = guests @host = host @insurances = insurances @no_show_indicator = no_show_indicator @renter_id_number = renter_id_number @renter_name = renter_name @total = total end |
Instance Attribute Details
#accommodation ⇒ Object
Accommodation details for the lodging.
1938 1939 1940 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1938 def accommodation @accommodation end |
#affiliate ⇒ Object
Affiliate details if applicable.
1940 1941 1942 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1940 def affiliate @affiliate end |
#booking_number ⇒ Object
Booking confirmation number for the lodging.
1942 1943 1944 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1942 def booking_number @booking_number end |
#checkin_at ⇒ Object
Check-in date.
1944 1945 1946 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1944 def checkin_at @checkin_at end |
#checkout_at ⇒ Object
Check-out date.
1946 1947 1948 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1946 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object
Customer service phone number for the lodging company.
1948 1949 1950 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1948 def customer_service_phone_number @customer_service_phone_number end |
#fire_safety_act_compliance_indicator ⇒ Object
Whether the lodging is compliant with any hotel fire safety regulations.
1950 1951 1952 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1950 def fire_safety_act_compliance_indicator @fire_safety_act_compliance_indicator end |
#guests ⇒ Object
List of guests for the lodging.
1952 1953 1954 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1952 def guests @guests end |
#host ⇒ Object
Host details for the lodging.
1954 1955 1956 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1954 def host @host end |
#insurances ⇒ Object
List of insurances for the lodging.
1956 1957 1958 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1956 def insurances @insurances end |
#no_show_indicator ⇒ Object
Whether the renter is a no-show.
1958 1959 1960 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1958 def no_show_indicator @no_show_indicator end |
#renter_id_number ⇒ Object
Renter ID number for the lodging.
1960 1961 1962 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1960 def renter_id_number @renter_id_number end |
#renter_name ⇒ Object
Renter name for the lodging.
1962 1963 1964 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1962 def renter_name @renter_name end |
#total ⇒ Object
Total details for the lodging.
1964 1965 1966 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1964 def total @total end |