Class: Stripe::PaymentIntentUpdateParams::PaymentDetails::MoneyServices
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentDetails::MoneyServices
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Defined Under Namespace
Classes: AccountFunding
Instance Attribute Summary collapse
-
#account_funding ⇒ Object
Account funding transaction details including sender and beneficiary information.
-
#transaction_type ⇒ Object
The type of money services transaction.
Instance Method Summary collapse
-
#initialize(account_funding: nil, transaction_type: nil) ⇒ MoneyServices
constructor
A new instance of MoneyServices.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(account_funding: nil, transaction_type: nil) ⇒ MoneyServices
Returns a new instance of MoneyServices.
2100 2101 2102 2103 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2100 def initialize(account_funding: nil, transaction_type: nil) @account_funding = account_funding @transaction_type = transaction_type end |
Instance Attribute Details
#account_funding ⇒ Object
Account funding transaction details including sender and beneficiary information.
2096 2097 2098 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2096 def account_funding @account_funding end |
#transaction_type ⇒ Object
The type of money services transaction.
2098 2099 2100 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2098 def transaction_type @transaction_type end |