Class: Stripe::PaymentIntentUpdateParams::PaymentDetails::MoneyServices::AccountFunding

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Defined Under Namespace

Classes: BeneficiaryDetails, SenderDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(beneficiary_account: nil, beneficiary_details: nil, sender_account: nil, sender_details: nil) ⇒ AccountFunding

Returns a new instance of AccountFunding.



2086
2087
2088
2089
2090
2091
2092
2093
2094
2095
2096
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2086

def initialize(
  beneficiary_account: nil,
  beneficiary_details: nil,
  sender_account: nil,
  sender_details: nil
)
  @beneficiary_account = 
  @beneficiary_details = beneficiary_details
  @sender_account = 
  @sender_details = sender_details
end

Instance Attribute Details

#beneficiary_accountObject

ID of the Account representing the beneficiary in this account funding transaction.



2078
2079
2080
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2078

def 
  @beneficiary_account
end

#beneficiary_detailsObject

Inline identity details for the beneficiary of this account funding transaction.



2080
2081
2082
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2080

def beneficiary_details
  @beneficiary_details
end

#sender_accountObject

ID of the Account representing the sender in this account funding transaction.



2082
2083
2084
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2082

def 
  @sender_account
end

#sender_detailsObject

Inline identity details for the sender of this account funding transaction.



2084
2085
2086
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2084

def sender_details
  @sender_details
end