Class: Stripe::PaymentIntentUpdateParams::PaymentDetails::Subscription
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentDetails::Subscription
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Defined Under Namespace
Classes: Affiliate, BillingInterval
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#auto_renewal ⇒ Object
Info whether the subscription will be auto renewed upon expiry.
-
#billing_interval ⇒ Object
Subscription billing details for this purchase.
-
#ends_at ⇒ Object
Subscription end time.
-
#name ⇒ Object
Name of the product on subscription.
-
#starts_at ⇒ Object
Subscription start time.
Instance Method Summary collapse
-
#initialize(affiliate: nil, auto_renewal: nil, billing_interval: nil, ends_at: nil, name: nil, starts_at: nil) ⇒ Subscription
constructor
A new instance of Subscription.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate: nil, auto_renewal: nil, billing_interval: nil, ends_at: nil, name: nil, starts_at: nil) ⇒ Subscription
Returns a new instance of Subscription.
2143 2144 2145 2146 2147 2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2143 def initialize( affiliate: nil, auto_renewal: nil, billing_interval: nil, ends_at: nil, name: nil, starts_at: nil ) @affiliate = affiliate @auto_renewal = auto_renewal @billing_interval = billing_interval @ends_at = ends_at @name = name @starts_at = starts_at end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
2131 2132 2133 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2131 def affiliate @affiliate end |
#auto_renewal ⇒ Object
Info whether the subscription will be auto renewed upon expiry.
2133 2134 2135 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2133 def auto_renewal @auto_renewal end |
#billing_interval ⇒ Object
Subscription billing details for this purchase.
2135 2136 2137 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2135 def billing_interval @billing_interval end |
#ends_at ⇒ Object
Subscription end time. Measured in seconds since the Unix epoch.
2137 2138 2139 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2137 def ends_at @ends_at end |
#name ⇒ Object
Name of the product on subscription. e.g. Apple Music Subscription
2139 2140 2141 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2139 def name @name end |
#starts_at ⇒ Object
Subscription start time. Measured in seconds since the Unix epoch.
2141 2142 2143 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2141 def starts_at @starts_at end |