Class: Stripe::PaymentIntentUpdateParams::PaymentDetails::Subscription::BillingInterval

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(count: nil, interval: nil) ⇒ BillingInterval

Returns a new instance of BillingInterval.



2193
2194
2195
2196
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2193

def initialize(count: nil, interval: nil)
  @count = count
  @interval = interval
end

Instance Attribute Details

#countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



2189
2190
2191
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2189

def count
  @count
end

#intervalObject

Specifies a type of interval unit. Either day, week, month or year.



2191
2192
2193
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2191

def interval
  @interval
end