Class: Stripe::PaymentIntentUpdateParams::PaymentMethodData::NaverPay
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodData::NaverPay
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Instance Attribute Summary collapse
-
#funding ⇒ Object
Whether to use Naver Pay points or a card to fund this transaction.
Instance Method Summary collapse
-
#initialize(funding: nil) ⇒ NaverPay
constructor
A new instance of NaverPay.
Methods inherited from RequestParams
Constructor Details
#initialize(funding: nil) ⇒ NaverPay
Returns a new instance of NaverPay.
2115 2116 2117 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2115 def initialize(funding: nil) @funding = funding end |
Instance Attribute Details
#funding ⇒ Object
Whether to use Naver Pay points or a card to fund this transaction. If not provided, this defaults to ‘card`.
2113 2114 2115 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2113 def funding @funding end |