Class: Stripe::PaymentIntentUpdateParams::PaymentMethodData::Sofort
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodData::Sofort
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Instance Attribute Summary collapse
-
#country ⇒ Object
Two-letter ISO code representing the country the bank account is located in.
Instance Method Summary collapse
-
#initialize(country: nil) ⇒ Sofort
constructor
A new instance of Sofort.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(country: nil) ⇒ Sofort
Returns a new instance of Sofort.
2222 2223 2224 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2222 def initialize(country: nil) @country = country end |
Instance Attribute Details
#country ⇒ Object
Two-letter ISO code representing the country the bank account is located in.
2220 2221 2222 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2220 def country @country end |