Class: Stripe::PaymentIntentUpdateParams::PaymentMethodData::StripeBalance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodData::StripeBalance
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Instance Attribute Summary collapse
-
#account ⇒ Object
The connected account ID whose Stripe balance to use as the source of payment.
Instance Method Summary collapse
-
#initialize(account: nil) ⇒ StripeBalance
constructor
A new instance of StripeBalance.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(account: nil) ⇒ StripeBalance
Returns a new instance of StripeBalance.
2231 2232 2233 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2231 def initialize(account: nil) @account = account end |
Instance Attribute Details
#account ⇒ Object
The connected account ID whose Stripe balance to use as the source of payment
2229 2230 2231 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2229 def account @account end |