Class: Stripe::PaymentIntentUpdateParams::PaymentMethodData::Upi::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



531
532
533
534
535
536
# File 'lib/stripe/params/payment_intent_update_params.rb', line 531

def initialize(amount: nil, amount_type: nil, description: nil, end_date: nil)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



523
524
525
# File 'lib/stripe/params/payment_intent_update_params.rb', line 523

def amount
  @amount
end

#amount_typeObject

One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.



525
526
527
# File 'lib/stripe/params/payment_intent_update_params.rb', line 525

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



527
528
529
# File 'lib/stripe/params/payment_intent_update_params.rb', line 527

def description
  @description
end

#end_dateObject

End date of the mandate or subscription.



529
530
531
# File 'lib/stripe/params/payment_intent_update_params.rb', line 529

def end_date
  @end_date
end