Class: Stripe::PaymentIntentUpdateParams::PaymentMethodData::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodData::UsBankAccount
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Instance Attribute Summary collapse
-
#account_holder_type ⇒ Object
Account holder type: individual or company.
-
#account_number ⇒ Object
Account number of the bank account.
-
#account_type ⇒ Object
Account type: checkings or savings.
-
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
-
#routing_number ⇒ Object
Routing number of the bank account.
Instance Method Summary collapse
-
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
2679 2680 2681 2682 2683 2684 2685 2686 2687 2688 2689 2690 2691 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2679 def initialize( account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil ) @account_holder_type = account_holder_type @account_number = account_number @account_type = account_type @financial_connections_account = financial_connections_account @routing_number = routing_number end |
Instance Attribute Details
#account_holder_type ⇒ Object
Account holder type: individual or company.
2669 2670 2671 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2669 def account_holder_type @account_holder_type end |
#account_number ⇒ Object
Account number of the bank account.
2671 2672 2673 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2671 def account_number @account_number end |
#account_type ⇒ Object
Account type: checkings or savings. Defaults to checking if omitted.
2673 2674 2675 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2673 def account_type @account_type end |
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
2675 2676 2677 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2675 def financial_connections_account @financial_connections_account end |
#routing_number ⇒ Object
Routing number of the bank account.
2677 2678 2679 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2677 def routing_number @routing_number end |