Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::AcssDebit

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Defined Under Namespace

Classes: MandateOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(mandate_options: nil, setup_future_usage: nil, target_date: nil, verification_method: nil) ⇒ AcssDebit

Returns a new instance of AcssDebit.



3026
3027
3028
3029
3030
3031
3032
3033
3034
3035
3036
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3026

def initialize(
  mandate_options: nil,
  setup_future_usage: nil,
  target_date: nil,
  verification_method: nil
)
  @mandate_options = mandate_options
  @setup_future_usage = setup_future_usage
  @target_date = target_date
  @verification_method = verification_method
end

Instance Attribute Details

#mandate_optionsObject

Additional fields for Mandate creation



3010
3011
3012
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3010

def mandate_options
  @mandate_options
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent's payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.

If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.

When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.

If you've already set setup_future_usage and you're performing a request using a publishable key, you can only update the value from on_session to off_session.



3020
3021
3022
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3020

def setup_future_usage
  @setup_future_usage
end

#target_dateObject

Controls when Stripe will attempt to debit the funds from the customer's account. The date must be a string in YYYY-MM-DD format. The date must be in the future and between 3 and 15 calendar days from now.



3022
3023
3024
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3022

def target_date
  @target_date
end

#verification_methodObject

Bank account verification method. The default value is automatic.



3024
3025
3026
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3024

def verification_method
  @verification_method
end