Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Billie::CompanyDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Billie::CompanyDetails
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Defined Under Namespace
Classes: RegisteredAddress
Instance Attribute Summary collapse
-
#registered_address ⇒ Object
The address the company or entity is registered with.
-
#registered_name ⇒ Object
Company or entity name.
-
#registration_number ⇒ Object
The official registration number for the given registration type.
-
#registration_type ⇒ Object
Type of registration the company or entity holds in their registered country.
-
#vat ⇒ Object
VAT id number.
Instance Method Summary collapse
-
#initialize(registered_address: nil, registered_name: nil, registration_number: nil, registration_type: nil, vat: nil) ⇒ CompanyDetails
constructor
A new instance of CompanyDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(registered_address: nil, registered_name: nil, registration_number: nil, registration_type: nil, vat: nil) ⇒ CompanyDetails
Returns a new instance of CompanyDetails.
1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1108 def initialize( registered_address: nil, registered_name: nil, registration_number: nil, registration_type: nil, vat: nil ) @registered_address = registered_address @registered_name = registered_name @registration_number = registration_number @registration_type = registration_type @vat = vat end |
Instance Attribute Details
#registered_address ⇒ Object
The address the company or entity is registered with.
1098 1099 1100 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1098 def registered_address @registered_address end |
#registered_name ⇒ Object
Company or entity name.
1100 1101 1102 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1100 def registered_name @registered_name end |
#registration_number ⇒ Object
The official registration number for the given registration type.
1102 1103 1104 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1102 def registration_number @registration_number end |
#registration_type ⇒ Object
Type of registration the company or entity holds in their registered country.
1104 1105 1106 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1104 def registration_type @registration_type end |
#vat ⇒ Object
VAT id number
1106 1107 1108 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1106 def vat @vat end |