Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Blik

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(code: nil, setup_future_usage: nil) ⇒ Blik

Returns a new instance of Blik.



2834
2835
2836
2837
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2834

def initialize(code: nil, setup_future_usage: nil)
  @code = code
  @setup_future_usage = setup_future_usage
end

Instance Attribute Details

#codeObject

The 6-digit BLIK code that a customer has generated using their banking application. Can only be set on confirmation.



2822
2823
2824
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2822

def code
  @code
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent's payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.

If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.

When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.

If you've already set setup_future_usage and you're performing a request using a publishable key, you can only update the value from on_session to off_session.



2832
2833
2834
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2832

def setup_future_usage
  @setup_future_usage
end