Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Card::Installments::Plan

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(count: nil, interval: nil, type: nil) ⇒ Plan

Returns a new instance of Plan.



1103
1104
1105
1106
1107
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1103

def initialize(count: nil, interval: nil, type: nil)
  @count = count
  @interval = interval
  @type = type
end

Instance Attribute Details

#countObject

For fixed_count installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.



1096
1097
1098
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1096

def count
  @count
end

#intervalObject

For fixed_count installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of month.



1099
1100
1101
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1099

def interval
  @interval
end

#typeObject

Type of installment plan, one of fixed_count, bonus, or revolving.



1101
1102
1103
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1101

def type
  @type
end