Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Card::PaymentDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Card::PaymentDetails
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Defined Under Namespace
Classes: MoneyServices
Instance Attribute Summary collapse
-
#money_services ⇒ Object
Money services details for payment method specific funding fields.
Instance Method Summary collapse
-
#initialize(money_services: nil) ⇒ PaymentDetails
constructor
A new instance of PaymentDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(money_services: nil) ⇒ PaymentDetails
Returns a new instance of PaymentDetails.
3332 3333 3334 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3332 def initialize(money_services: nil) @money_services = money_services end |
Instance Attribute Details
#money_services ⇒ Object
Money services details for payment method specific funding fields.
3330 3331 3332 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3330 def money_services @money_services end |