Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::CardPresent

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Defined Under Namespace

Classes: CaptureDelay, PaymentDetails, Routing

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(capture_by: nil, capture_delay: nil, capture_method: nil, payment_details: nil, request_extended_authorization: nil, request_incremental_authorization_support: nil, request_multicapture: nil, request_reauthorization: nil, routing: nil) ⇒ CardPresent

Returns a new instance of CardPresent.



3691
3692
3693
3694
3695
3696
3697
3698
3699
3700
3701
3702
3703
3704
3705
3706
3707
3708
3709
3710
3711
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3691

def initialize(
  capture_by: nil,
  capture_delay: nil,
  capture_method: nil,
  payment_details: nil,
  request_extended_authorization: nil,
  request_incremental_authorization_support: nil,
  request_multicapture: nil,
  request_reauthorization: nil,
  routing: nil
)
  @capture_by = capture_by
  @capture_delay = capture_delay
  @capture_method = capture_method
  @payment_details = payment_details
  @request_extended_authorization = request_extended_authorization
  @request_incremental_authorization_support = request_incremental_authorization_support
  @request_multicapture = request_multicapture
  @request_reauthorization = request_reauthorization
  @routing = routing
end

Instance Attribute Details

#capture_byObject

Controls when funds are captured from the customer's account when capture_method is automatic_delayed.

If omitted, funds are captured before the authorization expires.



3667
3668
3669
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3667

def capture_by
  @capture_by
end

#capture_delayObject

The number of days or hours to delay the capture of the funds. You can set both days and hours as long as the total delay does not exceed 30 days.

You can only set this if capture_method is automatic_delayed and capture_by is target_delay.



3671
3672
3673
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3671

def capture_delay
  @capture_delay
end

#capture_methodObject

Controls when the funds are captured from the customer's account.

If provided, this parameter overrides the behavior of the top-level capture_method for this payment method type when finalizing the payment with this payment method type.

If capture_method is already set on the PaymentIntent, providing an empty value for this parameter unsets the stored value for this payment method type.



3677
3678
3679
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3677

def capture_method
  @capture_method
end

#payment_detailsObject

Payment details for payment method specific funding transaction fields.



3679
3680
3681
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3679

def payment_details
  @payment_details
end

#request_extended_authorizationObject

Request ability to capture this payment beyond the standard authorization validity window



3681
3682
3683
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3681

def request_extended_authorization
  @request_extended_authorization
end

#request_incremental_authorization_supportObject

Request ability to increment this PaymentIntent if the combination of MCC and card brand is eligible. Check incremental_authorization_supported in the Confirm response to verify support.



3683
3684
3685
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3683

def request_incremental_authorization_support
  @request_incremental_authorization_support
end

#request_multicaptureObject

Request ability to make multiple captures for this PaymentIntent.



3685
3686
3687
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3685

def request_multicapture
  @request_multicapture
end

#request_reauthorizationObject

Request ability to reauthorize for this PaymentIntent.



3687
3688
3689
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3687

def request_reauthorization
  @request_reauthorization
end

#routingObject

Network routing priority on co-branded EMV cards supporting domestic debit and international card schemes.



3689
3690
3691
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3689

def routing
  @routing
end