Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Crypto

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Defined Under Namespace

Classes: AmountReconciliation, DepositOptions, TransactionVerificationOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount_reconciliation: nil, deposit_options: nil, mode: nil, setup_future_usage: nil, transaction_verification_options: nil) ⇒ Crypto

Returns a new instance of Crypto.



3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
3800
3801
3802
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3790

def initialize(
  amount_reconciliation: nil,
  deposit_options: nil,
  mode: nil,
  setup_future_usage: nil,
  transaction_verification_options: nil
)
  @amount_reconciliation = amount_reconciliation
  @deposit_options = deposit_options
  @mode = mode
  @setup_future_usage = setup_future_usage
  @transaction_verification_options = transaction_verification_options
end

Instance Attribute Details

#amount_reconciliationObject

Controls how crypto funding amounts are reconciled for this PaymentIntent.



3772
3773
3774
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3772

def amount_reconciliation
  @amount_reconciliation
end

#deposit_optionsObject

Specific configuration for this PaymentIntent when the mode is deposit.



3774
3775
3776
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3774

def deposit_options
  @deposit_options
end

#modeObject

The mode of the crypto payment.



3776
3777
3778
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3776

def mode
  @mode
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent's payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.

If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.

When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.

If you've already set setup_future_usage and you're performing a request using a publishable key, you can only update the value from on_session to off_session.



3786
3787
3788
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3786

def setup_future_usage
  @setup_future_usage
end

#transaction_verification_optionsObject

Specific configuration for this PaymentIntent when the mode is transaction_verification.



3788
3789
3790
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3788

def transaction_verification_options
  @transaction_verification_options
end