Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::CustomerBalance::BankTransfer
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::CustomerBalance::BankTransfer
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Defined Under Namespace
Classes: EuBankTransfer
Instance Attribute Summary collapse
-
#eu_bank_transfer ⇒ Object
Configuration for the eu_bank_transfer funding type.
-
#requested_address_types ⇒ Object
List of address types that should be returned in the financial_addresses response.
-
#type ⇒ Object
The list of bank transfer types that this PaymentIntent is allowed to use for funding Permitted values include: ‘eu_bank_transfer`, `gb_bank_transfer`, `jp_bank_transfer`, `mx_bank_transfer`, or `us_bank_transfer`.
Instance Method Summary collapse
-
#initialize(eu_bank_transfer: nil, requested_address_types: nil, type: nil) ⇒ BankTransfer
constructor
A new instance of BankTransfer.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(eu_bank_transfer: nil, requested_address_types: nil, type: nil) ⇒ BankTransfer
Returns a new instance of BankTransfer.
3735 3736 3737 3738 3739 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3735 def initialize(eu_bank_transfer: nil, requested_address_types: nil, type: nil) @eu_bank_transfer = eu_bank_transfer @requested_address_types = requested_address_types @type = type end |
Instance Attribute Details
#eu_bank_transfer ⇒ Object
Configuration for the eu_bank_transfer funding type.
3727 3728 3729 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3727 def eu_bank_transfer @eu_bank_transfer end |
#requested_address_types ⇒ Object
List of address types that should be returned in the financial_addresses response. If not specified, all valid types will be returned.
Permitted values include: ‘sort_code`, `zengin`, `iban`, or `spei`.
3731 3732 3733 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3731 def requested_address_types @requested_address_types end |
#type ⇒ Object
The list of bank transfer types that this PaymentIntent is allowed to use for funding Permitted values include: ‘eu_bank_transfer`, `gb_bank_transfer`, `jp_bank_transfer`, `mx_bank_transfer`, or `us_bank_transfer`.
3733 3734 3735 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3733 def type @type end |