Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::OnDemand

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(average_amount: nil, maximum_amount: nil, minimum_amount: nil, purchase_interval: nil, purchase_interval_count: nil) ⇒ OnDemand

Returns a new instance of OnDemand.



4033
4034
4035
4036
4037
4038
4039
4040
4041
4042
4043
4044
4045
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4033

def initialize(
  average_amount: nil,
  maximum_amount: nil,
  minimum_amount: nil,
  purchase_interval: nil,
  purchase_interval_count: nil
)
  @average_amount = average_amount
  @maximum_amount = maximum_amount
  @minimum_amount = minimum_amount
  @purchase_interval = purchase_interval
  @purchase_interval_count = purchase_interval_count
end

Instance Attribute Details

#average_amountObject

Your average amount value. You can use a value across your customer base, or segment based on customer type, country, etc.



4023
4024
4025
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4023

def average_amount
  @average_amount
end

#maximum_amountObject

The maximum value you may charge a customer per purchase. You can use a value across your customer base, or segment based on customer type, country, etc.



4025
4026
4027
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4025

def maximum_amount
  @maximum_amount
end

#minimum_amountObject

The lowest or minimum value you may charge a customer per purchase. You can use a value across your customer base, or segment based on customer type, country, etc.



4027
4028
4029
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4027

def minimum_amount
  @minimum_amount
end

#purchase_intervalObject

Interval at which the customer is making purchases



4029
4030
4031
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4029

def purchase_interval
  @purchase_interval
end

#purchase_interval_countObject

The number of purchase_interval between charges



4031
4032
4033
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4031

def purchase_interval_count
  @purchase_interval_count
end