Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::Subscription
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::Subscription
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Defined Under Namespace
Classes: NextBilling
Instance Attribute Summary collapse
-
#interval ⇒ Object
Unit of time between subscription charges.
-
#interval_count ⇒ Object
The number of intervals (specified in the
intervalattribute) between subscription charges. -
#name ⇒ Object
Name for subscription.
-
#next_billing ⇒ Object
Describes the upcoming charge for this subscription.
-
#reference ⇒ Object
A non-customer-facing reference to correlate subscription charges in the Klarna app.
Instance Method Summary collapse
-
#initialize(interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil) ⇒ Subscription
constructor
A new instance of Subscription.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil) ⇒ Subscription
Returns a new instance of Subscription.
4071 4072 4073 4074 4075 4076 4077 4078 4079 4080 4081 4082 4083 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4071 def initialize( interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil ) @interval = interval @interval_count = interval_count @name = name @next_billing = next_billing @reference = reference end |
Instance Attribute Details
#interval ⇒ Object
Unit of time between subscription charges.
4061 4062 4063 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4061 def interval @interval end |
#interval_count ⇒ Object
The number of intervals (specified in the interval attribute) between subscription charges. For example, interval=month and interval_count=3 charges every 3 months.
4063 4064 4065 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4063 def interval_count @interval_count end |
#name ⇒ Object
Name for subscription.
4065 4066 4067 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4065 def name @name end |
#next_billing ⇒ Object
Describes the upcoming charge for this subscription.
4067 4068 4069 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4067 def next_billing @next_billing end |
#reference ⇒ Object
A non-customer-facing reference to correlate subscription charges in the Klarna app. Use a value that persists across subscription charges.
4069 4070 4071 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4069 def reference @reference end |