Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::Subscription::NextBilling

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, date: nil) ⇒ NextBilling

Returns a new instance of NextBilling.



3444
3445
3446
3447
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3444

def initialize(amount: nil, date: nil)
  @amount = amount
  @date = date
end

Instance Attribute Details

#amountObject

The amount of the next charge for the subscription.



3440
3441
3442
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3440

def amount
  @amount
end

#dateObject

The date of the next charge for the subscription in YYYY-MM-DD format.



3442
3443
3444
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3442

def date
  @date
end