Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::EventReservationDetail
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::EventReservationDetail
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
Address of the event.
-
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
-
#ends_at ⇒ Object
End timestamp of the event.
-
#event_company_name ⇒ Object
Company selling the ticket.
-
#event_name ⇒ Object
Name of the event.
-
#event_type ⇒ Object
Type of the event.
-
#insurances ⇒ Object
List of insurances for this event.
-
#starts_at ⇒ Object
Start timestamp of the event.
-
#venue_name ⇒ Object
Name of the venue where the event takes place.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate_name: nil, ends_at: nil, event_company_name: nil, event_name: nil, event_type: nil, insurances: nil, starts_at: nil, venue_name: nil) ⇒ EventReservationDetail
constructor
A new instance of EventReservationDetail.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate_name: nil, ends_at: nil, event_company_name: nil, event_name: nil, event_type: nil, insurances: nil, starts_at: nil, venue_name: nil) ⇒ EventReservationDetail
Returns a new instance of EventReservationDetail.
4326 4327 4328 4329 4330 4331 4332 4333 4334 4335 4336 4337 4338 4339 4340 4341 4342 4343 4344 4345 4346 4347 4348 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4326 def initialize( access_controlled_venue: nil, address: nil, affiliate_name: nil, ends_at: nil, event_company_name: nil, event_name: nil, event_type: nil, insurances: nil, starts_at: nil, venue_name: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate_name = affiliate_name @ends_at = ends_at @event_company_name = event_company_name @event_name = event_name @event_type = event_type @insurances = insurances @starts_at = starts_at @venue_name = venue_name end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
4306 4307 4308 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4306 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
Address of the event.
4308 4309 4310 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4308 def address @address end |
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
4310 4311 4312 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4310 def affiliate_name @affiliate_name end |
#ends_at ⇒ Object
End timestamp of the event.
4312 4313 4314 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4312 def ends_at @ends_at end |
#event_company_name ⇒ Object
Company selling the ticket.
4314 4315 4316 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4314 def event_company_name @event_company_name end |
#event_name ⇒ Object
Name of the event.
4316 4317 4318 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4316 def event_name @event_name end |
#event_type ⇒ Object
Type of the event.
4318 4319 4320 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4318 def event_type @event_type end |
#insurances ⇒ Object
List of insurances for this event.
4320 4321 4322 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4320 def insurances @insurances end |
#starts_at ⇒ Object
Start timestamp of the event.
4322 4323 4324 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4322 def starts_at @starts_at end |
#venue_name ⇒ Object
Name of the venue where the event takes place.
4324 4325 4326 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4324 def venue_name @venue_name end |