Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::EventReservationDetail::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::EventReservationDetail::Address
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
3655 3656 3657 3658 3659 3660 3661 3662 3663 3664 3665 3666 3667 3668 3669 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3655 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
3643 3644 3645 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3643 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
3645 3646 3647 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3645 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
3647 3648 3649 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3647 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
3649 3650 3651 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3649 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
3651 3652 3653 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3651 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
3653 3654 3655 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3653 def street_address2 @street_address2 end |