Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::FerryReservationDetail
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::FerryReservationDetail
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Defined Under Namespace
Classes: Arrival, Departure, Insurance, Passenger
Instance Attribute Summary collapse
-
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
-
#arrival ⇒ Object
Arrival details.
-
#carrier_name ⇒ Object
Name of transportation company.
-
#currency ⇒ Object
Currency.
-
#departure ⇒ Object
Departure details.
-
#insurances ⇒ Object
List of insurances for this reservation.
-
#passengers ⇒ Object
List of passengers that this reservation applies to.
-
#price ⇒ Object
Price in cents.
-
#ticket_class ⇒ Object
Ticket class.
Instance Method Summary collapse
-
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ FerryReservationDetail
constructor
A new instance of FerryReservationDetail.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ FerryReservationDetail
Returns a new instance of FerryReservationDetail.
4492 4493 4494 4495 4496 4497 4498 4499 4500 4501 4502 4503 4504 4505 4506 4507 4508 4509 4510 4511 4512 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4492 def initialize( affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil ) @affiliate_name = affiliate_name @arrival = arrival @carrier_name = carrier_name @currency = currency @departure = departure @insurances = insurances @passengers = passengers @price = price @ticket_class = ticket_class end |
Instance Attribute Details
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
4474 4475 4476 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4474 def affiliate_name @affiliate_name end |
#arrival ⇒ Object
Arrival details.
4476 4477 4478 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4476 def arrival @arrival end |
#carrier_name ⇒ Object
Name of transportation company.
4478 4479 4480 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4478 def carrier_name @carrier_name end |
#currency ⇒ Object
Currency.
4480 4481 4482 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4480 def currency @currency end |
#departure ⇒ Object
Departure details.
4482 4483 4484 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4482 def departure @departure end |
#insurances ⇒ Object
List of insurances for this reservation.
4484 4485 4486 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4484 def insurances @insurances end |
#passengers ⇒ Object
List of passengers that this reservation applies to.
4486 4487 4488 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4486 def passengers @passengers end |
#price ⇒ Object
Price in cents.
4488 4489 4490 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4488 def price @price end |
#ticket_class ⇒ Object
Ticket class.
4490 4491 4492 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4490 def ticket_class @ticket_class end |