Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::MarketplaceSeller::MarketplaceSellerAddress
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::MarketplaceSeller::MarketplaceSellerAddress
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ MarketplaceSellerAddress
constructor
A new instance of MarketplaceSellerAddress.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ MarketplaceSellerAddress
Returns a new instance of MarketplaceSellerAddress.
4454 4455 4456 4457 4458 4459 4460 4461 4462 4463 4464 4465 4466 4467 4468 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4454 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
4442 4443 4444 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4442 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
4444 4445 4446 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4444 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
4446 4447 4448 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4446 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
4448 4449 4450 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4448 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
4450 4451 4452 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4450 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
4452 4453 4454 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4452 def street_address2 @street_address2 end |