Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::RoundTripReservationDetail::Arrival::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::RoundTripReservationDetail::Arrival::Address
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
4583 4584 4585 4586 4587 4588 4589 4590 4591 4592 4593 4594 4595 4596 4597 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4583 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
4571 4572 4573 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4571 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
4573 4574 4575 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4573 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
4575 4576 4577 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4575 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
4577 4578 4579 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4577 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
4579 4580 4581 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4579 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
4581 4582 4583 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4581 def street_address2 @street_address2 end |