Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::RoundTripReservationDetail::Departure::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::RoundTripReservationDetail::Departure::Address
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
4681 4682 4683 4684 4685 4686 4687 4688 4689 4690 4691 4692 4693 4694 4695 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4681 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
4669 4670 4671 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4669 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
4671 4672 4673 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4671 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
4673 4674 4675 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4673 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
4675 4676 4677 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4675 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
4677 4678 4679 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4677 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
4679 4680 4681 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4679 def street_address2 @street_address2 end |