Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::Voucher
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::Voucher
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Instance Attribute Summary collapse
-
#affiliate_name ⇒ Object
Name of associated or partner company for this voucher.
-
#ends_at ⇒ Object
The voucher validity end time.
-
#starts_at ⇒ Object
The voucher validity start time.
-
#voucher_company ⇒ Object
The issuer or provider of this voucher.
-
#voucher_name ⇒ Object
The name or reference to identify the voucher.
-
#voucher_type ⇒ Object
The type of this voucher.
Instance Method Summary collapse
-
#initialize(affiliate_name: nil, ends_at: nil, starts_at: nil, voucher_company: nil, voucher_name: nil, voucher_type: nil) ⇒ Voucher
constructor
A new instance of Voucher.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate_name: nil, ends_at: nil, starts_at: nil, voucher_company: nil, voucher_name: nil, voucher_type: nil) ⇒ Voucher
Returns a new instance of Voucher.
4965 4966 4967 4968 4969 4970 4971 4972 4973 4974 4975 4976 4977 4978 4979 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4965 def initialize( affiliate_name: nil, ends_at: nil, starts_at: nil, voucher_company: nil, voucher_name: nil, voucher_type: nil ) @affiliate_name = affiliate_name @ends_at = ends_at @starts_at = starts_at @voucher_company = voucher_company @voucher_name = voucher_name @voucher_type = voucher_type end |
Instance Attribute Details
#affiliate_name ⇒ Object
Name of associated or partner company for this voucher.
4953 4954 4955 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4953 def affiliate_name @affiliate_name end |
#ends_at ⇒ Object
The voucher validity end time.
4955 4956 4957 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4955 def ends_at @ends_at end |
#starts_at ⇒ Object
The voucher validity start time.
4957 4958 4959 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4957 def starts_at @starts_at end |
#voucher_company ⇒ Object
The issuer or provider of this voucher.
4959 4960 4961 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4959 def voucher_company @voucher_company end |
#voucher_name ⇒ Object
The name or reference to identify the voucher.
4961 4962 4963 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4961 def voucher_name @voucher_name end |
#voucher_type ⇒ Object
The type of this voucher.
4963 4964 4965 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4963 def voucher_type @voucher_type end |