Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::P24
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::P24
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Instance Attribute Summary collapse
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
-
#tos_shown_and_accepted ⇒ Object
Confirm that the payer has accepted the P24 terms and conditions.
Instance Method Summary collapse
-
#initialize(setup_future_usage: nil, tos_shown_and_accepted: nil) ⇒ P24
constructor
A new instance of P24.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(setup_future_usage: nil, tos_shown_and_accepted: nil) ⇒ P24
Returns a new instance of P24.
4667 4668 4669 4670 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4667 def initialize(setup_future_usage: nil, tos_shown_and_accepted: nil) @setup_future_usage = setup_future_usage @tos_shown_and_accepted = tos_shown_and_accepted end |
Instance Attribute Details
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.
If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.
When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).
If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.
4663 4664 4665 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4663 def setup_future_usage @setup_future_usage end |
#tos_shown_and_accepted ⇒ Object
Confirm that the payer has accepted the P24 terms and conditions.
4665 4666 4667 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4665 def tos_shown_and_accepted @tos_shown_and_accepted end |