Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Payco

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(capture_method: nil) ⇒ Payco

Returns a new instance of Payco.



1868
1869
1870
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1868

def initialize(capture_method: nil)
  @capture_method = capture_method
end

Instance Attribute Details

#capture_methodObject

Controls when the funds are captured from the customer’s account.

If provided, this parameter overrides the behavior of the top-level [capture_method](/api/payment_intents/update#update_payment_intent-capture_method) for this payment method type when finalizing the payment with this payment method type.

If capture_method is already set on the PaymentIntent, providing an empty value for this parameter unsets the stored value for this payment method type.



1866
1867
1868
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1866

def capture_method
  @capture_method
end