Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Paypal

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(capture_method: nil, preferred_locale: nil, reference: nil, risk_correlation_id: nil, setup_future_usage: nil) ⇒ Paypal

Returns a new instance of Paypal.



1910
1911
1912
1913
1914
1915
1916
1917
1918
1919
1920
1921
1922
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1910

def initialize(
  capture_method: nil,
  preferred_locale: nil,
  reference: nil,
  risk_correlation_id: nil,
  setup_future_usage: nil
)
  @capture_method = capture_method
  @preferred_locale = preferred_locale
  @reference = reference
  @risk_correlation_id = risk_correlation_id
  @setup_future_usage = setup_future_usage
end

Instance Attribute Details

#capture_methodObject

Controls when the funds will be captured from the customer’s account.



1892
1893
1894
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1892

def capture_method
  @capture_method
end

#preferred_localeObject

[Preferred locale](docs.stripe.com/payments/paypal/supported-locales) of the PayPal checkout page that the customer is redirected to.



1894
1895
1896
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1894

def preferred_locale
  @preferred_locale
end

#referenceObject

A reference of the PayPal transaction visible to customer which is mapped to PayPal’s invoice ID. This must be a globally unique ID if you have configured in your PayPal settings to block multiple payments per invoice ID.



1896
1897
1898
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1896

def reference
  @reference
end

#risk_correlation_idObject

The risk correlation ID for an on-session payment using a saved PayPal payment method.



1898
1899
1900
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1898

def risk_correlation_id
  @risk_correlation_id
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent’s payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.

If the payment method is card_present and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.

When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).

If you’ve already set setup_future_usage and you’re performing a request using a publishable key, you can only update the value from on_session to off_session.



1908
1909
1910
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1908

def setup_future_usage
  @setup_future_usage
end