Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Defined Under Namespace
Classes: Tax
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#name ⇒ Object
Descriptive name of the line item.
-
#quantity ⇒ Object
Quantity of the line item.
-
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
The tax information for the line item.
-
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
Returns a new instance of LineItem.
5290 5291 5292 5293 5294 5295 5296 5297 5298 5299 5300 5301 5302 5303 5304 5305 5306 5307 5308 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5290 def initialize( category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil ) @category = category @description = description @name = name @quantity = quantity @sku = sku @sold_by = sold_by @tax = tax @unit_amount = unit_amount end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
5274 5275 5276 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5274 def category @category end |
#description ⇒ Object
Description of the line item.
5276 5277 5278 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5276 def description @description end |
#name ⇒ Object
Descriptive name of the line item.
5278 5279 5280 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5278 def name @name end |
#quantity ⇒ Object
Quantity of the line item. Must be a positive number.
5280 5281 5282 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5280 def quantity @quantity end |
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
5282 5283 5284 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5282 def sku @sku end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
5284 5285 5286 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5284 def sold_by @sold_by end |
#tax ⇒ Object
The tax information for the line item.
5286 5287 5288 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5286 def tax @tax end |
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units. Cannot be a negative number.
5288 5289 5290 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5288 def unit_amount @unit_amount end |