Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Paypal::LineItem::Tax
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Paypal::LineItem::Tax
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The tax for a single unit of the line item in minor units.
-
#behavior ⇒ Object
The tax behavior for the line item.
Instance Method Summary collapse
-
#initialize(amount: nil, behavior: nil) ⇒ Tax
constructor
A new instance of Tax.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, behavior: nil) ⇒ Tax
Returns a new instance of Tax.
4756 4757 4758 4759 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4756 def initialize(amount: nil, behavior: nil) @amount = amount @behavior = behavior end |
Instance Attribute Details
#amount ⇒ Object
The tax for a single unit of the line item in minor units. Cannot be a negative number.
4752 4753 4754 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4752 def amount @amount end |
#behavior ⇒ Object
The tax behavior for the line item.
4754 4755 4756 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4754 def behavior @behavior end |