Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Pix
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Pix
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Instance Attribute Summary collapse
-
#amount_includes_iof ⇒ Object
Determines if the amount includes the IOF tax.
-
#expires_after_seconds ⇒ Object
The number of seconds (between 10 and 1209600) after which Pix payment will expire.
-
#expires_at ⇒ Object
The timestamp at which the Pix expires (between 10 and 1209600 seconds in the future).
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
Instance Method Summary collapse
-
#initialize(amount_includes_iof: nil, expires_after_seconds: nil, expires_at: nil, setup_future_usage: nil) ⇒ Pix
constructor
A new instance of Pix.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount_includes_iof: nil, expires_after_seconds: nil, expires_at: nil, setup_future_usage: nil) ⇒ Pix
Returns a new instance of Pix.
2021 2022 2023 2024 2025 2026 2027 2028 2029 2030 2031 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2021 def initialize( amount_includes_iof: nil, expires_after_seconds: nil, expires_at: nil, setup_future_usage: nil ) @amount_includes_iof = amount_includes_iof @expires_after_seconds = expires_after_seconds @expires_at = expires_at @setup_future_usage = setup_future_usage end |
Instance Attribute Details
#amount_includes_iof ⇒ Object
Determines if the amount includes the IOF tax. Defaults to never.
2005 2006 2007 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2005 def amount_includes_iof @amount_includes_iof end |
#expires_after_seconds ⇒ Object
The number of seconds (between 10 and 1209600) after which Pix payment will expire. Defaults to 86400 seconds.
2007 2008 2009 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2007 def expires_after_seconds @expires_after_seconds end |
#expires_at ⇒ Object
The timestamp at which the Pix expires (between 10 and 1209600 seconds in the future). Defaults to 1 day in the future.
2009 2010 2011 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2009 def expires_at @expires_at end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.
If the payment method is card_present and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.
When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).
If you’ve already set setup_future_usage and you’re performing a request using a publishable key, you can only update the value from on_session to off_session.
2019 2020 2021 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2019 def setup_future_usage @setup_future_usage end |