Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Pix::MandateOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Pix::MandateOptions
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount to be charged for future payments.
-
#amount_includes_iof ⇒ Object
Determines if the amount includes the IOF tax.
-
#amount_type ⇒ Object
Type of amount.
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#end_date ⇒ Object
Date when the mandate expires and no further payments will be charged, in ‘YYYY-MM-DD`.
-
#payment_schedule ⇒ Object
Schedule at which the future payments will be charged.
-
#reference ⇒ Object
Subscription name displayed to buyers in their bank app.
-
#start_date ⇒ Object
Start date of the mandate, in ‘YYYY-MM-DD`.
Instance Method Summary collapse
-
#initialize(amount: nil, amount_includes_iof: nil, amount_type: nil, currency: nil, end_date: nil, payment_schedule: nil, reference: nil, start_date: nil) ⇒ MandateOptions
constructor
A new instance of MandateOptions.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, amount_includes_iof: nil, amount_type: nil, currency: nil, end_date: nil, payment_schedule: nil, reference: nil, start_date: nil) ⇒ MandateOptions
Returns a new instance of MandateOptions.
5412 5413 5414 5415 5416 5417 5418 5419 5420 5421 5422 5423 5424 5425 5426 5427 5428 5429 5430 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5412 def initialize( amount: nil, amount_includes_iof: nil, amount_type: nil, currency: nil, end_date: nil, payment_schedule: nil, reference: nil, start_date: nil ) @amount = amount @amount_includes_iof = amount_includes_iof @amount_type = amount_type @currency = currency @end_date = end_date @payment_schedule = payment_schedule @reference = reference @start_date = start_date end |
Instance Attribute Details
#amount ⇒ Object
Amount to be charged for future payments. Required when ‘amount_type=fixed`. If not provided for `amount_type=maximum`, defaults to 40000.
5396 5397 5398 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5396 def amount @amount end |
#amount_includes_iof ⇒ Object
Determines if the amount includes the IOF tax. Defaults to ‘never`.
5398 5399 5400 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5398 def amount_includes_iof @amount_includes_iof end |
#amount_type ⇒ Object
Type of amount. Defaults to ‘maximum`.
5400 5401 5402 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5400 def amount_type @amount_type end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Only ‘brl` is supported currently.
5402 5403 5404 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5402 def currency @currency end |
#end_date ⇒ Object
Date when the mandate expires and no further payments will be charged, in ‘YYYY-MM-DD`. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.
5404 5405 5406 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5404 def end_date @end_date end |
#payment_schedule ⇒ Object
Schedule at which the future payments will be charged. Defaults to ‘monthly`.
5406 5407 5408 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5406 def payment_schedule @payment_schedule end |
#reference ⇒ Object
Subscription name displayed to buyers in their bank app. Defaults to the displayable business name.
5408 5409 5410 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5408 def reference @reference end |
#start_date ⇒ Object
Start date of the mandate, in ‘YYYY-MM-DD`. Start date should be at least 3 days in the future. Defaults to 3 days after the current date.
5410 5411 5412 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5410 def start_date @start_date end |