Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Shopeepay

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(setup_future_usage: nil) ⇒ Shopeepay

Returns a new instance of Shopeepay.



5114
5115
5116
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5114

def initialize(setup_future_usage: nil)
  @setup_future_usage = setup_future_usage
end

Instance Attribute Details

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent's payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.

If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.

When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.

If you've already set setup_future_usage and you're performing a request using a publishable key, you can only update the value from on_session to off_session.



5112
5113
5114
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5112

def setup_future_usage
  @setup_future_usage
end