Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Upi::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



2198
2199
2200
2201
2202
2203
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2198

def initialize(amount: nil, amount_type: nil, description: nil, end_date: nil)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



2190
2191
2192
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2190

def amount
  @amount
end

#amount_typeObject

One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.



2192
2193
2194
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2192

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



2194
2195
2196
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2194

def description
  @description
end

#end_dateObject

End date of the mandate or subscription.



2196
2197
2198
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2196

def end_date
  @end_date
end