Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::UsBankAccount::FinancialConnections

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Defined Under Namespace

Classes: Filters, ManualEntry

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections

Returns a new instance of FinancialConnections.



5726
5727
5728
5729
5730
5731
5732
5733
5734
5735
5736
5737
5738
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5726

def initialize(
  filters: nil,
  manual_entry: nil,
  permissions: nil,
  prefetch: nil,
  return_url: nil
)
  @filters = filters
  @manual_entry = manual_entry
  @permissions = permissions
  @prefetch = prefetch
  @return_url = return_url
end

Instance Attribute Details

#filtersObject

Provide filters for the linked accounts that the customer can select for the payment method.



5716
5717
5718
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5716

def filters
  @filters
end

#manual_entryObject

Customize manual entry behavior



5718
5719
5720
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5718

def manual_entry
  @manual_entry
end

#permissionsObject

The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.



5720
5721
5722
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5720

def permissions
  @permissions
end

#prefetchObject

List of data features that you would like to retrieve upon account creation.



5722
5723
5724
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5722

def prefetch
  @prefetch
end

#return_urlObject

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



5724
5725
5726
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5724

def return_url
  @return_url
end