Class: Stripe::PaymentIntentUpdateParams::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping



2601
2602
2603
2604
2605
2606
2607
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2601

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



2591
2592
2593
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2591

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



2593
2594
2595
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2593

def carrier
  @carrier
end

#nameObject

Recipient name.



2595
2596
2597
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2595

def name
  @name
end

#phoneObject

Recipient phone (including extension).



2597
2598
2599
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2597

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



2599
2600
2601
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2599

def tracking_number
  @tracking_number
end