Class: Stripe::PaymentIntentUpdateParams::TransferData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::TransferData
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount that will be transferred automatically when a charge succeeds.
Instance Method Summary collapse
-
#initialize(amount: nil) ⇒ TransferData
constructor
A new instance of TransferData.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil) ⇒ TransferData
Returns a new instance of TransferData.
2614 2615 2616 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2614 def initialize(amount: nil) @amount = amount end |
Instance Attribute Details
#amount ⇒ Object
The amount that will be transferred automatically when a charge succeeds.
2612 2613 2614 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2612 def amount @amount end |