Class: Stripe::PaymentIntentUpdateParams::TransferData::PaymentData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(description: nil, metadata: nil) ⇒ PaymentData

Returns a new instance of PaymentData.



2748
2749
2750
2751
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2748

def initialize(description: nil, metadata: nil)
  @description = description
  @metadata = 
end

Instance Attribute Details

#descriptionObject

An arbitrary string attached to the destination payment. Often useful for displaying to users.



2744
2745
2746
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2744

def description
  @description
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



2746
2747
2748
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2746

def 
  @metadata
end