Class: Stripe::PaymentLink::AutomaticSurcharge

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_link.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#calculation_basisObject (readonly)

Determines which amount serves as the basis for calculating the surcharge.



64
65
66
# File 'lib/stripe/resources/payment_link.rb', line 64

def calculation_basis
  @calculation_basis
end

#enabledObject (readonly)

Indicates whether automatic surcharge is enabled for the payment link.



66
67
68
# File 'lib/stripe/resources/payment_link.rb', line 66

def enabled
  @enabled
end

#providerObject (readonly)

The surcharge provider used for this payment link.



68
69
70
# File 'lib/stripe/resources/payment_link.rb', line 68

def provider
  @provider
end

#tax_behaviorObject (readonly)

Specifies whether the surcharge is considered inclusive or exclusive of taxes.



70
71
72
# File 'lib/stripe/resources/payment_link.rb', line 70

def tax_behavior
  @tax_behavior
end

Class Method Details

.field_remappingsObject



76
77
78
# File 'lib/stripe/resources/payment_link.rb', line 76

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



72
73
74
# File 'lib/stripe/resources/payment_link.rb', line 72

def self.inner_class_types
  @inner_class_types = {}
end