Class: Stripe::PaymentLink::ConsentCollection
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentLink::ConsentCollection
- Defined in:
- lib/stripe/resources/payment_link.rb
Defined Under Namespace
Classes: PaymentMethodReuseAgreement
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#payment_method_reuse_agreement ⇒ Object
readonly
Settings related to the payment method reuse text shown in the Checkout UI.
-
#promotions ⇒ Object
readonly
If set to
auto, enables the collection of customer consent for promotional communications. -
#terms_of_service ⇒ Object
readonly
If set to
required, it requires cutomers to accept the terms of service before being able to pay.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#payment_method_reuse_agreement ⇒ Object (readonly)
Settings related to the payment method reuse text shown in the Checkout UI.
107 108 109 |
# File 'lib/stripe/resources/payment_link.rb', line 107 def payment_method_reuse_agreement @payment_method_reuse_agreement end |
#promotions ⇒ Object (readonly)
If set to auto, enables the collection of customer consent for promotional communications.
109 110 111 |
# File 'lib/stripe/resources/payment_link.rb', line 109 def promotions @promotions end |
#terms_of_service ⇒ Object (readonly)
If set to required, it requires cutomers to accept the terms of service before being able to pay. If set to none, customers won’t be shown a checkbox to accept the terms of service.
111 112 113 |
# File 'lib/stripe/resources/payment_link.rb', line 111 def terms_of_service @terms_of_service end |
Class Method Details
.field_remappings ⇒ Object
117 118 119 |
# File 'lib/stripe/resources/payment_link.rb', line 117 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
113 114 115 |
# File 'lib/stripe/resources/payment_link.rb', line 113 def self.inner_class_types @inner_class_types = { payment_method_reuse_agreement: PaymentMethodReuseAgreement } end |