Class: Stripe::PaymentLink::ConsentCollection::PaymentMethodReuseAgreement

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_link.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#positionObject (readonly)

Determines the position and visibility of the payment method reuse agreement in the UI. When set to auto, Stripe's defaults will be used.

When set to hidden, the payment method reuse agreement text will always be hidden in the UI.



115
116
117
# File 'lib/stripe/resources/payment_link.rb', line 115

def position
  @position
end

Class Method Details

.field_remappingsObject



121
122
123
# File 'lib/stripe/resources/payment_link.rb', line 121

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



117
118
119
# File 'lib/stripe/resources/payment_link.rb', line 117

def self.inner_class_types
  @inner_class_types = {}
end