Class: Stripe::PaymentLink::CreateParams::ConsentCollection::PaymentMethodReuseAgreement

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_link.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(position: nil) ⇒ PaymentMethodReuseAgreement

Returns a new instance of PaymentMethodReuseAgreement.



386
387
388
# File 'lib/stripe/resources/payment_link.rb', line 386

def initialize(position: nil)
  @position = position
end

Instance Attribute Details

#positionObject

Determines the position and visibility of the payment method reuse agreement in the UI. When set to ‘auto`, Stripe’s defaults will be used. When set to ‘hidden`, the payment method reuse agreement text will always be hidden in the UI.



384
385
386
# File 'lib/stripe/resources/payment_link.rb', line 384

def position
  @position
end