Class: Stripe::PaymentLink::CreateParams::CustomText
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentLink::CreateParams::CustomText
- Defined in:
- lib/stripe/resources/payment_link.rb
Defined Under Namespace
Classes: AfterSubmit, ShippingAddress, Submit, TermsOfServiceAcceptance
Instance Attribute Summary collapse
-
#after_submit ⇒ Object
Custom text that should be displayed after the payment confirmation button.
-
#shipping_address ⇒ Object
Custom text that should be displayed alongside shipping address collection.
-
#submit ⇒ Object
Custom text that should be displayed alongside the payment confirmation button.
-
#terms_of_service_acceptance ⇒ Object
Custom text that should be displayed in place of the default terms of service agreement text.
Instance Method Summary collapse
-
#initialize(after_submit: nil, shipping_address: nil, submit: nil, terms_of_service_acceptance: nil) ⇒ CustomText
constructor
A new instance of CustomText.
Methods inherited from RequestParams
Constructor Details
#initialize(after_submit: nil, shipping_address: nil, submit: nil, terms_of_service_acceptance: nil) ⇒ CustomText
Returns a new instance of CustomText.
517 518 519 520 521 522 523 524 525 526 527 |
# File 'lib/stripe/resources/payment_link.rb', line 517 def initialize( after_submit: nil, shipping_address: nil, submit: nil, terms_of_service_acceptance: nil ) @after_submit = after_submit @shipping_address = shipping_address @submit = submit @terms_of_service_acceptance = terms_of_service_acceptance end |
Instance Attribute Details
#after_submit ⇒ Object
Custom text that should be displayed after the payment confirmation button.
509 510 511 |
# File 'lib/stripe/resources/payment_link.rb', line 509 def after_submit @after_submit end |
#shipping_address ⇒ Object
Custom text that should be displayed alongside shipping address collection.
511 512 513 |
# File 'lib/stripe/resources/payment_link.rb', line 511 def shipping_address @shipping_address end |
#submit ⇒ Object
Custom text that should be displayed alongside the payment confirmation button.
513 514 515 |
# File 'lib/stripe/resources/payment_link.rb', line 513 def submit @submit end |
#terms_of_service_acceptance ⇒ Object
Custom text that should be displayed in place of the default terms of service agreement text.
515 516 517 |
# File 'lib/stripe/resources/payment_link.rb', line 515 def terms_of_service_acceptance @terms_of_service_acceptance end |