Class: Stripe::PaymentLink::CreateParams::InvoiceCreation::InvoiceData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_link.rb

Defined Under Namespace

Classes: CustomField, Issuer, RenderingOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_tax_ids: nil, custom_fields: nil, description: nil, footer: nil, issuer: nil, metadata: nil, rendering_options: nil) ⇒ InvoiceData

Returns a new instance of InvoiceData.



929
930
931
932
933
934
935
936
937
938
939
940
941
942
943
944
945
# File 'lib/stripe/resources/payment_link.rb', line 929

def initialize(
  account_tax_ids: nil,
  custom_fields: nil,
  description: nil,
  footer: nil,
  issuer: nil,
  metadata: nil,
  rendering_options: nil
)
  @account_tax_ids = 
  @custom_fields = custom_fields
  @description = description
  @footer = footer
  @issuer = issuer
  @metadata = 
  @rendering_options = rendering_options
end

Instance Attribute Details

#account_tax_idsObject

The account tax IDs associated with the invoice.



915
916
917
# File 'lib/stripe/resources/payment_link.rb', line 915

def 
  @account_tax_ids
end

#custom_fieldsObject

Default custom fields to be displayed on invoices for this customer.



917
918
919
# File 'lib/stripe/resources/payment_link.rb', line 917

def custom_fields
  @custom_fields
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



919
920
921
# File 'lib/stripe/resources/payment_link.rb', line 919

def description
  @description
end

Default footer to be displayed on invoices for this customer.



921
922
923
# File 'lib/stripe/resources/payment_link.rb', line 921

def footer
  @footer
end

#issuerObject

The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.



923
924
925
# File 'lib/stripe/resources/payment_link.rb', line 923

def issuer
  @issuer
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



925
926
927
# File 'lib/stripe/resources/payment_link.rb', line 925

def 
  @metadata
end

#rendering_optionsObject

Default options for invoice PDF rendering for this customer.



927
928
929
# File 'lib/stripe/resources/payment_link.rb', line 927

def rendering_options
  @rendering_options
end