Class: Stripe::PaymentLink::CreateParams::LineItem::PriceData::ProductData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_link.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil) ⇒ ProductData

Returns a new instance of ProductData.



987
988
989
990
991
992
993
# File 'lib/stripe/resources/payment_link.rb', line 987

def initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil)
  @description = description
  @images = images
  @metadata = 
  @name = name
  @tax_code = tax_code
end

Instance Attribute Details

#descriptionObject

The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.



977
978
979
# File 'lib/stripe/resources/payment_link.rb', line 977

def description
  @description
end

#imagesObject

A list of up to 8 URLs of images for this product, meant to be displayable to the customer.



979
980
981
# File 'lib/stripe/resources/payment_link.rb', line 979

def images
  @images
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



981
982
983
# File 'lib/stripe/resources/payment_link.rb', line 981

def 
  @metadata
end

#nameObject

The product’s name, meant to be displayable to the customer.



983
984
985
# File 'lib/stripe/resources/payment_link.rb', line 983

def name
  @name
end

#tax_codeObject



985
986
987
# File 'lib/stripe/resources/payment_link.rb', line 985

def tax_code
  @tax_code
end