Class: Stripe::PaymentLink::CreateParams::PaymentIntentData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_link.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(capture_method: nil, description: nil, metadata: nil, setup_future_usage: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_group: nil) ⇒ PaymentIntentData

Returns a new instance of PaymentIntentData.



1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
1126
1127
1128
1129
1130
# File 'lib/stripe/resources/payment_link.rb', line 1114

def initialize(
  capture_method: nil,
  description: nil,
  metadata: nil,
  setup_future_usage: nil,
  statement_descriptor: nil,
  statement_descriptor_suffix: nil,
  transfer_group: nil
)
  @capture_method = capture_method
  @description = description
  @metadata = 
  @setup_future_usage = setup_future_usage
  @statement_descriptor = statement_descriptor
  @statement_descriptor_suffix = statement_descriptor_suffix
  @transfer_group = transfer_group
end

Instance Attribute Details

#capture_methodObject

Controls when the funds will be captured from the customer’s account.



1088
1089
1090
# File 'lib/stripe/resources/payment_link.rb', line 1088

def capture_method
  @capture_method
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



1090
1091
1092
# File 'lib/stripe/resources/payment_link.rb', line 1090

def description
  @description
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that will declaratively set metadata on [Payment Intents](stripe.com/docs/api/payment_intents) generated from this payment link. Unlike object-level metadata, this field is declarative. Updates will clear prior values.



1092
1093
1094
# File 'lib/stripe/resources/payment_link.rb', line 1092

def 
  @metadata
end

#setup_future_usageObject

Indicates that you intend to [make future payments](stripe.com/docs/payments/payment-intents#future-usage) with the payment method collected by this Checkout Session.

When setting this to ‘on_session`, Checkout will show a notice to the customer that their payment details will be saved.

When setting this to ‘off_session`, Checkout will show a notice to the customer that their payment details will be saved and used for future payments.

If a Customer has been provided or Checkout creates a new Customer,Checkout will attach the payment method to the Customer.

If Checkout does not create a Customer, the payment method is not attached to a Customer. To reuse the payment method, you can retrieve it from the Checkout Session’s PaymentIntent.

When processing card payments, Checkout also uses ‘setup_future_usage` to dynamically optimize your payment flow and comply with regional legislation and network rules, such as SCA.



1104
1105
1106
# File 'lib/stripe/resources/payment_link.rb', line 1104

def setup_future_usage
  @setup_future_usage
end

#statement_descriptorObject

Text that appears on the customer’s statement as the statement descriptor for a non-card charge. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).

Setting this value for a card charge returns an error. For card charges, set the [statement_descriptor_suffix](docs.stripe.com/get-started/account/statement-descriptors#dynamic) instead.



1108
1109
1110
# File 'lib/stripe/resources/payment_link.rb', line 1108

def statement_descriptor
  @statement_descriptor
end

#statement_descriptor_suffixObject

Provides information about a card charge. Concatenated to the account’s [statement descriptor prefix](docs.stripe.com/get-started/account/statement-descriptors#static) to form the complete statement descriptor that appears on the customer’s statement.



1110
1111
1112
# File 'lib/stripe/resources/payment_link.rb', line 1110

def statement_descriptor_suffix
  @statement_descriptor_suffix
end

#transfer_groupObject

A string that identifies the resulting payment as part of a group. See the PaymentIntents [use case for connected accounts](stripe.com/docs/connect/separate-charges-and-transfers) for details.



1112
1113
1114
# File 'lib/stripe/resources/payment_link.rb', line 1112

def transfer_group
  @transfer_group
end