Class: Stripe::PaymentLink::CreateParams::SubscriptionData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_link.rb

Defined Under Namespace

Classes: InvoiceSettings, TrialSettings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, invoice_settings: nil, metadata: nil, trial_period_days: nil, trial_settings: nil) ⇒ SubscriptionData

Returns a new instance of SubscriptionData.



1226
1227
1228
1229
1230
1231
1232
1233
1234
1235
1236
1237
1238
# File 'lib/stripe/resources/payment_link.rb', line 1226

def initialize(
  description: nil,
  invoice_settings: nil,
  metadata: nil,
  trial_period_days: nil,
  trial_settings: nil
)
  @description = description
  @invoice_settings = invoice_settings
  @metadata = 
  @trial_period_days = trial_period_days
  @trial_settings = trial_settings
end

Instance Attribute Details

#descriptionObject

The subscription’s description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.



1216
1217
1218
# File 'lib/stripe/resources/payment_link.rb', line 1216

def description
  @description
end

#invoice_settingsObject

All invoices will be billed using the specified settings.



1218
1219
1220
# File 'lib/stripe/resources/payment_link.rb', line 1218

def invoice_settings
  @invoice_settings
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that will declaratively set metadata on [Subscriptions](stripe.com/docs/api/subscriptions) generated from this payment link. Unlike object-level metadata, this field is declarative. Updates will clear prior values.



1220
1221
1222
# File 'lib/stripe/resources/payment_link.rb', line 1220

def 
  @metadata
end

#trial_period_daysObject

Integer representing the number of trial period days before the customer is charged for the first time. Has to be at least 1.



1222
1223
1224
# File 'lib/stripe/resources/payment_link.rb', line 1222

def trial_period_days
  @trial_period_days
end

#trial_settingsObject

Settings related to subscription trials.



1224
1225
1226
# File 'lib/stripe/resources/payment_link.rb', line 1224

def trial_settings
  @trial_settings
end