Class: Stripe::PaymentLink::CreateParams::SubscriptionData::TrialSettings::EndBehavior

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_link.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(missing_payment_method: nil) ⇒ EndBehavior

Returns a new instance of EndBehavior.



1204
1205
1206
# File 'lib/stripe/resources/payment_link.rb', line 1204

def initialize(missing_payment_method: nil)
  @missing_payment_method = missing_payment_method
end

Instance Attribute Details

#missing_payment_methodObject

Indicates how the subscription should change when the trial ends if the user did not provide a payment method.



1202
1203
1204
# File 'lib/stripe/resources/payment_link.rb', line 1202

def missing_payment_method
  @missing_payment_method
end