Class: Stripe::PaymentLink::CustomField

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/payment_link.rb

Defined Under Namespace

Classes: Dropdown, Label, Numeric, Text

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

Attribute for field dropdown



220
221
222
# File 'lib/stripe/resources/payment_link.rb', line 220

def dropdown
  @dropdown
end

#keyObject (readonly)

String of your choice that your integration can use to reconcile this field. Must be unique to this field, alphanumeric, and up to 200 characters.



222
223
224
# File 'lib/stripe/resources/payment_link.rb', line 222

def key
  @key
end

#labelObject (readonly)

Attribute for field label



224
225
226
# File 'lib/stripe/resources/payment_link.rb', line 224

def label
  @label
end

#numericObject (readonly)

Attribute for field numeric



226
227
228
# File 'lib/stripe/resources/payment_link.rb', line 226

def numeric
  @numeric
end

#optionalObject (readonly)

Whether the customer is required to complete the field before completing the Checkout Session. Defaults to ‘false`.



228
229
230
# File 'lib/stripe/resources/payment_link.rb', line 228

def optional
  @optional
end

#textObject (readonly)

Attribute for field text



230
231
232
# File 'lib/stripe/resources/payment_link.rb', line 230

def text
  @text
end

#typeObject (readonly)

The type of the field.



232
233
234
# File 'lib/stripe/resources/payment_link.rb', line 232

def type
  @type
end

Class Method Details

.field_remappingsObject



238
239
240
# File 'lib/stripe/resources/payment_link.rb', line 238

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



234
235
236
# File 'lib/stripe/resources/payment_link.rb', line 234

def self.inner_class_types
  @inner_class_types = { dropdown: Dropdown, label: Label, numeric: Numeric, text: Text }
end