Class: Stripe::PaymentLink::CustomText

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/payment_link.rb

Defined Under Namespace

Classes: AfterSubmit, ShippingAddress, Submit, TermsOfServiceAcceptance

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#after_submitObject (readonly)

Custom text that should be displayed after the payment confirmation button.



151
152
153
# File 'lib/stripe/resources/payment_link.rb', line 151

def after_submit
  @after_submit
end

#shipping_addressObject (readonly)

Custom text that should be displayed alongside shipping address collection.



154
155
156
# File 'lib/stripe/resources/payment_link.rb', line 154

def shipping_address
  @shipping_address
end

#submitObject (readonly)

Custom text that should be displayed alongside the payment confirmation button.



157
158
159
# File 'lib/stripe/resources/payment_link.rb', line 157

def submit
  @submit
end

#terms_of_service_acceptanceObject (readonly)

Custom text that should be displayed in place of the default terms of service agreement text.



160
161
162
# File 'lib/stripe/resources/payment_link.rb', line 160

def terms_of_service_acceptance
  @terms_of_service_acceptance
end