Class: Stripe::PaymentLink::InvoiceCreation::InvoiceData

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_link.rb

Defined Under Namespace

Classes: CustomField, Issuer, RenderingOptions

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_tax_idsObject (readonly)

The account tax IDs associated with the invoice.



365
366
367
# File 'lib/stripe/resources/payment_link.rb', line 365

def 
  @account_tax_ids
end

#custom_fieldsObject (readonly)

A list of up to 4 custom fields to be displayed on the invoice.



367
368
369
# File 'lib/stripe/resources/payment_link.rb', line 367

def custom_fields
  @custom_fields
end

#descriptionObject (readonly)

An arbitrary string attached to the object. Often useful for displaying to users.



369
370
371
# File 'lib/stripe/resources/payment_link.rb', line 369

def description
  @description
end

Footer to be displayed on the invoice.



371
372
373
# File 'lib/stripe/resources/payment_link.rb', line 371

def footer
  @footer
end

#issuerObject (readonly)

The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.



373
374
375
# File 'lib/stripe/resources/payment_link.rb', line 373

def issuer
  @issuer
end

#metadataObject (readonly)

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



375
376
377
# File 'lib/stripe/resources/payment_link.rb', line 375

def 
  @metadata
end

#rendering_optionsObject (readonly)

Options for invoice PDF rendering.



377
378
379
# File 'lib/stripe/resources/payment_link.rb', line 377

def rendering_options
  @rendering_options
end

Class Method Details

.field_remappingsObject



387
388
389
# File 'lib/stripe/resources/payment_link.rb', line 387

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



379
380
381
382
383
384
385
# File 'lib/stripe/resources/payment_link.rb', line 379

def self.inner_class_types
  @inner_class_types = {
    custom_fields: CustomField,
    issuer: Issuer,
    rendering_options: RenderingOptions,
  }
end