Class: Stripe::PaymentLink::ListLineItemsParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentLink::ListLineItemsParams
- Defined in:
- lib/stripe/resources/payment_link.rb
Instance Attribute Summary collapse
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#starting_after ⇒ Object
A cursor for use in pagination.
Instance Method Summary collapse
-
#initialize(ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListLineItemsParams
constructor
A new instance of ListLineItemsParams.
Methods inherited from RequestParams
Constructor Details
#initialize(ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListLineItemsParams
Returns a new instance of ListLineItemsParams.
1967 1968 1969 1970 1971 1972 |
# File 'lib/stripe/resources/payment_link.rb', line 1967 def initialize(ending_before: nil, expand: nil, limit: nil, starting_after: nil) @ending_before = ending_before @expand = @limit = limit @starting_after = starting_after end |
Instance Attribute Details
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
1959 1960 1961 |
# File 'lib/stripe/resources/payment_link.rb', line 1959 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1961 1962 1963 |
# File 'lib/stripe/resources/payment_link.rb', line 1961 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
1963 1964 1965 |
# File 'lib/stripe/resources/payment_link.rb', line 1963 def limit @limit end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
1965 1966 1967 |
# File 'lib/stripe/resources/payment_link.rb', line 1965 def starting_after @starting_after end |