Class: Stripe::PaymentLink::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/payment_link.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(active: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



313
314
315
316
317
318
319
# File 'lib/stripe/resources/payment_link.rb', line 313

def initialize(active: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil)
  @active = active
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
end

Instance Attribute Details

#activeObject

Only return payment links that are active or inactive (e.g., pass ‘false` to list all inactive payment links).



303
304
305
# File 'lib/stripe/resources/payment_link.rb', line 303

def active
  @active
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



305
306
307
# File 'lib/stripe/resources/payment_link.rb', line 305

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



307
308
309
# File 'lib/stripe/resources/payment_link.rb', line 307

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



309
310
311
# File 'lib/stripe/resources/payment_link.rb', line 309

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



311
312
313
# File 'lib/stripe/resources/payment_link.rb', line 311

def starting_after
  @starting_after
end