Class: Stripe::PaymentLink::OptionalItem::AdjustableQuantity

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_link.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#enabledObject (readonly)

Set to true if the quantity can be adjusted to any non-negative integer.



446
447
448
# File 'lib/stripe/resources/payment_link.rb', line 446

def enabled
  @enabled
end

#maximumObject (readonly)

The maximum quantity of this item the customer can purchase. By default this value is 99.



448
449
450
# File 'lib/stripe/resources/payment_link.rb', line 448

def maximum
  @maximum
end

#minimumObject (readonly)

The minimum quantity of this item the customer must purchase, if they choose to purchase it. Because this item is optional, the customer will always be able to remove it from their order, even if the ‘minimum` configured here is greater than 0. By default this value is 0.



450
451
452
# File 'lib/stripe/resources/payment_link.rb', line 450

def minimum
  @minimum
end

Class Method Details

.field_remappingsObject



456
457
458
# File 'lib/stripe/resources/payment_link.rb', line 456

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



452
453
454
# File 'lib/stripe/resources/payment_link.rb', line 452

def self.inner_class_types
  @inner_class_types = {}
end