Class: Stripe::PaymentLink::PaymentIntentData

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_link.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#capture_methodObject (readonly)

Indicates when the funds will be captured from the customer’s account.



421
422
423
# File 'lib/stripe/resources/payment_link.rb', line 421

def capture_method
  @capture_method
end

#descriptionObject (readonly)

An arbitrary string attached to the object. Often useful for displaying to users.



423
424
425
# File 'lib/stripe/resources/payment_link.rb', line 423

def description
  @description
end

#metadataObject (readonly)

Set of [key-value pairs](stripe.com/docs/api/metadata) that will set metadata on [Payment Intents](stripe.com/docs/api/payment_intents) generated from this payment link.



425
426
427
# File 'lib/stripe/resources/payment_link.rb', line 425

def 
  @metadata
end

#setup_future_usageObject (readonly)

Indicates that you intend to make future payments with the payment method collected during checkout.



427
428
429
# File 'lib/stripe/resources/payment_link.rb', line 427

def setup_future_usage
  @setup_future_usage
end

#statement_descriptorObject (readonly)

For a non-card payment, information about the charge that appears on the customer’s statement when this payment succeeds in creating a charge.



429
430
431
# File 'lib/stripe/resources/payment_link.rb', line 429

def statement_descriptor
  @statement_descriptor
end

#statement_descriptor_suffixObject (readonly)

For a card payment, information about the charge that appears on the customer’s statement when this payment succeeds in creating a charge. Concatenated with the account’s statement descriptor prefix to form the complete statement descriptor.



431
432
433
# File 'lib/stripe/resources/payment_link.rb', line 431

def statement_descriptor_suffix
  @statement_descriptor_suffix
end

#transfer_groupObject (readonly)

A string that identifies the resulting payment as part of a group. See the PaymentIntents [use case for connected accounts](stripe.com/docs/connect/separate-charges-and-transfers) for details.



433
434
435
# File 'lib/stripe/resources/payment_link.rb', line 433

def transfer_group
  @transfer_group
end

Class Method Details

.field_remappingsObject



439
440
441
# File 'lib/stripe/resources/payment_link.rb', line 439

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



435
436
437
# File 'lib/stripe/resources/payment_link.rb', line 435

def self.inner_class_types
  @inner_class_types = {}
end