Class: Stripe::PaymentLink::RetrieveParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentLink::RetrieveParams
- Defined in:
- lib/stripe/resources/payment_link.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ RetrieveParams
constructor
A new instance of RetrieveParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ RetrieveParams
Returns a new instance of RetrieveParams.
1065 1066 1067 |
# File 'lib/stripe/resources/payment_link.rb', line 1065 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1063 1064 1065 |
# File 'lib/stripe/resources/payment_link.rb', line 1063 def @expand end |