Class: Stripe::PaymentLink::SubscriptionData::TrialSettings::EndBehavior
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentLink::SubscriptionData::TrialSettings::EndBehavior
- Defined in:
- lib/stripe/resources/payment_link.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#missing_payment_method ⇒ Object
readonly
Indicates how the subscription should change when the trial ends if the user did not provide a payment method.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#missing_payment_method ⇒ Object (readonly)
Indicates how the subscription should change when the trial ends if the user did not provide a payment method.
637 638 639 |
# File 'lib/stripe/resources/payment_link.rb', line 637 def missing_payment_method @missing_payment_method end |
Class Method Details
.field_remappings ⇒ Object
643 644 645 |
# File 'lib/stripe/resources/payment_link.rb', line 643 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
639 640 641 |
# File 'lib/stripe/resources/payment_link.rb', line 639 def self.inner_class_types @inner_class_types = {} end |