Class: Stripe::PaymentLink::UpdateParams::AfterCompletion::HostedConfirmation
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentLink::UpdateParams::AfterCompletion::HostedConfirmation
- Defined in:
- lib/stripe/resources/payment_link.rb
Instance Attribute Summary collapse
-
#custom_message ⇒ Object
A custom message to display to the customer after the purchase is complete.
Instance Method Summary collapse
-
#initialize(custom_message: nil) ⇒ HostedConfirmation
constructor
A new instance of HostedConfirmation.
Methods inherited from RequestParams
Constructor Details
#initialize(custom_message: nil) ⇒ HostedConfirmation
Returns a new instance of HostedConfirmation.
1076 1077 1078 |
# File 'lib/stripe/resources/payment_link.rb', line 1076 def initialize(custom_message: nil) @custom_message = end |
Instance Attribute Details
#custom_message ⇒ Object
A custom message to display to the customer after the purchase is complete.
1074 1075 1076 |
# File 'lib/stripe/resources/payment_link.rb', line 1074 def @custom_message end |