Class: Stripe::PaymentLink::UpdateParams::AutomaticTax

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_link.rb

Defined Under Namespace

Classes: Liability

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(enabled: nil, liability: nil) ⇒ AutomaticTax

Returns a new instance of AutomaticTax.



1449
1450
1451
1452
# File 'lib/stripe/resources/payment_link.rb', line 1449

def initialize(enabled: nil, liability: nil)
  @enabled = enabled
  @liability = liability
end

Instance Attribute Details

#enabledObject

Set to ‘true` to [calculate tax automatically](docs.stripe.com/tax) using the customer’s location.

Enabling this parameter causes the payment link to collect any billing address information necessary for tax calculation.



1445
1446
1447
# File 'lib/stripe/resources/payment_link.rb', line 1445

def enabled
  @enabled
end

#liabilityObject

The account that’s liable for tax. If set, the business address and tax registrations required to perform the tax calculation are loaded from this account. The tax transaction is returned in the report of the connected account.



1447
1448
1449
# File 'lib/stripe/resources/payment_link.rb', line 1447

def liability
  @liability
end