Class: Stripe::PaymentLink::UpdateParams::CustomField

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_link.rb

Defined Under Namespace

Classes: Dropdown, Label, Numeric, Text

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(dropdown: nil, key: nil, label: nil, numeric: nil, optional: nil, text: nil, type: nil) ⇒ CustomField

Returns a new instance of CustomField.



1535
1536
1537
1538
1539
1540
1541
1542
1543
1544
1545
1546
1547
1548
1549
1550
1551
# File 'lib/stripe/resources/payment_link.rb', line 1535

def initialize(
  dropdown: nil,
  key: nil,
  label: nil,
  numeric: nil,
  optional: nil,
  text: nil,
  type: nil
)
  @dropdown = dropdown
  @key = key
  @label = label
  @numeric = numeric
  @optional = optional
  @text = text
  @type = type
end

Instance Attribute Details

Configuration for ‘type=dropdown` fields.



1521
1522
1523
# File 'lib/stripe/resources/payment_link.rb', line 1521

def dropdown
  @dropdown
end

#keyObject

String of your choice that your integration can use to reconcile this field. Must be unique to this field, alphanumeric, and up to 200 characters.



1523
1524
1525
# File 'lib/stripe/resources/payment_link.rb', line 1523

def key
  @key
end

#labelObject

The label for the field, displayed to the customer.



1525
1526
1527
# File 'lib/stripe/resources/payment_link.rb', line 1525

def label
  @label
end

#numericObject

Configuration for ‘type=numeric` fields.



1527
1528
1529
# File 'lib/stripe/resources/payment_link.rb', line 1527

def numeric
  @numeric
end

#optionalObject

Whether the customer is required to complete the field before completing the Checkout Session. Defaults to ‘false`.



1529
1530
1531
# File 'lib/stripe/resources/payment_link.rb', line 1529

def optional
  @optional
end

#textObject

Configuration for ‘type=text` fields.



1531
1532
1533
# File 'lib/stripe/resources/payment_link.rb', line 1531

def text
  @text
end

#typeObject

The type of the field.



1533
1534
1535
# File 'lib/stripe/resources/payment_link.rb', line 1533

def type
  @type
end