Class: Stripe::PaymentLink::UpdateParams::CustomField::Label
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentLink::UpdateParams::CustomField::Label
- Defined in:
- lib/stripe/resources/payment_link.rb
Instance Attribute Summary collapse
-
#custom ⇒ Object
Custom text for the label, displayed to the customer.
-
#type ⇒ Object
The type of the label.
Instance Method Summary collapse
-
#initialize(custom: nil, type: nil) ⇒ Label
constructor
A new instance of Label.
Methods inherited from RequestParams
Constructor Details
#initialize(custom: nil, type: nil) ⇒ Label
Returns a new instance of Label.
1172 1173 1174 1175 |
# File 'lib/stripe/resources/payment_link.rb', line 1172 def initialize(custom: nil, type: nil) @custom = custom @type = type end |
Instance Attribute Details
#custom ⇒ Object
Custom text for the label, displayed to the customer. Up to 50 characters.
1168 1169 1170 |
# File 'lib/stripe/resources/payment_link.rb', line 1168 def custom @custom end |
#type ⇒ Object
The type of the label.
1170 1171 1172 |
# File 'lib/stripe/resources/payment_link.rb', line 1170 def type @type end |