Class: Stripe::PaymentLink::UpdateParams::InvoiceCreation::InvoiceData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_link.rb

Defined Under Namespace

Classes: CustomField, Issuer, RenderingOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_tax_ids: nil, custom_fields: nil, description: nil, footer: nil, issuer: nil, metadata: nil, rendering_options: nil) ⇒ InvoiceData

Returns a new instance of InvoiceData.



1664
1665
1666
1667
1668
1669
1670
1671
1672
1673
1674
1675
1676
1677
1678
1679
1680
# File 'lib/stripe/resources/payment_link.rb', line 1664

def initialize(
  account_tax_ids: nil,
  custom_fields: nil,
  description: nil,
  footer: nil,
  issuer: nil,
  metadata: nil,
  rendering_options: nil
)
  @account_tax_ids = 
  @custom_fields = custom_fields
  @description = description
  @footer = footer
  @issuer = issuer
  @metadata = 
  @rendering_options = rendering_options
end

Instance Attribute Details

#account_tax_idsObject

The account tax IDs associated with the invoice.



1650
1651
1652
# File 'lib/stripe/resources/payment_link.rb', line 1650

def 
  @account_tax_ids
end

#custom_fieldsObject

Default custom fields to be displayed on invoices for this customer.



1652
1653
1654
# File 'lib/stripe/resources/payment_link.rb', line 1652

def custom_fields
  @custom_fields
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



1654
1655
1656
# File 'lib/stripe/resources/payment_link.rb', line 1654

def description
  @description
end

Default footer to be displayed on invoices for this customer.



1656
1657
1658
# File 'lib/stripe/resources/payment_link.rb', line 1656

def footer
  @footer
end

#issuerObject

The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.



1658
1659
1660
# File 'lib/stripe/resources/payment_link.rb', line 1658

def issuer
  @issuer
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1660
1661
1662
# File 'lib/stripe/resources/payment_link.rb', line 1660

def 
  @metadata
end

#rendering_optionsObject

Default options for invoice PDF rendering for this customer.



1662
1663
1664
# File 'lib/stripe/resources/payment_link.rb', line 1662

def rendering_options
  @rendering_options
end