Class: Stripe::PaymentLink::UpdateParams::InvoiceCreation::InvoiceData::RenderingOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_link.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_tax_display: nil, template: nil) ⇒ RenderingOptions

Returns a new instance of RenderingOptions.



1331
1332
1333
1334
# File 'lib/stripe/resources/payment_link.rb', line 1331

def initialize(amount_tax_display: nil, template: nil)
  @amount_tax_display = amount_tax_display
  @template = template
end

Instance Attribute Details

#amount_tax_displayObject

How line-item prices and amounts will be displayed with respect to tax on invoice PDFs. One of ‘exclude_tax` or `include_inclusive_tax`. `include_inclusive_tax` will include inclusive tax (and exclude exclusive tax) in invoice PDF amounts. `exclude_tax` will exclude all tax (inclusive and exclusive alike) from invoice PDF amounts.



1327
1328
1329
# File 'lib/stripe/resources/payment_link.rb', line 1327

def amount_tax_display
  @amount_tax_display
end

#templateObject

ID of the invoice rendering template to use for this invoice.



1329
1330
1331
# File 'lib/stripe/resources/payment_link.rb', line 1329

def template
  @template
end