Class: Stripe::PaymentLink::UpdateParams::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentLink::UpdateParams::LineItem
- Defined in:
- lib/stripe/resources/payment_link.rb
Defined Under Namespace
Classes: AdjustableQuantity
Instance Attribute Summary collapse
-
#adjustable_quantity ⇒ Object
When set, provides configuration for this item’s quantity to be adjusted by the customer during checkout.
-
#id ⇒ Object
The ID of an existing line item on the payment link.
-
#quantity ⇒ Object
The quantity of the line item being purchased.
Instance Method Summary collapse
-
#initialize(adjustable_quantity: nil, id: nil, quantity: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(adjustable_quantity: nil, id: nil, quantity: nil) ⇒ LineItem
Returns a new instance of LineItem.
1402 1403 1404 1405 1406 |
# File 'lib/stripe/resources/payment_link.rb', line 1402 def initialize(adjustable_quantity: nil, id: nil, quantity: nil) @adjustable_quantity = adjustable_quantity @id = id @quantity = quantity end |
Instance Attribute Details
#adjustable_quantity ⇒ Object
When set, provides configuration for this item’s quantity to be adjusted by the customer during checkout.
1396 1397 1398 |
# File 'lib/stripe/resources/payment_link.rb', line 1396 def adjustable_quantity @adjustable_quantity end |
#id ⇒ Object
The ID of an existing line item on the payment link.
1398 1399 1400 |
# File 'lib/stripe/resources/payment_link.rb', line 1398 def id @id end |
#quantity ⇒ Object
The quantity of the line item being purchased.
1400 1401 1402 |
# File 'lib/stripe/resources/payment_link.rb', line 1400 def quantity @quantity end |