Class: Stripe::PaymentLink::UpdateParams::PaymentIntentData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_link.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, metadata: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_group: nil) ⇒ PaymentIntentData

Returns a new instance of PaymentIntentData.



1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
# File 'lib/stripe/resources/payment_link.rb', line 1423

def initialize(
  description: nil,
  metadata: nil,
  statement_descriptor: nil,
  statement_descriptor_suffix: nil,
  transfer_group: nil
)
  @description = description
  @metadata = 
  @statement_descriptor = statement_descriptor
  @statement_descriptor_suffix = statement_descriptor_suffix
  @transfer_group = transfer_group
end

Instance Attribute Details

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



1411
1412
1413
# File 'lib/stripe/resources/payment_link.rb', line 1411

def description
  @description
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that will declaratively set metadata on [Payment Intents](stripe.com/docs/api/payment_intents) generated from this payment link. Unlike object-level metadata, this field is declarative. Updates will clear prior values.



1413
1414
1415
# File 'lib/stripe/resources/payment_link.rb', line 1413

def 
  @metadata
end

#statement_descriptorObject

Text that appears on the customer’s statement as the statement descriptor for a non-card charge. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).

Setting this value for a card charge returns an error. For card charges, set the [statement_descriptor_suffix](docs.stripe.com/get-started/account/statement-descriptors#dynamic) instead.



1417
1418
1419
# File 'lib/stripe/resources/payment_link.rb', line 1417

def statement_descriptor
  @statement_descriptor
end

#statement_descriptor_suffixObject

Provides information about a card charge. Concatenated to the account’s [statement descriptor prefix](docs.stripe.com/get-started/account/statement-descriptors#static) to form the complete statement descriptor that appears on the customer’s statement.



1419
1420
1421
# File 'lib/stripe/resources/payment_link.rb', line 1419

def statement_descriptor_suffix
  @statement_descriptor_suffix
end

#transfer_groupObject

A string that identifies the resulting payment as part of a group. See the PaymentIntents [use case for connected accounts](stripe.com/docs/connect/separate-charges-and-transfers) for details.



1421
1422
1423
# File 'lib/stripe/resources/payment_link.rb', line 1421

def transfer_group
  @transfer_group
end