Class: Stripe::PaymentLink::UpdateParams::ShippingAddressCollection
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentLink::UpdateParams::ShippingAddressCollection
- Defined in:
- lib/stripe/resources/payment_link.rb
Instance Attribute Summary collapse
-
#allowed_countries ⇒ Object
An array of two-letter ISO country codes representing which countries Checkout should provide as options for shipping locations.
Instance Method Summary collapse
-
#initialize(allowed_countries: nil) ⇒ ShippingAddressCollection
constructor
A new instance of ShippingAddressCollection.
Methods inherited from RequestParams
Constructor Details
#initialize(allowed_countries: nil) ⇒ ShippingAddressCollection
Returns a new instance of ShippingAddressCollection.
1324 1325 1326 |
# File 'lib/stripe/resources/payment_link.rb', line 1324 def initialize(allowed_countries: nil) @allowed_countries = allowed_countries end |
Instance Attribute Details
#allowed_countries ⇒ Object
An array of two-letter ISO country codes representing which countries Checkout should provide as options for shipping locations.
1322 1323 1324 |
# File 'lib/stripe/resources/payment_link.rb', line 1322 def allowed_countries @allowed_countries end |