Class: Stripe::PaymentLinkCreateParams::CustomText

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_link_create_params.rb

Defined Under Namespace

Classes: AfterSubmit, ShippingAddress, Submit, TermsOfServiceAcceptance

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(after_submit: nil, shipping_address: nil, submit: nil, terms_of_service_acceptance: nil) ⇒ CustomText

Returns a new instance of CustomText.



249
250
251
252
253
254
255
256
257
258
259
# File 'lib/stripe/params/payment_link_create_params.rb', line 249

def initialize(
  after_submit: nil,
  shipping_address: nil,
  submit: nil,
  terms_of_service_acceptance: nil
)
  @after_submit = after_submit
  @shipping_address = shipping_address
  @submit = submit
  @terms_of_service_acceptance = terms_of_service_acceptance
end

Instance Attribute Details

#after_submitObject

Custom text that should be displayed after the payment confirmation button.



241
242
243
# File 'lib/stripe/params/payment_link_create_params.rb', line 241

def after_submit
  @after_submit
end

#shipping_addressObject

Custom text that should be displayed alongside shipping address collection.



243
244
245
# File 'lib/stripe/params/payment_link_create_params.rb', line 243

def shipping_address
  @shipping_address
end

#submitObject

Custom text that should be displayed alongside the payment confirmation button.



245
246
247
# File 'lib/stripe/params/payment_link_create_params.rb', line 245

def submit
  @submit
end

#terms_of_service_acceptanceObject

Custom text that should be displayed in place of the default terms of service agreement text.



247
248
249
# File 'lib/stripe/params/payment_link_create_params.rb', line 247

def terms_of_service_acceptance
  @terms_of_service_acceptance
end