Class: Stripe::PaymentLinkCreateParams::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentLinkCreateParams::LineItem
- Defined in:
- lib/stripe/params/payment_link_create_params.rb
Defined Under Namespace
Classes: AdjustableQuantity, PriceData
Instance Attribute Summary collapse
-
#adjustable_quantity ⇒ Object
When set, provides configuration for this item’s quantity to be adjusted by the customer during checkout.
-
#price ⇒ Object
The ID of the [Price](docs.stripe.com/api/prices) or [Plan](docs.stripe.com/api/plans) object.
-
#price_data ⇒ Object
Data used to generate a new [Price](docs.stripe.com/api/prices) object inline.
-
#quantity ⇒ Object
The quantity of the line item being purchased.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(adjustable_quantity: nil, price: nil, price_data: nil, quantity: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(adjustable_quantity: nil, price: nil, price_data: nil, quantity: nil) ⇒ LineItem
433 434 435 436 437 438 |
# File 'lib/stripe/params/payment_link_create_params.rb', line 433 def initialize(adjustable_quantity: nil, price: nil, price_data: nil, quantity: nil) @adjustable_quantity = adjustable_quantity @price = price @price_data = price_data @quantity = quantity end |
Instance Attribute Details
#adjustable_quantity ⇒ Object
When set, provides configuration for this item’s quantity to be adjusted by the customer during checkout.
425 426 427 |
# File 'lib/stripe/params/payment_link_create_params.rb', line 425 def adjustable_quantity @adjustable_quantity end |
#price ⇒ Object
The ID of the [Price](docs.stripe.com/api/prices) or [Plan](docs.stripe.com/api/plans) object. One of price or price_data is required.
427 428 429 |
# File 'lib/stripe/params/payment_link_create_params.rb', line 427 def price @price end |
#price_data ⇒ Object
Data used to generate a new [Price](docs.stripe.com/api/prices) object inline. One of price or price_data is required.
429 430 431 |
# File 'lib/stripe/params/payment_link_create_params.rb', line 429 def price_data @price_data end |
#quantity ⇒ Object
The quantity of the line item being purchased.
431 432 433 |
# File 'lib/stripe/params/payment_link_create_params.rb', line 431 def quantity @quantity end |
Class Method Details
.field_encodings ⇒ Object
440 441 442 443 444 |
# File 'lib/stripe/params/payment_link_create_params.rb', line 440 def self.field_encodings @field_encodings = { price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } }, } end |