Class: Stripe::PaymentLinkCreateParams::LineItem::AdjustableQuantity

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_link_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(enabled: nil, maximum: nil, minimum: nil) ⇒ AdjustableQuantity

Returns a new instance of AdjustableQuantity.



352
353
354
355
356
# File 'lib/stripe/params/payment_link_create_params.rb', line 352

def initialize(enabled: nil, maximum: nil, minimum: nil)
  @enabled = enabled
  @maximum = maximum
  @minimum = minimum
end

Instance Attribute Details

#enabledObject

Set to true if the quantity can be adjusted to any non-negative Integer.



346
347
348
# File 'lib/stripe/params/payment_link_create_params.rb', line 346

def enabled
  @enabled
end

#maximumObject

The maximum quantity the customer can purchase. By default this value is 99. You can specify a value up to 999999.



348
349
350
# File 'lib/stripe/params/payment_link_create_params.rb', line 348

def maximum
  @maximum
end

#minimumObject

The minimum quantity the customer can purchase. By default this value is 0. If there is only one item in the cart then that item’s quantity cannot go down to 0.



350
351
352
# File 'lib/stripe/params/payment_link_create_params.rb', line 350

def minimum
  @minimum
end