Class: Stripe::PaymentLinkCreateParams::NameCollection::Individual
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentLinkCreateParams::NameCollection::Individual
- Defined in:
- lib/stripe/params/payment_link_create_params.rb
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Enable individual name collection on the payment link.
-
#optional ⇒ Object
Whether the customer is required to provide their full name before checking out.
Instance Method Summary collapse
-
#initialize(enabled: nil, optional: nil) ⇒ Individual
constructor
A new instance of Individual.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(enabled: nil, optional: nil) ⇒ Individual
Returns a new instance of Individual.
490 491 492 493 |
# File 'lib/stripe/params/payment_link_create_params.rb', line 490 def initialize(enabled: nil, optional: nil) @enabled = enabled @optional = optional end |
Instance Attribute Details
#enabled ⇒ Object
Enable individual name collection on the payment link. Defaults to ‘false`.
486 487 488 |
# File 'lib/stripe/params/payment_link_create_params.rb', line 486 def enabled @enabled end |
#optional ⇒ Object
Whether the customer is required to provide their full name before checking out. Defaults to ‘false`.
488 489 490 |
# File 'lib/stripe/params/payment_link_create_params.rb', line 488 def optional @optional end |