Class: Stripe::PaymentLinkCreateParams::Restrictions::CompletedSessions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentLinkCreateParams::Restrictions::CompletedSessions
- Defined in:
- lib/stripe/params/payment_link_create_params.rb
Instance Attribute Summary collapse
-
#limit ⇒ Object
The maximum number of checkout sessions that can be completed for the ‘completed_sessions` restriction to be met.
Instance Method Summary collapse
-
#initialize(limit: nil) ⇒ CompletedSessions
constructor
A new instance of CompletedSessions.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(limit: nil) ⇒ CompletedSessions
Returns a new instance of CompletedSessions.
596 597 598 |
# File 'lib/stripe/params/payment_link_create_params.rb', line 596 def initialize(limit: nil) @limit = limit end |
Instance Attribute Details
#limit ⇒ Object
The maximum number of checkout sessions that can be completed for the ‘completed_sessions` restriction to be met.
594 595 596 |
# File 'lib/stripe/params/payment_link_create_params.rb', line 594 def limit @limit end |