Class: Stripe::PaymentLinkCreateParams::SubscriptionData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_link_create_params.rb

Defined Under Namespace

Classes: InvoiceSettings, TrialSettings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(description: nil, invoice_settings: nil, metadata: nil, trial_period_days: nil, trial_settings: nil) ⇒ SubscriptionData

Returns a new instance of SubscriptionData.



715
716
717
718
719
720
721
722
723
724
725
726
727
# File 'lib/stripe/params/payment_link_create_params.rb', line 715

def initialize(
  description: nil,
  invoice_settings: nil,
  metadata: nil,
  trial_period_days: nil,
  trial_settings: nil
)
  @description = description
  @invoice_settings = invoice_settings
  @metadata = 
  @trial_period_days = trial_period_days
  @trial_settings = trial_settings
end

Instance Attribute Details

#descriptionObject

The subscription’s description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.



705
706
707
# File 'lib/stripe/params/payment_link_create_params.rb', line 705

def description
  @description
end

#invoice_settingsObject

All invoices will be billed using the specified settings.



707
708
709
# File 'lib/stripe/params/payment_link_create_params.rb', line 707

def invoice_settings
  @invoice_settings
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that will declaratively set metadata on [Subscriptions](docs.stripe.com/api/subscriptions) generated from this payment link. Unlike object-level metadata, this field is declarative. Updates will clear prior values.



709
710
711
# File 'lib/stripe/params/payment_link_create_params.rb', line 709

def 
  @metadata
end

#trial_period_daysObject

Integer representing the number of trial period days before the customer is charged for the first time. Has to be at least 1.



711
712
713
# File 'lib/stripe/params/payment_link_create_params.rb', line 711

def trial_period_days
  @trial_period_days
end

#trial_settingsObject

Settings related to subscription trials.



713
714
715
# File 'lib/stripe/params/payment_link_create_params.rb', line 713

def trial_settings
  @trial_settings
end