Class: Stripe::PaymentLinkCreateParams::SubscriptionData::TrialSettings::EndBehavior

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_link_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(missing_payment_method: nil) ⇒ EndBehavior

Returns a new instance of EndBehavior.



653
654
655
# File 'lib/stripe/params/payment_link_create_params.rb', line 653

def initialize(missing_payment_method: nil)
  @missing_payment_method = missing_payment_method
end

Instance Attribute Details

#missing_payment_methodObject

Indicates how the subscription should change when the trial ends if the user did not provide a payment method.



651
652
653
# File 'lib/stripe/params/payment_link_create_params.rb', line 651

def missing_payment_method
  @missing_payment_method
end