Class: Stripe::PaymentLinkService::CreateParams::AfterCompletion::HostedConfirmation
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentLinkService::CreateParams::AfterCompletion::HostedConfirmation
- Defined in:
- lib/stripe/services/payment_link_service.rb
Instance Attribute Summary collapse
-
#custom_message ⇒ Object
A custom message to display to the customer after the purchase is complete.
Instance Method Summary collapse
-
#initialize(custom_message: nil) ⇒ HostedConfirmation
constructor
A new instance of HostedConfirmation.
Methods inherited from RequestParams
Constructor Details
#initialize(custom_message: nil) ⇒ HostedConfirmation
Returns a new instance of HostedConfirmation.
44 45 46 |
# File 'lib/stripe/services/payment_link_service.rb', line 44 def initialize(custom_message: nil) @custom_message = end |
Instance Attribute Details
#custom_message ⇒ Object
A custom message to display to the customer after the purchase is complete.
42 43 44 |
# File 'lib/stripe/services/payment_link_service.rb', line 42 def @custom_message end |