Class: Stripe::PaymentLinkService::CreateParams::CustomField

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_link_service.rb

Defined Under Namespace

Classes: Dropdown, Label, Numeric, Text

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(dropdown: nil, key: nil, label: nil, numeric: nil, optional: nil, text: nil, type: nil) ⇒ CustomField

Returns a new instance of CustomField.



190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
# File 'lib/stripe/services/payment_link_service.rb', line 190

def initialize(
  dropdown: nil,
  key: nil,
  label: nil,
  numeric: nil,
  optional: nil,
  text: nil,
  type: nil
)
  @dropdown = dropdown
  @key = key
  @label = label
  @numeric = numeric
  @optional = optional
  @text = text
  @type = type
end

Instance Attribute Details

Configuration for ‘type=dropdown` fields.



176
177
178
# File 'lib/stripe/services/payment_link_service.rb', line 176

def dropdown
  @dropdown
end

#keyObject

String of your choice that your integration can use to reconcile this field. Must be unique to this field, alphanumeric, and up to 200 characters.



178
179
180
# File 'lib/stripe/services/payment_link_service.rb', line 178

def key
  @key
end

#labelObject

The label for the field, displayed to the customer.



180
181
182
# File 'lib/stripe/services/payment_link_service.rb', line 180

def label
  @label
end

#numericObject

Configuration for ‘type=numeric` fields.



182
183
184
# File 'lib/stripe/services/payment_link_service.rb', line 182

def numeric
  @numeric
end

#optionalObject

Whether the customer is required to complete the field before completing the Checkout Session. Defaults to ‘false`.



184
185
186
# File 'lib/stripe/services/payment_link_service.rb', line 184

def optional
  @optional
end

#textObject

Configuration for ‘type=text` fields.



186
187
188
# File 'lib/stripe/services/payment_link_service.rb', line 186

def text
  @text
end

#typeObject

The type of the field.



188
189
190
# File 'lib/stripe/services/payment_link_service.rb', line 188

def type
  @type
end