Class: Stripe::PaymentLinkService::CreateParams::CustomText

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_link_service.rb

Defined Under Namespace

Classes: AfterSubmit, ShippingAddress, Submit, TermsOfServiceAcceptance

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(after_submit: nil, shipping_address: nil, submit: nil, terms_of_service_acceptance: nil) ⇒ CustomText

Returns a new instance of CustomText.



263
264
265
266
267
268
269
270
271
272
273
# File 'lib/stripe/services/payment_link_service.rb', line 263

def initialize(
  after_submit: nil,
  shipping_address: nil,
  submit: nil,
  terms_of_service_acceptance: nil
)
  @after_submit = after_submit
  @shipping_address = shipping_address
  @submit = submit
  @terms_of_service_acceptance = terms_of_service_acceptance
end

Instance Attribute Details

#after_submitObject

Custom text that should be displayed after the payment confirmation button.



255
256
257
# File 'lib/stripe/services/payment_link_service.rb', line 255

def after_submit
  @after_submit
end

#shipping_addressObject

Custom text that should be displayed alongside shipping address collection.



257
258
259
# File 'lib/stripe/services/payment_link_service.rb', line 257

def shipping_address
  @shipping_address
end

#submitObject

Custom text that should be displayed alongside the payment confirmation button.



259
260
261
# File 'lib/stripe/services/payment_link_service.rb', line 259

def submit
  @submit
end

#terms_of_service_acceptanceObject

Custom text that should be displayed in place of the default terms of service agreement text.



261
262
263
# File 'lib/stripe/services/payment_link_service.rb', line 261

def terms_of_service_acceptance
  @terms_of_service_acceptance
end