Class: Stripe::PaymentLinkService::CreateParams::InvoiceCreation::InvoiceData::RenderingOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentLinkService::CreateParams::InvoiceCreation::InvoiceData::RenderingOptions
- Defined in:
- lib/stripe/services/payment_link_service.rb
Instance Attribute Summary collapse
-
#amount_tax_display ⇒ Object
How line-item prices and amounts will be displayed with respect to tax on invoice PDFs.
Instance Method Summary collapse
-
#initialize(amount_tax_display: nil) ⇒ RenderingOptions
constructor
A new instance of RenderingOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(amount_tax_display: nil) ⇒ RenderingOptions
Returns a new instance of RenderingOptions.
322 323 324 |
# File 'lib/stripe/services/payment_link_service.rb', line 322 def initialize(amount_tax_display: nil) @amount_tax_display = amount_tax_display end |
Instance Attribute Details
#amount_tax_display ⇒ Object
How line-item prices and amounts will be displayed with respect to tax on invoice PDFs. One of ‘exclude_tax` or `include_inclusive_tax`. `include_inclusive_tax` will include inclusive tax (and exclude exclusive tax) in invoice PDF amounts. `exclude_tax` will exclude all tax (inclusive and exclusive alike) from invoice PDF amounts.
320 321 322 |
# File 'lib/stripe/services/payment_link_service.rb', line 320 def amount_tax_display @amount_tax_display end |