Class: Stripe::PaymentLinkService::CreateParams::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentLinkService::CreateParams::LineItem
- Defined in:
- lib/stripe/services/payment_link_service.rb
Defined Under Namespace
Classes: AdjustableQuantity
Instance Attribute Summary collapse
-
#adjustable_quantity ⇒ Object
When set, provides configuration for this item’s quantity to be adjusted by the customer during checkout.
-
#price ⇒ Object
The ID of the [Price](stripe.com/docs/api/prices) or [Plan](stripe.com/docs/api/plans) object.
-
#quantity ⇒ Object
The quantity of the line item being purchased.
Instance Method Summary collapse
-
#initialize(adjustable_quantity: nil, price: nil, quantity: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(adjustable_quantity: nil, price: nil, quantity: nil) ⇒ LineItem
Returns a new instance of LineItem.
376 377 378 379 380 |
# File 'lib/stripe/services/payment_link_service.rb', line 376 def initialize(adjustable_quantity: nil, price: nil, quantity: nil) @adjustable_quantity = adjustable_quantity @price = price @quantity = quantity end |
Instance Attribute Details
#adjustable_quantity ⇒ Object
When set, provides configuration for this item’s quantity to be adjusted by the customer during checkout.
370 371 372 |
# File 'lib/stripe/services/payment_link_service.rb', line 370 def adjustable_quantity @adjustable_quantity end |
#price ⇒ Object
The ID of the [Price](stripe.com/docs/api/prices) or [Plan](stripe.com/docs/api/plans) object.
372 373 374 |
# File 'lib/stripe/services/payment_link_service.rb', line 372 def price @price end |
#quantity ⇒ Object
The quantity of the line item being purchased.
374 375 376 |
# File 'lib/stripe/services/payment_link_service.rb', line 374 def quantity @quantity end |