Class: Stripe::PaymentLinkService::CreateParams::LineItem::PriceData::ProductData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_link_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil) ⇒ ProductData

Returns a new instance of ProductData.



386
387
388
389
390
391
392
# File 'lib/stripe/services/payment_link_service.rb', line 386

def initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil)
  @description = description
  @images = images
  @metadata = 
  @name = name
  @tax_code = tax_code
end

Instance Attribute Details

#descriptionObject

The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.



376
377
378
# File 'lib/stripe/services/payment_link_service.rb', line 376

def description
  @description
end

#imagesObject

A list of up to 8 URLs of images for this product, meant to be displayable to the customer.



378
379
380
# File 'lib/stripe/services/payment_link_service.rb', line 378

def images
  @images
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



380
381
382
# File 'lib/stripe/services/payment_link_service.rb', line 380

def 
  @metadata
end

#nameObject

The product’s name, meant to be displayable to the customer.



382
383
384
# File 'lib/stripe/services/payment_link_service.rb', line 382

def name
  @name
end

#tax_codeObject



384
385
386
# File 'lib/stripe/services/payment_link_service.rb', line 384

def tax_code
  @tax_code
end