Class: Stripe::PaymentLinkService::CreateParams::SubscriptionData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_link_service.rb

Defined Under Namespace

Classes: InvoiceSettings, TrialSettings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, invoice_settings: nil, metadata: nil, trial_period_days: nil, trial_settings: nil) ⇒ SubscriptionData

Returns a new instance of SubscriptionData.



625
626
627
628
629
630
631
632
633
634
635
636
637
# File 'lib/stripe/services/payment_link_service.rb', line 625

def initialize(
  description: nil,
  invoice_settings: nil,
  metadata: nil,
  trial_period_days: nil,
  trial_settings: nil
)
  @description = description
  @invoice_settings = invoice_settings
  @metadata = 
  @trial_period_days = trial_period_days
  @trial_settings = trial_settings
end

Instance Attribute Details

#descriptionObject

The subscription’s description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.



615
616
617
# File 'lib/stripe/services/payment_link_service.rb', line 615

def description
  @description
end

#invoice_settingsObject

All invoices will be billed using the specified settings.



617
618
619
# File 'lib/stripe/services/payment_link_service.rb', line 617

def invoice_settings
  @invoice_settings
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that will declaratively set metadata on [Subscriptions](stripe.com/docs/api/subscriptions) generated from this payment link. Unlike object-level metadata, this field is declarative. Updates will clear prior values.



619
620
621
# File 'lib/stripe/services/payment_link_service.rb', line 619

def 
  @metadata
end

#trial_period_daysObject

Integer representing the number of trial period days before the customer is charged for the first time. Has to be at least 1.



621
622
623
# File 'lib/stripe/services/payment_link_service.rb', line 621

def trial_period_days
  @trial_period_days
end

#trial_settingsObject

Settings related to subscription trials.



623
624
625
# File 'lib/stripe/services/payment_link_service.rb', line 623

def trial_settings
  @trial_settings
end