Class: Stripe::PaymentLinkService::UpdateParams::CustomField::Dropdown::Option

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_link_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(label: nil, value: nil) ⇒ Option

Returns a new instance of Option.



754
755
756
757
# File 'lib/stripe/services/payment_link_service.rb', line 754

def initialize(label: nil, value: nil)
  @label = label
  @value = value
end

Instance Attribute Details

#labelObject

The label for the option, displayed to the customer. Up to 100 characters.



750
751
752
# File 'lib/stripe/services/payment_link_service.rb', line 750

def label
  @label
end

#valueObject

The value for this option, not displayed to the customer, used by your integration to reconcile the option selected by the customer. Must be unique to this option, alphanumeric, and up to 100 characters.



752
753
754
# File 'lib/stripe/services/payment_link_service.rb', line 752

def value
  @value
end