Class: Stripe::PaymentLinkService::UpdateParams::InvoiceCreation::InvoiceData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_link_service.rb

Defined Under Namespace

Classes: CustomField, Issuer, RenderingOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_tax_ids: nil, custom_fields: nil, description: nil, footer: nil, issuer: nil, metadata: nil, rendering_options: nil) ⇒ InvoiceData

Returns a new instance of InvoiceData.



1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
1087
1088
# File 'lib/stripe/services/payment_link_service.rb', line 1072

def initialize(
  account_tax_ids: nil,
  custom_fields: nil,
  description: nil,
  footer: nil,
  issuer: nil,
  metadata: nil,
  rendering_options: nil
)
  @account_tax_ids = 
  @custom_fields = custom_fields
  @description = description
  @footer = footer
  @issuer = issuer
  @metadata = 
  @rendering_options = rendering_options
end

Instance Attribute Details

#account_tax_idsObject

The account tax IDs associated with the invoice.



1058
1059
1060
# File 'lib/stripe/services/payment_link_service.rb', line 1058

def 
  @account_tax_ids
end

#custom_fieldsObject

Default custom fields to be displayed on invoices for this customer.



1060
1061
1062
# File 'lib/stripe/services/payment_link_service.rb', line 1060

def custom_fields
  @custom_fields
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



1062
1063
1064
# File 'lib/stripe/services/payment_link_service.rb', line 1062

def description
  @description
end

Default footer to be displayed on invoices for this customer.



1064
1065
1066
# File 'lib/stripe/services/payment_link_service.rb', line 1064

def footer
  @footer
end

#issuerObject

The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.



1066
1067
1068
# File 'lib/stripe/services/payment_link_service.rb', line 1066

def issuer
  @issuer
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1068
1069
1070
# File 'lib/stripe/services/payment_link_service.rb', line 1068

def 
  @metadata
end

#rendering_optionsObject

Default options for invoice PDF rendering for this customer.



1070
1071
1072
# File 'lib/stripe/services/payment_link_service.rb', line 1070

def rendering_options
  @rendering_options
end