Class: Stripe::PaymentLinkService::UpdateParams::InvoiceCreation::InvoiceData::RenderingOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_link_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_tax_display: nil, template: nil) ⇒ RenderingOptions

Returns a new instance of RenderingOptions.



1052
1053
1054
1055
# File 'lib/stripe/services/payment_link_service.rb', line 1052

def initialize(amount_tax_display: nil, template: nil)
  @amount_tax_display = amount_tax_display
  @template = template
end

Instance Attribute Details

#amount_tax_displayObject

How line-item prices and amounts will be displayed with respect to tax on invoice PDFs. One of ‘exclude_tax` or `include_inclusive_tax`. `include_inclusive_tax` will include inclusive tax (and exclude exclusive tax) in invoice PDF amounts. `exclude_tax` will exclude all tax (inclusive and exclusive alike) from invoice PDF amounts.



1048
1049
1050
# File 'lib/stripe/services/payment_link_service.rb', line 1048

def amount_tax_display
  @amount_tax_display
end

#templateObject

ID of the invoice rendering template to use for this invoice.



1050
1051
1052
# File 'lib/stripe/services/payment_link_service.rb', line 1050

def template
  @template
end