Class: Stripe::PaymentLinkService::UpdateParams::Restrictions::CompletedSessions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentLinkService::UpdateParams::Restrictions::CompletedSessions
- Defined in:
- lib/stripe/services/payment_link_service.rb
Instance Attribute Summary collapse
-
#limit ⇒ Object
The maximum number of checkout sessions that can be completed for the ‘completed_sessions` restriction to be met.
Instance Method Summary collapse
-
#initialize(limit: nil) ⇒ CompletedSessions
constructor
A new instance of CompletedSessions.
Methods inherited from RequestParams
Constructor Details
#initialize(limit: nil) ⇒ CompletedSessions
Returns a new instance of CompletedSessions.
1173 1174 1175 |
# File 'lib/stripe/services/payment_link_service.rb', line 1173 def initialize(limit: nil) @limit = limit end |
Instance Attribute Details
#limit ⇒ Object
The maximum number of checkout sessions that can be completed for the ‘completed_sessions` restriction to be met.
1171 1172 1173 |
# File 'lib/stripe/services/payment_link_service.rb', line 1171 def limit @limit end |