Class: Stripe::PaymentLinkUpdateParams::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentLinkUpdateParams::LineItem
- Defined in:
- lib/stripe/params/payment_link_update_params.rb
Defined Under Namespace
Classes: AdjustableQuantity
Instance Attribute Summary collapse
-
#adjustable_quantity ⇒ Object
When set, provides configuration for this item’s quantity to be adjusted by the customer during checkout.
-
#id ⇒ Object
The ID of an existing line item on the payment link.
-
#quantity ⇒ Object
The quantity of the line item being purchased.
Instance Method Summary collapse
-
#initialize(adjustable_quantity: nil, id: nil, quantity: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(adjustable_quantity: nil, id: nil, quantity: nil) ⇒ LineItem
Returns a new instance of LineItem.
350 351 352 353 354 |
# File 'lib/stripe/params/payment_link_update_params.rb', line 350 def initialize(adjustable_quantity: nil, id: nil, quantity: nil) @adjustable_quantity = adjustable_quantity @id = id @quantity = quantity end |
Instance Attribute Details
#adjustable_quantity ⇒ Object
When set, provides configuration for this item’s quantity to be adjusted by the customer during checkout.
344 345 346 |
# File 'lib/stripe/params/payment_link_update_params.rb', line 344 def adjustable_quantity @adjustable_quantity end |
#id ⇒ Object
The ID of an existing line item on the payment link.
346 347 348 |
# File 'lib/stripe/params/payment_link_update_params.rb', line 346 def id @id end |
#quantity ⇒ Object
The quantity of the line item being purchased.
348 349 350 |
# File 'lib/stripe/params/payment_link_update_params.rb', line 348 def quantity @quantity end |