Class: Stripe::PaymentLinkUpdateParams::OptionalItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentLinkUpdateParams::OptionalItem
- Defined in:
- lib/stripe/params/payment_link_update_params.rb
Defined Under Namespace
Classes: AdjustableQuantity
Instance Attribute Summary collapse
-
#adjustable_quantity ⇒ Object
When set, provides configuration for the customer to adjust the quantity of the line item created when a customer chooses to add this optional item to their order.
- #price ⇒ Object
-
#quantity ⇒ Object
The initial quantity of the line item created when a customer chooses to add this optional item to their order.
Instance Method Summary collapse
-
#initialize(adjustable_quantity: nil, price: nil, quantity: nil) ⇒ OptionalItem
constructor
A new instance of OptionalItem.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(adjustable_quantity: nil, price: nil, quantity: nil) ⇒ OptionalItem
Returns a new instance of OptionalItem.
414 415 416 417 418 |
# File 'lib/stripe/params/payment_link_update_params.rb', line 414 def initialize(adjustable_quantity: nil, price: nil, quantity: nil) @adjustable_quantity = adjustable_quantity @price = price @quantity = quantity end |
Instance Attribute Details
#adjustable_quantity ⇒ Object
When set, provides configuration for the customer to adjust the quantity of the line item created when a customer chooses to add this optional item to their order.
408 409 410 |
# File 'lib/stripe/params/payment_link_update_params.rb', line 408 def adjustable_quantity @adjustable_quantity end |
#price ⇒ Object
410 411 412 |
# File 'lib/stripe/params/payment_link_update_params.rb', line 410 def price @price end |
#quantity ⇒ Object
The initial quantity of the line item created when a customer chooses to add this optional item to their order.
412 413 414 |
# File 'lib/stripe/params/payment_link_update_params.rb', line 412 def quantity @quantity end |