Class: Stripe::PaymentLinkUpdateParams::SubscriptionData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_link_update_params.rb

Defined Under Namespace

Classes: InvoiceSettings, TrialSettings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(invoice_settings: nil, metadata: nil, trial_period_days: nil, trial_settings: nil) ⇒ SubscriptionData

Returns a new instance of SubscriptionData.



505
506
507
508
509
510
511
512
513
514
515
# File 'lib/stripe/params/payment_link_update_params.rb', line 505

def initialize(
  invoice_settings: nil,
  metadata: nil,
  trial_period_days: nil,
  trial_settings: nil
)
  @invoice_settings = invoice_settings
   = 
  @trial_period_days = trial_period_days
  @trial_settings = trial_settings
end

Instance Attribute Details

#invoice_settingsObject

All invoices will be billed using the specified settings.



497
498
499
# File 'lib/stripe/params/payment_link_update_params.rb', line 497

def invoice_settings
  @invoice_settings
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that will declaratively set metadata on [Subscriptions](docs.stripe.com/api/subscriptions) generated from this payment link. Unlike object-level metadata, this field is declarative. Updates will clear prior values.



499
500
501
# File 'lib/stripe/params/payment_link_update_params.rb', line 499

def 
  
end

#trial_period_daysObject

Integer representing the number of trial period days before the customer is charged for the first time. Has to be at least 1.



501
502
503
# File 'lib/stripe/params/payment_link_update_params.rb', line 501

def trial_period_days
  @trial_period_days
end

#trial_settingsObject

Settings related to subscription trials.



503
504
505
# File 'lib/stripe/params/payment_link_update_params.rb', line 503

def trial_settings
  @trial_settings
end