Class: Stripe::PaymentLinkUpdateParams::SubscriptionData::TrialSettings::EndBehavior

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_link_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(missing_payment_method: nil) ⇒ EndBehavior

Returns a new instance of EndBehavior.



485
486
487
# File 'lib/stripe/params/payment_link_update_params.rb', line 485

def initialize(missing_payment_method: nil)
  @missing_payment_method = missing_payment_method
end

Instance Attribute Details

#missing_payment_methodObject

Indicates how the subscription should change when the trial ends if the user did not provide a payment method.



483
484
485
# File 'lib/stripe/params/payment_link_update_params.rb', line 483

def missing_payment_method
  @missing_payment_method
end