Class: Stripe::PaymentLocationCapabilityListParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_location_capability_list_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(expand: nil, location: nil) ⇒ PaymentLocationCapabilityListParams

Returns a new instance of PaymentLocationCapabilityListParams.



11
12
13
14
# File 'lib/stripe/params/payment_location_capability_list_params.rb', line 11

def initialize(expand: nil, location: nil)
  @expand = expand
  @location = location
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



7
8
9
# File 'lib/stripe/params/payment_location_capability_list_params.rb', line 7

def expand
  @expand
end

#locationObject

The payment location that the capabilities enable functionality for.



9
10
11
# File 'lib/stripe/params/payment_location_capability_list_params.rb', line 9

def location
  @location
end