Class: Stripe::PaymentLocationCapabilityRetrieveParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentLocationCapabilityRetrieveParams
- Defined in:
- lib/stripe/params/payment_location_capability_retrieve_params.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#location ⇒ Object
The payment location that the capability enables functionality for.
Instance Method Summary collapse
-
#initialize(expand: nil, location: nil) ⇒ PaymentLocationCapabilityRetrieveParams
constructor
A new instance of PaymentLocationCapabilityRetrieveParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(expand: nil, location: nil) ⇒ PaymentLocationCapabilityRetrieveParams
Returns a new instance of PaymentLocationCapabilityRetrieveParams.
11 12 13 14 |
# File 'lib/stripe/params/payment_location_capability_retrieve_params.rb', line 11 def initialize(expand: nil, location: nil) @expand = @location = location end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
7 8 9 |
# File 'lib/stripe/params/payment_location_capability_retrieve_params.rb', line 7 def @expand end |
#location ⇒ Object
The payment location that the capability enables functionality for.
9 10 11 |
# File 'lib/stripe/params/payment_location_capability_retrieve_params.rb', line 9 def location @location end |