Class: Stripe::PaymentLocationCapabilityUpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_location_capability_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(expand: nil, location: nil, requested: nil) ⇒ PaymentLocationCapabilityUpdateParams

Returns a new instance of PaymentLocationCapabilityUpdateParams.



13
14
15
16
17
# File 'lib/stripe/params/payment_location_capability_update_params.rb', line 13

def initialize(expand: nil, location: nil, requested: nil)
  @expand = expand
  @location = location
  @requested = requested
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



7
8
9
# File 'lib/stripe/params/payment_location_capability_update_params.rb', line 7

def expand
  @expand
end

#locationObject

The location for which the capability enables functionality.



9
10
11
# File 'lib/stripe/params/payment_location_capability_update_params.rb', line 9

def location
  @location
end

#requestedObject

To request a new capability for the location, set this to ‘true`. You can remove it from the location by passing `false`.



11
12
13
# File 'lib/stripe/params/payment_location_capability_update_params.rb', line 11

def requested
  @requested
end