Class: Stripe::PaymentLocationUpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/payment_location_update_params.rb

Defined Under Namespace

Classes: Address, BusinessRegistration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(address: nil, business_registration: nil, display_name: nil, expand: nil, onboarding_data_update_acknowledged: nil) ⇒ PaymentLocationUpdateParams

Returns a new instance of PaymentLocationUpdateParams.



49
50
51
52
53
54
55
56
57
58
59
60
61
# File 'lib/stripe/params/payment_location_update_params.rb', line 49

def initialize(
  address: nil,
  business_registration: nil,
  display_name: nil,
  expand: nil,
  onboarding_data_update_acknowledged: nil
)
  @address = address
  @business_registration = business_registration
  @display_name = display_name
  @expand = expand
  @onboarding_data_update_acknowledged = onboarding_data_update_acknowledged
end

Instance Attribute Details

#addressObject

The full address of the location.



39
40
41
# File 'lib/stripe/params/payment_location_update_params.rb', line 39

def address
  @address
end

#business_registrationObject

Identification numbers associated with the location.



41
42
43
# File 'lib/stripe/params/payment_location_update_params.rb', line 41

def business_registration
  @business_registration
end

#display_nameObject

A name for the location.



43
44
45
# File 'lib/stripe/params/payment_location_update_params.rb', line 43

def display_name
  @display_name
end

#expandObject

Specifies which fields in the response should be expanded.



45
46
47
# File 'lib/stripe/params/payment_location_update_params.rb', line 45

def expand
  @expand
end

#onboarding_data_update_acknowledgedObject

Pass true when updating location fields that will trigger onboarding review for any of the location’s active location capabilities. If this parameter is not set to true, updates that would trigger onboarding review will fail. Only applicable for locations with active location capabilities.



47
48
49
# File 'lib/stripe/params/payment_location_update_params.rb', line 47

def onboarding_data_update_acknowledged
  @onboarding_data_update_acknowledged
end