Class: Stripe::PaymentMethod::AttachParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/payment_method.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(customer: nil, customer_account: nil, expand: nil) ⇒ AttachParams

Returns a new instance of AttachParams.



2335
2336
2337
2338
2339
# File 'lib/stripe/resources/payment_method.rb', line 2335

def initialize(customer: nil, customer_account: nil, expand: nil)
  @customer = customer
  @customer_account = 
  @expand = expand
end

Instance Attribute Details

#customerObject

The ID of the customer to which to attach the PaymentMethod.



2329
2330
2331
# File 'lib/stripe/resources/payment_method.rb', line 2329

def customer
  @customer
end

#customer_accountObject

The ID of the account to which to attach the PaymentMethod.



2331
2332
2333
# File 'lib/stripe/resources/payment_method.rb', line 2331

def 
  @customer_account
end

#expandObject

Specifies which fields in the response should be expanded.



2333
2334
2335
# File 'lib/stripe/resources/payment_method.rb', line 2333

def expand
  @expand
end