Class: Stripe::PaymentMethod::Card::GeneratedFrom::PaymentMethodDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentMethod::Card::GeneratedFrom::PaymentMethodDetails
- Defined in:
- lib/stripe/resources/payment_method.rb
Defined Under Namespace
Classes: CardPresent
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#card_present ⇒ Object
readonly
Attribute for field card_present.
-
#type ⇒ Object
readonly
The type of payment method transaction-specific details from the transaction that generated this ‘card` payment method.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#card_present ⇒ Object (readonly)
Attribute for field card_present
190 191 192 |
# File 'lib/stripe/resources/payment_method.rb', line 190 def card_present @card_present end |
#type ⇒ Object (readonly)
The type of payment method transaction-specific details from the transaction that generated this ‘card` payment method. Always `card_present`.
192 193 194 |
# File 'lib/stripe/resources/payment_method.rb', line 192 def type @type end |