Class: Stripe::PaymentMethod::Card::Wallet
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentMethod::Card::Wallet
- Defined in:
- lib/stripe/resources/payment_method.rb
Defined Under Namespace
Classes: AmexExpressCheckout, ApplePay, GooglePay, Link, Masterpass, SamsungPay, VisaCheckout
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amex_express_checkout ⇒ Object
readonly
Attribute for field amex_express_checkout.
-
#apple_pay ⇒ Object
readonly
Attribute for field apple_pay.
-
#dynamic_last4 ⇒ Object
readonly
(For tokenized numbers only.) The last four digits of the device account number.
-
#google_pay ⇒ Object
readonly
Attribute for field google_pay.
-
#link ⇒ Object
readonly
Attribute for field link.
-
#masterpass ⇒ Object
readonly
Attribute for field masterpass.
-
#samsung_pay ⇒ Object
readonly
Attribute for field samsung_pay.
-
#type ⇒ Object
readonly
The type of the card wallet, one of
amex_express_checkout,apple_pay,google_pay,masterpass,samsung_pay,visa_checkout, orlink. -
#visa_checkout ⇒ Object
readonly
Attribute for field visa_checkout.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amex_express_checkout ⇒ Object (readonly)
Attribute for field amex_express_checkout
595 596 597 |
# File 'lib/stripe/resources/payment_method.rb', line 595 def amex_express_checkout @amex_express_checkout end |
#apple_pay ⇒ Object (readonly)
Attribute for field apple_pay
597 598 599 |
# File 'lib/stripe/resources/payment_method.rb', line 597 def apple_pay @apple_pay end |
#dynamic_last4 ⇒ Object (readonly)
(For tokenized numbers only.) The last four digits of the device account number.
599 600 601 |
# File 'lib/stripe/resources/payment_method.rb', line 599 def dynamic_last4 @dynamic_last4 end |
#google_pay ⇒ Object (readonly)
Attribute for field google_pay
601 602 603 |
# File 'lib/stripe/resources/payment_method.rb', line 601 def google_pay @google_pay end |
#link ⇒ Object (readonly)
Attribute for field link
603 604 605 |
# File 'lib/stripe/resources/payment_method.rb', line 603 def link @link end |
#masterpass ⇒ Object (readonly)
Attribute for field masterpass
605 606 607 |
# File 'lib/stripe/resources/payment_method.rb', line 605 def masterpass @masterpass end |
#samsung_pay ⇒ Object (readonly)
Attribute for field samsung_pay
607 608 609 |
# File 'lib/stripe/resources/payment_method.rb', line 607 def samsung_pay @samsung_pay end |
#type ⇒ Object (readonly)
The type of the card wallet, one of amex_express_checkout, apple_pay, google_pay, masterpass, samsung_pay, visa_checkout, or link. An additional hash is included on the Wallet subhash with a name matching this value. It contains additional information specific to the card wallet type.
609 610 611 |
# File 'lib/stripe/resources/payment_method.rb', line 609 def type @type end |
#visa_checkout ⇒ Object (readonly)
Attribute for field visa_checkout
611 612 613 |
# File 'lib/stripe/resources/payment_method.rb', line 611 def visa_checkout @visa_checkout end |
Class Method Details
.field_remappings ⇒ Object
625 626 627 |
# File 'lib/stripe/resources/payment_method.rb', line 625 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
613 614 615 616 617 618 619 620 621 622 623 |
# File 'lib/stripe/resources/payment_method.rb', line 613 def self.inner_class_types @inner_class_types = { amex_express_checkout: AmexExpressCheckout, apple_pay: ApplePay, google_pay: GooglePay, link: Link, masterpass: Masterpass, samsung_pay: SamsungPay, visa_checkout: VisaCheckout, } end |