Class: Stripe::PaymentMethod::DetachParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethod::DetachParams
- Defined in:
- lib/stripe/resources/payment_method.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ DetachParams
constructor
A new instance of DetachParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ DetachParams
Returns a new instance of DetachParams.
2346 2347 2348 |
# File 'lib/stripe/resources/payment_method.rb', line 2346 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2344 2345 2346 |
# File 'lib/stripe/resources/payment_method.rb', line 2344 def @expand end |