Class: Stripe::PaymentMethod::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/payment_method.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(customer: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, type: nil) ⇒ ListParams

Returns a new instance of ListParams.



716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
# File 'lib/stripe/resources/payment_method.rb', line 716

def initialize(
  customer: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  starting_after: nil,
  type: nil
)
  @customer = customer
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
  @type = type
end

Instance Attribute Details

#customerObject

The ID of the customer whose PaymentMethods will be retrieved.



704
705
706
# File 'lib/stripe/resources/payment_method.rb', line 704

def customer
  @customer
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



706
707
708
# File 'lib/stripe/resources/payment_method.rb', line 706

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



708
709
710
# File 'lib/stripe/resources/payment_method.rb', line 708

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



710
711
712
# File 'lib/stripe/resources/payment_method.rb', line 710

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



712
713
714
# File 'lib/stripe/resources/payment_method.rb', line 712

def starting_after
  @starting_after
end

#typeObject

An optional filter on the list, based on the object ‘type` field. Without the filter, the list includes all current and future payment method types. If your integration expects only one type of payment method in the response, make sure to provide a type value in the request.



714
715
716
# File 'lib/stripe/resources/payment_method.rb', line 714

def type
  @type
end