Class: Stripe::PaymentMethod::NzBankAccount

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/payment_method.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_holder_nameObject (readonly)

The name on the bank account. Only present if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



1121
1122
1123
# File 'lib/stripe/resources/payment_method.rb', line 1121

def 
  @account_holder_name
end

#bank_codeObject (readonly)

The numeric code for the bank account’s bank.



1123
1124
1125
# File 'lib/stripe/resources/payment_method.rb', line 1123

def bank_code
  @bank_code
end

#bank_nameObject (readonly)

The name of the bank.



1125
1126
1127
# File 'lib/stripe/resources/payment_method.rb', line 1125

def bank_name
  @bank_name
end

#branch_codeObject (readonly)

The numeric code for the bank account’s bank branch.



1127
1128
1129
# File 'lib/stripe/resources/payment_method.rb', line 1127

def branch_code
  @branch_code
end

#last4Object (readonly)

Last four digits of the bank account number.



1129
1130
1131
# File 'lib/stripe/resources/payment_method.rb', line 1129

def last4
  @last4
end

#suffixObject (readonly)

The suffix of the bank account number.



1131
1132
1133
# File 'lib/stripe/resources/payment_method.rb', line 1131

def suffix
  @suffix
end

Class Method Details

.field_remappingsObject



1137
1138
1139
# File 'lib/stripe/resources/payment_method.rb', line 1137

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1133
1134
1135
# File 'lib/stripe/resources/payment_method.rb', line 1133

def self.inner_class_types
  @inner_class_types = {}
end