Class: Stripe::PaymentMethod::StripeBalance
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentMethod::StripeBalance
- Defined in:
- lib/stripe/resources/payment_method.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account ⇒ Object
readonly
The connected account ID whose Stripe balance to use as the source of payment.
-
#source_type ⇒ Object
readonly
The [source_type](docs.stripe.com/api/balance/balance_object#balance_object-available-source_types) of the balance.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account ⇒ Object (readonly)
The connected account ID whose Stripe balance to use as the source of payment
1382 1383 1384 |
# File 'lib/stripe/resources/payment_method.rb', line 1382 def account @account end |
#source_type ⇒ Object (readonly)
The [source_type](docs.stripe.com/api/balance/balance_object#balance_object-available-source_types) of the balance
1384 1385 1386 |
# File 'lib/stripe/resources/payment_method.rb', line 1384 def source_type @source_type end |
Class Method Details
.field_remappings ⇒ Object
1390 1391 1392 |
# File 'lib/stripe/resources/payment_method.rb', line 1390 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1386 1387 1388 |
# File 'lib/stripe/resources/payment_method.rb', line 1386 def self.inner_class_types @inner_class_types = {} end |