Class: Stripe::PaymentMethod::UpdateParams::Card
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethod::UpdateParams::Card
- Defined in:
- lib/stripe/resources/payment_method.rb
Defined Under Namespace
Classes: Networks
Instance Attribute Summary collapse
-
#exp_month ⇒ Object
Two-digit number representing the card’s expiration month.
-
#exp_year ⇒ Object
Four-digit number representing the card’s expiration year.
-
#networks ⇒ Object
Contains information about card networks used to process the payment.
Instance Method Summary collapse
-
#initialize(exp_month: nil, exp_year: nil, networks: nil) ⇒ Card
constructor
A new instance of Card.
Methods inherited from RequestParams
Constructor Details
#initialize(exp_month: nil, exp_year: nil, networks: nil) ⇒ Card
Returns a new instance of Card.
1321 1322 1323 1324 1325 |
# File 'lib/stripe/resources/payment_method.rb', line 1321 def initialize(exp_month: nil, exp_year: nil, networks: nil) @exp_month = exp_month @exp_year = exp_year @networks = networks end |
Instance Attribute Details
#exp_month ⇒ Object
Two-digit number representing the card’s expiration month.
1315 1316 1317 |
# File 'lib/stripe/resources/payment_method.rb', line 1315 def exp_month @exp_month end |
#exp_year ⇒ Object
Four-digit number representing the card’s expiration year.
1317 1318 1319 |
# File 'lib/stripe/resources/payment_method.rb', line 1317 def exp_year @exp_year end |
#networks ⇒ Object
Contains information about card networks used to process the payment.
1319 1320 1321 |
# File 'lib/stripe/resources/payment_method.rb', line 1319 def networks @networks end |