Class: Stripe::PaymentMethod::UpdateParams::NaverPay
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethod::UpdateParams::NaverPay
- Defined in:
- lib/stripe/resources/payment_method.rb
Instance Attribute Summary collapse
-
#funding ⇒ Object
Whether to use Naver Pay points or a card to fund this transaction.
Instance Method Summary collapse
-
#initialize(funding: nil) ⇒ NaverPay
constructor
A new instance of NaverPay.
Methods inherited from RequestParams
Constructor Details
#initialize(funding: nil) ⇒ NaverPay
Returns a new instance of NaverPay.
1440 1441 1442 |
# File 'lib/stripe/resources/payment_method.rb', line 1440 def initialize(funding: nil) @funding = funding end |
Instance Attribute Details
#funding ⇒ Object
Whether to use Naver Pay points or a card to fund this transaction. If not provided, this defaults to ‘card`.
1438 1439 1440 |
# File 'lib/stripe/resources/payment_method.rb', line 1438 def funding @funding end |