Class: Stripe::PaymentMethod::UsBankAccount

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/payment_method.rb

Defined Under Namespace

Classes: Networks, StatusDetails

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_holder_typeObject (readonly)

Account holder type: individual or company.



1408
1409
1410
# File 'lib/stripe/resources/payment_method.rb', line 1408

def 
  @account_holder_type
end

#account_typeObject (readonly)

Account type: checkings or savings. Defaults to checking if omitted.



1410
1411
1412
# File 'lib/stripe/resources/payment_method.rb', line 1410

def 
  @account_type
end

#bank_nameObject (readonly)

The name of the bank.



1412
1413
1414
# File 'lib/stripe/resources/payment_method.rb', line 1412

def bank_name
  @bank_name
end

#financial_connections_accountObject (readonly)

The ID of the Financial Connections Account used to create the payment method.



1414
1415
1416
# File 'lib/stripe/resources/payment_method.rb', line 1414

def 
  @financial_connections_account
end

#fingerprintObject (readonly)

Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.



1416
1417
1418
# File 'lib/stripe/resources/payment_method.rb', line 1416

def fingerprint
  @fingerprint
end

#last4Object (readonly)

Last four digits of the bank account number.



1418
1419
1420
# File 'lib/stripe/resources/payment_method.rb', line 1418

def last4
  @last4
end

#networksObject (readonly)

Contains information about US bank account networks that can be used.



1420
1421
1422
# File 'lib/stripe/resources/payment_method.rb', line 1420

def networks
  @networks
end

#routing_numberObject (readonly)

Routing number of the bank account.



1422
1423
1424
# File 'lib/stripe/resources/payment_method.rb', line 1422

def routing_number
  @routing_number
end

#status_detailsObject (readonly)

Contains information about the future reusability of this PaymentMethod.



1424
1425
1426
# File 'lib/stripe/resources/payment_method.rb', line 1424

def status_details
  @status_details
end

Class Method Details

.field_remappingsObject



1430
1431
1432
# File 'lib/stripe/resources/payment_method.rb', line 1430

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1426
1427
1428
# File 'lib/stripe/resources/payment_method.rb', line 1426

def self.inner_class_types
  @inner_class_types = { networks: Networks, status_details: StatusDetails }
end