Class: Stripe::PaymentMethodBalance

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/payment_method_balance.rb

Overview

PaymentMethodBalance objects represent balances available on a payment method. You can use v1/payment_methods/:id/check_balance to check the balance of a payment method.

Defined Under Namespace

Classes: Balance

Constant Summary collapse

OBJECT_NAME =
"payment_method_balance"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#as_ofObject (readonly)

The time at which the balance was calculated. Measured in seconds since the Unix epoch.



52
53
54
# File 'lib/stripe/resources/payment_method_balance.rb', line 52

def as_of
  @as_of
end

#balanceObject (readonly)

BalanceEntry contain information about every individual balance type of a card.



54
55
56
# File 'lib/stripe/resources/payment_method_balance.rb', line 54

def balance
  @balance
end

#livemodeObject (readonly)

If the object exists in live mode, the value is ‘true`. If the object exists in test mode, the value is `false`.



56
57
58
# File 'lib/stripe/resources/payment_method_balance.rb', line 56

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



58
59
60
# File 'lib/stripe/resources/payment_method_balance.rb', line 58

def object
  @object
end

Class Method Details

.field_remappingsObject



64
65
66
# File 'lib/stripe/resources/payment_method_balance.rb', line 64

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



60
61
62
# File 'lib/stripe/resources/payment_method_balance.rb', line 60

def self.inner_class_types
  @inner_class_types = { balance: Balance }
end

.object_nameObject



9
10
11
# File 'lib/stripe/resources/payment_method_balance.rb', line 9

def self.object_name
  "payment_method_balance"
end