Class: Stripe::PaymentMethodConfiguration

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List
Includes:
APIOperations::Save
Defined in:
lib/stripe/resources/payment_method_configuration.rb

Overview

PaymentMethodConfigurations control which payment methods are displayed to your customers when you don't explicitly specify payment method types. You can have multiple configurations with different sets of payment methods for different scenarios.

There are two types of PaymentMethodConfigurations. Which is used depends on the charge type:

Direct configurations apply to payments created on your account, including Connect destination charges, Connect separate charges and transfers, and payments not involving Connect.

Child configurations apply to payments created on your connected accounts using direct charges, and charges with the on_behalf_of parameter.

Child configurations have a parent that sets default values and controls which settings connected accounts may override. You can specify a parent ID at payment time, and Stripe will automatically resolve the connected account's associated child configuration. Parent configurations are managed in the dashboard and are not available in this API.

Related guides:

Defined Under Namespace

Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, ApplePay, AuBecsDebit, BacsDebit, Bancontact, Billie, Bizum, Blik, Boleto, Card, CartesBancaires, Cashapp, Crypto, CustomerBalance, Eps, Fpx, Giropay, GooglePay, Gopay, Grabpay, IdBankTransfer, Ideal, Jcb, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Paypay, Payto, Pix, Promptpay, Qris, RevolutPay, SamsungPay, Satispay, Scalapay, SepaDebit, Shopeepay, Sofort, Sunbit, Swish, Twint, Upi, UsBankAccount, Vipps, WechatPay, Zip

Constant Summary collapse

OBJECT_NAME =
"payment_method_configuration"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods included from APIOperations::Save

included, #save

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#acss_debitObject (readonly)

Attribute for field acss_debit



2013
2014
2015
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2013

def acss_debit
  @acss_debit
end

#activeObject (readonly)

Whether the configuration can be used for new payments.



2015
2016
2017
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2015

def active
  @active
end

#affirmObject (readonly)

Attribute for field affirm



2017
2018
2019
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2017

def affirm
  @affirm
end

#afterpay_clearpayObject (readonly)

Attribute for field afterpay_clearpay



2019
2020
2021
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2019

def afterpay_clearpay
  @afterpay_clearpay
end

#alipayObject (readonly)

Attribute for field alipay



2021
2022
2023
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2021

def alipay
  @alipay
end

#almaObject (readonly)

Attribute for field alma



2023
2024
2025
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2023

def alma
  @alma
end

#amazon_payObject (readonly)

Attribute for field amazon_pay



2025
2026
2027
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2025

def amazon_pay
  @amazon_pay
end

#apple_payObject (readonly)

Attribute for field apple_pay



2027
2028
2029
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2027

def apple_pay
  @apple_pay
end

#applicationObject (readonly)

For child configs, the Connect application associated with the configuration.



2029
2030
2031
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2029

def application
  @application
end

#au_becs_debitObject (readonly)

Attribute for field au_becs_debit



2031
2032
2033
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2031

def au_becs_debit
  @au_becs_debit
end

#bacs_debitObject (readonly)

Attribute for field bacs_debit



2033
2034
2035
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2033

def bacs_debit
  @bacs_debit
end

#bancontactObject (readonly)

Attribute for field bancontact



2035
2036
2037
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2035

def bancontact
  @bancontact
end

#billieObject (readonly)

Attribute for field billie



2037
2038
2039
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2037

def billie
  @billie
end

#bizumObject (readonly)

Attribute for field bizum



2039
2040
2041
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2039

def bizum
  @bizum
end

#blikObject (readonly)

Attribute for field blik



2041
2042
2043
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2041

def blik
  @blik
end

#boletoObject (readonly)

Attribute for field boleto



2043
2044
2045
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2043

def boleto
  @boleto
end

#cardObject (readonly)

Attribute for field card



2045
2046
2047
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2045

def card
  @card
end

#cartes_bancairesObject (readonly)

Attribute for field cartes_bancaires



2047
2048
2049
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2047

def cartes_bancaires
  @cartes_bancaires
end

#cashappObject (readonly)

Attribute for field cashapp



2049
2050
2051
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2049

def cashapp
  @cashapp
end

#cryptoObject (readonly)

Attribute for field crypto



2051
2052
2053
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2051

def crypto
  @crypto
end

#customer_balanceObject (readonly)

Attribute for field customer_balance



2053
2054
2055
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2053

def customer_balance
  @customer_balance
end

#epsObject (readonly)

Attribute for field eps



2055
2056
2057
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2055

def eps
  @eps
end

#fpxObject (readonly)

Attribute for field fpx



2057
2058
2059
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2057

def fpx
  @fpx
end

#giropayObject (readonly)

Attribute for field giropay



2059
2060
2061
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2059

def giropay
  @giropay
end

#google_payObject (readonly)

Attribute for field google_pay



2061
2062
2063
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2061

def google_pay
  @google_pay
end

#gopayObject (readonly)

Attribute for field gopay



2063
2064
2065
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2063

def gopay
  @gopay
end

#grabpayObject (readonly)

Attribute for field grabpay



2065
2066
2067
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2065

def grabpay
  @grabpay
end

#idObject (readonly)

Unique identifier for the object.



2067
2068
2069
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2067

def id
  @id
end

#id_bank_transferObject (readonly)

Attribute for field id_bank_transfer



2069
2070
2071
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2069

def id_bank_transfer
  @id_bank_transfer
end

#idealObject (readonly)

Attribute for field ideal



2071
2072
2073
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2071

def ideal
  @ideal
end

#is_defaultObject (readonly)

The default configuration is used whenever a payment method configuration is not specified.



2073
2074
2075
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2073

def is_default
  @is_default
end

#jcbObject (readonly)

Attribute for field jcb



2075
2076
2077
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2075

def jcb
  @jcb
end

#kakao_payObject (readonly)

Attribute for field kakao_pay



2077
2078
2079
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2077

def kakao_pay
  @kakao_pay
end

#klarnaObject (readonly)

Attribute for field klarna



2079
2080
2081
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2079

def klarna
  @klarna
end

#konbiniObject (readonly)

Attribute for field konbini



2081
2082
2083
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2081

def konbini
  @konbini
end

#kr_cardObject (readonly)

Attribute for field kr_card



2083
2084
2085
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2083

def kr_card
  @kr_card
end

Attribute for field link



2085
2086
2087
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2085

def link
  @link
end

#livemodeObject (readonly)

If the object exists in live mode, the value is true. If the object exists in test mode, the value is false.



2087
2088
2089
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2087

def livemode
  @livemode
end

#mb_wayObject (readonly)

Attribute for field mb_way



2089
2090
2091
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2089

def mb_way
  @mb_way
end

#mobilepayObject (readonly)

Attribute for field mobilepay



2091
2092
2093
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2091

def mobilepay
  @mobilepay
end

#multibancoObject (readonly)

Attribute for field multibanco



2093
2094
2095
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2093

def multibanco
  @multibanco
end

#nameObject (readonly)

The configuration's name.



2095
2096
2097
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2095

def name
  @name
end

Attribute for field naver_pay



2097
2098
2099
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2097

def naver_pay
  @naver_pay
end

#nz_bank_accountObject (readonly)

Attribute for field nz_bank_account



2099
2100
2101
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2099

def 
  @nz_bank_account
end

#objectObject (readonly)

String representing the object's type. Objects of the same type share the same value.



2101
2102
2103
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2101

def object
  @object
end

#oxxoObject (readonly)

Attribute for field oxxo



2103
2104
2105
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2103

def oxxo
  @oxxo
end

#p24Object (readonly)

Attribute for field p24



2105
2106
2107
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2105

def p24
  @p24
end

#parentObject (readonly)

For child configs, the configuration's parent configuration.



2107
2108
2109
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2107

def parent
  @parent
end

#pay_by_bankObject (readonly)

Attribute for field pay_by_bank



2109
2110
2111
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2109

def pay_by_bank
  @pay_by_bank
end

#paycoObject (readonly)

Attribute for field payco



2111
2112
2113
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2111

def payco
  @payco
end

#paynowObject (readonly)

Attribute for field paynow



2113
2114
2115
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2113

def paynow
  @paynow
end

#paypalObject (readonly)

Attribute for field paypal



2115
2116
2117
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2115

def paypal
  @paypal
end

#paypayObject (readonly)

Attribute for field paypay



2117
2118
2119
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2117

def paypay
  @paypay
end

#paytoObject (readonly)

Attribute for field payto



2119
2120
2121
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2119

def payto
  @payto
end

#pixObject (readonly)

Attribute for field pix



2121
2122
2123
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2121

def pix
  @pix
end

#promptpayObject (readonly)

Attribute for field promptpay



2123
2124
2125
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2123

def promptpay
  @promptpay
end

#qrisObject (readonly)

Attribute for field qris



2125
2126
2127
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2125

def qris
  @qris
end

#revolut_payObject (readonly)

Attribute for field revolut_pay



2127
2128
2129
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2127

def revolut_pay
  @revolut_pay
end

#samsung_payObject (readonly)

Attribute for field samsung_pay



2129
2130
2131
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2129

def samsung_pay
  @samsung_pay
end

#satispayObject (readonly)

Attribute for field satispay



2131
2132
2133
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2131

def satispay
  @satispay
end

#scalapayObject (readonly)

Attribute for field scalapay



2133
2134
2135
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2133

def scalapay
  @scalapay
end

#sepa_debitObject (readonly)

Attribute for field sepa_debit



2135
2136
2137
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2135

def sepa_debit
  @sepa_debit
end

#shopeepayObject (readonly)

Attribute for field shopeepay



2137
2138
2139
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2137

def shopeepay
  @shopeepay
end

#sofortObject (readonly)

Attribute for field sofort



2139
2140
2141
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2139

def sofort
  @sofort
end

#sunbitObject (readonly)

Attribute for field sunbit



2141
2142
2143
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2141

def sunbit
  @sunbit
end

#swishObject (readonly)

Attribute for field swish



2143
2144
2145
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2143

def swish
  @swish
end

#twintObject (readonly)

Attribute for field twint



2145
2146
2147
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2145

def twint
  @twint
end

#upiObject (readonly)

Attribute for field upi



2147
2148
2149
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2147

def upi
  @upi
end

#us_bank_accountObject (readonly)

Attribute for field us_bank_account



2149
2150
2151
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2149

def 
  @us_bank_account
end

#vippsObject (readonly)

Attribute for field vipps



2151
2152
2153
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2151

def vipps
  @vipps
end

#wechat_payObject (readonly)

Attribute for field wechat_pay



2153
2154
2155
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2153

def wechat_pay
  @wechat_pay
end

#zipObject (readonly)

Attribute for field zip



2155
2156
2157
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2155

def zip
  @zip
end

Class Method Details

.create(params = {}, opts = {}) ⇒ Object

Creates a payment method configuration



2158
2159
2160
2161
2162
2163
2164
2165
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2158

def self.create(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/payment_method_configurations",
    params: params,
    opts: opts
  )
end

.field_remappingsObject



2256
2257
2258
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2256

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2187
2188
2189
2190
2191
2192
2193
2194
2195
2196
2197
2198
2199
2200
2201
2202
2203
2204
2205
2206
2207
2208
2209
2210
2211
2212
2213
2214
2215
2216
2217
2218
2219
2220
2221
2222
2223
2224
2225
2226
2227
2228
2229
2230
2231
2232
2233
2234
2235
2236
2237
2238
2239
2240
2241
2242
2243
2244
2245
2246
2247
2248
2249
2250
2251
2252
2253
2254
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2187

def self.inner_class_types
  @inner_class_types = {
    acss_debit: AcssDebit,
    affirm: Affirm,
    afterpay_clearpay: AfterpayClearpay,
    alipay: Alipay,
    alma: Alma,
    amazon_pay: AmazonPay,
    apple_pay: ApplePay,
    au_becs_debit: AuBecsDebit,
    bacs_debit: BacsDebit,
    bancontact: Bancontact,
    billie: Billie,
    bizum: Bizum,
    blik: Blik,
    boleto: Boleto,
    card: Card,
    cartes_bancaires: CartesBancaires,
    cashapp: Cashapp,
    crypto: Crypto,
    customer_balance: CustomerBalance,
    eps: Eps,
    fpx: Fpx,
    giropay: Giropay,
    google_pay: GooglePay,
    gopay: Gopay,
    grabpay: Grabpay,
    id_bank_transfer: IdBankTransfer,
    ideal: Ideal,
    jcb: Jcb,
    kakao_pay: KakaoPay,
    klarna: Klarna,
    konbini: Konbini,
    kr_card: KrCard,
    link: Link,
    mb_way: MbWay,
    mobilepay: Mobilepay,
    multibanco: Multibanco,
    naver_pay: NaverPay,
    nz_bank_account: NzBankAccount,
    oxxo: Oxxo,
    p24: P24,
    pay_by_bank: PayByBank,
    payco: Payco,
    paynow: Paynow,
    paypal: Paypal,
    paypay: Paypay,
    payto: Payto,
    pix: Pix,
    promptpay: Promptpay,
    qris: Qris,
    revolut_pay: RevolutPay,
    samsung_pay: SamsungPay,
    satispay: Satispay,
    scalapay: Scalapay,
    sepa_debit: SepaDebit,
    shopeepay: Shopeepay,
    sofort: Sofort,
    sunbit: Sunbit,
    swish: Swish,
    twint: Twint,
    upi: Upi,
    us_bank_account: UsBankAccount,
    vipps: Vipps,
    wechat_pay: WechatPay,
    zip: Zip,
  }
end

.list(params = {}, opts = {}) ⇒ Object

List payment method configurations



2168
2169
2170
2171
2172
2173
2174
2175
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2168

def self.list(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/payment_method_configurations",
    params: params,
    opts: opts
  )
end

.object_nameObject



25
26
27
# File 'lib/stripe/resources/payment_method_configuration.rb', line 25

def self.object_name
  "payment_method_configuration"
end

.update(configuration, params = {}, opts = {}) ⇒ Object

Update payment method configuration



2178
2179
2180
2181
2182
2183
2184
2185
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2178

def self.update(configuration, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_method_configurations/%<configuration>s", { configuration: CGI.escape(configuration) }),
    params: params,
    opts: opts
  )
end