Class: Stripe::PaymentMethodConfiguration::CreateParams::Alipay
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethodConfiguration::CreateParams::Alipay
- Defined in:
- lib/stripe/resources/payment_method_configuration.rb
Defined Under Namespace
Classes: DisplayPreference
Instance Attribute Summary collapse
-
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
Instance Method Summary collapse
-
#initialize(display_preference: nil) ⇒ Alipay
constructor
A new instance of Alipay.
Methods inherited from RequestParams
Constructor Details
#initialize(display_preference: nil) ⇒ Alipay
Returns a new instance of Alipay.
1856 1857 1858 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1856 def initialize(display_preference: nil) @display_preference = display_preference end |
Instance Attribute Details
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
1854 1855 1856 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1854 def display_preference @display_preference end |