Class: Stripe::PaymentMethodConfiguration::CreateParams::Boleto
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethodConfiguration::CreateParams::Boleto
- Defined in:
- lib/stripe/resources/payment_method_configuration.rb
Defined Under Namespace
Classes: DisplayPreference
Instance Attribute Summary collapse
-
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
Instance Method Summary collapse
-
#initialize(display_preference: nil) ⇒ Boleto
constructor
A new instance of Boleto.
Methods inherited from RequestParams
Constructor Details
#initialize(display_preference: nil) ⇒ Boleto
Returns a new instance of Boleto.
963 964 965 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 963 def initialize(display_preference: nil) @display_preference = display_preference end |
Instance Attribute Details
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
961 962 963 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 961 def display_preference @display_preference end |