Class: Stripe::PaymentMethodConfiguration::CreateParams::Cashapp::DisplayPreference
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethodConfiguration::CreateParams::Cashapp::DisplayPreference
- Defined in:
- lib/stripe/resources/payment_method_configuration.rb
Instance Attribute Summary collapse
-
#preference ⇒ Object
The account’s preference for whether or not to display this payment method.
Instance Method Summary collapse
-
#initialize(preference: nil) ⇒ DisplayPreference
constructor
A new instance of DisplayPreference.
Methods inherited from RequestParams
Constructor Details
#initialize(preference: nil) ⇒ DisplayPreference
Returns a new instance of DisplayPreference.
1149 1150 1151 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1149 def initialize(preference: nil) @preference = preference end |
Instance Attribute Details
#preference ⇒ Object
The account’s preference for whether or not to display this payment method.
1147 1148 1149 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1147 def preference @preference end |