Class: Stripe::PaymentMethodConfiguration::CreateParams::IdBankTransfer
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethodConfiguration::CreateParams::IdBankTransfer
- Defined in:
- lib/stripe/resources/payment_method_configuration.rb
Defined Under Namespace
Classes: DisplayPreference
Instance Attribute Summary collapse
-
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
Instance Method Summary collapse
-
#initialize(display_preference: nil) ⇒ IdBankTransfer
constructor
A new instance of IdBankTransfer.
Methods inherited from RequestParams
Constructor Details
#initialize(display_preference: nil) ⇒ IdBankTransfer
Returns a new instance of IdBankTransfer.
1317 1318 1319 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1317 def initialize(display_preference: nil) @display_preference = display_preference end |
Instance Attribute Details
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
1315 1316 1317 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1315 def display_preference @display_preference end |