Class: Stripe::PaymentMethodConfiguration::CreateParams::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethodConfiguration::CreateParams::NzBankAccount
- Defined in:
- lib/stripe/resources/payment_method_configuration.rb
Defined Under Namespace
Classes: DisplayPreference
Instance Attribute Summary collapse
-
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
Instance Method Summary collapse
-
#initialize(display_preference: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(display_preference: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
2400 2401 2402 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2400 def initialize(display_preference: nil) @display_preference = display_preference end |
Instance Attribute Details
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
2398 2399 2400 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2398 def display_preference @display_preference end |