Class: Stripe::PaymentMethodConfiguration::CreateParams::Payco
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethodConfiguration::CreateParams::Payco
- Defined in:
- lib/stripe/resources/payment_method_configuration.rb
Defined Under Namespace
Classes: DisplayPreference
Instance Attribute Summary collapse
-
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
Instance Method Summary collapse
-
#initialize(display_preference: nil) ⇒ Payco
constructor
A new instance of Payco.
Methods inherited from RequestParams
Constructor Details
#initialize(display_preference: nil) ⇒ Payco
Returns a new instance of Payco.
1572 1573 1574 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1572 def initialize(display_preference: nil) @display_preference = display_preference end |
Instance Attribute Details
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
1570 1571 1572 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1570 def display_preference @display_preference end |