Class: Stripe::PaymentMethodConfiguration::CreateParams::Shopeepay
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethodConfiguration::CreateParams::Shopeepay
- Defined in:
- lib/stripe/resources/payment_method_configuration.rb
Defined Under Namespace
Classes: DisplayPreference
Instance Attribute Summary collapse
-
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
Instance Method Summary collapse
-
#initialize(display_preference: nil) ⇒ Shopeepay
constructor
A new instance of Shopeepay.
Methods inherited from RequestParams
Constructor Details
#initialize(display_preference: nil) ⇒ Shopeepay
Returns a new instance of Shopeepay.
1759 1760 1761 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1759 def initialize(display_preference: nil) @display_preference = display_preference end |
Instance Attribute Details
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
1757 1758 1759 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1757 def display_preference @display_preference end |