Class: Stripe::PaymentMethodConfiguration::CreateParams::Swish
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethodConfiguration::CreateParams::Swish
- Defined in:
- lib/stripe/resources/payment_method_configuration.rb
Defined Under Namespace
Classes: DisplayPreference
Instance Attribute Summary collapse
-
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
Instance Method Summary collapse
-
#initialize(display_preference: nil) ⇒ Swish
constructor
A new instance of Swish.
Methods inherited from RequestParams
Constructor Details
#initialize(display_preference: nil) ⇒ Swish
Returns a new instance of Swish.
1473 1474 1475 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1473 def initialize(display_preference: nil) @display_preference = display_preference end |
Instance Attribute Details
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
1471 1472 1473 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1471 def display_preference @display_preference end |