Class: Stripe::PaymentMethodConfiguration::CreateParams::Twint::DisplayPreference
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethodConfiguration::CreateParams::Twint::DisplayPreference
- Defined in:
- lib/stripe/resources/payment_method_configuration.rb
Instance Attribute Summary collapse
-
#preference ⇒ Object
The account’s preference for whether or not to display this payment method.
Instance Method Summary collapse
-
#initialize(preference: nil) ⇒ DisplayPreference
constructor
A new instance of DisplayPreference.
Methods inherited from RequestParams
Constructor Details
#initialize(preference: nil) ⇒ DisplayPreference
Returns a new instance of DisplayPreference.
2699 2700 2701 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2699 def initialize(preference: nil) @preference = preference end |
Instance Attribute Details
#preference ⇒ Object
The account’s preference for whether or not to display this payment method.
2697 2698 2699 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2697 def preference @preference end |