Class: Stripe::PaymentMethodConfiguration::CreateParams::Zip::DisplayPreference
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethodConfiguration::CreateParams::Zip::DisplayPreference
- Defined in:
- lib/stripe/resources/payment_method_configuration.rb
Instance Attribute Summary collapse
-
#preference ⇒ Object
The account’s preference for whether or not to display this payment method.
Instance Method Summary collapse
-
#initialize(preference: nil) ⇒ DisplayPreference
constructor
A new instance of DisplayPreference.
Methods inherited from RequestParams
Constructor Details
#initialize(preference: nil) ⇒ DisplayPreference
Returns a new instance of DisplayPreference.
1662 1663 1664 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1662 def initialize(preference: nil) @preference = preference end |
Instance Attribute Details
#preference ⇒ Object
The account’s preference for whether or not to display this payment method.
1660 1661 1662 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1660 def preference @preference end |