Class: Stripe::PaymentMethodConfiguration::ListParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_method_configuration.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(application: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



1777
1778
1779
1780
1781
1782
1783
1784
1785
1786
1787
1788
1789
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1777

def initialize(
  application: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  starting_after: nil
)
  @application = application
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
end

Instance Attribute Details

#applicationObject

The Connect application to filter by.



1767
1768
1769
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1767

def application
  @application
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



1769
1770
1771
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1769

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



1771
1772
1773
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1771

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



1773
1774
1775
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1773

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



1775
1776
1777
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1775

def starting_after
  @starting_after
end