Class: Stripe::PaymentMethodConfiguration::UpdateParams::AfterpayClearpay
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethodConfiguration::UpdateParams::AfterpayClearpay
- Defined in:
- lib/stripe/resources/payment_method_configuration.rb
Defined Under Namespace
Classes: DisplayPreference
Instance Attribute Summary collapse
-
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
Instance Method Summary collapse
-
#initialize(display_preference: nil) ⇒ AfterpayClearpay
constructor
A new instance of AfterpayClearpay.
Methods inherited from RequestParams
Constructor Details
#initialize(display_preference: nil) ⇒ AfterpayClearpay
Returns a new instance of AfterpayClearpay.
2158 2159 2160 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2158 def initialize(display_preference: nil) @display_preference = display_preference end |
Instance Attribute Details
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
2156 2157 2158 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2156 def display_preference @display_preference end |