Class: Stripe::PaymentMethodConfiguration::UpdateParams::Bancontact
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethodConfiguration::UpdateParams::Bancontact
- Defined in:
- lib/stripe/resources/payment_method_configuration.rb
Defined Under Namespace
Classes: DisplayPreference
Instance Attribute Summary collapse
-
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
Instance Method Summary collapse
-
#initialize(display_preference: nil) ⇒ Bancontact
constructor
A new instance of Bancontact.
Methods inherited from RequestParams
Constructor Details
#initialize(display_preference: nil) ⇒ Bancontact
Returns a new instance of Bancontact.
2294 2295 2296 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2294 def initialize(display_preference: nil) @display_preference = display_preference end |
Instance Attribute Details
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
2292 2293 2294 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2292 def display_preference @display_preference end |