Class: Stripe::PaymentMethodConfiguration::UpdateParams::Billie
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethodConfiguration::UpdateParams::Billie
- Defined in:
- lib/stripe/resources/payment_method_configuration.rb
Defined Under Namespace
Classes: DisplayPreference
Instance Attribute Summary collapse
-
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
Instance Method Summary collapse
-
#initialize(display_preference: nil) ⇒ Billie
constructor
A new instance of Billie.
Methods inherited from RequestParams
Constructor Details
#initialize(display_preference: nil) ⇒ Billie
Returns a new instance of Billie.
2095 2096 2097 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2095 def initialize(display_preference: nil) @display_preference = display_preference end |
Instance Attribute Details
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
2093 2094 2095 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2093 def display_preference @display_preference end |