Class: Stripe::PaymentMethodConfiguration::UpdateParams::Boleto
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethodConfiguration::UpdateParams::Boleto
- Defined in:
- lib/stripe/resources/payment_method_configuration.rb
Defined Under Namespace
Classes: DisplayPreference
Instance Attribute Summary collapse
-
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
Instance Method Summary collapse
-
#initialize(display_preference: nil) ⇒ Boleto
constructor
A new instance of Boleto.
Methods inherited from RequestParams
Constructor Details
#initialize(display_preference: nil) ⇒ Boleto
Returns a new instance of Boleto.
1977 1978 1979 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1977 def initialize(display_preference: nil) @display_preference = display_preference end |
Instance Attribute Details
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
1975 1976 1977 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1975 def display_preference @display_preference end |