Class: Stripe::PaymentMethodConfiguration::UpdateParams::GooglePay
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethodConfiguration::UpdateParams::GooglePay
- Defined in:
- lib/stripe/resources/payment_method_configuration.rb
Defined Under Namespace
Classes: DisplayPreference
Instance Attribute Summary collapse
-
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
Instance Method Summary collapse
-
#initialize(display_preference: nil) ⇒ GooglePay
constructor
A new instance of GooglePay.
Methods inherited from RequestParams
Constructor Details
#initialize(display_preference: nil) ⇒ GooglePay
Returns a new instance of GooglePay.
2301 2302 2303 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2301 def initialize(display_preference: nil) @display_preference = display_preference end |
Instance Attribute Details
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
2299 2300 2301 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2299 def display_preference @display_preference end |