Class: Stripe::PaymentMethodConfiguration::UpdateParams::Gopay
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethodConfiguration::UpdateParams::Gopay
- Defined in:
- lib/stripe/resources/payment_method_configuration.rb
Defined Under Namespace
Classes: DisplayPreference
Instance Attribute Summary collapse
-
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
Instance Method Summary collapse
-
#initialize(display_preference: nil) ⇒ Gopay
constructor
A new instance of Gopay.
Methods inherited from RequestParams
Constructor Details
#initialize(display_preference: nil) ⇒ Gopay
Returns a new instance of Gopay.
2130 2131 2132 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2130 def initialize(display_preference: nil) @display_preference = display_preference end |
Instance Attribute Details
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
2128 2129 2130 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2128 def display_preference @display_preference end |