Class: Stripe::PaymentMethodConfiguration::UpdateParams::KrCard
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethodConfiguration::UpdateParams::KrCard
- Defined in:
- lib/stripe/resources/payment_method_configuration.rb
Defined Under Namespace
Classes: DisplayPreference
Instance Attribute Summary collapse
-
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
Instance Method Summary collapse
-
#initialize(display_preference: nil) ⇒ KrCard
constructor
A new instance of KrCard.
Methods inherited from RequestParams
Constructor Details
#initialize(display_preference: nil) ⇒ KrCard
Returns a new instance of KrCard.
3530 3531 3532 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3530 def initialize(display_preference: nil) @display_preference = display_preference end |
Instance Attribute Details
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
3528 3529 3530 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3528 def display_preference @display_preference end |