Class: Stripe::PaymentMethodConfiguration::UpdateParams::KrCard::DisplayPreference
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethodConfiguration::UpdateParams::KrCard::DisplayPreference
- Defined in:
- lib/stripe/resources/payment_method_configuration.rb
Instance Attribute Summary collapse
-
#preference ⇒ Object
The account’s preference for whether or not to display this payment method.
Instance Method Summary collapse
-
#initialize(preference: nil) ⇒ DisplayPreference
constructor
A new instance of DisplayPreference.
Methods inherited from RequestParams
Constructor Details
#initialize(preference: nil) ⇒ DisplayPreference
Returns a new instance of DisplayPreference.
2627 2628 2629 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2627 def initialize(preference: nil) @preference = preference end |
Instance Attribute Details
#preference ⇒ Object
The account’s preference for whether or not to display this payment method.
2625 2626 2627 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2625 def preference @preference end |