Class: Stripe::PaymentMethodConfiguration::UpdateParams::Link
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethodConfiguration::UpdateParams::Link
- Defined in:
- lib/stripe/resources/payment_method_configuration.rb
Defined Under Namespace
Classes: DisplayPreference
Instance Attribute Summary collapse
-
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
Instance Method Summary collapse
-
#initialize(display_preference: nil) ⇒ Link
constructor
A new instance of Link.
Methods inherited from RequestParams
Constructor Details
#initialize(display_preference: nil) ⇒ Link
Returns a new instance of Link.
2285 2286 2287 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2285 def initialize(display_preference: nil) @display_preference = display_preference end |
Instance Attribute Details
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
2283 2284 2285 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2283 def display_preference @display_preference end |