Class: Stripe::PaymentMethodConfiguration::UpdateParams::Pix::DisplayPreference
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethodConfiguration::UpdateParams::Pix::DisplayPreference
- Defined in:
- lib/stripe/resources/payment_method_configuration.rb
Instance Attribute Summary collapse
-
#preference ⇒ Object
The account’s preference for whether or not to display this payment method.
Instance Method Summary collapse
-
#initialize(preference: nil) ⇒ DisplayPreference
constructor
A new instance of DisplayPreference.
Methods inherited from RequestParams
Constructor Details
#initialize(preference: nil) ⇒ DisplayPreference
Returns a new instance of DisplayPreference.
2600 2601 2602 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2600 def initialize(preference: nil) @preference = preference end |
Instance Attribute Details
#preference ⇒ Object
The account’s preference for whether or not to display this payment method.
2598 2599 2600 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2598 def preference @preference end |