Class: Stripe::PaymentMethodConfiguration::UpdateParams::Satispay
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethodConfiguration::UpdateParams::Satispay
- Defined in:
- lib/stripe/resources/payment_method_configuration.rb
Defined Under Namespace
Classes: DisplayPreference
Instance Attribute Summary collapse
-
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
Instance Method Summary collapse
-
#initialize(display_preference: nil) ⇒ Satispay
constructor
A new instance of Satispay.
Methods inherited from RequestParams
Constructor Details
#initialize(display_preference: nil) ⇒ Satispay
Returns a new instance of Satispay.
2622 2623 2624 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2622 def initialize(display_preference: nil) @display_preference = display_preference end |
Instance Attribute Details
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
2620 2621 2622 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2620 def display_preference @display_preference end |