Class: Stripe::PaymentMethodConfigurationCreateParams::Upi
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethodConfigurationCreateParams::Upi
- Defined in:
- lib/stripe/params/payment_method_configuration_create_params.rb
Defined Under Namespace
Classes: DisplayPreference
Instance Attribute Summary collapse
-
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
Instance Method Summary collapse
-
#initialize(display_preference: nil) ⇒ Upi
constructor
A new instance of Upi.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(display_preference: nil) ⇒ Upi
Returns a new instance of Upi.
1021 1022 1023 |
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1021 def initialize(display_preference: nil) @display_preference = display_preference end |
Instance Attribute Details
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
1019 1020 1021 |
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1019 def display_preference @display_preference end |