Class: Stripe::PaymentMethodConfigurationListParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_method_configuration_list_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(active: nil, application: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ PaymentMethodConfigurationListParams

Returns a new instance of PaymentMethodConfigurationListParams.



19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
# File 'lib/stripe/params/payment_method_configuration_list_params.rb', line 19

def initialize(
  active: nil,
  application: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  starting_after: nil
)
  @active = active
  @application = application
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
end

Instance Attribute Details

#activeObject

Whether the configuration is active.



7
8
9
# File 'lib/stripe/params/payment_method_configuration_list_params.rb', line 7

def active
  @active
end

#applicationObject

The Connect application to filter by.



9
10
11
# File 'lib/stripe/params/payment_method_configuration_list_params.rb', line 9

def application
  @application
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



11
12
13
# File 'lib/stripe/params/payment_method_configuration_list_params.rb', line 11

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



13
14
15
# File 'lib/stripe/params/payment_method_configuration_list_params.rb', line 13

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



15
16
17
# File 'lib/stripe/params/payment_method_configuration_list_params.rb', line 15

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



17
18
19
# File 'lib/stripe/params/payment_method_configuration_list_params.rb', line 17

def starting_after
  @starting_after
end