Class: Stripe::PaymentMethodConfigurationService::CreateParams::AuBecsDebit
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethodConfigurationService::CreateParams::AuBecsDebit
- Defined in:
- lib/stripe/services/payment_method_configuration_service.rb
Defined Under Namespace
Classes: DisplayPreference
Instance Attribute Summary collapse
-
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
Instance Method Summary collapse
-
#initialize(display_preference: nil) ⇒ AuBecsDebit
constructor
A new instance of AuBecsDebit.
Methods inherited from RequestParams
Constructor Details
#initialize(display_preference: nil) ⇒ AuBecsDebit
Returns a new instance of AuBecsDebit.
182 183 184 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 182 def initialize(display_preference: nil) @display_preference = display_preference end |
Instance Attribute Details
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
180 181 182 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 180 def display_preference @display_preference end |