Class: Stripe::PaymentMethodConfigurationService::CreateParams::GooglePay
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethodConfigurationService::CreateParams::GooglePay
- Defined in:
- lib/stripe/services/payment_method_configuration_service.rb
Defined Under Namespace
Classes: DisplayPreference
Instance Attribute Summary collapse
-
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
Instance Method Summary collapse
-
#initialize(display_preference: nil) ⇒ GooglePay
constructor
A new instance of GooglePay.
Methods inherited from RequestParams
Constructor Details
#initialize(display_preference: nil) ⇒ GooglePay
Returns a new instance of GooglePay.
390 391 392 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 390 def initialize(display_preference: nil) @display_preference = display_preference end |
Instance Attribute Details
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
388 389 390 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 388 def display_preference @display_preference end |