Class: Stripe::PaymentMethodConfigurationService::CreateParams::SamsungPay
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethodConfigurationService::CreateParams::SamsungPay
- Defined in:
- lib/stripe/services/payment_method_configuration_service.rb
Defined Under Namespace
Classes: DisplayPreference
Instance Attribute Summary collapse
-
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
Instance Method Summary collapse
-
#initialize(display_preference: nil) ⇒ SamsungPay
constructor
A new instance of SamsungPay.
Methods inherited from RequestParams
Constructor Details
#initialize(display_preference: nil) ⇒ SamsungPay
Returns a new instance of SamsungPay.
845 846 847 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 845 def initialize(display_preference: nil) @display_preference = display_preference end |
Instance Attribute Details
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
843 844 845 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 843 def display_preference @display_preference end |