Class: Stripe::PaymentMethodConfigurationService::UpdateParams::AcssDebit
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethodConfigurationService::UpdateParams::AcssDebit
- Defined in:
- lib/stripe/services/payment_method_configuration_service.rb
Defined Under Namespace
Classes: DisplayPreference
Instance Attribute Summary collapse
-
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
Instance Method Summary collapse
-
#initialize(display_preference: nil) ⇒ AcssDebit
constructor
A new instance of AcssDebit.
Methods inherited from RequestParams
Constructor Details
#initialize(display_preference: nil) ⇒ AcssDebit
Returns a new instance of AcssDebit.
1165 1166 1167 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1165 def initialize(display_preference: nil) @display_preference = display_preference end |
Instance Attribute Details
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
1163 1164 1165 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1163 def display_preference @display_preference end |