Class: Stripe::PaymentMethodConfigurationService::UpdateParams::AcssDebit::DisplayPreference
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethodConfigurationService::UpdateParams::AcssDebit::DisplayPreference
- Defined in:
- lib/stripe/services/payment_method_configuration_service.rb
Instance Attribute Summary collapse
-
#preference ⇒ Object
The account’s preference for whether or not to display this payment method.
Instance Method Summary collapse
-
#initialize(preference: nil) ⇒ DisplayPreference
constructor
A new instance of DisplayPreference.
Methods inherited from RequestParams
Constructor Details
#initialize(preference: nil) ⇒ DisplayPreference
Returns a new instance of DisplayPreference.
1158 1159 1160 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1158 def initialize(preference: nil) @preference = preference end |
Instance Attribute Details
#preference ⇒ Object
The account’s preference for whether or not to display this payment method.
1156 1157 1158 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1156 def preference @preference end |