Class: Stripe::PaymentMethodConfigurationService::UpdateParams::Alma
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethodConfigurationService::UpdateParams::Alma
- Defined in:
- lib/stripe/services/payment_method_configuration_service.rb
Defined Under Namespace
Classes: DisplayPreference
Instance Attribute Summary collapse
-
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
Instance Method Summary collapse
-
#initialize(display_preference: nil) ⇒ Alma
constructor
A new instance of Alma.
Methods inherited from RequestParams
Constructor Details
#initialize(display_preference: nil) ⇒ Alma
Returns a new instance of Alma.
1233 1234 1235 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1233 def initialize(display_preference: nil) @display_preference = display_preference end |
Instance Attribute Details
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
1231 1232 1233 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1231 def display_preference @display_preference end |