Class: Stripe::PaymentMethodConfigurationService::UpdateParams::Bancontact
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethodConfigurationService::UpdateParams::Bancontact
- Defined in:
- lib/stripe/services/payment_method_configuration_service.rb
Defined Under Namespace
Classes: DisplayPreference
Instance Attribute Summary collapse
-
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
Instance Method Summary collapse
-
#initialize(display_preference: nil) ⇒ Bancontact
constructor
A new instance of Bancontact.
Methods inherited from RequestParams
Constructor Details
#initialize(display_preference: nil) ⇒ Bancontact
Returns a new instance of Bancontact.
1335 1336 1337 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1335 def initialize(display_preference: nil) @display_preference = display_preference end |
Instance Attribute Details
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
1333 1334 1335 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1333 def display_preference @display_preference end |