Class: Stripe::PaymentMethodConfigurationService::UpdateParams::Boleto
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethodConfigurationService::UpdateParams::Boleto
- Defined in:
- lib/stripe/services/payment_method_configuration_service.rb
Defined Under Namespace
Classes: DisplayPreference
Instance Attribute Summary collapse
-
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
Instance Method Summary collapse
-
#initialize(display_preference: nil) ⇒ Boleto
constructor
A new instance of Boleto.
Methods inherited from RequestParams
Constructor Details
#initialize(display_preference: nil) ⇒ Boleto
Returns a new instance of Boleto.
1491 1492 1493 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1491 def initialize(display_preference: nil) @display_preference = display_preference end |
Instance Attribute Details
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
1489 1490 1491 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1489 def display_preference @display_preference end |