Class: Stripe::PaymentMethodConfigurationService::UpdateParams::GooglePay
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethodConfigurationService::UpdateParams::GooglePay
- Defined in:
- lib/stripe/services/payment_method_configuration_service.rb
Defined Under Namespace
Classes: DisplayPreference
Instance Attribute Summary collapse
-
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
Instance Method Summary collapse
-
#initialize(display_preference: nil) ⇒ GooglePay
constructor
A new instance of GooglePay.
Methods inherited from RequestParams
Constructor Details
#initialize(display_preference: nil) ⇒ GooglePay
Returns a new instance of GooglePay.
1522 1523 1524 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1522 def initialize(display_preference: nil) @display_preference = display_preference end |
Instance Attribute Details
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
1520 1521 1522 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1520 def display_preference @display_preference end |