Class: Stripe::PaymentMethodConfigurationService::UpdateParams::IdBankTransfer
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethodConfigurationService::UpdateParams::IdBankTransfer
- Defined in:
- lib/stripe/services/payment_method_configuration_service.rb
Defined Under Namespace
Classes: DisplayPreference
Instance Attribute Summary collapse
-
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
Instance Method Summary collapse
-
#initialize(display_preference: nil) ⇒ IdBankTransfer
constructor
A new instance of IdBankTransfer.
Methods inherited from RequestParams
Constructor Details
#initialize(display_preference: nil) ⇒ IdBankTransfer
Returns a new instance of IdBankTransfer.
1678 1679 1680 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1678 def initialize(display_preference: nil) @display_preference = display_preference end |
Instance Attribute Details
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
1676 1677 1678 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1676 def display_preference @display_preference end |