Class: Stripe::PaymentMethodConfigurationService::UpdateParams::Mobilepay
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethodConfigurationService::UpdateParams::Mobilepay
- Defined in:
- lib/stripe/services/payment_method_configuration_service.rb
Defined Under Namespace
Classes: DisplayPreference
Instance Attribute Summary collapse
-
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
Instance Method Summary collapse
-
#initialize(display_preference: nil) ⇒ Mobilepay
constructor
A new instance of Mobilepay.
Methods inherited from RequestParams
Constructor Details
#initialize(display_preference: nil) ⇒ Mobilepay
Returns a new instance of Mobilepay.
1515 1516 1517 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1515 def initialize(display_preference: nil) @display_preference = display_preference end |
Instance Attribute Details
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
1513 1514 1515 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1513 def display_preference @display_preference end |