Class: Stripe::PaymentMethodConfigurationService::UpdateParams::NaverPay
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethodConfigurationService::UpdateParams::NaverPay
- Defined in:
- lib/stripe/services/payment_method_configuration_service.rb
Defined Under Namespace
Classes: DisplayPreference
Instance Attribute Summary collapse
-
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
Instance Method Summary collapse
-
#initialize(display_preference: nil) ⇒ NaverPay
constructor
A new instance of NaverPay.
Methods inherited from RequestParams
Constructor Details
#initialize(display_preference: nil) ⇒ NaverPay
Returns a new instance of NaverPay.
1709 1710 1711 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1709 def initialize(display_preference: nil) @display_preference = display_preference end |
Instance Attribute Details
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
1707 1708 1709 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1707 def display_preference @display_preference end |