Class: Stripe::PaymentMethodConfigurationService::UpdateParams::Payto
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethodConfigurationService::UpdateParams::Payto
- Defined in:
- lib/stripe/services/payment_method_configuration_service.rb
Defined Under Namespace
Classes: DisplayPreference
Instance Attribute Summary collapse
-
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
Instance Method Summary collapse
-
#initialize(display_preference: nil) ⇒ Payto
constructor
A new instance of Payto.
Methods inherited from RequestParams
Constructor Details
#initialize(display_preference: nil) ⇒ Payto
Returns a new instance of Payto.
1708 1709 1710 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1708 def initialize(display_preference: nil) @display_preference = display_preference end |
Instance Attribute Details
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
1706 1707 1708 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1706 def display_preference @display_preference end |