Class: Stripe::PaymentMethodConfigurationService::UpdateParams::Promptpay::DisplayPreference
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethodConfigurationService::UpdateParams::Promptpay::DisplayPreference
- Defined in:
- lib/stripe/services/payment_method_configuration_service.rb
Instance Attribute Summary collapse
-
#preference ⇒ Object
The account’s preference for whether or not to display this payment method.
Instance Method Summary collapse
-
#initialize(preference: nil) ⇒ DisplayPreference
constructor
A new instance of DisplayPreference.
Methods inherited from RequestParams
Constructor Details
#initialize(preference: nil) ⇒ DisplayPreference
Returns a new instance of DisplayPreference.
1682 1683 1684 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1682 def initialize(preference: nil) @preference = preference end |
Instance Attribute Details
#preference ⇒ Object
The account’s preference for whether or not to display this payment method.
1680 1681 1682 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1680 def preference @preference end |