Class: Stripe::PaymentMethodConfigurationService::UpdateParams::Qris::DisplayPreference
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethodConfigurationService::UpdateParams::Qris::DisplayPreference
- Defined in:
- lib/stripe/services/payment_method_configuration_service.rb
Instance Attribute Summary collapse
-
#preference ⇒ Object
The account’s preference for whether or not to display this payment method.
Instance Method Summary collapse
-
#initialize(preference: nil) ⇒ DisplayPreference
constructor
A new instance of DisplayPreference.
Methods inherited from RequestParams
Constructor Details
#initialize(preference: nil) ⇒ DisplayPreference
Returns a new instance of DisplayPreference.
2028 2029 2030 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 2028 def initialize(preference: nil) @preference = preference end |
Instance Attribute Details
#preference ⇒ Object
The account’s preference for whether or not to display this payment method.
2026 2027 2028 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 2026 def preference @preference end |