Class: Stripe::PaymentMethodConfigurationService::UpdateParams::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethodConfigurationService::UpdateParams::UsBankAccount
- Defined in:
- lib/stripe/services/payment_method_configuration_service.rb
Defined Under Namespace
Classes: DisplayPreference
Instance Attribute Summary collapse
-
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
Instance Method Summary collapse
-
#initialize(display_preference: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(display_preference: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
1861 1862 1863 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1861 def initialize(display_preference: nil) @display_preference = display_preference end |
Instance Attribute Details
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
1859 1860 1861 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1859 def display_preference @display_preference end |