Class: Stripe::PaymentMethodConfigurationService::UpdateParams::WechatPay
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethodConfigurationService::UpdateParams::WechatPay
- Defined in:
- lib/stripe/services/payment_method_configuration_service.rb
Defined Under Namespace
Classes: DisplayPreference
Instance Attribute Summary collapse
-
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
Instance Method Summary collapse
-
#initialize(display_preference: nil) ⇒ WechatPay
constructor
A new instance of WechatPay.
Methods inherited from RequestParams
Constructor Details
#initialize(display_preference: nil) ⇒ WechatPay
Returns a new instance of WechatPay.
1977 1978 1979 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1977 def initialize(display_preference: nil) @display_preference = display_preference end |
Instance Attribute Details
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
1975 1976 1977 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1975 def display_preference @display_preference end |