Class: Stripe::PaymentMethodConfigurationService::UpdateParams::Zip
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethodConfigurationService::UpdateParams::Zip
- Defined in:
- lib/stripe/services/payment_method_configuration_service.rb
Defined Under Namespace
Classes: DisplayPreference
Instance Attribute Summary collapse
-
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
Instance Method Summary collapse
-
#initialize(display_preference: nil) ⇒ Zip
constructor
A new instance of Zip.
Methods inherited from RequestParams
Constructor Details
#initialize(display_preference: nil) ⇒ Zip
Returns a new instance of Zip.
2222 2223 2224 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 2222 def initialize(display_preference: nil) @display_preference = display_preference end |
Instance Attribute Details
#display_preference ⇒ Object
Whether or not the payment method should be displayed.
2220 2221 2222 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 2220 def display_preference @display_preference end |