Class: Stripe::PaymentMethodConfigurationUpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_method_configuration_update_params.rb

Defined Under Namespace

Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, ApplePay, ApplePayLater, AuBecsDebit, BacsDebit, Bancontact, Billie, Blik, Boleto, Card, CartesBancaires, Cashapp, Crypto, CustomerBalance, Eps, Fpx, FrMealVoucherConecs, Giropay, GooglePay, Gopay, Grabpay, IdBankTransfer, Ideal, Jcb, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Paypay, Payto, Pix, Promptpay, Qris, RevolutPay, SamsungPay, Satispay, SepaDebit, Shopeepay, Sofort, Sunbit, Swish, Twint, Upi, UsBankAccount, WechatPay, Zip

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(acss_debit: nil, active: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, alma: nil, amazon_pay: nil, apple_pay: nil, apple_pay_later: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, billie: nil, blik: nil, boleto: nil, card: nil, cartes_bancaires: nil, cashapp: nil, crypto: nil, customer_balance: nil, eps: nil, expand: nil, fpx: nil, fr_meal_voucher_conecs: nil, giropay: nil, google_pay: nil, gopay: nil, grabpay: nil, id_bank_transfer: nil, ideal: nil, jcb: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, mb_way: nil, mobilepay: nil, multibanco: nil, name: nil, naver_pay: nil, nz_bank_account: nil, oxxo: nil, p24: nil, pay_by_bank: nil, payco: nil, paynow: nil, paypal: nil, paypay: nil, payto: nil, pix: nil, promptpay: nil, qris: nil, revolut_pay: nil, samsung_pay: nil, satispay: nil, sepa_debit: nil, shopeepay: nil, sofort: nil, sunbit: nil, swish: nil, twint: nil, upi: nil, us_bank_account: nil, wechat_pay: nil, zip: nil) ⇒ PaymentMethodConfigurationUpdateParams

Returns a new instance of PaymentMethodConfigurationUpdateParams.



1209
1210
1211
1212
1213
1214
1215
1216
1217
1218
1219
1220
1221
1222
1223
1224
1225
1226
1227
1228
1229
1230
1231
1232
1233
1234
1235
1236
1237
1238
1239
1240
1241
1242
1243
1244
1245
1246
1247
1248
1249
1250
1251
1252
1253
1254
1255
1256
1257
1258
1259
1260
1261
1262
1263
1264
1265
1266
1267
1268
1269
1270
1271
1272
1273
1274
1275
1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
1315
1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
1342
1343
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1209

def initialize(
  acss_debit: nil,
  active: nil,
  affirm: nil,
  afterpay_clearpay: nil,
  alipay: nil,
  alma: nil,
  amazon_pay: nil,
  apple_pay: nil,
  apple_pay_later: nil,
  au_becs_debit: nil,
  bacs_debit: nil,
  bancontact: nil,
  billie: nil,
  blik: nil,
  boleto: nil,
  card: nil,
  cartes_bancaires: nil,
  cashapp: nil,
  crypto: nil,
  customer_balance: nil,
  eps: nil,
  expand: nil,
  fpx: nil,
  fr_meal_voucher_conecs: nil,
  giropay: nil,
  google_pay: nil,
  gopay: nil,
  grabpay: nil,
  id_bank_transfer: nil,
  ideal: nil,
  jcb: nil,
  kakao_pay: nil,
  klarna: nil,
  konbini: nil,
  kr_card: nil,
  link: nil,
  mb_way: nil,
  mobilepay: nil,
  multibanco: nil,
  name: nil,
  naver_pay: nil,
  nz_bank_account: nil,
  oxxo: nil,
  p24: nil,
  pay_by_bank: nil,
  payco: nil,
  paynow: nil,
  paypal: nil,
  paypay: nil,
  payto: nil,
  pix: nil,
  promptpay: nil,
  qris: nil,
  revolut_pay: nil,
  samsung_pay: nil,
  satispay: nil,
  sepa_debit: nil,
  shopeepay: nil,
  sofort: nil,
  sunbit: nil,
  swish: nil,
  twint: nil,
  upi: nil,
  us_bank_account: nil,
  wechat_pay: nil,
  zip: nil
)
  @acss_debit = acss_debit
  @active = active
  @affirm = affirm
  @afterpay_clearpay = afterpay_clearpay
  @alipay = alipay
  @alma = alma
  @amazon_pay = amazon_pay
  @apple_pay = apple_pay
  @apple_pay_later = apple_pay_later
  @au_becs_debit = au_becs_debit
  @bacs_debit = bacs_debit
  @bancontact = bancontact
  @billie = billie
  @blik = blik
  @boleto = boleto
  @card = card
  @cartes_bancaires = cartes_bancaires
  @cashapp = cashapp
  @crypto = crypto
  @customer_balance = customer_balance
  @eps = eps
  @expand = expand
  @fpx = fpx
  @fr_meal_voucher_conecs = fr_meal_voucher_conecs
  @giropay = giropay
  @google_pay = google_pay
  @gopay = gopay
  @grabpay = grabpay
  @id_bank_transfer = id_bank_transfer
  @ideal = ideal
  @jcb = jcb
  @kakao_pay = kakao_pay
  @klarna = klarna
  @konbini = konbini
  @kr_card = kr_card
  @link = link
  @mb_way = mb_way
  @mobilepay = mobilepay
  @multibanco = multibanco
  @name = name
  @naver_pay = naver_pay
  @nz_bank_account = 
  @oxxo = oxxo
  @p24 = p24
  @pay_by_bank = pay_by_bank
  @payco = payco
  @paynow = paynow
  @paypal = paypal
  @paypay = paypay
  @payto = payto
  @pix = pix
  @promptpay = promptpay
  @qris = qris
  @revolut_pay = revolut_pay
  @samsung_pay = samsung_pay
  @satispay = satispay
  @sepa_debit = sepa_debit
  @shopeepay = shopeepay
  @sofort = sofort
  @sunbit = sunbit
  @swish = swish
  @twint = twint
  @upi = upi
  @us_bank_account = 
  @wechat_pay = wechat_pay
  @zip = zip
end

Instance Attribute Details

#acss_debitObject

Canadian pre-authorized debit payments, check this [page](docs.stripe.com/payments/acss-debit) for more details like country availability.



1077
1078
1079
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1077

def acss_debit
  @acss_debit
end

#activeObject

Whether the configuration can be used for new payments.



1079
1080
1081
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1079

def active
  @active
end

#affirmObject

[Affirm](www.affirm.com/) gives your customers a way to split purchases over a series of payments. Depending on the purchase, they can pay with four interest-free payments (Split Pay) or pay over a longer term (Installments), which might include interest. Check this [page](docs.stripe.com/payments/affirm) for more details like country availability.



1081
1082
1083
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1081

def affirm
  @affirm
end

#afterpay_clearpayObject

Afterpay gives your customers a way to pay for purchases in installments, check this [page](docs.stripe.com/payments/afterpay-clearpay) for more details like country availability. Afterpay is particularly popular among businesses selling fashion, beauty, and sports products.



1083
1084
1085
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1083

def afterpay_clearpay
  @afterpay_clearpay
end

#alipayObject

Alipay is a digital wallet in China that has more than a billion active users worldwide. Alipay users can pay on the web or on a mobile device using login credentials or their Alipay app. Alipay has a low dispute rate and reduces fraud by authenticating payments using the customer’s login credentials. Check this [page](docs.stripe.com/payments/alipay) for more details.



1085
1086
1087
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1085

def alipay
  @alipay
end

#almaObject

Alma is a Buy Now, Pay Later payment method that offers customers the ability to pay in 2, 3, or 4 installments.



1087
1088
1089
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1087

def alma
  @alma
end

#amazon_payObject

Amazon Pay is a wallet payment method that lets your customers check out the same way as on Amazon.



1089
1090
1091
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1089

def amazon_pay
  @amazon_pay
end

#apple_payObject

Stripe users can accept [Apple Pay](stripe.com/payments/apple-pay) in iOS applications in iOS 9 and later, and on the web in Safari starting with iOS 10 or macOS Sierra. There are no additional fees to process Apple Pay payments, and the [pricing](stripe.com/pricing) is the same as other card transactions. Check this [page](docs.stripe.com/apple-pay) for more details.



1091
1092
1093
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1091

def apple_pay
  @apple_pay
end

#apple_pay_laterObject

Apple Pay Later, a payment method for customers to buy now and pay later, gives your customers a way to split purchases into four installments across six weeks.



1093
1094
1095
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1093

def apple_pay_later
  @apple_pay_later
end

#au_becs_debitObject

Stripe users in Australia can accept Bulk Electronic Clearing System (BECS) direct debit payments from customers with an Australian bank account. Check this [page](docs.stripe.com/payments/au-becs-debit) for more details.



1095
1096
1097
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1095

def au_becs_debit
  @au_becs_debit
end

#bacs_debitObject

Stripe users in the UK can accept Bacs Direct Debit payments from customers with a UK bank account, check this [page](docs.stripe.com/payments/payment-methods/bacs-debit) for more details.



1097
1098
1099
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1097

def bacs_debit
  @bacs_debit
end

#bancontactObject

Bancontact is the most popular online payment method in Belgium, with over 15 million cards in circulation. [Customers](docs.stripe.com/api/customers) use a Bancontact card or mobile app linked to a Belgian bank account to make online payments that are secure, guaranteed, and confirmed immediately. Check this [page](docs.stripe.com/payments/bancontact) for more details.



1099
1100
1101
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1099

def bancontact
  @bancontact
end

#billieObject

Billie is a [single-use](docs.stripe.com/payments/payment-methods#usage) payment method that offers businesses Pay by Invoice where they offer payment terms ranging from 7-120 days. Customers are redirected from your website or app, authorize the payment with Billie, then return to your website or app. You get [immediate notification](/payments/payment-methods#payment-notification) of whether the payment succeeded or failed.



1101
1102
1103
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1101

def billie
  @billie
end

#blikObject

BLIK is a [single use](docs.stripe.com/payments/payment-methods#usage) payment method that requires customers to authenticate their payments. When customers want to pay online using BLIK, they request a six-digit code from their banking application and enter it into the payment collection form. Check this [page](docs.stripe.com/payments/blik) for more details.



1103
1104
1105
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1103

def blik
  @blik
end

#boletoObject

Boleto is an official (regulated by the Central Bank of Brazil) payment method in Brazil. Check this [page](docs.stripe.com/payments/boleto) for more details.



1105
1106
1107
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1105

def boleto
  @boleto
end

#cardObject

Cards are a popular way for consumers and businesses to pay online or in person. Stripe supports global and local card networks.



1107
1108
1109
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1107

def card
  @card
end

#cartes_bancairesObject

Cartes Bancaires is France’s local card network. More than 95% of these cards are co-branded with either Visa or Mastercard, meaning you can process these cards over either Cartes Bancaires or the Visa or Mastercard networks. Check this [page](docs.stripe.com/payments/cartes-bancaires) for more details.



1109
1110
1111
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1109

def cartes_bancaires
  @cartes_bancaires
end

#cashappObject

Cash App is a popular consumer app in the US that allows customers to bank, invest, send, and receive money using their digital wallet. Check this [page](docs.stripe.com/payments/cash-app-pay) for more details.



1111
1112
1113
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1111

def cashapp
  @cashapp
end

#cryptoObject

[Stablecoin payments](docs.stripe.com/payments/stablecoin-payments) enable customers to pay in stablecoins like USDC from 100s of wallets including Phantom and Metamask.



1113
1114
1115
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1113

def crypto
  @crypto
end

#customer_balanceObject

Uses a customer’s [cash balance](docs.stripe.com/payments/customer-balance) for the payment. The cash balance can be funded via a bank transfer. Check this [page](docs.stripe.com/payments/bank-transfers) for more details.



1115
1116
1117
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1115

def customer_balance
  @customer_balance
end

#epsObject

EPS is an Austria-based payment method that allows customers to complete transactions online using their bank credentials. EPS is supported by all Austrian banks and is accepted by over 80% of Austrian online retailers. Check this [page](docs.stripe.com/payments/eps) for more details.



1117
1118
1119
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1117

def eps
  @eps
end

#expandObject

Specifies which fields in the response should be expanded.



1119
1120
1121
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1119

def expand
  @expand
end

#fpxObject

Financial Process Exchange (FPX) is a Malaysia-based payment method that allows customers to complete transactions online using their bank credentials. Bank Negara Malaysia (BNM), the Central Bank of Malaysia, and eleven other major Malaysian financial institutions are members of the PayNet Group, which owns and operates FPX. It is one of the most popular online payment methods in Malaysia, with nearly 90 million transactions in 2018 according to BNM. Check this [page](docs.stripe.com/payments/fpx) for more details.



1121
1122
1123
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1121

def fpx
  @fpx
end

#fr_meal_voucher_conecsObject

Meal vouchers in France, or “titres-restaurant”, is a local benefits program commonly offered by employers for their employees to purchase prepared food and beverages on working days. Check this [page](docs.stripe.com/payments/meal-vouchers/fr-meal-vouchers) for more details.



1123
1124
1125
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1123

def fr_meal_voucher_conecs
  @fr_meal_voucher_conecs
end

#giropayObject

giropay is a German payment method based on online banking, introduced in 2006. It allows customers to complete transactions online using their online banking environment, with funds debited from their bank account. Depending on their bank, customers confirm payments on giropay using a second factor of authentication or a PIN. giropay accounts for 10% of online checkouts in Germany. Check this [page](docs.stripe.com/payments/giropay) for more details.



1125
1126
1127
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1125

def giropay
  @giropay
end

#google_payObject

Google Pay allows customers to make payments in your app or website using any credit or debit card saved to their Google Account, including those from Google Play, YouTube, Chrome, or an Android device. Use the Google Pay API to request any credit or debit card stored in your customer’s Google account. Check this [page](docs.stripe.com/google-pay) for more details.



1127
1128
1129
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1127

def google_pay
  @google_pay
end

#gopayObject

GoPay is a [single use](docs.stripe.com/payments/payment-methods#usage) digital wallet payment method popular in Indonesia. When paying with GoPay, customers authenticate and approve payments using the Gojek app. Desktop checkout is performed by scanning a QR code. When checking out on mobile, customers are redirected to the Gojek app to confirm payment.



1129
1130
1131
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1129

def gopay
  @gopay
end

#grabpayObject

GrabPay is a payment method developed by [Grab](www.grab.com/sg/consumer/finance/pay/). GrabPay is a digital wallet - customers maintain a balance in their wallets that they pay out with. Check this [page](docs.stripe.com/payments/grabpay) for more details.



1131
1132
1133
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1131

def grabpay
  @grabpay
end

#id_bank_transferObject

Stripe users in Indonesia can receive bank transfers from customers in Indonesia. Bank transfers are a popular B2C and B2B payment method in Indonesia.



1133
1134
1135
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1133

def id_bank_transfer
  @id_bank_transfer
end

#idealObject

iDEAL is a Netherlands-based payment method that allows customers to complete transactions online using their bank credentials. All major Dutch banks are members of Currence, the scheme that operates iDEAL, making it the most popular online payment method in the Netherlands with a share of online transactions close to 55%. Check this [page](docs.stripe.com/payments/ideal) for more details.



1135
1136
1137
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1135

def ideal
  @ideal
end

#jcbObject

JCB is a credit card company based in Japan. JCB is currently available in Japan to businesses approved by JCB, and available to all businesses in Australia, Canada, Hong Kong, Japan, New Zealand, Singapore, Switzerland, United Kingdom, United States, and all countries in the European Economic Area except Iceland. Check this [page](support.stripe.com/questions/accepting-japan-credit-bureau-%28jcb%29-payments) for more details.



1137
1138
1139
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1137

def jcb
  @jcb
end

#kakao_payObject

Kakao Pay is a popular local wallet available in South Korea.



1139
1140
1141
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1139

def kakao_pay
  @kakao_pay
end

#klarnaObject

Klarna gives customers a range of [payment options](docs.stripe.com/payments/klarna#payment-options) during checkout. Available payment options vary depending on the customer’s billing address and the transaction amount. These payment options make it convenient for customers to purchase items in all price ranges. Check this [page](docs.stripe.com/payments/klarna) for more details.



1141
1142
1143
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1141

def klarna
  @klarna
end

#konbiniObject

Konbini allows customers in Japan to pay for bills and online purchases at convenience stores with cash. Check this [page](docs.stripe.com/payments/konbini) for more details.



1143
1144
1145
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1143

def konbini
  @konbini
end

#kr_cardObject

Korean cards let users pay using locally issued cards from South Korea.



1145
1146
1147
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1145

def kr_card
  @kr_card
end

[Link](docs.stripe.com/payments/link) is a payment method network. With Link, users save their payment details once, then reuse that information to pay with one click for any business on the network.



1147
1148
1149
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1147

def link
  @link
end

#mb_wayObject

MB WAY is the most popular wallet in Portugal. After entering their phone number in your checkout, customers approve the payment directly in their MB WAY app. Check this [page](docs.stripe.com/payments/mb-way) for more details.



1149
1150
1151
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1149

def mb_way
  @mb_way
end

#mobilepayObject

MobilePay is a [single-use](docs.stripe.com/payments/payment-methods#usage) card wallet payment method used in Denmark and Finland. It allows customers to [authenticate and approve](docs.stripe.com/payments/payment-methods#customer-actions) payments using the MobilePay app. Check this [page](docs.stripe.com/payments/mobilepay) for more details.



1151
1152
1153
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1151

def mobilepay
  @mobilepay
end

#multibancoObject

Stripe users in Europe and the United States can accept Multibanco payments from customers in Portugal using [Sources](stripe.com/docs/sources)—a single integration path for creating payments using any supported method.



1153
1154
1155
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1153

def multibanco
  @multibanco
end

#nameObject

Configuration name.



1155
1156
1157
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1155

def name
  @name
end

Naver Pay is a popular local wallet available in South Korea.



1157
1158
1159
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1157

def naver_pay
  @naver_pay
end

#nz_bank_accountObject

Stripe users in New Zealand can accept Bulk Electronic Clearing System (BECS) direct debit payments from customers with a New Zeland bank account. Check this [page](docs.stripe.com/payments/nz-bank-account) for more details.



1159
1160
1161
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1159

def 
  @nz_bank_account
end

#oxxoObject

OXXO is a Mexican chain of convenience stores with thousands of locations across Latin America and represents nearly 20% of online transactions in Mexico. OXXO allows customers to pay bills and online purchases in-store with cash. Check this [page](docs.stripe.com/payments/oxxo) for more details.



1161
1162
1163
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1161

def oxxo
  @oxxo
end

#p24Object

Przelewy24 is a Poland-based payment method aggregator that allows customers to complete transactions online using bank transfers and other methods. Bank transfers account for 30% of online payments in Poland and Przelewy24 provides a way for customers to pay with over 165 banks. Check this [page](docs.stripe.com/payments/p24) for more details.



1163
1164
1165
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1163

def p24
  @p24
end

#pay_by_bankObject

Pay by bank is a redirect payment method backed by bank transfers. A customer is redirected to their bank to authorize a bank transfer for a given amount. This removes a lot of the error risks inherent in waiting for the customer to initiate a transfer themselves, and is less expensive than card payments.



1165
1166
1167
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1165

def pay_by_bank
  @pay_by_bank
end

#paycoObject

PAYCO is a [single-use](docs.stripe.com/payments/payment-methods#usage local wallet available in South Korea.



1167
1168
1169
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1167

def payco
  @payco
end

#paynowObject

PayNow is a Singapore-based payment method that allows customers to make a payment using their preferred app from participating banks and participating non-bank financial institutions. Check this [page](docs.stripe.com/payments/paynow) for more details.



1169
1170
1171
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1169

def paynow
  @paynow
end

#paypalObject

PayPal, a digital wallet popular with customers in Europe, allows your customers worldwide to pay using their PayPal account. Check this [page](docs.stripe.com/payments/paypal) for more details.



1171
1172
1173
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1171

def paypal
  @paypal
end

#paypayObject

Customers can pay with PayPay online or using the PayPay app.



1173
1174
1175
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1173

def paypay
  @paypay
end

#paytoObject

PayTo is a [real-time](docs.stripe.com/payments/real-time) payment method that enables customers in Australia to pay by providing their bank account details. Customers must accept a mandate authorizing you to debit their account. Check this [page](docs.stripe.com/payments/payto) for more details.



1175
1176
1177
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1175

def payto
  @payto
end

#pixObject

Pix is a payment method popular in Brazil. When paying with Pix, customers authenticate and approve payments by scanning a QR code in their preferred banking app. Check this [page](docs.stripe.com/payments/pix) for more details.



1177
1178
1179
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1177

def pix
  @pix
end

#promptpayObject

PromptPay is a Thailand-based payment method that allows customers to make a payment using their preferred app from participating banks. Check this [page](docs.stripe.com/payments/promptpay) for more details.



1179
1180
1181
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1179

def promptpay
  @promptpay
end

#qrisObject

QRIS is a [real-time](docs.stripe.com/payments/real-time) payment method popular in Indonesia. When paying with QRIS, customers authenticate and approve payments by scanning a QR code in their preferred digital wallet app.



1181
1182
1183
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1181

def qris
  @qris
end

#revolut_payObject

Revolut Pay, developed by Revolut, a global finance app, is a digital wallet payment method. Revolut Pay uses the customer’s stored balance or cards to fund the payment, and offers the option for non-Revolut customers to save their details after their first purchase.



1183
1184
1185
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1183

def revolut_pay
  @revolut_pay
end

#samsung_payObject

Samsung Pay is a [single-use](docs.stripe.com/payments/payment-methods#usage local wallet available in South Korea.



1185
1186
1187
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1185

def samsung_pay
  @samsung_pay
end

#satispayObject

Satispay is a [single-use](docs.stripe.com/payments/payment-methods#usage) payment method where customers are required to [authenticate](/payments/payment-methods#customer-actions) their payment. Customers pay by being redirected from your website or app, authorizing the payment with Satispay, then returning to your website or app. You get [immediate notification](/payments/payment-methods#payment-notification) of whether the payment succeeded or failed.



1187
1188
1189
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1187

def satispay
  @satispay
end

#sepa_debitObject

The [Single Euro Payments Area (SEPA)](en.wikipedia.org/wiki/Single_Euro_Payments_Area) is an initiative of the European Union to simplify payments within and across member countries. SEPA established and enforced banking standards to allow for the direct debiting of every EUR-denominated bank account within the SEPA region, check this [page](docs.stripe.com/payments/sepa-debit) for more details.



1189
1190
1191
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1189

def sepa_debit
  @sepa_debit
end

#shopeepayObject

ShopeePay is a [single use](docs.stripe.com/payments/payment-methods#usage) digital wallet payment method popular in Indonesia. When paying with GoPay, customers authenticate and approve payments using the Shopee app. Desktop checkout is performed by scanning a QR code. When checking out on mobile, customers are redirected to the Shopee app to confirm payment.



1191
1192
1193
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1191

def shopeepay
  @shopeepay
end

#sofortObject

Stripe users in Europe and the United States can use the [Payment Intents API](stripe.com/docs/payments/payment-intents)—a single integration path for creating payments using any supported method—to accept [Sofort](www.sofort.com/) payments from customers. Check this [page](docs.stripe.com/payments/sofort) for more details.



1193
1194
1195
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1193

def sofort
  @sofort
end

#sunbitObject

Sunbit is a [single-use](docs.stripe.com/payments/payment-methods#usage) payment method where customers choose to pay in 3, 6, or 12 installments. Customers are redirected from your website or app, authorize the payment with Sunbit, then return to your website or app. You get [immediate notification](docs.stripe.com/payments/payment-methods#payment-notification) of whether the payment succeeded or failed.



1195
1196
1197
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1195

def sunbit
  @sunbit
end

#swishObject

Swish is a [real-time](docs.stripe.com/payments/real-time) payment method popular in Sweden. It allows customers to [authenticate and approve](docs.stripe.com/payments/payment-methods#customer-actions) payments using the Swish mobile app and the Swedish BankID mobile app. Check this [page](docs.stripe.com/payments/swish) for more details.



1197
1198
1199
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1197

def swish
  @swish
end

#twintObject

Twint is a payment method popular in Switzerland. It allows customers to pay using their mobile phone. Check this [page](docs.stripe.com/payments/twint) for more details.



1199
1200
1201
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1199

def twint
  @twint
end

#upiObject

Unified Payment Interface (UPI) is India’s leading payment method with exponential growth since it launched in 2016.



1201
1202
1203
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1201

def upi
  @upi
end

#us_bank_accountObject

Stripe users in the United States can accept ACH direct debit payments from customers with a US bank account using the Automated Clearing House (ACH) payments system operated by Nacha. Check this [page](docs.stripe.com/payments/ach-direct-debit) for more details.



1203
1204
1205
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1203

def 
  @us_bank_account
end

#wechat_payObject

WeChat, owned by Tencent, is China’s leading mobile app with over 1 billion monthly active users. Chinese consumers can use WeChat Pay to pay for goods and services inside of businesses’ apps and websites. WeChat Pay users buy most frequently in gaming, e-commerce, travel, online education, and food/nutrition. Check this [page](docs.stripe.com/payments/wechat-pay) for more details.



1205
1206
1207
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1205

def wechat_pay
  @wechat_pay
end

#zipObject

Zip gives your customers a way to split purchases over a series of payments. Check this [page](docs.stripe.com/payments/zip) for more details like country availability.



1207
1208
1209
# File 'lib/stripe/params/payment_method_configuration_update_params.rb', line 1207

def zip
  @zip
end