Class: Stripe::PaymentMethodCreateParams::StripeBalance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethodCreateParams::StripeBalance
- Defined in:
- lib/stripe/params/payment_method_create_params.rb
Instance Attribute Summary collapse
-
#account ⇒ Object
The connected account ID whose Stripe balance to use as the source of payment.
Instance Method Summary collapse
-
#initialize(account: nil) ⇒ StripeBalance
constructor
A new instance of StripeBalance.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(account: nil) ⇒ StripeBalance
Returns a new instance of StripeBalance.
381 382 383 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 381 def initialize(account: nil) @account = account end |
Instance Attribute Details
#account ⇒ Object
The connected account ID whose Stripe balance to use as the source of payment
379 380 381 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 379 def account @account end |