Class: Stripe::PaymentMethodDomain

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List
Includes:
APIOperations::Save
Defined in:
lib/stripe/resources/payment_method_domain.rb

Overview

A payment method domain represents a web domain that you have registered with Stripe. Stripe Elements use registered payment method domains to control where certain payment methods are shown.

Related guide: [Payment method domains](stripe.com/docs/payments/payment-methods/pmd-registration).

Defined Under Namespace

Classes: AmazonPay, ApplePay, CreateParams, GooglePay, Klarna, Link, ListParams, Paypal, UpdateParams, ValidateParams

Constant Summary collapse

OBJECT_NAME =
"payment_method_domain"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods included from APIOperations::Save

included, #save

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amazon_payObject (readonly)

Indicates the status of a specific payment method on a payment method domain.



248
249
250
# File 'lib/stripe/resources/payment_method_domain.rb', line 248

def amazon_pay
  @amazon_pay
end

#apple_payObject (readonly)

Indicates the status of a specific payment method on a payment method domain.



250
251
252
# File 'lib/stripe/resources/payment_method_domain.rb', line 250

def apple_pay
  @apple_pay
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



252
253
254
# File 'lib/stripe/resources/payment_method_domain.rb', line 252

def created
  @created
end

#domain_nameObject (readonly)

The domain name that this payment method domain object represents.



254
255
256
# File 'lib/stripe/resources/payment_method_domain.rb', line 254

def domain_name
  @domain_name
end

#enabledObject (readonly)

Whether this payment method domain is enabled. If the domain is not enabled, payment methods that require a payment method domain will not appear in Elements.



256
257
258
# File 'lib/stripe/resources/payment_method_domain.rb', line 256

def enabled
  @enabled
end

#google_payObject (readonly)

Indicates the status of a specific payment method on a payment method domain.



258
259
260
# File 'lib/stripe/resources/payment_method_domain.rb', line 258

def google_pay
  @google_pay
end

#idObject (readonly)

Unique identifier for the object.



260
261
262
# File 'lib/stripe/resources/payment_method_domain.rb', line 260

def id
  @id
end

#klarnaObject (readonly)

Indicates the status of a specific payment method on a payment method domain.



262
263
264
# File 'lib/stripe/resources/payment_method_domain.rb', line 262

def klarna
  @klarna
end

Indicates the status of a specific payment method on a payment method domain.



264
265
266
# File 'lib/stripe/resources/payment_method_domain.rb', line 264

def link
  @link
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



266
267
268
# File 'lib/stripe/resources/payment_method_domain.rb', line 266

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



268
269
270
# File 'lib/stripe/resources/payment_method_domain.rb', line 268

def object
  @object
end

#paypalObject (readonly)

Indicates the status of a specific payment method on a payment method domain.



270
271
272
# File 'lib/stripe/resources/payment_method_domain.rb', line 270

def paypal
  @paypal
end

Class Method Details

.create(params = {}, opts = {}) ⇒ Object

Creates a payment method domain.



273
274
275
276
277
278
279
280
# File 'lib/stripe/resources/payment_method_domain.rb', line 273

def self.create(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/payment_method_domains",
    params: params,
    opts: opts
  )
end

.field_remappingsObject



343
344
345
# File 'lib/stripe/resources/payment_method_domain.rb', line 343

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



332
333
334
335
336
337
338
339
340
341
# File 'lib/stripe/resources/payment_method_domain.rb', line 332

def self.inner_class_types
  @inner_class_types = {
    amazon_pay: AmazonPay,
    apple_pay: ApplePay,
    google_pay: GooglePay,
    klarna: Klarna,
    link: Link,
    paypal: Paypal,
  }
end

.list(params = {}, opts = {}) ⇒ Object

Lists the details of existing payment method domains.



283
284
285
286
287
288
289
290
# File 'lib/stripe/resources/payment_method_domain.rb', line 283

def self.list(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/payment_method_domains",
    params: params,
    opts: opts
  )
end

.object_nameObject



15
16
17
# File 'lib/stripe/resources/payment_method_domain.rb', line 15

def self.object_name
  "payment_method_domain"
end

.update(payment_method_domain, params = {}, opts = {}) ⇒ Object

Updates an existing payment method domain.



293
294
295
296
297
298
299
300
# File 'lib/stripe/resources/payment_method_domain.rb', line 293

def self.update(payment_method_domain, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_method_domains/%<payment_method_domain>s", { payment_method_domain: CGI.escape(payment_method_domain) }),
    params: params,
    opts: opts
  )
end

.validate(payment_method_domain, params = {}, opts = {}) ⇒ Object

Some payment methods might require additional steps to register a domain. If the requirements weren’t satisfied when the domain was created, the payment method will be inactive on the domain. The payment method doesn’t appear in Elements or Embedded Checkout for this domain until it is active.

To activate a payment method on an existing payment method domain, complete the required registration steps specific to the payment method, and then validate the payment method domain with this endpoint.

Related guides: [Payment method domains](docs.stripe.com/docs/payments/payment-methods/pmd-registration).



323
324
325
326
327
328
329
330
# File 'lib/stripe/resources/payment_method_domain.rb', line 323

def self.validate(payment_method_domain, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_method_domains/%<payment_method_domain>s/validate", { payment_method_domain: CGI.escape(payment_method_domain) }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#validate(params = {}, opts = {}) ⇒ Object

Some payment methods might require additional steps to register a domain. If the requirements weren’t satisfied when the domain was created, the payment method will be inactive on the domain. The payment method doesn’t appear in Elements or Embedded Checkout for this domain until it is active.

To activate a payment method on an existing payment method domain, complete the required registration steps specific to the payment method, and then validate the payment method domain with this endpoint.

Related guides: [Payment method domains](docs.stripe.com/docs/payments/payment-methods/pmd-registration).



308
309
310
311
312
313
314
315
# File 'lib/stripe/resources/payment_method_domain.rb', line 308

def validate(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_method_domains/%<payment_method_domain>s/validate", { payment_method_domain: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end