Class: Stripe::PaymentMethodDomain::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/payment_method_domain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(domain_name: nil, enabled: nil, expand: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



124
125
126
127
128
# File 'lib/stripe/resources/payment_method_domain.rb', line 124

def initialize(domain_name: nil, enabled: nil, expand: nil)
  @domain_name = domain_name
  @enabled = enabled
  @expand = expand
end

Instance Attribute Details

#domain_nameObject

The domain name that this payment method domain object represents.



118
119
120
# File 'lib/stripe/resources/payment_method_domain.rb', line 118

def domain_name
  @domain_name
end

#enabledObject

Whether this payment method domain is enabled. If the domain is not enabled, payment methods that require a payment method domain will not appear in Elements or Embedded Checkout.



120
121
122
# File 'lib/stripe/resources/payment_method_domain.rb', line 120

def enabled
  @enabled
end

#expandObject

Specifies which fields in the response should be expanded.



122
123
124
# File 'lib/stripe/resources/payment_method_domain.rb', line 122

def expand
  @expand
end