Class: Stripe::PaymentMethodDomain::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/payment_method_domain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(domain_name: nil, enabled: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/stripe/resources/payment_method_domain.rb', line 99

def initialize(
  domain_name: nil,
  enabled: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  starting_after: nil
)
  @domain_name = domain_name
  @enabled = enabled
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
end

Instance Attribute Details

#domain_nameObject

The domain name that this payment method domain object represents.



87
88
89
# File 'lib/stripe/resources/payment_method_domain.rb', line 87

def domain_name
  @domain_name
end

#enabledObject

Whether this payment method domain is enabled. If the domain is not enabled, payment methods will not appear in Elements or Embedded Checkout



89
90
91
# File 'lib/stripe/resources/payment_method_domain.rb', line 89

def enabled
  @enabled
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



91
92
93
# File 'lib/stripe/resources/payment_method_domain.rb', line 91

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



93
94
95
# File 'lib/stripe/resources/payment_method_domain.rb', line 93

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



95
96
97
# File 'lib/stripe/resources/payment_method_domain.rb', line 95

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



97
98
99
# File 'lib/stripe/resources/payment_method_domain.rb', line 97

def starting_after
  @starting_after
end