Class: Stripe::PaymentMethodDomain::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/payment_method_domain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(enabled: nil, expand: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



233
234
235
236
# File 'lib/stripe/resources/payment_method_domain.rb', line 233

def initialize(enabled: nil, expand: nil)
  @enabled = enabled
  @expand = expand
end

Instance Attribute Details

#enabledObject

Whether this payment method domain is enabled. If the domain is not enabled, payment methods that require a payment method domain will not appear in Elements or Embedded Checkout.



229
230
231
# File 'lib/stripe/resources/payment_method_domain.rb', line 229

def enabled
  @enabled
end

#expandObject

Specifies which fields in the response should be expanded.



231
232
233
# File 'lib/stripe/resources/payment_method_domain.rb', line 231

def expand
  @expand
end