Class: Stripe::PaymentMethodDomain::ValidateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethodDomain::ValidateParams
- Defined in:
- lib/stripe/resources/payment_method_domain.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ ValidateParams
constructor
A new instance of ValidateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ ValidateParams
Returns a new instance of ValidateParams.
136 137 138 |
# File 'lib/stripe/resources/payment_method_domain.rb', line 136 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
134 135 136 |
# File 'lib/stripe/resources/payment_method_domain.rb', line 134 def @expand end |