Method: Stripe::PaymentMethodDomain#validate

Defined in:
lib/stripe/resources/payment_method_domain.rb

#validate(params = {}, opts = {}) ⇒ Object

Some payment methods might require additional steps to register a domain. If the requirements weren’t satisfied when the domain was created, the payment method will be inactive on the domain. The payment method doesn’t appear in Elements or Embedded Checkout for this domain until it is active.

To activate a payment method on an existing payment method domain, complete the required registration steps specific to the payment method, and then validate the payment method domain with this endpoint.

Related guides: [Payment method domains](docs.stripe.com/docs/payments/payment-methods/pmd-registration).



241
242
243
244
245
246
247
248
# File 'lib/stripe/resources/payment_method_domain.rb', line 241

def validate(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_method_domains/%<payment_method_domain>s/validate", { payment_method_domain: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end