Class: Stripe::PaymentMethodService::CreateParams::Card
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethodService::CreateParams::Card
- Defined in:
- lib/stripe/services/payment_method_service.rb
Defined Under Namespace
Classes: Networks
Instance Attribute Summary collapse
-
#cvc ⇒ Object
The card’s CVC.
-
#exp_month ⇒ Object
Two-digit number representing the card’s expiration month.
-
#exp_year ⇒ Object
Four-digit number representing the card’s expiration year.
-
#networks ⇒ Object
Contains information about card networks used to process the payment.
-
#number ⇒ Object
The card number, as a string without any separators.
-
#token ⇒ Object
For backwards compatibility, you can alternatively provide a Stripe token (e.g., for Apple Pay, Amex Express Checkout, or legacy Checkout) into the card hash with format card: “tok_visa”.
Instance Method Summary collapse
-
#initialize(cvc: nil, exp_month: nil, exp_year: nil, networks: nil, number: nil, token: nil) ⇒ Card
constructor
A new instance of Card.
Methods inherited from RequestParams
Constructor Details
#initialize(cvc: nil, exp_month: nil, exp_year: nil, networks: nil, number: nil, token: nil) ⇒ Card
Returns a new instance of Card.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/stripe/services/payment_method_service.rb', line 170 def initialize( cvc: nil, exp_month: nil, exp_year: nil, networks: nil, number: nil, token: nil ) @cvc = cvc @exp_month = exp_month @exp_year = exp_year @networks = networks @number = number @token = token end |
Instance Attribute Details
#cvc ⇒ Object
The card’s CVC. It is highly recommended to always include this value.
158 159 160 |
# File 'lib/stripe/services/payment_method_service.rb', line 158 def cvc @cvc end |
#exp_month ⇒ Object
Two-digit number representing the card’s expiration month.
160 161 162 |
# File 'lib/stripe/services/payment_method_service.rb', line 160 def exp_month @exp_month end |
#exp_year ⇒ Object
Four-digit number representing the card’s expiration year.
162 163 164 |
# File 'lib/stripe/services/payment_method_service.rb', line 162 def exp_year @exp_year end |
#networks ⇒ Object
Contains information about card networks used to process the payment.
164 165 166 |
# File 'lib/stripe/services/payment_method_service.rb', line 164 def networks @networks end |
#number ⇒ Object
The card number, as a string without any separators.
166 167 168 |
# File 'lib/stripe/services/payment_method_service.rb', line 166 def number @number end |
#token ⇒ Object
For backwards compatibility, you can alternatively provide a Stripe token (e.g., for Apple Pay, Amex Express Checkout, or legacy Checkout) into the card hash with format card: “tok_visa”.
168 169 170 |
# File 'lib/stripe/services/payment_method_service.rb', line 168 def token @token end |