Class: Stripe::PaymentMethodService::CreateParams::StripeBalance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethodService::CreateParams::StripeBalance
- Defined in:
- lib/stripe/services/payment_method_service.rb
Instance Attribute Summary collapse
-
#account ⇒ Object
The connected account ID whose Stripe balance to use as the source of payment.
-
#source_type ⇒ Object
The [source_type](docs.stripe.com/api/balance/balance_object#balance_object-available-source_types) of the balance.
Instance Method Summary collapse
-
#initialize(account: nil, source_type: nil) ⇒ StripeBalance
constructor
A new instance of StripeBalance.
Methods inherited from RequestParams
Constructor Details
#initialize(account: nil, source_type: nil) ⇒ StripeBalance
Returns a new instance of StripeBalance.
404 405 406 407 |
# File 'lib/stripe/services/payment_method_service.rb', line 404 def initialize(account: nil, source_type: nil) @account = account @source_type = source_type end |
Instance Attribute Details
#account ⇒ Object
The connected account ID whose Stripe balance to use as the source of payment
400 401 402 |
# File 'lib/stripe/services/payment_method_service.rb', line 400 def account @account end |
#source_type ⇒ Object
The [source_type](docs.stripe.com/api/balance/balance_object#balance_object-available-source_types) of the balance
402 403 404 |
# File 'lib/stripe/services/payment_method_service.rb', line 402 def source_type @source_type end |