Class: Stripe::PaymentMethodService::CreateParams::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethodService::CreateParams::UsBankAccount
- Defined in:
- lib/stripe/services/payment_method_service.rb
Instance Attribute Summary collapse
-
#account_holder_type ⇒ Object
Account holder type: individual or company.
-
#account_number ⇒ Object
Account number of the bank account.
-
#account_type ⇒ Object
Account type: checkings or savings.
-
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
-
#routing_number ⇒ Object
Routing number of the bank account.
Instance Method Summary collapse
-
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
459 460 461 462 463 464 465 466 467 468 469 470 471 |
# File 'lib/stripe/services/payment_method_service.rb', line 459 def initialize( account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil ) @account_holder_type = account_holder_type @account_number = account_number @account_type = account_type @financial_connections_account = financial_connections_account @routing_number = routing_number end |
Instance Attribute Details
#account_holder_type ⇒ Object
Account holder type: individual or company.
445 446 447 |
# File 'lib/stripe/services/payment_method_service.rb', line 445 def account_holder_type @account_holder_type end |
#account_number ⇒ Object
Account number of the bank account.
448 449 450 |
# File 'lib/stripe/services/payment_method_service.rb', line 448 def account_number @account_number end |
#account_type ⇒ Object
Account type: checkings or savings. Defaults to checking if omitted.
451 452 453 |
# File 'lib/stripe/services/payment_method_service.rb', line 451 def account_type @account_type end |
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
454 455 456 |
# File 'lib/stripe/services/payment_method_service.rb', line 454 def financial_connections_account @financial_connections_account end |
#routing_number ⇒ Object
Routing number of the bank account.
457 458 459 |
# File 'lib/stripe/services/payment_method_service.rb', line 457 def routing_number @routing_number end |