Class: Stripe::PaymentMethodService::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_method_service.rb

Defined Under Namespace

Classes: BillingDetails, Card, Link, PayByBank, UsBankAccount

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(allow_redisplay: nil, billing_details: nil, card: nil, expand: nil, link: nil, metadata: nil, pay_by_bank: nil, us_bank_account: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
# File 'lib/stripe/services/payment_method_service.rb', line 726

def initialize(
  allow_redisplay: nil,
  billing_details: nil,
  card: nil,
  expand: nil,
  link: nil,
  metadata: nil,
  pay_by_bank: nil,
  us_bank_account: nil
)
  @allow_redisplay = allow_redisplay
  @billing_details = billing_details
  @card = card
  @expand = expand
  @link = link
  @metadata = 
  @pay_by_bank = pay_by_bank
  @us_bank_account = 
end

Instance Attribute Details

#allow_redisplayObject

This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. The field defaults to ‘unspecified`.



710
711
712
# File 'lib/stripe/services/payment_method_service.rb', line 710

def allow_redisplay
  @allow_redisplay
end

#billing_detailsObject

Billing information associated with the PaymentMethod that may be used or required by particular types of payment methods.



712
713
714
# File 'lib/stripe/services/payment_method_service.rb', line 712

def billing_details
  @billing_details
end

#cardObject

If this is a ‘card` PaymentMethod, this hash contains the user’s card details.



714
715
716
# File 'lib/stripe/services/payment_method_service.rb', line 714

def card
  @card
end

#expandObject

Specifies which fields in the response should be expanded.



716
717
718
# File 'lib/stripe/services/payment_method_service.rb', line 716

def expand
  @expand
end

If this is an ‘Link` PaymentMethod, this hash contains details about the Link payment method.



718
719
720
# File 'lib/stripe/services/payment_method_service.rb', line 718

def link
  @link
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



720
721
722
# File 'lib/stripe/services/payment_method_service.rb', line 720

def 
  @metadata
end

#pay_by_bankObject

If this is a ‘pay_by_bank` PaymentMethod, this hash contains details about the PayByBank payment method.



722
723
724
# File 'lib/stripe/services/payment_method_service.rb', line 722

def pay_by_bank
  @pay_by_bank
end

#us_bank_accountObject

If this is an ‘us_bank_account` PaymentMethod, this hash contains details about the US bank account payment method.



724
725
726
# File 'lib/stripe/services/payment_method_service.rb', line 724

def 
  @us_bank_account
end