Class: Stripe::PaymentMethodService::UpdateParams::Card
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethodService::UpdateParams::Card
- Defined in:
- lib/stripe/services/payment_method_service.rb
Defined Under Namespace
Classes: Networks
Instance Attribute Summary collapse
-
#exp_month ⇒ Object
Two-digit number representing the card’s expiration month.
-
#exp_year ⇒ Object
Four-digit number representing the card’s expiration year.
-
#networks ⇒ Object
Contains information about card networks used to process the payment.
Instance Method Summary collapse
-
#initialize(exp_month: nil, exp_year: nil, networks: nil) ⇒ Card
constructor
A new instance of Card.
Methods inherited from RequestParams
Constructor Details
#initialize(exp_month: nil, exp_year: nil, networks: nil) ⇒ Card
Returns a new instance of Card.
688 689 690 691 692 |
# File 'lib/stripe/services/payment_method_service.rb', line 688 def initialize(exp_month: nil, exp_year: nil, networks: nil) @exp_month = exp_month @exp_year = exp_year @networks = networks end |
Instance Attribute Details
#exp_month ⇒ Object
Two-digit number representing the card’s expiration month.
682 683 684 |
# File 'lib/stripe/services/payment_method_service.rb', line 682 def exp_month @exp_month end |
#exp_year ⇒ Object
Four-digit number representing the card’s expiration year.
684 685 686 |
# File 'lib/stripe/services/payment_method_service.rb', line 684 def exp_year @exp_year end |
#networks ⇒ Object
Contains information about card networks used to process the payment.
686 687 688 |
# File 'lib/stripe/services/payment_method_service.rb', line 686 def networks @networks end |