Class: Stripe::PaymentMethodUpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethodUpdateParams
- Defined in:
- lib/stripe/params/payment_method_update_params.rb
Defined Under Namespace
Classes: BillingDetails, Card, Custom, Payto, UsBankAccount
Instance Attribute Summary collapse
-
#allow_redisplay ⇒ Object
This field indicates whether this payment method can be shown again to its customer in a checkout flow.
-
#billing_details ⇒ Object
Billing information associated with the PaymentMethod that may be used or required by particular types of payment methods.
-
#card ⇒ Object
If this is a
cardPaymentMethod, this hash contains the user's card details. -
#custom ⇒ Object
If this is a
customPaymentMethod, this hash contains details about the Custom payment method. -
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#payto ⇒ Object
If this is a
paytoPaymentMethod, this hash contains details about the PayTo payment method. -
#us_bank_account ⇒ Object
If this is an
us_bank_accountPaymentMethod, this hash contains details about the US bank account payment method.
Instance Method Summary collapse
-
#initialize(allow_redisplay: nil, billing_details: nil, card: nil, custom: nil, expand: nil, metadata: nil, payto: nil, us_bank_account: nil) ⇒ PaymentMethodUpdateParams
constructor
A new instance of PaymentMethodUpdateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(allow_redisplay: nil, billing_details: nil, card: nil, custom: nil, expand: nil, metadata: nil, payto: nil, us_bank_account: nil) ⇒ PaymentMethodUpdateParams
Returns a new instance of PaymentMethodUpdateParams.
135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/stripe/params/payment_method_update_params.rb', line 135 def initialize( allow_redisplay: nil, billing_details: nil, card: nil, custom: nil, expand: nil, metadata: nil, payto: nil, us_bank_account: nil ) @allow_redisplay = allow_redisplay @billing_details = billing_details @card = card @custom = custom @expand = @metadata = @payto = payto @us_bank_account = us_bank_account end |
Instance Attribute Details
#allow_redisplay ⇒ Object
This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. The field defaults to unspecified.
119 120 121 |
# File 'lib/stripe/params/payment_method_update_params.rb', line 119 def allow_redisplay @allow_redisplay end |
#billing_details ⇒ Object
Billing information associated with the PaymentMethod that may be used or required by particular types of payment methods.
121 122 123 |
# File 'lib/stripe/params/payment_method_update_params.rb', line 121 def billing_details @billing_details end |
#card ⇒ Object
If this is a card PaymentMethod, this hash contains the user's card details.
123 124 125 |
# File 'lib/stripe/params/payment_method_update_params.rb', line 123 def card @card end |
#custom ⇒ Object
If this is a custom PaymentMethod, this hash contains details about the Custom payment method.
125 126 127 |
# File 'lib/stripe/params/payment_method_update_params.rb', line 125 def custom @custom end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
127 128 129 |
# File 'lib/stripe/params/payment_method_update_params.rb', line 127 def @expand end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
129 130 131 |
# File 'lib/stripe/params/payment_method_update_params.rb', line 129 def @metadata end |
#payto ⇒ Object
If this is a payto PaymentMethod, this hash contains details about the PayTo payment method.
131 132 133 |
# File 'lib/stripe/params/payment_method_update_params.rb', line 131 def payto @payto end |
#us_bank_account ⇒ Object
If this is an us_bank_account PaymentMethod, this hash contains details about the US bank account payment method.
133 134 135 |
# File 'lib/stripe/params/payment_method_update_params.rb', line 133 def us_bank_account @us_bank_account end |