Class: Stripe::PaymentMethodUpdateParams::Custom
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethodUpdateParams::Custom
- Defined in:
- lib/stripe/params/payment_method_update_params.rb
Instance Attribute Summary collapse
-
#payment_method_reference ⇒ Object
A reference to an external payment method, such as a PayPal Billing Agreement ID.
-
#usage ⇒ Object
Indicates whether the payment method supports off-session payments.
Instance Method Summary collapse
-
#initialize(payment_method_reference: nil, usage: nil) ⇒ Custom
constructor
A new instance of Custom.
Methods inherited from RequestParams
Constructor Details
#initialize(payment_method_reference: nil, usage: nil) ⇒ Custom
Returns a new instance of Custom.
86 87 88 89 |
# File 'lib/stripe/params/payment_method_update_params.rb', line 86 def initialize(payment_method_reference: nil, usage: nil) @payment_method_reference = payment_method_reference @usage = usage end |
Instance Attribute Details
#payment_method_reference ⇒ Object
A reference to an external payment method, such as a PayPal Billing Agreement ID.
82 83 84 |
# File 'lib/stripe/params/payment_method_update_params.rb', line 82 def payment_method_reference @payment_method_reference end |
#usage ⇒ Object
Indicates whether the payment method supports off-session payments.
84 85 86 |
# File 'lib/stripe/params/payment_method_update_params.rb', line 84 def usage @usage end |