Class: Stripe::PaymentPlan::Schedule::AmountsDue::Amount
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentPlan::Schedule::AmountsDue::Amount
- Defined in:
- lib/stripe/resources/payment_plan.rb
Defined Under Namespace
Classes: DueDate, FixedAmount
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#description ⇒ Object
readonly
A description of this schedule entry.
-
#due_date ⇒ Object
readonly
Attribute for field due_date.
-
#fixed_amount ⇒ Object
readonly
Attribute for field fixed_amount.
-
#id ⇒ Object
readonly
Unique identifier for this schedule entry.
-
#percentage ⇒ Object
readonly
Percentage of the invoice total for this entry (0–100).
-
#type ⇒ Object
readonly
The type of this schedule entry.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#description ⇒ Object (readonly)
A description of this schedule entry.
124 125 126 |
# File 'lib/stripe/resources/payment_plan.rb', line 124 def description @description end |
#due_date ⇒ Object (readonly)
Attribute for field due_date
126 127 128 |
# File 'lib/stripe/resources/payment_plan.rb', line 126 def due_date @due_date end |
#fixed_amount ⇒ Object (readonly)
Attribute for field fixed_amount
128 129 130 |
# File 'lib/stripe/resources/payment_plan.rb', line 128 def fixed_amount @fixed_amount end |
#id ⇒ Object (readonly)
Unique identifier for this schedule entry.
130 131 132 |
# File 'lib/stripe/resources/payment_plan.rb', line 130 def id @id end |
#percentage ⇒ Object (readonly)
Percentage of the invoice total for this entry (0–100). Present when type is percentage.
132 133 134 |
# File 'lib/stripe/resources/payment_plan.rb', line 132 def percentage @percentage end |
#type ⇒ Object (readonly)
The type of this schedule entry. Either fixed_amount or percentage.
134 135 136 |
# File 'lib/stripe/resources/payment_plan.rb', line 134 def type @type end |
Class Method Details
.field_remappings ⇒ Object
140 141 142 |
# File 'lib/stripe/resources/payment_plan.rb', line 140 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
136 137 138 |
# File 'lib/stripe/resources/payment_plan.rb', line 136 def self.inner_class_types @inner_class_types = { due_date: DueDate, fixed_amount: FixedAmount } end |