Class: Stripe::PaymentPlanCreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/payment_plan_create_params.rb

Defined Under Namespace

Classes: CollectsOn, Schedule

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(collects_on: nil, expand: nil, metadata: nil, schedule: nil) ⇒ PaymentPlanCreateParams

Returns a new instance of PaymentPlanCreateParams.



121
122
123
124
125
126
# File 'lib/stripe/params/payment_plan_create_params.rb', line 121

def initialize(collects_on: nil, expand: nil, metadata: nil, schedule: nil)
  @collects_on = collects_on
  @expand = expand
  @metadata = 
  @schedule = schedule
end

Instance Attribute Details

#collects_onObject

The invoice(s) this payment plan collects on. Currently must contain exactly one invoice entry.



113
114
115
# File 'lib/stripe/params/payment_plan_create_params.rb', line 113

def collects_on
  @collects_on
end

#expandObject

Specifies which fields in the response should be expanded.



115
116
117
# File 'lib/stripe/params/payment_plan_create_params.rb', line 115

def expand
  @expand
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.



117
118
119
# File 'lib/stripe/params/payment_plan_create_params.rb', line 117

def 
  @metadata
end

#scheduleObject

The schedule defining how to split the invoice total into installments.



119
120
121
# File 'lib/stripe/params/payment_plan_create_params.rb', line 119

def schedule
  @schedule
end