Class: Stripe::PaymentPlanCreateParams::CollectsOn
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentPlanCreateParams::CollectsOn
- Defined in:
- lib/stripe/params/payment_plan_create_params.rb
Defined Under Namespace
Classes: InvoiceDetails
Instance Attribute Summary collapse
-
#invoice_details ⇒ Object
Details of the invoice this payment plan collects on.
-
#type ⇒ Object
The type of object this plan collects on.
Instance Method Summary collapse
-
#initialize(invoice_details: nil, type: nil) ⇒ CollectsOn
constructor
A new instance of CollectsOn.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(invoice_details: nil, type: nil) ⇒ CollectsOn
Returns a new instance of CollectsOn.
20 21 22 23 |
# File 'lib/stripe/params/payment_plan_create_params.rb', line 20 def initialize(invoice_details: nil, type: nil) @invoice_details = invoice_details @type = type end |
Instance Attribute Details
#invoice_details ⇒ Object
Details of the invoice this payment plan collects on.
16 17 18 |
# File 'lib/stripe/params/payment_plan_create_params.rb', line 16 def invoice_details @invoice_details end |
#type ⇒ Object
The type of object this plan collects on. Currently always invoice_details.
18 19 20 |
# File 'lib/stripe/params/payment_plan_create_params.rb', line 18 def type @type end |