Class: Stripe::PaymentPlanService

Inherits:
StripeService show all
Defined in:
lib/stripe/services/payment_plan_service.rb

Instance Method Summary collapse

Methods inherited from StripeService

#initialize, #request, #request_stream

Constructor Details

This class inherits a constructor from Stripe::StripeService

Instance Method Details

#create(params = {}, opts = {}) ⇒ Object

Creates a payment plan that splits a single invoice obligation into installments with their own due dates and amounts.



7
8
9
10
11
12
13
14
15
# File 'lib/stripe/services/payment_plan_service.rb', line 7

def create(params = {}, opts = {})
  request(
    method: :post,
    path: "/v1/payment_plans",
    params: params,
    opts: opts,
    base_address: :api
  )
end

#list(params = {}, opts = {}) ⇒ Object

Returns a list of payment plans.



18
19
20
21
22
23
24
25
26
# File 'lib/stripe/services/payment_plan_service.rb', line 18

def list(params = {}, opts = {})
  request(
    method: :get,
    path: "/v1/payment_plans",
    params: params,
    opts: opts,
    base_address: :api
  )
end

#retrieve(id, params = {}, opts = {}) ⇒ Object

Retrieves the payment plan with the given ID.



29
30
31
32
33
34
35
36
37
# File 'lib/stripe/services/payment_plan_service.rb', line 29

def retrieve(id, params = {}, opts = {})
  request(
    method: :get,
    path: format("/v1/payment_plans/%<id>s", { id: CGI.escape(id) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end

#update(id, params = {}, opts = {}) ⇒ Object

Updates the schedule or metadata of an existing payment plan. Only unpaid installments can be updated.



40
41
42
43
44
45
46
47
48
# File 'lib/stripe/services/payment_plan_service.rb', line 40

def update(id, params = {}, opts = {})
  request(
    method: :post,
    path: format("/v1/payment_plans/%<id>s", { id: CGI.escape(id) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end