Class: Stripe::PaymentPlanUpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/payment_plan_update_params.rb

Defined Under Namespace

Classes: Schedule

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(expand: nil, metadata: nil, schedule: nil) ⇒ PaymentPlanUpdateParams

Returns a new instance of PaymentPlanUpdateParams.



99
100
101
102
103
# File 'lib/stripe/params/payment_plan_update_params.rb', line 99

def initialize(expand: nil, metadata: nil, schedule: nil)
  @expand = expand
  @metadata = 
  @schedule = schedule
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



93
94
95
# File 'lib/stripe/params/payment_plan_update_params.rb', line 93

def expand
  @expand
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.



95
96
97
# File 'lib/stripe/params/payment_plan_update_params.rb', line 95

def 
  @metadata
end

#scheduleObject

The new schedule for this payment plan.



97
98
99
# File 'lib/stripe/params/payment_plan_update_params.rb', line 97

def schedule
  @schedule
end