Class: Stripe::PaymentRecord

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List, APIOperations::Search
Defined in:
lib/stripe/resources/payment_record.rb

Overview

A Payment Record is a resource that allows you to represent payments that occur on- or off-Stripe. For example, you can create a Payment Record to model a payment made on a different payment processor, in order to mark an Invoice as paid and a Subscription as active. Payment Records consist of one or more Payment Attempt Records, which represent individual attempts made on a payment network.

Defined Under Namespace

Classes: Amount, AmountAuthorized, AmountCanceled, AmountFailed, AmountGuaranteed, AmountRefunded, AmountRequested, CustomerDetails, PaymentMethodDetails, ProcessorDetails, ShippingDetails

Constant Summary collapse

OBJECT_NAME =
"payment_record"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods included from APIOperations::Search

_search

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

A representation of an amount of money, consisting of an amount and a currency.



2338
2339
2340
# File 'lib/stripe/resources/payment_record.rb', line 2338

def amount
  @amount
end

#amount_authorizedObject (readonly)

A representation of an amount of money, consisting of an amount and a currency.



2340
2341
2342
# File 'lib/stripe/resources/payment_record.rb', line 2340

def amount_authorized
  @amount_authorized
end

#amount_canceledObject (readonly)

A representation of an amount of money, consisting of an amount and a currency.



2342
2343
2344
# File 'lib/stripe/resources/payment_record.rb', line 2342

def amount_canceled
  @amount_canceled
end

#amount_failedObject (readonly)

A representation of an amount of money, consisting of an amount and a currency.



2344
2345
2346
# File 'lib/stripe/resources/payment_record.rb', line 2344

def amount_failed
  @amount_failed
end

#amount_guaranteedObject (readonly)

A representation of an amount of money, consisting of an amount and a currency.



2346
2347
2348
# File 'lib/stripe/resources/payment_record.rb', line 2346

def amount_guaranteed
  @amount_guaranteed
end

#amount_refundedObject (readonly)

A representation of an amount of money, consisting of an amount and a currency.



2348
2349
2350
# File 'lib/stripe/resources/payment_record.rb', line 2348

def amount_refunded
  @amount_refunded
end

#amount_requestedObject (readonly)

A representation of an amount of money, consisting of an amount and a currency.



2350
2351
2352
# File 'lib/stripe/resources/payment_record.rb', line 2350

def amount_requested
  @amount_requested
end

#applicationObject (readonly)

ID of the Connect application that created the PaymentRecord.



2352
2353
2354
# File 'lib/stripe/resources/payment_record.rb', line 2352

def application
  @application
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



2354
2355
2356
# File 'lib/stripe/resources/payment_record.rb', line 2354

def created
  @created
end

#customer_detailsObject (readonly)

Customer information for this payment.



2356
2357
2358
# File 'lib/stripe/resources/payment_record.rb', line 2356

def customer_details
  @customer_details
end

#customer_presenceObject (readonly)

Indicates whether the customer was present in your checkout flow during this payment.



2358
2359
2360
# File 'lib/stripe/resources/payment_record.rb', line 2358

def customer_presence
  @customer_presence
end

#descriptionObject (readonly)

An arbitrary string attached to the object. Often useful for displaying to users.



2360
2361
2362
# File 'lib/stripe/resources/payment_record.rb', line 2360

def description
  @description
end

#idObject (readonly)

Unique identifier for the object.



2362
2363
2364
# File 'lib/stripe/resources/payment_record.rb', line 2362

def id
  @id
end

#latest_payment_attempt_recordObject (readonly)

ID of the latest Payment Attempt Record attached to this Payment Record.



2364
2365
2366
# File 'lib/stripe/resources/payment_record.rb', line 2364

def latest_payment_attempt_record
  @latest_payment_attempt_record
end

#livemodeObject (readonly)

If the object exists in live mode, the value is true. If the object exists in test mode, the value is false.



2366
2367
2368
# File 'lib/stripe/resources/payment_record.rb', line 2366

def livemode
  @livemode
end

#metadataObject (readonly)

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



2368
2369
2370
# File 'lib/stripe/resources/payment_record.rb', line 2368

def 
  @metadata
end

#objectObject (readonly)

String representing the object's type. Objects of the same type share the same value.



2370
2371
2372
# File 'lib/stripe/resources/payment_record.rb', line 2370

def object
  @object
end

#payment_method_detailsObject (readonly)

Information about the Payment Method debited for this payment.



2372
2373
2374
# File 'lib/stripe/resources/payment_record.rb', line 2372

def payment_method_details
  @payment_method_details
end

#processor_detailsObject (readonly)

Processor information associated with this payment.



2374
2375
2376
# File 'lib/stripe/resources/payment_record.rb', line 2374

def processor_details
  @processor_details
end

#reported_byObject (readonly)

Indicates who reported the payment.



2376
2377
2378
# File 'lib/stripe/resources/payment_record.rb', line 2376

def reported_by
  @reported_by
end

#shipping_detailsObject (readonly)

Shipping information for this payment.



2378
2379
2380
# File 'lib/stripe/resources/payment_record.rb', line 2378

def shipping_details
  @shipping_details
end

Class Method Details

.create(id, params = {}, opts = {}) ⇒ Object

Report that the most recent payment attempt on the specified Payment Record was disputed.



2382
2383
2384
2385
2386
2387
2388
2389
# File 'lib/stripe/resources/payment_record.rb', line 2382

def self.create(id, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_records/%<id>s/report_dispute", { id: CGI.escape(id) }),
    params: params,
    opts: opts
  )
end

.field_remappingsObject



2567
2568
2569
# File 'lib/stripe/resources/payment_record.rb', line 2567

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
# File 'lib/stripe/resources/payment_record.rb', line 2551

def self.inner_class_types
  @inner_class_types = {
    amount: Amount,
    amount_authorized: AmountAuthorized,
    amount_canceled: AmountCanceled,
    amount_failed: AmountFailed,
    amount_guaranteed: AmountGuaranteed,
    amount_refunded: AmountRefunded,
    amount_requested: AmountRequested,
    customer_details: CustomerDetails,
    payment_method_details: PaymentMethodDetails,
    processor_details: ProcessorDetails,
    shipping_details: ShippingDetails,
  }
end

.list(params = {}, opts = {}) ⇒ Object

List all the Payment Records for a given merchant.



2392
2393
2394
# File 'lib/stripe/resources/payment_record.rb', line 2392

def self.list(params = {}, opts = {})
  request_stripe_object(method: :get, path: "/v1/payment_records", params: params, opts: opts)
end

.object_nameObject



15
16
17
# File 'lib/stripe/resources/payment_record.rb', line 15

def self.object_name
  "payment_record"
end

.report_payment(params = {}, opts = {}) ⇒ Object

Report a new Payment Record. You may report a Payment Record as it is initialized and later report updates through the other report_* methods, or report Payment Records in a terminal state directly, through this method.



2399
2400
2401
2402
2403
2404
2405
2406
# File 'lib/stripe/resources/payment_record.rb', line 2399

def self.report_payment(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/payment_records/report_payment",
    params: params,
    opts: opts
  )
end

.report_payment_attempt(id, params = {}, opts = {}) ⇒ Object

Report a new payment attempt on the specified Payment Record. A new payment attempt can only be specified if all other payment attempts are canceled or failed.



2421
2422
2423
2424
2425
2426
2427
2428
# File 'lib/stripe/resources/payment_record.rb', line 2421

def self.report_payment_attempt(id, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_records/%<id>s/report_payment_attempt", { id: CGI.escape(id) }),
    params: params,
    opts: opts
  )
end

.report_payment_attempt_canceled(id, params = {}, opts = {}) ⇒ Object

Report that the most recent payment attempt on the specified Payment Record was canceled.



2443
2444
2445
2446
2447
2448
2449
2450
# File 'lib/stripe/resources/payment_record.rb', line 2443

def self.report_payment_attempt_canceled(id, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_records/%<id>s/report_payment_attempt_canceled", { id: CGI.escape(id) }),
    params: params,
    opts: opts
  )
end

.report_payment_attempt_failed(id, params = {}, opts = {}) ⇒ Object

Report that the most recent payment attempt on the specified Payment Record failed or errored.



2465
2466
2467
2468
2469
2470
2471
2472
# File 'lib/stripe/resources/payment_record.rb', line 2465

def self.report_payment_attempt_failed(id, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_records/%<id>s/report_payment_attempt_failed", { id: CGI.escape(id) }),
    params: params,
    opts: opts
  )
end

.report_payment_attempt_guaranteed(id, params = {}, opts = {}) ⇒ Object

Report that the most recent payment attempt on the specified Payment Record was guaranteed.



2487
2488
2489
2490
2491
2492
2493
2494
# File 'lib/stripe/resources/payment_record.rb', line 2487

def self.report_payment_attempt_guaranteed(id, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_records/%<id>s/report_payment_attempt_guaranteed", { id: CGI.escape(id) }),
    params: params,
    opts: opts
  )
end

.report_payment_attempt_informational(id, params = {}, opts = {}) ⇒ Object

Report informational updates on the specified Payment Record.



2507
2508
2509
2510
2511
2512
2513
2514
# File 'lib/stripe/resources/payment_record.rb', line 2507

def self.report_payment_attempt_informational(id, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_records/%<id>s/report_payment_attempt_informational", { id: CGI.escape(id) }),
    params: params,
    opts: opts
  )
end

.report_refund(id, params = {}, opts = {}) ⇒ Object

Report that the most recent payment attempt on the specified Payment Record was refunded.



2529
2530
2531
2532
2533
2534
2535
2536
# File 'lib/stripe/resources/payment_record.rb', line 2529

def self.report_refund(id, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_records/%<id>s/report_refund", { id: CGI.escape(id) }),
    params: params,
    opts: opts
  )
end

.search(params = {}, opts = {}) ⇒ Object



2538
2539
2540
2541
2542
2543
2544
2545
# File 'lib/stripe/resources/payment_record.rb', line 2538

def self.search(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/payment_records/search",
    params: params,
    opts: opts
  )
end

.search_auto_paging_each(params = {}, opts = {}, &blk) ⇒ Object



2547
2548
2549
# File 'lib/stripe/resources/payment_record.rb', line 2547

def self.search_auto_paging_each(params = {}, opts = {}, &blk)
  search(params, opts).auto_paging_each(&blk)
end

Instance Method Details

#report_payment_attempt(params = {}, opts = {}) ⇒ Object

Report a new payment attempt on the specified Payment Record. A new payment attempt can only be specified if all other payment attempts are canceled or failed.



2410
2411
2412
2413
2414
2415
2416
2417
# File 'lib/stripe/resources/payment_record.rb', line 2410

def report_payment_attempt(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_records/%<id>s/report_payment_attempt", { id: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#report_payment_attempt_canceled(params = {}, opts = {}) ⇒ Object

Report that the most recent payment attempt on the specified Payment Record was canceled.



2432
2433
2434
2435
2436
2437
2438
2439
# File 'lib/stripe/resources/payment_record.rb', line 2432

def report_payment_attempt_canceled(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_records/%<id>s/report_payment_attempt_canceled", { id: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#report_payment_attempt_failed(params = {}, opts = {}) ⇒ Object

Report that the most recent payment attempt on the specified Payment Record failed or errored.



2454
2455
2456
2457
2458
2459
2460
2461
# File 'lib/stripe/resources/payment_record.rb', line 2454

def report_payment_attempt_failed(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_records/%<id>s/report_payment_attempt_failed", { id: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#report_payment_attempt_guaranteed(params = {}, opts = {}) ⇒ Object

Report that the most recent payment attempt on the specified Payment Record was guaranteed.



2476
2477
2478
2479
2480
2481
2482
2483
# File 'lib/stripe/resources/payment_record.rb', line 2476

def report_payment_attempt_guaranteed(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_records/%<id>s/report_payment_attempt_guaranteed", { id: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#report_payment_attempt_informational(params = {}, opts = {}) ⇒ Object

Report informational updates on the specified Payment Record.



2497
2498
2499
2500
2501
2502
2503
2504
# File 'lib/stripe/resources/payment_record.rb', line 2497

def report_payment_attempt_informational(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_records/%<id>s/report_payment_attempt_informational", { id: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#report_refund(params = {}, opts = {}) ⇒ Object

Report that the most recent payment attempt on the specified Payment Record was refunded.



2518
2519
2520
2521
2522
2523
2524
2525
# File 'lib/stripe/resources/payment_record.rb', line 2518

def report_refund(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_records/%<id>s/report_refund", { id: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end