Class: Stripe::PaymentRecord::PaymentMethodDetails

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_record.rb

Defined Under Namespace

Classes: AchCreditTransfer, AchDebit, AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, BillingDetails, Bizum, Blik, Boleto, Card, CardPresent, Cashapp, Crypto, Custom, CustomerBalance, Eps, Fpx, GiftCard, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Paypay, Payto, Pix, Promptpay, Qris, Rechnung, RevolutPay, SamsungPay, Satispay, Scalapay, SepaCreditTransfer, SepaDebit, Shopeepay, Sofort, StripeAccount, StripeBalance, Sunbit, Swish, Twint, Upi, UsBankAccount, Wechat, WechatPay, Zip

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#ach_credit_transferObject (readonly)

Attribute for field ach_credit_transfer



1927
1928
1929
# File 'lib/stripe/resources/payment_record.rb', line 1927

def ach_credit_transfer
  @ach_credit_transfer
end

#ach_debitObject (readonly)

Attribute for field ach_debit



1929
1930
1931
# File 'lib/stripe/resources/payment_record.rb', line 1929

def ach_debit
  @ach_debit
end

#acss_debitObject (readonly)

Attribute for field acss_debit



1931
1932
1933
# File 'lib/stripe/resources/payment_record.rb', line 1931

def acss_debit
  @acss_debit
end

#affirmObject (readonly)

Attribute for field affirm



1933
1934
1935
# File 'lib/stripe/resources/payment_record.rb', line 1933

def affirm
  @affirm
end

#afterpay_clearpayObject (readonly)

Attribute for field afterpay_clearpay



1935
1936
1937
# File 'lib/stripe/resources/payment_record.rb', line 1935

def afterpay_clearpay
  @afterpay_clearpay
end

#alipayObject (readonly)

Attribute for field alipay



1937
1938
1939
# File 'lib/stripe/resources/payment_record.rb', line 1937

def alipay
  @alipay
end

#almaObject (readonly)

Attribute for field alma



1939
1940
1941
# File 'lib/stripe/resources/payment_record.rb', line 1939

def alma
  @alma
end

#amazon_payObject (readonly)

Attribute for field amazon_pay



1941
1942
1943
# File 'lib/stripe/resources/payment_record.rb', line 1941

def amazon_pay
  @amazon_pay
end

#au_becs_debitObject (readonly)

Attribute for field au_becs_debit



1943
1944
1945
# File 'lib/stripe/resources/payment_record.rb', line 1943

def au_becs_debit
  @au_becs_debit
end

#bacs_debitObject (readonly)

Attribute for field bacs_debit



1945
1946
1947
# File 'lib/stripe/resources/payment_record.rb', line 1945

def bacs_debit
  @bacs_debit
end

#bancontactObject (readonly)

Attribute for field bancontact



1947
1948
1949
# File 'lib/stripe/resources/payment_record.rb', line 1947

def bancontact
  @bancontact
end

#billieObject (readonly)

Attribute for field billie



1949
1950
1951
# File 'lib/stripe/resources/payment_record.rb', line 1949

def billie
  @billie
end

#billing_detailsObject (readonly)

The billing details associated with the method of payment.



1951
1952
1953
# File 'lib/stripe/resources/payment_record.rb', line 1951

def billing_details
  @billing_details
end

#bizumObject (readonly)

Attribute for field bizum



1953
1954
1955
# File 'lib/stripe/resources/payment_record.rb', line 1953

def bizum
  @bizum
end

#blikObject (readonly)

Attribute for field blik



1955
1956
1957
# File 'lib/stripe/resources/payment_record.rb', line 1955

def blik
  @blik
end

#boletoObject (readonly)

Attribute for field boleto



1957
1958
1959
# File 'lib/stripe/resources/payment_record.rb', line 1957

def boleto
  @boleto
end

#cardObject (readonly)

Details of the card used for this payment attempt.



1959
1960
1961
# File 'lib/stripe/resources/payment_record.rb', line 1959

def card
  @card
end

#card_presentObject (readonly)

Attribute for field card_present



1961
1962
1963
# File 'lib/stripe/resources/payment_record.rb', line 1961

def card_present
  @card_present
end

#cashappObject (readonly)

Attribute for field cashapp



1963
1964
1965
# File 'lib/stripe/resources/payment_record.rb', line 1963

def cashapp
  @cashapp
end

#cryptoObject (readonly)

Attribute for field crypto



1965
1966
1967
# File 'lib/stripe/resources/payment_record.rb', line 1965

def crypto
  @crypto
end

#customObject (readonly)

Custom Payment Methods represent Payment Method types not modeled directly in the Stripe API. This resource consists of details about the custom payment method used for this payment attempt.



1969
1970
1971
# File 'lib/stripe/resources/payment_record.rb', line 1969

def custom
  @custom
end

#customer_balanceObject (readonly)

Attribute for field customer_balance



1971
1972
1973
# File 'lib/stripe/resources/payment_record.rb', line 1971

def customer_balance
  @customer_balance
end

#epsObject (readonly)

Attribute for field eps



1973
1974
1975
# File 'lib/stripe/resources/payment_record.rb', line 1973

def eps
  @eps
end

#fpxObject (readonly)

Attribute for field fpx



1975
1976
1977
# File 'lib/stripe/resources/payment_record.rb', line 1975

def fpx
  @fpx
end

#gift_cardObject (readonly)

Attribute for field gift_card



1977
1978
1979
# File 'lib/stripe/resources/payment_record.rb', line 1977

def gift_card
  @gift_card
end

#giropayObject (readonly)

Attribute for field giropay



1979
1980
1981
# File 'lib/stripe/resources/payment_record.rb', line 1979

def giropay
  @giropay
end

#gopayObject (readonly)

Attribute for field gopay



1981
1982
1983
# File 'lib/stripe/resources/payment_record.rb', line 1981

def gopay
  @gopay
end

#grabpayObject (readonly)

Attribute for field grabpay



1983
1984
1985
# File 'lib/stripe/resources/payment_record.rb', line 1983

def grabpay
  @grabpay
end

#id_bank_transferObject (readonly)

Attribute for field id_bank_transfer



1985
1986
1987
# File 'lib/stripe/resources/payment_record.rb', line 1985

def id_bank_transfer
  @id_bank_transfer
end

#idealObject (readonly)

Attribute for field ideal



1987
1988
1989
# File 'lib/stripe/resources/payment_record.rb', line 1987

def ideal
  @ideal
end

#interac_presentObject (readonly)

Attribute for field interac_present



1989
1990
1991
# File 'lib/stripe/resources/payment_record.rb', line 1989

def interac_present
  @interac_present
end

#kakao_payObject (readonly)

Attribute for field kakao_pay



1991
1992
1993
# File 'lib/stripe/resources/payment_record.rb', line 1991

def kakao_pay
  @kakao_pay
end

#klarnaObject (readonly)

Attribute for field klarna



1993
1994
1995
# File 'lib/stripe/resources/payment_record.rb', line 1993

def klarna
  @klarna
end

#konbiniObject (readonly)

Attribute for field konbini



1995
1996
1997
# File 'lib/stripe/resources/payment_record.rb', line 1995

def konbini
  @konbini
end

#kr_cardObject (readonly)

Attribute for field kr_card



1997
1998
1999
# File 'lib/stripe/resources/payment_record.rb', line 1997

def kr_card
  @kr_card
end

Attribute for field link



1999
2000
2001
# File 'lib/stripe/resources/payment_record.rb', line 1999

def link
  @link
end

#mb_wayObject (readonly)

Attribute for field mb_way



2001
2002
2003
# File 'lib/stripe/resources/payment_record.rb', line 2001

def mb_way
  @mb_way
end

#mobilepayObject (readonly)

Attribute for field mobilepay



2003
2004
2005
# File 'lib/stripe/resources/payment_record.rb', line 2003

def mobilepay
  @mobilepay
end

#multibancoObject (readonly)

Attribute for field multibanco



2005
2006
2007
# File 'lib/stripe/resources/payment_record.rb', line 2005

def multibanco
  @multibanco
end

Attribute for field naver_pay



2007
2008
2009
# File 'lib/stripe/resources/payment_record.rb', line 2007

def naver_pay
  @naver_pay
end

#nz_bank_accountObject (readonly)

Attribute for field nz_bank_account



2009
2010
2011
# File 'lib/stripe/resources/payment_record.rb', line 2009

def 
  @nz_bank_account
end

#oxxoObject (readonly)

Attribute for field oxxo



2011
2012
2013
# File 'lib/stripe/resources/payment_record.rb', line 2011

def oxxo
  @oxxo
end

#p24Object (readonly)

Attribute for field p24



2013
2014
2015
# File 'lib/stripe/resources/payment_record.rb', line 2013

def p24
  @p24
end

#pay_by_bankObject (readonly)

Attribute for field pay_by_bank



2015
2016
2017
# File 'lib/stripe/resources/payment_record.rb', line 2015

def pay_by_bank
  @pay_by_bank
end

#paycoObject (readonly)

Attribute for field payco



2017
2018
2019
# File 'lib/stripe/resources/payment_record.rb', line 2017

def payco
  @payco
end

#payment_methodObject (readonly)

ID of the Stripe PaymentMethod used to make this payment.



2019
2020
2021
# File 'lib/stripe/resources/payment_record.rb', line 2019

def payment_method
  @payment_method
end

#paynowObject (readonly)

Attribute for field paynow



2021
2022
2023
# File 'lib/stripe/resources/payment_record.rb', line 2021

def paynow
  @paynow
end

#paypalObject (readonly)

Attribute for field paypal



2023
2024
2025
# File 'lib/stripe/resources/payment_record.rb', line 2023

def paypal
  @paypal
end

#paypayObject (readonly)

Attribute for field paypay



2025
2026
2027
# File 'lib/stripe/resources/payment_record.rb', line 2025

def paypay
  @paypay
end

#paytoObject (readonly)

Attribute for field payto



2027
2028
2029
# File 'lib/stripe/resources/payment_record.rb', line 2027

def payto
  @payto
end

#pixObject (readonly)

Attribute for field pix



2029
2030
2031
# File 'lib/stripe/resources/payment_record.rb', line 2029

def pix
  @pix
end

#promptpayObject (readonly)

Attribute for field promptpay



2031
2032
2033
# File 'lib/stripe/resources/payment_record.rb', line 2031

def promptpay
  @promptpay
end

#qrisObject (readonly)

Attribute for field qris



2033
2034
2035
# File 'lib/stripe/resources/payment_record.rb', line 2033

def qris
  @qris
end

#rechnungObject (readonly)

Attribute for field rechnung



2035
2036
2037
# File 'lib/stripe/resources/payment_record.rb', line 2035

def rechnung
  @rechnung
end

#revolut_payObject (readonly)

Attribute for field revolut_pay



2037
2038
2039
# File 'lib/stripe/resources/payment_record.rb', line 2037

def revolut_pay
  @revolut_pay
end

#samsung_payObject (readonly)

Attribute for field samsung_pay



2039
2040
2041
# File 'lib/stripe/resources/payment_record.rb', line 2039

def samsung_pay
  @samsung_pay
end

#satispayObject (readonly)

Attribute for field satispay



2041
2042
2043
# File 'lib/stripe/resources/payment_record.rb', line 2041

def satispay
  @satispay
end

#scalapayObject (readonly)

Attribute for field scalapay



2043
2044
2045
# File 'lib/stripe/resources/payment_record.rb', line 2043

def scalapay
  @scalapay
end

#sepa_credit_transferObject (readonly)

Attribute for field sepa_credit_transfer



2045
2046
2047
# File 'lib/stripe/resources/payment_record.rb', line 2045

def sepa_credit_transfer
  @sepa_credit_transfer
end

#sepa_debitObject (readonly)

Attribute for field sepa_debit



2047
2048
2049
# File 'lib/stripe/resources/payment_record.rb', line 2047

def sepa_debit
  @sepa_debit
end

#shopeepayObject (readonly)

Attribute for field shopeepay



2049
2050
2051
# File 'lib/stripe/resources/payment_record.rb', line 2049

def shopeepay
  @shopeepay
end

#sofortObject (readonly)

Attribute for field sofort



2051
2052
2053
# File 'lib/stripe/resources/payment_record.rb', line 2051

def sofort
  @sofort
end

#stripe_accountObject (readonly)

Attribute for field stripe_account



2053
2054
2055
# File 'lib/stripe/resources/payment_record.rb', line 2053

def 
  @stripe_account
end

#stripe_balanceObject (readonly)

Attribute for field stripe_balance



2055
2056
2057
# File 'lib/stripe/resources/payment_record.rb', line 2055

def stripe_balance
  @stripe_balance
end

#sunbitObject (readonly)

Attribute for field sunbit



2057
2058
2059
# File 'lib/stripe/resources/payment_record.rb', line 2057

def sunbit
  @sunbit
end

#swishObject (readonly)

Attribute for field swish



2059
2060
2061
# File 'lib/stripe/resources/payment_record.rb', line 2059

def swish
  @swish
end

#twintObject (readonly)

Attribute for field twint



2061
2062
2063
# File 'lib/stripe/resources/payment_record.rb', line 2061

def twint
  @twint
end

#typeObject (readonly)

The type of transaction-specific details of the payment method used in the payment. See [PaymentMethod.type](docs.stripe.com/api/payment_methods/object#payment_method_object-type) for the full list of possible types. An additional hash is included on ‘payment_method_details` with a name matching this value. It contains information specific to the payment method.



2065
2066
2067
# File 'lib/stripe/resources/payment_record.rb', line 2065

def type
  @type
end

#upiObject (readonly)

Attribute for field upi



2067
2068
2069
# File 'lib/stripe/resources/payment_record.rb', line 2067

def upi
  @upi
end

#us_bank_accountObject (readonly)

Attribute for field us_bank_account



2069
2070
2071
# File 'lib/stripe/resources/payment_record.rb', line 2069

def 
  @us_bank_account
end

#wechatObject (readonly)

Attribute for field wechat



2071
2072
2073
# File 'lib/stripe/resources/payment_record.rb', line 2071

def wechat
  @wechat
end

#wechat_payObject (readonly)

Attribute for field wechat_pay



2073
2074
2075
# File 'lib/stripe/resources/payment_record.rb', line 2073

def wechat_pay
  @wechat_pay
end

#zipObject (readonly)

Attribute for field zip



2075
2076
2077
# File 'lib/stripe/resources/payment_record.rb', line 2075

def zip
  @zip
end

Class Method Details

.field_remappingsObject



2153
2154
2155
# File 'lib/stripe/resources/payment_record.rb', line 2153

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2077
2078
2079
2080
2081
2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
2101
2102
2103
2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
2124
2125
2126
2127
2128
2129
2130
2131
2132
2133
2134
2135
2136
2137
2138
2139
2140
2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
# File 'lib/stripe/resources/payment_record.rb', line 2077

def self.inner_class_types
  @inner_class_types = {
    ach_credit_transfer: AchCreditTransfer,
    ach_debit: AchDebit,
    acss_debit: AcssDebit,
    affirm: Affirm,
    afterpay_clearpay: AfterpayClearpay,
    alipay: Alipay,
    alma: Alma,
    amazon_pay: AmazonPay,
    au_becs_debit: AuBecsDebit,
    bacs_debit: BacsDebit,
    bancontact: Bancontact,
    billie: Billie,
    billing_details: BillingDetails,
    bizum: Bizum,
    blik: Blik,
    boleto: Boleto,
    card: Card,
    card_present: CardPresent,
    cashapp: Cashapp,
    crypto: Crypto,
    custom: Custom,
    customer_balance: CustomerBalance,
    eps: Eps,
    fpx: Fpx,
    gift_card: GiftCard,
    giropay: Giropay,
    gopay: Gopay,
    grabpay: Grabpay,
    id_bank_transfer: IdBankTransfer,
    ideal: Ideal,
    interac_present: InteracPresent,
    kakao_pay: KakaoPay,
    klarna: Klarna,
    konbini: Konbini,
    kr_card: KrCard,
    link: Link,
    mb_way: MbWay,
    mobilepay: Mobilepay,
    multibanco: Multibanco,
    naver_pay: NaverPay,
    nz_bank_account: NzBankAccount,
    oxxo: Oxxo,
    p24: P24,
    pay_by_bank: PayByBank,
    payco: Payco,
    paynow: Paynow,
    paypal: Paypal,
    paypay: Paypay,
    payto: Payto,
    pix: Pix,
    promptpay: Promptpay,
    qris: Qris,
    rechnung: Rechnung,
    revolut_pay: RevolutPay,
    samsung_pay: SamsungPay,
    satispay: Satispay,
    scalapay: Scalapay,
    sepa_credit_transfer: SepaCreditTransfer,
    sepa_debit: SepaDebit,
    shopeepay: Shopeepay,
    sofort: Sofort,
    stripe_account: StripeAccount,
    stripe_balance: StripeBalance,
    sunbit: Sunbit,
    swish: Swish,
    twint: Twint,
    upi: Upi,
    us_bank_account: UsBankAccount,
    wechat: Wechat,
    wechat_pay: WechatPay,
    zip: Zip,
  }
end