Class: Stripe::PaymentRecord::PaymentMethodDetails::AchDebit

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_record.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_holder_typeObject (readonly)

Type of entity that holds the account. This can be either ‘individual` or `company`.



68
69
70
# File 'lib/stripe/resources/payment_record.rb', line 68

def 
  @account_holder_type
end

#bank_nameObject (readonly)

Name of the bank associated with the bank account.



70
71
72
# File 'lib/stripe/resources/payment_record.rb', line 70

def bank_name
  @bank_name
end

#countryObject (readonly)

Two-letter ISO code representing the country the bank account is located in.



72
73
74
# File 'lib/stripe/resources/payment_record.rb', line 72

def country
  @country
end

#fingerprintObject (readonly)

Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.



74
75
76
# File 'lib/stripe/resources/payment_record.rb', line 74

def fingerprint
  @fingerprint
end

#last4Object (readonly)

Last four digits of the bank account number.



76
77
78
# File 'lib/stripe/resources/payment_record.rb', line 76

def last4
  @last4
end

#routing_numberObject (readonly)

Routing transit number of the bank account.



78
79
80
# File 'lib/stripe/resources/payment_record.rb', line 78

def routing_number
  @routing_number
end