Class: Stripe::PaymentRecord::PaymentMethodDetails::Alipay

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_record.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#buyer_idObject (readonly)

Uniquely identifies this particular Alipay account. You can use this attribute to check whether two Alipay accounts are the same.



114
115
116
# File 'lib/stripe/resources/payment_record.rb', line 114

def buyer_id
  @buyer_id
end

#fingerprintObject (readonly)

Uniquely identifies this particular Alipay account. You can use this attribute to check whether two Alipay accounts are the same.



116
117
118
# File 'lib/stripe/resources/payment_record.rb', line 116

def fingerprint
  @fingerprint
end

#transaction_idObject (readonly)

Transaction ID of this particular Alipay transaction.



118
119
120
# File 'lib/stripe/resources/payment_record.rb', line 118

def transaction_id
  @transaction_id
end