Class: Stripe::PaymentRecord::PaymentMethodDetails::Crypto

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_record.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#buyer_addressObject (readonly)

The wallet address of the customer.



712
713
714
# File 'lib/stripe/resources/payment_record.rb', line 712

def buyer_address
  @buyer_address
end

#networkObject (readonly)

The blockchain network that the transaction was sent on.



714
715
716
# File 'lib/stripe/resources/payment_record.rb', line 714

def network
  @network
end

#token_currencyObject (readonly)

The token currency that the transaction was sent with.



716
717
718
# File 'lib/stripe/resources/payment_record.rb', line 716

def token_currency
  @token_currency
end

#transaction_hashObject (readonly)

The blockchain transaction hash of the crypto payment.



718
719
720
# File 'lib/stripe/resources/payment_record.rb', line 718

def transaction_hash
  @transaction_hash
end

Class Method Details

.field_remappingsObject



724
725
726
# File 'lib/stripe/resources/payment_record.rb', line 724

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



720
721
722
# File 'lib/stripe/resources/payment_record.rb', line 720

def self.inner_class_types
  @inner_class_types = {}
end