Class: Stripe::PaymentRecord::PaymentMethodDetails::Custom
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentRecord::PaymentMethodDetails::Custom
- Defined in:
- lib/stripe/resources/payment_record.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#display_name ⇒ Object
readonly
Display name for the custom (user-defined) payment method type used to make this payment.
-
#type ⇒ Object
readonly
The custom payment method type associated with this payment.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#display_name ⇒ Object (readonly)
Display name for the custom (user-defined) payment method type used to make this payment.
82 83 84 |
# File 'lib/stripe/resources/payment_record.rb', line 82 def display_name @display_name end |
#type ⇒ Object (readonly)
The custom payment method type associated with this payment.
84 85 86 |
# File 'lib/stripe/resources/payment_record.rb', line 84 def type @type end |