Class: Stripe::PaymentRecord::PaymentMethodDetails::Klarna

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_record.rb

Defined Under Namespace

Classes: PayerDetails

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#locationObject (readonly)

ID of the location that this transaction's reader is assigned to.



1084
1085
1086
# File 'lib/stripe/resources/payment_record.rb', line 1084

def location
  @location
end

#payer_detailsObject (readonly)

The payer details for this transaction.



1086
1087
1088
# File 'lib/stripe/resources/payment_record.rb', line 1086

def payer_details
  @payer_details
end

#payment_method_categoryObject (readonly)

The Klarna payment method used for this transaction. Can be one of pay_later, pay_now, pay_with_financing, or pay_in_installments



1088
1089
1090
# File 'lib/stripe/resources/payment_record.rb', line 1088

def payment_method_category
  @payment_method_category
end

#preferred_localeObject (readonly)

Preferred language of the Klarna authorization page that the customer is redirected to. Can be one of de-AT, en-AT, nl-BE, fr-BE, en-BE, de-DE, en-DE, da-DK, en-DK, es-ES, en-ES, fi-FI, sv-FI, en-FI, en-GB, en-IE, it-IT, en-IT, nl-NL, en-NL, nb-NO, en-NO, sv-SE, en-SE, en-US, es-US, fr-FR, en-FR, cs-CZ, en-CZ, ro-RO, en-RO, el-GR, en-GR, en-AU, en-NZ, en-CA, fr-CA, pl-PL, en-PL, pt-PT, en-PT, de-CH, fr-CH, it-CH, or en-CH



1090
1091
1092
# File 'lib/stripe/resources/payment_record.rb', line 1090

def preferred_locale
  @preferred_locale
end

#readerObject (readonly)

ID of the reader this transaction was made on.



1092
1093
1094
# File 'lib/stripe/resources/payment_record.rb', line 1092

def reader
  @reader
end

Class Method Details

.field_remappingsObject



1098
1099
1100
# File 'lib/stripe/resources/payment_record.rb', line 1098

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1094
1095
1096
# File 'lib/stripe/resources/payment_record.rb', line 1094

def self.inner_class_types
  @inner_class_types = { payer_details: PayerDetails }
end