Class: Stripe::PaymentRecord::PaymentMethodDetails::KrCard
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentRecord::PaymentMethodDetails::KrCard
- Defined in:
- lib/stripe/resources/payment_record.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#brand ⇒ Object
readonly
The local credit or debit card brand.
-
#buyer_id ⇒ Object
readonly
A unique identifier for the buyer as determined by the local payment processor.
-
#last4 ⇒ Object
readonly
The last four digits of the card.
-
#transaction_id ⇒ Object
readonly
The Korean Card transaction ID associated with this payment.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#brand ⇒ Object (readonly)
The local credit or debit card brand.
1161 1162 1163 |
# File 'lib/stripe/resources/payment_record.rb', line 1161 def brand @brand end |
#buyer_id ⇒ Object (readonly)
A unique identifier for the buyer as determined by the local payment processor.
1163 1164 1165 |
# File 'lib/stripe/resources/payment_record.rb', line 1163 def buyer_id @buyer_id end |
#last4 ⇒ Object (readonly)
The last four digits of the card. This may not be present for American Express cards.
1165 1166 1167 |
# File 'lib/stripe/resources/payment_record.rb', line 1165 def last4 @last4 end |
#transaction_id ⇒ Object (readonly)
The Korean Card transaction ID associated with this payment.
1167 1168 1169 |
# File 'lib/stripe/resources/payment_record.rb', line 1167 def transaction_id @transaction_id end |
Class Method Details
.field_remappings ⇒ Object
1173 1174 1175 |
# File 'lib/stripe/resources/payment_record.rb', line 1173 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1169 1170 1171 |
# File 'lib/stripe/resources/payment_record.rb', line 1169 def self.inner_class_types @inner_class_types = {} end |