Class: Stripe::PaymentRecord::PaymentMethodDetails::Link

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_record.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#countryObject (readonly)

Two-letter ISO code representing the funding source country beneath the Link payment. You could use this attribute to get a sense of international fees.



1170
1171
1172
# File 'lib/stripe/resources/payment_record.rb', line 1170

def country
  @country
end

Class Method Details

.field_remappingsObject



1176
1177
1178
# File 'lib/stripe/resources/payment_record.rb', line 1176

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1172
1173
1174
# File 'lib/stripe/resources/payment_record.rb', line 1172

def self.inner_class_types
  @inner_class_types = {}
end