Class: Stripe::PaymentRecord::PaymentMethodDetails::Momo
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentRecord::PaymentMethodDetails::Momo
- Defined in:
- lib/stripe/resources/payment_record.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#fingerprint ⇒ Object
readonly
Uniquely identifies this particular MoMo account.
-
#mandate ⇒ Object
readonly
ID of the multi-use Mandate created by, or used to make, this MoMo payment.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#fingerprint ⇒ Object (readonly)
Uniquely identifies this particular MoMo account. You can use this attribute to check whether two MoMo accounts are the same.
1217 1218 1219 |
# File 'lib/stripe/resources/payment_record.rb', line 1217 def fingerprint @fingerprint end |
#mandate ⇒ Object (readonly)
ID of the multi-use Mandate created by, or used to make, this MoMo payment.
1219 1220 1221 |
# File 'lib/stripe/resources/payment_record.rb', line 1219 def mandate @mandate end |
Class Method Details
.field_remappings ⇒ Object
1225 1226 1227 |
# File 'lib/stripe/resources/payment_record.rb', line 1225 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1221 1222 1223 |
# File 'lib/stripe/resources/payment_record.rb', line 1221 def self.inner_class_types @inner_class_types = {} end |