Class: Stripe::PaymentRecord::PaymentMethodDetails::Paypal
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentRecord::PaymentMethodDetails::Paypal
- Defined in:
- lib/stripe/resources/payment_record.rb
Defined Under Namespace
Classes: SellerProtection
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#country ⇒ Object
readonly
Two-letter ISO code representing the buyer's country.
-
#payer_email ⇒ Object
readonly
Owner's email.
-
#payer_id ⇒ Object
readonly
PayPal account PayerID.
-
#payer_name ⇒ Object
readonly
Owner's full name.
-
#seller_protection ⇒ Object
readonly
The level of protection offered as defined by PayPal Seller Protection for Merchants, for this transaction.
-
#transaction_id ⇒ Object
readonly
A unique ID generated by PayPal for this transaction.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#country ⇒ Object (readonly)
Two-letter ISO code representing the buyer's country. Values are provided by PayPal directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.
1373 1374 1375 |
# File 'lib/stripe/resources/payment_record.rb', line 1373 def country @country end |
#payer_email ⇒ Object (readonly)
Owner's email. Values are provided by PayPal directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.
1376 1377 1378 |
# File 'lib/stripe/resources/payment_record.rb', line 1376 def payer_email @payer_email end |
#payer_id ⇒ Object (readonly)
PayPal account PayerID. This identifier uniquely identifies the PayPal customer.
1378 1379 1380 |
# File 'lib/stripe/resources/payment_record.rb', line 1378 def payer_id @payer_id end |
#payer_name ⇒ Object (readonly)
Owner's full name. Values provided by PayPal directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.
1381 1382 1383 |
# File 'lib/stripe/resources/payment_record.rb', line 1381 def payer_name @payer_name end |
#seller_protection ⇒ Object (readonly)
The level of protection offered as defined by PayPal Seller Protection for Merchants, for this transaction.
1383 1384 1385 |
# File 'lib/stripe/resources/payment_record.rb', line 1383 def seller_protection @seller_protection end |
#transaction_id ⇒ Object (readonly)
A unique ID generated by PayPal for this transaction.
1385 1386 1387 |
# File 'lib/stripe/resources/payment_record.rb', line 1385 def transaction_id @transaction_id end |
Class Method Details
.field_remappings ⇒ Object
1391 1392 1393 |
# File 'lib/stripe/resources/payment_record.rb', line 1391 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1387 1388 1389 |
# File 'lib/stripe/resources/payment_record.rb', line 1387 def self.inner_class_types @inner_class_types = { seller_protection: SellerProtection } end |