Class: Stripe::PaymentRecord::PaymentMethodDetails::RevolutPay::Funding::Card

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_record.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#brandObject (readonly)

Card brand. Can be ‘amex`, `cartes_bancaires`, `diners`, `discover`, `eftpos_au`, `jcb`, `link`, `mastercard`, `unionpay`, `visa` or `unknown`.



1540
1541
1542
# File 'lib/stripe/resources/payment_record.rb', line 1540

def brand
  @brand
end

#brand_productObject (readonly)

The [product code](stripe.com/docs/card-product-codes) that identifies the specific program or product associated with a card. (For internal use only and not typically available in standard API requests.)



1542
1543
1544
# File 'lib/stripe/resources/payment_record.rb', line 1542

def brand_product
  @brand_product
end

#countryObject (readonly)

Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you’ve collected.



1544
1545
1546
# File 'lib/stripe/resources/payment_record.rb', line 1544

def country
  @country
end

#exp_monthObject (readonly)

Two-digit number representing the card’s expiration month.



1546
1547
1548
# File 'lib/stripe/resources/payment_record.rb', line 1546

def exp_month
  @exp_month
end

#exp_yearObject (readonly)

Four-digit number representing the card’s expiration year.



1548
1549
1550
# File 'lib/stripe/resources/payment_record.rb', line 1548

def exp_year
  @exp_year
end

#fundingObject (readonly)

Card funding type. Can be ‘credit`, `debit`, `prepaid`, or `unknown`.



1550
1551
1552
# File 'lib/stripe/resources/payment_record.rb', line 1550

def funding
  @funding
end

#last4Object (readonly)

The last four digits of the card.



1552
1553
1554
# File 'lib/stripe/resources/payment_record.rb', line 1552

def last4
  @last4
end

Class Method Details

.field_remappingsObject



1558
1559
1560
# File 'lib/stripe/resources/payment_record.rb', line 1558

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1554
1555
1556
# File 'lib/stripe/resources/payment_record.rb', line 1554

def self.inner_class_types
  @inner_class_types = {}
end