Class: Stripe::PaymentRecord::PaymentMethodDetails::SepaCreditTransfer

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_record.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_nameObject (readonly)

Name of the bank associated with the bank account.



1632
1633
1634
# File 'lib/stripe/resources/payment_record.rb', line 1632

def bank_name
  @bank_name
end

#bicObject (readonly)

Bank Identifier Code of the bank associated with the bank account.



1634
1635
1636
# File 'lib/stripe/resources/payment_record.rb', line 1634

def bic
  @bic
end

#ibanObject (readonly)

IBAN of the bank account to transfer funds to.



1636
1637
1638
# File 'lib/stripe/resources/payment_record.rb', line 1636

def iban
  @iban
end

Class Method Details

.field_remappingsObject



1642
1643
1644
# File 'lib/stripe/resources/payment_record.rb', line 1642

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1638
1639
1640
# File 'lib/stripe/resources/payment_record.rb', line 1638

def self.inner_class_types
  @inner_class_types = {}
end