Class: Stripe::PaymentRecord::PaymentMethodDetails::SepaDebit

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_record.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_codeObject (readonly)

Bank code of bank associated with the bank account.



1718
1719
1720
# File 'lib/stripe/resources/payment_record.rb', line 1718

def bank_code
  @bank_code
end

#branch_codeObject (readonly)

Branch code of bank associated with the bank account.



1720
1721
1722
# File 'lib/stripe/resources/payment_record.rb', line 1720

def branch_code
  @branch_code
end

#countryObject (readonly)

Two-letter ISO code representing the country the bank account is located in.



1722
1723
1724
# File 'lib/stripe/resources/payment_record.rb', line 1722

def country
  @country
end

#expected_debit_dateObject (readonly)

Estimated date to debit the customer’s bank account. A date string in YYYY-MM-DD format.



1724
1725
1726
# File 'lib/stripe/resources/payment_record.rb', line 1724

def expected_debit_date
  @expected_debit_date
end

#fingerprintObject (readonly)

Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.



1726
1727
1728
# File 'lib/stripe/resources/payment_record.rb', line 1726

def fingerprint
  @fingerprint
end

#last4Object (readonly)

Last four characters of the IBAN.



1728
1729
1730
# File 'lib/stripe/resources/payment_record.rb', line 1728

def last4
  @last4
end

#mandateObject (readonly)

Find the ID of the mandate used for this payment under the [payment_method_details.sepa_debit.mandate](docs.stripe.com/api/charges/object#charge_object-payment_method_details-sepa_debit-mandate) property on the Charge. Use this mandate ID to [retrieve the Mandate](docs.stripe.com/api/mandates/retrieve).



1730
1731
1732
# File 'lib/stripe/resources/payment_record.rb', line 1730

def mandate
  @mandate
end

Class Method Details

.field_remappingsObject



1736
1737
1738
# File 'lib/stripe/resources/payment_record.rb', line 1736

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1732
1733
1734
# File 'lib/stripe/resources/payment_record.rb', line 1732

def self.inner_class_types
  @inner_class_types = {}
end