Class: Stripe::PaymentRecord::PaymentMethodDetails::Swish

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_record.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#fingerprintObject (readonly)

Uniquely identifies the payer’s Swish account. You can use this attribute to check whether two Swish transactions were paid for by the same payer



1736
1737
1738
# File 'lib/stripe/resources/payment_record.rb', line 1736

def fingerprint
  @fingerprint
end

#payment_referenceObject (readonly)

Payer bank reference number for the payment



1738
1739
1740
# File 'lib/stripe/resources/payment_record.rb', line 1738

def payment_reference
  @payment_reference
end

#verified_phone_last4Object (readonly)

The last four digits of the Swish account phone number



1740
1741
1742
# File 'lib/stripe/resources/payment_record.rb', line 1740

def verified_phone_last4
  @verified_phone_last4
end

Class Method Details

.field_remappingsObject



1746
1747
1748
# File 'lib/stripe/resources/payment_record.rb', line 1746

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1742
1743
1744
# File 'lib/stripe/resources/payment_record.rb', line 1742

def self.inner_class_types
  @inner_class_types = {}
end