Class: Stripe::PaymentRecord::PaymentMethodDetails::UsBankAccount

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_record.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_holder_typeObject (readonly)

The type of entity that holds the account. This can be either ‘individual’ or ‘company’.



1800
1801
1802
# File 'lib/stripe/resources/payment_record.rb', line 1800

def 
  @account_holder_type
end

#account_typeObject (readonly)

The type of the bank account. This can be either ‘checking’ or ‘savings’.



1802
1803
1804
# File 'lib/stripe/resources/payment_record.rb', line 1802

def 
  @account_type
end

#bank_nameObject (readonly)

Name of the bank associated with the bank account.



1804
1805
1806
# File 'lib/stripe/resources/payment_record.rb', line 1804

def bank_name
  @bank_name
end

#expected_debit_dateObject (readonly)

Estimated date to debit the customer’s bank account. A date string in YYYY-MM-DD format.



1806
1807
1808
# File 'lib/stripe/resources/payment_record.rb', line 1806

def expected_debit_date
  @expected_debit_date
end

#fingerprintObject (readonly)

Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.



1808
1809
1810
# File 'lib/stripe/resources/payment_record.rb', line 1808

def fingerprint
  @fingerprint
end

#last4Object (readonly)

Last four digits of the bank account number.



1810
1811
1812
# File 'lib/stripe/resources/payment_record.rb', line 1810

def last4
  @last4
end

#mandateObject (readonly)

ID of the mandate used to make this payment.



1812
1813
1814
# File 'lib/stripe/resources/payment_record.rb', line 1812

def mandate
  @mandate
end

#payment_referenceObject (readonly)

The ACH payment reference for this transaction.



1814
1815
1816
# File 'lib/stripe/resources/payment_record.rb', line 1814

def payment_reference
  @payment_reference
end

#routing_numberObject (readonly)

The routing number for the bank account.



1816
1817
1818
# File 'lib/stripe/resources/payment_record.rb', line 1816

def routing_number
  @routing_number
end

Class Method Details

.field_remappingsObject



1822
1823
1824
# File 'lib/stripe/resources/payment_record.rb', line 1822

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1818
1819
1820
# File 'lib/stripe/resources/payment_record.rb', line 1818

def self.inner_class_types
  @inner_class_types = {}
end