Class: Stripe::PaymentRecord::ProcessorDetails

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_record.rb

Defined Under Namespace

Classes: Custom

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#custom ⇒ Object (readonly)

Custom processors represent payment processors not modeled directly in the Stripe API. This resource consists of details about the custom processor used for this payment attempt.



1995
1996
1997
# File 'lib/stripe/resources/payment_record.rb', line 1995

def custom
  @custom
end

#type ⇒ Object (readonly)

The processor used for this payment attempt.



1997
1998
1999
# File 'lib/stripe/resources/payment_record.rb', line 1997

def type
  @type
end

Class Method Details

.field_remappings ⇒ Object



2003
2004
2005
# File 'lib/stripe/resources/payment_record.rb', line 2003

def self.field_remappings
  @field_remappings = {}
end

.inner_class_types ⇒ Object



1999
2000
2001
# File 'lib/stripe/resources/payment_record.rb', line 1999

def self.inner_class_types
  @inner_class_types = { custom: Custom }
end