Class: Stripe::PaymentRecord::ReportPaymentAttemptCanceledParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecord::ReportPaymentAttemptCanceledParams
- Defined in:
- lib/stripe/resources/payment_record.rb
Instance Attribute Summary collapse
-
#canceled_at ⇒ Object
When the reported payment was canceled.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Attribute for param field metadata.
Instance Method Summary collapse
-
#initialize(canceled_at: nil, expand: nil, metadata: nil) ⇒ ReportPaymentAttemptCanceledParams
constructor
A new instance of ReportPaymentAttemptCanceledParams.
Methods inherited from RequestParams
Constructor Details
#initialize(canceled_at: nil, expand: nil, metadata: nil) ⇒ ReportPaymentAttemptCanceledParams
Returns a new instance of ReportPaymentAttemptCanceledParams.
2157 2158 2159 2160 2161 |
# File 'lib/stripe/resources/payment_record.rb', line 2157 def initialize(canceled_at: nil, expand: nil, metadata: nil) @canceled_at = canceled_at @expand = @metadata = end |
Instance Attribute Details
#canceled_at ⇒ Object
When the reported payment was canceled. Measured in seconds since the Unix epoch.
2151 2152 2153 |
# File 'lib/stripe/resources/payment_record.rb', line 2151 def canceled_at @canceled_at end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2153 2154 2155 |
# File 'lib/stripe/resources/payment_record.rb', line 2153 def @expand end |
#metadata ⇒ Object
Attribute for param field metadata
2155 2156 2157 |
# File 'lib/stripe/resources/payment_record.rb', line 2155 def @metadata end |