Class: Stripe::PaymentRecord::ReportPaymentAttemptFailedParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecord::ReportPaymentAttemptFailedParams
- Defined in:
- lib/stripe/resources/payment_record.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#failed_at ⇒ Object
When the reported payment failed.
-
#metadata ⇒ Object
Attribute for param field metadata.
Instance Method Summary collapse
-
#initialize(expand: nil, failed_at: nil, metadata: nil) ⇒ ReportPaymentAttemptFailedParams
constructor
A new instance of ReportPaymentAttemptFailedParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, failed_at: nil, metadata: nil) ⇒ ReportPaymentAttemptFailedParams
Returns a new instance of ReportPaymentAttemptFailedParams.
1313 1314 1315 1316 1317 |
# File 'lib/stripe/resources/payment_record.rb', line 1313 def initialize(expand: nil, failed_at: nil, metadata: nil) @expand = @failed_at = failed_at @metadata = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1307 1308 1309 |
# File 'lib/stripe/resources/payment_record.rb', line 1307 def @expand end |
#failed_at ⇒ Object
When the reported payment failed. Measured in seconds since the Unix epoch.
1309 1310 1311 |
# File 'lib/stripe/resources/payment_record.rb', line 1309 def failed_at @failed_at end |
#metadata ⇒ Object
Attribute for param field metadata
1311 1312 1313 |
# File 'lib/stripe/resources/payment_record.rb', line 1311 def @metadata end |