Class: Stripe::PaymentRecord::ReportPaymentAttemptGuaranteedParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecord::ReportPaymentAttemptGuaranteedParams
- Defined in:
- lib/stripe/resources/payment_record.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#guaranteed_at ⇒ Object
When the reported payment was guaranteed.
-
#metadata ⇒ Object
Attribute for param field metadata.
Instance Method Summary collapse
-
#initialize(expand: nil, guaranteed_at: nil, metadata: nil) ⇒ ReportPaymentAttemptGuaranteedParams
constructor
A new instance of ReportPaymentAttemptGuaranteedParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, guaranteed_at: nil, metadata: nil) ⇒ ReportPaymentAttemptGuaranteedParams
Returns a new instance of ReportPaymentAttemptGuaranteedParams.
2187 2188 2189 2190 2191 |
# File 'lib/stripe/resources/payment_record.rb', line 2187 def initialize(expand: nil, guaranteed_at: nil, metadata: nil) @expand = @guaranteed_at = guaranteed_at @metadata = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2181 2182 2183 |
# File 'lib/stripe/resources/payment_record.rb', line 2181 def @expand end |
#guaranteed_at ⇒ Object
When the reported payment was guaranteed. Measured in seconds since the Unix epoch.
2183 2184 2185 |
# File 'lib/stripe/resources/payment_record.rb', line 2183 def guaranteed_at @guaranteed_at end |
#metadata ⇒ Object
Attribute for param field metadata
2185 2186 2187 |
# File 'lib/stripe/resources/payment_record.rb', line 2185 def @metadata end |