Class: Stripe::PaymentRecord::ReportPaymentAttemptParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_record.rb

Defined Under Namespace

Classes: Failed, Guaranteed, PaymentMethodDetails, ShippingDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, expand: nil, failed: nil, guaranteed: nil, initiated_at: nil, metadata: nil, outcome: nil, payment_method_details: nil, shipping_details: nil) ⇒ ReportPaymentAttemptParams

Returns a new instance of ReportPaymentAttemptParams.



1267
1268
1269
1270
1271
1272
1273
1274
1275
1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
# File 'lib/stripe/resources/payment_record.rb', line 1267

def initialize(
  description: nil,
  expand: nil,
  failed: nil,
  guaranteed: nil,
  initiated_at: nil,
  metadata: nil,
  outcome: nil,
  payment_method_details: nil,
  shipping_details: nil
)
  @description = description
  @expand = expand
  @failed = failed
  @guaranteed = guaranteed
  @initiated_at = initiated_at
  @metadata = 
  @outcome = outcome
  @payment_method_details = payment_method_details
  @shipping_details = shipping_details
end

Instance Attribute Details

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



1249
1250
1251
# File 'lib/stripe/resources/payment_record.rb', line 1249

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



1251
1252
1253
# File 'lib/stripe/resources/payment_record.rb', line 1251

def expand
  @expand
end

#failedObject

Information about the payment attempt failure.



1253
1254
1255
# File 'lib/stripe/resources/payment_record.rb', line 1253

def failed
  @failed
end

#guaranteedObject

Information about the payment attempt guarantee.



1255
1256
1257
# File 'lib/stripe/resources/payment_record.rb', line 1255

def guaranteed
  @guaranteed
end

#initiated_atObject

When the reported payment was initiated. Measured in seconds since the Unix epoch.



1257
1258
1259
# File 'lib/stripe/resources/payment_record.rb', line 1257

def initiated_at
  @initiated_at
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1259
1260
1261
# File 'lib/stripe/resources/payment_record.rb', line 1259

def 
  @metadata
end

#outcomeObject

The outcome of the reported payment.



1261
1262
1263
# File 'lib/stripe/resources/payment_record.rb', line 1261

def outcome
  @outcome
end

#payment_method_detailsObject

Information about the Payment Method debited for this payment.



1263
1264
1265
# File 'lib/stripe/resources/payment_record.rb', line 1263

def payment_method_details
  @payment_method_details
end

#shipping_detailsObject

Shipping information for this payment.



1265
1266
1267
# File 'lib/stripe/resources/payment_record.rb', line 1265

def shipping_details
  @shipping_details
end