Class: Stripe::PaymentRecord::ReportPaymentAttemptParams::PaymentMethodDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecord::ReportPaymentAttemptParams::PaymentMethodDetails
- Defined in:
- lib/stripe/resources/payment_record.rb
Defined Under Namespace
Classes: BillingDetails, Custom
Instance Attribute Summary collapse
-
#billing_details ⇒ Object
The billing details associated with the method of payment.
-
#custom ⇒ Object
Information about the custom (user-defined) payment method used to make this payment.
-
#payment_method ⇒ Object
ID of the Stripe Payment Method used to make this payment.
-
#type ⇒ Object
The type of the payment method details.
Instance Method Summary collapse
-
#initialize(billing_details: nil, custom: nil, payment_method: nil, type: nil) ⇒ PaymentMethodDetails
constructor
A new instance of PaymentMethodDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(billing_details: nil, custom: nil, payment_method: nil, type: nil) ⇒ PaymentMethodDetails
Returns a new instance of PaymentMethodDetails.
2055 2056 2057 2058 2059 2060 |
# File 'lib/stripe/resources/payment_record.rb', line 2055 def initialize(billing_details: nil, custom: nil, payment_method: nil, type: nil) @billing_details = billing_details @custom = custom @payment_method = payment_method @type = type end |
Instance Attribute Details
#billing_details ⇒ Object
The billing details associated with the method of payment.
2047 2048 2049 |
# File 'lib/stripe/resources/payment_record.rb', line 2047 def billing_details @billing_details end |
#custom ⇒ Object
Information about the custom (user-defined) payment method used to make this payment.
2049 2050 2051 |
# File 'lib/stripe/resources/payment_record.rb', line 2049 def custom @custom end |
#payment_method ⇒ Object
ID of the Stripe Payment Method used to make this payment.
2051 2052 2053 |
# File 'lib/stripe/resources/payment_record.rb', line 2051 def payment_method @payment_method end |
#type ⇒ Object
The type of the payment method details. An additional hash is included on the payment_method_details with a name matching this value. It contains additional information specific to the type.
2053 2054 2055 |
# File 'lib/stripe/resources/payment_record.rb', line 2053 def type @type end |