Class: Stripe::PaymentRecord::ReportPaymentAttemptParams::PaymentMethodDetails::BillingDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_record.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, email: nil, name: nil, phone: nil) ⇒ BillingDetails

Returns a new instance of BillingDetails.



2027
2028
2029
2030
2031
2032
# File 'lib/stripe/resources/payment_record.rb', line 2027

def initialize(address: nil, email: nil, name: nil, phone: nil)
  @address = address
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#addressObject

The billing address associated with the method of payment.



2019
2020
2021
# File 'lib/stripe/resources/payment_record.rb', line 2019

def address
  @address
end

#emailObject

The billing email associated with the method of payment.



2021
2022
2023
# File 'lib/stripe/resources/payment_record.rb', line 2021

def email
  @email
end

#nameObject

The billing name associated with the method of payment.



2023
2024
2025
# File 'lib/stripe/resources/payment_record.rb', line 2023

def name
  @name
end

#phoneObject

The billing phone number associated with the method of payment.



2025
2026
2027
# File 'lib/stripe/resources/payment_record.rb', line 2025

def phone
  @phone
end