Class: Stripe::PaymentRecord::ReportPaymentAttemptParams::PaymentMethodDetails::Custom
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecord::ReportPaymentAttemptParams::PaymentMethodDetails::Custom
- Defined in:
- lib/stripe/resources/payment_record.rb
Instance Attribute Summary collapse
-
#display_name ⇒ Object
Display name for the custom (user-defined) payment method type used to make this payment.
-
#type ⇒ Object
The custom payment method type associated with this payment.
Instance Method Summary collapse
-
#initialize(display_name: nil, type: nil) ⇒ Custom
constructor
A new instance of Custom.
Methods inherited from RequestParams
Constructor Details
#initialize(display_name: nil, type: nil) ⇒ Custom
Returns a new instance of Custom.
2041 2042 2043 2044 |
# File 'lib/stripe/resources/payment_record.rb', line 2041 def initialize(display_name: nil, type: nil) @display_name = display_name @type = type end |
Instance Attribute Details
#display_name ⇒ Object
Display name for the custom (user-defined) payment method type used to make this payment.
2037 2038 2039 |
# File 'lib/stripe/resources/payment_record.rb', line 2037 def display_name @display_name end |
#type ⇒ Object
The custom payment method type associated with this payment.
2039 2040 2041 |
# File 'lib/stripe/resources/payment_record.rb', line 2039 def type @type end |