Class: Stripe::PaymentRecord::ReportPaymentParams::PaymentMethodDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_record.rb

Defined Under Namespace

Classes: BillingDetails, Custom

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_details: nil, custom: nil, payment_method: nil, type: nil) ⇒ PaymentMethodDetails

Returns a new instance of PaymentMethodDetails.



1453
1454
1455
1456
1457
1458
# File 'lib/stripe/resources/payment_record.rb', line 1453

def initialize(billing_details: nil, custom: nil, payment_method: nil, type: nil)
  @billing_details = billing_details
  @custom = custom
  @payment_method = payment_method
  @type = type
end

Instance Attribute Details

#billing_detailsObject

The billing details associated with the method of payment.



1445
1446
1447
# File 'lib/stripe/resources/payment_record.rb', line 1445

def billing_details
  @billing_details
end

#customObject

Information about the custom (user-defined) payment method used to make this payment.



1447
1448
1449
# File 'lib/stripe/resources/payment_record.rb', line 1447

def custom
  @custom
end

#payment_methodObject

ID of the Stripe Payment Method used to make this payment.



1449
1450
1451
# File 'lib/stripe/resources/payment_record.rb', line 1449

def payment_method
  @payment_method
end

#typeObject

The type of the payment method details. An additional hash is included on the payment_method_details with a name matching this value. It contains additional information specific to the type.



1451
1452
1453
# File 'lib/stripe/resources/payment_record.rb', line 1451

def type
  @type
end