Class: Stripe::PaymentRecord::ReportPaymentParams::PaymentMethodDetails::BillingDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_record.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, email: nil, name: nil, phone: nil) ⇒ BillingDetails

Returns a new instance of BillingDetails.



1425
1426
1427
1428
1429
1430
# File 'lib/stripe/resources/payment_record.rb', line 1425

def initialize(address: nil, email: nil, name: nil, phone: nil)
  @address = address
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#addressObject

The billing address associated with the method of payment.



1417
1418
1419
# File 'lib/stripe/resources/payment_record.rb', line 1417

def address
  @address
end

#emailObject

The billing email associated with the method of payment.



1419
1420
1421
# File 'lib/stripe/resources/payment_record.rb', line 1419

def email
  @email
end

#nameObject

The billing name associated with the method of payment.



1421
1422
1423
# File 'lib/stripe/resources/payment_record.rb', line 1421

def name
  @name
end

#phoneObject

The billing phone number associated with the method of payment.



1423
1424
1425
# File 'lib/stripe/resources/payment_record.rb', line 1423

def phone
  @phone
end