Class: Stripe::PaymentRecord::ReportPaymentParams::PaymentMethodDetails::Custom
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecord::ReportPaymentParams::PaymentMethodDetails::Custom
- Defined in:
- lib/stripe/resources/payment_record.rb
Instance Attribute Summary collapse
-
#display_name ⇒ Object
Display name for the custom (user-defined) payment method type used to make this payment.
-
#type ⇒ Object
The custom payment method type associated with this payment.
Instance Method Summary collapse
-
#initialize(display_name: nil, type: nil) ⇒ Custom
constructor
A new instance of Custom.
Methods inherited from RequestParams
Constructor Details
#initialize(display_name: nil, type: nil) ⇒ Custom
Returns a new instance of Custom.
459 460 461 462 |
# File 'lib/stripe/resources/payment_record.rb', line 459 def initialize(display_name: nil, type: nil) @display_name = display_name @type = type end |
Instance Attribute Details
#display_name ⇒ Object
Display name for the custom (user-defined) payment method type used to make this payment.
455 456 457 |
# File 'lib/stripe/resources/payment_record.rb', line 455 def display_name @display_name end |
#type ⇒ Object
The custom payment method type associated with this payment.
457 458 459 |
# File 'lib/stripe/resources/payment_record.rb', line 457 def type @type end |