Class: Stripe::PaymentRecord::ReportPaymentParams::ProcessorDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecord::ReportPaymentParams::ProcessorDetails
- Defined in:
- lib/stripe/resources/payment_record.rb
Defined Under Namespace
Classes: Custom
Instance Attribute Summary collapse
-
#custom ⇒ Object
Information about the custom processor used to make this payment.
-
#type ⇒ Object
The type of the processor details.
Instance Method Summary collapse
-
#initialize(custom: nil, type: nil) ⇒ ProcessorDetails
constructor
A new instance of ProcessorDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(custom: nil, type: nil) ⇒ ProcessorDetails
Returns a new instance of ProcessorDetails.
1475 1476 1477 1478 |
# File 'lib/stripe/resources/payment_record.rb', line 1475 def initialize(custom: nil, type: nil) @custom = custom @type = type end |
Instance Attribute Details
#custom ⇒ Object
Information about the custom processor used to make this payment.
1471 1472 1473 |
# File 'lib/stripe/resources/payment_record.rb', line 1471 def custom @custom end |
#type ⇒ Object
The type of the processor details. An additional hash is included on processor_details with a name matching this value. It contains additional information specific to the processor.
1473 1474 1475 |
# File 'lib/stripe/resources/payment_record.rb', line 1473 def type @type end |