Class: Stripe::PaymentRecordCreateParams::Funded
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecordCreateParams::Funded
- Defined in:
- lib/stripe/params/payment_record_create_params.rb
Defined Under Namespace
Classes: Amount
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount that has been lost to the customer due to disputes on this payment.
-
#funded_at ⇒ Object
When the dispute funding event occurred.
-
#type ⇒ Object
The type of dispute funding event.
Instance Method Summary collapse
-
#initialize(amount: nil, funded_at: nil, type: nil) ⇒ Funded
constructor
A new instance of Funded.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, funded_at: nil, type: nil) ⇒ Funded
Returns a new instance of Funded.
46 47 48 49 50 |
# File 'lib/stripe/params/payment_record_create_params.rb', line 46 def initialize(amount: nil, funded_at: nil, type: nil) @amount = amount @funded_at = funded_at @type = type end |
Instance Attribute Details
#amount ⇒ Object
The amount that has been lost to the customer due to disputes on this payment.
40 41 42 |
# File 'lib/stripe/params/payment_record_create_params.rb', line 40 def amount @amount end |
#funded_at ⇒ Object
When the dispute funding event occurred. Measured in seconds since the Unix epoch.
42 43 44 |
# File 'lib/stripe/params/payment_record_create_params.rb', line 42 def funded_at @funded_at end |
#type ⇒ Object
The type of dispute funding event.
44 45 46 |
# File 'lib/stripe/params/payment_record_create_params.rb', line 44 def type @type end |