Class: Stripe::PaymentRecordReportPaymentAttemptFailedParams::PaymentMethodDetails::Card
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecordReportPaymentAttemptFailedParams::PaymentMethodDetails::Card
- Defined in:
- lib/stripe/params/payment_record_report_payment_attempt_failed_params.rb
Defined Under Namespace
Classes: Checks
Instance Attribute Summary collapse
-
#checks ⇒ Object
Verification checks performed on the card.
-
#network_decline_code ⇒ Object
Decline code from the card network for the failed payment.
Instance Method Summary collapse
-
#initialize(checks: nil, network_decline_code: nil) ⇒ Card
constructor
A new instance of Card.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(checks: nil, network_decline_code: nil) ⇒ Card
Returns a new instance of Card.
27 28 29 30 |
# File 'lib/stripe/params/payment_record_report_payment_attempt_failed_params.rb', line 27 def initialize(checks: nil, network_decline_code: nil) @checks = checks @network_decline_code = network_decline_code end |
Instance Attribute Details
#checks ⇒ Object
Verification checks performed on the card.
23 24 25 |
# File 'lib/stripe/params/payment_record_report_payment_attempt_failed_params.rb', line 23 def checks @checks end |
#network_decline_code ⇒ Object
Decline code from the card network for the failed payment.
25 26 27 |
# File 'lib/stripe/params/payment_record_report_payment_attempt_failed_params.rb', line 25 def network_decline_code @network_decline_code end |