Class: Stripe::PaymentRecordReportPaymentAttemptFailedParams::ProcessorDetails::Custom

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_record_report_payment_attempt_failed_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(payment_reference: nil) ⇒ Custom

Returns a new instance of Custom.



11
12
13
# File 'lib/stripe/params/payment_record_report_payment_attempt_failed_params.rb', line 11

def initialize(payment_reference: nil)
  @payment_reference = payment_reference
end

Instance Attribute Details

#payment_referenceObject

An opaque string for manual reconciliation of this payment, for example a check number or a payment processor ID.



9
10
11
# File 'lib/stripe/params/payment_record_report_payment_attempt_failed_params.rb', line 9

def payment_reference
  @payment_reference
end