Class: Stripe::PaymentRecordReportPaymentAttemptGuaranteedParams::PaymentMethodDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecordReportPaymentAttemptGuaranteedParams::PaymentMethodDetails
- Defined in:
- lib/stripe/params/payment_record_report_payment_attempt_guaranteed_params.rb
Defined Under Namespace
Classes: Card
Instance Attribute Summary collapse
-
#card ⇒ Object
Information about the card payment method used to make this payment.
-
#type ⇒ Object
The type of the payment method details.
Instance Method Summary collapse
-
#initialize(card: nil, type: nil) ⇒ PaymentMethodDetails
constructor
A new instance of PaymentMethodDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(card: nil, type: nil) ⇒ PaymentMethodDetails
Returns a new instance of PaymentMethodDetails.
34 35 36 37 |
# File 'lib/stripe/params/payment_record_report_payment_attempt_guaranteed_params.rb', line 34 def initialize(card: nil, type: nil) @card = card @type = type end |
Instance Attribute Details
#card ⇒ Object
Information about the card payment method used to make this payment.
30 31 32 |
# File 'lib/stripe/params/payment_record_report_payment_attempt_guaranteed_params.rb', line 30 def card @card end |
#type ⇒ Object
The type of the payment method details. An additional hash is included on the payment_method_details with a name matching this value. It contains additional information specific to the type.
32 33 34 |
# File 'lib/stripe/params/payment_record_report_payment_attempt_guaranteed_params.rb', line 32 def type @type end |