Class: Stripe::PaymentRecordReportPaymentAttemptParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecordReportPaymentAttemptParams
- Defined in:
- lib/stripe/params/payment_record_report_payment_attempt_params.rb
Defined Under Namespace
Classes: Failed, Guaranteed, PaymentMethodDetails, ShippingDetails
Instance Attribute Summary collapse
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#failed ⇒ Object
Information about the payment attempt failure.
-
#guaranteed ⇒ Object
Information about the payment attempt guarantee.
-
#initiated_at ⇒ Object
When the reported payment was initiated.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#outcome ⇒ Object
The outcome of the reported payment.
-
#payment_method_details ⇒ Object
Information about the Payment Method debited for this payment.
-
#shipping_details ⇒ Object
Shipping information for this payment.
Instance Method Summary collapse
-
#initialize(description: nil, expand: nil, failed: nil, guaranteed: nil, initiated_at: nil, metadata: nil, outcome: nil, payment_method_details: nil, shipping_details: nil) ⇒ PaymentRecordReportPaymentAttemptParams
constructor
A new instance of PaymentRecordReportPaymentAttemptParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(description: nil, expand: nil, failed: nil, guaranteed: nil, initiated_at: nil, metadata: nil, outcome: nil, payment_method_details: nil, shipping_details: nil) ⇒ PaymentRecordReportPaymentAttemptParams
Returns a new instance of PaymentRecordReportPaymentAttemptParams.
248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 |
# File 'lib/stripe/params/payment_record_report_payment_attempt_params.rb', line 248 def initialize( description: nil, expand: nil, failed: nil, guaranteed: nil, initiated_at: nil, metadata: nil, outcome: nil, payment_method_details: nil, shipping_details: nil ) @description = description @expand = @failed = failed @guaranteed = guaranteed @initiated_at = initiated_at @metadata = @outcome = outcome @payment_method_details = payment_method_details @shipping_details = shipping_details end |
Instance Attribute Details
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
230 231 232 |
# File 'lib/stripe/params/payment_record_report_payment_attempt_params.rb', line 230 def description @description end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
232 233 234 |
# File 'lib/stripe/params/payment_record_report_payment_attempt_params.rb', line 232 def @expand end |
#failed ⇒ Object
Information about the payment attempt failure.
234 235 236 |
# File 'lib/stripe/params/payment_record_report_payment_attempt_params.rb', line 234 def failed @failed end |
#guaranteed ⇒ Object
Information about the payment attempt guarantee.
236 237 238 |
# File 'lib/stripe/params/payment_record_report_payment_attempt_params.rb', line 236 def guaranteed @guaranteed end |
#initiated_at ⇒ Object
When the reported payment was initiated. Measured in seconds since the Unix epoch.
238 239 240 |
# File 'lib/stripe/params/payment_record_report_payment_attempt_params.rb', line 238 def initiated_at @initiated_at end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
240 241 242 |
# File 'lib/stripe/params/payment_record_report_payment_attempt_params.rb', line 240 def @metadata end |
#outcome ⇒ Object
The outcome of the reported payment.
242 243 244 |
# File 'lib/stripe/params/payment_record_report_payment_attempt_params.rb', line 242 def outcome @outcome end |
#payment_method_details ⇒ Object
Information about the Payment Method debited for this payment.
244 245 246 |
# File 'lib/stripe/params/payment_record_report_payment_attempt_params.rb', line 244 def payment_method_details @payment_method_details end |
#shipping_details ⇒ Object
Shipping information for this payment.
246 247 248 |
# File 'lib/stripe/params/payment_record_report_payment_attempt_params.rb', line 246 def shipping_details @shipping_details end |