Class: Stripe::PaymentRecordReportPaymentAttemptParams::PaymentMethodDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_record_report_payment_attempt_params.rb

Defined Under Namespace

Classes: BillingDetails, Card, Custom

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(billing_details: nil, card: nil, custom: nil, payment_method: nil, type: nil) ⇒ PaymentMethodDetails

Returns a new instance of PaymentMethodDetails.



176
177
178
179
180
181
182
# File 'lib/stripe/params/payment_record_report_payment_attempt_params.rb', line 176

def initialize(billing_details: nil, card: nil, custom: nil, payment_method: nil, type: nil)
  @billing_details = billing_details
  @card = card
  @custom = custom
  @payment_method = payment_method
  @type = type
end

Instance Attribute Details

#billing_detailsObject

The billing details associated with the method of payment.



166
167
168
# File 'lib/stripe/params/payment_record_report_payment_attempt_params.rb', line 166

def billing_details
  @billing_details
end

#cardObject

Information about the card payment method used to make this payment.



168
169
170
# File 'lib/stripe/params/payment_record_report_payment_attempt_params.rb', line 168

def card
  @card
end

#customObject

Information about the custom (user-defined) payment method used to make this payment.



170
171
172
# File 'lib/stripe/params/payment_record_report_payment_attempt_params.rb', line 170

def custom
  @custom
end

#payment_methodObject

ID of the Stripe Payment Method used to make this payment.



172
173
174
# File 'lib/stripe/params/payment_record_report_payment_attempt_params.rb', line 172

def payment_method
  @payment_method
end

#typeObject

The type of the payment method details. An additional hash is included on the payment_method_details with a name matching this value. It contains additional information specific to the type.



174
175
176
# File 'lib/stripe/params/payment_record_report_payment_attempt_params.rb', line 174

def type
  @type
end