Class: Stripe::PaymentRecordReportPaymentParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/payment_record_report_payment_params.rb

Defined Under Namespace

Classes: AmountRequested, CustomerDetails, Failed, Guaranteed, PaymentMethodDetails, ProcessorDetails, ShippingDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount_requested: nil, customer_details: nil, customer_presence: nil, description: nil, expand: nil, failed: nil, guaranteed: nil, initiated_at: nil, metadata: nil, outcome: nil, payment_method_details: nil, processor_details: nil, shipping_details: nil) ⇒ PaymentRecordReportPaymentParams

Returns a new instance of PaymentRecordReportPaymentParams.



306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 306

def initialize(
  amount_requested: nil,
  customer_details: nil,
  customer_presence: nil,
  description: nil,
  expand: nil,
  failed: nil,
  guaranteed: nil,
  initiated_at: nil,
  metadata: nil,
  outcome: nil,
  payment_method_details: nil,
  processor_details: nil,
  shipping_details: nil
)
  @amount_requested = amount_requested
  @customer_details = customer_details
  @customer_presence = customer_presence
  @description = description
  @expand = expand
  @failed = failed
  @guaranteed = guaranteed
  @initiated_at = initiated_at
  @metadata = 
  @outcome = outcome
  @payment_method_details = payment_method_details
  @processor_details = processor_details
  @shipping_details = shipping_details
end

Instance Attribute Details

#amount_requestedObject

The amount you initially requested for this payment.



280
281
282
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 280

def amount_requested
  @amount_requested
end

#customer_detailsObject

Customer information for this payment.



282
283
284
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 282

def customer_details
  @customer_details
end

#customer_presenceObject

Indicates whether the customer was present in your checkout flow during this payment.



284
285
286
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 284

def customer_presence
  @customer_presence
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



286
287
288
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 286

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



288
289
290
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 288

def expand
  @expand
end

#failedObject

Information about the payment attempt failure.



290
291
292
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 290

def failed
  @failed
end

#guaranteedObject

Information about the payment attempt guarantee.



292
293
294
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 292

def guaranteed
  @guaranteed
end

#initiated_atObject

When the reported payment was initiated. Measured in seconds since the Unix epoch.



294
295
296
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 294

def initiated_at
  @initiated_at
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.



296
297
298
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 296

def 
  @metadata
end

#outcomeObject

The outcome of the reported payment.



298
299
300
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 298

def outcome
  @outcome
end

#payment_method_detailsObject

Information about the Payment Method debited for this payment.



300
301
302
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 300

def payment_method_details
  @payment_method_details
end

#processor_detailsObject

Processor information for this payment.



302
303
304
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 302

def processor_details
  @processor_details
end

#shipping_detailsObject

Shipping information for this payment.



304
305
306
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 304

def shipping_details
  @shipping_details
end