Class: Stripe::PaymentRecordReportPaymentParams::Failed::ProcessorDetails::Custom

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_record_report_payment_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(payment_reference: nil) ⇒ Custom

Returns a new instance of Custom.



42
43
44
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 42

def initialize(payment_reference: nil)
  @payment_reference = payment_reference
end

Instance Attribute Details

#payment_referenceObject

An opaque string for manual reconciliation of this payment, for example a check number or a payment processor ID.



40
41
42
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 40

def payment_reference
  @payment_reference
end