Class: Stripe::PaymentRecordReportPaymentParams::PaymentMethodDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecordReportPaymentParams::PaymentMethodDetails
- Defined in:
- lib/stripe/params/payment_record_report_payment_params.rb
Defined Under Namespace
Classes: BillingDetails, Card, Custom
Instance Attribute Summary collapse
-
#billing_details ⇒ Object
The billing details associated with the method of payment.
-
#card ⇒ Object
Information about the card payment method used to make this payment.
-
#custom ⇒ Object
Information about the custom (user-defined) payment method used to make this payment.
-
#payment_method ⇒ Object
ID of the Stripe Payment Method used to make this payment.
-
#type ⇒ Object
The type of the payment method details.
Instance Method Summary collapse
-
#initialize(billing_details: nil, card: nil, custom: nil, payment_method: nil, type: nil) ⇒ PaymentMethodDetails
constructor
A new instance of PaymentMethodDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(billing_details: nil, card: nil, custom: nil, payment_method: nil, type: nil) ⇒ PaymentMethodDetails
Returns a new instance of PaymentMethodDetails.
206 207 208 209 210 211 212 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 206 def initialize(billing_details: nil, card: nil, custom: nil, payment_method: nil, type: nil) @billing_details = billing_details @card = card @custom = custom @payment_method = payment_method @type = type end |
Instance Attribute Details
#billing_details ⇒ Object
The billing details associated with the method of payment.
196 197 198 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 196 def billing_details @billing_details end |
#card ⇒ Object
Information about the card payment method used to make this payment.
198 199 200 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 198 def card @card end |
#custom ⇒ Object
Information about the custom (user-defined) payment method used to make this payment.
200 201 202 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 200 def custom @custom end |
#payment_method ⇒ Object
ID of the Stripe Payment Method used to make this payment.
202 203 204 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 202 def payment_method @payment_method end |
#type ⇒ Object
The type of the payment method details. An additional hash is included on the payment_method_details with a name matching this value. It contains additional information specific to the type.
204 205 206 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 204 def type @type end |