Class: Stripe::PaymentRecordReportPaymentParams::PaymentMethodDetails::BillingDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_record_report_payment_params.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(address: nil, email: nil, name: nil, phone: nil) ⇒ BillingDetails

Returns a new instance of BillingDetails.



153
154
155
156
157
158
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 153

def initialize(address: nil, email: nil, name: nil, phone: nil)
  @address = address
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#addressObject

The billing address associated with the method of payment.



145
146
147
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 145

def address
  @address
end

#emailObject

The billing email associated with the method of payment.



147
148
149
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 147

def email
  @email
end

#nameObject

The billing name associated with the method of payment.



149
150
151
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 149

def name
  @name
end

#phoneObject

The billing phone number associated with the method of payment.



151
152
153
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 151

def phone
  @phone
end