Class: Stripe::PaymentRecordService::ReportPaymentAttemptCanceledParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecordService::ReportPaymentAttemptCanceledParams
- Defined in:
- lib/stripe/services/payment_record_service.rb
Instance Attribute Summary collapse
-
#canceled_at ⇒ Object
When the reported payment was canceled.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Attribute for param field metadata.
Instance Method Summary collapse
-
#initialize(canceled_at: nil, expand: nil, metadata: nil) ⇒ ReportPaymentAttemptCanceledParams
constructor
A new instance of ReportPaymentAttemptCanceledParams.
Methods inherited from RequestParams
Constructor Details
#initialize(canceled_at: nil, expand: nil, metadata: nil) ⇒ ReportPaymentAttemptCanceledParams
Returns a new instance of ReportPaymentAttemptCanceledParams.
205 206 207 208 209 |
# File 'lib/stripe/services/payment_record_service.rb', line 205 def initialize(canceled_at: nil, expand: nil, metadata: nil) @canceled_at = canceled_at @expand = @metadata = end |
Instance Attribute Details
#canceled_at ⇒ Object
When the reported payment was canceled. Measured in seconds since the Unix epoch.
199 200 201 |
# File 'lib/stripe/services/payment_record_service.rb', line 199 def canceled_at @canceled_at end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
201 202 203 |
# File 'lib/stripe/services/payment_record_service.rb', line 201 def @expand end |
#metadata ⇒ Object
Attribute for param field metadata
203 204 205 |
# File 'lib/stripe/services/payment_record_service.rb', line 203 def @metadata end |