Class: Stripe::PaymentRecordService::ReportPaymentAttemptFailedParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecordService::ReportPaymentAttemptFailedParams
- Defined in:
- lib/stripe/services/payment_record_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#failed_at ⇒ Object
When the reported payment failed.
-
#metadata ⇒ Object
Attribute for param field metadata.
Instance Method Summary collapse
-
#initialize(expand: nil, failed_at: nil, metadata: nil) ⇒ ReportPaymentAttemptFailedParams
constructor
A new instance of ReportPaymentAttemptFailedParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, failed_at: nil, metadata: nil) ⇒ ReportPaymentAttemptFailedParams
Returns a new instance of ReportPaymentAttemptFailedParams.
220 221 222 223 224 |
# File 'lib/stripe/services/payment_record_service.rb', line 220 def initialize(expand: nil, failed_at: nil, metadata: nil) @expand = @failed_at = failed_at @metadata = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
214 215 216 |
# File 'lib/stripe/services/payment_record_service.rb', line 214 def @expand end |
#failed_at ⇒ Object
When the reported payment failed. Measured in seconds since the Unix epoch.
216 217 218 |
# File 'lib/stripe/services/payment_record_service.rb', line 216 def failed_at @failed_at end |
#metadata ⇒ Object
Attribute for param field metadata
218 219 220 |
# File 'lib/stripe/services/payment_record_service.rb', line 218 def @metadata end |