Class: Stripe::PaymentRecordService::ReportPaymentAttemptGuaranteedParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecordService::ReportPaymentAttemptGuaranteedParams
- Defined in:
- lib/stripe/services/payment_record_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#guaranteed_at ⇒ Object
When the reported payment was guaranteed.
-
#metadata ⇒ Object
Attribute for param field metadata.
Instance Method Summary collapse
-
#initialize(expand: nil, guaranteed_at: nil, metadata: nil) ⇒ ReportPaymentAttemptGuaranteedParams
constructor
A new instance of ReportPaymentAttemptGuaranteedParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, guaranteed_at: nil, metadata: nil) ⇒ ReportPaymentAttemptGuaranteedParams
Returns a new instance of ReportPaymentAttemptGuaranteedParams.
235 236 237 238 239 |
# File 'lib/stripe/services/payment_record_service.rb', line 235 def initialize(expand: nil, guaranteed_at: nil, metadata: nil) @expand = @guaranteed_at = guaranteed_at @metadata = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
229 230 231 |
# File 'lib/stripe/services/payment_record_service.rb', line 229 def @expand end |
#guaranteed_at ⇒ Object
When the reported payment was guaranteed. Measured in seconds since the Unix epoch.
231 232 233 |
# File 'lib/stripe/services/payment_record_service.rb', line 231 def guaranteed_at @guaranteed_at end |
#metadata ⇒ Object
Attribute for param field metadata
233 234 235 |
# File 'lib/stripe/services/payment_record_service.rb', line 233 def @metadata end |