Class: Stripe::PaymentRecordService::ReportPaymentAttemptParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecordService::ReportPaymentAttemptParams
- Defined in:
- lib/stripe/services/payment_record_service.rb
Defined Under Namespace
Classes: Failed, Guaranteed, PaymentMethodDetails, ShippingDetails
Instance Attribute Summary collapse
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#failed ⇒ Object
Information about the payment attempt failure.
-
#guaranteed ⇒ Object
Information about the payment attempt guarantee.
-
#initiated_at ⇒ Object
When the reported payment was initiated.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#outcome ⇒ Object
The outcome of the reported payment.
-
#payment_method_details ⇒ Object
Information about the Payment Method debited for this payment.
-
#shipping_details ⇒ Object
Shipping information for this payment.
Instance Method Summary collapse
-
#initialize(description: nil, expand: nil, failed: nil, guaranteed: nil, initiated_at: nil, metadata: nil, outcome: nil, payment_method_details: nil, shipping_details: nil) ⇒ ReportPaymentAttemptParams
constructor
A new instance of ReportPaymentAttemptParams.
Methods inherited from RequestParams
Constructor Details
#initialize(description: nil, expand: nil, failed: nil, guaranteed: nil, initiated_at: nil, metadata: nil, outcome: nil, payment_method_details: nil, shipping_details: nil) ⇒ ReportPaymentAttemptParams
Returns a new instance of ReportPaymentAttemptParams.
174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/stripe/services/payment_record_service.rb', line 174 def initialize( description: nil, expand: nil, failed: nil, guaranteed: nil, initiated_at: nil, metadata: nil, outcome: nil, payment_method_details: nil, shipping_details: nil ) @description = description @expand = @failed = failed @guaranteed = guaranteed @initiated_at = initiated_at @metadata = @outcome = outcome @payment_method_details = payment_method_details @shipping_details = shipping_details end |
Instance Attribute Details
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
156 157 158 |
# File 'lib/stripe/services/payment_record_service.rb', line 156 def description @description end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
158 159 160 |
# File 'lib/stripe/services/payment_record_service.rb', line 158 def @expand end |
#failed ⇒ Object
Information about the payment attempt failure.
160 161 162 |
# File 'lib/stripe/services/payment_record_service.rb', line 160 def failed @failed end |
#guaranteed ⇒ Object
Information about the payment attempt guarantee.
162 163 164 |
# File 'lib/stripe/services/payment_record_service.rb', line 162 def guaranteed @guaranteed end |
#initiated_at ⇒ Object
When the reported payment was initiated. Measured in seconds since the Unix epoch.
164 165 166 |
# File 'lib/stripe/services/payment_record_service.rb', line 164 def initiated_at @initiated_at end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
166 167 168 |
# File 'lib/stripe/services/payment_record_service.rb', line 166 def @metadata end |
#outcome ⇒ Object
The outcome of the reported payment.
168 169 170 |
# File 'lib/stripe/services/payment_record_service.rb', line 168 def outcome @outcome end |
#payment_method_details ⇒ Object
Information about the Payment Method debited for this payment.
170 171 172 |
# File 'lib/stripe/services/payment_record_service.rb', line 170 def payment_method_details @payment_method_details end |
#shipping_details ⇒ Object
Shipping information for this payment.
172 173 174 |
# File 'lib/stripe/services/payment_record_service.rb', line 172 def shipping_details @shipping_details end |