Class: Stripe::PaymentRecordService::ReportPaymentAttemptParams::PaymentMethodDetails::BillingDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecordService::ReportPaymentAttemptParams::PaymentMethodDetails::BillingDetails
- Defined in:
- lib/stripe/services/payment_record_service.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
The billing address associated with the method of payment.
-
#email ⇒ Object
The billing email associated with the method of payment.
-
#name ⇒ Object
The billing name associated with the method of payment.
-
#phone ⇒ Object
The billing phone number associated with the method of payment.
Instance Method Summary collapse
-
#initialize(address: nil, email: nil, name: nil, phone: nil) ⇒ BillingDetails
constructor
A new instance of BillingDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, email: nil, name: nil, phone: nil) ⇒ BillingDetails
Returns a new instance of BillingDetails.
75 76 77 78 79 80 |
# File 'lib/stripe/services/payment_record_service.rb', line 75 def initialize(address: nil, email: nil, name: nil, phone: nil) @address = address @email = email @name = name @phone = phone end |
Instance Attribute Details
#address ⇒ Object
The billing address associated with the method of payment.
67 68 69 |
# File 'lib/stripe/services/payment_record_service.rb', line 67 def address @address end |
#email ⇒ Object
The billing email associated with the method of payment.
69 70 71 |
# File 'lib/stripe/services/payment_record_service.rb', line 69 def email @email end |
#name ⇒ Object
The billing name associated with the method of payment.
71 72 73 |
# File 'lib/stripe/services/payment_record_service.rb', line 71 def name @name end |
#phone ⇒ Object
The billing phone number associated with the method of payment.
73 74 75 |
# File 'lib/stripe/services/payment_record_service.rb', line 73 def phone @phone end |