Class: Stripe::PaymentRecordService::ReportPaymentAttemptParams::PaymentMethodDetails::Custom
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecordService::ReportPaymentAttemptParams::PaymentMethodDetails::Custom
- Defined in:
- lib/stripe/services/payment_record_service.rb
Instance Attribute Summary collapse
-
#display_name ⇒ Object
Display name for the custom (user-defined) payment method type used to make this payment.
-
#type ⇒ Object
The custom payment method type associated with this payment.
Instance Method Summary collapse
-
#initialize(display_name: nil, type: nil) ⇒ Custom
constructor
A new instance of Custom.
Methods inherited from RequestParams
Constructor Details
#initialize(display_name: nil, type: nil) ⇒ Custom
Returns a new instance of Custom.
89 90 91 92 |
# File 'lib/stripe/services/payment_record_service.rb', line 89 def initialize(display_name: nil, type: nil) @display_name = display_name @type = type end |
Instance Attribute Details
#display_name ⇒ Object
Display name for the custom (user-defined) payment method type used to make this payment.
85 86 87 |
# File 'lib/stripe/services/payment_record_service.rb', line 85 def display_name @display_name end |
#type ⇒ Object
The custom payment method type associated with this payment.
87 88 89 |
# File 'lib/stripe/services/payment_record_service.rb', line 87 def type @type end |