Class: Stripe::PaymentRecordService::ReportPaymentParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_record_service.rb

Defined Under Namespace

Classes: AmountRequested, CustomerDetails, Failed, Guaranteed, PaymentMethodDetails, ProcessorDetails, ShippingDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_requested: nil, customer_details: nil, customer_presence: nil, description: nil, expand: nil, failed: nil, guaranteed: nil, initiated_at: nil, metadata: nil, outcome: nil, payment_method_details: nil, processor_details: nil, shipping_details: nil) ⇒ ReportPaymentParams

Returns a new instance of ReportPaymentParams.



459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
# File 'lib/stripe/services/payment_record_service.rb', line 459

def initialize(
  amount_requested: nil,
  customer_details: nil,
  customer_presence: nil,
  description: nil,
  expand: nil,
  failed: nil,
  guaranteed: nil,
  initiated_at: nil,
  metadata: nil,
  outcome: nil,
  payment_method_details: nil,
  processor_details: nil,
  shipping_details: nil
)
  @amount_requested = amount_requested
  @customer_details = customer_details
  @customer_presence = customer_presence
  @description = description
  @expand = expand
  @failed = failed
  @guaranteed = guaranteed
  @initiated_at = initiated_at
  @metadata = 
  @outcome = outcome
  @payment_method_details = payment_method_details
  @processor_details = processor_details
  @shipping_details = shipping_details
end

Instance Attribute Details

#amount_requestedObject

The amount you initially requested for this payment.



433
434
435
# File 'lib/stripe/services/payment_record_service.rb', line 433

def amount_requested
  @amount_requested
end

#customer_detailsObject

Customer information for this payment.



435
436
437
# File 'lib/stripe/services/payment_record_service.rb', line 435

def customer_details
  @customer_details
end

#customer_presenceObject

Indicates whether the customer was present in your checkout flow during this payment.



437
438
439
# File 'lib/stripe/services/payment_record_service.rb', line 437

def customer_presence
  @customer_presence
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



439
440
441
# File 'lib/stripe/services/payment_record_service.rb', line 439

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



441
442
443
# File 'lib/stripe/services/payment_record_service.rb', line 441

def expand
  @expand
end

#failedObject

Information about the payment attempt failure.



443
444
445
# File 'lib/stripe/services/payment_record_service.rb', line 443

def failed
  @failed
end

#guaranteedObject

Information about the payment attempt guarantee.



445
446
447
# File 'lib/stripe/services/payment_record_service.rb', line 445

def guaranteed
  @guaranteed
end

#initiated_atObject

When the reported payment was initiated. Measured in seconds since the Unix epoch.



447
448
449
# File 'lib/stripe/services/payment_record_service.rb', line 447

def initiated_at
  @initiated_at
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



449
450
451
# File 'lib/stripe/services/payment_record_service.rb', line 449

def 
  @metadata
end

#outcomeObject

The outcome of the reported payment.



451
452
453
# File 'lib/stripe/services/payment_record_service.rb', line 451

def outcome
  @outcome
end

#payment_method_detailsObject

Information about the Payment Method debited for this payment.



453
454
455
# File 'lib/stripe/services/payment_record_service.rb', line 453

def payment_method_details
  @payment_method_details
end

#processor_detailsObject

Processor information for this payment.



455
456
457
# File 'lib/stripe/services/payment_record_service.rb', line 455

def processor_details
  @processor_details
end

#shipping_detailsObject

Shipping information for this payment.



457
458
459
# File 'lib/stripe/services/payment_record_service.rb', line 457

def shipping_details
  @shipping_details
end