Class: Stripe::PaymentRecordService::ReportPaymentParams::AmountRequested
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecordService::ReportPaymentParams::AmountRequested
- Defined in:
- lib/stripe/services/payment_record_service.rb
Instance Attribute Summary collapse
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#value ⇒ Object
A positive integer representing the amount in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal) e.g., 100 cents for $1.00 or 100 for ¥100, a zero-decimal currency).
Instance Method Summary collapse
-
#initialize(currency: nil, value: nil) ⇒ AmountRequested
constructor
A new instance of AmountRequested.
Methods inherited from RequestParams
Constructor Details
#initialize(currency: nil, value: nil) ⇒ AmountRequested
Returns a new instance of AmountRequested.
283 284 285 286 |
# File 'lib/stripe/services/payment_record_service.rb', line 283 def initialize(currency: nil, value: nil) @currency = currency @value = value end |
Instance Attribute Details
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
278 279 280 |
# File 'lib/stripe/services/payment_record_service.rb', line 278 def currency @currency end |
#value ⇒ Object
A positive integer representing the amount in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal) e.g., 100 cents for $1.00 or 100 for ¥100, a zero-decimal currency).
281 282 283 |
# File 'lib/stripe/services/payment_record_service.rb', line 281 def value @value end |