Class: Stripe::PaymentRecordService::ReportPaymentParams::PaymentMethodDetails::BillingDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_record_service.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, email: nil, name: nil, phone: nil) ⇒ BillingDetails

Returns a new instance of BillingDetails.



332
333
334
335
336
337
# File 'lib/stripe/services/payment_record_service.rb', line 332

def initialize(address: nil, email: nil, name: nil, phone: nil)
  @address = address
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#addressObject

The billing address associated with the method of payment.



324
325
326
# File 'lib/stripe/services/payment_record_service.rb', line 324

def address
  @address
end

#emailObject

The billing email associated with the method of payment.



326
327
328
# File 'lib/stripe/services/payment_record_service.rb', line 326

def email
  @email
end

#nameObject

The billing name associated with the method of payment.



328
329
330
# File 'lib/stripe/services/payment_record_service.rb', line 328

def name
  @name
end

#phoneObject

The billing phone number associated with the method of payment.



330
331
332
# File 'lib/stripe/services/payment_record_service.rb', line 330

def phone
  @phone
end