Class: Stripe::PaymentRecordService::ReportPaymentParams::PaymentMethodDetails::Custom
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecordService::ReportPaymentParams::PaymentMethodDetails::Custom
- Defined in:
- lib/stripe/services/payment_record_service.rb
Instance Attribute Summary collapse
-
#display_name ⇒ Object
Display name for the custom (user-defined) payment method type used to make this payment.
-
#type ⇒ Object
The custom payment method type associated with this payment.
Instance Method Summary collapse
-
#initialize(display_name: nil, type: nil) ⇒ Custom
constructor
A new instance of Custom.
Methods inherited from RequestParams
Constructor Details
#initialize(display_name: nil, type: nil) ⇒ Custom
Returns a new instance of Custom.
392 393 394 395 |
# File 'lib/stripe/services/payment_record_service.rb', line 392 def initialize(display_name: nil, type: nil) @display_name = display_name @type = type end |
Instance Attribute Details
#display_name ⇒ Object
Display name for the custom (user-defined) payment method type used to make this payment.
387 388 389 |
# File 'lib/stripe/services/payment_record_service.rb', line 387 def display_name @display_name end |
#type ⇒ Object
The custom payment method type associated with this payment.
390 391 392 |
# File 'lib/stripe/services/payment_record_service.rb', line 390 def type @type end |