Class: Stripe::PaymentRecordService::ReportPaymentParams::ProcessorDetails::Custom

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_record_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(payment_reference: nil) ⇒ Custom

Returns a new instance of Custom.



373
374
375
# File 'lib/stripe/services/payment_record_service.rb', line 373

def initialize(payment_reference: nil)
  @payment_reference = payment_reference
end

Instance Attribute Details

#payment_referenceObject

An opaque string for manual reconciliation of this payment, for example a check number or a payment processor ID.



371
372
373
# File 'lib/stripe/services/payment_record_service.rb', line 371

def payment_reference
  @payment_reference
end