Class: Stripe::Person::Relationship

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/person.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#authorizerObject (readonly)

Whether the person is the authorizer of the account’s representative.



239
240
241
# File 'lib/stripe/resources/person.rb', line 239

def authorizer
  @authorizer
end

#directorObject (readonly)

Whether the person is a director of the account’s legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



241
242
243
# File 'lib/stripe/resources/person.rb', line 241

def director
  @director
end

#executiveObject (readonly)

Whether the person has significant responsibility to control, manage, or direct the organization.



243
244
245
# File 'lib/stripe/resources/person.rb', line 243

def executive
  @executive
end

Whether the person is the legal guardian of the account’s representative.



245
246
247
# File 'lib/stripe/resources/person.rb', line 245

def legal_guardian
  @legal_guardian
end

#ownerObject (readonly)

Whether the person is an owner of the account’s legal entity.



247
248
249
# File 'lib/stripe/resources/person.rb', line 247

def owner
  @owner
end

#percent_ownershipObject (readonly)

The percent owned by the person of the account’s legal entity.



249
250
251
# File 'lib/stripe/resources/person.rb', line 249

def percent_ownership
  @percent_ownership
end

#representativeObject (readonly)

Whether the person is authorized as the primary representative of the account. This is the person nominated by the business to provide information about themselves, and general information about the account. There can only be one representative at any given time. At the time the account is created, this person should be set to the person responsible for opening the account.



251
252
253
# File 'lib/stripe/resources/person.rb', line 251

def representative
  @representative
end

#titleObject (readonly)

The person’s title (e.g., CEO, Support Engineer).



253
254
255
# File 'lib/stripe/resources/person.rb', line 253

def title
  @title
end

Class Method Details

.field_remappingsObject



259
260
261
# File 'lib/stripe/resources/person.rb', line 259

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



255
256
257
# File 'lib/stripe/resources/person.rb', line 255

def self.inner_class_types
  @inner_class_types = {}
end