Class: Stripe::Plan::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Plan::ListParams
- Defined in:
- lib/stripe/resources/plan.rb
Defined Under Namespace
Classes: Created
Instance Attribute Summary collapse
-
#active ⇒ Object
Only return plans that are active or inactive (e.g., pass ‘false` to list all inactive plans).
-
#created ⇒ Object
A filter on the list, based on the object ‘created` field.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#product ⇒ Object
Only return plans for the given product.
-
#starting_after ⇒ Object
A cursor for use in pagination.
Instance Method Summary collapse
-
#initialize(active: nil, created: nil, ending_before: nil, expand: nil, limit: nil, product: nil, starting_after: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(active: nil, created: nil, ending_before: nil, expand: nil, limit: nil, product: nil, starting_after: nil) ⇒ ListParams
Returns a new instance of ListParams.
126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/stripe/resources/plan.rb', line 126 def initialize( active: nil, created: nil, ending_before: nil, expand: nil, limit: nil, product: nil, starting_after: nil ) @active = active @created = created @ending_before = ending_before @expand = @limit = limit @product = product @starting_after = starting_after end |
Instance Attribute Details
#active ⇒ Object
Only return plans that are active or inactive (e.g., pass ‘false` to list all inactive plans).
112 113 114 |
# File 'lib/stripe/resources/plan.rb', line 112 def active @active end |
#created ⇒ Object
A filter on the list, based on the object ‘created` field. The value can be a string with an integer Unix timestamp, or it can be a dictionary with a number of different query options.
114 115 116 |
# File 'lib/stripe/resources/plan.rb', line 114 def created @created end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
116 117 118 |
# File 'lib/stripe/resources/plan.rb', line 116 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
118 119 120 |
# File 'lib/stripe/resources/plan.rb', line 118 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
120 121 122 |
# File 'lib/stripe/resources/plan.rb', line 120 def limit @limit end |
#product ⇒ Object
Only return plans for the given product.
122 123 124 |
# File 'lib/stripe/resources/plan.rb', line 122 def product @product end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
124 125 126 |
# File 'lib/stripe/resources/plan.rb', line 124 def starting_after @starting_after end |