Class: Stripe::PlanService::CreateParams::Product
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PlanService::CreateParams::Product
- Defined in:
- lib/stripe/services/plan_service.rb
Instance Attribute Summary collapse
-
#active ⇒ Object
Whether the product is currently available for purchase.
-
#id ⇒ Object
The identifier for the product.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#name ⇒ Object
The product’s name, meant to be displayable to the customer.
-
#statement_descriptor ⇒ Object
An arbitrary string to be displayed on your customer’s credit card or bank statement.
-
#tax_code ⇒ Object
A [tax code](stripe.com/docs/tax/tax-categories) ID.
-
#unit_label ⇒ Object
A label that represents units of this product.
Instance Method Summary collapse
-
#initialize(active: nil, id: nil, metadata: nil, name: nil, statement_descriptor: nil, tax_code: nil, unit_label: nil) ⇒ Product
constructor
A new instance of Product.
Methods inherited from RequestParams
Constructor Details
#initialize(active: nil, id: nil, metadata: nil, name: nil, statement_descriptor: nil, tax_code: nil, unit_label: nil) ⇒ Product
Returns a new instance of Product.
119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/stripe/services/plan_service.rb', line 119 def initialize( active: nil, id: nil, metadata: nil, name: nil, statement_descriptor: nil, tax_code: nil, unit_label: nil ) @active = active @id = id @metadata = @name = name @statement_descriptor = statement_descriptor @tax_code = tax_code @unit_label = unit_label end |
Instance Attribute Details
#active ⇒ Object
Whether the product is currently available for purchase. Defaults to ‘true`.
103 104 105 |
# File 'lib/stripe/services/plan_service.rb', line 103 def active @active end |
#id ⇒ Object
The identifier for the product. Must be unique. If not provided, an identifier will be randomly generated.
105 106 107 |
# File 'lib/stripe/services/plan_service.rb', line 105 def id @id end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
107 108 109 |
# File 'lib/stripe/services/plan_service.rb', line 107 def @metadata end |
#name ⇒ Object
The product’s name, meant to be displayable to the customer.
109 110 111 |
# File 'lib/stripe/services/plan_service.rb', line 109 def name @name end |
#statement_descriptor ⇒ Object
An arbitrary string to be displayed on your customer’s credit card or bank statement. While most banks display this information consistently, some may display it incorrectly or not at all.
This may be up to 22 characters. The statement description may not include ‘<`, `>`, ``, `“`, `’‘ characters, and will appear on your customer’s statement in capital letters. Non-ASCII characters are automatically stripped.
113 114 115 |
# File 'lib/stripe/services/plan_service.rb', line 113 def statement_descriptor @statement_descriptor end |
#tax_code ⇒ Object
A [tax code](stripe.com/docs/tax/tax-categories) ID.
115 116 117 |
# File 'lib/stripe/services/plan_service.rb', line 115 def tax_code @tax_code end |
#unit_label ⇒ Object
A label that represents units of this product. When set, this will be included in customers’ receipts, invoices, Checkout, and the customer portal.
117 118 119 |
# File 'lib/stripe/services/plan_service.rb', line 117 def unit_label @unit_label end |