Class: Stripe::PlanService::CreateParams::Tier

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/plan_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(flat_amount: nil, flat_amount_decimal: nil, unit_amount: nil, unit_amount_decimal: nil, up_to: nil) ⇒ Tier

Returns a new instance of Tier.



151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/stripe/services/plan_service.rb', line 151

def initialize(
  flat_amount: nil,
  flat_amount_decimal: nil,
  unit_amount: nil,
  unit_amount_decimal: nil,
  up_to: nil
)
  @flat_amount = flat_amount
  @flat_amount_decimal = flat_amount_decimal
  @unit_amount = unit_amount
  @unit_amount_decimal = unit_amount_decimal
  @up_to = up_to
end

Instance Attribute Details

#flat_amountObject

The flat billing amount for an entire tier, regardless of the number of units in the tier.



141
142
143
# File 'lib/stripe/services/plan_service.rb', line 141

def flat_amount
  @flat_amount
end

#flat_amount_decimalObject

Same as ‘flat_amount`, but accepts a decimal value representing an integer in the minor units of the currency. Only one of `flat_amount` and `flat_amount_decimal` can be set.



143
144
145
# File 'lib/stripe/services/plan_service.rb', line 143

def flat_amount_decimal
  @flat_amount_decimal
end

#unit_amountObject

The per unit billing amount for each individual unit for which this tier applies.



145
146
147
# File 'lib/stripe/services/plan_service.rb', line 145

def unit_amount
  @unit_amount
end

#unit_amount_decimalObject

Same as ‘unit_amount`, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places. Only one of `unit_amount` and `unit_amount_decimal` can be set.



147
148
149
# File 'lib/stripe/services/plan_service.rb', line 147

def unit_amount_decimal
  @unit_amount_decimal
end

#up_toObject

Specifies the upper bound of this tier. The lower bound of a tier is the upper bound of the previous tier adding one. Use ‘inf` to define a fallback tier.



149
150
151
# File 'lib/stripe/services/plan_service.rb', line 149

def up_to
  @up_to
end