Class: Stripe::Price::CreateParams::CurrencyOptions::CustomUnitAmount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Price::CreateParams::CurrencyOptions::CustomUnitAmount
- Defined in:
- lib/stripe/resources/price.rb
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Pass in ‘true` to enable `custom_unit_amount`, otherwise omit `custom_unit_amount`.
-
#maximum ⇒ Object
The maximum unit amount the customer can specify for this item.
-
#minimum ⇒ Object
The minimum unit amount the customer can specify for this item.
-
#preset ⇒ Object
The starting unit amount which can be updated by the customer.
Instance Method Summary collapse
-
#initialize(enabled: nil, maximum: nil, minimum: nil, preset: nil) ⇒ CustomUnitAmount
constructor
A new instance of CustomUnitAmount.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, maximum: nil, minimum: nil, preset: nil) ⇒ CustomUnitAmount
Returns a new instance of CustomUnitAmount.
246 247 248 249 250 251 |
# File 'lib/stripe/resources/price.rb', line 246 def initialize(enabled: nil, maximum: nil, minimum: nil, preset: nil) @enabled = enabled @maximum = maximum @minimum = minimum @preset = preset end |
Instance Attribute Details
#enabled ⇒ Object
Pass in ‘true` to enable `custom_unit_amount`, otherwise omit `custom_unit_amount`.
235 236 237 |
# File 'lib/stripe/resources/price.rb', line 235 def enabled @enabled end |
#maximum ⇒ Object
The maximum unit amount the customer can specify for this item.
238 239 240 |
# File 'lib/stripe/resources/price.rb', line 238 def maximum @maximum end |
#minimum ⇒ Object
The minimum unit amount the customer can specify for this item. Must be at least the minimum charge amount.
241 242 243 |
# File 'lib/stripe/resources/price.rb', line 241 def minimum @minimum end |
#preset ⇒ Object
The starting unit amount which can be updated by the customer.
244 245 246 |
# File 'lib/stripe/resources/price.rb', line 244 def preset @preset end |