Class: Stripe::Price::CustomUnitAmount
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Price::CustomUnitAmount
- Defined in:
- lib/stripe/resources/price.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#maximum ⇒ Object
readonly
The maximum unit amount the customer can specify for this item.
-
#minimum ⇒ Object
readonly
The minimum unit amount the customer can specify for this item.
-
#preset ⇒ Object
readonly
The starting unit amount which can be updated by the customer.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#maximum ⇒ Object (readonly)
The maximum unit amount the customer can specify for this item.
102 103 104 |
# File 'lib/stripe/resources/price.rb', line 102 def maximum @maximum end |
#minimum ⇒ Object (readonly)
The minimum unit amount the customer can specify for this item. Must be at least the minimum charge amount.
104 105 106 |
# File 'lib/stripe/resources/price.rb', line 104 def minimum @minimum end |
#preset ⇒ Object (readonly)
The starting unit amount which can be updated by the customer.
106 107 108 |
# File 'lib/stripe/resources/price.rb', line 106 def preset @preset end |
Class Method Details
.field_remappings ⇒ Object
112 113 114 |
# File 'lib/stripe/resources/price.rb', line 112 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
108 109 110 |
# File 'lib/stripe/resources/price.rb', line 108 def self.inner_class_types @inner_class_types = {} end |