Class: Stripe::Price::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/price.rb

Defined Under Namespace

Classes: Created, Recurring

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(active: nil, created: nil, currency: nil, ending_before: nil, expand: nil, limit: nil, lookup_keys: nil, product: nil, recurring: nil, starting_after: nil, type: nil) ⇒ ListParams

Returns a new instance of ListParams.



227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
# File 'lib/stripe/resources/price.rb', line 227

def initialize(
  active: nil,
  created: nil,
  currency: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  lookup_keys: nil,
  product: nil,
  recurring: nil,
  starting_after: nil,
  type: nil
)
  @active = active
  @created = created
  @currency = currency
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @lookup_keys = lookup_keys
  @product = product
  @recurring = recurring
  @starting_after = starting_after
  @type = type
end

Instance Attribute Details

#activeObject

Only return prices that are active or inactive (e.g., pass ‘false` to list all inactive prices).



205
206
207
# File 'lib/stripe/resources/price.rb', line 205

def active
  @active
end

#createdObject

A filter on the list, based on the object ‘created` field. The value can be a string with an integer Unix timestamp, or it can be a dictionary with a number of different query options.



207
208
209
# File 'lib/stripe/resources/price.rb', line 207

def created
  @created
end

#currencyObject

Only return prices for the given currency.



209
210
211
# File 'lib/stripe/resources/price.rb', line 209

def currency
  @currency
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



211
212
213
# File 'lib/stripe/resources/price.rb', line 211

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



213
214
215
# File 'lib/stripe/resources/price.rb', line 213

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



215
216
217
# File 'lib/stripe/resources/price.rb', line 215

def limit
  @limit
end

#lookup_keysObject

Only return the price with these lookup_keys, if any exist. You can specify up to 10 lookup_keys.



217
218
219
# File 'lib/stripe/resources/price.rb', line 217

def lookup_keys
  @lookup_keys
end

#productObject

Only return prices for the given product.



219
220
221
# File 'lib/stripe/resources/price.rb', line 219

def product
  @product
end

#recurringObject

Only return prices with these recurring fields.



221
222
223
# File 'lib/stripe/resources/price.rb', line 221

def recurring
  @recurring
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



223
224
225
# File 'lib/stripe/resources/price.rb', line 223

def starting_after
  @starting_after
end

#typeObject

Only return prices of type ‘recurring` or `one_time`.



225
226
227
# File 'lib/stripe/resources/price.rb', line 225

def type
  @type
end