Class: Stripe::Price::Recurring
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Price::Recurring
- Defined in:
- lib/stripe/resources/price.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#interval ⇒ Object
readonly
The frequency at which a subscription is billed.
-
#interval_count ⇒ Object
readonly
The number of intervals (specified in the ‘interval` attribute) between subscription billings.
-
#meter ⇒ Object
readonly
The meter tracking the usage of a metered price.
-
#trial_period_days ⇒ Object
readonly
Default number of trial days when subscribing a customer to this price using [‘trial_from_plan=true`](docs.stripe.com/api#create_subscription-trial_from_plan).
-
#usage_type ⇒ Object
readonly
Configures how the quantity per period should be determined.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#interval ⇒ Object (readonly)
The frequency at which a subscription is billed. One of ‘day`, `week`, `month` or `year`.
136 137 138 |
# File 'lib/stripe/resources/price.rb', line 136 def interval @interval end |
#interval_count ⇒ Object (readonly)
The number of intervals (specified in the ‘interval` attribute) between subscription billings. For example, `interval=month` and `interval_count=3` bills every 3 months.
138 139 140 |
# File 'lib/stripe/resources/price.rb', line 138 def interval_count @interval_count end |
#meter ⇒ Object (readonly)
The meter tracking the usage of a metered price
140 141 142 |
# File 'lib/stripe/resources/price.rb', line 140 def meter @meter end |
#trial_period_days ⇒ Object (readonly)
Default number of trial days when subscribing a customer to this price using [‘trial_from_plan=true`](docs.stripe.com/api#create_subscription-trial_from_plan).
142 143 144 |
# File 'lib/stripe/resources/price.rb', line 142 def trial_period_days @trial_period_days end |
#usage_type ⇒ Object (readonly)
Configures how the quantity per period should be determined. Can be either ‘metered` or `licensed`. `licensed` automatically bills the `quantity` set when adding it to a subscription. `metered` aggregates the total usage based on usage records. Defaults to `licensed`.
144 145 146 |
# File 'lib/stripe/resources/price.rb', line 144 def usage_type @usage_type end |
Class Method Details
.field_remappings ⇒ Object
150 151 152 |
# File 'lib/stripe/resources/price.rb', line 150 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
146 147 148 |
# File 'lib/stripe/resources/price.rb', line 146 def self.inner_class_types @inner_class_types = {} end |