Class: Stripe::Price::SearchParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/price.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, limit: nil, page: nil, query: nil) ⇒ SearchParams

Returns a new instance of SearchParams.



602
603
604
605
606
607
# File 'lib/stripe/resources/price.rb', line 602

def initialize(expand: nil, limit: nil, page: nil, query: nil)
  @expand = expand
  @limit = limit
  @page = page
  @query = query
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



594
595
596
# File 'lib/stripe/resources/price.rb', line 594

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



596
597
598
# File 'lib/stripe/resources/price.rb', line 596

def limit
  @limit
end

#pageObject

A cursor for pagination across multiple pages of results. Don’t include this parameter on the first call. Use the next_page value returned in a previous response to request subsequent results.



598
599
600
# File 'lib/stripe/resources/price.rb', line 598

def page
  @page
end

#queryObject

The search query string. See [search query language](stripe.com/docs/search#search-query-language) and the list of supported [query fields for prices](stripe.com/docs/search#query-fields-for-prices).



600
601
602
# File 'lib/stripe/resources/price.rb', line 600

def query
  @query
end