Class: Stripe::Price::UpdateParams::CurrencyOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/price.rb

Defined Under Namespace

Classes: CustomUnitAmount, Tier

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(custom_unit_amount: nil, tax_behavior: nil, tiers: nil, unit_amount: nil, unit_amount_decimal: nil) ⇒ CurrencyOptions

Returns a new instance of CurrencyOptions.



536
537
538
539
540
541
542
543
544
545
546
547
548
# File 'lib/stripe/resources/price.rb', line 536

def initialize(
  custom_unit_amount: nil,
  tax_behavior: nil,
  tiers: nil,
  unit_amount: nil,
  unit_amount_decimal: nil
)
  @custom_unit_amount = custom_unit_amount
  @tax_behavior = tax_behavior
  @tiers = tiers
  @unit_amount = unit_amount
  @unit_amount_decimal = unit_amount_decimal
end

Instance Attribute Details

#custom_unit_amountObject

When set, provides configuration for the amount to be adjusted by the customer during Checkout Sessions and Payment Links.



526
527
528
# File 'lib/stripe/resources/price.rb', line 526

def custom_unit_amount
  @custom_unit_amount
end

#tax_behaviorObject

Only required if a [default tax behavior](stripe.com/docs/tax/products-prices-tax-categories-tax-behavior#setting-a-default-tax-behavior-(recommended)) was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`. Once specified as either `inclusive` or `exclusive`, it cannot be changed.



528
529
530
# File 'lib/stripe/resources/price.rb', line 528

def tax_behavior
  @tax_behavior
end

#tiersObject

Each element represents a pricing tier. This parameter requires ‘billing_scheme` to be set to `tiered`. See also the documentation for `billing_scheme`.



530
531
532
# File 'lib/stripe/resources/price.rb', line 530

def tiers
  @tiers
end

#unit_amountObject

A positive integer in cents (or local equivalent) (or 0 for a free price) representing how much to charge.



532
533
534
# File 'lib/stripe/resources/price.rb', line 532

def unit_amount
  @unit_amount
end

#unit_amount_decimalObject

Same as ‘unit_amount`, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places. Only one of `unit_amount` and `unit_amount_decimal` can be set.



534
535
536
# File 'lib/stripe/resources/price.rb', line 534

def unit_amount_decimal
  @unit_amount_decimal
end