Class: Stripe::Price::UpdateParams::CurrencyOptions::CustomUnitAmount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Price::UpdateParams::CurrencyOptions::CustomUnitAmount
- Defined in:
- lib/stripe/resources/price.rb
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Pass in ‘true` to enable `custom_unit_amount`, otherwise omit `custom_unit_amount`.
-
#maximum ⇒ Object
The maximum unit amount the customer can specify for this item.
-
#minimum ⇒ Object
The minimum unit amount the customer can specify for this item.
-
#preset ⇒ Object
The starting unit amount which can be updated by the customer.
Instance Method Summary collapse
-
#initialize(enabled: nil, maximum: nil, minimum: nil, preset: nil) ⇒ CustomUnitAmount
constructor
A new instance of CustomUnitAmount.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, maximum: nil, minimum: nil, preset: nil) ⇒ CustomUnitAmount
Returns a new instance of CustomUnitAmount.
540 541 542 543 544 545 |
# File 'lib/stripe/resources/price.rb', line 540 def initialize(enabled: nil, maximum: nil, minimum: nil, preset: nil) @enabled = enabled @maximum = maximum @minimum = minimum @preset = preset end |
Instance Attribute Details
#enabled ⇒ Object
Pass in ‘true` to enable `custom_unit_amount`, otherwise omit `custom_unit_amount`.
532 533 534 |
# File 'lib/stripe/resources/price.rb', line 532 def enabled @enabled end |
#maximum ⇒ Object
The maximum unit amount the customer can specify for this item.
534 535 536 |
# File 'lib/stripe/resources/price.rb', line 534 def maximum @maximum end |
#minimum ⇒ Object
The minimum unit amount the customer can specify for this item. Must be at least the minimum charge amount.
536 537 538 |
# File 'lib/stripe/resources/price.rb', line 536 def minimum @minimum end |
#preset ⇒ Object
The starting unit amount which can be updated by the customer.
538 539 540 |
# File 'lib/stripe/resources/price.rb', line 538 def preset @preset end |