Class: Stripe::Price::UpdateParams::CurrencyOptions::Tier
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Price::UpdateParams::CurrencyOptions::Tier
- Defined in:
- lib/stripe/resources/price.rb
Instance Attribute Summary collapse
-
#flat_amount ⇒ Object
The flat billing amount for an entire tier, regardless of the number of units in the tier.
-
#flat_amount_decimal ⇒ Object
Same as ‘flat_amount`, but accepts a decimal value representing an integer in the minor units of the currency.
-
#unit_amount ⇒ Object
The per unit billing amount for each individual unit for which this tier applies.
-
#unit_amount_decimal ⇒ Object
Same as ‘unit_amount`, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places.
-
#up_to ⇒ Object
Specifies the upper bound of this tier.
Instance Method Summary collapse
-
#initialize(flat_amount: nil, flat_amount_decimal: nil, unit_amount: nil, unit_amount_decimal: nil, up_to: nil) ⇒ Tier
constructor
A new instance of Tier.
Methods inherited from RequestParams
Constructor Details
#initialize(flat_amount: nil, flat_amount_decimal: nil, unit_amount: nil, unit_amount_decimal: nil, up_to: nil) ⇒ Tier
Returns a new instance of Tier.
560 561 562 563 564 565 566 567 568 569 570 571 572 |
# File 'lib/stripe/resources/price.rb', line 560 def initialize( flat_amount: nil, flat_amount_decimal: nil, unit_amount: nil, unit_amount_decimal: nil, up_to: nil ) @flat_amount = flat_amount @flat_amount_decimal = flat_amount_decimal @unit_amount = unit_amount @unit_amount_decimal = unit_amount_decimal @up_to = up_to end |
Instance Attribute Details
#flat_amount ⇒ Object
The flat billing amount for an entire tier, regardless of the number of units in the tier.
550 551 552 |
# File 'lib/stripe/resources/price.rb', line 550 def flat_amount @flat_amount end |
#flat_amount_decimal ⇒ Object
Same as ‘flat_amount`, but accepts a decimal value representing an integer in the minor units of the currency. Only one of `flat_amount` and `flat_amount_decimal` can be set.
552 553 554 |
# File 'lib/stripe/resources/price.rb', line 552 def flat_amount_decimal @flat_amount_decimal end |
#unit_amount ⇒ Object
The per unit billing amount for each individual unit for which this tier applies.
554 555 556 |
# File 'lib/stripe/resources/price.rb', line 554 def unit_amount @unit_amount end |
#unit_amount_decimal ⇒ Object
Same as ‘unit_amount`, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places. Only one of `unit_amount` and `unit_amount_decimal` can be set.
556 557 558 |
# File 'lib/stripe/resources/price.rb', line 556 def unit_amount_decimal @unit_amount_decimal end |
#up_to ⇒ Object
Specifies the upper bound of this tier. The lower bound of a tier is the upper bound of the previous tier adding one. Use ‘inf` to define a fallback tier.
558 559 560 |
# File 'lib/stripe/resources/price.rb', line 558 def up_to @up_to end |