Class: Stripe::Price::UpdateParams::MigrateTo
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Price::UpdateParams::MigrateTo
- Defined in:
- lib/stripe/resources/price.rb
Instance Attribute Summary collapse
-
#behavior ⇒ Object
The behavior controlling the point in the subscription lifecycle after which to migrate the price.
-
#effective_after ⇒ Object
The time after which subscriptions should start using the new price.
-
#price ⇒ Object
The ID of the price object.
Instance Method Summary collapse
-
#initialize(behavior: nil, effective_after: nil, price: nil) ⇒ MigrateTo
constructor
A new instance of MigrateTo.
Methods inherited from RequestParams
Constructor Details
#initialize(behavior: nil, effective_after: nil, price: nil) ⇒ MigrateTo
Returns a new instance of MigrateTo.
608 609 610 611 612 |
# File 'lib/stripe/resources/price.rb', line 608 def initialize(behavior: nil, effective_after: nil, price: nil) @behavior = behavior @effective_after = effective_after @price = price end |
Instance Attribute Details
#behavior ⇒ Object
The behavior controlling the point in the subscription lifecycle after which to migrate the price. Currently must be ‘at_cycle_end`.
602 603 604 |
# File 'lib/stripe/resources/price.rb', line 602 def behavior @behavior end |
#effective_after ⇒ Object
The time after which subscriptions should start using the new price.
604 605 606 |
# File 'lib/stripe/resources/price.rb', line 604 def effective_after @effective_after end |
#price ⇒ Object
The ID of the price object.
606 607 608 |
# File 'lib/stripe/resources/price.rb', line 606 def price @price end |