Class: Stripe::PriceService::CreateParams::CurrencyOptions::CustomUnitAmount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PriceService::CreateParams::CurrencyOptions::CustomUnitAmount
- Defined in:
- lib/stripe/services/price_service.rb
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Pass in ‘true` to enable `custom_unit_amount`, otherwise omit `custom_unit_amount`.
-
#maximum ⇒ Object
The maximum unit amount the customer can specify for this item.
-
#minimum ⇒ Object
The minimum unit amount the customer can specify for this item.
-
#preset ⇒ Object
The starting unit amount which can be updated by the customer.
Instance Method Summary collapse
-
#initialize(enabled: nil, maximum: nil, minimum: nil, preset: nil) ⇒ CustomUnitAmount
constructor
A new instance of CustomUnitAmount.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, maximum: nil, minimum: nil, preset: nil) ⇒ CustomUnitAmount
Returns a new instance of CustomUnitAmount.
119 120 121 122 123 124 |
# File 'lib/stripe/services/price_service.rb', line 119 def initialize(enabled: nil, maximum: nil, minimum: nil, preset: nil) @enabled = enabled @maximum = maximum @minimum = minimum @preset = preset end |
Instance Attribute Details
#enabled ⇒ Object
Pass in ‘true` to enable `custom_unit_amount`, otherwise omit `custom_unit_amount`.
108 109 110 |
# File 'lib/stripe/services/price_service.rb', line 108 def enabled @enabled end |
#maximum ⇒ Object
The maximum unit amount the customer can specify for this item.
111 112 113 |
# File 'lib/stripe/services/price_service.rb', line 111 def maximum @maximum end |
#minimum ⇒ Object
The minimum unit amount the customer can specify for this item. Must be at least the minimum charge amount.
114 115 116 |
# File 'lib/stripe/services/price_service.rb', line 114 def minimum @minimum end |
#preset ⇒ Object
The starting unit amount which can be updated by the customer.
117 118 119 |
# File 'lib/stripe/services/price_service.rb', line 117 def preset @preset end |