Class: Stripe::PriceService::CreateParams::CurrencyOptions::Tier

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/price_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(flat_amount: nil, flat_amount_decimal: nil, unit_amount: nil, unit_amount_decimal: nil, up_to: nil) ⇒ Tier

Returns a new instance of Tier.



143
144
145
146
147
148
149
150
151
152
153
154
155
# File 'lib/stripe/services/price_service.rb', line 143

def initialize(
  flat_amount: nil,
  flat_amount_decimal: nil,
  unit_amount: nil,
  unit_amount_decimal: nil,
  up_to: nil
)
  @flat_amount = flat_amount
  @flat_amount_decimal = flat_amount_decimal
  @unit_amount = unit_amount
  @unit_amount_decimal = unit_amount_decimal
  @up_to = up_to
end

Instance Attribute Details

#flat_amountObject

The flat billing amount for an entire tier, regardless of the number of units in the tier.



129
130
131
# File 'lib/stripe/services/price_service.rb', line 129

def flat_amount
  @flat_amount
end

#flat_amount_decimalObject

Same as ‘flat_amount`, but accepts a decimal value representing an integer in the minor units of the currency. Only one of `flat_amount` and `flat_amount_decimal` can be set.



132
133
134
# File 'lib/stripe/services/price_service.rb', line 132

def flat_amount_decimal
  @flat_amount_decimal
end

#unit_amountObject

The per unit billing amount for each individual unit for which this tier applies.



135
136
137
# File 'lib/stripe/services/price_service.rb', line 135

def unit_amount
  @unit_amount
end

#unit_amount_decimalObject

Same as ‘unit_amount`, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places. Only one of `unit_amount` and `unit_amount_decimal` can be set.



138
139
140
# File 'lib/stripe/services/price_service.rb', line 138

def unit_amount_decimal
  @unit_amount_decimal
end

#up_toObject

Specifies the upper bound of this tier. The lower bound of a tier is the upper bound of the previous tier adding one. Use ‘inf` to define a fallback tier.



141
142
143
# File 'lib/stripe/services/price_service.rb', line 141

def up_to
  @up_to
end