Class: Stripe::PriceService::CreateParams::Tier

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/price_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(flat_amount: nil, flat_amount_decimal: nil, unit_amount: nil, unit_amount_decimal: nil, up_to: nil) ⇒ Tier

Returns a new instance of Tier.



303
304
305
306
307
308
309
310
311
312
313
314
315
# File 'lib/stripe/services/price_service.rb', line 303

def initialize(
  flat_amount: nil,
  flat_amount_decimal: nil,
  unit_amount: nil,
  unit_amount_decimal: nil,
  up_to: nil
)
  @flat_amount = flat_amount
  @flat_amount_decimal = flat_amount_decimal
  @unit_amount = unit_amount
  @unit_amount_decimal = unit_amount_decimal
  @up_to = up_to
end

Instance Attribute Details

#flat_amountObject

The flat billing amount for an entire tier, regardless of the number of units in the tier.



289
290
291
# File 'lib/stripe/services/price_service.rb', line 289

def flat_amount
  @flat_amount
end

#flat_amount_decimalObject

Same as ‘flat_amount`, but accepts a decimal value representing an integer in the minor units of the currency. Only one of `flat_amount` and `flat_amount_decimal` can be set.



292
293
294
# File 'lib/stripe/services/price_service.rb', line 292

def flat_amount_decimal
  @flat_amount_decimal
end

#unit_amountObject

The per unit billing amount for each individual unit for which this tier applies.



295
296
297
# File 'lib/stripe/services/price_service.rb', line 295

def unit_amount
  @unit_amount
end

#unit_amount_decimalObject

Same as ‘unit_amount`, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places. Only one of `unit_amount` and `unit_amount_decimal` can be set.



298
299
300
# File 'lib/stripe/services/price_service.rb', line 298

def unit_amount_decimal
  @unit_amount_decimal
end

#up_toObject

Specifies the upper bound of this tier. The lower bound of a tier is the upper bound of the previous tier adding one. Use ‘inf` to define a fallback tier.



301
302
303
# File 'lib/stripe/services/price_service.rb', line 301

def up_to
  @up_to
end