Class: Stripe::PriceService::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/price_service.rb

Defined Under Namespace

Classes: Created, Recurring

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(active: nil, created: nil, currency: nil, ending_before: nil, expand: nil, limit: nil, lookup_keys: nil, product: nil, recurring: nil, starting_after: nil, type: nil) ⇒ ListParams

Returns a new instance of ListParams.



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/stripe/services/price_service.rb', line 77

def initialize(
  active: nil,
  created: nil,
  currency: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  lookup_keys: nil,
  product: nil,
  recurring: nil,
  starting_after: nil,
  type: nil
)
  @active = active
  @created = created
  @currency = currency
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @lookup_keys = lookup_keys
  @product = product
  @recurring = recurring
  @starting_after = starting_after
  @type = type
end

Instance Attribute Details

#activeObject

Only return prices that are active or inactive (e.g., pass ‘false` to list all inactive prices).



45
46
47
# File 'lib/stripe/services/price_service.rb', line 45

def active
  @active
end

#createdObject

A filter on the list, based on the object ‘created` field. The value can be a string with an integer Unix timestamp, or it can be a dictionary with a number of different query options.



48
49
50
# File 'lib/stripe/services/price_service.rb', line 48

def created
  @created
end

#currencyObject

Only return prices for the given currency.



51
52
53
# File 'lib/stripe/services/price_service.rb', line 51

def currency
  @currency
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



54
55
56
# File 'lib/stripe/services/price_service.rb', line 54

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



57
58
59
# File 'lib/stripe/services/price_service.rb', line 57

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



60
61
62
# File 'lib/stripe/services/price_service.rb', line 60

def limit
  @limit
end

#lookup_keysObject

Only return the price with these lookup_keys, if any exist. You can specify up to 10 lookup_keys.



63
64
65
# File 'lib/stripe/services/price_service.rb', line 63

def lookup_keys
  @lookup_keys
end

#productObject

Only return prices for the given product.



66
67
68
# File 'lib/stripe/services/price_service.rb', line 66

def product
  @product
end

#recurringObject

Only return prices with these recurring fields.



69
70
71
# File 'lib/stripe/services/price_service.rb', line 69

def recurring
  @recurring
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



72
73
74
# File 'lib/stripe/services/price_service.rb', line 72

def starting_after
  @starting_after
end

#typeObject

Only return prices of type ‘recurring` or `one_time`.



75
76
77
# File 'lib/stripe/services/price_service.rb', line 75

def type
  @type
end