Class: Stripe::PriceService::SearchParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/price_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, limit: nil, page: nil, query: nil) ⇒ SearchParams

Returns a new instance of SearchParams.



510
511
512
513
514
515
# File 'lib/stripe/services/price_service.rb', line 510

def initialize(expand: nil, limit: nil, page: nil, query: nil)
  @expand = expand
  @limit = limit
  @page = page
  @query = query
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



502
503
504
# File 'lib/stripe/services/price_service.rb', line 502

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



504
505
506
# File 'lib/stripe/services/price_service.rb', line 504

def limit
  @limit
end

#pageObject

A cursor for pagination across multiple pages of results. Don’t include this parameter on the first call. Use the next_page value returned in a previous response to request subsequent results.



506
507
508
# File 'lib/stripe/services/price_service.rb', line 506

def page
  @page
end

#queryObject

The search query string. See [search query language](stripe.com/docs/search#search-query-language) and the list of supported [query fields for prices](stripe.com/docs/search#query-fields-for-prices).



508
509
510
# File 'lib/stripe/services/price_service.rb', line 508

def query
  @query
end