Class: Stripe::PriceService::UpdateParams::MigrateTo

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/price_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(behavior: nil, effective_after: nil, price: nil) ⇒ MigrateTo

Returns a new instance of MigrateTo.



452
453
454
455
456
# File 'lib/stripe/services/price_service.rb', line 452

def initialize(behavior: nil, effective_after: nil, price: nil)
  @behavior = behavior
  @effective_after = effective_after
  @price = price
end

Instance Attribute Details

#behaviorObject

The behavior controlling the point in the subscription lifecycle after which to migrate the price. Currently must be ‘at_cycle_end`.



446
447
448
# File 'lib/stripe/services/price_service.rb', line 446

def behavior
  @behavior
end

#effective_afterObject

The time after which subscriptions should start using the new price.



448
449
450
# File 'lib/stripe/services/price_service.rb', line 448

def effective_after
  @effective_after
end

#priceObject

The ID of the price object.



450
451
452
# File 'lib/stripe/services/price_service.rb', line 450

def price
  @price
end