Class: Stripe::PriceUpdateParams::MigrateTo

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/price_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(behavior: nil, effective_after: nil, price: nil) ⇒ MigrateTo

Returns a new instance of MigrateTo.



105
106
107
108
109
# File 'lib/stripe/params/price_update_params.rb', line 105

def initialize(behavior: nil, effective_after: nil, price: nil)
  @behavior = behavior
  @effective_after = effective_after
  @price = price
end

Instance Attribute Details

#behaviorObject

The behavior controlling the point in the subscription lifecycle after which to migrate the price. Currently must be ‘at_cycle_end`.



99
100
101
# File 'lib/stripe/params/price_update_params.rb', line 99

def behavior
  @behavior
end

#effective_afterObject

The time after which subscriptions should start using the new price.



101
102
103
# File 'lib/stripe/params/price_update_params.rb', line 101

def effective_after
  @effective_after
end

#priceObject

The ID of the price object.



103
104
105
# File 'lib/stripe/params/price_update_params.rb', line 103

def price
  @price
end