Class: Stripe::Privacy::RedactionJob::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Privacy::RedactionJob::UpdateParams
- Defined in:
- lib/stripe/resources/privacy/redaction_job.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#validation_behavior ⇒ Object
Determines the validation behavior of the job.
Instance Method Summary collapse
-
#initialize(expand: nil, validation_behavior: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, validation_behavior: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
146 147 148 149 |
# File 'lib/stripe/resources/privacy/redaction_job.rb', line 146 def initialize(expand: nil, validation_behavior: nil) @expand = @validation_behavior = validation_behavior end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
142 143 144 |
# File 'lib/stripe/resources/privacy/redaction_job.rb', line 142 def @expand end |
#validation_behavior ⇒ Object
Determines the validation behavior of the job. Default is ‘error`.
144 145 146 |
# File 'lib/stripe/resources/privacy/redaction_job.rb', line 144 def validation_behavior @validation_behavior end |