Class: Stripe::Privacy::RedactionJob::ValidateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Privacy::RedactionJob::ValidateParams
- Defined in:
- lib/stripe/resources/privacy/redaction_job.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ ValidateParams
constructor
A new instance of ValidateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ ValidateParams
Returns a new instance of ValidateParams.
166 167 168 |
# File 'lib/stripe/resources/privacy/redaction_job.rb', line 166 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
164 165 166 |
# File 'lib/stripe/resources/privacy/redaction_job.rb', line 164 def @expand end |