Class: Stripe::Privacy::RedactionJobCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Privacy::RedactionJobCreateParams
- Defined in:
- lib/stripe/params/privacy/redaction_job_create_params.rb
Defined Under Namespace
Classes: Objects
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#objects ⇒ Object
The objects to redact.
-
#validation_behavior ⇒ Object
Determines the validation behavior of the job.
Instance Method Summary collapse
-
#initialize(expand: nil, objects: nil, validation_behavior: nil) ⇒ RedactionJobCreateParams
constructor
A new instance of RedactionJobCreateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(expand: nil, objects: nil, validation_behavior: nil) ⇒ RedactionJobCreateParams
Returns a new instance of RedactionJobCreateParams.
60 61 62 63 64 |
# File 'lib/stripe/params/privacy/redaction_job_create_params.rb', line 60 def initialize(expand: nil, objects: nil, validation_behavior: nil) @expand = @objects = objects @validation_behavior = validation_behavior end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
54 55 56 |
# File 'lib/stripe/params/privacy/redaction_job_create_params.rb', line 54 def @expand end |
#objects ⇒ Object
The objects to redact. These root objects and their related ones will be validated for redaction.
56 57 58 |
# File 'lib/stripe/params/privacy/redaction_job_create_params.rb', line 56 def objects @objects end |
#validation_behavior ⇒ Object
Determines the validation behavior of the job. Default is ‘error`.
58 59 60 |
# File 'lib/stripe/params/privacy/redaction_job_create_params.rb', line 58 def validation_behavior @validation_behavior end |