Class: Stripe::Privacy::RedactionJobService::CancelParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Privacy::RedactionJobService::CancelParams
- Defined in:
- lib/stripe/services/privacy/redaction_job_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ CancelParams
constructor
A new instance of CancelParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ CancelParams
Returns a new instance of CancelParams.
127 128 129 |
# File 'lib/stripe/services/privacy/redaction_job_service.rb', line 127 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
125 126 127 |
# File 'lib/stripe/services/privacy/redaction_job_service.rb', line 125 def @expand end |