Class: Stripe::Privacy::RedactionJobService::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/privacy/redaction_job_service.rb

Defined Under Namespace

Classes: Objects

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, objects: nil, validation_behavior: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



95
96
97
98
99
# File 'lib/stripe/services/privacy/redaction_job_service.rb', line 95

def initialize(expand: nil, objects: nil, validation_behavior: nil)
  @expand = expand
  @objects = objects
  @validation_behavior = validation_behavior
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



89
90
91
# File 'lib/stripe/services/privacy/redaction_job_service.rb', line 89

def expand
  @expand
end

#objectsObject

The objects to redact. These root objects and their related ones will be validated for redaction.



91
92
93
# File 'lib/stripe/services/privacy/redaction_job_service.rb', line 91

def objects
  @objects
end

#validation_behaviorObject

Determines the validation behavior of the job. Default is ‘error`.



93
94
95
# File 'lib/stripe/services/privacy/redaction_job_service.rb', line 93

def validation_behavior
  @validation_behavior
end