Class: Stripe::Privacy::RedactionJobService::RunParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Privacy::RedactionJobService::RunParams
- Defined in:
- lib/stripe/services/privacy/redaction_job_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ RunParams
constructor
A new instance of RunParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ RunParams
Returns a new instance of RunParams.
136 137 138 |
# File 'lib/stripe/services/privacy/redaction_job_service.rb', line 136 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
134 135 136 |
# File 'lib/stripe/services/privacy/redaction_job_service.rb', line 134 def @expand end |