Class: Stripe::Privacy::RedactionJobService::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Privacy::RedactionJobService::UpdateParams
- Defined in:
- lib/stripe/services/privacy/redaction_job_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#validation_behavior ⇒ Object
Determines the validation behavior of the job.
Instance Method Summary collapse
-
#initialize(expand: nil, validation_behavior: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, validation_behavior: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
117 118 119 120 |
# File 'lib/stripe/services/privacy/redaction_job_service.rb', line 117 def initialize(expand: nil, validation_behavior: nil) @expand = @validation_behavior = validation_behavior end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
113 114 115 |
# File 'lib/stripe/services/privacy/redaction_job_service.rb', line 113 def @expand end |
#validation_behavior ⇒ Object
Determines the validation behavior of the job. Default is ‘error`.
115 116 117 |
# File 'lib/stripe/services/privacy/redaction_job_service.rb', line 115 def validation_behavior @validation_behavior end |