Class: Stripe::Product::CreateParams::DefaultPriceData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Product::CreateParams::DefaultPriceData
- Defined in:
- lib/stripe/resources/product.rb
Defined Under Namespace
Classes: CurrencyOptions, CustomUnitAmount, Recurring
Instance Attribute Summary collapse
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#currency_options ⇒ Object
Prices defined in each available currency option.
-
#custom_unit_amount ⇒ Object
When set, provides configuration for the amount to be adjusted by the customer during Checkout Sessions and Payment Links.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#recurring ⇒ Object
The recurring components of a price such as ‘interval` and `interval_count`.
-
#tax_behavior ⇒ Object
Only required if a [default tax behavior](stripe.com/docs/tax/products-prices-tax-categories-tax-behavior#setting-a-default-tax-behavior-(recommended)) was not provided in the Stripe Tax settings.
-
#unit_amount ⇒ Object
A positive integer in cents (or local equivalent) (or 0 for a free price) representing how much to charge.
-
#unit_amount_decimal ⇒ Object
Same as ‘unit_amount`, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places.
Instance Method Summary collapse
-
#initialize(currency: nil, currency_options: nil, custom_unit_amount: nil, metadata: nil, recurring: nil, tax_behavior: nil, unit_amount: nil, unit_amount_decimal: nil) ⇒ DefaultPriceData
constructor
A new instance of DefaultPriceData.
Methods inherited from RequestParams
Constructor Details
#initialize(currency: nil, currency_options: nil, custom_unit_amount: nil, metadata: nil, recurring: nil, tax_behavior: nil, unit_amount: nil, unit_amount_decimal: nil) ⇒ DefaultPriceData
Returns a new instance of DefaultPriceData.
337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 |
# File 'lib/stripe/resources/product.rb', line 337 def initialize( currency: nil, currency_options: nil, custom_unit_amount: nil, metadata: nil, recurring: nil, tax_behavior: nil, unit_amount: nil, unit_amount_decimal: nil ) @currency = currency @currency_options = @custom_unit_amount = custom_unit_amount @metadata = @recurring = recurring @tax_behavior = tax_behavior @unit_amount = unit_amount @unit_amount_decimal = unit_amount_decimal end |
Instance Attribute Details
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
321 322 323 |
# File 'lib/stripe/resources/product.rb', line 321 def currency @currency end |
#currency_options ⇒ Object
Prices defined in each available currency option. Each key must be a three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html) and a [supported currency](stripe.com/docs/currencies).
323 324 325 |
# File 'lib/stripe/resources/product.rb', line 323 def @currency_options end |
#custom_unit_amount ⇒ Object
When set, provides configuration for the amount to be adjusted by the customer during Checkout Sessions and Payment Links.
325 326 327 |
# File 'lib/stripe/resources/product.rb', line 325 def custom_unit_amount @custom_unit_amount end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
327 328 329 |
# File 'lib/stripe/resources/product.rb', line 327 def @metadata end |
#recurring ⇒ Object
The recurring components of a price such as ‘interval` and `interval_count`.
329 330 331 |
# File 'lib/stripe/resources/product.rb', line 329 def recurring @recurring end |
#tax_behavior ⇒ Object
Only required if a [default tax behavior](stripe.com/docs/tax/products-prices-tax-categories-tax-behavior#setting-a-default-tax-behavior-(recommended)) was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`. Once specified as either `inclusive` or `exclusive`, it cannot be changed.
331 332 333 |
# File 'lib/stripe/resources/product.rb', line 331 def tax_behavior @tax_behavior end |
#unit_amount ⇒ Object
A positive integer in cents (or local equivalent) (or 0 for a free price) representing how much to charge. One of ‘unit_amount`, `unit_amount_decimal`, or `custom_unit_amount` is required.
333 334 335 |
# File 'lib/stripe/resources/product.rb', line 333 def unit_amount @unit_amount end |
#unit_amount_decimal ⇒ Object
Same as ‘unit_amount`, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places. Only one of `unit_amount` and `unit_amount_decimal` can be set.
335 336 337 |
# File 'lib/stripe/resources/product.rb', line 335 def unit_amount_decimal @unit_amount_decimal end |