Class: Stripe::Product::CreateParams::DefaultPriceData::CurrencyOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/product.rb

Defined Under Namespace

Classes: CustomUnitAmount, Tier

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(custom_unit_amount: nil, tax_behavior: nil, tiers: nil, unit_amount: nil, unit_amount_decimal: nil) ⇒ CurrencyOptions

Returns a new instance of CurrencyOptions.



289
290
291
292
293
294
295
296
297
298
299
300
301
# File 'lib/stripe/resources/product.rb', line 289

def initialize(
  custom_unit_amount: nil,
  tax_behavior: nil,
  tiers: nil,
  unit_amount: nil,
  unit_amount_decimal: nil
)
  @custom_unit_amount = custom_unit_amount
  @tax_behavior = tax_behavior
  @tiers = tiers
  @unit_amount = unit_amount
  @unit_amount_decimal = unit_amount_decimal
end

Instance Attribute Details

#custom_unit_amountObject

When set, provides configuration for the amount to be adjusted by the customer during Checkout Sessions and Payment Links.



279
280
281
# File 'lib/stripe/resources/product.rb', line 279

def custom_unit_amount
  @custom_unit_amount
end

#tax_behaviorObject

Only required if a [default tax behavior](stripe.com/docs/tax/products-prices-tax-categories-tax-behavior#setting-a-default-tax-behavior-(recommended)) was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`. Once specified as either `inclusive` or `exclusive`, it cannot be changed.



281
282
283
# File 'lib/stripe/resources/product.rb', line 281

def tax_behavior
  @tax_behavior
end

#tiersObject

Each element represents a pricing tier. This parameter requires ‘billing_scheme` to be set to `tiered`. See also the documentation for `billing_scheme`.



283
284
285
# File 'lib/stripe/resources/product.rb', line 283

def tiers
  @tiers
end

#unit_amountObject

A positive integer in cents (or local equivalent) (or 0 for a free price) representing how much to charge.



285
286
287
# File 'lib/stripe/resources/product.rb', line 285

def unit_amount
  @unit_amount
end

#unit_amount_decimalObject

Same as ‘unit_amount`, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places. Only one of `unit_amount` and `unit_amount_decimal` can be set.



287
288
289
# File 'lib/stripe/resources/product.rb', line 287

def unit_amount_decimal
  @unit_amount_decimal
end