Class: Stripe::Product::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/product.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(active: nil, created: nil, ending_before: nil, expand: nil, ids: nil, limit: nil, shippable: nil, starting_after: nil, type: nil, url: nil) ⇒ ListParams

Returns a new instance of ListParams.



177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
# File 'lib/stripe/resources/product.rb', line 177

def initialize(
  active: nil,
  created: nil,
  ending_before: nil,
  expand: nil,
  ids: nil,
  limit: nil,
  shippable: nil,
  starting_after: nil,
  type: nil,
  url: nil
)
  @active = active
  @created = created
  @ending_before = ending_before
  @expand = expand
  @ids = ids
  @limit = limit
  @shippable = shippable
  @starting_after = starting_after
  @type = type
  @url = url
end

Instance Attribute Details

#activeObject

Only return products that are active or inactive (e.g., pass ‘false` to list all inactive products).



157
158
159
# File 'lib/stripe/resources/product.rb', line 157

def active
  @active
end

#createdObject

Only return products that were created during the given date interval.



159
160
161
# File 'lib/stripe/resources/product.rb', line 159

def created
  @created
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



161
162
163
# File 'lib/stripe/resources/product.rb', line 161

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



163
164
165
# File 'lib/stripe/resources/product.rb', line 163

def expand
  @expand
end

#idsObject

Only return products with the given IDs. Cannot be used with [starting_after](stripe.com/docs/api#list_products-starting_after) or [ending_before](stripe.com/docs/api#list_products-ending_before).



165
166
167
# File 'lib/stripe/resources/product.rb', line 165

def ids
  @ids
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



167
168
169
# File 'lib/stripe/resources/product.rb', line 167

def limit
  @limit
end

#shippableObject

Only return products that can be shipped (i.e., physical, not digital products).



169
170
171
# File 'lib/stripe/resources/product.rb', line 169

def shippable
  @shippable
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



171
172
173
# File 'lib/stripe/resources/product.rb', line 171

def starting_after
  @starting_after
end

#typeObject

Only return products of this type.



173
174
175
# File 'lib/stripe/resources/product.rb', line 173

def type
  @type
end

#urlObject

Only return products with the given url.



175
176
177
# File 'lib/stripe/resources/product.rb', line 175

def url
  @url
end