Class: Stripe::Product::SearchParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/product.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, limit: nil, page: nil, query: nil) ⇒ SearchParams

Returns a new instance of SearchParams.



467
468
469
470
471
472
# File 'lib/stripe/resources/product.rb', line 467

def initialize(expand: nil, limit: nil, page: nil, query: nil)
  @expand = expand
  @limit = limit
  @page = page
  @query = query
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



459
460
461
# File 'lib/stripe/resources/product.rb', line 459

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



461
462
463
# File 'lib/stripe/resources/product.rb', line 461

def limit
  @limit
end

#pageObject

A cursor for pagination across multiple pages of results. Don’t include this parameter on the first call. Use the next_page value returned in a previous response to request subsequent results.



463
464
465
# File 'lib/stripe/resources/product.rb', line 463

def page
  @page
end

#queryObject

The search query string. See [search query language](stripe.com/docs/search#search-query-language) and the list of supported [query fields for products](stripe.com/docs/search#query-fields-for-products).



465
466
467
# File 'lib/stripe/resources/product.rb', line 465

def query
  @query
end