Class: Stripe::Product::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/product.rb

Defined Under Namespace

Classes: MarketingFeature, PackageDimensions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(active: nil, default_price: nil, description: nil, expand: nil, images: nil, marketing_features: nil, metadata: nil, name: nil, package_dimensions: nil, shippable: nil, statement_descriptor: nil, tax_code: nil, unit_label: nil, url: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/stripe/resources/product.rb', line 121

def initialize(
  active: nil,
  default_price: nil,
  description: nil,
  expand: nil,
  images: nil,
  marketing_features: nil,
  metadata: nil,
  name: nil,
  package_dimensions: nil,
  shippable: nil,
  statement_descriptor: nil,
  tax_code: nil,
  unit_label: nil,
  url: nil
)
  @active = active
  @default_price = default_price
  @description = description
  @expand = expand
  @images = images
  @marketing_features = marketing_features
  @metadata = 
  @name = name
  @package_dimensions = package_dimensions
  @shippable = shippable
  @statement_descriptor = statement_descriptor
  @tax_code = tax_code
  @unit_label = unit_label
  @url = url
end

Instance Attribute Details

#activeObject

Whether the product is available for purchase.



90
91
92
# File 'lib/stripe/resources/product.rb', line 90

def active
  @active
end

#default_priceObject

The ID of the [Price](stripe.com/docs/api/prices) object that is the default price for this product.



92
93
94
# File 'lib/stripe/resources/product.rb', line 92

def default_price
  @default_price
end

#descriptionObject

The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.



94
95
96
# File 'lib/stripe/resources/product.rb', line 94

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



96
97
98
# File 'lib/stripe/resources/product.rb', line 96

def expand
  @expand
end

#imagesObject

A list of up to 8 URLs of images for this product, meant to be displayable to the customer.



98
99
100
# File 'lib/stripe/resources/product.rb', line 98

def images
  @images
end

#marketing_featuresObject

A list of up to 15 marketing features for this product. These are displayed in [pricing tables](stripe.com/docs/payments/checkout/pricing-table).



100
101
102
# File 'lib/stripe/resources/product.rb', line 100

def marketing_features
  @marketing_features
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



102
103
104
# File 'lib/stripe/resources/product.rb', line 102

def 
  @metadata
end

#nameObject

The product’s name, meant to be displayable to the customer.



104
105
106
# File 'lib/stripe/resources/product.rb', line 104

def name
  @name
end

#package_dimensionsObject

The dimensions of this product for shipping purposes.



106
107
108
# File 'lib/stripe/resources/product.rb', line 106

def package_dimensions
  @package_dimensions
end

#shippableObject

Whether this product is shipped (i.e., physical goods).



108
109
110
# File 'lib/stripe/resources/product.rb', line 108

def shippable
  @shippable
end

#statement_descriptorObject

An arbitrary string to be displayed on your customer’s credit card or bank statement. While most banks display this information consistently, some may display it incorrectly or not at all.

This may be up to 22 characters. The statement description may not include ‘<`, `>`, ``, `“`, `’‘ characters, and will appear on your customer’s statement in capital letters. Non-ASCII characters are automatically stripped.

It must contain at least one letter. May only be set if `type=service`. Only used for subscription payments.


113
114
115
# File 'lib/stripe/resources/product.rb', line 113

def statement_descriptor
  @statement_descriptor
end

#tax_codeObject



115
116
117
# File 'lib/stripe/resources/product.rb', line 115

def tax_code
  @tax_code
end

#unit_labelObject

A label that represents units of this product. When set, this will be included in customers’ receipts, invoices, Checkout, and the customer portal. May only be set if ‘type=service`.



117
118
119
# File 'lib/stripe/resources/product.rb', line 117

def unit_label
  @unit_label
end

#urlObject

A URL of a publicly-accessible webpage for this product.



119
120
121
# File 'lib/stripe/resources/product.rb', line 119

def url
  @url
end