Class: Stripe::ProductCatalog::TrialOffer::EndBehavior
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::ProductCatalog::TrialOffer::EndBehavior
- Defined in:
- lib/stripe/resources/product_catalog/trial_offer.rb
Defined Under Namespace
Classes: Transition
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#transition ⇒ Object
readonly
Attribute for field transition.
-
#type ⇒ Object
readonly
The type of behavior when the trial offer ends.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#transition ⇒ Object (readonly)
Attribute for field transition
57 58 59 |
# File 'lib/stripe/resources/product_catalog/trial_offer.rb', line 57 def transition @transition end |
#type ⇒ Object (readonly)
The type of behavior when the trial offer ends.
59 60 61 |
# File 'lib/stripe/resources/product_catalog/trial_offer.rb', line 59 def type @type end |
Class Method Details
.field_remappings ⇒ Object
65 66 67 |
# File 'lib/stripe/resources/product_catalog/trial_offer.rb', line 65 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
61 62 63 |
# File 'lib/stripe/resources/product_catalog/trial_offer.rb', line 61 def self.inner_class_types @inner_class_types = { transition: Transition } end |