Class: Stripe::ProductCatalog::TrialOfferCreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/product_catalog/trial_offer_create_params.rb

Defined Under Namespace

Classes: Duration, EndBehavior

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(duration: nil, end_behavior: nil, expand: nil, name: nil, price: nil) ⇒ TrialOfferCreateParams

Returns a new instance of TrialOfferCreateParams.



54
55
56
57
58
59
60
# File 'lib/stripe/params/product_catalog/trial_offer_create_params.rb', line 54

def initialize(duration: nil, end_behavior: nil, expand: nil, name: nil, price: nil)
  @duration = duration
  @end_behavior = end_behavior
  @expand = expand
  @name = name
  @price = price
end

Instance Attribute Details

#durationObject

Duration of one service period of the trial.



44
45
46
# File 'lib/stripe/params/product_catalog/trial_offer_create_params.rb', line 44

def duration
  @duration
end

#end_behaviorObject

Define behavior that occurs at the end of the trial.



46
47
48
# File 'lib/stripe/params/product_catalog/trial_offer_create_params.rb', line 46

def end_behavior
  @end_behavior
end

#expandObject

Specifies which fields in the response should be expanded.



48
49
50
# File 'lib/stripe/params/product_catalog/trial_offer_create_params.rb', line 48

def expand
  @expand
end

#nameObject

A brief, user-friendly name for the trial offer-for identification purposes.



50
51
52
# File 'lib/stripe/params/product_catalog/trial_offer_create_params.rb', line 50

def name
  @name
end

#priceObject

Price configuration during the trial period (amount, billing scheme, etc).



52
53
54
# File 'lib/stripe/params/product_catalog/trial_offer_create_params.rb', line 52

def price
  @price
end