Class: Stripe::ProductCatalog::TrialOfferCreateParams::Duration
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ProductCatalog::TrialOfferCreateParams::Duration
- Defined in:
- lib/stripe/params/product_catalog/trial_offer_create_params.rb
Defined Under Namespace
Classes: Relative
Instance Attribute Summary collapse
-
#relative ⇒ Object
The relative duration of the trial period computed as the number of recurring price intervals.
-
#type ⇒ Object
Specifies how the trial offer duration is determined.
Instance Method Summary collapse
-
#initialize(relative: nil, type: nil) ⇒ Duration
constructor
A new instance of Duration.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(relative: nil, type: nil) ⇒ Duration
Returns a new instance of Duration.
21 22 23 24 |
# File 'lib/stripe/params/product_catalog/trial_offer_create_params.rb', line 21 def initialize(relative: nil, type: nil) @relative = relative @type = type end |
Instance Attribute Details
#relative ⇒ Object
The relative duration of the trial period computed as the number of recurring price intervals.
17 18 19 |
# File 'lib/stripe/params/product_catalog/trial_offer_create_params.rb', line 17 def relative @relative end |
#type ⇒ Object
Specifies how the trial offer duration is determined.
19 20 21 |
# File 'lib/stripe/params/product_catalog/trial_offer_create_params.rb', line 19 def type @type end |