Class: Stripe::ProductCatalog::TrialOfferCreateParams::EndBehavior
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ProductCatalog::TrialOfferCreateParams::EndBehavior
- Defined in:
- lib/stripe/params/product_catalog/trial_offer_create_params.rb
Defined Under Namespace
Classes: Transition
Instance Attribute Summary collapse
-
#transition ⇒ Object
The transition to apply when the trial offer ends.
Instance Method Summary collapse
-
#initialize(transition: nil) ⇒ EndBehavior
constructor
A new instance of EndBehavior.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(transition: nil) ⇒ EndBehavior
Returns a new instance of EndBehavior.
39 40 41 |
# File 'lib/stripe/params/product_catalog/trial_offer_create_params.rb', line 39 def initialize(transition: nil) @transition = transition end |
Instance Attribute Details
#transition ⇒ Object
The transition to apply when the trial offer ends.
37 38 39 |
# File 'lib/stripe/params/product_catalog/trial_offer_create_params.rb', line 37 def transition @transition end |