Class: Stripe::ProductCatalog::TrialOfferCreateParams::EndBehavior::Transition
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ProductCatalog::TrialOfferCreateParams::EndBehavior::Transition
- Defined in:
- lib/stripe/params/product_catalog/trial_offer_create_params.rb
Instance Attribute Summary collapse
-
#price ⇒ Object
The price to transition the recurring item to when the trial offer ends.
Instance Method Summary collapse
-
#initialize(price: nil) ⇒ Transition
constructor
A new instance of Transition.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(price: nil) ⇒ Transition
Returns a new instance of Transition.
32 33 34 |
# File 'lib/stripe/params/product_catalog/trial_offer_create_params.rb', line 32 def initialize(price: nil) @price = price end |
Instance Attribute Details
#price ⇒ Object
The price to transition the recurring item to when the trial offer ends.
30 31 32 |
# File 'lib/stripe/params/product_catalog/trial_offer_create_params.rb', line 30 def price @price end |