Class: Stripe::ProductCatalog::TrialOfferListParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/product_catalog/trial_offer_list_params.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(created: nil, ending_before: nil, expand: nil, limit: nil, prices: nil, starting_after: nil) ⇒ TrialOfferListParams

Returns a new instance of TrialOfferListParams.



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
# File 'lib/stripe/params/product_catalog/trial_offer_list_params.rb', line 37

def initialize(
  created: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  prices: nil,
  starting_after: nil
)
  @created = created
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @prices = prices
  @starting_after = starting_after
end

Instance Attribute Details

#createdObject

Only return trial offers that were created during the given date interval.



25
26
27
# File 'lib/stripe/params/product_catalog/trial_offer_list_params.rb', line 25

def created
  @created
end

#ending_beforeObject

A cursor for use in pagination. ending_before is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with obj_bar, your subsequent call can include ending_before=obj_bar in order to fetch the previous page of the list.



27
28
29
# File 'lib/stripe/params/product_catalog/trial_offer_list_params.rb', line 27

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



29
30
31
# File 'lib/stripe/params/product_catalog/trial_offer_list_params.rb', line 29

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



31
32
33
# File 'lib/stripe/params/product_catalog/trial_offer_list_params.rb', line 31

def limit
  @limit
end

#pricesObject

Only return trial offers that reference these prices (during the trial period).



33
34
35
# File 'lib/stripe/params/product_catalog/trial_offer_list_params.rb', line 33

def prices
  @prices
end

#starting_afterObject

A cursor for use in pagination. starting_after is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with obj_foo, your subsequent call can include starting_after=obj_foo in order to fetch the next page of the list.



35
36
37
# File 'lib/stripe/params/product_catalog/trial_offer_list_params.rb', line 35

def starting_after
  @starting_after
end