Class: Stripe::ProductService::CreateParams::DefaultPriceData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ProductService::CreateParams::DefaultPriceData
- Defined in:
- lib/stripe/services/product_service.rb
Defined Under Namespace
Classes: CurrencyOptions, CustomUnitAmount, Recurring
Instance Attribute Summary collapse
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#currency_options ⇒ Object
Prices defined in each available currency option.
-
#custom_unit_amount ⇒ Object
When set, provides configuration for the amount to be adjusted by the customer during Checkout Sessions and Payment Links.
-
#recurring ⇒ Object
The recurring components of a price such as ‘interval` and `interval_count`.
-
#tax_behavior ⇒ Object
Only required if a [default tax behavior](stripe.com/docs/tax/products-prices-tax-categories-tax-behavior#setting-a-default-tax-behavior-(recommended)) was not provided in the Stripe Tax settings.
-
#unit_amount ⇒ Object
A positive integer in cents (or local equivalent) (or 0 for a free price) representing how much to charge.
-
#unit_amount_decimal ⇒ Object
Same as ‘unit_amount`, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places.
Instance Method Summary collapse
-
#initialize(currency: nil, currency_options: nil, custom_unit_amount: nil, recurring: nil, tax_behavior: nil, unit_amount: nil, unit_amount_decimal: nil) ⇒ DefaultPriceData
constructor
A new instance of DefaultPriceData.
Methods inherited from RequestParams
Constructor Details
#initialize(currency: nil, currency_options: nil, custom_unit_amount: nil, recurring: nil, tax_behavior: nil, unit_amount: nil, unit_amount_decimal: nil) ⇒ DefaultPriceData
Returns a new instance of DefaultPriceData.
347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 |
# File 'lib/stripe/services/product_service.rb', line 347 def initialize( currency: nil, currency_options: nil, custom_unit_amount: nil, recurring: nil, tax_behavior: nil, unit_amount: nil, unit_amount_decimal: nil ) @currency = currency @currency_options = @custom_unit_amount = custom_unit_amount @recurring = recurring @tax_behavior = tax_behavior @unit_amount = unit_amount @unit_amount_decimal = unit_amount_decimal end |
Instance Attribute Details
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
327 328 329 |
# File 'lib/stripe/services/product_service.rb', line 327 def currency @currency end |
#currency_options ⇒ Object
Prices defined in each available currency option. Each key must be a three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html) and a [supported currency](stripe.com/docs/currencies).
330 331 332 |
# File 'lib/stripe/services/product_service.rb', line 330 def @currency_options end |
#custom_unit_amount ⇒ Object
When set, provides configuration for the amount to be adjusted by the customer during Checkout Sessions and Payment Links.
333 334 335 |
# File 'lib/stripe/services/product_service.rb', line 333 def custom_unit_amount @custom_unit_amount end |
#recurring ⇒ Object
The recurring components of a price such as ‘interval` and `interval_count`.
336 337 338 |
# File 'lib/stripe/services/product_service.rb', line 336 def recurring @recurring end |
#tax_behavior ⇒ Object
Only required if a [default tax behavior](stripe.com/docs/tax/products-prices-tax-categories-tax-behavior#setting-a-default-tax-behavior-(recommended)) was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`. Once specified as either `inclusive` or `exclusive`, it cannot be changed.
339 340 341 |
# File 'lib/stripe/services/product_service.rb', line 339 def tax_behavior @tax_behavior end |
#unit_amount ⇒ Object
A positive integer in cents (or local equivalent) (or 0 for a free price) representing how much to charge. One of ‘unit_amount`, `unit_amount_decimal`, or `custom_unit_amount` is required.
342 343 344 |
# File 'lib/stripe/services/product_service.rb', line 342 def unit_amount @unit_amount end |
#unit_amount_decimal ⇒ Object
Same as ‘unit_amount`, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places. Only one of `unit_amount` and `unit_amount_decimal` can be set.
345 346 347 |
# File 'lib/stripe/services/product_service.rb', line 345 def unit_amount_decimal @unit_amount_decimal end |