Class: Stripe::ProductService::CreateParams::DefaultPriceData::CustomUnitAmount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ProductService::CreateParams::DefaultPriceData::CustomUnitAmount
- Defined in:
- lib/stripe/services/product_service.rb
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Pass in ‘true` to enable `custom_unit_amount`, otherwise omit `custom_unit_amount`.
-
#maximum ⇒ Object
The maximum unit amount the customer can specify for this item.
-
#minimum ⇒ Object
The minimum unit amount the customer can specify for this item.
-
#preset ⇒ Object
The starting unit amount which can be updated by the customer.
Instance Method Summary collapse
-
#initialize(enabled: nil, maximum: nil, minimum: nil, preset: nil) ⇒ CustomUnitAmount
constructor
A new instance of CustomUnitAmount.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, maximum: nil, minimum: nil, preset: nil) ⇒ CustomUnitAmount
Returns a new instance of CustomUnitAmount.
306 307 308 309 310 311 |
# File 'lib/stripe/services/product_service.rb', line 306 def initialize(enabled: nil, maximum: nil, minimum: nil, preset: nil) @enabled = enabled @maximum = maximum @minimum = minimum @preset = preset end |
Instance Attribute Details
#enabled ⇒ Object
Pass in ‘true` to enable `custom_unit_amount`, otherwise omit `custom_unit_amount`.
295 296 297 |
# File 'lib/stripe/services/product_service.rb', line 295 def enabled @enabled end |
#maximum ⇒ Object
The maximum unit amount the customer can specify for this item.
298 299 300 |
# File 'lib/stripe/services/product_service.rb', line 298 def maximum @maximum end |
#minimum ⇒ Object
The minimum unit amount the customer can specify for this item. Must be at least the minimum charge amount.
301 302 303 |
# File 'lib/stripe/services/product_service.rb', line 301 def minimum @minimum end |
#preset ⇒ Object
The starting unit amount which can be updated by the customer.
304 305 306 |
# File 'lib/stripe/services/product_service.rb', line 304 def preset @preset end |