Class: Stripe::ProductService::SearchParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/product_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, limit: nil, page: nil, query: nil) ⇒ SearchParams

Returns a new instance of SearchParams.



468
469
470
471
472
473
# File 'lib/stripe/services/product_service.rb', line 468

def initialize(expand: nil, limit: nil, page: nil, query: nil)
  @expand = expand
  @limit = limit
  @page = page
  @query = query
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



460
461
462
# File 'lib/stripe/services/product_service.rb', line 460

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



462
463
464
# File 'lib/stripe/services/product_service.rb', line 462

def limit
  @limit
end

#pageObject

A cursor for pagination across multiple pages of results. Don’t include this parameter on the first call. Use the next_page value returned in a previous response to request subsequent results.



464
465
466
# File 'lib/stripe/services/product_service.rb', line 464

def page
  @page
end

#queryObject

The search query string. See [search query language](stripe.com/docs/search#search-query-language) and the list of supported [query fields for products](stripe.com/docs/search#query-fields-for-products).



466
467
468
# File 'lib/stripe/services/product_service.rb', line 466

def query
  @query
end