Class: Stripe::PromotionCode::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/promotion_code.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(active: nil, code: nil, coupon: nil, created: nil, customer: nil, customer_account: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/stripe/resources/promotion_code.rb', line 90

def initialize(
  active: nil,
  code: nil,
  coupon: nil,
  created: nil,
  customer: nil,
  customer_account: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  starting_after: nil
)
  @active = active
  @code = code
  @coupon = coupon
  @created = created
  @customer = customer
  @customer_account = 
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
end

Instance Attribute Details

#activeObject

Filter promotion codes by whether they are active.



70
71
72
# File 'lib/stripe/resources/promotion_code.rb', line 70

def active
  @active
end

#codeObject

Only return promotion codes that have this case-insensitive code.



72
73
74
# File 'lib/stripe/resources/promotion_code.rb', line 72

def code
  @code
end

#couponObject

Only return promotion codes for this coupon.



74
75
76
# File 'lib/stripe/resources/promotion_code.rb', line 74

def coupon
  @coupon
end

#createdObject

A filter on the list, based on the object ‘created` field. The value can be a string with an integer Unix timestamp, or it can be a dictionary with a number of different query options.



76
77
78
# File 'lib/stripe/resources/promotion_code.rb', line 76

def created
  @created
end

#customerObject

Only return promotion codes that are restricted to this customer.



78
79
80
# File 'lib/stripe/resources/promotion_code.rb', line 78

def customer
  @customer
end

#customer_accountObject

Only return promotion codes that are restricted to this account.



80
81
82
# File 'lib/stripe/resources/promotion_code.rb', line 80

def 
  @customer_account
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



82
83
84
# File 'lib/stripe/resources/promotion_code.rb', line 82

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



84
85
86
# File 'lib/stripe/resources/promotion_code.rb', line 84

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



86
87
88
# File 'lib/stripe/resources/promotion_code.rb', line 86

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



88
89
90
# File 'lib/stripe/resources/promotion_code.rb', line 88

def starting_after
  @starting_after
end