Class: Stripe::PromotionCode::Restrictions

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/promotion_code.rb

Defined Under Namespace

Classes: CurrencyOptions

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#currency_optionsObject (readonly)

Promotion code restrictions defined in each available currency option. Each key must be a three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html) and a [supported currency](stripe.com/docs/currencies).



26
27
28
# File 'lib/stripe/resources/promotion_code.rb', line 26

def currency_options
  @currency_options
end

#first_time_transactionObject (readonly)

A Boolean indicating if the Promotion Code should only be redeemed for Customers without any successful payments or invoices



28
29
30
# File 'lib/stripe/resources/promotion_code.rb', line 28

def first_time_transaction
  @first_time_transaction
end

#minimum_amountObject (readonly)

Minimum amount required to redeem this Promotion Code into a Coupon (e.g., a purchase must be $100 or more to work).



30
31
32
# File 'lib/stripe/resources/promotion_code.rb', line 30

def minimum_amount
  @minimum_amount
end

#minimum_amount_currencyObject (readonly)

Three-letter [ISO code](stripe.com/docs/currencies) for minimum_amount



32
33
34
# File 'lib/stripe/resources/promotion_code.rb', line 32

def minimum_amount_currency
  @minimum_amount_currency
end