Class: Stripe::PromotionCode::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/promotion_code.rb

Defined Under Namespace

Classes: Restrictions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(active: nil, expand: nil, metadata: nil, restrictions: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



220
221
222
223
224
225
# File 'lib/stripe/resources/promotion_code.rb', line 220

def initialize(active: nil, expand: nil, metadata: nil, restrictions: nil)
  @active = active
  @expand = expand
  @metadata = 
  @restrictions = restrictions
end

Instance Attribute Details

#activeObject

Whether the promotion code is currently active. A promotion code can only be reactivated when the coupon is still valid and the promotion code is otherwise redeemable.



212
213
214
# File 'lib/stripe/resources/promotion_code.rb', line 212

def active
  @active
end

#expandObject

Specifies which fields in the response should be expanded.



214
215
216
# File 'lib/stripe/resources/promotion_code.rb', line 214

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



216
217
218
# File 'lib/stripe/resources/promotion_code.rb', line 216

def 
  @metadata
end

#restrictionsObject

Settings that restrict the redemption of the promotion code.



218
219
220
# File 'lib/stripe/resources/promotion_code.rb', line 218

def restrictions
  @restrictions
end