Class: Stripe::Quote::AutomaticTax
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Quote::AutomaticTax
- Defined in:
- lib/stripe/resources/quote.rb
Defined Under Namespace
Classes: Liability
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#enabled ⇒ Object
readonly
Automatically calculate taxes.
-
#liability ⇒ Object
readonly
The account that’s liable for tax.
-
#provider ⇒ Object
readonly
The tax provider powering automatic tax.
-
#status ⇒ Object
readonly
The status of the most recent automated tax calculation for this quote.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#enabled ⇒ Object (readonly)
Automatically calculate taxes
37 38 39 |
# File 'lib/stripe/resources/quote.rb', line 37 def enabled @enabled end |
#liability ⇒ Object (readonly)
The account that’s liable for tax. If set, the business address and tax registrations required to perform the tax calculation are loaded from this account. The tax transaction is returned in the report of the connected account.
39 40 41 |
# File 'lib/stripe/resources/quote.rb', line 39 def liability @liability end |
#provider ⇒ Object (readonly)
The tax provider powering automatic tax.
41 42 43 |
# File 'lib/stripe/resources/quote.rb', line 41 def provider @provider end |
#status ⇒ Object (readonly)
The status of the most recent automated tax calculation for this quote.
43 44 45 |
# File 'lib/stripe/resources/quote.rb', line 43 def status @status end |
Class Method Details
.field_remappings ⇒ Object
49 50 51 |
# File 'lib/stripe/resources/quote.rb', line 49 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
45 46 47 |
# File 'lib/stripe/resources/quote.rb', line 45 def self.inner_class_types @inner_class_types = { liability: Liability } end |