Class: Stripe::Quote::Computed::LastReestimationDetails::Failed

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#failure_codeObject (readonly)

The failure ‘code` is more granular than the `reason` provided and may correspond to a Stripe error code. For automation errors, this field is one of: `reverse_api_failure`, `reverse_api_deadline_exceeeded`, or `reverse_api_response_validation_error`, which are Stripe error codes and map to the error `message` field.



58
59
60
# File 'lib/stripe/resources/quote.rb', line 58

def failure_code
  @failure_code
end

#messageObject (readonly)

Information derived from the ‘failure_code` or a freeform message that explains the error as a human-readable English string. For example, “margin ID is not a valid ID”.



60
61
62
# File 'lib/stripe/resources/quote.rb', line 60

def message
  @message
end

#reasonObject (readonly)

The reason the reestimation failed.



62
63
64
# File 'lib/stripe/resources/quote.rb', line 62

def reason
  @reason
end

Class Method Details

.field_remappingsObject



68
69
70
# File 'lib/stripe/resources/quote.rb', line 68

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



64
65
66
# File 'lib/stripe/resources/quote.rb', line 64

def self.inner_class_types
  @inner_class_types = {}
end