Class: Stripe::Quote::Computed::Upfront

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: TotalDetails

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amount_subtotalObject (readonly)

Total before any discounts or taxes are applied.



249
250
251
# File 'lib/stripe/resources/quote.rb', line 249

def amount_subtotal
  @amount_subtotal
end

#amount_totalObject (readonly)

Total after discounts and taxes are applied.



251
252
253
# File 'lib/stripe/resources/quote.rb', line 251

def amount_total
  @amount_total
end

#line_itemsObject (readonly)

The line items that will appear on the next invoice after this quote is accepted. This does not include pending invoice items that exist on the customer but may still be included in the next invoice.



253
254
255
# File 'lib/stripe/resources/quote.rb', line 253

def line_items
  @line_items
end

#total_detailsObject (readonly)

Attribute for field total_details



255
256
257
# File 'lib/stripe/resources/quote.rb', line 255

def total_details
  @total_details
end

Class Method Details

.field_remappingsObject



261
262
263
# File 'lib/stripe/resources/quote.rb', line 261

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



257
258
259
# File 'lib/stripe/resources/quote.rb', line 257

def self.inner_class_types
  @inner_class_types = { total_details: TotalDetails }
end