Class: Stripe::Quote::CreateParams::AutomaticTax

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: Liability

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(enabled: nil, liability: nil) ⇒ AutomaticTax

Returns a new instance of AutomaticTax.



529
530
531
532
# File 'lib/stripe/resources/quote.rb', line 529

def initialize(enabled: nil, liability: nil)
  @enabled = enabled
  @liability = liability
end

Instance Attribute Details

#enabledObject

Controls whether Stripe will automatically compute tax on the resulting invoices or subscriptions as well as the quote itself.



525
526
527
# File 'lib/stripe/resources/quote.rb', line 525

def enabled
  @enabled
end

#liabilityObject

The account that’s liable for tax. If set, the business address and tax registrations required to perform the tax calculation are loaded from this account. The tax transaction is returned in the report of the connected account.



527
528
529
# File 'lib/stripe/resources/quote.rb', line 527

def liability
  @liability
end