Class: Stripe::Quote::CreateParams::Discount

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



982
983
984
985
986
987
# File 'lib/stripe/resources/quote.rb', line 982

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



974
975
976
# File 'lib/stripe/resources/quote.rb', line 974

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



976
977
978
# File 'lib/stripe/resources/quote.rb', line 976

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



978
979
980
# File 'lib/stripe/resources/quote.rb', line 978

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



980
981
982
# File 'lib/stripe/resources/quote.rb', line 980

def promotion_code
  @promotion_code
end