Class: Stripe::Quote::CreateParams::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



555
556
557
558
559
# File 'lib/stripe/resources/quote.rb', line 555

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



549
550
551
# File 'lib/stripe/resources/quote.rb', line 549

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



551
552
553
# File 'lib/stripe/resources/quote.rb', line 551

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



553
554
555
# File 'lib/stripe/resources/quote.rb', line 553

def type
  @type
end