Class: Stripe::Quote::CreateParams::FromQuote
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::CreateParams::FromQuote
- Defined in:
- lib/stripe/resources/quote.rb
Instance Attribute Summary collapse
-
#is_revision ⇒ Object
Whether this quote is a revision of the previous quote.
-
#quote ⇒ Object
The ‘id` of the quote that will be cloned.
Instance Method Summary collapse
-
#initialize(is_revision: nil, quote: nil) ⇒ FromQuote
constructor
A new instance of FromQuote.
Methods inherited from RequestParams
Constructor Details
#initialize(is_revision: nil, quote: nil) ⇒ FromQuote
Returns a new instance of FromQuote.
584 585 586 587 |
# File 'lib/stripe/resources/quote.rb', line 584 def initialize(is_revision: nil, quote: nil) @is_revision = is_revision @quote = quote end |
Instance Attribute Details
#is_revision ⇒ Object
Whether this quote is a revision of the previous quote.
580 581 582 |
# File 'lib/stripe/resources/quote.rb', line 580 def is_revision @is_revision end |
#quote ⇒ Object
The ‘id` of the quote that will be cloned.
582 583 584 |
# File 'lib/stripe/resources/quote.rb', line 582 def quote @quote end |