Class: Stripe::Quote::CreateParams::Line::Action::AddDiscount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ AddDiscount

Returns a new instance of AddDiscount.



1047
1048
1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
# File 'lib/stripe/resources/quote.rb', line 1047

def initialize(
  coupon: nil,
  discount: nil,
  discount_end: nil,
  index: nil,
  promotion_code: nil
)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @index = index
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to redeem.



1037
1038
1039
# File 'lib/stripe/resources/quote.rb', line 1037

def coupon
  @coupon
end

#discountObject

An ID of an existing discount for a coupon that was already redeemed.



1039
1040
1041
# File 'lib/stripe/resources/quote.rb', line 1039

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1041
1042
1043
# File 'lib/stripe/resources/quote.rb', line 1041

def discount_end
  @discount_end
end

#indexObject

The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the ‘discounts` array.



1043
1044
1045
# File 'lib/stripe/resources/quote.rb', line 1043

def index
  @index
end

#promotion_codeObject

The promotion code to redeem.



1045
1046
1047
# File 'lib/stripe/resources/quote.rb', line 1045

def promotion_code
  @promotion_code
end