Class: Stripe::Quote::CreateParams::Line::Action::AddDiscount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::CreateParams::Line::Action::AddDiscount::DiscountEnd
- Defined in:
- lib/stripe/resources/quote.rb
Instance Attribute Summary collapse
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
615 616 617 |
# File 'lib/stripe/resources/quote.rb', line 615 def initialize(type: nil) @type = type end |
Instance Attribute Details
#type ⇒ Object
The type of calculation made to determine when the discount ends.
613 614 615 |
# File 'lib/stripe/resources/quote.rb', line 613 def type @type end |