Class: Stripe::Quote::CreateParams::Line::Action::AddItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: Discount, Trial

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ AddItem

Returns a new instance of AddItem.



1130
1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
# File 'lib/stripe/resources/quote.rb', line 1130

def initialize(
  discounts: nil,
  metadata: nil,
  price: nil,
  quantity: nil,
  tax_rates: nil,
  trial: nil
)
  @discounts = discounts
  @metadata = 
  @price = price
  @quantity = quantity
  @tax_rates = tax_rates
  @trial = trial
end

Instance Attribute Details

#discountsObject

The discounts applied to the item. Subscription item discounts are applied before subscription discounts.



1118
1119
1120
# File 'lib/stripe/resources/quote.rb', line 1118

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1120
1121
1122
# File 'lib/stripe/resources/quote.rb', line 1120

def 
  @metadata
end

#priceObject

The ID of the price object.



1122
1123
1124
# File 'lib/stripe/resources/quote.rb', line 1122

def price
  @price
end

#quantityObject

Quantity for this item.



1124
1125
1126
# File 'lib/stripe/resources/quote.rb', line 1124

def quantity
  @quantity
end

#tax_ratesObject

The tax rates that apply to this subscription item. When set, the ‘default_tax_rates` on the subscription do not apply to this `subscription_item`.



1126
1127
1128
# File 'lib/stripe/resources/quote.rb', line 1126

def tax_rates
  @tax_rates
end

#trialObject

Options that configure the trial on the subscription item.



1128
1129
1130
# File 'lib/stripe/resources/quote.rb', line 1128

def trial
  @trial
end