Class: Stripe::Quote::CreateParams::Line::Action::AddItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



671
672
673
674
675
# File 'lib/stripe/resources/quote.rb', line 671

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



665
666
667
# File 'lib/stripe/resources/quote.rb', line 665

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



667
668
669
# File 'lib/stripe/resources/quote.rb', line 667

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



669
670
671
# File 'lib/stripe/resources/quote.rb', line 669

def type
  @type
end