Class: Stripe::Quote::CreateParams::Line::Action::RemoveDiscount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ RemoveDiscount

Returns a new instance of RemoveDiscount.



743
744
745
746
747
# File 'lib/stripe/resources/quote.rb', line 743

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to remove from the ‘discounts` array.



737
738
739
# File 'lib/stripe/resources/quote.rb', line 737

def coupon
  @coupon
end

#discountObject

The ID of a discount to remove from the ‘discounts` array.



739
740
741
# File 'lib/stripe/resources/quote.rb', line 739

def discount
  @discount
end

#promotion_codeObject

The ID of a promotion code to remove from the ‘discounts` array.



741
742
743
# File 'lib/stripe/resources/quote.rb', line 741

def promotion_code
  @promotion_code
end