Class: Stripe::Quote::CreateParams::Line::Action::SetDiscount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ SetDiscount

Returns a new instance of SetDiscount.



1179
1180
1181
1182
1183
# File 'lib/stripe/resources/quote.rb', line 1179

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to replace the ‘discounts` array with.



1173
1174
1175
# File 'lib/stripe/resources/quote.rb', line 1173

def coupon
  @coupon
end

#discountObject

An ID of an existing discount to replace the ‘discounts` array with.



1175
1176
1177
# File 'lib/stripe/resources/quote.rb', line 1175

def discount
  @discount
end

#promotion_codeObject

An ID of an existing promotion code to replace the ‘discounts` array with.



1177
1178
1179
# File 'lib/stripe/resources/quote.rb', line 1177

def promotion_code
  @promotion_code
end