Class: Stripe::Quote::CreateParams::Line::Action::SetItem::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::CreateParams::Line::Action::SetItem::Discount::DiscountEnd
- Defined in:
- lib/stripe/resources/quote.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
782 783 784 785 786 |
# File 'lib/stripe/resources/quote.rb', line 782 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
776 777 778 |
# File 'lib/stripe/resources/quote.rb', line 776 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
778 779 780 |
# File 'lib/stripe/resources/quote.rb', line 778 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
780 781 782 |
# File 'lib/stripe/resources/quote.rb', line 780 def type @type end |