Class: Stripe::Quote::CreateParams::Line::AppliesTo

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(new_reference: nil, subscription_schedule: nil, type: nil) ⇒ AppliesTo

Returns a new instance of AppliesTo.



912
913
914
915
916
# File 'lib/stripe/resources/quote.rb', line 912

def initialize(new_reference: nil, subscription_schedule: nil, type: nil)
  @new_reference = new_reference
  @subscription_schedule = subscription_schedule
  @type = type
end

Instance Attribute Details

#new_referenceObject

A custom string that identifies a new subscription schedule being created upon quote acceptance. All quote lines with the same ‘new_reference` field will be applied to the creation of a new subscription schedule.



906
907
908
# File 'lib/stripe/resources/quote.rb', line 906

def new_reference
  @new_reference
end

#subscription_scheduleObject

The ID of the schedule the line applies to.



908
909
910
# File 'lib/stripe/resources/quote.rb', line 908

def subscription_schedule
  @subscription_schedule
end

#typeObject

Describes whether the quote line is affecting a new schedule or an existing schedule.



910
911
912
# File 'lib/stripe/resources/quote.rb', line 910

def type
  @type
end