Class: Stripe::Quote::CreateParams::Line::CancelSubscriptionSchedule
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::CreateParams::Line::CancelSubscriptionSchedule
- Defined in:
- lib/stripe/resources/quote.rb
Instance Attribute Summary collapse
-
#cancel_at ⇒ Object
Timestamp helper to cancel the underlying schedule on the accompanying line’s start date.
-
#invoice_now ⇒ Object
If the subscription schedule is ‘active`, indicates if a final invoice will be generated that contains any un-invoiced metered usage and new/pending proration invoice items.
-
#prorate ⇒ Object
If the subscription schedule is ‘active`, indicates if the cancellation should be prorated.
Instance Method Summary collapse
-
#initialize(cancel_at: nil, invoice_now: nil, prorate: nil) ⇒ CancelSubscriptionSchedule
constructor
A new instance of CancelSubscriptionSchedule.
Methods inherited from RequestParams
Constructor Details
#initialize(cancel_at: nil, invoice_now: nil, prorate: nil) ⇒ CancelSubscriptionSchedule
Returns a new instance of CancelSubscriptionSchedule.
1339 1340 1341 1342 1343 |
# File 'lib/stripe/resources/quote.rb', line 1339 def initialize(cancel_at: nil, invoice_now: nil, prorate: nil) @cancel_at = cancel_at @invoice_now = invoice_now @prorate = prorate end |
Instance Attribute Details
#cancel_at ⇒ Object
Timestamp helper to cancel the underlying schedule on the accompanying line’s start date. Must be set to ‘line_starts_at`.
1333 1334 1335 |
# File 'lib/stripe/resources/quote.rb', line 1333 def cancel_at @cancel_at end |
#invoice_now ⇒ Object
If the subscription schedule is ‘active`, indicates if a final invoice will be generated that contains any un-invoiced metered usage and new/pending proration invoice items. Boolean that defaults to `true`.
1335 1336 1337 |
# File 'lib/stripe/resources/quote.rb', line 1335 def invoice_now @invoice_now end |
#prorate ⇒ Object
If the subscription schedule is ‘active`, indicates if the cancellation should be prorated. Boolean that defaults to `true`.
1337 1338 1339 |
# File 'lib/stripe/resources/quote.rb', line 1337 def prorate @prorate end |