Class: Stripe::Quote::CreateParams::Line::EndsAt
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::CreateParams::Line::EndsAt
- Defined in:
- lib/stripe/resources/quote.rb
Defined Under Namespace
Classes: DiscountEnd, Duration
Instance Attribute Summary collapse
-
#discount_end ⇒ Object
Use the ‘end` time of a given discount.
-
#duration ⇒ Object
Time span for the quote line starting from the ‘starts_at` date.
-
#timestamp ⇒ Object
A precise Unix timestamp.
-
#type ⇒ Object
Select a way to pass in ‘ends_at`.
Instance Method Summary collapse
-
#initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ EndsAt
constructor
A new instance of EndsAt.
Methods inherited from RequestParams
Constructor Details
#initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ EndsAt
Returns a new instance of EndsAt.
957 958 959 960 961 962 |
# File 'lib/stripe/resources/quote.rb', line 957 def initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) @discount_end = discount_end @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#discount_end ⇒ Object
Use the ‘end` time of a given discount.
949 950 951 |
# File 'lib/stripe/resources/quote.rb', line 949 def discount_end @discount_end end |
#duration ⇒ Object
Time span for the quote line starting from the ‘starts_at` date.
951 952 953 |
# File 'lib/stripe/resources/quote.rb', line 951 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp.
953 954 955 |
# File 'lib/stripe/resources/quote.rb', line 953 def @timestamp end |
#type ⇒ Object
Select a way to pass in ‘ends_at`.
955 956 957 |
# File 'lib/stripe/resources/quote.rb', line 955 def type @type end |