Class: Stripe::Quote::CreateParams::Line::EndsAt::Duration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(interval: nil, interval_count: nil) ⇒ Duration

Returns a new instance of Duration.



950
951
952
953
# File 'lib/stripe/resources/quote.rb', line 950

def initialize(interval: nil, interval_count: nil)
  @interval = interval
  @interval_count = interval_count
end

Instance Attribute Details

#intervalObject

Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.



946
947
948
# File 'lib/stripe/resources/quote.rb', line 946

def interval
  @interval
end

#interval_countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



948
949
950
# File 'lib/stripe/resources/quote.rb', line 948

def interval_count
  @interval_count
end