Class: Stripe::Quote::CreateParams::Line::TrialSettings::EndBehavior
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::CreateParams::Line::TrialSettings::EndBehavior
- Defined in:
- lib/stripe/resources/quote.rb
Instance Attribute Summary collapse
-
#prorate_up_front ⇒ Object
Configure how an opt-in following a paid trial is billed when using ‘billing_behavior: prorate_up_front`.
Instance Method Summary collapse
-
#initialize(prorate_up_front: nil) ⇒ EndBehavior
constructor
A new instance of EndBehavior.
Methods inherited from RequestParams
Constructor Details
#initialize(prorate_up_front: nil) ⇒ EndBehavior
Returns a new instance of EndBehavior.
1025 1026 1027 |
# File 'lib/stripe/resources/quote.rb', line 1025 def initialize(prorate_up_front: nil) @prorate_up_front = prorate_up_front end |
Instance Attribute Details
#prorate_up_front ⇒ Object
Configure how an opt-in following a paid trial is billed when using ‘billing_behavior: prorate_up_front`.
1023 1024 1025 |
# File 'lib/stripe/resources/quote.rb', line 1023 def prorate_up_front @prorate_up_front end |