Class: Stripe::Quote::CreateParams::LineItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



1522
1523
1524
1525
1526
# File 'lib/stripe/resources/quote.rb', line 1522

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



1516
1517
1518
# File 'lib/stripe/resources/quote.rb', line 1516

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



1518
1519
1520
# File 'lib/stripe/resources/quote.rb', line 1518

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



1520
1521
1522
# File 'lib/stripe/resources/quote.rb', line 1520

def type
  @type
end