Class: Stripe::Quote::CreateParams::LineItem::Discount::DiscountEnd::Duration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(interval: nil, interval_count: nil) ⇒ Duration

Returns a new instance of Duration.



1098
1099
1100
1101
# File 'lib/stripe/resources/quote.rb', line 1098

def initialize(interval: nil, interval_count: nil)
  @interval = interval
  @interval_count = interval_count
end

Instance Attribute Details

#intervalObject

Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.



1094
1095
1096
# File 'lib/stripe/resources/quote.rb', line 1094

def interval
  @interval
end

#interval_countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



1096
1097
1098
# File 'lib/stripe/resources/quote.rb', line 1096

def interval_count
  @interval_count
end