Class: Stripe::Quote::CreateParams::SubscriptionData::BillOnAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: BillFrom, BillUntil

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bill_from: nil, bill_until: nil) ⇒ BillOnAcceptance

Returns a new instance of BillOnAcceptance.



1267
1268
1269
1270
# File 'lib/stripe/resources/quote.rb', line 1267

def initialize(bill_from: nil, bill_until: nil)
  @bill_from = bill_from
  @bill_until = bill_until
end

Instance Attribute Details

#bill_fromObject

The start of the period to bill from when the Quote is accepted.



1263
1264
1265
# File 'lib/stripe/resources/quote.rb', line 1263

def bill_from
  @bill_from
end

#bill_untilObject

The end of the period to bill until when the Quote is accepted.



1265
1266
1267
# File 'lib/stripe/resources/quote.rb', line 1265

def bill_until
  @bill_until
end