Class: Stripe::Quote::CreateParams::SubscriptionData::BillOnAcceptance::BillUntil
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::CreateParams::SubscriptionData::BillOnAcceptance::BillUntil
- Defined in:
- lib/stripe/resources/quote.rb
Defined Under Namespace
Classes: Duration, LineEndsAt
Instance Attribute Summary collapse
-
#duration ⇒ Object
Details of the duration over which to bill.
-
#line_ends_at ⇒ Object
Details of a Quote line item from which to bill until.
-
#timestamp ⇒ Object
A precise Unix timestamp.
-
#type ⇒ Object
The type of method to specify the ‘bill_until` time.
Instance Method Summary collapse
-
#initialize(duration: nil, line_ends_at: nil, timestamp: nil, type: nil) ⇒ BillUntil
constructor
A new instance of BillUntil.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, line_ends_at: nil, timestamp: nil, type: nil) ⇒ BillUntil
Returns a new instance of BillUntil.
1667 1668 1669 1670 1671 1672 |
# File 'lib/stripe/resources/quote.rb', line 1667 def initialize(duration: nil, line_ends_at: nil, timestamp: nil, type: nil) @duration = duration @line_ends_at = line_ends_at @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Details of the duration over which to bill.
1659 1660 1661 |
# File 'lib/stripe/resources/quote.rb', line 1659 def duration @duration end |
#line_ends_at ⇒ Object
Details of a Quote line item from which to bill until.
1661 1662 1663 |
# File 'lib/stripe/resources/quote.rb', line 1661 def line_ends_at @line_ends_at end |
#timestamp ⇒ Object
A precise Unix timestamp.
1663 1664 1665 |
# File 'lib/stripe/resources/quote.rb', line 1663 def @timestamp end |
#type ⇒ Object
The type of method to specify the ‘bill_until` time.
1665 1666 1667 |
# File 'lib/stripe/resources/quote.rb', line 1665 def type @type end |