Class: Stripe::Quote::CreateParams::SubscriptionDataOverride::BillOnAcceptance::BillFrom::LineStartsAt

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(id: nil, index: nil) ⇒ LineStartsAt

Returns a new instance of LineStartsAt.



1360
1361
1362
1363
# File 'lib/stripe/resources/quote.rb', line 1360

def initialize(id: nil, index: nil)
  @id = id
  @index = index
end

Instance Attribute Details

#idObject

The ID of a quote line.



1356
1357
1358
# File 'lib/stripe/resources/quote.rb', line 1356

def id
  @id
end

#indexObject

The position of the previous quote line in the ‘lines` array after which this line should begin. Indexes start from 0 and must be less than the index of the current line in the array.



1358
1359
1360
# File 'lib/stripe/resources/quote.rb', line 1358

def index
  @index
end