Class: Stripe::Quote::CreateParams::SubscriptionDataOverride::BillOnAcceptance::BillUntil::LineEndsAt
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::CreateParams::SubscriptionDataOverride::BillOnAcceptance::BillUntil::LineEndsAt
- Defined in:
- lib/stripe/resources/quote.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
The ID of a quote line.
-
#index ⇒ Object
The position of the previous quote line in the ‘lines` array after which this line should begin.
Instance Method Summary collapse
-
#initialize(id: nil, index: nil) ⇒ LineEndsAt
constructor
A new instance of LineEndsAt.
Methods inherited from RequestParams
Constructor Details
#initialize(id: nil, index: nil) ⇒ LineEndsAt
Returns a new instance of LineEndsAt.
1824 1825 1826 1827 |
# File 'lib/stripe/resources/quote.rb', line 1824 def initialize(id: nil, index: nil) @id = id @index = index end |
Instance Attribute Details
#id ⇒ Object
The ID of a quote line.
1820 1821 1822 |
# File 'lib/stripe/resources/quote.rb', line 1820 def id @id end |
#index ⇒ Object
The position of the previous quote line in the ‘lines` array after which this line should begin. Indexes start from 0 and must be less than the index of the current line in the array.
1822 1823 1824 |
# File 'lib/stripe/resources/quote.rb', line 1822 def index @index end |