Class: Stripe::Quote::CreateParams::TransferData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::CreateParams::TransferData
- Defined in:
- lib/stripe/resources/quote.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount that will be transferred automatically when the invoice is paid.
-
#amount_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places.
-
#destination ⇒ Object
ID of an existing, connected Stripe account.
Instance Method Summary collapse
-
#initialize(amount: nil, amount_percent: nil, destination: nil) ⇒ TransferData
constructor
A new instance of TransferData.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, amount_percent: nil, destination: nil) ⇒ TransferData
Returns a new instance of TransferData.
1491 1492 1493 1494 1495 |
# File 'lib/stripe/resources/quote.rb', line 1491 def initialize(amount: nil, amount_percent: nil, destination: nil) @amount = amount @amount_percent = amount_percent @destination = destination end |
Instance Attribute Details
#amount ⇒ Object
The amount that will be transferred automatically when the invoice is paid. If no amount is set, the full amount is transferred. There cannot be any line items with recurring prices when using this field.
1485 1486 1487 |
# File 'lib/stripe/resources/quote.rb', line 1485 def amount @amount end |
#amount_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination. There must be at least 1 line item with a recurring price to use this field.
1487 1488 1489 |
# File 'lib/stripe/resources/quote.rb', line 1487 def amount_percent @amount_percent end |
#destination ⇒ Object
ID of an existing, connected Stripe account.
1489 1490 1491 |
# File 'lib/stripe/resources/quote.rb', line 1489 def destination @destination end |