Class: Stripe::Quote::FinalizeQuoteParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/quote.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, expires_at: nil) ⇒ FinalizeQuoteParams

Returns a new instance of FinalizeQuoteParams.



2720
2721
2722
2723
# File 'lib/stripe/resources/quote.rb', line 2720

def initialize(expand: nil, expires_at: nil)
  @expand = expand
  @expires_at = expires_at
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



2716
2717
2718
# File 'lib/stripe/resources/quote.rb', line 2716

def expand
  @expand
end

#expires_atObject

A future timestamp on which the quote will be canceled if in ‘open` or `draft` status. Measured in seconds since the Unix epoch.



2718
2719
2720
# File 'lib/stripe/resources/quote.rb', line 2718

def expires_at
  @expires_at
end