Class: Stripe::Quote::ListComputedUpfrontLineItemsParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::ListComputedUpfrontLineItemsParams
- Defined in:
- lib/stripe/resources/quote.rb
Instance Attribute Summary collapse
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#starting_after ⇒ Object
A cursor for use in pagination.
Instance Method Summary collapse
-
#initialize(ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListComputedUpfrontLineItemsParams
constructor
A new instance of ListComputedUpfrontLineItemsParams.
Methods inherited from RequestParams
Constructor Details
#initialize(ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListComputedUpfrontLineItemsParams
Returns a new instance of ListComputedUpfrontLineItemsParams.
824 825 826 827 828 829 |
# File 'lib/stripe/resources/quote.rb', line 824 def initialize(ending_before: nil, expand: nil, limit: nil, starting_after: nil) @ending_before = ending_before @expand = @limit = limit @starting_after = starting_after end |
Instance Attribute Details
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
816 817 818 |
# File 'lib/stripe/resources/quote.rb', line 816 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
818 819 820 |
# File 'lib/stripe/resources/quote.rb', line 818 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
820 821 822 |
# File 'lib/stripe/resources/quote.rb', line 820 def limit @limit end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
822 823 824 |
# File 'lib/stripe/resources/quote.rb', line 822 def starting_after @starting_after end |