Class: Stripe::Quote::ListLinesParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/quote.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListLinesParams

Returns a new instance of ListLinesParams.



3102
3103
3104
3105
3106
3107
# File 'lib/stripe/resources/quote.rb', line 3102

def initialize(ending_before: nil, expand: nil, limit: nil, starting_after: nil)
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
end

Instance Attribute Details

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



3091
3092
3093
# File 'lib/stripe/resources/quote.rb', line 3091

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



3094
3095
3096
# File 'lib/stripe/resources/quote.rb', line 3094

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



3097
3098
3099
# File 'lib/stripe/resources/quote.rb', line 3097

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



3100
3101
3102
# File 'lib/stripe/resources/quote.rb', line 3100

def starting_after
  @starting_after
end