Class: Stripe::Quote::MarkDraftParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::MarkDraftParams
- Defined in:
- lib/stripe/resources/quote.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ MarkDraftParams
constructor
A new instance of MarkDraftParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ MarkDraftParams
Returns a new instance of MarkDraftParams.
2755 2756 2757 |
# File 'lib/stripe/resources/quote.rb', line 2755 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2753 2754 2755 |
# File 'lib/stripe/resources/quote.rb', line 2753 def @expand end |