Class: Stripe::Quote::MarkStaleParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::MarkStaleParams
- Defined in:
- lib/stripe/resources/quote.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#reason ⇒ Object
Reason the Quote is being marked stale.
Instance Method Summary collapse
-
#initialize(expand: nil, reason: nil) ⇒ MarkStaleParams
constructor
A new instance of MarkStaleParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, reason: nil) ⇒ MarkStaleParams
Returns a new instance of MarkStaleParams.
3178 3179 3180 3181 |
# File 'lib/stripe/resources/quote.rb', line 3178 def initialize(expand: nil, reason: nil) @expand = @reason = reason end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
3174 3175 3176 |
# File 'lib/stripe/resources/quote.rb', line 3174 def @expand end |
#reason ⇒ Object
Reason the Quote is being marked stale.
3176 3177 3178 |
# File 'lib/stripe/resources/quote.rb', line 3176 def reason @reason end |