Class: Stripe::Quote::PdfParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::PdfParams
- Defined in:
- lib/stripe/resources/quote.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ PdfParams
constructor
A new instance of PdfParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ PdfParams
Returns a new instance of PdfParams.
3197 3198 3199 |
# File 'lib/stripe/resources/quote.rb', line 3197 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
3195 3196 3197 |
# File 'lib/stripe/resources/quote.rb', line 3195 def @expand end |