Class: Stripe::Quote::ReestimateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::ReestimateParams
- Defined in:
- lib/stripe/resources/quote.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ ReestimateParams
constructor
A new instance of ReestimateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ ReestimateParams
Returns a new instance of ReestimateParams.
2762 2763 2764 |
# File 'lib/stripe/resources/quote.rb', line 2762 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2760 2761 2762 |
# File 'lib/stripe/resources/quote.rb', line 2760 def @expand end |