Class: Stripe::Quote::SubscriptionData
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Quote::SubscriptionData
- Defined in:
- lib/stripe/resources/quote.rb
Defined Under Namespace
Classes: BillOnAcceptance, BillingMode, BillingSchedule, Prebilling
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bill_on_acceptance ⇒ Object
readonly
Describes the period to bill for upon accepting the quote.
-
#billing_behavior ⇒ Object
readonly
Configures when the subscription schedule generates prorations for phase transitions.
-
#billing_cycle_anchor ⇒ Object
readonly
Whether the subscription will always start a new billing period when the quote is accepted.
-
#billing_mode ⇒ Object
readonly
The billing mode of the quote.
-
#billing_schedules ⇒ Object
readonly
Billing schedules that will be applied to the subscription or subscription schedule created from this quote.
-
#description ⇒ Object
readonly
The subscription's description, meant to be displayable to the customer.
-
#effective_date ⇒ Object
readonly
When creating a new subscription, the date of which the subscription schedule will start after the quote is accepted.
-
#end_behavior ⇒ Object
readonly
Behavior of the subscription schedule and underlying subscription when it ends.
-
#from_subscription ⇒ Object
readonly
The id of the subscription that will be updated when the quote is accepted.
-
#metadata ⇒ Object
readonly
Set of key-value pairs that will set metadata on the subscription or subscription schedule when the quote is accepted.
-
#phase_effective_at ⇒ Object
readonly
Configures how the subscription schedule handles billing for phase transitions when the quote is accepted.
-
#prebilling ⇒ Object
readonly
If specified, the invoicing for the given billing cycle iterations will be processed when the quote is accepted.
-
#proration_behavior ⇒ Object
readonly
Determines how to handle prorations when the quote is accepted.
-
#trial_period_days ⇒ Object
readonly
Integer representing the number of trial period days before the customer is charged for the first time.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bill_on_acceptance ⇒ Object (readonly)
Describes the period to bill for upon accepting the quote.
737 738 739 |
# File 'lib/stripe/resources/quote.rb', line 737 def bill_on_acceptance @bill_on_acceptance end |
#billing_behavior ⇒ Object (readonly)
Configures when the subscription schedule generates prorations for phase transitions. Possible values are prorate_on_next_phase or prorate_up_front with the default being prorate_on_next_phase. prorate_on_next_phase will apply phase changes and generate prorations at transition time. prorate_up_front will bill for all phases within the current billing cycle up front.
739 740 741 |
# File 'lib/stripe/resources/quote.rb', line 739 def billing_behavior @billing_behavior end |
#billing_cycle_anchor ⇒ Object (readonly)
Whether the subscription will always start a new billing period when the quote is accepted.
741 742 743 |
# File 'lib/stripe/resources/quote.rb', line 741 def billing_cycle_anchor @billing_cycle_anchor end |
#billing_mode ⇒ Object (readonly)
The billing mode of the quote.
743 744 745 |
# File 'lib/stripe/resources/quote.rb', line 743 def billing_mode @billing_mode end |
#billing_schedules ⇒ Object (readonly)
Billing schedules that will be applied to the subscription or subscription schedule created from this quote.
745 746 747 |
# File 'lib/stripe/resources/quote.rb', line 745 def billing_schedules @billing_schedules end |
#description ⇒ Object (readonly)
The subscription's description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.
747 748 749 |
# File 'lib/stripe/resources/quote.rb', line 747 def description @description end |
#effective_date ⇒ Object (readonly)
When creating a new subscription, the date of which the subscription schedule will start after the quote is accepted. This date is ignored if it is in the past when the quote is accepted. Measured in seconds since the Unix epoch.
749 750 751 |
# File 'lib/stripe/resources/quote.rb', line 749 def effective_date @effective_date end |
#end_behavior ⇒ Object (readonly)
Behavior of the subscription schedule and underlying subscription when it ends.
751 752 753 |
# File 'lib/stripe/resources/quote.rb', line 751 def end_behavior @end_behavior end |
#from_subscription ⇒ Object (readonly)
The id of the subscription that will be updated when the quote is accepted.
753 754 755 |
# File 'lib/stripe/resources/quote.rb', line 753 def from_subscription @from_subscription end |
#metadata ⇒ Object (readonly)
Set of key-value pairs that will set metadata on the subscription or subscription schedule when the quote is accepted. If a recurring price is included in line_items, this field will be passed to the resulting subscription's metadata field. If subscription_data.effective_date is used, this field will be passed to the resulting subscription schedule's phases.metadata field. Unlike object-level metadata, this field is declarative. Updates will clear prior values.
755 756 757 |
# File 'lib/stripe/resources/quote.rb', line 755 def @metadata end |
#phase_effective_at ⇒ Object (readonly)
Configures how the subscription schedule handles billing for phase transitions when the quote is accepted.
757 758 759 |
# File 'lib/stripe/resources/quote.rb', line 757 def phase_effective_at @phase_effective_at end |
#prebilling ⇒ Object (readonly)
If specified, the invoicing for the given billing cycle iterations will be processed when the quote is accepted. Cannot be used with effective_date.
759 760 761 |
# File 'lib/stripe/resources/quote.rb', line 759 def prebilling @prebilling end |
#proration_behavior ⇒ Object (readonly)
Determines how to handle prorations when the quote is accepted.
761 762 763 |
# File 'lib/stripe/resources/quote.rb', line 761 def proration_behavior @proration_behavior end |
#trial_period_days ⇒ Object (readonly)
Integer representing the number of trial period days before the customer is charged for the first time.
763 764 765 |
# File 'lib/stripe/resources/quote.rb', line 763 def trial_period_days @trial_period_days end |
Class Method Details
.field_remappings ⇒ Object
774 775 776 |
# File 'lib/stripe/resources/quote.rb', line 774 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
765 766 767 768 769 770 771 772 |
# File 'lib/stripe/resources/quote.rb', line 765 def self.inner_class_types @inner_class_types = { bill_on_acceptance: BillOnAcceptance, billing_mode: BillingMode, billing_schedules: BillingSchedule, prebilling: Prebilling, } end |