Class: Stripe::Quote::SubscriptionData::BillOnAcceptance

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: BillFrom, BillUntil

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bill_fromObject (readonly)

The start of the period to bill from when the Quote is accepted.



551
552
553
# File 'lib/stripe/resources/quote.rb', line 551

def bill_from
  @bill_from
end

#bill_untilObject (readonly)

The end of the period to bill until when the Quote is accepted.



553
554
555
# File 'lib/stripe/resources/quote.rb', line 553

def bill_until
  @bill_until
end

Class Method Details

.field_remappingsObject



559
560
561
# File 'lib/stripe/resources/quote.rb', line 559

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



555
556
557
# File 'lib/stripe/resources/quote.rb', line 555

def self.inner_class_types
  @inner_class_types = { bill_from: BillFrom, bill_until: BillUntil }
end