Class: Stripe::Quote::SubscriptionData::BillOnAcceptance::BillUntil::Duration
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Quote::SubscriptionData::BillOnAcceptance::BillUntil::Duration
- Defined in:
- lib/stripe/resources/quote.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#interval ⇒ Object
readonly
Specifies a type of interval unit.
-
#interval_count ⇒ Object
readonly
The number of intervals, as an whole number greater than 0.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#interval ⇒ Object (readonly)
Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.
274 275 276 |
# File 'lib/stripe/resources/quote.rb', line 274 def interval @interval end |
#interval_count ⇒ Object (readonly)
The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.
276 277 278 |
# File 'lib/stripe/resources/quote.rb', line 276 def interval_count @interval_count end |