Class: Stripe::Quote::SubscriptionData::BillingSchedule::BillFrom

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: LineStartsAt

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#computed_timestampObject (readonly)

The time the billing schedule applies from.



642
643
644
# File 'lib/stripe/resources/quote.rb', line 642

def computed_timestamp
  @computed_timestamp
end

#line_starts_atObject (readonly)

Lets you bill the period starting from a particular Quote line.



644
645
646
# File 'lib/stripe/resources/quote.rb', line 644

def line_starts_at
  @line_starts_at
end

#timestampObject (readonly)

Use a precise Unix timestamp for prebilling to start. Must be earlier than bill_until.



646
647
648
# File 'lib/stripe/resources/quote.rb', line 646

def timestamp
  @timestamp
end

#typeObject (readonly)

Describes how the billing schedule determines the start date. Possible values are timestamp, relative, amendment_start, now, quote_acceptance_date, line_starts_at, or pause_collection_start.



648
649
650
# File 'lib/stripe/resources/quote.rb', line 648

def type
  @type
end

Class Method Details

.field_remappingsObject



654
655
656
# File 'lib/stripe/resources/quote.rb', line 654

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



650
651
652
# File 'lib/stripe/resources/quote.rb', line 650

def self.inner_class_types
  @inner_class_types = { line_starts_at: LineStartsAt }
end