Class: Stripe::Quote::SubscriptionData::BillingSchedule::BillUntil

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: Duration, LineEndsAt

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#computed_timestampObject (readonly)

The timestamp the billing schedule will apply until.



688
689
690
# File 'lib/stripe/resources/quote.rb', line 688

def computed_timestamp
  @computed_timestamp
end

#durationObject (readonly)

Specifies the billing period.



690
691
692
# File 'lib/stripe/resources/quote.rb', line 690

def duration
  @duration
end

#line_ends_atObject (readonly)

Lets you bill the period ending at a particular Quote line.



692
693
694
# File 'lib/stripe/resources/quote.rb', line 692

def line_ends_at
  @line_ends_at
end

#timestampObject (readonly)

If specified, the billing schedule will apply until the specified timestamp.



694
695
696
# File 'lib/stripe/resources/quote.rb', line 694

def timestamp
  @timestamp
end

#typeObject (readonly)

Describes how the billing schedule will determine the end date. Either duration or timestamp.



696
697
698
# File 'lib/stripe/resources/quote.rb', line 696

def type
  @type
end

Class Method Details

.field_remappingsObject



702
703
704
# File 'lib/stripe/resources/quote.rb', line 702

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



698
699
700
# File 'lib/stripe/resources/quote.rb', line 698

def self.inner_class_types
  @inner_class_types = { duration: Duration, line_ends_at: LineEndsAt }
end