Class: Stripe::Quote::SubscriptionDataOverride::AppliesTo
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Quote::SubscriptionDataOverride::AppliesTo
- Defined in:
- lib/stripe/resources/quote.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#new_reference ⇒ Object
readonly
A custom string that identifies a new subscription schedule being created upon quote acceptance.
-
#subscription_schedule ⇒ Object
readonly
The ID of the schedule the line applies to.
-
#type ⇒ Object
readonly
Describes whether the quote line is affecting a new schedule or an existing schedule.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#new_reference ⇒ Object (readonly)
A custom string that identifies a new subscription schedule being created upon quote acceptance. All quote lines with the same ‘new_reference` field will be applied to the creation of a new subscription schedule.
644 645 646 |
# File 'lib/stripe/resources/quote.rb', line 644 def new_reference @new_reference end |
#subscription_schedule ⇒ Object (readonly)
The ID of the schedule the line applies to.
646 647 648 |
# File 'lib/stripe/resources/quote.rb', line 646 def subscription_schedule @subscription_schedule end |
#type ⇒ Object (readonly)
Describes whether the quote line is affecting a new schedule or an existing schedule.
648 649 650 |
# File 'lib/stripe/resources/quote.rb', line 648 def type @type end |
Class Method Details
.field_remappings ⇒ Object
654 655 656 |
# File 'lib/stripe/resources/quote.rb', line 654 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
650 651 652 |
# File 'lib/stripe/resources/quote.rb', line 650 def self.inner_class_types @inner_class_types = {} end |