Class: Stripe::Quote::SubscriptionDataOverride::BillOnAcceptance

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: BillFrom, BillUntil

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bill_fromObject (readonly)

The start of the period to bill from when the Quote is accepted.



856
857
858
# File 'lib/stripe/resources/quote.rb', line 856

def bill_from
  @bill_from
end

#bill_untilObject (readonly)

The end of the period to bill until when the Quote is accepted.



858
859
860
# File 'lib/stripe/resources/quote.rb', line 858

def bill_until
  @bill_until
end

Class Method Details

.field_remappingsObject



864
865
866
# File 'lib/stripe/resources/quote.rb', line 864

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



860
861
862
# File 'lib/stripe/resources/quote.rb', line 860

def self.inner_class_types
  @inner_class_types = { bill_from: BillFrom, bill_until: BillUntil }
end