Class: Stripe::Quote::SubscriptionDataOverride::BillOnAcceptance::BillUntil
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Quote::SubscriptionDataOverride::BillOnAcceptance::BillUntil
- Defined in:
- lib/stripe/resources/quote.rb
Defined Under Namespace
Classes: Duration, LineEndsAt
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#computed ⇒ Object
readonly
The materialized time.
-
#duration ⇒ Object
readonly
Time span for the quote line starting from the ‘starts_at` date.
-
#line_ends_at ⇒ Object
readonly
The timestamp the given line ends at.
-
#timestamp ⇒ Object
readonly
A precise Unix timestamp.
-
#type ⇒ Object
readonly
The type of method to specify the ‘bill_until` time.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#computed ⇒ Object (readonly)
The materialized time.
720 721 722 |
# File 'lib/stripe/resources/quote.rb', line 720 def computed @computed end |
#duration ⇒ Object (readonly)
Time span for the quote line starting from the ‘starts_at` date.
722 723 724 |
# File 'lib/stripe/resources/quote.rb', line 722 def duration @duration end |
#line_ends_at ⇒ Object (readonly)
The timestamp the given line ends at.
724 725 726 |
# File 'lib/stripe/resources/quote.rb', line 724 def line_ends_at @line_ends_at end |
#timestamp ⇒ Object (readonly)
A precise Unix timestamp.
726 727 728 |
# File 'lib/stripe/resources/quote.rb', line 726 def @timestamp end |
#type ⇒ Object (readonly)
The type of method to specify the ‘bill_until` time.
728 729 730 |
# File 'lib/stripe/resources/quote.rb', line 728 def type @type end |
Class Method Details
.field_remappings ⇒ Object
734 735 736 |
# File 'lib/stripe/resources/quote.rb', line 734 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
730 731 732 |
# File 'lib/stripe/resources/quote.rb', line 730 def self.inner_class_types @inner_class_types = { duration: Duration, line_ends_at: LineEndsAt } end |