Class: Stripe::Quote::SubscriptionDataOverride::BillingSchedule
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Quote::SubscriptionDataOverride::BillingSchedule
- Defined in:
- lib/stripe/resources/quote.rb
Defined Under Namespace
Classes: AppliesTo, BillFrom, BillUntil
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#applies_to ⇒ Object
readonly
Specifies which subscription items the billing schedule applies to.
-
#bill_from ⇒ Object
readonly
Specifies the start of the billing period.
-
#bill_until ⇒ Object
readonly
Attribute for field bill_until.
-
#key ⇒ Object
readonly
Unique identifier for the billing schedule.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#applies_to ⇒ Object (readonly)
Specifies which subscription items the billing schedule applies to.
964 965 966 |
# File 'lib/stripe/resources/quote.rb', line 964 def applies_to @applies_to end |
#bill_from ⇒ Object (readonly)
Specifies the start of the billing period.
966 967 968 |
# File 'lib/stripe/resources/quote.rb', line 966 def bill_from @bill_from end |
#bill_until ⇒ Object (readonly)
Attribute for field bill_until
968 969 970 |
# File 'lib/stripe/resources/quote.rb', line 968 def bill_until @bill_until end |
#key ⇒ Object (readonly)
Unique identifier for the billing schedule.
970 971 972 |
# File 'lib/stripe/resources/quote.rb', line 970 def key @key end |
Class Method Details
.field_remappings ⇒ Object
976 977 978 |
# File 'lib/stripe/resources/quote.rb', line 976 def self.field_remappings @field_remappings = {} end |