Class: Stripe::Quote::SubscriptionSchedule
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Quote::SubscriptionSchedule
- Defined in:
- lib/stripe/resources/quote.rb
Defined Under Namespace
Classes: AppliesTo
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#applies_to ⇒ Object
readonly
Attribute for field applies_to.
-
#subscription_schedule ⇒ Object
readonly
The subscription schedule that was created or updated from this quote.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#applies_to ⇒ Object (readonly)
Attribute for field applies_to
408 409 410 |
# File 'lib/stripe/resources/quote.rb', line 408 def applies_to @applies_to end |
#subscription_schedule ⇒ Object (readonly)
The subscription schedule that was created or updated from this quote.
410 411 412 |
# File 'lib/stripe/resources/quote.rb', line 410 def subscription_schedule @subscription_schedule end |