Class: Stripe::Quote::TotalDetails

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: Breakdown

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amount_discountObject (readonly)

This is the sum of all the discounts.



1207
1208
1209
# File 'lib/stripe/resources/quote.rb', line 1207

def amount_discount
  @amount_discount
end

#amount_shippingObject (readonly)

This is the sum of all the shipping amounts.



1209
1210
1211
# File 'lib/stripe/resources/quote.rb', line 1209

def amount_shipping
  @amount_shipping
end

#amount_taxObject (readonly)

This is the sum of all the tax amounts.



1211
1212
1213
# File 'lib/stripe/resources/quote.rb', line 1211

def amount_tax
  @amount_tax
end

#breakdownObject (readonly)

Attribute for field breakdown



1213
1214
1215
# File 'lib/stripe/resources/quote.rb', line 1213

def breakdown
  @breakdown
end

Class Method Details

.field_remappingsObject



1219
1220
1221
# File 'lib/stripe/resources/quote.rb', line 1219

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1215
1216
1217
# File 'lib/stripe/resources/quote.rb', line 1215

def self.inner_class_types
  @inner_class_types = { breakdown: Breakdown }
end