Class: Stripe::Quote::TotalDetails::Breakdown::Tax

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Amount of tax applied for this rate.



1086
1087
1088
# File 'lib/stripe/resources/quote.rb', line 1086

def amount
  @amount
end

#rateObject (readonly)

Tax rates can be applied to invoices, subscriptions and Checkout Sessions to collect tax.

Related guide: Tax rates



1090
1091
1092
# File 'lib/stripe/resources/quote.rb', line 1090

def rate
  @rate
end

#taxability_reasonObject (readonly)

The reasoning behind this tax, for example, if the product is tax exempt. The possible values for this field may be extended as new tax rules are supported.



1092
1093
1094
# File 'lib/stripe/resources/quote.rb', line 1092

def taxability_reason
  @taxability_reason
end

#taxable_amountObject (readonly)

The amount on which tax is calculated, in cents (or local equivalent).



1094
1095
1096
# File 'lib/stripe/resources/quote.rb', line 1094

def taxable_amount
  @taxable_amount
end

Class Method Details

.field_remappingsObject



1100
1101
1102
# File 'lib/stripe/resources/quote.rb', line 1100

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1096
1097
1098
# File 'lib/stripe/resources/quote.rb', line 1096

def self.inner_class_types
  @inner_class_types = {}
end