Class: Stripe::Quote::UpdateParams::AutomaticTax

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: Liability

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(enabled: nil, liability: nil) ⇒ AutomaticTax

Returns a new instance of AutomaticTax.



1617
1618
1619
1620
# File 'lib/stripe/resources/quote.rb', line 1617

def initialize(enabled: nil, liability: nil)
  @enabled = enabled
  @liability = liability
end

Instance Attribute Details

#enabledObject

Controls whether Stripe will automatically compute tax on the resulting invoices or subscriptions as well as the quote itself.



1613
1614
1615
# File 'lib/stripe/resources/quote.rb', line 1613

def enabled
  @enabled
end

#liabilityObject

The account that’s liable for tax. If set, the business address and tax registrations required to perform the tax calculation are loaded from this account. The tax transaction is returned in the report of the connected account.



1615
1616
1617
# File 'lib/stripe/resources/quote.rb', line 1615

def liability
  @liability
end