Class: Stripe::Quote::UpdateParams::Discount

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



2070
2071
2072
2073
2074
2075
# File 'lib/stripe/resources/quote.rb', line 2070

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



2062
2063
2064
# File 'lib/stripe/resources/quote.rb', line 2062

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



2064
2065
2066
# File 'lib/stripe/resources/quote.rb', line 2064

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



2066
2067
2068
# File 'lib/stripe/resources/quote.rb', line 2066

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



2068
2069
2070
# File 'lib/stripe/resources/quote.rb', line 2068

def promotion_code
  @promotion_code
end