Class: Stripe::Quote::UpdateParams::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::UpdateParams::Discount::DiscountEnd
- Defined in:
- lib/stripe/resources/quote.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
1643 1644 1645 1646 1647 |
# File 'lib/stripe/resources/quote.rb', line 1643 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
1637 1638 1639 |
# File 'lib/stripe/resources/quote.rb', line 1637 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
1639 1640 1641 |
# File 'lib/stripe/resources/quote.rb', line 1639 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
1641 1642 1643 |
# File 'lib/stripe/resources/quote.rb', line 1641 def type @type end |