Class: Stripe::Quote::UpdateParams::Discount::DiscountEnd::Duration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(interval: nil, interval_count: nil) ⇒ Duration

Returns a new instance of Duration.



1617
1618
1619
1620
# File 'lib/stripe/resources/quote.rb', line 1617

def initialize(interval: nil, interval_count: nil)
  @interval = interval
  @interval_count = interval_count
end

Instance Attribute Details

#intervalObject

Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.



1613
1614
1615
# File 'lib/stripe/resources/quote.rb', line 1613

def interval
  @interval
end

#interval_countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



1615
1616
1617
# File 'lib/stripe/resources/quote.rb', line 1615

def interval_count
  @interval_count
end