Class: Stripe::Quote::UpdateParams::Line::Action::AddDiscount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ AddDiscount

Returns a new instance of AddDiscount.



2123
2124
2125
2126
2127
2128
2129
2130
2131
2132
2133
2134
2135
# File 'lib/stripe/resources/quote.rb', line 2123

def initialize(
  coupon: nil,
  discount: nil,
  discount_end: nil,
  index: nil,
  promotion_code: nil
)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @index = index
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to redeem.



2113
2114
2115
# File 'lib/stripe/resources/quote.rb', line 2113

def coupon
  @coupon
end

#discountObject

An ID of an existing discount for a coupon that was already redeemed.



2115
2116
2117
# File 'lib/stripe/resources/quote.rb', line 2115

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



2117
2118
2119
# File 'lib/stripe/resources/quote.rb', line 2117

def discount_end
  @discount_end
end

#indexObject

The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the ‘discounts` array.



2119
2120
2121
# File 'lib/stripe/resources/quote.rb', line 2119

def index
  @index
end

#promotion_codeObject

The promotion code to redeem.



2121
2122
2123
# File 'lib/stripe/resources/quote.rb', line 2121

def promotion_code
  @promotion_code
end