Class: Stripe::Quote::UpdateParams::Line::Action::AddDiscount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::UpdateParams::Line::Action::AddDiscount::DiscountEnd
- Defined in:
- lib/stripe/resources/quote.rb
Instance Attribute Summary collapse
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
1682 1683 1684 |
# File 'lib/stripe/resources/quote.rb', line 1682 def initialize(type: nil) @type = type end |
Instance Attribute Details
#type ⇒ Object
The type of calculation made to determine when the discount ends.
1680 1681 1682 |
# File 'lib/stripe/resources/quote.rb', line 1680 def type @type end |