Class: Stripe::Quote::UpdateParams::Line::Action::AddItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1741
1742
1743
1744
1745
1746
# File 'lib/stripe/resources/quote.rb', line 1741

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1733
1734
1735
# File 'lib/stripe/resources/quote.rb', line 1733

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1735
1736
1737
# File 'lib/stripe/resources/quote.rb', line 1735

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1737
1738
1739
# File 'lib/stripe/resources/quote.rb', line 1737

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1739
1740
1741
# File 'lib/stripe/resources/quote.rb', line 1739

def promotion_code
  @promotion_code
end