Class: Stripe::Quote::UpdateParams::Line::Action::AddItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



2159
2160
2161
2162
2163
# File 'lib/stripe/resources/quote.rb', line 2159

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



2153
2154
2155
# File 'lib/stripe/resources/quote.rb', line 2153

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



2155
2156
2157
# File 'lib/stripe/resources/quote.rb', line 2155

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



2157
2158
2159
# File 'lib/stripe/resources/quote.rb', line 2157

def type
  @type
end