Class: Stripe::Quote::UpdateParams::Line::Action::AddItem::Trial
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::UpdateParams::Line::Action::AddItem::Trial
- Defined in:
- lib/stripe/resources/quote.rb
Instance Attribute Summary collapse
-
#converts_to ⇒ Object
List of price IDs which, if present on the subscription following a paid trial, constitute opting-in to the paid trial.
-
#type ⇒ Object
Determines the type of trial for this item.
Instance Method Summary collapse
-
#initialize(converts_to: nil, type: nil) ⇒ Trial
constructor
A new instance of Trial.
Methods inherited from RequestParams
Constructor Details
#initialize(converts_to: nil, type: nil) ⇒ Trial
Returns a new instance of Trial.
2033 2034 2035 2036 |
# File 'lib/stripe/resources/quote.rb', line 2033 def initialize(converts_to: nil, type: nil) @converts_to = converts_to @type = type end |
Instance Attribute Details
#converts_to ⇒ Object
List of price IDs which, if present on the subscription following a paid trial, constitute opting-in to the paid trial. Currently only supports at most 1 price ID.
2028 2029 2030 |
# File 'lib/stripe/resources/quote.rb', line 2028 def converts_to @converts_to end |
#type ⇒ Object
Determines the type of trial for this item.
2031 2032 2033 |
# File 'lib/stripe/resources/quote.rb', line 2031 def type @type end |