Class: Stripe::Quote::UpdateParams::Line::Action::RemoveDiscount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ RemoveDiscount

Returns a new instance of RemoveDiscount.



2231
2232
2233
2234
2235
# File 'lib/stripe/resources/quote.rb', line 2231

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to remove from the ‘discounts` array.



2225
2226
2227
# File 'lib/stripe/resources/quote.rb', line 2225

def coupon
  @coupon
end

#discountObject

The ID of a discount to remove from the ‘discounts` array.



2227
2228
2229
# File 'lib/stripe/resources/quote.rb', line 2227

def discount
  @discount
end

#promotion_codeObject

The ID of a promotion code to remove from the ‘discounts` array.



2229
2230
2231
# File 'lib/stripe/resources/quote.rb', line 2229

def promotion_code
  @promotion_code
end