Class: Stripe::Quote::UpdateParams::Line::Action::SetDiscount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::UpdateParams::Line::Action::SetDiscount
- Defined in:
- lib/stripe/resources/quote.rb
Instance Attribute Summary collapse
-
#coupon ⇒ Object
The coupon code to replace the ‘discounts` array with.
-
#discount ⇒ Object
An ID of an existing discount to replace the ‘discounts` array with.
-
#promotion_code ⇒ Object
An ID of an existing promotion code to replace the ‘discounts` array with.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ SetDiscount
constructor
A new instance of SetDiscount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ SetDiscount
Returns a new instance of SetDiscount.
2255 2256 2257 2258 2259 |
# File 'lib/stripe/resources/quote.rb', line 2255 def initialize(coupon: nil, discount: nil, promotion_code: nil) @coupon = coupon @discount = discount @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
The coupon code to replace the ‘discounts` array with.
2249 2250 2251 |
# File 'lib/stripe/resources/quote.rb', line 2249 def coupon @coupon end |
#discount ⇒ Object
An ID of an existing discount to replace the ‘discounts` array with.
2251 2252 2253 |
# File 'lib/stripe/resources/quote.rb', line 2251 def discount @discount end |
#promotion_code ⇒ Object
An ID of an existing promotion code to replace the ‘discounts` array with.
2253 2254 2255 |
# File 'lib/stripe/resources/quote.rb', line 2253 def promotion_code @promotion_code end |