Class: Stripe::Quote::UpdateParams::Line::Action::SetItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



2298
2299
2300
2301
2302
2303
# File 'lib/stripe/resources/quote.rb', line 2298

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



2290
2291
2292
# File 'lib/stripe/resources/quote.rb', line 2290

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



2292
2293
2294
# File 'lib/stripe/resources/quote.rb', line 2292

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



2294
2295
2296
# File 'lib/stripe/resources/quote.rb', line 2294

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



2296
2297
2298
# File 'lib/stripe/resources/quote.rb', line 2296

def promotion_code
  @promotion_code
end