Class: Stripe::Quote::UpdateParams::Line::Action::SetItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



2283
2284
2285
2286
2287
# File 'lib/stripe/resources/quote.rb', line 2283

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



2277
2278
2279
# File 'lib/stripe/resources/quote.rb', line 2277

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



2279
2280
2281
# File 'lib/stripe/resources/quote.rb', line 2279

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



2281
2282
2283
# File 'lib/stripe/resources/quote.rb', line 2281

def type
  @type
end