Class: Stripe::Quote::UpdateParams::Line::AppliesTo

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(new_reference: nil, subscription_schedule: nil, type: nil) ⇒ AppliesTo

Returns a new instance of AppliesTo.



1974
1975
1976
1977
1978
# File 'lib/stripe/resources/quote.rb', line 1974

def initialize(new_reference: nil, subscription_schedule: nil, type: nil)
  @new_reference = new_reference
  @subscription_schedule = subscription_schedule
  @type = type
end

Instance Attribute Details

#new_referenceObject

A custom string that identifies a new subscription schedule being created upon quote acceptance. All quote lines with the same ‘new_reference` field will be applied to the creation of a new subscription schedule.



1968
1969
1970
# File 'lib/stripe/resources/quote.rb', line 1968

def new_reference
  @new_reference
end

#subscription_scheduleObject

The ID of the schedule the line applies to.



1970
1971
1972
# File 'lib/stripe/resources/quote.rb', line 1970

def subscription_schedule
  @subscription_schedule
end

#typeObject

Describes whether the quote line is affecting a new schedule or an existing schedule.



1972
1973
1974
# File 'lib/stripe/resources/quote.rb', line 1972

def type
  @type
end