Class: Stripe::Quote::UpdateParams::Line::CancelSubscriptionSchedule

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(cancel_at: nil, invoice_now: nil, prorate: nil) ⇒ CancelSubscriptionSchedule

Returns a new instance of CancelSubscriptionSchedule.



1982
1983
1984
1985
1986
# File 'lib/stripe/resources/quote.rb', line 1982

def initialize(cancel_at: nil, invoice_now: nil, prorate: nil)
  @cancel_at = cancel_at
  @invoice_now = invoice_now
  @prorate = prorate
end

Instance Attribute Details

#cancel_atObject

Timestamp helper to cancel the underlying schedule on the accompanying line’s start date. Must be set to ‘line_starts_at`.



1976
1977
1978
# File 'lib/stripe/resources/quote.rb', line 1976

def cancel_at
  @cancel_at
end

#invoice_nowObject

If the subscription schedule is ‘active`, indicates if a final invoice will be generated that contains any un-invoiced metered usage and new/pending proration invoice items. Boolean that defaults to `true`.



1978
1979
1980
# File 'lib/stripe/resources/quote.rb', line 1978

def invoice_now
  @invoice_now
end

#prorateObject

If the subscription schedule is ‘active`, indicates if the cancellation should be prorated. Boolean that defaults to `true`.



1980
1981
1982
# File 'lib/stripe/resources/quote.rb', line 1980

def prorate
  @prorate
end