Class: Stripe::Quote::UpdateParams::Line::EndsAt
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::UpdateParams::Line::EndsAt
- Defined in:
- lib/stripe/resources/quote.rb
Defined Under Namespace
Classes: DiscountEnd, Duration
Instance Attribute Summary collapse
-
#discount_end ⇒ Object
Use the ‘end` time of a given discount.
-
#duration ⇒ Object
Time span for the quote line starting from the ‘starts_at` date.
-
#timestamp ⇒ Object
A precise Unix timestamp.
-
#type ⇒ Object
Select a way to pass in ‘ends_at`.
Instance Method Summary collapse
-
#initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ EndsAt
constructor
A new instance of EndsAt.
Methods inherited from RequestParams
Constructor Details
#initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ EndsAt
Returns a new instance of EndsAt.
2040 2041 2042 2043 2044 2045 |
# File 'lib/stripe/resources/quote.rb', line 2040 def initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) @discount_end = discount_end @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#discount_end ⇒ Object
Use the ‘end` time of a given discount.
2032 2033 2034 |
# File 'lib/stripe/resources/quote.rb', line 2032 def discount_end @discount_end end |
#duration ⇒ Object
Time span for the quote line starting from the ‘starts_at` date.
2034 2035 2036 |
# File 'lib/stripe/resources/quote.rb', line 2034 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp.
2036 2037 2038 |
# File 'lib/stripe/resources/quote.rb', line 2036 def @timestamp end |
#type ⇒ Object
Select a way to pass in ‘ends_at`.
2038 2039 2040 |
# File 'lib/stripe/resources/quote.rb', line 2038 def type @type end |