Class: Stripe::Quote::UpdateParams::Line::StartsAt::LineEndsAt

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(id: nil, index: nil) ⇒ LineEndsAt

Returns a new instance of LineEndsAt.



2064
2065
2066
2067
# File 'lib/stripe/resources/quote.rb', line 2064

def initialize(id: nil, index: nil)
  @id = id
  @index = index
end

Instance Attribute Details

#idObject

The ID of a quote line.



2060
2061
2062
# File 'lib/stripe/resources/quote.rb', line 2060

def id
  @id
end

#indexObject

The position of the previous quote line in the ‘lines` array after which this line should begin. Indexes start from 0 and must be less than the index of the current line in the array.



2062
2063
2064
# File 'lib/stripe/resources/quote.rb', line 2062

def index
  @index
end