Class: Stripe::Quote::UpdateParams::Line::TrialSettings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::UpdateParams::Line::TrialSettings
- Defined in:
- lib/stripe/resources/quote.rb
Defined Under Namespace
Classes: EndBehavior
Instance Attribute Summary collapse
-
#end_behavior ⇒ Object
Defines how the subscription should behave when a trial ends.
Instance Method Summary collapse
-
#initialize(end_behavior: nil) ⇒ TrialSettings
constructor
A new instance of TrialSettings.
Methods inherited from RequestParams
Constructor Details
#initialize(end_behavior: nil) ⇒ TrialSettings
Returns a new instance of TrialSettings.
2418 2419 2420 |
# File 'lib/stripe/resources/quote.rb', line 2418 def initialize(end_behavior: nil) @end_behavior = end_behavior end |
Instance Attribute Details
#end_behavior ⇒ Object
Defines how the subscription should behave when a trial ends.
2416 2417 2418 |
# File 'lib/stripe/resources/quote.rb', line 2416 def end_behavior @end_behavior end |