Class: Stripe::Quote::UpdateParams::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::UpdateParams::LineItem
- Defined in:
- lib/stripe/resources/quote.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#discounts ⇒ Object
The discounts applied to this line item.
-
#id ⇒ Object
The ID of an existing line item on the quote.
-
#price ⇒ Object
The ID of the price object.
-
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.
-
#quantity ⇒ Object
The quantity of the line item.
-
#tax_rates ⇒ Object
The tax rates which apply to the line item.
Instance Method Summary collapse
-
#initialize(discounts: nil, id: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(discounts: nil, id: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ LineItem
Returns a new instance of LineItem.
2682 2683 2684 2685 2686 2687 2688 2689 2690 2691 2692 2693 2694 2695 2696 |
# File 'lib/stripe/resources/quote.rb', line 2682 def initialize( discounts: nil, id: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil ) @discounts = discounts @id = id @price = price @price_data = price_data @quantity = quantity @tax_rates = tax_rates end |
Instance Attribute Details
#discounts ⇒ Object
The discounts applied to this line item.
2670 2671 2672 |
# File 'lib/stripe/resources/quote.rb', line 2670 def discounts @discounts end |
#id ⇒ Object
The ID of an existing line item on the quote.
2672 2673 2674 |
# File 'lib/stripe/resources/quote.rb', line 2672 def id @id end |
#price ⇒ Object
The ID of the price object. One of ‘price` or `price_data` is required.
2674 2675 2676 |
# File 'lib/stripe/resources/quote.rb', line 2674 def price @price end |
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.
2676 2677 2678 |
# File 'lib/stripe/resources/quote.rb', line 2676 def price_data @price_data end |
#quantity ⇒ Object
The quantity of the line item.
2678 2679 2680 |
# File 'lib/stripe/resources/quote.rb', line 2678 def quantity @quantity end |
#tax_rates ⇒ Object
The tax rates which apply to the line item. When set, the ‘default_tax_rates` on the quote do not apply to this line item.
2680 2681 2682 |
# File 'lib/stripe/resources/quote.rb', line 2680 def tax_rates @tax_rates end |