Class: Stripe::Quote::UpdateParams::LineItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



2179
2180
2181
2182
2183
# File 'lib/stripe/resources/quote.rb', line 2179

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



2173
2174
2175
# File 'lib/stripe/resources/quote.rb', line 2173

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



2175
2176
2177
# File 'lib/stripe/resources/quote.rb', line 2175

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



2177
2178
2179
# File 'lib/stripe/resources/quote.rb', line 2177

def type
  @type
end