Class: Stripe::Quote::UpdateParams::LineItem::Discount::DiscountEnd::Duration
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::UpdateParams::LineItem::Discount::DiscountEnd::Duration
- Defined in:
- lib/stripe/resources/quote.rb
Instance Attribute Summary collapse
-
#interval ⇒ Object
Specifies a type of interval unit.
-
#interval_count ⇒ Object
The number of intervals, as an whole number greater than 0.
Instance Method Summary collapse
-
#initialize(interval: nil, interval_count: nil) ⇒ Duration
constructor
A new instance of Duration.
Methods inherited from RequestParams
Constructor Details
#initialize(interval: nil, interval_count: nil) ⇒ Duration
Returns a new instance of Duration.
2160 2161 2162 2163 |
# File 'lib/stripe/resources/quote.rb', line 2160 def initialize(interval: nil, interval_count: nil) @interval = interval @interval_count = interval_count end |
Instance Attribute Details
#interval ⇒ Object
Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.
2156 2157 2158 |
# File 'lib/stripe/resources/quote.rb', line 2156 def interval @interval end |
#interval_count ⇒ Object
The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.
2158 2159 2160 |
# File 'lib/stripe/resources/quote.rb', line 2158 def interval_count @interval_count end |