Class: Stripe::Quote::UpdateParams::SubscriptionData::BillOnAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: BillFrom, BillUntil

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bill_from: nil, bill_until: nil) ⇒ BillOnAcceptance

Returns a new instance of BillOnAcceptance.



2346
2347
2348
2349
# File 'lib/stripe/resources/quote.rb', line 2346

def initialize(bill_from: nil, bill_until: nil)
  @bill_from = bill_from
  @bill_until = bill_until
end

Instance Attribute Details

#bill_fromObject

The start of the period to bill from when the Quote is accepted.



2342
2343
2344
# File 'lib/stripe/resources/quote.rb', line 2342

def bill_from
  @bill_from
end

#bill_untilObject

The end of the period to bill until when the Quote is accepted.



2344
2345
2346
# File 'lib/stripe/resources/quote.rb', line 2344

def bill_until
  @bill_until
end