Class: Stripe::Quote::UpdateParams::SubscriptionData::BillOnAcceptance::BillUntil
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::UpdateParams::SubscriptionData::BillOnAcceptance::BillUntil
- Defined in:
- lib/stripe/resources/quote.rb
Defined Under Namespace
Classes: Duration, LineEndsAt
Instance Attribute Summary collapse
-
#duration ⇒ Object
Details of the duration over which to bill.
-
#line_ends_at ⇒ Object
Details of a Quote line item from which to bill until.
-
#timestamp ⇒ Object
A precise Unix timestamp.
-
#type ⇒ Object
The type of method to specify the ‘bill_until` time.
Instance Method Summary collapse
-
#initialize(duration: nil, line_ends_at: nil, timestamp: nil, type: nil) ⇒ BillUntil
constructor
A new instance of BillUntil.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, line_ends_at: nil, timestamp: nil, type: nil) ⇒ BillUntil
Returns a new instance of BillUntil.
2327 2328 2329 2330 2331 2332 |
# File 'lib/stripe/resources/quote.rb', line 2327 def initialize(duration: nil, line_ends_at: nil, timestamp: nil, type: nil) @duration = duration @line_ends_at = line_ends_at @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Details of the duration over which to bill.
2319 2320 2321 |
# File 'lib/stripe/resources/quote.rb', line 2319 def duration @duration end |
#line_ends_at ⇒ Object
Details of a Quote line item from which to bill until.
2321 2322 2323 |
# File 'lib/stripe/resources/quote.rb', line 2321 def line_ends_at @line_ends_at end |
#timestamp ⇒ Object
A precise Unix timestamp.
2323 2324 2325 |
# File 'lib/stripe/resources/quote.rb', line 2323 def @timestamp end |
#type ⇒ Object
The type of method to specify the ‘bill_until` time.
2325 2326 2327 |
# File 'lib/stripe/resources/quote.rb', line 2325 def type @type end |