Class: Stripe::Quote::UpdateParams::SubscriptionDataOverride::AppliesTo

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(new_reference: nil, subscription_schedule: nil, type: nil) ⇒ AppliesTo

Returns a new instance of AppliesTo.



2435
2436
2437
2438
2439
# File 'lib/stripe/resources/quote.rb', line 2435

def initialize(new_reference: nil, subscription_schedule: nil, type: nil)
  @new_reference = new_reference
  @subscription_schedule = subscription_schedule
  @type = type
end

Instance Attribute Details

#new_referenceObject

A custom string that identifies a new subscription schedule being created upon quote acceptance. All quote lines with the same ‘new_reference` field will be applied to the creation of a new subscription schedule.



2429
2430
2431
# File 'lib/stripe/resources/quote.rb', line 2429

def new_reference
  @new_reference
end

#subscription_scheduleObject

The ID of the schedule the line applies to.



2431
2432
2433
# File 'lib/stripe/resources/quote.rb', line 2431

def subscription_schedule
  @subscription_schedule
end

#typeObject

Describes whether the quote line is affecting a new schedule or an existing schedule.



2433
2434
2435
# File 'lib/stripe/resources/quote.rb', line 2433

def type
  @type
end