Class: Stripe::Quote::UpdateParams::TransferData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::UpdateParams::TransferData
- Defined in:
- lib/stripe/resources/quote.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount that will be transferred automatically when the invoice is paid.
-
#amount_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places.
-
#destination ⇒ Object
ID of an existing, connected Stripe account.
Instance Method Summary collapse
-
#initialize(amount: nil, amount_percent: nil, destination: nil) ⇒ TransferData
constructor
A new instance of TransferData.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, amount_percent: nil, destination: nil) ⇒ TransferData
Returns a new instance of TransferData.
2567 2568 2569 2570 2571 |
# File 'lib/stripe/resources/quote.rb', line 2567 def initialize(amount: nil, amount_percent: nil, destination: nil) @amount = amount @amount_percent = amount_percent @destination = destination end |
Instance Attribute Details
#amount ⇒ Object
The amount that will be transferred automatically when the invoice is paid. If no amount is set, the full amount is transferred. There cannot be any line items with recurring prices when using this field.
2561 2562 2563 |
# File 'lib/stripe/resources/quote.rb', line 2561 def amount @amount end |
#amount_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination. There must be at least 1 line item with a recurring price to use this field.
2563 2564 2565 |
# File 'lib/stripe/resources/quote.rb', line 2563 def amount_percent @amount_percent end |
#destination ⇒ Object
ID of an existing, connected Stripe account.
2565 2566 2567 |
# File 'lib/stripe/resources/quote.rb', line 2565 def destination @destination end |