Class: Stripe::QuoteCreateParams::FromQuote
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteCreateParams::FromQuote
- Defined in:
- lib/stripe/params/quote_create_params.rb
Instance Attribute Summary collapse
-
#is_revision ⇒ Object
Whether this quote is a revision of the previous quote.
-
#quote ⇒ Object
The ‘id` of the quote that will be cloned.
Instance Method Summary collapse
-
#initialize(is_revision: nil, quote: nil) ⇒ FromQuote
constructor
A new instance of FromQuote.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(is_revision: nil, quote: nil) ⇒ FromQuote
Returns a new instance of FromQuote.
78 79 80 81 |
# File 'lib/stripe/params/quote_create_params.rb', line 78 def initialize(is_revision: nil, quote: nil) @is_revision = is_revision @quote = quote end |
Instance Attribute Details
#is_revision ⇒ Object
Whether this quote is a revision of the previous quote.
74 75 76 |
# File 'lib/stripe/params/quote_create_params.rb', line 74 def is_revision @is_revision end |
#quote ⇒ Object
The ‘id` of the quote that will be cloned.
76 77 78 |
# File 'lib/stripe/params/quote_create_params.rb', line 76 def quote @quote end |