Class: Stripe::QuoteCreateParams::InvoiceSettings

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_create_params.rb

Defined Under Namespace

Classes: CustomField, Issuer

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(custom_fields: nil, days_until_due: nil, description: nil, footer: nil, issuer: nil) ⇒ InvoiceSettings

Returns a new instance of InvoiceSettings.



91
92
93
94
95
96
97
98
99
100
101
102
103
# File 'lib/stripe/params/quote_create_params.rb', line 91

def initialize(
  custom_fields: nil,
  days_until_due: nil,
  description: nil,
  footer: nil,
  issuer: nil
)
  @custom_fields = custom_fields
  @days_until_due = days_until_due
  @description = description
  @footer = footer
  @issuer = issuer
end

Instance Attribute Details

#custom_fieldsObject

A list of up to 4 custom fields to be displayed on the invoice.



81
82
83
# File 'lib/stripe/params/quote_create_params.rb', line 81

def custom_fields
  @custom_fields
end

#days_until_dueObject

Number of days within which a customer must pay the invoice generated by this quote. This value will be null for quotes where collection_method=charge_automatically.



83
84
85
# File 'lib/stripe/params/quote_create_params.rb', line 83

def days_until_due
  @days_until_due
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



85
86
87
# File 'lib/stripe/params/quote_create_params.rb', line 85

def description
  @description
end

Footer to be displayed on the invoice.



87
88
89
# File 'lib/stripe/params/quote_create_params.rb', line 87

def footer
  @footer
end

#issuerObject

The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.



89
90
91
# File 'lib/stripe/params/quote_create_params.rb', line 89

def issuer
  @issuer
end