Class: Stripe::QuoteCreateParams::Line::Action::AddDiscount::Settings::ServicePeriodAnchorConfig::Custom

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom

Returns a new instance of Custom.



133
134
135
136
137
138
139
# File 'lib/stripe/params/quote_create_params.rb', line 133

def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil)
  @day_of_month = day_of_month
  @hour = hour
  @minute = minute
  @month = month
  @second = second
end

Instance Attribute Details

#day_of_monthObject

The day of the month the anchor should be. Ranges from 1 to 31.



123
124
125
# File 'lib/stripe/params/quote_create_params.rb', line 123

def day_of_month
  @day_of_month
end

#hourObject

The hour of the day the anchor should be. Ranges from 0 to 23.



125
126
127
# File 'lib/stripe/params/quote_create_params.rb', line 125

def hour
  @hour
end

#minuteObject

The minute of the hour the anchor should be. Ranges from 0 to 59.



127
128
129
# File 'lib/stripe/params/quote_create_params.rb', line 127

def minute
  @minute
end

#monthObject

The month to start full cycle periods. Ranges from 1 to 12.



129
130
131
# File 'lib/stripe/params/quote_create_params.rb', line 129

def month
  @month
end

#secondObject

The second of the minute the anchor should be. Ranges from 0 to 59.



131
132
133
# File 'lib/stripe/params/quote_create_params.rb', line 131

def second
  @second
end