Class: Stripe::QuoteCreateParams::Line::Action::AddItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_create_params.rb

Defined Under Namespace

Classes: Discount, Trial

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil) ⇒ AddItem

Returns a new instance of AddItem.



340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
# File 'lib/stripe/params/quote_create_params.rb', line 340

def initialize(
  discounts: nil,
  metadata: nil,
  price: nil,
  quantity: nil,
  tax_rates: nil,
  trial: nil,
  trial_offer: nil
)
  @discounts = discounts
  @metadata = 
  @price = price
  @quantity = quantity
  @tax_rates = tax_rates
  @trial = trial
  @trial_offer = trial_offer
end

Instance Attribute Details

#discountsObject

The discounts applied to the item. Subscription item discounts are applied before subscription discounts.



326
327
328
# File 'lib/stripe/params/quote_create_params.rb', line 326

def discounts
  @discounts
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.



328
329
330
# File 'lib/stripe/params/quote_create_params.rb', line 328

def 
  @metadata
end

#priceObject

The ID of the price object.



330
331
332
# File 'lib/stripe/params/quote_create_params.rb', line 330

def price
  @price
end

#quantityObject

Quantity for this item.



332
333
334
# File 'lib/stripe/params/quote_create_params.rb', line 332

def quantity
  @quantity
end

#tax_ratesObject

The tax rates that apply to this subscription item. When set, the default_tax_rates on the subscription do not apply to this subscription_item.



334
335
336
# File 'lib/stripe/params/quote_create_params.rb', line 334

def tax_rates
  @tax_rates
end

#trialObject

Options that configure the trial on the subscription item.



336
337
338
# File 'lib/stripe/params/quote_create_params.rb', line 336

def trial
  @trial
end

#trial_offerObject

The ID of the trial offer to apply to the configuration item.



338
339
340
# File 'lib/stripe/params/quote_create_params.rb', line 338

def trial_offer
  @trial_offer
end