Class: Stripe::QuoteCreateParams::Line::Action::AddItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_create_params.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



207
208
209
210
211
212
# File 'lib/stripe/params/quote_create_params.rb', line 207

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



199
200
201
# File 'lib/stripe/params/quote_create_params.rb', line 199

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



201
202
203
# File 'lib/stripe/params/quote_create_params.rb', line 201

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



203
204
205
# File 'lib/stripe/params/quote_create_params.rb', line 203

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



205
206
207
# File 'lib/stripe/params/quote_create_params.rb', line 205

def promotion_code
  @promotion_code
end