Class: Stripe::QuoteCreateParams::Line::Action::AddItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_create_params.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



165
166
167
168
169
# File 'lib/stripe/params/quote_create_params.rb', line 165

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



159
160
161
# File 'lib/stripe/params/quote_create_params.rb', line 159

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



161
162
163
# File 'lib/stripe/params/quote_create_params.rb', line 161

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



163
164
165
# File 'lib/stripe/params/quote_create_params.rb', line 163

def type
  @type
end