Class: Stripe::QuoteCreateParams::Line::Action::AddItem::Discount::Settings::ServicePeriodAnchorConfig::Custom
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteCreateParams::Line::Action::AddItem::Discount::Settings::ServicePeriodAnchorConfig::Custom
- Defined in:
- lib/stripe/params/quote_create_params.rb
Instance Attribute Summary collapse
-
#day_of_month ⇒ Object
The day of the month the anchor should be.
-
#hour ⇒ Object
The hour of the day the anchor should be.
-
#minute ⇒ Object
The minute of the hour the anchor should be.
-
#month ⇒ Object
The month to start full cycle periods.
-
#second ⇒ Object
The second of the minute the anchor should be.
Instance Method Summary collapse
-
#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom
constructor
A new instance of Custom.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom
Returns a new instance of Custom.
260 261 262 263 264 265 266 |
# File 'lib/stripe/params/quote_create_params.rb', line 260 def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) @day_of_month = day_of_month @hour = hour @minute = minute @month = month @second = second end |
Instance Attribute Details
#day_of_month ⇒ Object
The day of the month the anchor should be. Ranges from 1 to 31.
250 251 252 |
# File 'lib/stripe/params/quote_create_params.rb', line 250 def day_of_month @day_of_month end |
#hour ⇒ Object
The hour of the day the anchor should be. Ranges from 0 to 23.
252 253 254 |
# File 'lib/stripe/params/quote_create_params.rb', line 252 def hour @hour end |
#minute ⇒ Object
The minute of the hour the anchor should be. Ranges from 0 to 59.
254 255 256 |
# File 'lib/stripe/params/quote_create_params.rb', line 254 def minute @minute end |
#month ⇒ Object
The month to start full cycle periods. Ranges from 1 to 12.
256 257 258 |
# File 'lib/stripe/params/quote_create_params.rb', line 256 def month @month end |
#second ⇒ Object
The second of the minute the anchor should be. Ranges from 0 to 59.
258 259 260 |
# File 'lib/stripe/params/quote_create_params.rb', line 258 def second @second end |