Class: Stripe::QuoteCreateParams::Line::Action::RemoveDiscount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ RemoveDiscount

Returns a new instance of RemoveDiscount.



268
269
270
271
272
# File 'lib/stripe/params/quote_create_params.rb', line 268

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to remove from the discounts array.



262
263
264
# File 'lib/stripe/params/quote_create_params.rb', line 262

def coupon
  @coupon
end

#discountObject

The ID of a discount to remove from the discounts array.



264
265
266
# File 'lib/stripe/params/quote_create_params.rb', line 264

def discount
  @discount
end

#promotion_codeObject

The ID of a promotion code to remove from the discounts array.



266
267
268
# File 'lib/stripe/params/quote_create_params.rb', line 266

def promotion_code
  @promotion_code
end