Class: Stripe::QuoteCreateParams::Line::Action::SetDiscount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_create_params.rb

Defined Under Namespace

Classes: Settings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil, settings: nil) ⇒ SetDiscount

Returns a new instance of SetDiscount.



435
436
437
438
439
440
# File 'lib/stripe/params/quote_create_params.rb', line 435

def initialize(coupon: nil, discount: nil, promotion_code: nil, settings: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
  @settings = settings
end

Instance Attribute Details

#couponObject

The coupon code to replace the discounts array with.



427
428
429
# File 'lib/stripe/params/quote_create_params.rb', line 427

def coupon
  @coupon
end

#discountObject

An ID of an existing discount to replace the discounts array with.



429
430
431
# File 'lib/stripe/params/quote_create_params.rb', line 429

def discount
  @discount
end

#promotion_codeObject

An ID of an existing promotion code to replace the discounts array with.



431
432
433
# File 'lib/stripe/params/quote_create_params.rb', line 431

def promotion_code
  @promotion_code
end

#settingsObject

Settings for discount application including service period anchoring.



433
434
435
# File 'lib/stripe/params/quote_create_params.rb', line 433

def settings
  @settings
end