Class: Stripe::QuoteCreateParams::Line::Action::SetDiscount::Settings::ServicePeriodAnchorConfig::Custom

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom

Returns a new instance of Custom.



398
399
400
401
402
403
404
# File 'lib/stripe/params/quote_create_params.rb', line 398

def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil)
  @day_of_month = day_of_month
  @hour = hour
  @minute = minute
  @month = month
  @second = second
end

Instance Attribute Details

#day_of_monthObject

The day of the month the anchor should be. Ranges from 1 to 31.



388
389
390
# File 'lib/stripe/params/quote_create_params.rb', line 388

def day_of_month
  @day_of_month
end

#hourObject

The hour of the day the anchor should be. Ranges from 0 to 23.



390
391
392
# File 'lib/stripe/params/quote_create_params.rb', line 390

def hour
  @hour
end

#minuteObject

The minute of the hour the anchor should be. Ranges from 0 to 59.



392
393
394
# File 'lib/stripe/params/quote_create_params.rb', line 392

def minute
  @minute
end

#monthObject

The month to start full cycle periods. Ranges from 1 to 12.



394
395
396
# File 'lib/stripe/params/quote_create_params.rb', line 394

def month
  @month
end

#secondObject

The second of the minute the anchor should be. Ranges from 0 to 59.



396
397
398
# File 'lib/stripe/params/quote_create_params.rb', line 396

def second
  @second
end