Class: Stripe::QuoteCreateParams::Line::Action::SetItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_create_params.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



464
465
466
467
468
# File 'lib/stripe/params/quote_create_params.rb', line 464

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



458
459
460
# File 'lib/stripe/params/quote_create_params.rb', line 458

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



460
461
462
# File 'lib/stripe/params/quote_create_params.rb', line 460

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



462
463
464
# File 'lib/stripe/params/quote_create_params.rb', line 462

def type
  @type
end