Class: Stripe::QuoteCreateParams::Line::Action::SetItem::Discount::Settings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteCreateParams::Line::Action::SetItem::Discount::Settings
- Defined in:
- lib/stripe/params/quote_create_params.rb
Defined Under Namespace
Classes: ServicePeriodAnchorConfig
Instance Attribute Summary collapse
-
#service_period_anchor_config ⇒ Object
Configures service period cycle anchoring.
-
#start_date ⇒ Object
The start date of the discount's service period when applying a coupon or promotion code with a service period duration.
Instance Method Summary collapse
-
#initialize(service_period_anchor_config: nil, start_date: nil) ⇒ Settings
constructor
A new instance of Settings.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(service_period_anchor_config: nil, start_date: nil) ⇒ Settings
Returns a new instance of Settings.
508 509 510 511 |
# File 'lib/stripe/params/quote_create_params.rb', line 508 def initialize(service_period_anchor_config: nil, start_date: nil) @service_period_anchor_config = service_period_anchor_config @start_date = start_date end |
Instance Attribute Details
#service_period_anchor_config ⇒ Object
Configures service period cycle anchoring.
504 505 506 |
# File 'lib/stripe/params/quote_create_params.rb', line 504 def service_period_anchor_config @service_period_anchor_config end |
#start_date ⇒ Object
The start date of the discount's service period when applying a coupon or promotion code with a service period duration. Defaults to line_start if omitted.
506 507 508 |
# File 'lib/stripe/params/quote_create_params.rb', line 506 def start_date @start_date end |