Class: Stripe::QuoteCreateParams::Line::Action::SetItem::Discount::Settings::ServicePeriodAnchorConfig::Custom

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom

Returns a new instance of Custom.



485
486
487
488
489
490
491
# File 'lib/stripe/params/quote_create_params.rb', line 485

def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil)
  @day_of_month = day_of_month
  @hour = hour
  @minute = minute
  @month = month
  @second = second
end

Instance Attribute Details

#day_of_monthObject

The day of the month the anchor should be. Ranges from 1 to 31.



475
476
477
# File 'lib/stripe/params/quote_create_params.rb', line 475

def day_of_month
  @day_of_month
end

#hourObject

The hour of the day the anchor should be. Ranges from 0 to 23.



477
478
479
# File 'lib/stripe/params/quote_create_params.rb', line 477

def hour
  @hour
end

#minuteObject

The minute of the hour the anchor should be. Ranges from 0 to 59.



479
480
481
# File 'lib/stripe/params/quote_create_params.rb', line 479

def minute
  @minute
end

#monthObject

The month to start full cycle periods. Ranges from 1 to 12.



481
482
483
# File 'lib/stripe/params/quote_create_params.rb', line 481

def month
  @month
end

#secondObject

The second of the minute the anchor should be. Ranges from 0 to 59.



483
484
485
# File 'lib/stripe/params/quote_create_params.rb', line 483

def second
  @second
end