Class: Stripe::QuoteCreateParams::Line::AppliesTo

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(new_reference: nil, subscription_schedule: nil, type: nil) ⇒ AppliesTo

Returns a new instance of AppliesTo.



637
638
639
640
641
# File 'lib/stripe/params/quote_create_params.rb', line 637

def initialize(new_reference: nil, subscription_schedule: nil, type: nil)
  @new_reference = new_reference
  @subscription_schedule = subscription_schedule
  @type = type
end

Instance Attribute Details

#new_referenceObject

A custom string that identifies a new subscription schedule being created upon quote acceptance. All quote lines with the same new_reference field will be applied to the creation of a new subscription schedule.



631
632
633
# File 'lib/stripe/params/quote_create_params.rb', line 631

def new_reference
  @new_reference
end

#subscription_scheduleObject

The ID of the schedule the line applies to.



633
634
635
# File 'lib/stripe/params/quote_create_params.rb', line 633

def subscription_schedule
  @subscription_schedule
end

#typeObject

Describes whether the quote line is affecting a new schedule or an existing schedule.



635
636
637
# File 'lib/stripe/params/quote_create_params.rb', line 635

def type
  @type
end