Class: Stripe::QuoteCreateParams::Line::EndsAt
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteCreateParams::Line::EndsAt
- Defined in:
- lib/stripe/params/quote_create_params.rb
Defined Under Namespace
Classes: DiscountEnd, Duration
Instance Attribute Summary collapse
-
#discount_end ⇒ Object
Use the ‘end` time of a given discount.
-
#duration ⇒ Object
Time span for the quote line starting from the ‘starts_at` date.
-
#timestamp ⇒ Object
A precise Unix timestamp.
-
#type ⇒ Object
Select a way to pass in ‘ends_at`.
Instance Method Summary collapse
-
#initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ EndsAt
constructor
A new instance of EndsAt.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ EndsAt
Returns a new instance of EndsAt.
466 467 468 469 470 471 |
# File 'lib/stripe/params/quote_create_params.rb', line 466 def initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) @discount_end = discount_end @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#discount_end ⇒ Object
Use the ‘end` time of a given discount.
458 459 460 |
# File 'lib/stripe/params/quote_create_params.rb', line 458 def discount_end @discount_end end |
#duration ⇒ Object
Time span for the quote line starting from the ‘starts_at` date.
460 461 462 |
# File 'lib/stripe/params/quote_create_params.rb', line 460 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp.
462 463 464 |
# File 'lib/stripe/params/quote_create_params.rb', line 462 def @timestamp end |
#type ⇒ Object
Select a way to pass in ‘ends_at`.
464 465 466 |
# File 'lib/stripe/params/quote_create_params.rb', line 464 def type @type end |