Class: Stripe::QuoteCreateParams::Line::StartsAt::LineEndsAt

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(index: nil) ⇒ LineEndsAt

Returns a new instance of LineEndsAt.



508
509
510
# File 'lib/stripe/params/quote_create_params.rb', line 508

def initialize(index: nil)
  @index = index
end

Instance Attribute Details

#indexObject

The position of the previous quote line in the ‘lines` array after which this line should begin. Indexes start from 0 and must be less than the index of the current line in the array.



506
507
508
# File 'lib/stripe/params/quote_create_params.rb', line 506

def index
  @index
end