Class: Stripe::QuoteCreateParams::LineItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



115
116
117
118
119
# File 'lib/stripe/params/quote_create_params.rb', line 115

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



109
110
111
# File 'lib/stripe/params/quote_create_params.rb', line 109

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



111
112
113
# File 'lib/stripe/params/quote_create_params.rb', line 111

def discount
  @discount
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



113
114
115
# File 'lib/stripe/params/quote_create_params.rb', line 113

def promotion_code
  @promotion_code
end