Class: Stripe::QuoteCreateParams::LineItem::PriceData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteCreateParams::LineItem::PriceData
- Defined in:
- lib/stripe/params/quote_create_params.rb
Defined Under Namespace
Classes: Recurring
Instance Attribute Summary collapse
-
#currency ⇒ Object
Three-letter ISO currency code, in lowercase.
- #product ⇒ Object
-
#recurring ⇒ Object
The recurring components of a price such as
intervalandinterval_count. -
#tax_behavior ⇒ Object
Only required if a default tax behavior was not provided in the Stripe Tax settings.
-
#unit_amount ⇒ Object
A positive integer in cents (or local equivalent) (or 0 for a free price) representing how much to charge.
-
#unit_amount_decimal ⇒ Object
Same as
unit_amount, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(currency: nil, product: nil, recurring: nil, tax_behavior: nil, unit_amount: nil, unit_amount_decimal: nil) ⇒ PriceData
constructor
A new instance of PriceData.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(currency: nil, product: nil, recurring: nil, tax_behavior: nil, unit_amount: nil, unit_amount_decimal: nil) ⇒ PriceData
Returns a new instance of PriceData.
887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 |
# File 'lib/stripe/params/quote_create_params.rb', line 887 def initialize( currency: nil, product: nil, recurring: nil, tax_behavior: nil, unit_amount: nil, unit_amount_decimal: nil ) @currency = currency @product = product @recurring = recurring @tax_behavior = tax_behavior @unit_amount = unit_amount @unit_amount_decimal = unit_amount_decimal end |
Instance Attribute Details
#currency ⇒ Object
Three-letter ISO currency code, in lowercase. Must be a supported currency.
875 876 877 |
# File 'lib/stripe/params/quote_create_params.rb', line 875 def currency @currency end |
#product ⇒ Object
877 878 879 |
# File 'lib/stripe/params/quote_create_params.rb', line 877 def product @product end |
#recurring ⇒ Object
The recurring components of a price such as interval and interval_count.
879 880 881 |
# File 'lib/stripe/params/quote_create_params.rb', line 879 def recurring @recurring end |
#tax_behavior ⇒ Object
Only required if a default tax behavior was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One of inclusive, exclusive, or unspecified. Once specified as either inclusive or exclusive, it cannot be changed.
881 882 883 |
# File 'lib/stripe/params/quote_create_params.rb', line 881 def tax_behavior @tax_behavior end |
#unit_amount ⇒ Object
A positive integer in cents (or local equivalent) (or 0 for a free price) representing how much to charge.
883 884 885 |
# File 'lib/stripe/params/quote_create_params.rb', line 883 def unit_amount @unit_amount end |
#unit_amount_decimal ⇒ Object
Same as unit_amount, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places. Only one of unit_amount and unit_amount_decimal can be set.
885 886 887 |
# File 'lib/stripe/params/quote_create_params.rb', line 885 def unit_amount_decimal @unit_amount_decimal end |
Class Method Details
.field_encodings ⇒ Object
903 904 905 |
# File 'lib/stripe/params/quote_create_params.rb', line 903 def self.field_encodings @field_encodings = { unit_amount_decimal: :decimal_string } end |