Class: Stripe::QuoteCreateParams::SubscriptionData::BillOnAcceptance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteCreateParams::SubscriptionData::BillOnAcceptance
- Defined in:
- lib/stripe/params/quote_create_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#bill_from ⇒ Object
The start of the period to bill from when the Quote is accepted.
-
#bill_until ⇒ Object
The end of the period to bill until when the Quote is accepted.
Instance Method Summary collapse
-
#initialize(bill_from: nil, bill_until: nil) ⇒ BillOnAcceptance
constructor
A new instance of BillOnAcceptance.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(bill_from: nil, bill_until: nil) ⇒ BillOnAcceptance
Returns a new instance of BillOnAcceptance.
779 780 781 782 |
# File 'lib/stripe/params/quote_create_params.rb', line 779 def initialize(bill_from: nil, bill_until: nil) @bill_from = bill_from @bill_until = bill_until end |
Instance Attribute Details
#bill_from ⇒ Object
The start of the period to bill from when the Quote is accepted.
775 776 777 |
# File 'lib/stripe/params/quote_create_params.rb', line 775 def bill_from @bill_from end |
#bill_until ⇒ Object
The end of the period to bill until when the Quote is accepted.
777 778 779 |
# File 'lib/stripe/params/quote_create_params.rb', line 777 def bill_until @bill_until end |