Class: Stripe::QuoteCreateParams::SubscriptionData::BillOnAcceptance::BillUntil
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteCreateParams::SubscriptionData::BillOnAcceptance::BillUntil
- Defined in:
- lib/stripe/params/quote_create_params.rb
Defined Under Namespace
Classes: Duration, LineEndsAt
Instance Attribute Summary collapse
-
#duration ⇒ Object
Details of the duration over which to bill.
-
#line_ends_at ⇒ Object
Details of a Quote line item from which to bill until.
-
#timestamp ⇒ Object
A precise Unix timestamp.
-
#type ⇒ Object
The type of method to specify the ‘bill_until` time.
Instance Method Summary collapse
-
#initialize(duration: nil, line_ends_at: nil, timestamp: nil, type: nil) ⇒ BillUntil
constructor
A new instance of BillUntil.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(duration: nil, line_ends_at: nil, timestamp: nil, type: nil) ⇒ BillUntil
Returns a new instance of BillUntil.
767 768 769 770 771 772 |
# File 'lib/stripe/params/quote_create_params.rb', line 767 def initialize(duration: nil, line_ends_at: nil, timestamp: nil, type: nil) @duration = duration @line_ends_at = line_ends_at @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Details of the duration over which to bill.
759 760 761 |
# File 'lib/stripe/params/quote_create_params.rb', line 759 def duration @duration end |
#line_ends_at ⇒ Object
Details of a Quote line item from which to bill until.
761 762 763 |
# File 'lib/stripe/params/quote_create_params.rb', line 761 def line_ends_at @line_ends_at end |
#timestamp ⇒ Object
A precise Unix timestamp.
763 764 765 |
# File 'lib/stripe/params/quote_create_params.rb', line 763 def @timestamp end |
#type ⇒ Object
The type of method to specify the ‘bill_until` time.
765 766 767 |
# File 'lib/stripe/params/quote_create_params.rb', line 765 def type @type end |