Class: Stripe::QuoteCreateParams::SubscriptionData::BillingMode

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_create_params.rb

Defined Under Namespace

Classes: Flexible

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(flexible: nil, type: nil) ⇒ BillingMode



181
182
183
184
# File 'lib/stripe/params/quote_create_params.rb', line 181

def initialize(flexible: nil, type: nil)
  @flexible = flexible
  @type = type
end

Instance Attribute Details

#flexibleObject

Configure behavior for flexible billing mode.



177
178
179
# File 'lib/stripe/params/quote_create_params.rb', line 177

def flexible
  @flexible
end

#typeObject

Controls the calculation and orchestration of prorations and invoices for subscriptions. If no value is passed, the default is flexible.



179
180
181
# File 'lib/stripe/params/quote_create_params.rb', line 179

def type
  @type
end