Class: Stripe::QuoteCreateParams::SubscriptionData::BillingSchedule
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteCreateParams::SubscriptionData::BillingSchedule
- Defined in:
- lib/stripe/params/quote_create_params.rb
Defined Under Namespace
Classes: AppliesTo, BillFrom, BillUntil
Instance Attribute Summary collapse
-
#applies_to ⇒ Object
Configure billing schedule differently for individual subscription items.
-
#bill_from ⇒ Object
The start of the period to bill from when the Quote is accepted.
-
#bill_until ⇒ Object
The end of the period to bill until when the Quote is accepted.
-
#key ⇒ Object
Specify a key for the billing schedule.
Instance Method Summary collapse
-
#initialize(applies_to: nil, bill_from: nil, bill_until: nil, key: nil) ⇒ BillingSchedule
constructor
A new instance of BillingSchedule.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(applies_to: nil, bill_from: nil, bill_until: nil, key: nil) ⇒ BillingSchedule
Returns a new instance of BillingSchedule.
1120 1121 1122 1123 1124 1125 |
# File 'lib/stripe/params/quote_create_params.rb', line 1120 def initialize(applies_to: nil, bill_from: nil, bill_until: nil, key: nil) @applies_to = applies_to @bill_from = bill_from @bill_until = bill_until @key = key end |
Instance Attribute Details
#applies_to ⇒ Object
Configure billing schedule differently for individual subscription items.
1112 1113 1114 |
# File 'lib/stripe/params/quote_create_params.rb', line 1112 def applies_to @applies_to end |
#bill_from ⇒ Object
The start of the period to bill from when the Quote is accepted.
1114 1115 1116 |
# File 'lib/stripe/params/quote_create_params.rb', line 1114 def bill_from @bill_from end |
#bill_until ⇒ Object
The end of the period to bill until when the Quote is accepted.
1116 1117 1118 |
# File 'lib/stripe/params/quote_create_params.rb', line 1116 def bill_until @bill_until end |
#key ⇒ Object
Specify a key for the billing schedule. Must be unique to this field, alphanumeric, and up to 200 characters. If not provided, a unique key will be generated.
1118 1119 1120 |
# File 'lib/stripe/params/quote_create_params.rb', line 1118 def key @key end |