Class: Stripe::QuoteCreateParams::SubscriptionData::BillingSchedule::AppliesTo
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteCreateParams::SubscriptionData::BillingSchedule::AppliesTo
- Defined in:
- lib/stripe/params/quote_create_params.rb
Instance Attribute Summary collapse
-
#price ⇒ Object
The ID of the price object.
-
#type ⇒ Object
Controls which subscription items the billing schedule applies to.
Instance Method Summary collapse
-
#initialize(price: nil, type: nil) ⇒ AppliesTo
constructor
A new instance of AppliesTo.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(price: nil, type: nil) ⇒ AppliesTo
Returns a new instance of AppliesTo.
1012 1013 1014 1015 |
# File 'lib/stripe/params/quote_create_params.rb', line 1012 def initialize(price: nil, type: nil) @price = price @type = type end |
Instance Attribute Details
#price ⇒ Object
The ID of the price object.
1008 1009 1010 |
# File 'lib/stripe/params/quote_create_params.rb', line 1008 def price @price end |
#type ⇒ Object
Controls which subscription items the billing schedule applies to.
1010 1011 1012 |
# File 'lib/stripe/params/quote_create_params.rb', line 1010 def type @type end |