Class: Stripe::QuoteCreateParams::SubscriptionData::BillingSchedule::BillUntil
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteCreateParams::SubscriptionData::BillingSchedule::BillUntil
- Defined in:
- lib/stripe/params/quote_create_params.rb
Defined Under Namespace
Classes: Duration, LineEndsAt
Instance Attribute Summary collapse
-
#duration ⇒ Object
Details of the duration over which to bill.
-
#line_ends_at ⇒ Object
Details of a Quote line item from which to bill until.
-
#timestamp ⇒ Object
A precise Unix timestamp.
-
#type ⇒ Object
The type of method to specify the ‘bill_until` time.
Instance Method Summary collapse
-
#initialize(duration: nil, line_ends_at: nil, timestamp: nil, type: nil) ⇒ BillUntil
constructor
A new instance of BillUntil.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, line_ends_at: nil, timestamp: nil, type: nil) ⇒ BillUntil
Returns a new instance of BillUntil.
1067 1068 1069 1070 1071 1072 |
# File 'lib/stripe/params/quote_create_params.rb', line 1067 def initialize(duration: nil, line_ends_at: nil, timestamp: nil, type: nil) @duration = duration @line_ends_at = line_ends_at @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Details of the duration over which to bill.
1059 1060 1061 |
# File 'lib/stripe/params/quote_create_params.rb', line 1059 def duration @duration end |
#line_ends_at ⇒ Object
Details of a Quote line item from which to bill until.
1061 1062 1063 |
# File 'lib/stripe/params/quote_create_params.rb', line 1061 def line_ends_at @line_ends_at end |
#timestamp ⇒ Object
A precise Unix timestamp.
1063 1064 1065 |
# File 'lib/stripe/params/quote_create_params.rb', line 1063 def @timestamp end |
#type ⇒ Object
The type of method to specify the ‘bill_until` time.
1065 1066 1067 |
# File 'lib/stripe/params/quote_create_params.rb', line 1065 def type @type end |