Class: Stripe::QuoteCreateParams::SubscriptionData::BillingSchedule::BillUntil::Duration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(interval: nil, interval_count: nil) ⇒ Duration

Returns a new instance of Duration.



1078
1079
1080
1081
# File 'lib/stripe/params/quote_create_params.rb', line 1078

def initialize(interval: nil, interval_count: nil)
  @interval = interval
  @interval_count = interval_count
end

Instance Attribute Details

#intervalObject

Specifies a type of interval unit. Either day, week, month or year.



1074
1075
1076
# File 'lib/stripe/params/quote_create_params.rb', line 1074

def interval
  @interval
end

#interval_countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



1076
1077
1078
# File 'lib/stripe/params/quote_create_params.rb', line 1076

def interval_count
  @interval_count
end