Class: Stripe::QuoteCreateParams::SubscriptionData::BillingSchedule::BillUntil::LineEndsAt

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(id: nil, index: nil) ⇒ LineEndsAt

Returns a new instance of LineEndsAt.



1090
1091
1092
1093
# File 'lib/stripe/params/quote_create_params.rb', line 1090

def initialize(id: nil, index: nil)
  @id = id
  @index = index
end

Instance Attribute Details

#idObject

The ID of a quote line.



1086
1087
1088
# File 'lib/stripe/params/quote_create_params.rb', line 1086

def id
  @id
end

#indexObject

The position of the previous quote line in the lines array after which this line should begin. Indexes start from 0 and must be less than the index of the current line in the array.



1088
1089
1090
# File 'lib/stripe/params/quote_create_params.rb', line 1088

def index
  @index
end