Class: Stripe::QuoteCreateParams::SubscriptionData::Prebilling
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteCreateParams::SubscriptionData::Prebilling
- Defined in:
- lib/stripe/params/quote_create_params.rb
Instance Attribute Summary collapse
-
#iterations ⇒ Object
This is used to determine the number of billing cycles to prebill.
Instance Method Summary collapse
-
#initialize(iterations: nil) ⇒ Prebilling
constructor
A new instance of Prebilling.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(iterations: nil) ⇒ Prebilling
Returns a new instance of Prebilling.
809 810 811 |
# File 'lib/stripe/params/quote_create_params.rb', line 809 def initialize(iterations: nil) @iterations = iterations end |
Instance Attribute Details
#iterations ⇒ Object
This is used to determine the number of billing cycles to prebill.
807 808 809 |
# File 'lib/stripe/params/quote_create_params.rb', line 807 def iterations @iterations end |