Class: Stripe::QuoteCreateParams::SubscriptionDataOverride

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_create_params.rb

Defined Under Namespace

Classes: AppliesTo, BillOnAcceptance, BillingSchedule

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(applies_to: nil, bill_on_acceptance: nil, billing_behavior: nil, billing_schedules: nil, customer: nil, description: nil, end_behavior: nil, phase_effective_at: nil, proration_behavior: nil) ⇒ SubscriptionDataOverride

Returns a new instance of SubscriptionDataOverride.



1418
1419
1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
# File 'lib/stripe/params/quote_create_params.rb', line 1418

def initialize(
  applies_to: nil,
  bill_on_acceptance: nil,
  billing_behavior: nil,
  billing_schedules: nil,
  customer: nil,
  description: nil,
  end_behavior: nil,
  phase_effective_at: nil,
  proration_behavior: nil
)
  @applies_to = applies_to
  @bill_on_acceptance = bill_on_acceptance
  @billing_behavior = billing_behavior
  @billing_schedules = billing_schedules
  @customer = customer
  @description = description
  @end_behavior = end_behavior
  @phase_effective_at = phase_effective_at
  @proration_behavior = proration_behavior
end

Instance Attribute Details

#applies_toObject

Whether the override applies to an existing Subscription Schedule or a new Subscription Schedule.



1394
1395
1396
# File 'lib/stripe/params/quote_create_params.rb', line 1394

def applies_to
  @applies_to
end

#bill_on_acceptanceObject

Describes the period to bill for upon accepting the quote.



1396
1397
1398
# File 'lib/stripe/params/quote_create_params.rb', line 1396

def bill_on_acceptance
  @bill_on_acceptance
end

#billing_behaviorObject

Configures when the subscription schedule generates prorations for phase transitions. Possible values are prorate_on_next_phase or prorate_up_front with the default being prorate_on_next_phase. prorate_on_next_phase will apply phase changes and generate prorations at transition time. prorate_up_front will bill for all phases within the current billing cycle up front.



1398
1399
1400
# File 'lib/stripe/params/quote_create_params.rb', line 1398

def billing_behavior
  @billing_behavior
end

#billing_schedulesObject

Billing schedules that will be applied to the subscription or subscription schedule created when the quote is accepted.



1400
1401
1402
# File 'lib/stripe/params/quote_create_params.rb', line 1400

def billing_schedules
  @billing_schedules
end

#customerObject

The customer the Subscription Data override applies to. This is only relevant when applies_to.type=new_reference.



1402
1403
1404
# File 'lib/stripe/params/quote_create_params.rb', line 1402

def customer
  @customer
end

#descriptionObject

The subscription's description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.



1404
1405
1406
# File 'lib/stripe/params/quote_create_params.rb', line 1404

def description
  @description
end

#end_behaviorObject

Behavior of the subscription schedule and underlying subscription when it ends.



1406
1407
1408
# File 'lib/stripe/params/quote_create_params.rb', line 1406

def end_behavior
  @end_behavior
end

#phase_effective_atObject

Configures how the subscription schedule handles billing for phase transitions when the quote is accepted.



1408
1409
1410
# File 'lib/stripe/params/quote_create_params.rb', line 1408

def phase_effective_at
  @phase_effective_at
end

#proration_behaviorObject

Determines how to handle prorations. When creating a subscription, valid values are create_prorations or none.

When updating a subscription, valid values are create_prorations, none, or always_invoice.

Passing create_prorations will cause proration invoice items to be created when applicable. These proration items will only be invoiced immediately under certain conditions. In order to always invoice immediately for prorations, pass always_invoice.

Prorations can be disabled by passing none.



1416
1417
1418
# File 'lib/stripe/params/quote_create_params.rb', line 1416

def proration_behavior
  @proration_behavior
end