Class: Stripe::QuoteCreateParams::SubscriptionDataOverride::BillOnAcceptance::BillFrom
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteCreateParams::SubscriptionDataOverride::BillOnAcceptance::BillFrom
- Defined in:
- lib/stripe/params/quote_create_params.rb
Defined Under Namespace
Classes: LineStartsAt
Instance Attribute Summary collapse
-
#line_starts_at ⇒ Object
Details of a Quote line to start the bill period from.
-
#timestamp ⇒ Object
A precise Unix timestamp.
-
#type ⇒ Object
The type of method to specify the ‘bill_from` time.
Instance Method Summary collapse
-
#initialize(line_starts_at: nil, timestamp: nil, type: nil) ⇒ BillFrom
constructor
A new instance of BillFrom.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(line_starts_at: nil, timestamp: nil, type: nil) ⇒ BillFrom
Returns a new instance of BillFrom.
909 910 911 912 913 |
# File 'lib/stripe/params/quote_create_params.rb', line 909 def initialize(line_starts_at: nil, timestamp: nil, type: nil) @line_starts_at = line_starts_at @timestamp = @type = type end |
Instance Attribute Details
#line_starts_at ⇒ Object
Details of a Quote line to start the bill period from.
903 904 905 |
# File 'lib/stripe/params/quote_create_params.rb', line 903 def line_starts_at @line_starts_at end |
#timestamp ⇒ Object
A precise Unix timestamp.
905 906 907 |
# File 'lib/stripe/params/quote_create_params.rb', line 905 def @timestamp end |
#type ⇒ Object
The type of method to specify the ‘bill_from` time.
907 908 909 |
# File 'lib/stripe/params/quote_create_params.rb', line 907 def type @type end |