Class: Stripe::QuoteCreateParams::SubscriptionDataOverride::BillOnAcceptance::BillFrom::LineStartsAt

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(id: nil, index: nil) ⇒ LineStartsAt

Returns a new instance of LineStartsAt.



1228
1229
1230
1231
# File 'lib/stripe/params/quote_create_params.rb', line 1228

def initialize(id: nil, index: nil)
  @id = id
  @index = index
end

Instance Attribute Details

#idObject

The ID of a quote line.



1224
1225
1226
# File 'lib/stripe/params/quote_create_params.rb', line 1224

def id
  @id
end

#indexObject

The position of the previous quote line in the lines array after which this line should begin. Indexes start from 0 and must be less than the index of the current line in the array.



1226
1227
1228
# File 'lib/stripe/params/quote_create_params.rb', line 1226

def index
  @index
end