Class: Stripe::QuoteCreateParams::SubscriptionDataOverride::BillOnAcceptance::BillUntil
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteCreateParams::SubscriptionDataOverride::BillOnAcceptance::BillUntil
- Defined in:
- lib/stripe/params/quote_create_params.rb
Defined Under Namespace
Classes: Duration, LineEndsAt
Instance Attribute Summary collapse
-
#duration ⇒ Object
Details of the duration over which to bill.
-
#line_ends_at ⇒ Object
Details of a Quote line item from which to bill until.
-
#timestamp ⇒ Object
A precise Unix timestamp.
-
#type ⇒ Object
The type of method to specify the ‘bill_until` time.
Instance Method Summary collapse
-
#initialize(duration: nil, line_ends_at: nil, timestamp: nil, type: nil) ⇒ BillUntil
constructor
A new instance of BillUntil.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(duration: nil, line_ends_at: nil, timestamp: nil, type: nil) ⇒ BillUntil
Returns a new instance of BillUntil.
949 950 951 952 953 954 |
# File 'lib/stripe/params/quote_create_params.rb', line 949 def initialize(duration: nil, line_ends_at: nil, timestamp: nil, type: nil) @duration = duration @line_ends_at = line_ends_at @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Details of the duration over which to bill.
941 942 943 |
# File 'lib/stripe/params/quote_create_params.rb', line 941 def duration @duration end |
#line_ends_at ⇒ Object
Details of a Quote line item from which to bill until.
943 944 945 |
# File 'lib/stripe/params/quote_create_params.rb', line 943 def line_ends_at @line_ends_at end |
#timestamp ⇒ Object
A precise Unix timestamp.
945 946 947 |
# File 'lib/stripe/params/quote_create_params.rb', line 945 def @timestamp end |
#type ⇒ Object
The type of method to specify the ‘bill_until` time.
947 948 949 |
# File 'lib/stripe/params/quote_create_params.rb', line 947 def type @type end |