Class: Stripe::QuoteCreateParams::SubscriptionDataOverride::BillOnAcceptance::BillUntil::LineEndsAt
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteCreateParams::SubscriptionDataOverride::BillOnAcceptance::BillUntil::LineEndsAt
- Defined in:
- lib/stripe/params/quote_create_params.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
The ID of a quote line.
-
#index ⇒ Object
The position of the previous quote line in the ‘lines` array after which this line should begin.
Instance Method Summary collapse
-
#initialize(id: nil, index: nil) ⇒ LineEndsAt
constructor
A new instance of LineEndsAt.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(id: nil, index: nil) ⇒ LineEndsAt
Returns a new instance of LineEndsAt.
935 936 937 938 |
# File 'lib/stripe/params/quote_create_params.rb', line 935 def initialize(id: nil, index: nil) @id = id @index = index end |
Instance Attribute Details
#id ⇒ Object
The ID of a quote line.
931 932 933 |
# File 'lib/stripe/params/quote_create_params.rb', line 931 def id @id end |
#index ⇒ Object
The position of the previous quote line in the ‘lines` array after which this line should begin. Indexes start from 0 and must be less than the index of the current line in the array.
933 934 935 |
# File 'lib/stripe/params/quote_create_params.rb', line 933 def index @index end |