Class: Stripe::QuoteCreateParams::SubscriptionDataOverride::BillingSchedule

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_create_params.rb

Defined Under Namespace

Classes: AppliesTo, BillFrom, BillUntil

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(applies_to: nil, bill_from: nil, bill_until: nil, key: nil) ⇒ BillingSchedule

Returns a new instance of BillingSchedule.



1386
1387
1388
1389
1390
1391
# File 'lib/stripe/params/quote_create_params.rb', line 1386

def initialize(applies_to: nil, bill_from: nil, bill_until: nil, key: nil)
  @applies_to = applies_to
  @bill_from = bill_from
  @bill_until = bill_until
  @key = key
end

Instance Attribute Details

#applies_toObject

Configure billing schedule differently for individual subscription items.



1378
1379
1380
# File 'lib/stripe/params/quote_create_params.rb', line 1378

def applies_to
  @applies_to
end

#bill_fromObject

The start of the period to bill from when the Quote is accepted.



1380
1381
1382
# File 'lib/stripe/params/quote_create_params.rb', line 1380

def bill_from
  @bill_from
end

#bill_untilObject

The end of the period to bill until when the Quote is accepted.



1382
1383
1384
# File 'lib/stripe/params/quote_create_params.rb', line 1382

def bill_until
  @bill_until
end

#keyObject

Specify a key for the billing schedule. Must be unique to this field, alphanumeric, and up to 200 characters. If not provided, a unique key will be generated.



1384
1385
1386
# File 'lib/stripe/params/quote_create_params.rb', line 1384

def key
  @key
end