Class: Stripe::QuoteCreateParams::SubscriptionDataOverride::BillingSchedule::BillFrom::LineStartsAt

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(id: nil, index: nil) ⇒ LineStartsAt

Returns a new instance of LineStartsAt.



1085
1086
1087
1088
# File 'lib/stripe/params/quote_create_params.rb', line 1085

def initialize(id: nil, index: nil)
  @id = id
  @index = index
end

Instance Attribute Details

#idObject

The ID of a quote line.



1081
1082
1083
# File 'lib/stripe/params/quote_create_params.rb', line 1081

def id
  @id
end

#indexObject

The position of the previous quote line in the ‘lines` array after which this line should begin. Indexes start from 0 and must be less than the index of the current line in the array.



1083
1084
1085
# File 'lib/stripe/params/quote_create_params.rb', line 1083

def index
  @index
end