Class: Stripe::QuoteCreateParams::SubscriptionDataOverride::BillingSchedule::BillUntil
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteCreateParams::SubscriptionDataOverride::BillingSchedule::BillUntil
- Defined in:
- lib/stripe/params/quote_create_params.rb
Defined Under Namespace
Classes: Duration, LineEndsAt
Instance Attribute Summary collapse
-
#duration ⇒ Object
Details of the duration over which to bill.
-
#line_ends_at ⇒ Object
Details of a Quote line item from which to bill until.
-
#timestamp ⇒ Object
A precise Unix timestamp.
-
#type ⇒ Object
The type of method to specify the ‘bill_until` time.
Instance Method Summary collapse
-
#initialize(duration: nil, line_ends_at: nil, timestamp: nil, type: nil) ⇒ BillUntil
constructor
A new instance of BillUntil.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(duration: nil, line_ends_at: nil, timestamp: nil, type: nil) ⇒ BillUntil
Returns a new instance of BillUntil.
1343 1344 1345 1346 1347 1348 |
# File 'lib/stripe/params/quote_create_params.rb', line 1343 def initialize(duration: nil, line_ends_at: nil, timestamp: nil, type: nil) @duration = duration @line_ends_at = line_ends_at @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Details of the duration over which to bill.
1335 1336 1337 |
# File 'lib/stripe/params/quote_create_params.rb', line 1335 def duration @duration end |
#line_ends_at ⇒ Object
Details of a Quote line item from which to bill until.
1337 1338 1339 |
# File 'lib/stripe/params/quote_create_params.rb', line 1337 def line_ends_at @line_ends_at end |
#timestamp ⇒ Object
A precise Unix timestamp.
1339 1340 1341 |
# File 'lib/stripe/params/quote_create_params.rb', line 1339 def @timestamp end |
#type ⇒ Object
The type of method to specify the ‘bill_until` time.
1341 1342 1343 |
# File 'lib/stripe/params/quote_create_params.rb', line 1341 def type @type end |