Class: Stripe::QuoteCreateParams::SubscriptionDataOverride::BillingSchedule::BillUntil::LineEndsAt

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(id: nil, index: nil) ⇒ LineEndsAt

Returns a new instance of LineEndsAt.



1319
1320
1321
1322
# File 'lib/stripe/params/quote_create_params.rb', line 1319

def initialize(id: nil, index: nil)
  @id = id
  @index = index
end

Instance Attribute Details

#idObject

The ID of a quote line.



1315
1316
1317
# File 'lib/stripe/params/quote_create_params.rb', line 1315

def id
  @id
end

#indexObject

The position of the previous quote line in the ‘lines` array after which this line should begin. Indexes start from 0 and must be less than the index of the current line in the array.



1317
1318
1319
# File 'lib/stripe/params/quote_create_params.rb', line 1317

def index
  @index
end