Class: Stripe::QuoteLine::Action::AddDiscount

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/quote_line.rb

Defined Under Namespace

Classes: DiscountEnd, Settings

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#couponObject (readonly)

ID of the coupon to create a new discount for.



76
77
78
# File 'lib/stripe/resources/quote_line.rb', line 76

def coupon
  @coupon
end

#discountObject (readonly)

ID of an existing discount on the object (or one of its ancestors) to reuse.



78
79
80
# File 'lib/stripe/resources/quote_line.rb', line 78

def discount
  @discount
end

#discount_endObject (readonly)

Details to determine how long the discount should be applied for.



80
81
82
# File 'lib/stripe/resources/quote_line.rb', line 80

def discount_end
  @discount_end
end

#indexObject (readonly)

The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the discounts array.



82
83
84
# File 'lib/stripe/resources/quote_line.rb', line 82

def index
  @index
end

#promotion_codeObject (readonly)

ID of the promotion code to create a new discount for.



84
85
86
# File 'lib/stripe/resources/quote_line.rb', line 84

def promotion_code
  @promotion_code
end

#settingsObject (readonly)

Attribute for field settings



86
87
88
# File 'lib/stripe/resources/quote_line.rb', line 86

def settings
  @settings
end

Class Method Details

.field_remappingsObject



92
93
94
# File 'lib/stripe/resources/quote_line.rb', line 92

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



88
89
90
# File 'lib/stripe/resources/quote_line.rb', line 88

def self.inner_class_types
  @inner_class_types = { discount_end: DiscountEnd, settings: Settings }
end