Class: Stripe::QuoteLine::Action::AddDiscount::Settings::ServicePeriodAnchorConfig::Custom

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/quote_line.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#day_of_monthObject (readonly)

The day of the month the anchor should be. Ranges from 1 to 31.



31
32
33
# File 'lib/stripe/resources/quote_line.rb', line 31

def day_of_month
  @day_of_month
end

#hourObject (readonly)

The hour of the day the anchor should be. Ranges from 0 to 23.



33
34
35
# File 'lib/stripe/resources/quote_line.rb', line 33

def hour
  @hour
end

#minuteObject (readonly)

The minute of the hour the anchor should be. Ranges from 0 to 59.



35
36
37
# File 'lib/stripe/resources/quote_line.rb', line 35

def minute
  @minute
end

#monthObject (readonly)

The month to start full cycle periods. Ranges from 1 to 12.



37
38
39
# File 'lib/stripe/resources/quote_line.rb', line 37

def month
  @month
end

#secondObject (readonly)

The second of the minute the anchor should be. Ranges from 0 to 59.



39
40
41
# File 'lib/stripe/resources/quote_line.rb', line 39

def second
  @second
end

Class Method Details

.field_remappingsObject



45
46
47
# File 'lib/stripe/resources/quote_line.rb', line 45

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



41
42
43
# File 'lib/stripe/resources/quote_line.rb', line 41

def self.inner_class_types
  @inner_class_types = {}
end