Class: Stripe::QuoteLine::Action::AddItem
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::QuoteLine::Action::AddItem
- Defined in:
- lib/stripe/resources/quote_line.rb
Defined Under Namespace
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#discounts ⇒ Object
readonly
The discounts applied to the subscription item.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an item.
-
#price ⇒ Object
readonly
ID of the price to which the customer should be subscribed.
-
#quantity ⇒ Object
readonly
Quantity of the plan to which the customer should be subscribed.
-
#tax_rates ⇒ Object
readonly
The tax rates which apply to this ‘phase_item`.
-
#trial ⇒ Object
readonly
Options that configure the trial on the subscription item.
-
#trial_offer ⇒ Object
readonly
The ID of the trial offer to apply to the configuration item.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#discounts ⇒ Object (readonly)
The discounts applied to the subscription item. Subscription item discounts are applied before subscription discounts. Use ‘expand[]=discounts` to expand each discount.
95 96 97 |
# File 'lib/stripe/resources/quote_line.rb', line 95 def discounts @discounts end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an item. Metadata on this item will update the underlying subscription item’s ‘metadata` when the phase is entered.
97 98 99 |
# File 'lib/stripe/resources/quote_line.rb', line 97 def @metadata end |
#price ⇒ Object (readonly)
ID of the price to which the customer should be subscribed.
99 100 101 |
# File 'lib/stripe/resources/quote_line.rb', line 99 def price @price end |
#quantity ⇒ Object (readonly)
Quantity of the plan to which the customer should be subscribed.
101 102 103 |
# File 'lib/stripe/resources/quote_line.rb', line 101 def quantity @quantity end |
#tax_rates ⇒ Object (readonly)
The tax rates which apply to this ‘phase_item`. When set, the `default_tax_rates` on the phase do not apply to this `phase_item`.
103 104 105 |
# File 'lib/stripe/resources/quote_line.rb', line 103 def tax_rates @tax_rates end |
#trial ⇒ Object (readonly)
Options that configure the trial on the subscription item.
105 106 107 |
# File 'lib/stripe/resources/quote_line.rb', line 105 def trial @trial end |
#trial_offer ⇒ Object (readonly)
The ID of the trial offer to apply to the configuration item.
107 108 109 |
# File 'lib/stripe/resources/quote_line.rb', line 107 def trial_offer @trial_offer end |
Class Method Details
.field_remappings ⇒ Object
113 114 115 |
# File 'lib/stripe/resources/quote_line.rb', line 113 def self.field_remappings @field_remappings = {} end |