Class: Stripe::QuoteLine::Action::RemoveDiscount

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/quote_line.rb

Defined Under Namespace

Classes: DiscountEnd

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#couponObject (readonly)

ID of the coupon to create a new discount for.



134
135
136
# File 'lib/stripe/resources/quote_line.rb', line 134

def coupon
  @coupon
end

#discountObject (readonly)

ID of an existing discount on the object (or one of its ancestors) to reuse.



136
137
138
# File 'lib/stripe/resources/quote_line.rb', line 136

def discount
  @discount
end

#discount_endObject (readonly)

Details to determine how long the discount should be applied for.



138
139
140
# File 'lib/stripe/resources/quote_line.rb', line 138

def discount_end
  @discount_end
end

#promotion_codeObject (readonly)

ID of the promotion code to create a new discount for.



140
141
142
# File 'lib/stripe/resources/quote_line.rb', line 140

def promotion_code
  @promotion_code
end

Class Method Details

.field_remappingsObject



146
147
148
# File 'lib/stripe/resources/quote_line.rb', line 146

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



142
143
144
# File 'lib/stripe/resources/quote_line.rb', line 142

def self.inner_class_types
  @inner_class_types = { discount_end: DiscountEnd }
end