Class: Stripe::QuoteLine::Action::SetItem::Discount
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::QuoteLine::Action::SetItem::Discount
- Defined in:
- lib/stripe/resources/quote_line.rb
Defined Under Namespace
Classes: DiscountEnd
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#coupon ⇒ Object
readonly
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
readonly
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
readonly
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
readonly
ID of the promotion code to create a new discount for.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#coupon ⇒ Object (readonly)
ID of the coupon to create a new discount for.
214 215 216 |
# File 'lib/stripe/resources/quote_line.rb', line 214 def coupon @coupon end |
#discount ⇒ Object (readonly)
ID of an existing discount on the object (or one of its ancestors) to reuse.
216 217 218 |
# File 'lib/stripe/resources/quote_line.rb', line 216 def discount @discount end |
#discount_end ⇒ Object (readonly)
Details to determine how long the discount should be applied for.
218 219 220 |
# File 'lib/stripe/resources/quote_line.rb', line 218 def discount_end @discount_end end |
#promotion_code ⇒ Object (readonly)
ID of the promotion code to create a new discount for.
220 221 222 |
# File 'lib/stripe/resources/quote_line.rb', line 220 def promotion_code @promotion_code end |
Class Method Details
.field_remappings ⇒ Object
226 227 228 |
# File 'lib/stripe/resources/quote_line.rb', line 226 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
222 223 224 |
# File 'lib/stripe/resources/quote_line.rb', line 222 def self.inner_class_types @inner_class_types = { discount_end: DiscountEnd } end |