Class: Stripe::QuoteLine::EndsAt

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/quote_line.rb

Defined Under Namespace

Classes: DiscountEnd, Duration

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#computedObject (readonly)

The timestamp value that will be used to determine when to make changes to the subscription schedule, as computed from the ‘ends_at` field. For example, if `ends_at=upcoming_invoice`, the upcoming invoice date will be computed at the time the `ends_at` field was specified and saved. This field will not be recomputed upon future requests to update or finalize the quote unless `ends_at` is respecified. This field is guaranteed to be populated after quote acceptance.



368
369
370
# File 'lib/stripe/resources/quote_line.rb', line 368

def computed
  @computed
end

#discount_endObject (readonly)

Use the ‘end` time of a given discount.



370
371
372
# File 'lib/stripe/resources/quote_line.rb', line 370

def discount_end
  @discount_end
end

#durationObject (readonly)

Time span for the quote line starting from the ‘starts_at` date.



372
373
374
# File 'lib/stripe/resources/quote_line.rb', line 372

def duration
  @duration
end

#timestampObject (readonly)

A precise Unix timestamp.



374
375
376
# File 'lib/stripe/resources/quote_line.rb', line 374

def timestamp
  @timestamp
end

#typeObject (readonly)

Select a way to pass in ‘ends_at`.



376
377
378
# File 'lib/stripe/resources/quote_line.rb', line 376

def type
  @type
end

Class Method Details

.field_remappingsObject



382
383
384
# File 'lib/stripe/resources/quote_line.rb', line 382

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



378
379
380
# File 'lib/stripe/resources/quote_line.rb', line 378

def self.inner_class_types
  @inner_class_types = { discount_end: DiscountEnd, duration: Duration }
end