Class: Stripe::QuoteLine::EndsAt::Duration
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::QuoteLine::EndsAt::Duration
- Defined in:
- lib/stripe/resources/quote_line.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#interval ⇒ Object
readonly
Specifies a type of interval unit.
-
#interval_count ⇒ Object
readonly
The number of intervals, as an whole number greater than 0.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#interval ⇒ Object (readonly)
Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.
355 356 357 |
# File 'lib/stripe/resources/quote_line.rb', line 355 def interval @interval end |
#interval_count ⇒ Object (readonly)
The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.
357 358 359 |
# File 'lib/stripe/resources/quote_line.rb', line 357 def interval_count @interval_count end |
Class Method Details
.field_remappings ⇒ Object
363 364 365 |
# File 'lib/stripe/resources/quote_line.rb', line 363 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
359 360 361 |
# File 'lib/stripe/resources/quote_line.rb', line 359 def self.inner_class_types @inner_class_types = {} end |