Class: Stripe::QuotePreviewInvoice::AmountsDue

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/quote_preview_invoice.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Incremental amount due for this payment in cents (or local equivalent).



45
46
47
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 45

def amount
  @amount
end

#amount_paidObject (readonly)

The amount in cents (or local equivalent) that was paid for this payment.



47
48
49
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 47

def amount_paid
  @amount_paid
end

#amount_remainingObject (readonly)

The difference between the payment’s amount and amount_paid, in cents (or local equivalent).



49
50
51
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 49

def amount_remaining
  @amount_remaining
end

#days_until_dueObject (readonly)

Number of days from when invoice is finalized until the payment is due.



51
52
53
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 51

def days_until_due
  @days_until_due
end

#descriptionObject (readonly)

An arbitrary string attached to the object. Often useful for displaying to users.



53
54
55
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 53

def description
  @description
end

#due_dateObject (readonly)

Date on which a payment plan’s payment is due.



55
56
57
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 55

def due_date
  @due_date
end

Timestamp when the payment was paid.



57
58
59
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 57

def paid_at
  @paid_at
end

#statusObject (readonly)

The status of the payment, one of ‘open`, `paid`, or `past_due`



59
60
61
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 59

def status
  @status
end

Class Method Details

.field_remappingsObject



65
66
67
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 65

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



61
62
63
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 61

def self.inner_class_types
  @inner_class_types = {}
end