Class: Stripe::QuotePreviewInvoice::AppliesTo
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::QuotePreviewInvoice::AppliesTo
- Defined in:
- lib/stripe/resources/quote_preview_invoice.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#new_reference ⇒ Object
readonly
A custom string that identifies a new subscription schedule being created upon quote acceptance.
-
#subscription_schedule ⇒ Object
readonly
The ID of the schedule the line applies to.
-
#type ⇒ Object
readonly
Describes whether the quote line is affecting a new schedule or an existing schedule.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#new_reference ⇒ Object (readonly)
A custom string that identifies a new subscription schedule being created upon quote acceptance. All quote lines with the same ‘new_reference` field will be applied to the creation of a new subscription schedule.
72 73 74 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 72 def new_reference @new_reference end |
#subscription_schedule ⇒ Object (readonly)
The ID of the schedule the line applies to.
74 75 76 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 74 def subscription_schedule @subscription_schedule end |
#type ⇒ Object (readonly)
Describes whether the quote line is affecting a new schedule or an existing schedule.
76 77 78 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 76 def type @type end |
Class Method Details
.field_remappings ⇒ Object
82 83 84 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 82 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
78 79 80 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 78 def self.inner_class_types @inner_class_types = {} end |