Class: Stripe::QuotePreviewInvoice::AutomaticTax
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::QuotePreviewInvoice::AutomaticTax
- Defined in:
- lib/stripe/resources/quote_preview_invoice.rb
Defined Under Namespace
Classes: Liability
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#disabled_reason ⇒ Object
readonly
If Stripe disabled automatic tax, this enum describes why.
-
#enabled ⇒ Object
readonly
Whether Stripe automatically computes tax on this invoice.
-
#liability ⇒ Object
readonly
The account that’s liable for tax.
-
#provider ⇒ Object
readonly
The tax provider powering automatic tax.
-
#status ⇒ Object
readonly
The status of the most recent automated tax calculation for this invoice.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#disabled_reason ⇒ Object (readonly)
If Stripe disabled automatic tax, this enum describes why.
103 104 105 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 103 def disabled_reason @disabled_reason end |
#enabled ⇒ Object (readonly)
Whether Stripe automatically computes tax on this invoice. Note that incompatible invoice items (invoice items with manually specified [tax rates](docs.stripe.com/api/tax_rates), negative amounts, or ‘tax_behavior=unspecified`) cannot be added to automatic tax invoices.
105 106 107 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 105 def enabled @enabled end |
#liability ⇒ Object (readonly)
The account that’s liable for tax. If set, the business address and tax registrations required to perform the tax calculation are loaded from this account. The tax transaction is returned in the report of the connected account.
107 108 109 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 107 def liability @liability end |
#provider ⇒ Object (readonly)
The tax provider powering automatic tax.
109 110 111 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 109 def provider @provider end |
#status ⇒ Object (readonly)
The status of the most recent automated tax calculation for this invoice.
111 112 113 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 111 def status @status end |
Class Method Details
.field_remappings ⇒ Object
117 118 119 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 117 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
113 114 115 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 113 def self.inner_class_types @inner_class_types = { liability: Liability } end |