Class: Stripe::QuotePreviewInvoice::CustomerBalance
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::QuotePreviewInvoice::CustomerBalance
- Defined in:
- lib/stripe/resources/quote_preview_invoice.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#applied_balance ⇒ Object
readonly
The total amount of customer balance applied to this invoice (automatically + manually).
-
#automatically_applied_balance ⇒ Object
readonly
The amount of customer balance automatically applied during invoice finalization.
-
#manually_applied_balance ⇒ Object
readonly
The total amount of customer balance manually applied after finalization.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#applied_balance ⇒ Object (readonly)
The total amount of customer balance applied to this invoice (automatically + manually).
177 178 179 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 177 def applied_balance @applied_balance end |
#automatically_applied_balance ⇒ Object (readonly)
The amount of customer balance automatically applied during invoice finalization.
179 180 181 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 179 def automatically_applied_balance @automatically_applied_balance end |
#manually_applied_balance ⇒ Object (readonly)
The total amount of customer balance manually applied after finalization.
181 182 183 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 181 def manually_applied_balance @manually_applied_balance end |
Class Method Details
.field_remappings ⇒ Object
187 188 189 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 187 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
183 184 185 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 183 def self.inner_class_types @inner_class_types = {} end |