Class: Stripe::QuotePreviewInvoice::FromInvoice
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::QuotePreviewInvoice::FromInvoice
- Defined in:
- lib/stripe/resources/quote_preview_invoice.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#action ⇒ Object
readonly
The relation between this invoice and the cloned invoice.
-
#invoice ⇒ Object
readonly
The invoice that was cloned.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#action ⇒ Object (readonly)
The relation between this invoice and the cloned invoice
175 176 177 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 175 def action @action end |
#invoice ⇒ Object (readonly)
The invoice that was cloned.
178 179 180 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 178 def invoice @invoice end |