Class: Stripe::QuotePreviewInvoice::Parent
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::QuotePreviewInvoice::Parent
- Defined in:
- lib/stripe/resources/quote_preview_invoice.rb
Defined Under Namespace
Classes: BillingCadenceDetails, QuoteDetails, SubscriptionDetails
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#billing_cadence_details ⇒ Object
readonly
Details about the billing cadence that generated this invoice.
-
#quote_details ⇒ Object
readonly
Details about the quote that generated this invoice.
-
#subscription_details ⇒ Object
readonly
Details about the subscription that generated this invoice.
-
#type ⇒ Object
readonly
The type of parent that generated this invoice.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#billing_cadence_details ⇒ Object (readonly)
Details about the billing cadence that generated this invoice
265 266 267 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 265 def billing_cadence_details @billing_cadence_details end |
#quote_details ⇒ Object (readonly)
Details about the quote that generated this invoice
267 268 269 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 267 def quote_details @quote_details end |
#subscription_details ⇒ Object (readonly)
Details about the subscription that generated this invoice
269 270 271 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 269 def subscription_details @subscription_details end |
#type ⇒ Object (readonly)
The type of parent that generated this invoice
271 272 273 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 271 def type @type end |