Class: Stripe::QuotePreviewInvoice::PaymentSettings::PaymentMethodOptions

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/quote_preview_invoice.rb

Defined Under Namespace

Classes: AcssDebit, Bancontact, Billie, Bizum, Blik, Card, CheckScan, CustomerBalance, IdBankTransfer, Konbini, Payto, Pix, SepaDebit, Upi, UsBankAccount, WechatPay

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#acss_debitObject (readonly)

If paying by acss_debit, this sub-hash contains details about the Canadian pre-authorized debit payment method options to pass to the invoice’s PaymentIntent.



775
776
777
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 775

def acss_debit
  @acss_debit
end

#bancontactObject (readonly)

If paying by bancontact, this sub-hash contains details about the Bancontact payment method options to pass to the invoice’s PaymentIntent.



777
778
779
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 777

def bancontact
  @bancontact
end

#billieObject (readonly)

If paying by billie, this sub-hash contains details about the Billie payment method options to pass to the invoice’s PaymentIntent.



779
780
781
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 779

def billie
  @billie
end

#bizumObject (readonly)

If paying by bizum, this sub-hash contains details about the Bizum payment method options to pass to the invoice’s PaymentIntent.



781
782
783
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 781

def bizum
  @bizum
end

#blikObject (readonly)

If paying by blik, this sub-hash contains details about the Blik payment method options to pass to the invoice’s PaymentIntent.



783
784
785
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 783

def blik
  @blik
end

#cardObject (readonly)

If paying by card, this sub-hash contains details about the Card payment method options to pass to the invoice’s PaymentIntent.



785
786
787
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 785

def card
  @card
end

#check_scanObject (readonly)

If paying by check_scan, this sub-hash contains details about the Check Scan payment method options to pass to the invoice’s PaymentIntent.



787
788
789
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 787

def check_scan
  @check_scan
end

#customer_balanceObject (readonly)

If paying by customer_balance, this sub-hash contains details about the Bank transfer payment method options to pass to the invoice’s PaymentIntent.



789
790
791
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 789

def customer_balance
  @customer_balance
end

#id_bank_transferObject (readonly)

If paying by id_bank_transfer, this sub-hash contains details about the Indonesia bank transfer payment method options to pass to the invoice’s PaymentIntent.



791
792
793
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 791

def id_bank_transfer
  @id_bank_transfer
end

#konbiniObject (readonly)

If paying by konbini, this sub-hash contains details about the Konbini payment method options to pass to the invoice’s PaymentIntent.



793
794
795
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 793

def konbini
  @konbini
end

#paytoObject (readonly)

If paying by payto, this sub-hash contains details about the PayTo payment method options to pass to the invoice’s PaymentIntent.



795
796
797
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 795

def payto
  @payto
end

#pixObject (readonly)

If paying by pix, this sub-hash contains details about the Pix payment method options to pass to the invoice’s PaymentIntent.



797
798
799
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 797

def pix
  @pix
end

#sepa_debitObject (readonly)

If paying by sepa_debit, this sub-hash contains details about the SEPA Direct Debit payment method options to pass to the invoice’s PaymentIntent.



799
800
801
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 799

def sepa_debit
  @sepa_debit
end

#upiObject (readonly)

If paying by upi, this sub-hash contains details about the UPI payment method options to pass to the invoice’s PaymentIntent.



801
802
803
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 801

def upi
  @upi
end

#us_bank_accountObject (readonly)

If paying by us_bank_account, this sub-hash contains details about the ACH direct debit payment method options to pass to the invoice’s PaymentIntent.



803
804
805
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 803

def 
  @us_bank_account
end

#wechat_payObject (readonly)

If paying by wechat_pay, this sub-hash contains details about the WeChat Pay payment method options to pass to the invoice’s PaymentIntent.



805
806
807
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 805

def wechat_pay
  @wechat_pay
end

Class Method Details

.field_remappingsObject



828
829
830
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 828

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 807

def self.inner_class_types
  @inner_class_types = {
    acss_debit: AcssDebit,
    bancontact: Bancontact,
    billie: Billie,
    bizum: Bizum,
    blik: Blik,
    card: Card,
    check_scan: CheckScan,
    customer_balance: CustomerBalance,
    id_bank_transfer: IdBankTransfer,
    konbini: Konbini,
    payto: Payto,
    pix: Pix,
    sepa_debit: SepaDebit,
    upi: Upi,
    us_bank_account: UsBankAccount,
    wechat_pay: WechatPay,
  }
end