Class: Stripe::QuotePreviewInvoice::PaymentSettings::PaymentMethodOptions::Payto::MandateOptions

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/quote_preview_invoice.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

The maximum amount that can be collected in a single invoice. If you don’t specify a maximum, then there is no limit.



549
550
551
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 549

def amount
  @amount
end

#amount_typeObject (readonly)

Only ‘maximum` is supported.



551
552
553
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 551

def amount_type
  @amount_type
end

#purposeObject (readonly)

The purpose for which payments are made. Has a default value based on your merchant category code.



553
554
555
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 553

def purpose
  @purpose
end

Class Method Details

.field_remappingsObject



559
560
561
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 559

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



555
556
557
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 555

def self.inner_class_types
  @inner_class_types = {}
end