Class: Stripe::QuotePreviewInvoice::PaymentSettings::PaymentMethodOptions::Upi::MandateOptions

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/quote_preview_invoice.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Amount to be charged for future payments.



687
688
689
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 687

def amount
  @amount
end

#amount_typeObject (readonly)

One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.



689
690
691
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 689

def amount_type
  @amount_type
end

#descriptionObject (readonly)

A description of the mandate or subscription that is meant to be displayed to the customer.



691
692
693
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 691

def description
  @description
end

#end_dateObject (readonly)

End date of the mandate or subscription.



693
694
695
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 693

def end_date
  @end_date
end

Class Method Details

.field_remappingsObject



699
700
701
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 699

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



695
696
697
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 695

def self.inner_class_types
  @inner_class_types = {}
end