Class: Stripe::QuotePreviewInvoice::ShippingDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::QuotePreviewInvoice::ShippingDetails
- Defined in:
- lib/stripe/resources/quote_preview_invoice.rb
Defined Under Namespace
Classes: Address
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#address ⇒ Object
readonly
Attribute for field address.
-
#carrier ⇒ Object
readonly
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
-
#name ⇒ Object
readonly
Recipient name.
-
#phone ⇒ Object
readonly
Recipient phone (including extension).
-
#tracking_number ⇒ Object
readonly
The tracking number for a physical product, obtained from the delivery service.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#address ⇒ Object (readonly)
Attribute for field address
818 819 820 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 818 def address @address end |
#carrier ⇒ Object (readonly)
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
820 821 822 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 820 def carrier @carrier end |
#name ⇒ Object (readonly)
Recipient name.
822 823 824 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 822 def name @name end |
#phone ⇒ Object (readonly)
Recipient phone (including extension).
824 825 826 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 824 def phone @phone end |
#tracking_number ⇒ Object (readonly)
The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
826 827 828 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 826 def tracking_number @tracking_number end |
Class Method Details
.field_remappings ⇒ Object
832 833 834 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 832 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
828 829 830 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 828 def self.inner_class_types @inner_class_types = { address: Address } end |