Class: Stripe::QuotePreviewInvoice::ThresholdReason
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::QuotePreviewInvoice::ThresholdReason
- Defined in:
- lib/stripe/resources/quote_preview_invoice.rb
Defined Under Namespace
Classes: ItemReason
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount_gte ⇒ Object
readonly
The total invoice amount threshold boundary if it triggered the threshold invoice.
-
#item_reasons ⇒ Object
readonly
Indicates which line items triggered a threshold invoice.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount_gte ⇒ Object (readonly)
The total invoice amount threshold boundary if it triggered the threshold invoice.
422 423 424 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 422 def amount_gte @amount_gte end |
#item_reasons ⇒ Object (readonly)
Indicates which line items triggered a threshold invoice.
424 425 426 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 424 def item_reasons @item_reasons end |