Class: Stripe::QuotePreviewInvoice::ThresholdReason::ItemReason

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/quote_preview_invoice.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#line_item_idsObject (readonly)

The IDs of the line items that triggered the threshold invoice.



874
875
876
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 874

def line_item_ids
  @line_item_ids
end

#usage_gteObject (readonly)

The quantity threshold boundary that applied to the given line item.



876
877
878
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 876

def usage_gte
  @usage_gte
end

Class Method Details

.field_remappingsObject



882
883
884
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 882

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



878
879
880
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 878

def self.inner_class_types
  @inner_class_types = {}
end