Class: Stripe::QuotePreviewInvoice::TotalMarginAmount
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::QuotePreviewInvoice::TotalMarginAmount
- Defined in:
- lib/stripe/resources/quote_preview_invoice.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The amount, in cents (or local equivalent), of the reduction in line item amount.
-
#margin ⇒ Object
readonly
The margin that was applied to get this margin amount.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The amount, in cents (or local equivalent), of the reduction in line item amount.
479 480 481 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 479 def amount @amount end |
#margin ⇒ Object (readonly)
The margin that was applied to get this margin amount.
481 482 483 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 481 def margin @margin end |