Class: Stripe::QuotePreviewInvoice::TotalPretaxCreditAmount

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/quote_preview_invoice.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

The amount, in cents (or local equivalent), of the pretax credit amount.



932
933
934
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 932

def amount
  @amount
end

#credit_balance_transactionObject (readonly)

The credit balance transaction that was applied to get this pretax credit amount.



934
935
936
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 934

def credit_balance_transaction
  @credit_balance_transaction
end

#discountObject (readonly)

The discount that was applied to get this pretax credit amount.



936
937
938
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 936

def discount
  @discount
end

#marginObject (readonly)

The margin that was applied to get this pretax credit amount.



938
939
940
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 938

def margin
  @margin
end

#typeObject (readonly)

Type of the pretax credit amount referenced.



940
941
942
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 940

def type
  @type
end

Class Method Details

.field_remappingsObject



946
947
948
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 946

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



942
943
944
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 942

def self.inner_class_types
  @inner_class_types = {}
end