Class: Stripe::QuotePreviewSubscriptionSchedule

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/quote_preview_subscription_schedule.rb

Defined Under Namespace

Classes: AppliesTo, BillingMode, BillingSchedule, CurrentPhase, DefaultSettings, LastPriceMigrationError, PauseSchedule, Phase, Prebilling

Constant Summary collapse

OBJECT_NAME =
"quote_preview_subscription_schedule"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#applicationObject (readonly)

ID of the Connect Application that created the schedule.



1068
1069
1070
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 1068

def application
  @application
end

#applies_toObject (readonly)

Attribute for field applies_to



1070
1071
1072
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 1070

def applies_to
  @applies_to
end

#billing_behaviorObject (readonly)

Configures when the subscription schedule generates prorations for phase transitions. Possible values are prorate_on_next_phase or prorate_up_front with the default being prorate_on_next_phase. prorate_on_next_phase will apply phase changes and generate prorations at transition time. prorate_up_front will bill for all phases within the current billing cycle up front.



1072
1073
1074
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 1072

def billing_behavior
  @billing_behavior
end

#billing_modeObject (readonly)

The billing mode of the subscription.



1074
1075
1076
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 1074

def billing_mode
  @billing_mode
end

#billing_schedulesObject (readonly)

Billing schedules for this subscription schedule.



1076
1077
1078
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 1076

def billing_schedules
  @billing_schedules
end

#canceled_atObject (readonly)

Time at which the subscription schedule was canceled. Measured in seconds since the Unix epoch.



1078
1079
1080
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 1078

def canceled_at
  @canceled_at
end

#completed_atObject (readonly)

Time at which the subscription schedule was completed. Measured in seconds since the Unix epoch.



1080
1081
1082
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 1080

def completed_at
  @completed_at
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



1082
1083
1084
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 1082

def created
  @created
end

#current_phaseObject (readonly)

Object representing the start and end dates for the current phase of the subscription schedule, if it is active.



1084
1085
1086
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 1084

def current_phase
  @current_phase
end

#customerObject (readonly)

ID of the customer who owns the subscription schedule.



1086
1087
1088
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 1086

def customer
  @customer
end

#customer_accountObject (readonly)

ID of the account who owns the subscription schedule.



1088
1089
1090
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 1088

def 
  @customer_account
end

#default_settingsObject (readonly)

Attribute for field default_settings



1090
1091
1092
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 1090

def default_settings
  @default_settings
end

#end_behaviorObject (readonly)

Behavior of the subscription schedule and underlying subscription when it ends. Possible values are release or cancel with the default being release. release will end the subscription schedule and keep the underlying subscription running. cancel will end the subscription schedule and cancel the underlying subscription.



1092
1093
1094
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 1092

def end_behavior
  @end_behavior
end

#idObject (readonly)

Unique identifier for the object.



1094
1095
1096
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 1094

def id
  @id
end

#last_price_migration_errorObject (readonly)

Details of the most recent price migration that failed for the subscription schedule.



1096
1097
1098
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 1096

def last_price_migration_error
  @last_price_migration_error
end

#latest_invoiceObject (readonly)

The most recent invoice this subscription schedule has generated.



1098
1099
1100
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 1098

def latest_invoice
  @latest_invoice
end

#livemodeObject (readonly)

If the object exists in live mode, the value is true. If the object exists in test mode, the value is false.



1100
1101
1102
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 1100

def livemode
  @livemode
end

#metadataObject (readonly)

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



1102
1103
1104
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 1102

def 
  @metadata
end

#objectObject (readonly)

String representing the object's type. Objects of the same type share the same value.



1104
1105
1106
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 1104

def object
  @object
end

#pause_schedulesObject (readonly)

The pause schedules for this subscription schedule.



1106
1107
1108
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 1106

def pause_schedules
  @pause_schedules
end

#phasesObject (readonly)

Configuration for the subscription schedule's phases.



1108
1109
1110
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 1108

def phases
  @phases
end

#prebillingObject (readonly)

Time period and invoice for a Subscription billed in advance.



1110
1111
1112
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 1110

def prebilling
  @prebilling
end

#released_atObject (readonly)

Time at which the subscription schedule was released. Measured in seconds since the Unix epoch.



1112
1113
1114
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 1112

def released_at
  @released_at
end

#released_subscriptionObject (readonly)

ID of the subscription once managed by the subscription schedule (if it is released).



1114
1115
1116
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 1114

def released_subscription
  @released_subscription
end

#statusObject (readonly)

The present status of the subscription schedule. Possible values are not_started, active, completed, released, and canceled. You can read more about the different states in our behavior guide.



1116
1117
1118
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 1116

def status
  @status
end

#subscriptionObject (readonly)

ID of the subscription managed by the subscription schedule.



1118
1119
1120
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 1118

def subscription
  @subscription
end

#test_clockObject (readonly)

ID of the test clock this subscription schedule belongs to.



1120
1121
1122
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 1120

def test_clock
  @test_clock
end

Class Method Details

.field_remappingsObject



1136
1137
1138
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 1136

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1122
1123
1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
1134
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 1122

def self.inner_class_types
  @inner_class_types = {
    applies_to: AppliesTo,
    billing_mode: BillingMode,
    billing_schedules: BillingSchedule,
    current_phase: CurrentPhase,
    default_settings: DefaultSettings,
    last_price_migration_error: LastPriceMigrationError,
    pause_schedules: PauseSchedule,
    phases: Phase,
    prebilling: Prebilling,
  }
end

.object_nameObject



7
8
9
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 7

def self.object_name
  "quote_preview_subscription_schedule"
end