Class: Stripe::QuotePreviewSubscriptionSchedule::BillingSchedule::AppliesTo

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/quote_preview_subscription_schedule.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#priceObject (readonly)

The billing schedule will apply to the subscription item with the given price ID.



673
674
675
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 673

def price
  @price
end

#typeObject (readonly)

Controls which subscription items the billing schedule applies to.



675
676
677
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 675

def type
  @type
end

Class Method Details

.field_remappingsObject



681
682
683
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 681

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



677
678
679
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 677

def self.inner_class_types
  @inner_class_types = {}
end