Class: Stripe::QuotePreviewSubscriptionSchedule::BillingSchedule::BillUntil

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/quote_preview_subscription_schedule.rb

Defined Under Namespace

Classes: Duration

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#computed_timestampObject (readonly)

The timestamp the billing schedule will apply until.



89
90
91
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 89

def computed_timestamp
  @computed_timestamp
end

#durationObject (readonly)

Specifies the billing period.



91
92
93
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 91

def duration
  @duration
end

#timestampObject (readonly)

If specified, the billing schedule will apply until the specified timestamp.



93
94
95
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 93

def timestamp
  @timestamp
end

#typeObject (readonly)

Describes how the billing schedule will determine the end date. Either ‘duration` or `timestamp`.



95
96
97
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 95

def type
  @type
end

Class Method Details

.field_remappingsObject



101
102
103
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 101

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



97
98
99
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 97

def self.inner_class_types
  @inner_class_types = { duration: Duration }
end