Class: Stripe::QuotePreviewSubscriptionSchedule::BillingSchedule::BillUntil::AmendmentEnd
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::QuotePreviewSubscriptionSchedule::BillingSchedule::BillUntil::AmendmentEnd
- Defined in:
- lib/stripe/resources/quote_preview_subscription_schedule.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#index ⇒ Object
readonly
Use an index to specify the position of an amendment to end prebilling with.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#index ⇒ Object (readonly)
Use an index to specify the position of an amendment to end prebilling with.
756 757 758 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 756 def index @index end |
Class Method Details
.field_remappings ⇒ Object
762 763 764 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 762 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
758 759 760 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 758 def self.inner_class_types @inner_class_types = {} end |