Class: Stripe::QuotePreviewSubscriptionSchedule::DefaultSettings
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::QuotePreviewSubscriptionSchedule::DefaultSettings
- Defined in:
- lib/stripe/resources/quote_preview_subscription_schedule.rb
Defined Under Namespace
Classes: AutomaticTax, BillingThresholds, InvoiceSettings, TransferData
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#application_fee_percent ⇒ Object
readonly
A non-negative decimal between 0 and 100, with at most two decimal places.
-
#automatic_tax ⇒ Object
readonly
Attribute for field automatic_tax.
-
#billing_cycle_anchor ⇒ Object
readonly
Possible values are
phase_startorautomatic. -
#billing_thresholds ⇒ Object
readonly
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period.
-
#collection_method ⇒ Object
readonly
Either
charge_automatically, orsend_invoice. -
#default_payment_method ⇒ Object
readonly
ID of the default payment method for the subscription schedule.
-
#description ⇒ Object
readonly
Subscription description, meant to be displayable to the customer.
-
#invoice_settings ⇒ Object
readonly
Attribute for field invoice_settings.
-
#on_behalf_of ⇒ Object
readonly
The account (if any) the charge was made on behalf of for charges associated with the schedule's subscription.
-
#phase_effective_at ⇒ Object
readonly
Configures how the subscription schedule handles billing for phase transitions.
-
#transfer_data ⇒ Object
readonly
The account (if any) the associated subscription's payments will be attributed to for tax reporting, and where funds from each payment will be transferred to for each of the subscription's invoices.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#application_fee_percent ⇒ Object (readonly)
A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the application owner's Stripe account during this phase of the schedule.
250 251 252 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 250 def application_fee_percent @application_fee_percent end |
#automatic_tax ⇒ Object (readonly)
Attribute for field automatic_tax
252 253 254 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 252 def automatic_tax @automatic_tax end |
#billing_cycle_anchor ⇒ Object (readonly)
Possible values are phase_start or automatic. If phase_start then billing cycle anchor of the subscription is set to the start of the phase when entering the phase. If automatic then the billing cycle anchor is automatically modified as needed when entering the phase. For more information, see the billing cycle documentation.
254 255 256 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 254 def billing_cycle_anchor @billing_cycle_anchor end |
#billing_thresholds ⇒ Object (readonly)
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period
256 257 258 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 256 def billing_thresholds @billing_thresholds end |
#collection_method ⇒ Object (readonly)
Either charge_automatically, or send_invoice. When charging automatically, Stripe will attempt to pay the underlying subscription at the end of each billing cycle using the default source attached to the customer. When sending an invoice, Stripe will email your customer an invoice with payment instructions and mark the subscription as active.
258 259 260 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 258 def collection_method @collection_method end |
#default_payment_method ⇒ Object (readonly)
ID of the default payment method for the subscription schedule. If not set, invoices will use the default payment method in the customer's invoice settings.
260 261 262 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 260 def default_payment_method @default_payment_method end |
#description ⇒ Object (readonly)
Subscription description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.
262 263 264 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 262 def description @description end |
#invoice_settings ⇒ Object (readonly)
Attribute for field invoice_settings
264 265 266 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 264 def invoice_settings @invoice_settings end |
#on_behalf_of ⇒ Object (readonly)
The account (if any) the charge was made on behalf of for charges associated with the schedule's subscription. See the Connect documentation for details.
266 267 268 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 266 def on_behalf_of @on_behalf_of end |
#phase_effective_at ⇒ Object (readonly)
Configures how the subscription schedule handles billing for phase transitions. Possible values are phase_start (default) or billing_period_start. phase_start bills based on the current state of the subscription, ignoring changes scheduled in future phases. billing_period_start bills predictively for upcoming phase transitions within the current billing cycle, including pricing changes and service period adjustments that will occur before the next invoice.
268 269 270 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 268 def phase_effective_at @phase_effective_at end |
#transfer_data ⇒ Object (readonly)
The account (if any) the associated subscription's payments will be attributed to for tax reporting, and where funds from each payment will be transferred to for each of the subscription's invoices.
270 271 272 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 270 def transfer_data @transfer_data end |
Class Method Details
.field_remappings ⇒ Object
281 282 283 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 281 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
272 273 274 275 276 277 278 279 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 272 def self.inner_class_types @inner_class_types = { automatic_tax: AutomaticTax, billing_thresholds: BillingThresholds, invoice_settings: InvoiceSettings, transfer_data: TransferData, } end |