Class: Stripe::QuotePreviewSubscriptionSchedule::DefaultSettings::InvoiceSettings
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::QuotePreviewSubscriptionSchedule::DefaultSettings::InvoiceSettings
- Defined in:
- lib/stripe/resources/quote_preview_subscription_schedule.rb
Defined Under Namespace
Classes: CustomField, Issuer
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_tax_ids ⇒ Object
readonly
The account tax IDs associated with the subscription schedule.
-
#custom_fields ⇒ Object
readonly
A list of up to 4 custom fields to be displayed on the invoice.
-
#days_until_due ⇒ Object
readonly
Number of days within which a customer must pay invoices generated by this subscription schedule.
-
#description ⇒ Object
readonly
An arbitrary string attached to the object.
-
#footer ⇒ Object
readonly
Footer to be displayed on the invoice.
-
#issuer ⇒ Object
readonly
Attribute for field issuer.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_tax_ids ⇒ Object (readonly)
The account tax IDs associated with the subscription schedule. Will be set on invoices generated by the subscription schedule.
150 151 152 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 150 def account_tax_ids @account_tax_ids end |
#custom_fields ⇒ Object (readonly)
A list of up to 4 custom fields to be displayed on the invoice.
152 153 154 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 152 def custom_fields @custom_fields end |
#days_until_due ⇒ Object (readonly)
Number of days within which a customer must pay invoices generated by this subscription schedule. This value will be null for subscription schedules where billing=charge_automatically.
154 155 156 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 154 def days_until_due @days_until_due end |
#description ⇒ Object (readonly)
An arbitrary string attached to the object. Often useful for displaying to users.
156 157 158 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 156 def description @description end |
#footer ⇒ Object (readonly)
Footer to be displayed on the invoice.
158 159 160 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 158 def @footer end |
#issuer ⇒ Object (readonly)
Attribute for field issuer
160 161 162 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 160 def issuer @issuer end |
Class Method Details
.field_remappings ⇒ Object
166 167 168 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 166 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
162 163 164 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 162 def self.inner_class_types @inner_class_types = { custom_fields: CustomField, issuer: Issuer } end |