Class: Stripe::QuotePreviewSubscriptionSchedule::LastPriceMigrationError
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::QuotePreviewSubscriptionSchedule::LastPriceMigrationError
- Defined in:
- lib/stripe/resources/quote_preview_subscription_schedule.rb
Defined Under Namespace
Classes: FailedTransition
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#errored_at ⇒ Object
readonly
The time at which the price migration encountered an error.
-
#failed_transitions ⇒ Object
readonly
The involved price pairs in each failed transition.
-
#type ⇒ Object
readonly
The type of error encountered by the price migration.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#errored_at ⇒ Object (readonly)
The time at which the price migration encountered an error.
215 216 217 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 215 def errored_at @errored_at end |
#failed_transitions ⇒ Object (readonly)
The involved price pairs in each failed transition.
217 218 219 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 217 def failed_transitions @failed_transitions end |
#type ⇒ Object (readonly)
The type of error encountered by the price migration.
219 220 221 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 219 def type @type end |
Class Method Details
.field_remappings ⇒ Object
225 226 227 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 225 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
221 222 223 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 221 def self.inner_class_types @inner_class_types = { failed_transitions: FailedTransition } end |