Class: Stripe::QuotePreviewSubscriptionSchedule::Phase::AddInvoiceItem

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/quote_preview_subscription_schedule.rb

Defined Under Namespace

Classes: Discount, Period

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#discountableObject (readonly)

Controls whether discounts apply to this invoice item. Defaults to true if no value is provided.



578
579
580
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 578

def discountable
  @discountable
end

#discountsObject (readonly)

The stackable discounts that will be applied to the item.



580
581
582
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 580

def discounts
  @discounts
end

#metadataObject (readonly)

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



582
583
584
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 582

def 
  @metadata
end

#periodObject (readonly)

Attribute for field period



584
585
586
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 584

def period
  @period
end

#priceObject (readonly)

ID of the price used to generate the invoice item.



586
587
588
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 586

def price
  @price
end

#quantityObject (readonly)

The quantity of the invoice item.



588
589
590
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 588

def quantity
  @quantity
end

#tax_ratesObject (readonly)

The tax rates which apply to the item. When set, the default_tax_rates do not apply to this item.



590
591
592
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 590

def tax_rates
  @tax_rates
end

Class Method Details

.field_remappingsObject



596
597
598
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 596

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



592
593
594
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 592

def self.inner_class_types
  @inner_class_types = { discounts: Discount, period: Period }
end