Class: Stripe::QuotePreviewSubscriptionSchedule::Phase::BillingThresholds
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::QuotePreviewSubscriptionSchedule::Phase::BillingThresholds
- Defined in:
- lib/stripe/resources/quote_preview_subscription_schedule.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount_gte ⇒ Object
readonly
Monetary threshold that triggers the subscription to create an invoice.
-
#reset_billing_cycle_anchor ⇒ Object
readonly
Indicates if the ‘billing_cycle_anchor` should be reset when a threshold is reached.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount_gte ⇒ Object (readonly)
Monetary threshold that triggers the subscription to create an invoice
153 154 155 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 153 def amount_gte @amount_gte end |
#reset_billing_cycle_anchor ⇒ Object (readonly)
Indicates if the ‘billing_cycle_anchor` should be reset when a threshold is reached. If true, `billing_cycle_anchor` will be updated to the date/time the threshold was last reached; otherwise, the value will remain unchanged. This value may not be `true` if the subscription contains items with plans that have `aggregate_usage=last_ever`.
155 156 157 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 155 def reset_billing_cycle_anchor @reset_billing_cycle_anchor end |