Class: Stripe::QuotePreviewSubscriptionSchedule::Phase::InvoiceSettings

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/quote_preview_subscription_schedule.rb

Defined Under Namespace

Classes: CustomField, Issuer

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_tax_idsObject (readonly)

The account tax IDs associated with this phase of the subscription schedule. Will be set on invoices generated by this phase of the subscription schedule.



762
763
764
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 762

def 
  @account_tax_ids
end

#custom_fieldsObject (readonly)

A list of up to 4 custom fields to be displayed on the invoice.



764
765
766
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 764

def custom_fields
  @custom_fields
end

#days_until_dueObject (readonly)

Number of days within which a customer must pay invoices generated by this subscription schedule. This value will be null for subscription schedules where billing=charge_automatically.



766
767
768
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 766

def days_until_due
  @days_until_due
end

#descriptionObject (readonly)

An arbitrary string attached to the object. Often useful for displaying to users.



768
769
770
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 768

def description
  @description
end

Footer to be displayed on the invoice.



770
771
772
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 770

def footer
  @footer
end

#issuerObject (readonly)

The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.



772
773
774
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 772

def issuer
  @issuer
end

Class Method Details

.field_remappingsObject



778
779
780
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 778

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



774
775
776
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 774

def self.inner_class_types
  @inner_class_types = { custom_fields: CustomField, issuer: Issuer }
end