Class: Stripe::QuotePreviewSubscriptionSchedule::Phase::Item

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/quote_preview_subscription_schedule.rb

Defined Under Namespace

Classes: BillingThresholds, Discount, Trial

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#billing_thresholdsObject (readonly)

Define thresholds at which an invoice will be sent, and the related subscription advanced to a new billing period



896
897
898
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 896

def billing_thresholds
  @billing_thresholds
end

#discountsObject (readonly)

The discounts applied to the subscription item. Subscription item discounts are applied before subscription discounts. Use expand[]=discounts to expand each discount.



898
899
900
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 898

def discounts
  @discounts
end

#metadataObject (readonly)

Set of key-value pairs that you can attach to an item. Metadata on this item will update the underlying subscription item's metadata when the phase is entered.



900
901
902
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 900

def 
  @metadata
end

#planObject (readonly)

ID of the plan to which the customer should be subscribed.



902
903
904
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 902

def plan
  @plan
end

#priceObject (readonly)

ID of the price to which the customer should be subscribed.



904
905
906
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 904

def price
  @price
end

#quantityObject (readonly)

Quantity of the plan to which the customer should be subscribed.



906
907
908
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 906

def quantity
  @quantity
end

#tax_ratesObject (readonly)

The tax rates which apply to this phase_item. When set, the default_tax_rates on the phase do not apply to this phase_item.



908
909
910
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 908

def tax_rates
  @tax_rates
end

#trialObject (readonly)

Options that configure the trial on the subscription item.



910
911
912
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 910

def trial
  @trial
end

#trial_offerObject (readonly)

The ID of the trial offer to apply to the configuration item.



912
913
914
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 912

def trial_offer
  @trial_offer
end

Class Method Details

.field_remappingsObject



922
923
924
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 922

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



914
915
916
917
918
919
920
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 914

def self.inner_class_types
  @inner_class_types = {
    billing_thresholds: BillingThresholds,
    discounts: Discount,
    trial: Trial,
  }
end