Class: Stripe::QuotePreviewSubscriptionSchedule::Phase::Item::BillingThresholds
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::QuotePreviewSubscriptionSchedule::Phase::Item::BillingThresholds
- Defined in:
- lib/stripe/resources/quote_preview_subscription_schedule.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#usage_gte ⇒ Object
readonly
Usage threshold that triggers the subscription to create an invoice.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#usage_gte ⇒ Object (readonly)
Usage threshold that triggers the subscription to create an invoice
443 444 445 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 443 def usage_gte @usage_gte end |
Class Method Details
.field_remappings ⇒ Object
449 450 451 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 449 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
445 446 447 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 445 def self.inner_class_types @inner_class_types = {} end |