Class: Stripe::QuotePreviewSubscriptionSchedule::Phase::Item::Discount::Settings
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::QuotePreviewSubscriptionSchedule::Phase::Item::Discount::Settings
- Defined in:
- lib/stripe/resources/quote_preview_subscription_schedule.rb
Defined Under Namespace
Classes: ServicePeriodAnchorConfig
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#service_period_anchor_config ⇒ Object
readonly
Attribute for field service_period_anchor_config.
-
#start_date ⇒ Object
readonly
The start date of the discount’s service period when applying a coupon or promotion code with a service period duration.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#service_period_anchor_config ⇒ Object (readonly)
Attribute for field service_period_anchor_config
642 643 644 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 642 def service_period_anchor_config @service_period_anchor_config end |
#start_date ⇒ Object (readonly)
The start date of the discount’s service period when applying a coupon or promotion code with a service period duration.
644 645 646 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 644 def start_date @start_date end |
Class Method Details
.field_remappings ⇒ Object
650 651 652 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 650 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
646 647 648 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 646 def self.inner_class_types @inner_class_types = { service_period_anchor_config: ServicePeriodAnchorConfig } end |