Class: Stripe::QuotePreviewSubscriptionSchedule::Prebilling
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::QuotePreviewSubscriptionSchedule::Prebilling
- Defined in:
- lib/stripe/resources/quote_preview_subscription_schedule.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#invoice ⇒ Object
readonly
ID of the prebilling invoice.
-
#period_end ⇒ Object
readonly
The end of the last period for which the invoice pre-bills.
-
#period_start ⇒ Object
readonly
The start of the first period for which the invoice pre-bills.
-
#update_behavior ⇒ Object
readonly
Whether to cancel or preserve ‘prebilling` if the subscription is updated during the prebilled period.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#invoice ⇒ Object (readonly)
ID of the prebilling invoice.
653 654 655 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 653 def invoice @invoice end |
#period_end ⇒ Object (readonly)
The end of the last period for which the invoice pre-bills.
655 656 657 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 655 def period_end @period_end end |
#period_start ⇒ Object (readonly)
The start of the first period for which the invoice pre-bills.
657 658 659 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 657 def period_start @period_start end |
#update_behavior ⇒ Object (readonly)
Whether to cancel or preserve ‘prebilling` if the subscription is updated during the prebilled period.
659 660 661 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 659 def update_behavior @update_behavior end |
Class Method Details
.field_remappings ⇒ Object
665 666 667 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 665 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
661 662 663 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 661 def self.inner_class_types @inner_class_types = {} end |