Class: Stripe::QuotePreviewSubscriptionScheduleService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::QuotePreviewSubscriptionScheduleService
- Defined in:
- lib/stripe/services/quote_preview_subscription_schedule_service.rb
Instance Method Summary collapse
-
#list(quote, params = {}, opts = {}) ⇒ Object
Preview the schedules that would be generated by accepting the quote.
Methods inherited from StripeService
#initialize, #request, #request_stream
Constructor Details
This class inherits a constructor from Stripe::StripeService
Instance Method Details
#list(quote, params = {}, opts = {}) ⇒ Object
Preview the schedules that would be generated by accepting the quote
7 8 9 10 11 12 13 14 15 |
# File 'lib/stripe/services/quote_preview_subscription_schedule_service.rb', line 7 def list(quote, params = {}, opts = {}) request( method: :get, path: format("/v1/quotes/%<quote>s/preview_subscription_schedules", { quote: CGI.escape(quote) }), params: params, opts: opts, base_address: :api ) end |