Class: Stripe::QuoteService::CreateParams::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/quote_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



105
106
107
108
109
# File 'lib/stripe/services/quote_service.rb', line 105

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



99
100
101
# File 'lib/stripe/services/quote_service.rb', line 99

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



101
102
103
# File 'lib/stripe/services/quote_service.rb', line 101

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



103
104
105
# File 'lib/stripe/services/quote_service.rb', line 103

def type
  @type
end