Class: Stripe::QuoteService::CreateParams::FromQuote
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteService::CreateParams::FromQuote
- Defined in:
- lib/stripe/services/quote_service.rb
Instance Attribute Summary collapse
-
#is_revision ⇒ Object
Whether this quote is a revision of the previous quote.
-
#quote ⇒ Object
The ‘id` of the quote that will be cloned.
Instance Method Summary collapse
-
#initialize(is_revision: nil, quote: nil) ⇒ FromQuote
constructor
A new instance of FromQuote.
Methods inherited from RequestParams
Constructor Details
#initialize(is_revision: nil, quote: nil) ⇒ FromQuote
Returns a new instance of FromQuote.
134 135 136 137 |
# File 'lib/stripe/services/quote_service.rb', line 134 def initialize(is_revision: nil, quote: nil) @is_revision = is_revision @quote = quote end |
Instance Attribute Details
#is_revision ⇒ Object
Whether this quote is a revision of the previous quote.
130 131 132 |
# File 'lib/stripe/services/quote_service.rb', line 130 def is_revision @is_revision end |
#quote ⇒ Object
The ‘id` of the quote that will be cloned.
132 133 134 |
# File 'lib/stripe/services/quote_service.rb', line 132 def quote @quote end |