Class: Stripe::QuoteService::CreateParams::InvoiceSettings

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/quote_service.rb

Defined Under Namespace

Classes: Issuer

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(days_until_due: nil, issuer: nil) ⇒ InvoiceSettings

Returns a new instance of InvoiceSettings.



157
158
159
160
# File 'lib/stripe/services/quote_service.rb', line 157

def initialize(days_until_due: nil, issuer: nil)
  @days_until_due = days_until_due
  @issuer = issuer
end

Instance Attribute Details

#days_until_dueObject

Number of days within which a customer must pay the invoice generated by this quote. This value will be ‘null` for quotes where `collection_method=charge_automatically`.



153
154
155
# File 'lib/stripe/services/quote_service.rb', line 153

def days_until_due
  @days_until_due
end

#issuerObject

The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.



155
156
157
# File 'lib/stripe/services/quote_service.rb', line 155

def issuer
  @issuer
end