Class: Stripe::QuoteService::CreateParams::Line::Action::AddItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/quote_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



260
261
262
263
264
265
# File 'lib/stripe/services/quote_service.rb', line 260

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



249
250
251
# File 'lib/stripe/services/quote_service.rb', line 249

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



252
253
254
# File 'lib/stripe/services/quote_service.rb', line 252

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



255
256
257
# File 'lib/stripe/services/quote_service.rb', line 255

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



258
259
260
# File 'lib/stripe/services/quote_service.rb', line 258

def promotion_code
  @promotion_code
end