Class: Stripe::QuoteService::CreateParams::Line::Action::AddItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/quote_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



221
222
223
224
225
# File 'lib/stripe/services/quote_service.rb', line 221

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



215
216
217
# File 'lib/stripe/services/quote_service.rb', line 215

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



217
218
219
# File 'lib/stripe/services/quote_service.rb', line 217

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



219
220
221
# File 'lib/stripe/services/quote_service.rb', line 219

def type
  @type
end