Class: Stripe::QuoteService::CreateParams::Line::Action::SetItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/quote_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



356
357
358
359
360
361
# File 'lib/stripe/services/quote_service.rb', line 356

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



348
349
350
# File 'lib/stripe/services/quote_service.rb', line 348

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



350
351
352
# File 'lib/stripe/services/quote_service.rb', line 350

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



352
353
354
# File 'lib/stripe/services/quote_service.rb', line 352

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



354
355
356
# File 'lib/stripe/services/quote_service.rb', line 354

def promotion_code
  @promotion_code
end