Class: Stripe::QuoteService::CreateParams::Line::EndsAt
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteService::CreateParams::Line::EndsAt
- Defined in:
- lib/stripe/services/quote_service.rb
Defined Under Namespace
Classes: DiscountEnd, Duration
Instance Attribute Summary collapse
-
#discount_end ⇒ Object
Use the ‘end` time of a given discount.
-
#duration ⇒ Object
Time span for the quote line starting from the ‘starts_at` date.
-
#timestamp ⇒ Object
A precise Unix timestamp.
-
#type ⇒ Object
Select a way to pass in ‘ends_at`.
Instance Method Summary collapse
-
#initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ EndsAt
constructor
A new instance of EndsAt.
Methods inherited from RequestParams
Constructor Details
#initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ EndsAt
Returns a new instance of EndsAt.
577 578 579 580 581 582 |
# File 'lib/stripe/services/quote_service.rb', line 577 def initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) @discount_end = discount_end @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#discount_end ⇒ Object
Use the ‘end` time of a given discount.
566 567 568 |
# File 'lib/stripe/services/quote_service.rb', line 566 def discount_end @discount_end end |
#duration ⇒ Object
Time span for the quote line starting from the ‘starts_at` date.
569 570 571 |
# File 'lib/stripe/services/quote_service.rb', line 569 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp.
572 573 574 |
# File 'lib/stripe/services/quote_service.rb', line 572 def @timestamp end |
#type ⇒ Object
Select a way to pass in ‘ends_at`.
575 576 577 |
# File 'lib/stripe/services/quote_service.rb', line 575 def type @type end |