Class: Stripe::QuoteService::CreateParams::Line::StartsAt::LineEndsAt

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/quote_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(index: nil) ⇒ LineEndsAt

Returns a new instance of LineEndsAt.



552
553
554
# File 'lib/stripe/services/quote_service.rb', line 552

def initialize(index: nil)
  @index = index
end

Instance Attribute Details

#indexObject

The position of the previous quote line in the ‘lines` array after which this line should begin. Indexes start from 0 and must be less than the index of the current line in the array.



550
551
552
# File 'lib/stripe/services/quote_service.rb', line 550

def index
  @index
end