Class: Stripe::QuoteService::CreateParams::LineItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/quote_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



671
672
673
674
675
676
# File 'lib/stripe/services/quote_service.rb', line 671

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



663
664
665
# File 'lib/stripe/services/quote_service.rb', line 663

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



665
666
667
# File 'lib/stripe/services/quote_service.rb', line 665

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



667
668
669
# File 'lib/stripe/services/quote_service.rb', line 667

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



669
670
671
# File 'lib/stripe/services/quote_service.rb', line 669

def promotion_code
  @promotion_code
end