Class: Stripe::QuoteService::CreateParams::LineItem::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteService::CreateParams::LineItem::Discount::DiscountEnd
- Defined in:
- lib/stripe/services/quote_service.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
660 661 662 663 664 |
# File 'lib/stripe/services/quote_service.rb', line 660 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
654 655 656 |
# File 'lib/stripe/services/quote_service.rb', line 654 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
656 657 658 |
# File 'lib/stripe/services/quote_service.rb', line 656 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
658 659 660 |
# File 'lib/stripe/services/quote_service.rb', line 658 def type @type end |