Class: Stripe::QuoteService::CreateParams::SubscriptionData::BillOnAcceptance::BillFrom
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteService::CreateParams::SubscriptionData::BillOnAcceptance::BillFrom
- Defined in:
- lib/stripe/services/quote_service.rb
Defined Under Namespace
Classes: LineStartsAt
Instance Attribute Summary collapse
-
#line_starts_at ⇒ Object
Details of a Quote line to start the bill period from.
-
#timestamp ⇒ Object
A precise Unix timestamp.
-
#type ⇒ Object
The type of method to specify the ‘bill_from` time.
Instance Method Summary collapse
-
#initialize(line_starts_at: nil, timestamp: nil, type: nil) ⇒ BillFrom
constructor
A new instance of BillFrom.
Methods inherited from RequestParams
Constructor Details
#initialize(line_starts_at: nil, timestamp: nil, type: nil) ⇒ BillFrom
Returns a new instance of BillFrom.
761 762 763 764 765 |
# File 'lib/stripe/services/quote_service.rb', line 761 def initialize(line_starts_at: nil, timestamp: nil, type: nil) @line_starts_at = line_starts_at @timestamp = @type = type end |
Instance Attribute Details
#line_starts_at ⇒ Object
Details of a Quote line to start the bill period from.
755 756 757 |
# File 'lib/stripe/services/quote_service.rb', line 755 def line_starts_at @line_starts_at end |
#timestamp ⇒ Object
A precise Unix timestamp.
757 758 759 |
# File 'lib/stripe/services/quote_service.rb', line 757 def @timestamp end |
#type ⇒ Object
The type of method to specify the ‘bill_from` time.
759 760 761 |
# File 'lib/stripe/services/quote_service.rb', line 759 def type @type end |