Class: Stripe::QuoteService::CreateParams::SubscriptionData::BillOnAcceptance::BillUntil
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteService::CreateParams::SubscriptionData::BillOnAcceptance::BillUntil
- Defined in:
- lib/stripe/services/quote_service.rb
Defined Under Namespace
Classes: Duration, LineEndsAt
Instance Attribute Summary collapse
-
#duration ⇒ Object
Details of the duration over which to bill.
-
#line_ends_at ⇒ Object
Details of a Quote line item from which to bill until.
-
#timestamp ⇒ Object
A precise Unix timestamp.
-
#type ⇒ Object
The type of method to specify the ‘bill_until` time.
Instance Method Summary collapse
-
#initialize(duration: nil, line_ends_at: nil, timestamp: nil, type: nil) ⇒ BillUntil
constructor
A new instance of BillUntil.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, line_ends_at: nil, timestamp: nil, type: nil) ⇒ BillUntil
Returns a new instance of BillUntil.
801 802 803 804 805 806 |
# File 'lib/stripe/services/quote_service.rb', line 801 def initialize(duration: nil, line_ends_at: nil, timestamp: nil, type: nil) @duration = duration @line_ends_at = line_ends_at @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Details of the duration over which to bill.
793 794 795 |
# File 'lib/stripe/services/quote_service.rb', line 793 def duration @duration end |
#line_ends_at ⇒ Object
Details of a Quote line item from which to bill until.
795 796 797 |
# File 'lib/stripe/services/quote_service.rb', line 795 def line_ends_at @line_ends_at end |
#timestamp ⇒ Object
A precise Unix timestamp.
797 798 799 |
# File 'lib/stripe/services/quote_service.rb', line 797 def @timestamp end |
#type ⇒ Object
The type of method to specify the ‘bill_until` time.
799 800 801 |
# File 'lib/stripe/services/quote_service.rb', line 799 def type @type end |