Class: Stripe::QuoteService::CreateParams::SubscriptionData::BillOnAcceptance::BillUntil::LineEndsAt

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/quote_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(id: nil, index: nil) ⇒ LineEndsAt

Returns a new instance of LineEndsAt.



791
792
793
794
# File 'lib/stripe/services/quote_service.rb', line 791

def initialize(id: nil, index: nil)
  @id = id
  @index = index
end

Instance Attribute Details

#idObject

The ID of a quote line.



787
788
789
# File 'lib/stripe/services/quote_service.rb', line 787

def id
  @id
end

#indexObject

The position of the previous quote line in the ‘lines` array after which this line should begin. Indexes start from 0 and must be less than the index of the current line in the array.



789
790
791
# File 'lib/stripe/services/quote_service.rb', line 789

def index
  @index
end