Class: Stripe::QuoteService::CreateParams::SubscriptionData::Prebilling
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteService::CreateParams::SubscriptionData::Prebilling
- Defined in:
- lib/stripe/services/quote_service.rb
Instance Attribute Summary collapse
-
#iterations ⇒ Object
This is used to determine the number of billing cycles to prebill.
Instance Method Summary collapse
-
#initialize(iterations: nil) ⇒ Prebilling
constructor
A new instance of Prebilling.
Methods inherited from RequestParams
Constructor Details
#initialize(iterations: nil) ⇒ Prebilling
Returns a new instance of Prebilling.
827 828 829 |
# File 'lib/stripe/services/quote_service.rb', line 827 def initialize(iterations: nil) @iterations = iterations end |
Instance Attribute Details
#iterations ⇒ Object
This is used to determine the number of billing cycles to prebill.
825 826 827 |
# File 'lib/stripe/services/quote_service.rb', line 825 def iterations @iterations end |