Class: Stripe::QuoteService::CreateParams::SubscriptionDataOverride::AppliesTo

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/quote_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(new_reference: nil, subscription_schedule: nil, type: nil) ⇒ AppliesTo

Returns a new instance of AppliesTo.



900
901
902
903
904
# File 'lib/stripe/services/quote_service.rb', line 900

def initialize(new_reference: nil, subscription_schedule: nil, type: nil)
  @new_reference = new_reference
  @subscription_schedule = subscription_schedule
  @type = type
end

Instance Attribute Details

#new_referenceObject

A custom string that identifies a new subscription schedule being created upon quote acceptance. All quote lines with the same ‘new_reference` field will be applied to the creation of a new subscription schedule.



894
895
896
# File 'lib/stripe/services/quote_service.rb', line 894

def new_reference
  @new_reference
end

#subscription_scheduleObject

The ID of the schedule the line applies to.



896
897
898
# File 'lib/stripe/services/quote_service.rb', line 896

def subscription_schedule
  @subscription_schedule
end

#typeObject

Describes whether the quote line is affecting a new schedule or an existing schedule.



898
899
900
# File 'lib/stripe/services/quote_service.rb', line 898

def type
  @type
end