Class: Stripe::QuoteService::CreateParams::SubscriptionDataOverride::BillOnAcceptance::BillUntil
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteService::CreateParams::SubscriptionDataOverride::BillOnAcceptance::BillUntil
- Defined in:
- lib/stripe/services/quote_service.rb
Defined Under Namespace
Classes: Duration, LineEndsAt
Instance Attribute Summary collapse
-
#duration ⇒ Object
Details of the duration over which to bill.
-
#line_ends_at ⇒ Object
Details of a Quote line item from which to bill until.
-
#timestamp ⇒ Object
A precise Unix timestamp.
-
#type ⇒ Object
The type of method to specify the ‘bill_until` time.
Instance Method Summary collapse
-
#initialize(duration: nil, line_ends_at: nil, timestamp: nil, type: nil) ⇒ BillUntil
constructor
A new instance of BillUntil.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, line_ends_at: nil, timestamp: nil, type: nil) ⇒ BillUntil
Returns a new instance of BillUntil.
976 977 978 979 980 981 |
# File 'lib/stripe/services/quote_service.rb', line 976 def initialize(duration: nil, line_ends_at: nil, timestamp: nil, type: nil) @duration = duration @line_ends_at = line_ends_at @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Details of the duration over which to bill.
968 969 970 |
# File 'lib/stripe/services/quote_service.rb', line 968 def duration @duration end |
#line_ends_at ⇒ Object
Details of a Quote line item from which to bill until.
970 971 972 |
# File 'lib/stripe/services/quote_service.rb', line 970 def line_ends_at @line_ends_at end |
#timestamp ⇒ Object
A precise Unix timestamp.
972 973 974 |
# File 'lib/stripe/services/quote_service.rb', line 972 def @timestamp end |
#type ⇒ Object
The type of method to specify the ‘bill_until` time.
974 975 976 |
# File 'lib/stripe/services/quote_service.rb', line 974 def type @type end |