Class: Stripe::QuoteService::CreateParams::SubscriptionDataOverride::BillOnAcceptance::BillUntil::Duration
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteService::CreateParams::SubscriptionDataOverride::BillOnAcceptance::BillUntil::Duration
- Defined in:
- lib/stripe/services/quote_service.rb
Instance Attribute Summary collapse
-
#interval ⇒ Object
Specifies a type of interval unit.
-
#interval_count ⇒ Object
The number of intervals, as an whole number greater than 0.
Instance Method Summary collapse
-
#initialize(interval: nil, interval_count: nil) ⇒ Duration
constructor
A new instance of Duration.
Methods inherited from RequestParams
Constructor Details
#initialize(interval: nil, interval_count: nil) ⇒ Duration
Returns a new instance of Duration.
1054 1055 1056 1057 |
# File 'lib/stripe/services/quote_service.rb', line 1054 def initialize(interval: nil, interval_count: nil) @interval = interval @interval_count = interval_count end |
Instance Attribute Details
#interval ⇒ Object
Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.
1049 1050 1051 |
# File 'lib/stripe/services/quote_service.rb', line 1049 def interval @interval end |
#interval_count ⇒ Object
The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.
1052 1053 1054 |
# File 'lib/stripe/services/quote_service.rb', line 1052 def interval_count @interval_count end |