Class: Stripe::QuoteService::FinalizeQuoteParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/quote_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, expires_at: nil) ⇒ FinalizeQuoteParams

Returns a new instance of FinalizeQuoteParams.



2225
2226
2227
2228
# File 'lib/stripe/services/quote_service.rb', line 2225

def initialize(expand: nil, expires_at: nil)
  @expand = expand
  @expires_at = expires_at
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



2221
2222
2223
# File 'lib/stripe/services/quote_service.rb', line 2221

def expand
  @expand
end

#expires_atObject

A future timestamp on which the quote will be canceled if in ‘open` or `draft` status. Measured in seconds since the Unix epoch.



2223
2224
2225
# File 'lib/stripe/services/quote_service.rb', line 2223

def expires_at
  @expires_at
end