Class: Stripe::QuoteService::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/quote_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(customer: nil, customer_account: nil, ending_before: nil, expand: nil, from_subscription: nil, limit: nil, starting_after: nil, status: nil, test_clock: nil) ⇒ ListParams

Returns a new instance of ListParams.



38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
# File 'lib/stripe/services/quote_service.rb', line 38

def initialize(
  customer: nil,
  customer_account: nil,
  ending_before: nil,
  expand: nil,
  from_subscription: nil,
  limit: nil,
  starting_after: nil,
  status: nil,
  test_clock: nil
)
  @customer = customer
  @customer_account = 
  @ending_before = ending_before
  @expand = expand
  @from_subscription = from_subscription
  @limit = limit
  @starting_after = starting_after
  @status = status
  @test_clock = test_clock
end

Instance Attribute Details

#customerObject

The ID of the customer whose quotes will be retrieved.



20
21
22
# File 'lib/stripe/services/quote_service.rb', line 20

def customer
  @customer
end

#customer_accountObject

The ID of the account whose quotes will be retrieved.



22
23
24
# File 'lib/stripe/services/quote_service.rb', line 22

def 
  @customer_account
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



24
25
26
# File 'lib/stripe/services/quote_service.rb', line 24

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



26
27
28
# File 'lib/stripe/services/quote_service.rb', line 26

def expand
  @expand
end

#from_subscriptionObject

The subscription which the quote updates.



28
29
30
# File 'lib/stripe/services/quote_service.rb', line 28

def from_subscription
  @from_subscription
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



30
31
32
# File 'lib/stripe/services/quote_service.rb', line 30

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



32
33
34
# File 'lib/stripe/services/quote_service.rb', line 32

def starting_after
  @starting_after
end

#statusObject

The status of the quote.



34
35
36
# File 'lib/stripe/services/quote_service.rb', line 34

def status
  @status
end

#test_clockObject

Provides a list of quotes that are associated with the specified test clock. The response will not include quotes with test clocks if this and the customer parameter is not set.



36
37
38
# File 'lib/stripe/services/quote_service.rb', line 36

def test_clock
  @test_clock
end