Class: Stripe::QuoteService::ListPreviewInvoiceLinesParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteService::ListPreviewInvoiceLinesParams
- Defined in:
- lib/stripe/services/quote_service.rb
Instance Attribute Summary collapse
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#starting_after ⇒ Object
A cursor for use in pagination.
Instance Method Summary collapse
-
#initialize(ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListPreviewInvoiceLinesParams
constructor
A new instance of ListPreviewInvoiceLinesParams.
Methods inherited from RequestParams
Constructor Details
#initialize(ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListPreviewInvoiceLinesParams
Returns a new instance of ListPreviewInvoiceLinesParams.
2280 2281 2282 2283 2284 2285 |
# File 'lib/stripe/services/quote_service.rb', line 2280 def initialize(ending_before: nil, expand: nil, limit: nil, starting_after: nil) @ending_before = ending_before @expand = @limit = limit @starting_after = starting_after end |
Instance Attribute Details
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
2272 2273 2274 |
# File 'lib/stripe/services/quote_service.rb', line 2272 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2274 2275 2276 |
# File 'lib/stripe/services/quote_service.rb', line 2274 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
2276 2277 2278 |
# File 'lib/stripe/services/quote_service.rb', line 2276 def limit @limit end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
2278 2279 2280 |
# File 'lib/stripe/services/quote_service.rb', line 2278 def starting_after @starting_after end |