Class: Stripe::QuoteService::MarkDraftParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteService::MarkDraftParams
- Defined in:
- lib/stripe/services/quote_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ MarkDraftParams
constructor
A new instance of MarkDraftParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ MarkDraftParams
Returns a new instance of MarkDraftParams.
2247 2248 2249 |
# File 'lib/stripe/services/quote_service.rb', line 2247 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2245 2246 2247 |
# File 'lib/stripe/services/quote_service.rb', line 2245 def @expand end |