Class: Stripe::QuoteService::MarkStaleParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteService::MarkStaleParams
- Defined in:
- lib/stripe/services/quote_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#reason ⇒ Object
Reason the Quote is being marked stale.
Instance Method Summary collapse
-
#initialize(expand: nil, reason: nil) ⇒ MarkStaleParams
constructor
A new instance of MarkStaleParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, reason: nil) ⇒ MarkStaleParams
Returns a new instance of MarkStaleParams.
2258 2259 2260 2261 |
# File 'lib/stripe/services/quote_service.rb', line 2258 def initialize(expand: nil, reason: nil) @expand = @reason = reason end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2254 2255 2256 |
# File 'lib/stripe/services/quote_service.rb', line 2254 def @expand end |
#reason ⇒ Object
Reason the Quote is being marked stale.
2256 2257 2258 |
# File 'lib/stripe/services/quote_service.rb', line 2256 def reason @reason end |