Class: Stripe::QuoteService::ReestimateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteService::ReestimateParams
- Defined in:
- lib/stripe/services/quote_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ ReestimateParams
constructor
A new instance of ReestimateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ ReestimateParams
Returns a new instance of ReestimateParams.
2272 2273 2274 |
# File 'lib/stripe/services/quote_service.rb', line 2272 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2270 2271 2272 |
# File 'lib/stripe/services/quote_service.rb', line 2270 def @expand end |