Class: Stripe::QuoteService::UpdateParams::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/quote_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1217
1218
1219
1220
1221
1222
# File 'lib/stripe/services/quote_service.rb', line 1217

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1209
1210
1211
# File 'lib/stripe/services/quote_service.rb', line 1209

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1211
1212
1213
# File 'lib/stripe/services/quote_service.rb', line 1211

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1213
1214
1215
# File 'lib/stripe/services/quote_service.rb', line 1213

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1215
1216
1217
# File 'lib/stripe/services/quote_service.rb', line 1215

def promotion_code
  @promotion_code
end