Class: Stripe::QuoteService::UpdateParams::Line::Action::AddDiscount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteService::UpdateParams::Line::Action::AddDiscount
- Defined in:
- lib/stripe/services/quote_service.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
The coupon code to redeem.
-
#discount ⇒ Object
An ID of an existing discount for a coupon that was already redeemed.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#index ⇒ Object
The index, starting at 0, at which to position the new discount.
-
#promotion_code ⇒ Object
The promotion code to redeem.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ AddDiscount
constructor
A new instance of AddDiscount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ AddDiscount
Returns a new instance of AddDiscount.
1270 1271 1272 1273 1274 1275 1276 1277 1278 1279 1280 1281 1282 |
# File 'lib/stripe/services/quote_service.rb', line 1270 def initialize( coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil ) @coupon = coupon @discount = discount @discount_end = discount_end @index = index @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
The coupon code to redeem.
1260 1261 1262 |
# File 'lib/stripe/services/quote_service.rb', line 1260 def coupon @coupon end |
#discount ⇒ Object
An ID of an existing discount for a coupon that was already redeemed.
1262 1263 1264 |
# File 'lib/stripe/services/quote_service.rb', line 1262 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
1264 1265 1266 |
# File 'lib/stripe/services/quote_service.rb', line 1264 def discount_end @discount_end end |
#index ⇒ Object
The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the ‘discounts` array.
1266 1267 1268 |
# File 'lib/stripe/services/quote_service.rb', line 1266 def index @index end |
#promotion_code ⇒ Object
The promotion code to redeem.
1268 1269 1270 |
# File 'lib/stripe/services/quote_service.rb', line 1268 def promotion_code @promotion_code end |