Class: Stripe::QuoteService::UpdateParams::Line::Action::AddDiscount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteService::UpdateParams::Line::Action::AddDiscount::DiscountEnd
- Defined in:
- lib/stripe/services/quote_service.rb
Instance Attribute Summary collapse
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
1234 1235 1236 |
# File 'lib/stripe/services/quote_service.rb', line 1234 def initialize(type: nil) @type = type end |
Instance Attribute Details
#type ⇒ Object
The type of calculation made to determine when the discount ends.
1232 1233 1234 |
# File 'lib/stripe/services/quote_service.rb', line 1232 def type @type end |