Class: Stripe::QuoteService::UpdateParams::Line::Action::AddItem::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteService::UpdateParams::Line::Action::AddItem::Discount
- Defined in:
- lib/stripe/services/quote_service.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
1312 1313 1314 1315 1316 1317 |
# File 'lib/stripe/services/quote_service.rb', line 1312 def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
1304 1305 1306 |
# File 'lib/stripe/services/quote_service.rb', line 1304 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
1306 1307 1308 |
# File 'lib/stripe/services/quote_service.rb', line 1306 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
1308 1309 1310 |
# File 'lib/stripe/services/quote_service.rb', line 1308 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
1310 1311 1312 |
# File 'lib/stripe/services/quote_service.rb', line 1310 def promotion_code @promotion_code end |