Class: Stripe::QuoteService::UpdateParams::Line::Action::AddItem::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteService::UpdateParams::Line::Action::AddItem::Discount::DiscountEnd
- Defined in:
- lib/stripe/services/quote_service.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
1306 1307 1308 1309 1310 |
# File 'lib/stripe/services/quote_service.rb', line 1306 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
1300 1301 1302 |
# File 'lib/stripe/services/quote_service.rb', line 1300 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
1302 1303 1304 |
# File 'lib/stripe/services/quote_service.rb', line 1302 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
1304 1305 1306 |
# File 'lib/stripe/services/quote_service.rb', line 1304 def type @type end |