Class: Stripe::QuoteService::UpdateParams::Line::Action::AddItem::Trial
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteService::UpdateParams::Line::Action::AddItem::Trial
- Defined in:
- lib/stripe/services/quote_service.rb
Instance Attribute Summary collapse
-
#converts_to ⇒ Object
List of price IDs which, if present on the subscription following a paid trial, constitute opting-in to the paid trial.
-
#type ⇒ Object
Determines the type of trial for this item.
Instance Method Summary collapse
-
#initialize(converts_to: nil, type: nil) ⇒ Trial
constructor
A new instance of Trial.
Methods inherited from RequestParams
Constructor Details
#initialize(converts_to: nil, type: nil) ⇒ Trial
Returns a new instance of Trial.
1314 1315 1316 1317 |
# File 'lib/stripe/services/quote_service.rb', line 1314 def initialize(converts_to: nil, type: nil) @converts_to = converts_to @type = type end |
Instance Attribute Details
#converts_to ⇒ Object
List of price IDs which, if present on the subscription following a paid trial, constitute opting-in to the paid trial. Currently only supports at most 1 price ID.
1310 1311 1312 |
# File 'lib/stripe/services/quote_service.rb', line 1310 def converts_to @converts_to end |
#type ⇒ Object
Determines the type of trial for this item.
1312 1313 1314 |
# File 'lib/stripe/services/quote_service.rb', line 1312 def type @type end |