Class: Stripe::QuoteService::UpdateParams::Line::Action::RemoveDiscount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/quote_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ RemoveDiscount

Returns a new instance of RemoveDiscount.



1378
1379
1380
1381
1382
# File 'lib/stripe/services/quote_service.rb', line 1378

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to remove from the ‘discounts` array.



1372
1373
1374
# File 'lib/stripe/services/quote_service.rb', line 1372

def coupon
  @coupon
end

#discountObject

The ID of a discount to remove from the ‘discounts` array.



1374
1375
1376
# File 'lib/stripe/services/quote_service.rb', line 1374

def discount
  @discount
end

#promotion_codeObject

The ID of a promotion code to remove from the ‘discounts` array.



1376
1377
1378
# File 'lib/stripe/services/quote_service.rb', line 1376

def promotion_code
  @promotion_code
end