Class: Stripe::QuoteService::UpdateParams::Line::Action::SetItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/quote_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1445
1446
1447
1448
1449
1450
# File 'lib/stripe/services/quote_service.rb', line 1445

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1437
1438
1439
# File 'lib/stripe/services/quote_service.rb', line 1437

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1439
1440
1441
# File 'lib/stripe/services/quote_service.rb', line 1439

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1441
1442
1443
# File 'lib/stripe/services/quote_service.rb', line 1441

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1443
1444
1445
# File 'lib/stripe/services/quote_service.rb', line 1443

def promotion_code
  @promotion_code
end