Class: Stripe::QuoteService::UpdateParams::Line::Action::SetItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/quote_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



1430
1431
1432
1433
1434
# File 'lib/stripe/services/quote_service.rb', line 1430

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



1424
1425
1426
# File 'lib/stripe/services/quote_service.rb', line 1424

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



1426
1427
1428
# File 'lib/stripe/services/quote_service.rb', line 1426

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



1428
1429
1430
# File 'lib/stripe/services/quote_service.rb', line 1428

def type
  @type
end