Class: Stripe::QuoteService::UpdateParams::Line::Action::SetItem::Discount::DiscountEnd::Duration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/quote_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(interval: nil, interval_count: nil) ⇒ Duration

Returns a new instance of Duration.



1584
1585
1586
1587
# File 'lib/stripe/services/quote_service.rb', line 1584

def initialize(interval: nil, interval_count: nil)
  @interval = interval
  @interval_count = interval_count
end

Instance Attribute Details

#intervalObject

Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.



1579
1580
1581
# File 'lib/stripe/services/quote_service.rb', line 1579

def interval
  @interval
end

#interval_countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



1582
1583
1584
# File 'lib/stripe/services/quote_service.rb', line 1582

def interval_count
  @interval_count
end