Class: Stripe::QuoteService::UpdateParams::Line::AppliesTo

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/quote_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(new_reference: nil, subscription_schedule: nil, type: nil) ⇒ AppliesTo

Returns a new instance of AppliesTo.



1547
1548
1549
1550
1551
# File 'lib/stripe/services/quote_service.rb', line 1547

def initialize(new_reference: nil, subscription_schedule: nil, type: nil)
  @new_reference = new_reference
  @subscription_schedule = subscription_schedule
  @type = type
end

Instance Attribute Details

#new_referenceObject

A custom string that identifies a new subscription schedule being created upon quote acceptance. All quote lines with the same ‘new_reference` field will be applied to the creation of a new subscription schedule.



1541
1542
1543
# File 'lib/stripe/services/quote_service.rb', line 1541

def new_reference
  @new_reference
end

#subscription_scheduleObject

The ID of the schedule the line applies to.



1543
1544
1545
# File 'lib/stripe/services/quote_service.rb', line 1543

def subscription_schedule
  @subscription_schedule
end

#typeObject

Describes whether the quote line is affecting a new schedule or an existing schedule.



1545
1546
1547
# File 'lib/stripe/services/quote_service.rb', line 1545

def type
  @type
end