Class: Stripe::QuoteService::UpdateParams::Line::EndsAt
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteService::UpdateParams::Line::EndsAt
- Defined in:
- lib/stripe/services/quote_service.rb
Defined Under Namespace
Classes: DiscountEnd, Duration
Instance Attribute Summary collapse
-
#discount_end ⇒ Object
Use the ‘end` time of a given discount.
-
#duration ⇒ Object
Time span for the quote line starting from the ‘starts_at` date.
-
#timestamp ⇒ Object
A precise Unix timestamp.
-
#type ⇒ Object
Select a way to pass in ‘ends_at`.
Instance Method Summary collapse
-
#initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ EndsAt
constructor
A new instance of EndsAt.
Methods inherited from RequestParams
Constructor Details
#initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ EndsAt
Returns a new instance of EndsAt.
1599 1600 1601 1602 1603 1604 |
# File 'lib/stripe/services/quote_service.rb', line 1599 def initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) @discount_end = discount_end @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#discount_end ⇒ Object
Use the ‘end` time of a given discount.
1591 1592 1593 |
# File 'lib/stripe/services/quote_service.rb', line 1591 def discount_end @discount_end end |
#duration ⇒ Object
Time span for the quote line starting from the ‘starts_at` date.
1593 1594 1595 |
# File 'lib/stripe/services/quote_service.rb', line 1593 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp.
1595 1596 1597 |
# File 'lib/stripe/services/quote_service.rb', line 1595 def @timestamp end |
#type ⇒ Object
Select a way to pass in ‘ends_at`.
1597 1598 1599 |
# File 'lib/stripe/services/quote_service.rb', line 1597 def type @type end |