Class: Stripe::QuoteService::UpdateParams::Line::StartsAt::LineEndsAt

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/quote_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(id: nil, index: nil) ⇒ LineEndsAt

Returns a new instance of LineEndsAt.



1643
1644
1645
1646
# File 'lib/stripe/services/quote_service.rb', line 1643

def initialize(id: nil, index: nil)
  @id = id
  @index = index
end

Instance Attribute Details

#idObject

The ID of a quote line.



1639
1640
1641
# File 'lib/stripe/services/quote_service.rb', line 1639

def id
  @id
end

#indexObject

The position of the previous quote line in the ‘lines` array after which this line should begin. Indexes start from 0 and must be less than the index of the current line in the array.



1641
1642
1643
# File 'lib/stripe/services/quote_service.rb', line 1641

def index
  @index
end