Class: Stripe::QuoteService::UpdateParams::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteService::UpdateParams::LineItem
- Defined in:
- lib/stripe/services/quote_service.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#discounts ⇒ Object
The discounts applied to this line item.
-
#id ⇒ Object
The ID of an existing line item on the quote.
-
#price ⇒ Object
The ID of the price object.
-
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.
-
#quantity ⇒ Object
The quantity of the line item.
-
#tax_rates ⇒ Object
The tax rates which apply to the line item.
Instance Method Summary collapse
-
#initialize(discounts: nil, id: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(discounts: nil, id: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ LineItem
Returns a new instance of LineItem.
476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 |
# File 'lib/stripe/services/quote_service.rb', line 476 def initialize( discounts: nil, id: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil ) @discounts = discounts @id = id @price = price @price_data = price_data @quantity = quantity @tax_rates = tax_rates end |
Instance Attribute Details
#discounts ⇒ Object
The discounts applied to this line item.
464 465 466 |
# File 'lib/stripe/services/quote_service.rb', line 464 def discounts @discounts end |
#id ⇒ Object
The ID of an existing line item on the quote.
466 467 468 |
# File 'lib/stripe/services/quote_service.rb', line 466 def id @id end |
#price ⇒ Object
The ID of the price object. One of ‘price` or `price_data` is required.
468 469 470 |
# File 'lib/stripe/services/quote_service.rb', line 468 def price @price end |
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.
470 471 472 |
# File 'lib/stripe/services/quote_service.rb', line 470 def price_data @price_data end |
#quantity ⇒ Object
The quantity of the line item.
472 473 474 |
# File 'lib/stripe/services/quote_service.rb', line 472 def quantity @quantity end |
#tax_rates ⇒ Object
The tax rates which apply to the line item. When set, the ‘default_tax_rates` on the quote do not apply to this line item.
474 475 476 |
# File 'lib/stripe/services/quote_service.rb', line 474 def tax_rates @tax_rates end |