Class: Stripe::QuoteService::UpdateParams::LineItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/quote_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1767
1768
1769
1770
1771
1772
# File 'lib/stripe/services/quote_service.rb', line 1767

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1759
1760
1761
# File 'lib/stripe/services/quote_service.rb', line 1759

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1761
1762
1763
# File 'lib/stripe/services/quote_service.rb', line 1761

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1763
1764
1765
# File 'lib/stripe/services/quote_service.rb', line 1763

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1765
1766
1767
# File 'lib/stripe/services/quote_service.rb', line 1765

def promotion_code
  @promotion_code
end