Class: Stripe::QuoteService::UpdateParams::LineItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/quote_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



1731
1732
1733
1734
1735
# File 'lib/stripe/services/quote_service.rb', line 1731

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



1725
1726
1727
# File 'lib/stripe/services/quote_service.rb', line 1725

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



1727
1728
1729
# File 'lib/stripe/services/quote_service.rb', line 1727

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



1729
1730
1731
# File 'lib/stripe/services/quote_service.rb', line 1729

def type
  @type
end