Class: Stripe::QuoteService::UpdateParams::LineItem::Discount::DiscountEnd::Duration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/quote_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(interval: nil, interval_count: nil) ⇒ Duration

Returns a new instance of Duration.



1950
1951
1952
1953
# File 'lib/stripe/services/quote_service.rb', line 1950

def initialize(interval: nil, interval_count: nil)
  @interval = interval
  @interval_count = interval_count
end

Instance Attribute Details

#intervalObject

Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.



1945
1946
1947
# File 'lib/stripe/services/quote_service.rb', line 1945

def interval
  @interval
end

#interval_countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



1948
1949
1950
# File 'lib/stripe/services/quote_service.rb', line 1948

def interval_count
  @interval_count
end