Class: Stripe::QuoteService::UpdateParams::SubscriptionData::BillOnAcceptance::BillFrom::LineStartsAt
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteService::UpdateParams::SubscriptionData::BillOnAcceptance::BillFrom::LineStartsAt
- Defined in:
- lib/stripe/services/quote_service.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
The ID of a quote line.
-
#index ⇒ Object
The position of the previous quote line in the ‘lines` array after which this line should begin.
Instance Method Summary collapse
-
#initialize(id: nil, index: nil) ⇒ LineStartsAt
constructor
A new instance of LineStartsAt.
Methods inherited from RequestParams
Constructor Details
#initialize(id: nil, index: nil) ⇒ LineStartsAt
Returns a new instance of LineStartsAt.
1855 1856 1857 1858 |
# File 'lib/stripe/services/quote_service.rb', line 1855 def initialize(id: nil, index: nil) @id = id @index = index end |
Instance Attribute Details
#id ⇒ Object
The ID of a quote line.
1851 1852 1853 |
# File 'lib/stripe/services/quote_service.rb', line 1851 def id @id end |
#index ⇒ Object
The position of the previous quote line in the ‘lines` array after which this line should begin. Indexes start from 0 and must be less than the index of the current line in the array.
1853 1854 1855 |
# File 'lib/stripe/services/quote_service.rb', line 1853 def index @index end |