Class: Stripe::QuoteService::UpdateParams::SubscriptionData::BillOnAcceptance::BillUntil
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteService::UpdateParams::SubscriptionData::BillOnAcceptance::BillUntil
- Defined in:
- lib/stripe/services/quote_service.rb
Defined Under Namespace
Classes: Duration, LineEndsAt
Instance Attribute Summary collapse
-
#duration ⇒ Object
Details of the duration over which to bill.
-
#line_ends_at ⇒ Object
Details of a Quote line item from which to bill until.
-
#timestamp ⇒ Object
A precise Unix timestamp.
-
#type ⇒ Object
The type of method to specify the ‘bill_until` time.
Instance Method Summary collapse
-
#initialize(duration: nil, line_ends_at: nil, timestamp: nil, type: nil) ⇒ BillUntil
constructor
A new instance of BillUntil.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, line_ends_at: nil, timestamp: nil, type: nil) ⇒ BillUntil
Returns a new instance of BillUntil.
1886 1887 1888 1889 1890 1891 |
# File 'lib/stripe/services/quote_service.rb', line 1886 def initialize(duration: nil, line_ends_at: nil, timestamp: nil, type: nil) @duration = duration @line_ends_at = line_ends_at @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Details of the duration over which to bill.
1878 1879 1880 |
# File 'lib/stripe/services/quote_service.rb', line 1878 def duration @duration end |
#line_ends_at ⇒ Object
Details of a Quote line item from which to bill until.
1880 1881 1882 |
# File 'lib/stripe/services/quote_service.rb', line 1880 def line_ends_at @line_ends_at end |
#timestamp ⇒ Object
A precise Unix timestamp.
1882 1883 1884 |
# File 'lib/stripe/services/quote_service.rb', line 1882 def @timestamp end |
#type ⇒ Object
The type of method to specify the ‘bill_until` time.
1884 1885 1886 |
# File 'lib/stripe/services/quote_service.rb', line 1884 def type @type end |