Class: Stripe::QuoteService::UpdateParams::SubscriptionData::BillOnAcceptance::BillUntil::LineEndsAt
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteService::UpdateParams::SubscriptionData::BillOnAcceptance::BillUntil::LineEndsAt
- Defined in:
- lib/stripe/services/quote_service.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
The ID of a quote line.
-
#index ⇒ Object
The position of the previous quote line in the ‘lines` array after which this line should begin.
Instance Method Summary collapse
-
#initialize(id: nil, index: nil) ⇒ LineEndsAt
constructor
A new instance of LineEndsAt.
Methods inherited from RequestParams
Constructor Details
#initialize(id: nil, index: nil) ⇒ LineEndsAt
Returns a new instance of LineEndsAt.
1893 1894 1895 1896 |
# File 'lib/stripe/services/quote_service.rb', line 1893 def initialize(id: nil, index: nil) @id = id @index = index end |
Instance Attribute Details
#id ⇒ Object
The ID of a quote line.
1889 1890 1891 |
# File 'lib/stripe/services/quote_service.rb', line 1889 def id @id end |
#index ⇒ Object
The position of the previous quote line in the ‘lines` array after which this line should begin. Indexes start from 0 and must be less than the index of the current line in the array.
1891 1892 1893 |
# File 'lib/stripe/services/quote_service.rb', line 1891 def index @index end |