Class: Stripe::QuoteService::UpdateParams::SubscriptionData::Prebilling
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteService::UpdateParams::SubscriptionData::Prebilling
- Defined in:
- lib/stripe/services/quote_service.rb
Instance Attribute Summary collapse
-
#iterations ⇒ Object
This is used to determine the number of billing cycles to prebill.
Instance Method Summary collapse
-
#initialize(iterations: nil) ⇒ Prebilling
constructor
A new instance of Prebilling.
Methods inherited from RequestParams
Constructor Details
#initialize(iterations: nil) ⇒ Prebilling
Returns a new instance of Prebilling.
1908 1909 1910 |
# File 'lib/stripe/services/quote_service.rb', line 1908 def initialize(iterations: nil) @iterations = iterations end |
Instance Attribute Details
#iterations ⇒ Object
This is used to determine the number of billing cycles to prebill.
1906 1907 1908 |
# File 'lib/stripe/services/quote_service.rb', line 1906 def iterations @iterations end |