Class: Stripe::QuoteService::UpdateParams::SubscriptionDataOverride::AppliesTo

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/quote_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(new_reference: nil, subscription_schedule: nil, type: nil) ⇒ AppliesTo

Returns a new instance of AppliesTo.



1973
1974
1975
1976
1977
# File 'lib/stripe/services/quote_service.rb', line 1973

def initialize(new_reference: nil, subscription_schedule: nil, type: nil)
  @new_reference = new_reference
  @subscription_schedule = subscription_schedule
  @type = type
end

Instance Attribute Details

#new_referenceObject

A custom string that identifies a new subscription schedule being created upon quote acceptance. All quote lines with the same ‘new_reference` field will be applied to the creation of a new subscription schedule.



1967
1968
1969
# File 'lib/stripe/services/quote_service.rb', line 1967

def new_reference
  @new_reference
end

#subscription_scheduleObject

The ID of the schedule the line applies to.



1969
1970
1971
# File 'lib/stripe/services/quote_service.rb', line 1969

def subscription_schedule
  @subscription_schedule
end

#typeObject

Describes whether the quote line is affecting a new schedule or an existing schedule.



1971
1972
1973
# File 'lib/stripe/services/quote_service.rb', line 1971

def type
  @type
end