Class: Stripe::QuoteService::UpdateParams::SubscriptionDataOverride::BillOnAcceptance::BillFrom
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteService::UpdateParams::SubscriptionDataOverride::BillOnAcceptance::BillFrom
- Defined in:
- lib/stripe/services/quote_service.rb
Defined Under Namespace
Classes: LineStartsAt
Instance Attribute Summary collapse
-
#line_starts_at ⇒ Object
Details of a Quote line to start the bill period from.
-
#timestamp ⇒ Object
A precise Unix timestamp.
-
#type ⇒ Object
The type of method to specify the ‘bill_from` time.
Instance Method Summary collapse
-
#initialize(line_starts_at: nil, timestamp: nil, type: nil) ⇒ BillFrom
constructor
A new instance of BillFrom.
Methods inherited from RequestParams
Constructor Details
#initialize(line_starts_at: nil, timestamp: nil, type: nil) ⇒ BillFrom
Returns a new instance of BillFrom.
2021 2022 2023 2024 2025 |
# File 'lib/stripe/services/quote_service.rb', line 2021 def initialize(line_starts_at: nil, timestamp: nil, type: nil) @line_starts_at = line_starts_at @timestamp = @type = type end |
Instance Attribute Details
#line_starts_at ⇒ Object
Details of a Quote line to start the bill period from.
2015 2016 2017 |
# File 'lib/stripe/services/quote_service.rb', line 2015 def line_starts_at @line_starts_at end |
#timestamp ⇒ Object
A precise Unix timestamp.
2017 2018 2019 |
# File 'lib/stripe/services/quote_service.rb', line 2017 def @timestamp end |
#type ⇒ Object
The type of method to specify the ‘bill_from` time.
2019 2020 2021 |
# File 'lib/stripe/services/quote_service.rb', line 2019 def type @type end |