Class: Stripe::QuoteService::UpdateParams::SubscriptionDataOverride::BillOnAcceptance::BillUntil
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteService::UpdateParams::SubscriptionDataOverride::BillOnAcceptance::BillUntil
- Defined in:
- lib/stripe/services/quote_service.rb
Defined Under Namespace
Classes: Duration, LineEndsAt
Instance Attribute Summary collapse
-
#duration ⇒ Object
Details of the duration over which to bill.
-
#line_ends_at ⇒ Object
Details of a Quote line item from which to bill until.
-
#timestamp ⇒ Object
A precise Unix timestamp.
-
#type ⇒ Object
The type of method to specify the ‘bill_until` time.
Instance Method Summary collapse
-
#initialize(duration: nil, line_ends_at: nil, timestamp: nil, type: nil) ⇒ BillUntil
constructor
A new instance of BillUntil.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, line_ends_at: nil, timestamp: nil, type: nil) ⇒ BillUntil
Returns a new instance of BillUntil.
2040 2041 2042 2043 2044 2045 |
# File 'lib/stripe/services/quote_service.rb', line 2040 def initialize(duration: nil, line_ends_at: nil, timestamp: nil, type: nil) @duration = duration @line_ends_at = line_ends_at @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Details of the duration over which to bill.
2032 2033 2034 |
# File 'lib/stripe/services/quote_service.rb', line 2032 def duration @duration end |
#line_ends_at ⇒ Object
Details of a Quote line item from which to bill until.
2034 2035 2036 |
# File 'lib/stripe/services/quote_service.rb', line 2034 def line_ends_at @line_ends_at end |
#timestamp ⇒ Object
A precise Unix timestamp.
2036 2037 2038 |
# File 'lib/stripe/services/quote_service.rb', line 2036 def @timestamp end |
#type ⇒ Object
The type of method to specify the ‘bill_until` time.
2038 2039 2040 |
# File 'lib/stripe/services/quote_service.rb', line 2038 def type @type end |