Class: Stripe::QuoteService::UpdateParams::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/quote_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, amount_percent: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



2126
2127
2128
2129
2130
# File 'lib/stripe/services/quote_service.rb', line 2126

def initialize(amount: nil, amount_percent: nil, destination: nil)
  @amount = amount
  @amount_percent = amount_percent
  @destination = destination
end

Instance Attribute Details

#amountObject

The amount that will be transferred automatically when the invoice is paid. If no amount is set, the full amount is transferred. There cannot be any line items with recurring prices when using this field.



2120
2121
2122
# File 'lib/stripe/services/quote_service.rb', line 2120

def amount
  @amount
end

#amount_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination. There must be at least 1 line item with a recurring price to use this field.



2122
2123
2124
# File 'lib/stripe/services/quote_service.rb', line 2122

def amount_percent
  @amount_percent
end

#destinationObject

ID of an existing, connected Stripe account.



2124
2125
2126
# File 'lib/stripe/services/quote_service.rb', line 2124

def destination
  @destination
end