Class: Stripe::QuoteUpdateParams::Discount

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/quote_update_params.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



64
65
66
67
68
69
# File 'lib/stripe/params/quote_update_params.rb', line 64

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



56
57
58
# File 'lib/stripe/params/quote_update_params.rb', line 56

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



58
59
60
# File 'lib/stripe/params/quote_update_params.rb', line 58

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



60
61
62
# File 'lib/stripe/params/quote_update_params.rb', line 60

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



62
63
64
# File 'lib/stripe/params/quote_update_params.rb', line 62

def promotion_code
  @promotion_code
end