Class: Stripe::QuoteUpdateParams::Line::Action::AddDiscount::Settings::ServicePeriodAnchorConfig::Custom

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom

Returns a new instance of Custom.



148
149
150
151
152
153
154
# File 'lib/stripe/params/quote_update_params.rb', line 148

def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil)
  @day_of_month = day_of_month
  @hour = hour
  @minute = minute
  @month = month
  @second = second
end

Instance Attribute Details

#day_of_monthObject

The day of the month the anchor should be. Ranges from 1 to 31.



138
139
140
# File 'lib/stripe/params/quote_update_params.rb', line 138

def day_of_month
  @day_of_month
end

#hourObject

The hour of the day the anchor should be. Ranges from 0 to 23.



140
141
142
# File 'lib/stripe/params/quote_update_params.rb', line 140

def hour
  @hour
end

#minuteObject

The minute of the hour the anchor should be. Ranges from 0 to 59.



142
143
144
# File 'lib/stripe/params/quote_update_params.rb', line 142

def minute
  @minute
end

#monthObject

The month to start full cycle periods. Ranges from 1 to 12.



144
145
146
# File 'lib/stripe/params/quote_update_params.rb', line 144

def month
  @month
end

#secondObject

The second of the minute the anchor should be. Ranges from 0 to 59.



146
147
148
# File 'lib/stripe/params/quote_update_params.rb', line 146

def second
  @second
end