Class: Stripe::QuoteUpdateParams::Line::Action::AddItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteUpdateParams::Line::Action::AddItem
- Defined in:
- lib/stripe/params/quote_update_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#discounts ⇒ Object
The discounts applied to the item.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#price ⇒ Object
The ID of the price object.
-
#quantity ⇒ Object
Quantity for this item.
-
#tax_rates ⇒ Object
The tax rates that apply to this subscription item.
-
#trial ⇒ Object
Options that configure the trial on the subscription item.
-
#trial_offer ⇒ Object
The ID of the trial offer to apply to the configuration item.
Instance Method Summary collapse
-
#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil) ⇒ AddItem
constructor
A new instance of AddItem.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil) ⇒ AddItem
Returns a new instance of AddItem.
202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/stripe/params/quote_update_params.rb', line 202 def initialize( discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil ) @discounts = discounts @metadata = @price = price @quantity = quantity @tax_rates = tax_rates @trial = trial @trial_offer = trial_offer end |
Instance Attribute Details
#discounts ⇒ Object
The discounts applied to the item. Subscription item discounts are applied before subscription discounts.
188 189 190 |
# File 'lib/stripe/params/quote_update_params.rb', line 188 def discounts @discounts end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
190 191 192 |
# File 'lib/stripe/params/quote_update_params.rb', line 190 def @metadata end |
#price ⇒ Object
The ID of the price object.
192 193 194 |
# File 'lib/stripe/params/quote_update_params.rb', line 192 def price @price end |
#quantity ⇒ Object
Quantity for this item.
194 195 196 |
# File 'lib/stripe/params/quote_update_params.rb', line 194 def quantity @quantity end |
#tax_rates ⇒ Object
The tax rates that apply to this subscription item. When set, the ‘default_tax_rates` on the subscription do not apply to this `subscription_item`.
196 197 198 |
# File 'lib/stripe/params/quote_update_params.rb', line 196 def tax_rates @tax_rates end |
#trial ⇒ Object
Options that configure the trial on the subscription item.
198 199 200 |
# File 'lib/stripe/params/quote_update_params.rb', line 198 def trial @trial end |
#trial_offer ⇒ Object
The ID of the trial offer to apply to the configuration item.
200 201 202 |
# File 'lib/stripe/params/quote_update_params.rb', line 200 def trial_offer @trial_offer end |