Class: Stripe::QuoteUpdateParams::Line::Action::AddItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_update_params.rb

Defined Under Namespace

Classes: DiscountEnd, Settings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil, settings: nil) ⇒ Discount

Returns a new instance of Discount.



260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'lib/stripe/params/quote_update_params.rb', line 260

def initialize(
  coupon: nil,
  discount: nil,
  discount_end: nil,
  promotion_code: nil,
  settings: nil
)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
  @settings = settings
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



250
251
252
# File 'lib/stripe/params/quote_update_params.rb', line 250

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



252
253
254
# File 'lib/stripe/params/quote_update_params.rb', line 252

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



254
255
256
# File 'lib/stripe/params/quote_update_params.rb', line 254

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



256
257
258
# File 'lib/stripe/params/quote_update_params.rb', line 256

def promotion_code
  @promotion_code
end

#settingsObject

Settings for discount application including service period anchoring.



258
259
260
# File 'lib/stripe/params/quote_update_params.rb', line 258

def settings
  @settings
end