Class: Stripe::QuoteUpdateParams::Line::Action::AddItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_update_params.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



180
181
182
183
184
# File 'lib/stripe/params/quote_update_params.rb', line 180

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



174
175
176
# File 'lib/stripe/params/quote_update_params.rb', line 174

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



176
177
178
# File 'lib/stripe/params/quote_update_params.rb', line 176

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



178
179
180
# File 'lib/stripe/params/quote_update_params.rb', line 178

def type
  @type
end