Class: Stripe::QuoteUpdateParams::Line::Action::AddItem::Discount::Settings::ServicePeriodAnchorConfig::Custom
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteUpdateParams::Line::Action::AddItem::Discount::Settings::ServicePeriodAnchorConfig::Custom
- Defined in:
- lib/stripe/params/quote_update_params.rb
Instance Attribute Summary collapse
-
#day_of_month ⇒ Object
The day of the month the anchor should be.
-
#hour ⇒ Object
The hour of the day the anchor should be.
-
#minute ⇒ Object
The minute of the hour the anchor should be.
-
#month ⇒ Object
The month to start full cycle periods.
-
#second ⇒ Object
The second of the minute the anchor should be.
Instance Method Summary collapse
-
#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom
constructor
A new instance of Custom.
Methods inherited from RequestParams
Constructor Details
#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom
Returns a new instance of Custom.
221 222 223 224 225 226 227 |
# File 'lib/stripe/params/quote_update_params.rb', line 221 def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) @day_of_month = day_of_month @hour = hour @minute = minute @month = month @second = second end |
Instance Attribute Details
#day_of_month ⇒ Object
The day of the month the anchor should be. Ranges from 1 to 31.
211 212 213 |
# File 'lib/stripe/params/quote_update_params.rb', line 211 def day_of_month @day_of_month end |
#hour ⇒ Object
The hour of the day the anchor should be. Ranges from 0 to 23.
213 214 215 |
# File 'lib/stripe/params/quote_update_params.rb', line 213 def hour @hour end |
#minute ⇒ Object
The minute of the hour the anchor should be. Ranges from 0 to 59.
215 216 217 |
# File 'lib/stripe/params/quote_update_params.rb', line 215 def minute @minute end |
#month ⇒ Object
The month to start full cycle periods. Ranges from 1 to 12.
217 218 219 |
# File 'lib/stripe/params/quote_update_params.rb', line 217 def month @month end |
#second ⇒ Object
The second of the minute the anchor should be. Ranges from 0 to 59.
219 220 221 |
# File 'lib/stripe/params/quote_update_params.rb', line 219 def second @second end |