Class: Stripe::QuoteUpdateParams::Line::Action::RemoveDiscount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteUpdateParams::Line::Action::RemoveDiscount
- Defined in:
- lib/stripe/params/quote_update_params.rb
Instance Attribute Summary collapse
-
#coupon ⇒ Object
The coupon code to remove from the
discountsarray. -
#discount ⇒ Object
The ID of a discount to remove from the
discountsarray. -
#promotion_code ⇒ Object
The ID of a promotion code to remove from the
discountsarray.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ RemoveDiscount
constructor
A new instance of RemoveDiscount.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ RemoveDiscount
Returns a new instance of RemoveDiscount.
256 257 258 259 260 |
# File 'lib/stripe/params/quote_update_params.rb', line 256 def initialize(coupon: nil, discount: nil, promotion_code: nil) @coupon = coupon @discount = discount @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
The coupon code to remove from the discounts array.
250 251 252 |
# File 'lib/stripe/params/quote_update_params.rb', line 250 def coupon @coupon end |
#discount ⇒ Object
The ID of a discount to remove from the discounts array.
252 253 254 |
# File 'lib/stripe/params/quote_update_params.rb', line 252 def discount @discount end |
#promotion_code ⇒ Object
The ID of a promotion code to remove from the discounts array.
254 255 256 |
# File 'lib/stripe/params/quote_update_params.rb', line 254 def promotion_code @promotion_code end |