Class: Stripe::QuoteUpdateParams::Line::Action::SetDiscount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_update_params.rb

Defined Under Namespace

Classes: Settings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil, settings: nil) ⇒ SetDiscount

Returns a new instance of SetDiscount.



423
424
425
426
427
428
# File 'lib/stripe/params/quote_update_params.rb', line 423

def initialize(coupon: nil, discount: nil, promotion_code: nil, settings: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
  @settings = settings
end

Instance Attribute Details

#couponObject

The coupon code to replace the discounts array with.



415
416
417
# File 'lib/stripe/params/quote_update_params.rb', line 415

def coupon
  @coupon
end

#discountObject

An ID of an existing discount to replace the discounts array with.



417
418
419
# File 'lib/stripe/params/quote_update_params.rb', line 417

def discount
  @discount
end

#promotion_codeObject

An ID of an existing promotion code to replace the discounts array with.



419
420
421
# File 'lib/stripe/params/quote_update_params.rb', line 419

def promotion_code
  @promotion_code
end

#settingsObject

Settings for discount application including service period anchoring.



421
422
423
# File 'lib/stripe/params/quote_update_params.rb', line 421

def settings
  @settings
end