Class: Stripe::QuoteUpdateParams::Line::Action::SetDiscount::Settings::ServicePeriodAnchorConfig::Custom
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteUpdateParams::Line::Action::SetDiscount::Settings::ServicePeriodAnchorConfig::Custom
- Defined in:
- lib/stripe/params/quote_update_params.rb
Instance Attribute Summary collapse
-
#day_of_month ⇒ Object
The day of the month the anchor should be.
-
#hour ⇒ Object
The hour of the day the anchor should be.
-
#minute ⇒ Object
The minute of the hour the anchor should be.
-
#month ⇒ Object
The month to start full cycle periods.
-
#second ⇒ Object
The second of the minute the anchor should be.
Instance Method Summary collapse
-
#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom
constructor
A new instance of Custom.
Methods inherited from RequestParams
Constructor Details
#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom
Returns a new instance of Custom.
359 360 361 362 363 364 365 |
# File 'lib/stripe/params/quote_update_params.rb', line 359 def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) @day_of_month = day_of_month @hour = hour @minute = minute @month = month @second = second end |
Instance Attribute Details
#day_of_month ⇒ Object
The day of the month the anchor should be. Ranges from 1 to 31.
349 350 351 |
# File 'lib/stripe/params/quote_update_params.rb', line 349 def day_of_month @day_of_month end |
#hour ⇒ Object
The hour of the day the anchor should be. Ranges from 0 to 23.
351 352 353 |
# File 'lib/stripe/params/quote_update_params.rb', line 351 def hour @hour end |
#minute ⇒ Object
The minute of the hour the anchor should be. Ranges from 0 to 59.
353 354 355 |
# File 'lib/stripe/params/quote_update_params.rb', line 353 def minute @minute end |
#month ⇒ Object
The month to start full cycle periods. Ranges from 1 to 12.
355 356 357 |
# File 'lib/stripe/params/quote_update_params.rb', line 355 def month @month end |
#second ⇒ Object
The second of the minute the anchor should be. Ranges from 0 to 59.
357 358 359 |
# File 'lib/stripe/params/quote_update_params.rb', line 357 def second @second end |