Class: Stripe::QuoteUpdateParams::Line::Action::SetItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_update_params.rb

Defined Under Namespace

Classes: Discount, Trial

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil) ⇒ SetItem

Returns a new instance of SetItem.



553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
# File 'lib/stripe/params/quote_update_params.rb', line 553

def initialize(
  discounts: nil,
  metadata: nil,
  price: nil,
  quantity: nil,
  tax_rates: nil,
  trial: nil,
  trial_offer: nil
)
  @discounts = discounts
  @metadata = 
  @price = price
  @quantity = quantity
  @tax_rates = tax_rates
  @trial = trial
  @trial_offer = trial_offer
end

Instance Attribute Details

#discountsObject

If an item with the price already exists, passing this will override the discounts array on the subscription item that matches that price. Otherwise, the items array is cleared and a single new item is added with the supplied discounts.



539
540
541
# File 'lib/stripe/params/quote_update_params.rb', line 539

def discounts
  @discounts
end

#metadataObject

If an item with the price already exists, passing this will override the metadata on the subscription item that matches that price. Otherwise, the items array is cleared and a single new item is added with the supplied metadata.



541
542
543
# File 'lib/stripe/params/quote_update_params.rb', line 541

def 
  @metadata
end

#priceObject

The ID of the price object.



543
544
545
# File 'lib/stripe/params/quote_update_params.rb', line 543

def price
  @price
end

#quantityObject

If an item with the price already exists, passing this will override the quantity on the subscription item that matches that price. Otherwise, the items array is cleared and a single new item is added with the supplied quantity.



545
546
547
# File 'lib/stripe/params/quote_update_params.rb', line 545

def quantity
  @quantity
end

#tax_ratesObject

If an item with the price already exists, passing this will override the tax_rates array on the subscription item that matches that price. Otherwise, the items array is cleared and a single new item is added with the supplied tax_rates.



547
548
549
# File 'lib/stripe/params/quote_update_params.rb', line 547

def tax_rates
  @tax_rates
end

#trialObject

If an item with the price already exists, passing this will override the trial configuration on the subscription item that matches that price. Otherwise, the items array is cleared and a single new item is added with the supplied trial.



549
550
551
# File 'lib/stripe/params/quote_update_params.rb', line 549

def trial
  @trial
end

#trial_offerObject

The ID of the trial offer to apply to the configuration item.



551
552
553
# File 'lib/stripe/params/quote_update_params.rb', line 551

def trial_offer
  @trial_offer
end