Class: Stripe::QuoteUpdateParams::Line::Action::SetItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_update_params.rb

Defined Under Namespace

Classes: DiscountEnd, Settings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil, settings: nil) ⇒ Discount

Returns a new instance of Discount.



485
486
487
488
489
490
491
492
493
494
495
496
497
# File 'lib/stripe/params/quote_update_params.rb', line 485

def initialize(
  coupon: nil,
  discount: nil,
  discount_end: nil,
  promotion_code: nil,
  settings: nil
)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
  @settings = settings
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



475
476
477
# File 'lib/stripe/params/quote_update_params.rb', line 475

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



477
478
479
# File 'lib/stripe/params/quote_update_params.rb', line 477

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



479
480
481
# File 'lib/stripe/params/quote_update_params.rb', line 479

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



481
482
483
# File 'lib/stripe/params/quote_update_params.rb', line 481

def promotion_code
  @promotion_code
end

#settingsObject

Settings for discount application including service period anchoring.



483
484
485
# File 'lib/stripe/params/quote_update_params.rb', line 483

def settings
  @settings
end