Class: Stripe::QuoteUpdateParams::Line::Action::SetItem::Discount::Settings::ServicePeriodAnchorConfig::Custom
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteUpdateParams::Line::Action::SetItem::Discount::Settings::ServicePeriodAnchorConfig::Custom
- Defined in:
- lib/stripe/params/quote_update_params.rb
Instance Attribute Summary collapse
-
#day_of_month ⇒ Object
The day of the month the anchor should be.
-
#hour ⇒ Object
The hour of the day the anchor should be.
-
#minute ⇒ Object
The minute of the hour the anchor should be.
-
#month ⇒ Object
The month to start full cycle periods.
-
#second ⇒ Object
The second of the minute the anchor should be.
Instance Method Summary collapse
-
#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom
constructor
A new instance of Custom.
Methods inherited from RequestParams
Constructor Details
#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom
Returns a new instance of Custom.
446 447 448 449 450 451 452 |
# File 'lib/stripe/params/quote_update_params.rb', line 446 def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) @day_of_month = day_of_month @hour = hour @minute = minute @month = month @second = second end |
Instance Attribute Details
#day_of_month ⇒ Object
The day of the month the anchor should be. Ranges from 1 to 31.
436 437 438 |
# File 'lib/stripe/params/quote_update_params.rb', line 436 def day_of_month @day_of_month end |
#hour ⇒ Object
The hour of the day the anchor should be. Ranges from 0 to 23.
438 439 440 |
# File 'lib/stripe/params/quote_update_params.rb', line 438 def hour @hour end |
#minute ⇒ Object
The minute of the hour the anchor should be. Ranges from 0 to 59.
440 441 442 |
# File 'lib/stripe/params/quote_update_params.rb', line 440 def minute @minute end |
#month ⇒ Object
The month to start full cycle periods. Ranges from 1 to 12.
442 443 444 |
# File 'lib/stripe/params/quote_update_params.rb', line 442 def month @month end |
#second ⇒ Object
The second of the minute the anchor should be. Ranges from 0 to 59.
444 445 446 |
# File 'lib/stripe/params/quote_update_params.rb', line 444 def second @second end |