Class: Stripe::QuoteUpdateParams::Line::Action::SetItem::Trial
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteUpdateParams::Line::Action::SetItem::Trial
- Defined in:
- lib/stripe/params/quote_update_params.rb
Instance Attribute Summary collapse
-
#converts_to ⇒ Object
List of price IDs which, if present on the subscription following a paid trial, constitute opting-in to the paid trial.
-
#type ⇒ Object
Determines the type of trial for this item.
Instance Method Summary collapse
-
#initialize(converts_to: nil, type: nil) ⇒ Trial
constructor
A new instance of Trial.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(converts_to: nil, type: nil) ⇒ Trial
Returns a new instance of Trial.
310 311 312 313 |
# File 'lib/stripe/params/quote_update_params.rb', line 310 def initialize(converts_to: nil, type: nil) @converts_to = converts_to @type = type end |
Instance Attribute Details
#converts_to ⇒ Object
List of price IDs which, if present on the subscription following a paid trial, constitute opting-in to the paid trial. Currently only supports at most 1 price ID.
306 307 308 |
# File 'lib/stripe/params/quote_update_params.rb', line 306 def converts_to @converts_to end |
#type ⇒ Object
Determines the type of trial for this item.
308 309 310 |
# File 'lib/stripe/params/quote_update_params.rb', line 308 def type @type end |