Class: Stripe::QuoteUpdateParams::Line::CancelSubscriptionSchedule

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(cancel_at: nil, invoice_now: nil, prorate: nil) ⇒ CancelSubscriptionSchedule

Returns a new instance of CancelSubscriptionSchedule.



417
418
419
420
421
# File 'lib/stripe/params/quote_update_params.rb', line 417

def initialize(cancel_at: nil, invoice_now: nil, prorate: nil)
  @cancel_at = cancel_at
  @invoice_now = invoice_now
  @prorate = prorate
end

Instance Attribute Details

#cancel_atObject

Timestamp helper to cancel the underlying schedule on the accompanying line’s start date. Must be set to ‘line_starts_at`.



411
412
413
# File 'lib/stripe/params/quote_update_params.rb', line 411

def cancel_at
  @cancel_at
end

#invoice_nowObject

If the subscription schedule is ‘active`, indicates if a final invoice will be generated that contains any un-invoiced metered usage and new/pending proration invoice items. Boolean that defaults to `true`.



413
414
415
# File 'lib/stripe/params/quote_update_params.rb', line 413

def invoice_now
  @invoice_now
end

#prorateObject

If the subscription schedule is ‘active`, indicates if the cancellation should be prorated. Boolean that defaults to `true`.



415
416
417
# File 'lib/stripe/params/quote_update_params.rb', line 415

def prorate
  @prorate
end