Class: Stripe::QuoteUpdateParams::Line::EndsAt
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteUpdateParams::Line::EndsAt
- Defined in:
- lib/stripe/params/quote_update_params.rb
Defined Under Namespace
Classes: DiscountEnd, Duration
Instance Attribute Summary collapse
-
#discount_end ⇒ Object
Use the
endtime of a given discount. -
#duration ⇒ Object
Time span for the quote line starting from the
starts_atdate. -
#timestamp ⇒ Object
A precise Unix timestamp.
-
#type ⇒ Object
Select a way to pass in
ends_at.
Instance Method Summary collapse
-
#initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ EndsAt
constructor
A new instance of EndsAt.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ EndsAt
Returns a new instance of EndsAt.
481 482 483 484 485 486 |
# File 'lib/stripe/params/quote_update_params.rb', line 481 def initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) @discount_end = discount_end @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#discount_end ⇒ Object
Use the end time of a given discount.
473 474 475 |
# File 'lib/stripe/params/quote_update_params.rb', line 473 def discount_end @discount_end end |
#duration ⇒ Object
Time span for the quote line starting from the starts_at date.
475 476 477 |
# File 'lib/stripe/params/quote_update_params.rb', line 475 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp.
477 478 479 |
# File 'lib/stripe/params/quote_update_params.rb', line 477 def @timestamp end |
#type ⇒ Object
Select a way to pass in ends_at.
479 480 481 |
# File 'lib/stripe/params/quote_update_params.rb', line 479 def type @type end |