Class: Stripe::QuoteUpdateParams::Line::StartsAt::LineEndsAt

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(id: nil, index: nil) ⇒ LineEndsAt

Returns a new instance of LineEndsAt.



498
499
500
501
# File 'lib/stripe/params/quote_update_params.rb', line 498

def initialize(id: nil, index: nil)
  @id = id
  @index = index
end

Instance Attribute Details

#idObject

The ID of a quote line.



494
495
496
# File 'lib/stripe/params/quote_update_params.rb', line 494

def id
  @id
end

#indexObject

The position of the previous quote line in the ‘lines` array after which this line should begin. Indexes start from 0 and must be less than the index of the current line in the array.



496
497
498
# File 'lib/stripe/params/quote_update_params.rb', line 496

def index
  @index
end