Class: Stripe::QuoteUpdateParams::Line::TrialSettings::EndBehavior
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteUpdateParams::Line::TrialSettings::EndBehavior
- Defined in:
- lib/stripe/params/quote_update_params.rb
Instance Attribute Summary collapse
-
#prorate_up_front ⇒ Object
Configure how an opt-in following a paid trial is billed when using ‘billing_behavior: prorate_up_front`.
Instance Method Summary collapse
-
#initialize(prorate_up_front: nil) ⇒ EndBehavior
constructor
A new instance of EndBehavior.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(prorate_up_front: nil) ⇒ EndBehavior
Returns a new instance of EndBehavior.
525 526 527 |
# File 'lib/stripe/params/quote_update_params.rb', line 525 def initialize(prorate_up_front: nil) @prorate_up_front = prorate_up_front end |
Instance Attribute Details
#prorate_up_front ⇒ Object
Configure how an opt-in following a paid trial is billed when using ‘billing_behavior: prorate_up_front`.
523 524 525 |
# File 'lib/stripe/params/quote_update_params.rb', line 523 def prorate_up_front @prorate_up_front end |