Class: Stripe::QuoteUpdateParams::LineItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_update_params.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



849
850
851
852
853
854
# File 'lib/stripe/params/quote_update_params.rb', line 849

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



841
842
843
# File 'lib/stripe/params/quote_update_params.rb', line 841

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



843
844
845
# File 'lib/stripe/params/quote_update_params.rb', line 843

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



845
846
847
# File 'lib/stripe/params/quote_update_params.rb', line 845

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



847
848
849
# File 'lib/stripe/params/quote_update_params.rb', line 847

def promotion_code
  @promotion_code
end