Class: Stripe::QuoteUpdateParams::LineItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_update_params.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



607
608
609
610
611
# File 'lib/stripe/params/quote_update_params.rb', line 607

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



601
602
603
# File 'lib/stripe/params/quote_update_params.rb', line 601

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



603
604
605
# File 'lib/stripe/params/quote_update_params.rb', line 603

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



605
606
607
# File 'lib/stripe/params/quote_update_params.rb', line 605

def type
  @type
end