Class: Stripe::QuoteUpdateParams::LineItem::Discount::DiscountEnd::Duration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(interval: nil, interval_count: nil) ⇒ Duration

Returns a new instance of Duration.



822
823
824
825
# File 'lib/stripe/params/quote_update_params.rb', line 822

def initialize(interval: nil, interval_count: nil)
  @interval = interval
  @interval_count = interval_count
end

Instance Attribute Details

#intervalObject

Specifies a type of interval unit. Either day, week, month or year.



818
819
820
# File 'lib/stripe/params/quote_update_params.rb', line 818

def interval
  @interval
end

#interval_countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



820
821
822
# File 'lib/stripe/params/quote_update_params.rb', line 820

def interval_count
  @interval_count
end