Class: Stripe::QuoteUpdateParams::SubscriptionData::BillOnAcceptance::BillFrom
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteUpdateParams::SubscriptionData::BillOnAcceptance::BillFrom
- Defined in:
- lib/stripe/params/quote_update_params.rb
Defined Under Namespace
Classes: LineStartsAt
Instance Attribute Summary collapse
-
#line_starts_at ⇒ Object
Details of a Quote line to start the bill period from.
-
#timestamp ⇒ Object
A precise Unix timestamp.
-
#type ⇒ Object
The type of method to specify the ‘bill_from` time.
Instance Method Summary collapse
-
#initialize(line_starts_at: nil, timestamp: nil, type: nil) ⇒ BillFrom
constructor
A new instance of BillFrom.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(line_starts_at: nil, timestamp: nil, type: nil) ⇒ BillFrom
Returns a new instance of BillFrom.
732 733 734 735 736 |
# File 'lib/stripe/params/quote_update_params.rb', line 732 def initialize(line_starts_at: nil, timestamp: nil, type: nil) @line_starts_at = line_starts_at @timestamp = @type = type end |
Instance Attribute Details
#line_starts_at ⇒ Object
Details of a Quote line to start the bill period from.
726 727 728 |
# File 'lib/stripe/params/quote_update_params.rb', line 726 def line_starts_at @line_starts_at end |
#timestamp ⇒ Object
A precise Unix timestamp.
728 729 730 |
# File 'lib/stripe/params/quote_update_params.rb', line 728 def @timestamp end |
#type ⇒ Object
The type of method to specify the ‘bill_from` time.
730 731 732 |
# File 'lib/stripe/params/quote_update_params.rb', line 730 def type @type end |