Class: Stripe::QuoteUpdateParams::SubscriptionData::BillOnAcceptance::BillUntil
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteUpdateParams::SubscriptionData::BillOnAcceptance::BillUntil
- Defined in:
- lib/stripe/params/quote_update_params.rb
Defined Under Namespace
Classes: Duration, LineEndsAt
Instance Attribute Summary collapse
-
#duration ⇒ Object
Details of the duration over which to bill.
-
#line_ends_at ⇒ Object
Details of a Quote line item from which to bill until.
-
#timestamp ⇒ Object
A precise Unix timestamp.
-
#type ⇒ Object
The type of method to specify the
bill_untiltime.
Instance Method Summary collapse
-
#initialize(duration: nil, line_ends_at: nil, timestamp: nil, type: nil) ⇒ BillUntil
constructor
A new instance of BillUntil.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(duration: nil, line_ends_at: nil, timestamp: nil, type: nil) ⇒ BillUntil
Returns a new instance of BillUntil.
799 800 801 802 803 804 |
# File 'lib/stripe/params/quote_update_params.rb', line 799 def initialize(duration: nil, line_ends_at: nil, timestamp: nil, type: nil) @duration = duration @line_ends_at = line_ends_at @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Details of the duration over which to bill.
791 792 793 |
# File 'lib/stripe/params/quote_update_params.rb', line 791 def duration @duration end |
#line_ends_at ⇒ Object
Details of a Quote line item from which to bill until.
793 794 795 |
# File 'lib/stripe/params/quote_update_params.rb', line 793 def line_ends_at @line_ends_at end |
#timestamp ⇒ Object
A precise Unix timestamp.
795 796 797 |
# File 'lib/stripe/params/quote_update_params.rb', line 795 def @timestamp end |
#type ⇒ Object
The type of method to specify the bill_until time.
797 798 799 |
# File 'lib/stripe/params/quote_update_params.rb', line 797 def type @type end |