Class: Stripe::QuoteUpdateParams::SubscriptionData::BillOnAcceptance::BillUntil::Duration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(interval: nil, interval_count: nil) ⇒ Duration

Returns a new instance of Duration.



746
747
748
749
# File 'lib/stripe/params/quote_update_params.rb', line 746

def initialize(interval: nil, interval_count: nil)
  @interval = interval
  @interval_count = interval_count
end

Instance Attribute Details

#intervalObject

Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.



742
743
744
# File 'lib/stripe/params/quote_update_params.rb', line 742

def interval
  @interval
end

#interval_countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



744
745
746
# File 'lib/stripe/params/quote_update_params.rb', line 744

def interval_count
  @interval_count
end