Class: Stripe::QuoteUpdateParams::SubscriptionData::BillOnAcceptance::BillUntil::LineEndsAt

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(id: nil, index: nil) ⇒ LineEndsAt

Returns a new instance of LineEndsAt.



758
759
760
761
# File 'lib/stripe/params/quote_update_params.rb', line 758

def initialize(id: nil, index: nil)
  @id = id
  @index = index
end

Instance Attribute Details

#idObject

The ID of a quote line.



754
755
756
# File 'lib/stripe/params/quote_update_params.rb', line 754

def id
  @id
end

#indexObject

The position of the previous quote line in the ‘lines` array after which this line should begin. Indexes start from 0 and must be less than the index of the current line in the array.



756
757
758
# File 'lib/stripe/params/quote_update_params.rb', line 756

def index
  @index
end