Class: Stripe::QuoteUpdateParams::SubscriptionData::BillingSchedule::AppliesTo
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteUpdateParams::SubscriptionData::BillingSchedule::AppliesTo
- Defined in:
- lib/stripe/params/quote_update_params.rb
Instance Attribute Summary collapse
-
#price ⇒ Object
The ID of the price object.
-
#type ⇒ Object
Controls which subscription items the billing schedule applies to.
Instance Method Summary collapse
-
#initialize(price: nil, type: nil) ⇒ AppliesTo
constructor
A new instance of AppliesTo.
Methods inherited from RequestParams
Constructor Details
#initialize(price: nil, type: nil) ⇒ AppliesTo
Returns a new instance of AppliesTo.
987 988 989 990 |
# File 'lib/stripe/params/quote_update_params.rb', line 987 def initialize(price: nil, type: nil) @price = price @type = type end |
Instance Attribute Details
#price ⇒ Object
The ID of the price object.
983 984 985 |
# File 'lib/stripe/params/quote_update_params.rb', line 983 def price @price end |
#type ⇒ Object
Controls which subscription items the billing schedule applies to.
985 986 987 |
# File 'lib/stripe/params/quote_update_params.rb', line 985 def type @type end |