Class: Stripe::QuoteUpdateParams::SubscriptionData::BillingSchedule::BillFrom
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteUpdateParams::SubscriptionData::BillingSchedule::BillFrom
- Defined in:
- lib/stripe/params/quote_update_params.rb
Defined Under Namespace
Classes: LineStartsAt
Instance Attribute Summary collapse
-
#line_starts_at ⇒ Object
Details of a Quote line to start the bill period from.
-
#timestamp ⇒ Object
A precise Unix timestamp.
-
#type ⇒ Object
The type of method to specify the ‘bill_from` time.
Instance Method Summary collapse
-
#initialize(line_starts_at: nil, timestamp: nil, type: nil) ⇒ BillFrom
constructor
A new instance of BillFrom.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(line_starts_at: nil, timestamp: nil, type: nil) ⇒ BillFrom
Returns a new instance of BillFrom.
1022 1023 1024 1025 1026 |
# File 'lib/stripe/params/quote_update_params.rb', line 1022 def initialize(line_starts_at: nil, timestamp: nil, type: nil) @line_starts_at = line_starts_at @timestamp = @type = type end |
Instance Attribute Details
#line_starts_at ⇒ Object
Details of a Quote line to start the bill period from.
1016 1017 1018 |
# File 'lib/stripe/params/quote_update_params.rb', line 1016 def line_starts_at @line_starts_at end |
#timestamp ⇒ Object
A precise Unix timestamp.
1018 1019 1020 |
# File 'lib/stripe/params/quote_update_params.rb', line 1018 def @timestamp end |
#type ⇒ Object
The type of method to specify the ‘bill_from` time.
1020 1021 1022 |
# File 'lib/stripe/params/quote_update_params.rb', line 1020 def type @type end |