Class: Stripe::QuoteUpdateParams::SubscriptionData::BillingSchedule::BillUntil
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteUpdateParams::SubscriptionData::BillingSchedule::BillUntil
- Defined in:
- lib/stripe/params/quote_update_params.rb
Defined Under Namespace
Classes: Duration, LineEndsAt
Instance Attribute Summary collapse
-
#duration ⇒ Object
Details of the duration over which to bill.
-
#line_ends_at ⇒ Object
Details of a Quote line item from which to bill until.
-
#timestamp ⇒ Object
A precise Unix timestamp.
-
#type ⇒ Object
The type of method to specify the ‘bill_until` time.
Instance Method Summary collapse
-
#initialize(duration: nil, line_ends_at: nil, timestamp: nil, type: nil) ⇒ BillUntil
constructor
A new instance of BillUntil.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, line_ends_at: nil, timestamp: nil, type: nil) ⇒ BillUntil
Returns a new instance of BillUntil.
844 845 846 847 848 849 |
# File 'lib/stripe/params/quote_update_params.rb', line 844 def initialize(duration: nil, line_ends_at: nil, timestamp: nil, type: nil) @duration = duration @line_ends_at = line_ends_at @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Details of the duration over which to bill.
836 837 838 |
# File 'lib/stripe/params/quote_update_params.rb', line 836 def duration @duration end |
#line_ends_at ⇒ Object
Details of a Quote line item from which to bill until.
838 839 840 |
# File 'lib/stripe/params/quote_update_params.rb', line 838 def line_ends_at @line_ends_at end |
#timestamp ⇒ Object
A precise Unix timestamp.
840 841 842 |
# File 'lib/stripe/params/quote_update_params.rb', line 840 def @timestamp end |
#type ⇒ Object
The type of method to specify the ‘bill_until` time.
842 843 844 |
# File 'lib/stripe/params/quote_update_params.rb', line 842 def type @type end |