Class: Stripe::QuoteUpdateParams::SubscriptionData::BillingSchedule::BillUntil::Duration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(interval: nil, interval_count: nil) ⇒ Duration

Returns a new instance of Duration.



1026
1027
1028
1029
# File 'lib/stripe/params/quote_update_params.rb', line 1026

def initialize(interval: nil, interval_count: nil)
  @interval = interval
  @interval_count = interval_count
end

Instance Attribute Details

#intervalObject

Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.



1022
1023
1024
# File 'lib/stripe/params/quote_update_params.rb', line 1022

def interval
  @interval
end

#interval_countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



1024
1025
1026
# File 'lib/stripe/params/quote_update_params.rb', line 1024

def interval_count
  @interval_count
end