Class: Stripe::QuoteUpdateParams::SubscriptionDataOverride::AppliesTo

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(new_reference: nil, subscription_schedule: nil, type: nil) ⇒ AppliesTo

Returns a new instance of AppliesTo.



1190
1191
1192
1193
1194
# File 'lib/stripe/params/quote_update_params.rb', line 1190

def initialize(new_reference: nil, subscription_schedule: nil, type: nil)
  @new_reference = new_reference
  @subscription_schedule = subscription_schedule
  @type = type
end

Instance Attribute Details

#new_referenceObject

A custom string that identifies a new subscription schedule being created upon quote acceptance. All quote lines with the same new_reference field will be applied to the creation of a new subscription schedule.



1184
1185
1186
# File 'lib/stripe/params/quote_update_params.rb', line 1184

def new_reference
  @new_reference
end

#subscription_scheduleObject

The ID of the schedule the line applies to.



1186
1187
1188
# File 'lib/stripe/params/quote_update_params.rb', line 1186

def subscription_schedule
  @subscription_schedule
end

#typeObject

Describes whether the quote line is affecting a new schedule or an existing schedule.



1188
1189
1190
# File 'lib/stripe/params/quote_update_params.rb', line 1188

def type
  @type
end