Class: Stripe::QuoteUpdateParams::SubscriptionDataOverride::BillOnAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_update_params.rb

Defined Under Namespace

Classes: BillFrom, BillUntil

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(bill_from: nil, bill_until: nil) ⇒ BillOnAcceptance

Returns a new instance of BillOnAcceptance.



1242
1243
1244
1245
# File 'lib/stripe/params/quote_update_params.rb', line 1242

def initialize(bill_from: nil, bill_until: nil)
  @bill_from = bill_from
  @bill_until = bill_until
end

Instance Attribute Details

#bill_fromObject

The start of the period to bill from when the Quote is accepted.



1238
1239
1240
# File 'lib/stripe/params/quote_update_params.rb', line 1238

def bill_from
  @bill_from
end

#bill_untilObject

The end of the period to bill until when the Quote is accepted.



1240
1241
1242
# File 'lib/stripe/params/quote_update_params.rb', line 1240

def bill_until
  @bill_until
end