Class: Stripe::QuoteUpdateParams::SubscriptionDataOverride::BillOnAcceptance::BillFrom::LineStartsAt
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteUpdateParams::SubscriptionDataOverride::BillOnAcceptance::BillFrom::LineStartsAt
- Defined in:
- lib/stripe/params/quote_update_params.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
The ID of a quote line.
-
#index ⇒ Object
The position of the previous quote line in the
linesarray after which this line should begin.
Instance Method Summary collapse
-
#initialize(id: nil, index: nil) ⇒ LineStartsAt
constructor
A new instance of LineStartsAt.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(id: nil, index: nil) ⇒ LineStartsAt
Returns a new instance of LineStartsAt.
901 902 903 904 |
# File 'lib/stripe/params/quote_update_params.rb', line 901 def initialize(id: nil, index: nil) @id = id @index = index end |
Instance Attribute Details
#id ⇒ Object
The ID of a quote line.
897 898 899 |
# File 'lib/stripe/params/quote_update_params.rb', line 897 def id @id end |
#index ⇒ Object
The position of the previous quote line in the lines array after which this line should begin. Indexes start from 0 and must be less than the index of the current line in the array.
899 900 901 |
# File 'lib/stripe/params/quote_update_params.rb', line 899 def index @index end |