Class: Stripe::QuoteUpdateParams::SubscriptionDataOverride::BillOnAcceptance::BillUntil
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteUpdateParams::SubscriptionDataOverride::BillOnAcceptance::BillUntil
- Defined in:
- lib/stripe/params/quote_update_params.rb
Defined Under Namespace
Classes: Duration, LineEndsAt
Instance Attribute Summary collapse
-
#duration ⇒ Object
Details of the duration over which to bill.
-
#line_ends_at ⇒ Object
Details of a Quote line item from which to bill until.
-
#timestamp ⇒ Object
A precise Unix timestamp.
-
#type ⇒ Object
The type of method to specify the ‘bill_until` time.
Instance Method Summary collapse
-
#initialize(duration: nil, line_ends_at: nil, timestamp: nil, type: nil) ⇒ BillUntil
constructor
A new instance of BillUntil.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(duration: nil, line_ends_at: nil, timestamp: nil, type: nil) ⇒ BillUntil
Returns a new instance of BillUntil.
926 927 928 929 930 931 |
# File 'lib/stripe/params/quote_update_params.rb', line 926 def initialize(duration: nil, line_ends_at: nil, timestamp: nil, type: nil) @duration = duration @line_ends_at = line_ends_at @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Details of the duration over which to bill.
918 919 920 |
# File 'lib/stripe/params/quote_update_params.rb', line 918 def duration @duration end |
#line_ends_at ⇒ Object
Details of a Quote line item from which to bill until.
920 921 922 |
# File 'lib/stripe/params/quote_update_params.rb', line 920 def line_ends_at @line_ends_at end |
#timestamp ⇒ Object
A precise Unix timestamp.
922 923 924 |
# File 'lib/stripe/params/quote_update_params.rb', line 922 def @timestamp end |
#type ⇒ Object
The type of method to specify the ‘bill_until` time.
924 925 926 |
# File 'lib/stripe/params/quote_update_params.rb', line 924 def type @type end |