Class: Stripe::QuoteUpdateParams::SubscriptionDataOverride::BillingSchedule::AppliesTo
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteUpdateParams::SubscriptionDataOverride::BillingSchedule::AppliesTo
- Defined in:
- lib/stripe/params/quote_update_params.rb
Instance Attribute Summary collapse
-
#price ⇒ Object
The ID of the price object.
-
#type ⇒ Object
Controls which subscription items the billing schedule applies to.
Instance Method Summary collapse
-
#initialize(price: nil, type: nil) ⇒ AppliesTo
constructor
A new instance of AppliesTo.
Methods inherited from RequestParams
Constructor Details
#initialize(price: nil, type: nil) ⇒ AppliesTo
Returns a new instance of AppliesTo.
1049 1050 1051 1052 |
# File 'lib/stripe/params/quote_update_params.rb', line 1049 def initialize(price: nil, type: nil) @price = price @type = type end |
Instance Attribute Details
#price ⇒ Object
The ID of the price object.
1045 1046 1047 |
# File 'lib/stripe/params/quote_update_params.rb', line 1045 def price @price end |
#type ⇒ Object
Controls which subscription items the billing schedule applies to.
1047 1048 1049 |
# File 'lib/stripe/params/quote_update_params.rb', line 1047 def type @type end |