Class: Stripe::QuoteUpdateParams::SubscriptionDataOverride::BillingSchedule::BillFrom
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteUpdateParams::SubscriptionDataOverride::BillingSchedule::BillFrom
- Defined in:
- lib/stripe/params/quote_update_params.rb
Defined Under Namespace
Classes: LineStartsAt
Instance Attribute Summary collapse
-
#line_starts_at ⇒ Object
Details of a Quote line to start the bill period from.
-
#timestamp ⇒ Object
A precise Unix timestamp.
-
#type ⇒ Object
The type of method to specify the ‘bill_from` time.
Instance Method Summary collapse
-
#initialize(line_starts_at: nil, timestamp: nil, type: nil) ⇒ BillFrom
constructor
A new instance of BillFrom.
Methods inherited from RequestParams
Constructor Details
#initialize(line_starts_at: nil, timestamp: nil, type: nil) ⇒ BillFrom
Returns a new instance of BillFrom.
1062 1063 1064 1065 1066 |
# File 'lib/stripe/params/quote_update_params.rb', line 1062 def initialize(line_starts_at: nil, timestamp: nil, type: nil) @line_starts_at = line_starts_at @timestamp = @type = type end |
Instance Attribute Details
#line_starts_at ⇒ Object
Details of a Quote line to start the bill period from.
1056 1057 1058 |
# File 'lib/stripe/params/quote_update_params.rb', line 1056 def line_starts_at @line_starts_at end |
#timestamp ⇒ Object
A precise Unix timestamp.
1058 1059 1060 |
# File 'lib/stripe/params/quote_update_params.rb', line 1058 def @timestamp end |
#type ⇒ Object
The type of method to specify the ‘bill_from` time.
1060 1061 1062 |
# File 'lib/stripe/params/quote_update_params.rb', line 1060 def type @type end |