Class: Stripe::QuoteUpdateParams::SubscriptionDataOverride::BillingSchedule::BillFrom::LineStartsAt

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(id: nil, index: nil) ⇒ LineStartsAt

Returns a new instance of LineStartsAt.



1258
1259
1260
1261
# File 'lib/stripe/params/quote_update_params.rb', line 1258

def initialize(id: nil, index: nil)
  @id = id
  @index = index
end

Instance Attribute Details

#idObject

The ID of a quote line.



1254
1255
1256
# File 'lib/stripe/params/quote_update_params.rb', line 1254

def id
  @id
end

#indexObject

The position of the previous quote line in the ‘lines` array after which this line should begin. Indexes start from 0 and must be less than the index of the current line in the array.



1256
1257
1258
# File 'lib/stripe/params/quote_update_params.rb', line 1256

def index
  @index
end