Class: Stripe::QuoteUpdateParams::SubscriptionDataOverride::BillingSchedule::BillUntil
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteUpdateParams::SubscriptionDataOverride::BillingSchedule::BillUntil
- Defined in:
- lib/stripe/params/quote_update_params.rb
Defined Under Namespace
Classes: Duration, LineEndsAt
Instance Attribute Summary collapse
-
#duration ⇒ Object
Details of the duration over which to bill.
-
#line_ends_at ⇒ Object
Details of a Quote line item from which to bill until.
-
#timestamp ⇒ Object
A precise Unix timestamp.
-
#type ⇒ Object
The type of method to specify the ‘bill_until` time.
Instance Method Summary collapse
-
#initialize(duration: nil, line_ends_at: nil, timestamp: nil, type: nil) ⇒ BillUntil
constructor
A new instance of BillUntil.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, line_ends_at: nil, timestamp: nil, type: nil) ⇒ BillUntil
Returns a new instance of BillUntil.
1310 1311 1312 1313 1314 1315 |
# File 'lib/stripe/params/quote_update_params.rb', line 1310 def initialize(duration: nil, line_ends_at: nil, timestamp: nil, type: nil) @duration = duration @line_ends_at = line_ends_at @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Details of the duration over which to bill.
1302 1303 1304 |
# File 'lib/stripe/params/quote_update_params.rb', line 1302 def duration @duration end |
#line_ends_at ⇒ Object
Details of a Quote line item from which to bill until.
1304 1305 1306 |
# File 'lib/stripe/params/quote_update_params.rb', line 1304 def line_ends_at @line_ends_at end |
#timestamp ⇒ Object
A precise Unix timestamp.
1306 1307 1308 |
# File 'lib/stripe/params/quote_update_params.rb', line 1306 def @timestamp end |
#type ⇒ Object
The type of method to specify the ‘bill_until` time.
1308 1309 1310 |
# File 'lib/stripe/params/quote_update_params.rb', line 1308 def type @type end |