Class: Stripe::QuoteUpdateParams::SubscriptionDataOverride::BillingSchedule::BillUntil::LineEndsAt

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(id: nil, index: nil) ⇒ LineEndsAt

Returns a new instance of LineEndsAt.



1088
1089
1090
1091
# File 'lib/stripe/params/quote_update_params.rb', line 1088

def initialize(id: nil, index: nil)
  @id = id
  @index = index
end

Instance Attribute Details

#idObject

The ID of a quote line.



1084
1085
1086
# File 'lib/stripe/params/quote_update_params.rb', line 1084

def id
  @id
end

#indexObject

The position of the previous quote line in the ‘lines` array after which this line should begin. Indexes start from 0 and must be less than the index of the current line in the array.



1086
1087
1088
# File 'lib/stripe/params/quote_update_params.rb', line 1086

def index
  @index
end