Class: Stripe::Radar::AccountEvaluationUpdateParams
- Inherits:
-
Stripe::RequestParams
- Object
- Stripe::RequestParams
- Stripe::Radar::AccountEvaluationUpdateParams
- Defined in:
- lib/stripe/params/radar/account_evaluation_update_params.rb
Defined Under Namespace
Classes: LoginFailed, RegistrationFailed
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#login_failed ⇒ Object
Event payload for login_failed.
-
#registration_failed ⇒ Object
Event payload for registration_failed.
-
#type ⇒ Object
The type of event to report.
Instance Method Summary collapse
-
#initialize(expand: nil, type: nil, login_failed: nil, registration_failed: nil) ⇒ AccountEvaluationUpdateParams
constructor
A new instance of AccountEvaluationUpdateParams.
Methods inherited from Stripe::RequestParams
Constructor Details
#initialize(expand: nil, type: nil, login_failed: nil, registration_failed: nil) ⇒ AccountEvaluationUpdateParams
Returns a new instance of AccountEvaluationUpdateParams.
33 34 35 36 37 38 |
# File 'lib/stripe/params/radar/account_evaluation_update_params.rb', line 33 def initialize(expand: nil, type: nil, login_failed: nil, registration_failed: nil) @expand = @type = type @login_failed = login_failed @registration_failed = registration_failed end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
25 26 27 |
# File 'lib/stripe/params/radar/account_evaluation_update_params.rb', line 25 def @expand end |
#login_failed ⇒ Object
Event payload for login_failed.
29 30 31 |
# File 'lib/stripe/params/radar/account_evaluation_update_params.rb', line 29 def login_failed @login_failed end |
#registration_failed ⇒ Object
Event payload for registration_failed.
31 32 33 |
# File 'lib/stripe/params/radar/account_evaluation_update_params.rb', line 31 def registration_failed @registration_failed end |
#type ⇒ Object
The type of event to report.
27 28 29 |
# File 'lib/stripe/params/radar/account_evaluation_update_params.rb', line 27 def type @type end |