Class: Stripe::Radar::CustomerEvaluationCreateParams
- Inherits:
-
Stripe::RequestParams
- Object
- Stripe::RequestParams
- Stripe::Radar::CustomerEvaluationCreateParams
- Defined in:
- lib/stripe/params/radar/customer_evaluation_create_params.rb
Defined Under Namespace
Classes: EvaluationContext
Instance Attribute Summary collapse
-
#evaluation_context ⇒ Object
Array of context entries for the evaluation.
-
#event_type ⇒ Object
The type of evaluation event.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(evaluation_context: nil, event_type: nil, expand: nil) ⇒ CustomerEvaluationCreateParams
constructor
A new instance of CustomerEvaluationCreateParams.
Methods inherited from Stripe::RequestParams
Constructor Details
#initialize(evaluation_context: nil, event_type: nil, expand: nil) ⇒ CustomerEvaluationCreateParams
Returns a new instance of CustomerEvaluationCreateParams.
62 63 64 65 66 |
# File 'lib/stripe/params/radar/customer_evaluation_create_params.rb', line 62 def initialize(evaluation_context: nil, event_type: nil, expand: nil) @evaluation_context = evaluation_context @event_type = event_type @expand = end |
Instance Attribute Details
#evaluation_context ⇒ Object
Array of context entries for the evaluation.
56 57 58 |
# File 'lib/stripe/params/radar/customer_evaluation_create_params.rb', line 56 def evaluation_context @evaluation_context end |
#event_type ⇒ Object
The type of evaluation event.
58 59 60 |
# File 'lib/stripe/params/radar/customer_evaluation_create_params.rb', line 58 def event_type @event_type end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
60 61 62 |
# File 'lib/stripe/params/radar/customer_evaluation_create_params.rb', line 60 def @expand end |