Class: Stripe::Radar::CustomerEvaluationUpdateParams

Inherits:
Stripe::RequestParams show all
Defined in:
lib/stripe/params/radar/customer_evaluation_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Stripe::RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(customer: nil, expand: nil, status: nil) ⇒ CustomerEvaluationUpdateParams

Returns a new instance of CustomerEvaluationUpdateParams.



14
15
16
17
18
# File 'lib/stripe/params/radar/customer_evaluation_update_params.rb', line 14

def initialize(customer: nil, expand: nil, status: nil)
  @customer = customer
  @expand = expand
  @status = status
end

Instance Attribute Details

#customerObject

The ID of a Customer to attach to an entity-less registration evaluation.



8
9
10
# File 'lib/stripe/params/radar/customer_evaluation_update_params.rb', line 8

def customer
  @customer
end

#expandObject

Specifies which fields in the response should be expanded.



10
11
12
# File 'lib/stripe/params/radar/customer_evaluation_update_params.rb', line 10

def expand
  @expand
end

#statusObject

The outcome status of the evaluation: allowed, restricted, or blocked.



12
13
14
# File 'lib/stripe/params/radar/customer_evaluation_update_params.rb', line 12

def status
  @status
end