Class: Stripe::Radar::EarlyFraudWarning::ListParams

Inherits:
Stripe::RequestParams show all
Defined in:
lib/stripe/resources/radar/early_fraud_warning.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Stripe::RequestParams

#to_h

Constructor Details

#initialize(charge: nil, created: nil, ending_before: nil, expand: nil, limit: nil, payment_intent: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/stripe/resources/radar/early_fraud_warning.rb', line 51

def initialize(
  charge: nil,
  created: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  payment_intent: nil,
  starting_after: nil
)
  @charge = charge
  @created = created
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @payment_intent = payment_intent
  @starting_after = starting_after
end

Instance Attribute Details

#chargeObject

Only return early fraud warnings for the charge specified by this charge ID.



37
38
39
# File 'lib/stripe/resources/radar/early_fraud_warning.rb', line 37

def charge
  @charge
end

#createdObject

Only return early fraud warnings that were created during the given date interval.



39
40
41
# File 'lib/stripe/resources/radar/early_fraud_warning.rb', line 39

def created
  @created
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



41
42
43
# File 'lib/stripe/resources/radar/early_fraud_warning.rb', line 41

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



43
44
45
# File 'lib/stripe/resources/radar/early_fraud_warning.rb', line 43

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



45
46
47
# File 'lib/stripe/resources/radar/early_fraud_warning.rb', line 45

def limit
  @limit
end

#payment_intentObject

Only return early fraud warnings for charges that were created by the PaymentIntent specified by this PaymentIntent ID.



47
48
49
# File 'lib/stripe/resources/radar/early_fraud_warning.rb', line 47

def payment_intent
  @payment_intent
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



49
50
51
# File 'lib/stripe/resources/radar/early_fraud_warning.rb', line 49

def starting_after
  @starting_after
end