Class: Stripe::Radar::EarlyFraudWarning::RetrieveParams
- Inherits:
-
Stripe::RequestParams
- Object
- Stripe::RequestParams
- Stripe::Radar::EarlyFraudWarning::RetrieveParams
- Defined in:
- lib/stripe/resources/radar/early_fraud_warning.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ RetrieveParams
constructor
A new instance of RetrieveParams.
Methods inherited from Stripe::RequestParams
Constructor Details
#initialize(expand: nil) ⇒ RetrieveParams
Returns a new instance of RetrieveParams.
74 75 76 |
# File 'lib/stripe/resources/radar/early_fraud_warning.rb', line 74 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
72 73 74 |
# File 'lib/stripe/resources/radar/early_fraud_warning.rb', line 72 def @expand end |