Class: Stripe::Radar::IssuingAuthorizationEvaluation::AuthorizationDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Radar::IssuingAuthorizationEvaluation::AuthorizationDetails
- Defined in:
- lib/stripe/resources/radar/issuing_authorization_evaluation.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The total amount of the authorization in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).
-
#authorization_method ⇒ Object
readonly
How the card details were provided.
-
#currency ⇒ Object
readonly
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#entry_mode ⇒ Object
readonly
Defines how the card’s information was entered for the authorization.
-
#entry_mode_raw_code ⇒ Object
readonly
Raw code indicating the entry mode from the network message.
-
#initiated_at ⇒ Object
readonly
The timestamp of the authorization initiated in seconds.
-
#point_of_sale_condition ⇒ Object
readonly
Defines how the card was read at the point of sale.
-
#point_of_sale_condition_raw_code ⇒ Object
readonly
Raw code indicating the point of sale condition from the network message.
-
#reference ⇒ Object
readonly
User’s specified unique ID for this authorization attempt (e.g., RRN or internal reference).
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The total amount of the authorization in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).
17 18 19 |
# File 'lib/stripe/resources/radar/issuing_authorization_evaluation.rb', line 17 def amount @amount end |
#authorization_method ⇒ Object (readonly)
How the card details were provided.
19 20 21 |
# File 'lib/stripe/resources/radar/issuing_authorization_evaluation.rb', line 19 def @authorization_method end |
#currency ⇒ Object (readonly)
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
21 22 23 |
# File 'lib/stripe/resources/radar/issuing_authorization_evaluation.rb', line 21 def currency @currency end |
#entry_mode ⇒ Object (readonly)
Defines how the card’s information was entered for the authorization.
23 24 25 |
# File 'lib/stripe/resources/radar/issuing_authorization_evaluation.rb', line 23 def entry_mode @entry_mode end |
#entry_mode_raw_code ⇒ Object (readonly)
Raw code indicating the entry mode from the network message.
25 26 27 |
# File 'lib/stripe/resources/radar/issuing_authorization_evaluation.rb', line 25 def entry_mode_raw_code @entry_mode_raw_code end |
#initiated_at ⇒ Object (readonly)
The timestamp of the authorization initiated in seconds.
27 28 29 |
# File 'lib/stripe/resources/radar/issuing_authorization_evaluation.rb', line 27 def initiated_at @initiated_at end |
#point_of_sale_condition ⇒ Object (readonly)
Defines how the card was read at the point of sale.
29 30 31 |
# File 'lib/stripe/resources/radar/issuing_authorization_evaluation.rb', line 29 def point_of_sale_condition @point_of_sale_condition end |
#point_of_sale_condition_raw_code ⇒ Object (readonly)
Raw code indicating the point of sale condition from the network message.
31 32 33 |
# File 'lib/stripe/resources/radar/issuing_authorization_evaluation.rb', line 31 def point_of_sale_condition_raw_code @point_of_sale_condition_raw_code end |
#reference ⇒ Object (readonly)
User’s specified unique ID for this authorization attempt (e.g., RRN or internal reference).
33 34 35 |
# File 'lib/stripe/resources/radar/issuing_authorization_evaluation.rb', line 33 def reference @reference end |
Class Method Details
.field_remappings ⇒ Object
39 40 41 |
# File 'lib/stripe/resources/radar/issuing_authorization_evaluation.rb', line 39 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
35 36 37 |
# File 'lib/stripe/resources/radar/issuing_authorization_evaluation.rb', line 35 def self.inner_class_types @inner_class_types = {} end |