Class: Stripe::Radar::IssuingAuthorizationEvaluation::CardDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Radar::IssuingAuthorizationEvaluation::CardDetails
- Defined in:
- lib/stripe/resources/radar/issuing_authorization_evaluation.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bin ⇒ Object
readonly
The Bank Identification Number (BIN) of the card.
-
#bin_country ⇒ Object
readonly
The two-letter country code of the BIN issuer.
-
#card_type ⇒ Object
readonly
The type of the card.
-
#created_at ⇒ Object
readonly
The timestamp when the card was created, as a Unix timestamp in seconds.
-
#last4 ⇒ Object
readonly
The last 4 digits of the card number.
-
#reference ⇒ Object
readonly
User’s specified unique ID of the card for this authorization attempt (e.g., RRN or internal reference).
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bin ⇒ Object (readonly)
The Bank Identification Number (BIN) of the card.
46 47 48 |
# File 'lib/stripe/resources/radar/issuing_authorization_evaluation.rb', line 46 def bin @bin end |
#bin_country ⇒ Object (readonly)
The two-letter country code of the BIN issuer.
48 49 50 |
# File 'lib/stripe/resources/radar/issuing_authorization_evaluation.rb', line 48 def bin_country @bin_country end |
#card_type ⇒ Object (readonly)
The type of the card.
50 51 52 |
# File 'lib/stripe/resources/radar/issuing_authorization_evaluation.rb', line 50 def card_type @card_type end |
#created_at ⇒ Object (readonly)
The timestamp when the card was created, as a Unix timestamp in seconds.
52 53 54 |
# File 'lib/stripe/resources/radar/issuing_authorization_evaluation.rb', line 52 def created_at @created_at end |
#last4 ⇒ Object (readonly)
The last 4 digits of the card number.
54 55 56 |
# File 'lib/stripe/resources/radar/issuing_authorization_evaluation.rb', line 54 def last4 @last4 end |
#reference ⇒ Object (readonly)
User’s specified unique ID of the card for this authorization attempt (e.g., RRN or internal reference).
56 57 58 |
# File 'lib/stripe/resources/radar/issuing_authorization_evaluation.rb', line 56 def reference @reference end |
Class Method Details
.field_remappings ⇒ Object
62 63 64 |
# File 'lib/stripe/resources/radar/issuing_authorization_evaluation.rb', line 62 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
58 59 60 |
# File 'lib/stripe/resources/radar/issuing_authorization_evaluation.rb', line 58 def self.inner_class_types @inner_class_types = {} end |