Class: Stripe::Radar::IssuingAuthorizationEvaluation::MerchantDetails

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/radar/issuing_authorization_evaluation.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#category_codeObject (readonly)

The merchant category code for the seller’s business.



84
85
86
# File 'lib/stripe/resources/radar/issuing_authorization_evaluation.rb', line 84

def category_code
  @category_code
end

#countryObject (readonly)

Country where the seller is located.



86
87
88
# File 'lib/stripe/resources/radar/issuing_authorization_evaluation.rb', line 86

def country
  @country
end

#nameObject (readonly)

Name of the seller.



88
89
90
# File 'lib/stripe/resources/radar/issuing_authorization_evaluation.rb', line 88

def name
  @name
end

#network_idObject (readonly)

Identifier assigned to the seller by the card network. Different card networks may assign different network_id fields to the same merchant.



90
91
92
# File 'lib/stripe/resources/radar/issuing_authorization_evaluation.rb', line 90

def network_id
  @network_id
end

#terminal_idObject (readonly)

An ID assigned by the seller to the location of the sale.



92
93
94
# File 'lib/stripe/resources/radar/issuing_authorization_evaluation.rb', line 92

def terminal_id
  @terminal_id
end

Class Method Details

.field_remappingsObject



98
99
100
# File 'lib/stripe/resources/radar/issuing_authorization_evaluation.rb', line 98

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



94
95
96
# File 'lib/stripe/resources/radar/issuing_authorization_evaluation.rb', line 94

def self.inner_class_types
  @inner_class_types = {}
end