Class: Stripe::Radar::IssuingAuthorizationEvaluation::NetworkDetails

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/radar/issuing_authorization_evaluation.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#acquiring_institution_idObject (readonly)

Identifier assigned to the acquirer by the card network. Sometimes this value is not provided by the network; in this case, the value will be null.



105
106
107
# File 'lib/stripe/resources/radar/issuing_authorization_evaluation.rb', line 105

def acquiring_institution_id
  @acquiring_institution_id
end

#routed_networkObject (readonly)

The card network over which Stripe received the authorization.



107
108
109
# File 'lib/stripe/resources/radar/issuing_authorization_evaluation.rb', line 107

def routed_network
  @routed_network
end

Class Method Details

.field_remappingsObject



113
114
115
# File 'lib/stripe/resources/radar/issuing_authorization_evaluation.rb', line 113

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



109
110
111
# File 'lib/stripe/resources/radar/issuing_authorization_evaluation.rb', line 109

def self.inner_class_types
  @inner_class_types = {}
end