Class: Stripe::Radar::IssuingAuthorizationEvaluationCreateParams::AuthorizationDetails

Inherits:
Stripe::RequestParams
  • Object
show all
Defined in:
lib/stripe/params/radar/issuing_authorization_evaluation_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Stripe::RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, authorization_method: nil, currency: nil, entry_mode: nil, entry_mode_raw_code: nil, initiated_at: nil, point_of_sale_condition: nil, point_of_sale_condition_raw_code: nil, reference: nil) ⇒ AuthorizationDetails

Returns a new instance of AuthorizationDetails.



27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
# File 'lib/stripe/params/radar/issuing_authorization_evaluation_create_params.rb', line 27

def initialize(
  amount: nil,
  authorization_method: nil,
  currency: nil,
  entry_mode: nil,
  entry_mode_raw_code: nil,
  initiated_at: nil,
  point_of_sale_condition: nil,
  point_of_sale_condition_raw_code: nil,
  reference: nil
)
  @amount = amount
  @authorization_method = authorization_method
  @currency = currency
  @entry_mode = entry_mode
  @entry_mode_raw_code = entry_mode_raw_code
  @initiated_at = initiated_at
  @point_of_sale_condition = point_of_sale_condition
  @point_of_sale_condition_raw_code = point_of_sale_condition_raw_code
  @reference = reference
end

Instance Attribute Details

#amountObject

The total amount of the authorization in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).



9
10
11
# File 'lib/stripe/params/radar/issuing_authorization_evaluation_create_params.rb', line 9

def amount
  @amount
end

#authorization_methodObject

How the card details were provided.



11
12
13
# File 'lib/stripe/params/radar/issuing_authorization_evaluation_create_params.rb', line 11

def authorization_method
  @authorization_method
end

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



13
14
15
# File 'lib/stripe/params/radar/issuing_authorization_evaluation_create_params.rb', line 13

def currency
  @currency
end

#entry_modeObject

Defines how the card’s information was entered for the authorization.



15
16
17
# File 'lib/stripe/params/radar/issuing_authorization_evaluation_create_params.rb', line 15

def entry_mode
  @entry_mode
end

#entry_mode_raw_codeObject

Raw code indicating the entry mode from the network message.



17
18
19
# File 'lib/stripe/params/radar/issuing_authorization_evaluation_create_params.rb', line 17

def entry_mode_raw_code
  @entry_mode_raw_code
end

#initiated_atObject

The time the authorization was initiated, as a Unix timestamp in seconds. Must not be in the future.



19
20
21
# File 'lib/stripe/params/radar/issuing_authorization_evaluation_create_params.rb', line 19

def initiated_at
  @initiated_at
end

#point_of_sale_conditionObject

Defines how the card was read at the point of sale.



21
22
23
# File 'lib/stripe/params/radar/issuing_authorization_evaluation_create_params.rb', line 21

def point_of_sale_condition
  @point_of_sale_condition
end

#point_of_sale_condition_raw_codeObject

Raw code indicating the point of sale condition from the network message.



23
24
25
# File 'lib/stripe/params/radar/issuing_authorization_evaluation_create_params.rb', line 23

def point_of_sale_condition_raw_code
  @point_of_sale_condition_raw_code
end

#referenceObject

User’s specified unique ID for this authorization attempt (e.g., RRN or internal reference).



25
26
27
# File 'lib/stripe/params/radar/issuing_authorization_evaluation_create_params.rb', line 25

def reference
  @reference
end