Class: Stripe::Radar::IssuingAuthorizationEvaluationCreateParams::CardDetails
- Inherits:
-
Stripe::RequestParams
- Object
- Stripe::RequestParams
- Stripe::Radar::IssuingAuthorizationEvaluationCreateParams::CardDetails
- Defined in:
- lib/stripe/params/radar/issuing_authorization_evaluation_create_params.rb
Instance Attribute Summary collapse
-
#bin ⇒ Object
The Bank Identification Number (BIN) of the card.
-
#bin_country ⇒ Object
The two-letter country code of the BIN issuer.
-
#card_type ⇒ Object
The type of the card.
-
#created_at ⇒ Object
The timestamp when the card was created, as a Unix timestamp in seconds.
-
#last4 ⇒ Object
The last 4 digits of the card number.
-
#reference ⇒ Object
User’s specified unique ID of the card for this authorization attempt (e.g., RRN or internal reference).
Instance Method Summary collapse
-
#initialize(bin: nil, bin_country: nil, card_type: nil, created_at: nil, last4: nil, reference: nil) ⇒ CardDetails
constructor
A new instance of CardDetails.
Methods inherited from Stripe::RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(bin: nil, bin_country: nil, card_type: nil, created_at: nil, last4: nil, reference: nil) ⇒ CardDetails
Returns a new instance of CardDetails.
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/stripe/params/radar/issuing_authorization_evaluation_create_params.rb', line 64 def initialize( bin: nil, bin_country: nil, card_type: nil, created_at: nil, last4: nil, reference: nil ) @bin = bin @bin_country = bin_country @card_type = card_type @created_at = created_at @last4 = last4 @reference = reference end |
Instance Attribute Details
#bin ⇒ Object
The Bank Identification Number (BIN) of the card.
52 53 54 |
# File 'lib/stripe/params/radar/issuing_authorization_evaluation_create_params.rb', line 52 def bin @bin end |
#bin_country ⇒ Object
The two-letter country code of the BIN issuer.
54 55 56 |
# File 'lib/stripe/params/radar/issuing_authorization_evaluation_create_params.rb', line 54 def bin_country @bin_country end |
#card_type ⇒ Object
The type of the card.
56 57 58 |
# File 'lib/stripe/params/radar/issuing_authorization_evaluation_create_params.rb', line 56 def card_type @card_type end |
#created_at ⇒ Object
The timestamp when the card was created, as a Unix timestamp in seconds.
58 59 60 |
# File 'lib/stripe/params/radar/issuing_authorization_evaluation_create_params.rb', line 58 def created_at @created_at end |
#last4 ⇒ Object
The last 4 digits of the card number.
60 61 62 |
# File 'lib/stripe/params/radar/issuing_authorization_evaluation_create_params.rb', line 60 def last4 @last4 end |
#reference ⇒ Object
User’s specified unique ID of the card for this authorization attempt (e.g., RRN or internal reference).
62 63 64 |
# File 'lib/stripe/params/radar/issuing_authorization_evaluation_create_params.rb', line 62 def reference @reference end |