Class: Stripe::Radar::IssuingAuthorizationEvaluationCreateParams::MerchantDetails

Inherits:
Stripe::RequestParams
  • Object
show all
Defined in:
lib/stripe/params/radar/issuing_authorization_evaluation_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Stripe::RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(category_code: nil, country: nil, name: nil, network_id: nil, terminal_id: nil) ⇒ MerchantDetails

Returns a new instance of MerchantDetails.



105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/stripe/params/radar/issuing_authorization_evaluation_create_params.rb', line 105

def initialize(
  category_code: nil,
  country: nil,
  name: nil,
  network_id: nil,
  terminal_id: nil
)
  @category_code = category_code
  @country = country
  @name = name
  @network_id = network_id
  @terminal_id = terminal_id
end

Instance Attribute Details

#category_codeObject

The merchant category code for the seller’s business.



95
96
97
# File 'lib/stripe/params/radar/issuing_authorization_evaluation_create_params.rb', line 95

def category_code
  @category_code
end

#countryObject

Country where the seller is located.



97
98
99
# File 'lib/stripe/params/radar/issuing_authorization_evaluation_create_params.rb', line 97

def country
  @country
end

#nameObject

Name of the seller.



99
100
101
# File 'lib/stripe/params/radar/issuing_authorization_evaluation_create_params.rb', line 99

def name
  @name
end

#network_idObject

Identifier assigned to the seller by the card network. Different card networks may assign different network_id fields to the same merchant.



101
102
103
# File 'lib/stripe/params/radar/issuing_authorization_evaluation_create_params.rb', line 101

def network_id
  @network_id
end

#terminal_idObject

An ID assigned by the seller to the location of the sale.



103
104
105
# File 'lib/stripe/params/radar/issuing_authorization_evaluation_create_params.rb', line 103

def terminal_id
  @terminal_id
end