Class: Stripe::Radar::IssuingAuthorizationEvaluationCreateParams::TokenDetails
- Inherits:
-
Stripe::RequestParams
- Object
- Stripe::RequestParams
- Stripe::Radar::IssuingAuthorizationEvaluationCreateParams::TokenDetails
- Defined in:
- lib/stripe/params/radar/issuing_authorization_evaluation_create_params.rb
Instance Attribute Summary collapse
-
#created_at ⇒ Object
The timestamp when the network token was created.
-
#reference ⇒ Object
User’s specified unique ID of the card token for this authorization attempt (e.g., RRN or internal reference).
-
#wallet ⇒ Object
The digital wallet used for this transaction.
Instance Method Summary collapse
-
#initialize(created_at: nil, reference: nil, wallet: nil) ⇒ TokenDetails
constructor
A new instance of TokenDetails.
Methods inherited from Stripe::RequestParams
Constructor Details
#initialize(created_at: nil, reference: nil, wallet: nil) ⇒ TokenDetails
Returns a new instance of TokenDetails.
140 141 142 143 144 |
# File 'lib/stripe/params/radar/issuing_authorization_evaluation_create_params.rb', line 140 def initialize(created_at: nil, reference: nil, wallet: nil) @created_at = created_at @reference = reference @wallet = wallet end |
Instance Attribute Details
#created_at ⇒ Object
The timestamp when the network token was created.
134 135 136 |
# File 'lib/stripe/params/radar/issuing_authorization_evaluation_create_params.rb', line 134 def created_at @created_at end |
#reference ⇒ Object
User’s specified unique ID of the card token for this authorization attempt (e.g., RRN or internal reference).
136 137 138 |
# File 'lib/stripe/params/radar/issuing_authorization_evaluation_create_params.rb', line 136 def reference @reference end |
#wallet ⇒ Object
The digital wallet used for this transaction. One of ‘apple_pay`, `google_pay`, or `samsung_pay`.
138 139 140 |
# File 'lib/stripe/params/radar/issuing_authorization_evaluation_create_params.rb', line 138 def wallet @wallet end |