Class: Stripe::Radar::PaymentEvaluation::ClientDeviceMetadataDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Radar::PaymentEvaluation::ClientDeviceMetadataDetails
- Defined in:
- lib/stripe/resources/radar/payment_evaluation.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#radar_session ⇒ Object
readonly
ID for the Radar Session associated with the payment evaluation.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#radar_session ⇒ Object (readonly)
ID for the Radar Session associated with the payment evaluation. A [Radar Session](docs.stripe.com/radar/radar-session) is a snapshot of the browser metadata and device details that help Radar make more accurate predictions on your payments.
17 18 19 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 17 def radar_session @radar_session end |
Class Method Details
.field_remappings ⇒ Object
23 24 25 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 23 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
19 20 21 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 19 def self.inner_class_types @inner_class_types = {} end |