Class: Stripe::Radar::PaymentEvaluation::CustomerDetails

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/radar/payment_evaluation.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#customerObject (readonly)

The ID of the customer associated with the payment evaluation.



52
53
54
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 52

def customer
  @customer
end

#customer_accountObject (readonly)

The ID of the Account representing the customer associated with the payment evaluation.



54
55
56
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 54

def 
  @customer_account
end

#emailObject (readonly)

The customer’s email address.



56
57
58
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 56

def email
  @email
end

#nameObject (readonly)

The customer’s full name or business name.



58
59
60
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 58

def name
  @name
end

#phoneObject (readonly)

The customer’s phone number.



60
61
62
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 60

def phone
  @phone
end

Class Method Details

.field_remappingsObject



66
67
68
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 66

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



62
63
64
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 62

def self.inner_class_types
  @inner_class_types = {}
end