Class: Stripe::Radar::PaymentEvaluation::Event

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/radar/payment_evaluation.rb

Defined Under Namespace

Classes: DisputeOpened, EarlyFraudWarningReceived, Refunded, UserInterventionRaised, UserInterventionResolved

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#dispute_openedObject (readonly)

Dispute opened event details attached to this payment evaluation.



163
164
165
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 163

def dispute_opened
  @dispute_opened
end

#early_fraud_warning_receivedObject (readonly)

Early Fraud Warning Received event details attached to this payment evaluation.



165
166
167
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 165

def early_fraud_warning_received
  @early_fraud_warning_received
end

#occurred_atObject (readonly)

Timestamp when the event occurred.



167
168
169
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 167

def occurred_at
  @occurred_at
end

#refundedObject (readonly)

Refunded Event details attached to this payment evaluation.



169
170
171
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 169

def refunded
  @refunded
end

#typeObject (readonly)

Indicates the type of event attached to the payment evaluation.



171
172
173
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 171

def type
  @type
end

#user_intervention_raisedObject (readonly)

User intervention raised event details attached to this payment evaluation



173
174
175
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 173

def user_intervention_raised
  @user_intervention_raised
end

#user_intervention_resolvedObject (readonly)

User Intervention Resolved Event details attached to this payment evaluation



175
176
177
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 175

def user_intervention_resolved
  @user_intervention_resolved
end

Class Method Details

.field_remappingsObject



187
188
189
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 187

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



177
178
179
180
181
182
183
184
185
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 177

def self.inner_class_types
  @inner_class_types = {
    dispute_opened: DisputeOpened,
    early_fraud_warning_received: EarlyFraudWarningReceived,
    refunded: Refunded,
    user_intervention_raised: UserInterventionRaised,
    user_intervention_resolved: UserInterventionResolved,
  }
end