Class: Stripe::Radar::PaymentEvaluation::Event::UserInterventionRaised
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Radar::PaymentEvaluation::Event::UserInterventionRaised
- Defined in:
- lib/stripe/resources/radar/payment_evaluation.rb
Defined Under Namespace
Classes: Custom
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#custom ⇒ Object
readonly
User intervention raised custom event details attached to this payment evaluation.
-
#key ⇒ Object
readonly
Unique identifier for the user intervention event.
-
#type ⇒ Object
readonly
Type of user intervention raised.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#custom ⇒ Object (readonly)
User intervention raised custom event details attached to this payment evaluation
111 112 113 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 111 def custom @custom end |
#key ⇒ Object (readonly)
Unique identifier for the user intervention event.
113 114 115 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 113 def key @key end |
#type ⇒ Object (readonly)
Type of user intervention raised.
115 116 117 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 115 def type @type end |
Class Method Details
.field_remappings ⇒ Object
121 122 123 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 121 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
117 118 119 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 117 def self.inner_class_types @inner_class_types = { custom: Custom } end |