Class: Stripe::Radar::PaymentEvaluation::Insights::CardIssuerDecline

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/radar/payment_evaluation.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#model_scoreObject (readonly)

Stripe Radar’s evaluation of the likelihood that the payment will be declined by the card issuer. Scores range from 0 to 100, with higher values indicating a higher likelihood of decline.



173
174
175
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 173

def model_score
  @model_score
end

Recommended action based on the model score. Possible values are ‘block` and `continue`.



175
176
177
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 175

def recommended_action
  @recommended_action
end

Class Method Details

.field_remappingsObject



181
182
183
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 181

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



177
178
179
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 177

def self.inner_class_types
  @inner_class_types = {}
end