Class: Stripe::Radar::PaymentEvaluation::Insights::FraudulentDispute
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Radar::PaymentEvaluation::Insights::FraudulentDispute
- Defined in:
- lib/stripe/resources/radar/payment_evaluation.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#recommended_action ⇒ Object
readonly
Recommended action based on the risk score.
-
#risk_score ⇒ Object
readonly
Stripe Radar’s evaluation of the risk level of the payment.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#recommended_action ⇒ Object (readonly)
Recommended action based on the risk score. Possible values are ‘block` and `continue`.
188 189 190 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 188 def recommended_action @recommended_action end |
#risk_score ⇒ Object (readonly)
Stripe Radar’s evaluation of the risk level of the payment. Possible values for evaluated payments are between 0 and 100, with higher scores indicating higher risk.
190 191 192 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 190 def risk_score @risk_score end |
Class Method Details
.field_remappings ⇒ Object
196 197 198 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 196 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
192 193 194 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 192 def self.inner_class_types @inner_class_types = {} end |