Class: Stripe::Radar::PaymentEvaluation::Outcome

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/radar/payment_evaluation.rb

Defined Under Namespace

Classes: MerchantBlocked, Rejected, Succeeded

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#merchant_blockedObject (readonly)

Details of a merchant_blocked outcome attached to this payment evaluation.



266
267
268
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 266

def merchant_blocked
  @merchant_blocked
end

#payment_intent_idObject (readonly)

The PaymentIntent ID associated with the payment evaluation.



268
269
270
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 268

def payment_intent_id
  @payment_intent_id
end

#rejectedObject (readonly)

Details of an rejected outcome attached to this payment evaluation.



270
271
272
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 270

def rejected
  @rejected
end

#succeededObject (readonly)

Details of a succeeded outcome attached to this payment evaluation.



272
273
274
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 272

def succeeded
  @succeeded
end

#typeObject (readonly)

Indicates the outcome of the payment evaluation.



274
275
276
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 274

def type
  @type
end

Class Method Details

.field_remappingsObject



284
285
286
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 284

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



276
277
278
279
280
281
282
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 276

def self.inner_class_types
  @inner_class_types = {
    merchant_blocked: MerchantBlocked,
    rejected: Rejected,
    succeeded: Succeeded,
  }
end