Class: Stripe::Radar::PaymentEvaluation::Outcome::Rejected::Card
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Radar::PaymentEvaluation::Outcome::Rejected::Card
- Defined in:
- lib/stripe/resources/radar/payment_evaluation.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#address_line1_check ⇒ Object
readonly
Result of the address line 1 check.
-
#address_postal_code_check ⇒ Object
readonly
Indicates whether the cardholder provided a postal code and if it matched the cardholder’s billing address.
-
#cvc_check ⇒ Object
readonly
Result of the CVC check.
-
#reason ⇒ Object
readonly
Card issuer’s reason for the network decline.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#address_line1_check ⇒ Object (readonly)
Result of the address line 1 check.
187 188 189 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 187 def address_line1_check @address_line1_check end |
#address_postal_code_check ⇒ Object (readonly)
Indicates whether the cardholder provided a postal code and if it matched the cardholder’s billing address.
189 190 191 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 189 def address_postal_code_check @address_postal_code_check end |
#cvc_check ⇒ Object (readonly)
Result of the CVC check.
191 192 193 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 191 def cvc_check @cvc_check end |
#reason ⇒ Object (readonly)
Card issuer’s reason for the network decline.
193 194 195 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 193 def reason @reason end |
Class Method Details
.field_remappings ⇒ Object
199 200 201 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 199 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
195 196 197 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 195 def self.inner_class_types @inner_class_types = {} end |