Class: Stripe::Radar::PaymentEvaluation::Outcome::Succeeded::Card
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Radar::PaymentEvaluation::Outcome::Succeeded::Card
- Defined in:
- lib/stripe/resources/radar/payment_evaluation.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#address_line1_check ⇒ Object
readonly
Result of the address line 1 check.
-
#address_postal_code_check ⇒ Object
readonly
Indicates whether the cardholder provided a postal code and if it matched the cardholder’s billing address.
-
#cvc_check ⇒ Object
readonly
Result of the CVC check.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#address_line1_check ⇒ Object (readonly)
Result of the address line 1 check.
218 219 220 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 218 def address_line1_check @address_line1_check end |
#address_postal_code_check ⇒ Object (readonly)
Indicates whether the cardholder provided a postal code and if it matched the cardholder’s billing address.
220 221 222 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 220 def address_postal_code_check @address_postal_code_check end |
#cvc_check ⇒ Object (readonly)
Result of the CVC check.
222 223 224 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 222 def cvc_check @cvc_check end |
Class Method Details
.field_remappings ⇒ Object
228 229 230 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 228 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
224 225 226 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 224 def self.inner_class_types @inner_class_types = {} end |