Class: Stripe::Radar::PaymentEvaluation::PaymentDetails

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/radar/payment_evaluation.rb

Defined Under Namespace

Classes: MoneyMovementDetails, PaymentMethodDetails, ShippingDetails

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Amount intended to be collected by this payment. A positive integer representing how much to charge in the [smallest currency unit](docs.stripe.com/currencies#zero-decimal) (e.g., 100 cents to charge $1.00 or 100 to charge ¥100, a zero-decimal currency). The minimum amount is $0.50 US or [equivalent in charge currency](docs.stripe.com/currencies#minimum-and-maximum-charge-amounts). The amount value supports up to eight digits (e.g., a value of 99999999 for a USD charge of $999,999.99).



391
392
393
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 391

def amount
  @amount
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



393
394
395
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 393

def currency
  @currency
end

#descriptionObject (readonly)

An arbitrary string attached to the object. Often useful for displaying to users.



395
396
397
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 395

def description
  @description
end

#money_movement_detailsObject (readonly)

Details about the payment’s customer presence and type.



397
398
399
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 397

def money_movement_details
  @money_movement_details
end

#payment_method_detailsObject (readonly)

Details about the payment method used for the payment.



399
400
401
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 399

def payment_method_details
  @payment_method_details
end

#shipping_detailsObject (readonly)

Shipping details for the payment evaluation.



401
402
403
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 401

def shipping_details
  @shipping_details
end

#statement_descriptorObject (readonly)

Payment statement descriptor.



403
404
405
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 403

def statement_descriptor
  @statement_descriptor
end

Class Method Details

.field_remappingsObject



413
414
415
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 413

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



405
406
407
408
409
410
411
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 405

def self.inner_class_types
  @inner_class_types = {
    money_movement_details: MoneyMovementDetails,
    payment_method_details: PaymentMethodDetails,
    shipping_details: ShippingDetails,
  }
end