Class: Stripe::Radar::PaymentEvaluation::PaymentDetails::MoneyMovementDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Radar::PaymentEvaluation::PaymentDetails::MoneyMovementDetails
- Defined in:
- lib/stripe/resources/radar/payment_evaluation.rb
Defined Under Namespace
Classes: Card
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#card ⇒ Object
readonly
Describes card money movement details for the payment evaluation.
-
#money_movement_type ⇒ Object
readonly
Describes the type of money movement.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#card ⇒ Object (readonly)
Describes card money movement details for the payment evaluation.
284 285 286 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 284 def card @card end |
#money_movement_type ⇒ Object (readonly)
Describes the type of money movement. Currently only ‘card` is supported.
286 287 288 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 286 def money_movement_type @money_movement_type end |
Class Method Details
.field_remappings ⇒ Object
292 293 294 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 292 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
288 289 290 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 288 def self.inner_class_types @inner_class_types = { card: Card } end |