Class: Stripe::Radar::PaymentEvaluation::Signals::FraudulentPayment

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/radar/payment_evaluation.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#evaluated_atObject (readonly)

The time when this signal was evaluated.



464
465
466
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 464

def evaluated_at
  @evaluated_at
end

#risk_levelObject (readonly)

Risk level of this signal, based on the score.



466
467
468
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 466

def risk_level
  @risk_level
end

#scoreObject (readonly)

Score for this signal. Possible values for evaluated payments are between 0 and 100. The value is returned with two decimal places and higher scores indicate a higher likelihood of the signal being true. A score of -1 is returned when a model evaluation was not performed, such as requests from incomplete integrations.



468
469
470
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 468

def score
  @score
end

Class Method Details

.field_remappingsObject



474
475
476
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 474

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



470
471
472
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 470

def self.inner_class_types
  @inner_class_types = {}
end