Class: Stripe::Radar::PaymentEvaluationCreateParams
- Inherits:
-
Stripe::RequestParams
- Object
- Stripe::RequestParams
- Stripe::Radar::PaymentEvaluationCreateParams
- Defined in:
- lib/stripe/params/radar/payment_evaluation_create_params.rb
Defined Under Namespace
Classes: ClientDeviceMetadataDetails, CustomerDetails, PaymentDetails
Instance Attribute Summary collapse
-
#client_device_metadata_details ⇒ Object
Details about the Client Device Metadata to associate with the payment evaluation.
-
#customer_details ⇒ Object
Details about the customer associated with the payment evaluation.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#payment_details ⇒ Object
Details about the payment.
Instance Method Summary collapse
-
#initialize(client_device_metadata_details: nil, customer_details: nil, expand: nil, metadata: nil, payment_details: nil) ⇒ PaymentEvaluationCreateParams
constructor
A new instance of PaymentEvaluationCreateParams.
Methods inherited from Stripe::RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(client_device_metadata_details: nil, customer_details: nil, expand: nil, metadata: nil, payment_details: nil) ⇒ PaymentEvaluationCreateParams
Returns a new instance of PaymentEvaluationCreateParams.
271 272 273 274 275 276 277 278 279 280 281 282 283 |
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 271 def initialize( client_device_metadata_details: nil, customer_details: nil, expand: nil, metadata: nil, payment_details: nil ) @client_device_metadata_details = @customer_details = customer_details @expand = @metadata = @payment_details = payment_details end |
Instance Attribute Details
#client_device_metadata_details ⇒ Object
Details about the Client Device Metadata to associate with the payment evaluation.
261 262 263 |
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 261 def @client_device_metadata_details end |
#customer_details ⇒ Object
Details about the customer associated with the payment evaluation.
263 264 265 |
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 263 def customer_details @customer_details end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
265 266 267 |
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 265 def @expand end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
267 268 269 |
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 267 def @metadata end |
#payment_details ⇒ Object
Details about the payment.
269 270 271 |
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 269 def payment_details @payment_details end |