Class: Stripe::Radar::PaymentEvaluationCreateParams::CustomerDetails

Inherits:
Stripe::RequestParams show all
Defined in:
lib/stripe/params/radar/payment_evaluation_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Stripe::RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(customer: nil, customer_account: nil, email: nil, name: nil, phone: nil) ⇒ CustomerDetails

Returns a new instance of CustomerDetails.



28
29
30
31
32
33
34
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 28

def initialize(customer: nil, customer_account: nil, email: nil, name: nil, phone: nil)
  @customer = customer
  @customer_account = 
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#customerObject

The ID of the customer associated with the payment evaluation.



18
19
20
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 18

def customer
  @customer
end

#customer_accountObject

The ID of the Account representing the customer associated with the payment evaluation.



20
21
22
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 20

def 
  @customer_account
end

#emailObject

The customer’s email address.



22
23
24
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 22

def email
  @email
end

#nameObject

The customer’s full name or business name.



24
25
26
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 24

def name
  @name
end

#phoneObject

The customer’s phone number.



26
27
28
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 26

def phone
  @phone
end