Class: Stripe::Radar::PaymentEvaluationCreateParams::PaymentDetails::MoneyMovementDetails::Card
- Inherits:
-
Stripe::RequestParams
- Object
- Stripe::RequestParams
- Stripe::Radar::PaymentEvaluationCreateParams::PaymentDetails::MoneyMovementDetails::Card
- Defined in:
- lib/stripe/params/radar/payment_evaluation_create_params.rb
Instance Attribute Summary collapse
-
#customer_presence ⇒ Object
Describes the presence of the customer during the payment.
-
#payment_type ⇒ Object
Describes the type of payment.
Instance Method Summary collapse
-
#initialize(customer_presence: nil, payment_type: nil) ⇒ Card
constructor
A new instance of Card.
Methods inherited from Stripe::RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(customer_presence: nil, payment_type: nil) ⇒ Card
Returns a new instance of Card.
45 46 47 48 |
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 45 def initialize(customer_presence: nil, payment_type: nil) @customer_presence = customer_presence @payment_type = payment_type end |
Instance Attribute Details
#customer_presence ⇒ Object
Describes the presence of the customer during the payment.
41 42 43 |
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 41 def customer_presence @customer_presence end |
#payment_type ⇒ Object
Describes the type of payment.
43 44 45 |
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 43 def payment_type @payment_type end |