Class: Stripe::Radar::PaymentEvaluationCreateParams::PaymentDetails::PaymentMethodDetails
- Inherits:
-
Stripe::RequestParams
- Object
- Stripe::RequestParams
- Stripe::Radar::PaymentEvaluationCreateParams::PaymentDetails::PaymentMethodDetails
- Defined in:
- lib/stripe/params/radar/payment_evaluation_create_params.rb
Defined Under Namespace
Classes: BillingDetails, Card
Instance Attribute Summary collapse
-
#billing_details ⇒ Object
Billing information associated with the payment evaluation.
-
#card ⇒ Object
Masked/raw PAN card details to use as an alternative to a payment_method token.
-
#payment_method ⇒ Object
ID of the payment method used in this payment evaluation.
Instance Method Summary collapse
-
#initialize(billing_details: nil, card: nil, payment_method: nil) ⇒ PaymentMethodDetails
constructor
A new instance of PaymentMethodDetails.
Methods inherited from Stripe::RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(billing_details: nil, card: nil, payment_method: nil) ⇒ PaymentMethodDetails
Returns a new instance of PaymentMethodDetails.
176 177 178 179 180 |
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 176 def initialize(billing_details: nil, card: nil, payment_method: nil) @billing_details = billing_details @card = card @payment_method = payment_method end |
Instance Attribute Details
#billing_details ⇒ Object
Billing information associated with the payment evaluation.
170 171 172 |
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 170 def billing_details @billing_details end |
#card ⇒ Object
Masked/raw PAN card details to use as an alternative to a payment_method token.
172 173 174 |
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 172 def card @card end |
#payment_method ⇒ Object
ID of the payment method used in this payment evaluation.
174 175 176 |
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 174 def payment_method @payment_method end |