Class: Stripe::Radar::PaymentEvaluationCreateParams::PaymentDetails::PaymentMethodDetails::Card
- Inherits:
-
Stripe::RequestParams
- Object
- Stripe::RequestParams
- Stripe::Radar::PaymentEvaluationCreateParams::PaymentDetails::PaymentMethodDetails::Card
- Defined in:
- lib/stripe/params/radar/payment_evaluation_create_params.rb
Instance Attribute Summary collapse
-
#cvc ⇒ Object
The CVC of the card.
-
#exp_month ⇒ Object
Two-digit number representing the card's expiration month.
-
#exp_year ⇒ Object
Four-digit number representing the card's expiration year.
-
#first6 ⇒ Object
First six digits of the card number.
-
#last4 ⇒ Object
Last four digits of the card number.
-
#number ⇒ Object
The card number, as a string without any separators.
Instance Method Summary collapse
-
#initialize(cvc: nil, exp_month: nil, exp_year: nil, first6: nil, last4: nil, number: nil) ⇒ Card
constructor
A new instance of Card.
Methods inherited from Stripe::RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(cvc: nil, exp_month: nil, exp_year: nil, first6: nil, last4: nil, number: nil) ⇒ Card
Returns a new instance of Card.
153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 153 def initialize( cvc: nil, exp_month: nil, exp_year: nil, first6: nil, last4: nil, number: nil ) @cvc = cvc @exp_month = exp_month @exp_year = exp_year @first6 = first6 @last4 = last4 @number = number end |
Instance Attribute Details
#cvc ⇒ Object
The CVC of the card.
141 142 143 |
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 141 def cvc @cvc end |
#exp_month ⇒ Object
Two-digit number representing the card's expiration month.
143 144 145 |
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 143 def exp_month @exp_month end |
#exp_year ⇒ Object
Four-digit number representing the card's expiration year.
145 146 147 |
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 145 def exp_year @exp_year end |
#first6 ⇒ Object
First six digits of the card number.
147 148 149 |
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 147 def first6 @first6 end |
#last4 ⇒ Object
Last four digits of the card number.
149 150 151 |
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 149 def last4 @last4 end |
#number ⇒ Object
The card number, as a string without any separators.
151 152 153 |
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 151 def number @number end |