Class: Stripe::Radar::ValueList::ListParams

Inherits:
Stripe::RequestParams show all
Defined in:
lib/stripe/resources/radar/value_list.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Stripe::RequestParams

#to_h

Constructor Details

#initialize(alias_: nil, contains: nil, created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/stripe/resources/radar/value_list.rb', line 73

def initialize(
  alias_: nil,
  contains: nil,
  created: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  starting_after: nil
)
  @alias = alias_
  @contains = contains
  @created = created
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
end

Instance Attribute Details

#aliasObject

The alias used to reference the value list when writing rules.



59
60
61
# File 'lib/stripe/resources/radar/value_list.rb', line 59

def alias
  @alias
end

#containsObject

A value contained within a value list - returns all value lists containing this value.



61
62
63
# File 'lib/stripe/resources/radar/value_list.rb', line 61

def contains
  @contains
end

#createdObject

Only return value lists that were created during the given date interval.



63
64
65
# File 'lib/stripe/resources/radar/value_list.rb', line 63

def created
  @created
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



65
66
67
# File 'lib/stripe/resources/radar/value_list.rb', line 65

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



67
68
69
# File 'lib/stripe/resources/radar/value_list.rb', line 67

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



69
70
71
# File 'lib/stripe/resources/radar/value_list.rb', line 69

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



71
72
73
# File 'lib/stripe/resources/radar/value_list.rb', line 71

def starting_after
  @starting_after
end