Class: Stripe::Radar::ValueListItem::CreateParams
- Inherits:
-
Stripe::RequestParams
- Object
- Stripe::RequestParams
- Stripe::Radar::ValueListItem::CreateParams
- Defined in:
- lib/stripe/resources/radar/value_list_item.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#value ⇒ Object
The value of the item (whose type must match the type of the parent value list).
-
#value_list ⇒ Object
The identifier of the value list which the created item will be added to.
Instance Method Summary collapse
-
#initialize(expand: nil, value: nil, value_list: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from Stripe::RequestParams
Constructor Details
#initialize(expand: nil, value: nil, value_list: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
82 83 84 85 86 |
# File 'lib/stripe/resources/radar/value_list_item.rb', line 82 def initialize(expand: nil, value: nil, value_list: nil) @expand = @value = value @value_list = value_list end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
76 77 78 |
# File 'lib/stripe/resources/radar/value_list_item.rb', line 76 def @expand end |
#value ⇒ Object
The value of the item (whose type must match the type of the parent value list).
78 79 80 |
# File 'lib/stripe/resources/radar/value_list_item.rb', line 78 def value @value end |
#value_list ⇒ Object
The identifier of the value list which the created item will be added to.
80 81 82 |
# File 'lib/stripe/resources/radar/value_list_item.rb', line 80 def value_list @value_list end |