Class: Stripe::Radar::ValueListItem::ListParams

Inherits:
Stripe::RequestParams show all
Defined in:
lib/stripe/resources/radar/value_list_item.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Stripe::RequestParams

#to_h

Constructor Details

#initialize(created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, value: nil, value_list: nil) ⇒ ListParams

Returns a new instance of ListParams.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/stripe/resources/radar/value_list_item.rb', line 73

def initialize(
  created: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  starting_after: nil,
  value: nil,
  value_list: nil
)
  @created = created
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
  @value = value
  @value_list = value_list
end

Instance Attribute Details

#createdObject

Only return items that were created during the given date interval.



53
54
55
# File 'lib/stripe/resources/radar/value_list_item.rb', line 53

def created
  @created
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



56
57
58
# File 'lib/stripe/resources/radar/value_list_item.rb', line 56

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



59
60
61
# File 'lib/stripe/resources/radar/value_list_item.rb', line 59

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



62
63
64
# File 'lib/stripe/resources/radar/value_list_item.rb', line 62

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



65
66
67
# File 'lib/stripe/resources/radar/value_list_item.rb', line 65

def starting_after
  @starting_after
end

#valueObject

Return items belonging to the parent list whose value matches the specified value (using an “is like” match).



68
69
70
# File 'lib/stripe/resources/radar/value_list_item.rb', line 68

def value
  @value
end

#value_listObject

Identifier for the parent value list this item belongs to.



71
72
73
# File 'lib/stripe/resources/radar/value_list_item.rb', line 71

def value_list
  @value_list
end