Class: Stripe::Radar::ValueListItemService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::Radar::ValueListItemService
- Defined in:
- lib/stripe/services/radar/value_list_item_service.rb
Instance Method Summary collapse
-
#create(params = {}, opts = {}) ⇒ Object
Creates a new ValueListItem object, which is added to the specified parent value list.
-
#delete(item, params = {}, opts = {}) ⇒ Object
Deletes a ValueListItem object, removing it from its parent value list.
-
#list(params = {}, opts = {}) ⇒ Object
Returns a list of ValueListItem objects.
-
#retrieve(item, params = {}, opts = {}) ⇒ Object
Retrieves a ValueListItem object.
-
#serialize_batch_create(params = {}, opts = {}) ⇒ Object
Serializes a ValueListItem create request into a batch job JSONL line.
Methods inherited from StripeService
#initialize, #request, #request_stream
Constructor Details
This class inherits a constructor from Stripe::StripeService
Instance Method Details
#create(params = {}, opts = {}) ⇒ Object
Creates a new ValueListItem object, which is added to the specified parent value list.
8 9 10 11 12 13 14 15 16 |
# File 'lib/stripe/services/radar/value_list_item_service.rb', line 8 def create(params = {}, opts = {}) request( method: :post, path: "/v1/radar/value_list_items", params: params, opts: opts, base_address: :api ) end |
#delete(item, params = {}, opts = {}) ⇒ Object
Deletes a ValueListItem object, removing it from its parent value list.
19 20 21 22 23 24 25 26 27 |
# File 'lib/stripe/services/radar/value_list_item_service.rb', line 19 def delete(item, params = {}, opts = {}) request( method: :delete, path: format("/v1/radar/value_list_items/%<item>s", { item: CGI.escape(item) }), params: params, opts: opts, base_address: :api ) end |
#list(params = {}, opts = {}) ⇒ Object
Returns a list of ValueListItem objects. The objects are sorted in descending order by creation date, with the most recently created object appearing first.
30 31 32 33 34 35 36 37 38 |
# File 'lib/stripe/services/radar/value_list_item_service.rb', line 30 def list(params = {}, opts = {}) request( method: :get, path: "/v1/radar/value_list_items", params: params, opts: opts, base_address: :api ) end |
#retrieve(item, params = {}, opts = {}) ⇒ Object
Retrieves a ValueListItem object.
41 42 43 44 45 46 47 48 49 |
# File 'lib/stripe/services/radar/value_list_item_service.rb', line 41 def retrieve(item, params = {}, opts = {}) request( method: :get, path: format("/v1/radar/value_list_items/%<item>s", { item: CGI.escape(item) }), params: params, opts: opts, base_address: :api ) end |
#serialize_batch_create(params = {}, opts = {}) ⇒ Object
Serializes a ValueListItem create request into a batch job JSONL line.
52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/stripe/services/radar/value_list_item_service.rb', line 52 def serialize_batch_create(params = {}, opts = {}) request_id = SecureRandom.uuid stripe_version = opts[:stripe_version] || Stripe.api_version request_body = { id: request_id, params: params, stripe_version: stripe_version, } request_body[:context] = opts[:stripe_context] if opts[:stripe_context] JSON.generate(request_body) end |