Class: Stripe::Radar::ValueListItemService::ListParams

Inherits:
Stripe::RequestParams show all
Defined in:
lib/stripe/services/radar/value_list_item_service.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Stripe::RequestParams

#to_h

Constructor Details

#initialize(created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, value: nil, value_list: nil) ⇒ ListParams

Returns a new instance of ListParams.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/stripe/services/radar/value_list_item_service.rb', line 52

def initialize(
  created: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  starting_after: nil,
  value: nil,
  value_list: nil
)
  @created = created
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
  @value = value
  @value_list = value_list
end

Instance Attribute Details

#createdObject

Only return items that were created during the given date interval.



38
39
40
# File 'lib/stripe/services/radar/value_list_item_service.rb', line 38

def created
  @created
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



40
41
42
# File 'lib/stripe/services/radar/value_list_item_service.rb', line 40

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



42
43
44
# File 'lib/stripe/services/radar/value_list_item_service.rb', line 42

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



44
45
46
# File 'lib/stripe/services/radar/value_list_item_service.rb', line 44

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



46
47
48
# File 'lib/stripe/services/radar/value_list_item_service.rb', line 46

def starting_after
  @starting_after
end

#valueObject

Return items belonging to the parent list whose value matches the specified value (using an “is like” match).



48
49
50
# File 'lib/stripe/services/radar/value_list_item_service.rb', line 48

def value
  @value
end

#value_listObject

Identifier for the parent value list this item belongs to.



50
51
52
# File 'lib/stripe/services/radar/value_list_item_service.rb', line 50

def value_list
  @value_list
end