Class: Stripe::Radar::ValueListService::CreateParams

Inherits:
Stripe::RequestParams show all
Defined in:
lib/stripe/services/radar/value_list_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Stripe::RequestParams

#to_h

Constructor Details

#initialize(alias_: nil, expand: nil, item_type: nil, metadata: nil, name: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



100
101
102
103
104
105
106
# File 'lib/stripe/services/radar/value_list_service.rb', line 100

def initialize(alias_: nil, expand: nil, item_type: nil, metadata: nil, name: nil)
  @alias = alias_
  @expand = expand
  @item_type = item_type
  @metadata = 
  @name = name
end

Instance Attribute Details

#aliasObject

The name of the value list for use in rules.



90
91
92
# File 'lib/stripe/services/radar/value_list_service.rb', line 90

def alias
  @alias
end

#expandObject

Specifies which fields in the response should be expanded.



92
93
94
# File 'lib/stripe/services/radar/value_list_service.rb', line 92

def expand
  @expand
end

#item_typeObject

Type of the items in the value list. One of ‘card_fingerprint`, `us_bank_account_fingerprint`, `sepa_debit_fingerprint`, `card_bin`, `email`, `ip_address`, `country`, `string`, `case_sensitive_string`, or `customer_id`. Use `string` if the item type is unknown or mixed.



94
95
96
# File 'lib/stripe/services/radar/value_list_service.rb', line 94

def item_type
  @item_type
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



96
97
98
# File 'lib/stripe/services/radar/value_list_service.rb', line 96

def 
  @metadata
end

#nameObject

The human-readable name of the value list.



98
99
100
# File 'lib/stripe/services/radar/value_list_service.rb', line 98

def name
  @name
end