Class: Stripe::Radar::ValueListService::UpdateParams

Inherits:
Stripe::RequestParams show all
Defined in:
lib/stripe/services/radar/value_list_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Stripe::RequestParams

#to_h

Constructor Details

#initialize(alias_: nil, expand: nil, metadata: nil, name: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



28
29
30
31
32
33
# File 'lib/stripe/services/radar/value_list_service.rb', line 28

def initialize(alias_: nil, expand: nil, metadata: nil, name: nil)
  @alias = alias_
  @expand = expand
  @metadata = 
  @name = name
end

Instance Attribute Details

#aliasObject

The name of the value list for use in rules.



20
21
22
# File 'lib/stripe/services/radar/value_list_service.rb', line 20

def alias
  @alias
end

#expandObject

Specifies which fields in the response should be expanded.



22
23
24
# File 'lib/stripe/services/radar/value_list_service.rb', line 22

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



24
25
26
# File 'lib/stripe/services/radar/value_list_service.rb', line 24

def 
  @metadata
end

#nameObject

The human-readable name of the value list.



26
27
28
# File 'lib/stripe/services/radar/value_list_service.rb', line 26

def name
  @name
end