Class: Stripe::Refund::DestinationDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Refund::DestinationDetails
- Defined in:
- lib/stripe/resources/refund.rb
Defined Under Namespace
Classes: Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBankTransfer, Blik, BrBankTransfer, Card, Cashapp, Crypto, CustomerCashBalance, Eps, EuBankTransfer, GbBankTransfer, Giropay, Grabpay, IdBankTransfer, JpBankTransfer, Klarna, MbWay, Multibanco, MxBankTransfer, NzBankTransfer, P24, Paynow, Paypal, Pix, Revolut, Scalapay, Sofort, Swish, ThBankTransfer, Twint, UsBankTransfer, WechatPay, Zip
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#affirm ⇒ Object
readonly
Attribute for field affirm.
-
#afterpay_clearpay ⇒ Object
readonly
Attribute for field afterpay_clearpay.
-
#alipay ⇒ Object
readonly
Attribute for field alipay.
-
#alma ⇒ Object
readonly
Attribute for field alma.
-
#amazon_pay ⇒ Object
readonly
Attribute for field amazon_pay.
-
#au_bank_transfer ⇒ Object
readonly
Attribute for field au_bank_transfer.
-
#blik ⇒ Object
readonly
Attribute for field blik.
-
#br_bank_transfer ⇒ Object
readonly
Attribute for field br_bank_transfer.
-
#card ⇒ Object
readonly
Attribute for field card.
-
#cashapp ⇒ Object
readonly
Attribute for field cashapp.
-
#crypto ⇒ Object
readonly
Attribute for field crypto.
-
#customer_cash_balance ⇒ Object
readonly
Attribute for field customer_cash_balance.
-
#eps ⇒ Object
readonly
Attribute for field eps.
-
#eu_bank_transfer ⇒ Object
readonly
Attribute for field eu_bank_transfer.
-
#gb_bank_transfer ⇒ Object
readonly
Attribute for field gb_bank_transfer.
-
#giropay ⇒ Object
readonly
Attribute for field giropay.
-
#grabpay ⇒ Object
readonly
Attribute for field grabpay.
-
#id_bank_transfer ⇒ Object
readonly
Attribute for field id_bank_transfer.
-
#jp_bank_transfer ⇒ Object
readonly
Attribute for field jp_bank_transfer.
-
#klarna ⇒ Object
readonly
Attribute for field klarna.
-
#mb_way ⇒ Object
readonly
Attribute for field mb_way.
-
#multibanco ⇒ Object
readonly
Attribute for field multibanco.
-
#mx_bank_transfer ⇒ Object
readonly
Attribute for field mx_bank_transfer.
-
#nz_bank_transfer ⇒ Object
readonly
Attribute for field nz_bank_transfer.
-
#p24 ⇒ Object
readonly
Attribute for field p24.
-
#paynow ⇒ Object
readonly
Attribute for field paynow.
-
#paypal ⇒ Object
readonly
Attribute for field paypal.
-
#pix ⇒ Object
readonly
Attribute for field pix.
-
#revolut ⇒ Object
readonly
Attribute for field revolut.
-
#scalapay ⇒ Object
readonly
Attribute for field scalapay.
-
#sofort ⇒ Object
readonly
Attribute for field sofort.
-
#swish ⇒ Object
readonly
Attribute for field swish.
-
#th_bank_transfer ⇒ Object
readonly
Attribute for field th_bank_transfer.
-
#twint ⇒ Object
readonly
Attribute for field twint.
-
#type ⇒ Object
readonly
The type of transaction-specific details of the payment method used in the refund (e.g., ‘card`).
-
#us_bank_transfer ⇒ Object
readonly
Attribute for field us_bank_transfer.
-
#wechat_pay ⇒ Object
readonly
Attribute for field wechat_pay.
-
#zip ⇒ Object
readonly
Attribute for field zip.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#affirm ⇒ Object (readonly)
Attribute for field affirm
475 476 477 |
# File 'lib/stripe/resources/refund.rb', line 475 def affirm @affirm end |
#afterpay_clearpay ⇒ Object (readonly)
Attribute for field afterpay_clearpay
477 478 479 |
# File 'lib/stripe/resources/refund.rb', line 477 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object (readonly)
Attribute for field alipay
479 480 481 |
# File 'lib/stripe/resources/refund.rb', line 479 def alipay @alipay end |
#alma ⇒ Object (readonly)
Attribute for field alma
481 482 483 |
# File 'lib/stripe/resources/refund.rb', line 481 def alma @alma end |
#amazon_pay ⇒ Object (readonly)
Attribute for field amazon_pay
483 484 485 |
# File 'lib/stripe/resources/refund.rb', line 483 def amazon_pay @amazon_pay end |
#au_bank_transfer ⇒ Object (readonly)
Attribute for field au_bank_transfer
485 486 487 |
# File 'lib/stripe/resources/refund.rb', line 485 def au_bank_transfer @au_bank_transfer end |
#blik ⇒ Object (readonly)
Attribute for field blik
487 488 489 |
# File 'lib/stripe/resources/refund.rb', line 487 def blik @blik end |
#br_bank_transfer ⇒ Object (readonly)
Attribute for field br_bank_transfer
489 490 491 |
# File 'lib/stripe/resources/refund.rb', line 489 def br_bank_transfer @br_bank_transfer end |
#card ⇒ Object (readonly)
Attribute for field card
491 492 493 |
# File 'lib/stripe/resources/refund.rb', line 491 def card @card end |
#cashapp ⇒ Object (readonly)
Attribute for field cashapp
493 494 495 |
# File 'lib/stripe/resources/refund.rb', line 493 def cashapp @cashapp end |
#crypto ⇒ Object (readonly)
Attribute for field crypto
495 496 497 |
# File 'lib/stripe/resources/refund.rb', line 495 def crypto @crypto end |
#customer_cash_balance ⇒ Object (readonly)
Attribute for field customer_cash_balance
497 498 499 |
# File 'lib/stripe/resources/refund.rb', line 497 def customer_cash_balance @customer_cash_balance end |
#eps ⇒ Object (readonly)
Attribute for field eps
499 500 501 |
# File 'lib/stripe/resources/refund.rb', line 499 def eps @eps end |
#eu_bank_transfer ⇒ Object (readonly)
Attribute for field eu_bank_transfer
501 502 503 |
# File 'lib/stripe/resources/refund.rb', line 501 def eu_bank_transfer @eu_bank_transfer end |
#gb_bank_transfer ⇒ Object (readonly)
Attribute for field gb_bank_transfer
503 504 505 |
# File 'lib/stripe/resources/refund.rb', line 503 def gb_bank_transfer @gb_bank_transfer end |
#giropay ⇒ Object (readonly)
Attribute for field giropay
505 506 507 |
# File 'lib/stripe/resources/refund.rb', line 505 def giropay @giropay end |
#grabpay ⇒ Object (readonly)
Attribute for field grabpay
507 508 509 |
# File 'lib/stripe/resources/refund.rb', line 507 def grabpay @grabpay end |
#id_bank_transfer ⇒ Object (readonly)
Attribute for field id_bank_transfer
509 510 511 |
# File 'lib/stripe/resources/refund.rb', line 509 def id_bank_transfer @id_bank_transfer end |
#jp_bank_transfer ⇒ Object (readonly)
Attribute for field jp_bank_transfer
511 512 513 |
# File 'lib/stripe/resources/refund.rb', line 511 def jp_bank_transfer @jp_bank_transfer end |
#klarna ⇒ Object (readonly)
Attribute for field klarna
513 514 515 |
# File 'lib/stripe/resources/refund.rb', line 513 def klarna @klarna end |
#mb_way ⇒ Object (readonly)
Attribute for field mb_way
515 516 517 |
# File 'lib/stripe/resources/refund.rb', line 515 def mb_way @mb_way end |
#multibanco ⇒ Object (readonly)
Attribute for field multibanco
517 518 519 |
# File 'lib/stripe/resources/refund.rb', line 517 def multibanco @multibanco end |
#mx_bank_transfer ⇒ Object (readonly)
Attribute for field mx_bank_transfer
519 520 521 |
# File 'lib/stripe/resources/refund.rb', line 519 def mx_bank_transfer @mx_bank_transfer end |
#nz_bank_transfer ⇒ Object (readonly)
Attribute for field nz_bank_transfer
521 522 523 |
# File 'lib/stripe/resources/refund.rb', line 521 def nz_bank_transfer @nz_bank_transfer end |
#p24 ⇒ Object (readonly)
Attribute for field p24
523 524 525 |
# File 'lib/stripe/resources/refund.rb', line 523 def p24 @p24 end |
#paynow ⇒ Object (readonly)
Attribute for field paynow
525 526 527 |
# File 'lib/stripe/resources/refund.rb', line 525 def paynow @paynow end |
#paypal ⇒ Object (readonly)
Attribute for field paypal
527 528 529 |
# File 'lib/stripe/resources/refund.rb', line 527 def paypal @paypal end |
#pix ⇒ Object (readonly)
Attribute for field pix
529 530 531 |
# File 'lib/stripe/resources/refund.rb', line 529 def pix @pix end |
#revolut ⇒ Object (readonly)
Attribute for field revolut
531 532 533 |
# File 'lib/stripe/resources/refund.rb', line 531 def revolut @revolut end |
#scalapay ⇒ Object (readonly)
Attribute for field scalapay
533 534 535 |
# File 'lib/stripe/resources/refund.rb', line 533 def scalapay @scalapay end |
#sofort ⇒ Object (readonly)
Attribute for field sofort
535 536 537 |
# File 'lib/stripe/resources/refund.rb', line 535 def sofort @sofort end |
#swish ⇒ Object (readonly)
Attribute for field swish
537 538 539 |
# File 'lib/stripe/resources/refund.rb', line 537 def swish @swish end |
#th_bank_transfer ⇒ Object (readonly)
Attribute for field th_bank_transfer
539 540 541 |
# File 'lib/stripe/resources/refund.rb', line 539 def th_bank_transfer @th_bank_transfer end |
#twint ⇒ Object (readonly)
Attribute for field twint
541 542 543 |
# File 'lib/stripe/resources/refund.rb', line 541 def twint @twint end |
#type ⇒ Object (readonly)
The type of transaction-specific details of the payment method used in the refund (e.g., ‘card`). An additional hash is included on `destination_details` with a name matching this value. It contains information specific to the refund transaction.
543 544 545 |
# File 'lib/stripe/resources/refund.rb', line 543 def type @type end |
#us_bank_transfer ⇒ Object (readonly)
Attribute for field us_bank_transfer
545 546 547 |
# File 'lib/stripe/resources/refund.rb', line 545 def us_bank_transfer @us_bank_transfer end |
#wechat_pay ⇒ Object (readonly)
Attribute for field wechat_pay
547 548 549 |
# File 'lib/stripe/resources/refund.rb', line 547 def wechat_pay @wechat_pay end |
#zip ⇒ Object (readonly)
Attribute for field zip
549 550 551 |
# File 'lib/stripe/resources/refund.rb', line 549 def zip @zip end |
Class Method Details
.field_remappings ⇒ Object
593 594 595 |
# File 'lib/stripe/resources/refund.rb', line 593 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 |
# File 'lib/stripe/resources/refund.rb', line 551 def self.inner_class_types @inner_class_types = { affirm: Affirm, afterpay_clearpay: AfterpayClearpay, alipay: Alipay, alma: Alma, amazon_pay: AmazonPay, au_bank_transfer: AuBankTransfer, blik: Blik, br_bank_transfer: BrBankTransfer, card: Card, cashapp: Cashapp, crypto: Crypto, customer_cash_balance: CustomerCashBalance, eps: Eps, eu_bank_transfer: EuBankTransfer, gb_bank_transfer: GbBankTransfer, giropay: Giropay, grabpay: Grabpay, id_bank_transfer: IdBankTransfer, jp_bank_transfer: JpBankTransfer, klarna: Klarna, mb_way: MbWay, multibanco: Multibanco, mx_bank_transfer: MxBankTransfer, nz_bank_transfer: NzBankTransfer, p24: P24, paynow: Paynow, paypal: Paypal, pix: Pix, revolut: Revolut, scalapay: Scalapay, sofort: Sofort, swish: Swish, th_bank_transfer: ThBankTransfer, twint: Twint, us_bank_transfer: UsBankTransfer, wechat_pay: WechatPay, zip: Zip, } end |