Class: Stripe::Refund::DestinationDetails::Card

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/refund.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#referenceObject (readonly)

Value of the reference number assigned to the refund.



49
50
51
# File 'lib/stripe/resources/refund.rb', line 49

def reference
  @reference
end

#reference_statusObject (readonly)

Status of the reference number on the refund. This can be ‘pending`, `available` or `unavailable`.



52
53
54
# File 'lib/stripe/resources/refund.rb', line 52

def reference_status
  @reference_status
end

#reference_typeObject (readonly)

Type of the reference number assigned to the refund.



55
56
57
# File 'lib/stripe/resources/refund.rb', line 55

def reference_type
  @reference_type
end

#typeObject (readonly)

The type of refund. This can be ‘refund`, `reversal`, or `pending`.



58
59
60
# File 'lib/stripe/resources/refund.rb', line 58

def type
  @type
end