Class: Stripe::RefundService::CancelParams
- Inherits:
-
Stripe::RequestParams
- Object
- Stripe::RequestParams
- Stripe::RefundService::CancelParams
- Defined in:
- lib/stripe/services/refund_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ CancelParams
constructor
A new instance of CancelParams.
Methods inherited from Stripe::RequestParams
Constructor Details
#initialize(expand: nil) ⇒ CancelParams
Returns a new instance of CancelParams.
138 139 140 |
# File 'lib/stripe/services/refund_service.rb', line 138 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
136 137 138 |
# File 'lib/stripe/services/refund_service.rb', line 136 def @expand end |