Class: Stripe::RefundService::CreateParams

Inherits:
Stripe::RequestParams show all
Defined in:
lib/stripe/services/refund_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Stripe::RequestParams

#to_h

Constructor Details

#initialize(amount: nil, charge: nil, currency: nil, customer: nil, expand: nil, instructions_email: nil, metadata: nil, origin: nil, payment_intent: nil, reason: nil, refund_application_fee: nil, reverse_transfer: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/stripe/services/refund_service.rb', line 104

def initialize(
  amount: nil,
  charge: nil,
  currency: nil,
  customer: nil,
  expand: nil,
  instructions_email: nil,
  metadata: nil,
  origin: nil,
  payment_intent: nil,
  reason: nil,
  refund_application_fee: nil,
  reverse_transfer: nil
)
  @amount = amount
  @charge = charge
  @currency = currency
  @customer = customer
  @expand = expand
  @instructions_email = instructions_email
  @metadata = 
  @origin = origin
  @payment_intent = payment_intent
  @reason = reason
  @refund_application_fee = refund_application_fee
  @reverse_transfer = reverse_transfer
end

Instance Attribute Details

#amountObject

Attribute for param field amount



69
70
71
# File 'lib/stripe/services/refund_service.rb', line 69

def amount
  @amount
end

#chargeObject

The identifier of the charge to refund.



72
73
74
# File 'lib/stripe/services/refund_service.rb', line 72

def charge
  @charge
end

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



75
76
77
# File 'lib/stripe/services/refund_service.rb', line 75

def currency
  @currency
end

#customerObject

Customer whose customer balance to refund from.



78
79
80
# File 'lib/stripe/services/refund_service.rb', line 78

def customer
  @customer
end

#expandObject

Specifies which fields in the response should be expanded.



81
82
83
# File 'lib/stripe/services/refund_service.rb', line 81

def expand
  @expand
end

#instructions_emailObject

For payment methods without native refund support (e.g., Konbini, PromptPay), use this email from the customer to receive refund instructions.



84
85
86
# File 'lib/stripe/services/refund_service.rb', line 84

def instructions_email
  @instructions_email
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



87
88
89
# File 'lib/stripe/services/refund_service.rb', line 87

def 
  @metadata
end

#originObject

Origin of the refund



90
91
92
# File 'lib/stripe/services/refund_service.rb', line 90

def origin
  @origin
end

#payment_intentObject

The identifier of the PaymentIntent to refund.



93
94
95
# File 'lib/stripe/services/refund_service.rb', line 93

def payment_intent
  @payment_intent
end

#reasonObject

String indicating the reason for the refund. If set, possible values are ‘duplicate`, `fraudulent`, and `requested_by_customer`. If you believe the charge to be fraudulent, specifying `fraudulent` as the reason will add the associated card and email to your [block lists](stripe.com/docs/radar/lists), and will also help us improve our fraud detection algorithms.



96
97
98
# File 'lib/stripe/services/refund_service.rb', line 96

def reason
  @reason
end

#refund_application_feeObject

Boolean indicating whether the application fee should be refunded when refunding this charge. If a full charge refund is given, the full application fee will be refunded. Otherwise, the application fee will be refunded in an amount proportional to the amount of the charge refunded. An application fee can be refunded only by the application that created the charge.



99
100
101
# File 'lib/stripe/services/refund_service.rb', line 99

def refund_application_fee
  @refund_application_fee
end

#reverse_transferObject

Boolean indicating whether the transfer should be reversed when refunding this charge. The transfer will be reversed proportionally to the amount being refunded (either the entire or partial amount).
A transfer can be reversed only by the application that created the charge.



102
103
104
# File 'lib/stripe/services/refund_service.rb', line 102

def reverse_transfer
  @reverse_transfer
end