Class: Stripe::RefundService::RetrieveParams
- Inherits:
-
Stripe::RequestParams
- Object
- Stripe::RequestParams
- Stripe::RefundService::RetrieveParams
- Defined in:
- lib/stripe/services/refund_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ RetrieveParams
constructor
A new instance of RetrieveParams.
Methods inherited from Stripe::RequestParams
Constructor Details
#initialize(expand: nil) ⇒ RetrieveParams
Returns a new instance of RetrieveParams.
117 118 119 |
# File 'lib/stripe/services/refund_service.rb', line 117 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
115 116 117 |
# File 'lib/stripe/services/refund_service.rb', line 115 def @expand end |