Class: Stripe::RefundService::UpdateParams
- Inherits:
-
Stripe::RequestParams
- Object
- Stripe::RequestParams
- Stripe::RefundService::UpdateParams
- Defined in:
- lib/stripe/services/refund_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
Instance Method Summary collapse
-
#initialize(expand: nil, metadata: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from Stripe::RequestParams
Constructor Details
#initialize(expand: nil, metadata: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
128 129 130 131 |
# File 'lib/stripe/services/refund_service.rb', line 128 def initialize(expand: nil, metadata: nil) @expand = @metadata = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
124 125 126 |
# File 'lib/stripe/services/refund_service.rb', line 124 def @expand end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
126 127 128 |
# File 'lib/stripe/services/refund_service.rb', line 126 def @metadata end |