Class: Stripe::Reporting::ReportRun::ListParams

Inherits:
Stripe::RequestParams show all
Defined in:
lib/stripe/resources/reporting/report_run.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Stripe::RequestParams

#to_h

Constructor Details

#initialize(created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/stripe/resources/reporting/report_run.rb', line 85

def initialize(
  created: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  starting_after: nil
)
  @created = created
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
end

Instance Attribute Details

#createdObject

Only return Report Runs that were created during the given date interval.



71
72
73
# File 'lib/stripe/resources/reporting/report_run.rb', line 71

def created
  @created
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



74
75
76
# File 'lib/stripe/resources/reporting/report_run.rb', line 74

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



77
78
79
# File 'lib/stripe/resources/reporting/report_run.rb', line 77

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



80
81
82
# File 'lib/stripe/resources/reporting/report_run.rb', line 80

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



83
84
85
# File 'lib/stripe/resources/reporting/report_run.rb', line 83

def starting_after
  @starting_after
end