Class: Stripe::Reporting::ReportRunService::CreateParams

Inherits:
Stripe::RequestParams show all
Defined in:
lib/stripe/services/reporting/report_run_service.rb

Defined Under Namespace

Classes: Parameters

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Stripe::RequestParams

#to_h

Constructor Details

#initialize(expand: nil, parameters: nil, report_type: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



97
98
99
100
101
# File 'lib/stripe/services/reporting/report_run_service.rb', line 97

def initialize(expand: nil, parameters: nil, report_type: nil)
  @expand = expand
  @parameters = parameters
  @report_type = report_type
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



91
92
93
# File 'lib/stripe/services/reporting/report_run_service.rb', line 91

def expand
  @expand
end

#parametersObject

Parameters specifying how the report should be run. Different Report Types have different required and optional parameters, listed in the [API Access to Reports](stripe.com/docs/reporting/statements/api) documentation.



93
94
95
# File 'lib/stripe/services/reporting/report_run_service.rb', line 93

def parameters
  @parameters
end

#report_typeObject

The ID of the [report type](stripe.com/docs/reporting/statements/api#report-types) to run, such as ‘“balance.summary.1”`.



95
96
97
# File 'lib/stripe/services/reporting/report_run_service.rb', line 95

def report_type
  @report_type
end