Class: Stripe::Reserve::Hold::ReleaseSchedule
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Reserve::Hold::ReleaseSchedule
- Defined in:
- lib/stripe/resources/reserve/hold.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#release_after ⇒ Object
readonly
The time after which the ReserveHold is requested to be released.
-
#scheduled_release ⇒ Object
readonly
The time at which the ReserveHold is scheduled to be released, automatically set to midnight UTC of the day after ‘release_after`.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#release_after ⇒ Object (readonly)
The time after which the ReserveHold is requested to be released.
17 18 19 |
# File 'lib/stripe/resources/reserve/hold.rb', line 17 def release_after @release_after end |
#scheduled_release ⇒ Object (readonly)
The time at which the ReserveHold is scheduled to be released, automatically set to midnight UTC of the day after ‘release_after`.
19 20 21 |
# File 'lib/stripe/resources/reserve/hold.rb', line 19 def scheduled_release @scheduled_release end |
Class Method Details
.field_remappings ⇒ Object
25 26 27 |
# File 'lib/stripe/resources/reserve/hold.rb', line 25 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
21 22 23 |
# File 'lib/stripe/resources/reserve/hold.rb', line 21 def self.inner_class_types @inner_class_types = {} end |