Class: Stripe::Reserve::HoldListParams

Inherits:
Stripe::RequestParams show all
Defined in:
lib/stripe/params/reserve/hold_list_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Stripe::RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(currency: nil, ending_before: nil, expand: nil, is_releasable: nil, limit: nil, reason: nil, reserve_plan: nil, reserve_release: nil, source_charge: nil, starting_after: nil) ⇒ HoldListParams

Returns a new instance of HoldListParams.



28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
# File 'lib/stripe/params/reserve/hold_list_params.rb', line 28

def initialize(
  currency: nil,
  ending_before: nil,
  expand: nil,
  is_releasable: nil,
  limit: nil,
  reason: nil,
  reserve_plan: nil,
  reserve_release: nil,
  source_charge: nil,
  starting_after: nil
)
  @currency = currency
  @ending_before = ending_before
  @expand = expand
  @is_releasable = is_releasable
  @limit = limit
  @reason = reason
  @reserve_plan = reserve_plan
  @reserve_release = reserve_release
  @source_charge = source_charge
  @starting_after = starting_after
end

Instance Attribute Details

#currencyObject

Only return ReserveHolds associated with the currency specified by this currency code. Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



8
9
10
# File 'lib/stripe/params/reserve/hold_list_params.rb', line 8

def currency
  @currency
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



10
11
12
# File 'lib/stripe/params/reserve/hold_list_params.rb', line 10

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



12
13
14
# File 'lib/stripe/params/reserve/hold_list_params.rb', line 12

def expand
  @expand
end

#is_releasableObject

Only return ReserveHolds that are releasable.



14
15
16
# File 'lib/stripe/params/reserve/hold_list_params.rb', line 14

def is_releasable
  @is_releasable
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



16
17
18
# File 'lib/stripe/params/reserve/hold_list_params.rb', line 16

def limit
  @limit
end

#reasonObject

Attribute for param field reason



18
19
20
# File 'lib/stripe/params/reserve/hold_list_params.rb', line 18

def reason
  @reason
end

#reserve_planObject

Only return ReserveHolds associated with the ReservePlan specified by this ReservePlan ID.



20
21
22
# File 'lib/stripe/params/reserve/hold_list_params.rb', line 20

def reserve_plan
  @reserve_plan
end

#reserve_releaseObject

Only return ReserveHolds associated with the ReserveRelease specified by this ReserveRelease ID.



22
23
24
# File 'lib/stripe/params/reserve/hold_list_params.rb', line 22

def reserve_release
  @reserve_release
end

#source_chargeObject

Only return ReserveHolds associated with the Charge specified by this source charge ID.



24
25
26
# File 'lib/stripe/params/reserve/hold_list_params.rb', line 24

def source_charge
  @source_charge
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



26
27
28
# File 'lib/stripe/params/reserve/hold_list_params.rb', line 26

def starting_after
  @starting_after
end