Class: Stripe::Reserve::HoldRetrieveParams
- Inherits:
-
Stripe::RequestParams
- Object
- Stripe::RequestParams
- Stripe::Reserve::HoldRetrieveParams
- Defined in:
- lib/stripe/params/reserve/hold_retrieve_params.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ HoldRetrieveParams
constructor
A new instance of HoldRetrieveParams.
Methods inherited from Stripe::RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(expand: nil) ⇒ HoldRetrieveParams
Returns a new instance of HoldRetrieveParams.
10 11 12 |
# File 'lib/stripe/params/reserve/hold_retrieve_params.rb', line 10 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
8 9 10 |
# File 'lib/stripe/params/reserve/hold_retrieve_params.rb', line 8 def @expand end |