Class: Stripe::Reserve::Plan::RollingRelease
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Reserve::Plan::RollingRelease
- Defined in:
- lib/stripe/resources/reserve/plan.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#days_after_charge ⇒ Object
readonly
The number of days to reserve funds before releasing.
-
#expires_on ⇒ Object
readonly
The time at which the ReservePlan expires.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#days_after_charge ⇒ Object (readonly)
The number of days to reserve funds before releasing.
30 31 32 |
# File 'lib/stripe/resources/reserve/plan.rb', line 30 def days_after_charge @days_after_charge end |
#expires_on ⇒ Object (readonly)
The time at which the ReservePlan expires.
32 33 34 |
# File 'lib/stripe/resources/reserve/plan.rb', line 32 def expires_on @expires_on end |
Class Method Details
.field_remappings ⇒ Object
38 39 40 |
# File 'lib/stripe/resources/reserve/plan.rb', line 38 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
34 35 36 |
# File 'lib/stripe/resources/reserve/plan.rb', line 34 def self.inner_class_types @inner_class_types = {} end |