Class: Stripe::Reserve::PlanRetrieveParams
- Inherits:
-
Stripe::RequestParams
- Object
- Stripe::RequestParams
- Stripe::Reserve::PlanRetrieveParams
- Defined in:
- lib/stripe/params/reserve/plan_retrieve_params.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ PlanRetrieveParams
constructor
A new instance of PlanRetrieveParams.
Methods inherited from Stripe::RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(expand: nil) ⇒ PlanRetrieveParams
Returns a new instance of PlanRetrieveParams.
10 11 12 |
# File 'lib/stripe/params/reserve/plan_retrieve_params.rb', line 10 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
8 9 10 |
# File 'lib/stripe/params/reserve/plan_retrieve_params.rb', line 8 def @expand end |