Class: Stripe::Reserve::ReleaseListParams
- Inherits:
-
Stripe::RequestParams
- Object
- Stripe::RequestParams
- Stripe::Reserve::ReleaseListParams
- Defined in:
- lib/stripe/params/reserve/release_list_params.rb
Instance Attribute Summary collapse
-
#currency ⇒ Object
Only return ReserveReleases associated with the currency specified by this currency code.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#reserve_hold ⇒ Object
Only return ReserveReleases associated with the ReserveHold specified by this ReserveHold ID.
-
#reserve_plan ⇒ Object
Only return ReserveReleases associated with the ReservePlan specified by this ReservePlan ID.
-
#starting_after ⇒ Object
A cursor for use in pagination.
Instance Method Summary collapse
-
#initialize(currency: nil, ending_before: nil, expand: nil, limit: nil, reserve_hold: nil, reserve_plan: nil, starting_after: nil) ⇒ ReleaseListParams
constructor
A new instance of ReleaseListParams.
Methods inherited from Stripe::RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(currency: nil, ending_before: nil, expand: nil, limit: nil, reserve_hold: nil, reserve_plan: nil, starting_after: nil) ⇒ ReleaseListParams
Returns a new instance of ReleaseListParams.
22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 |
# File 'lib/stripe/params/reserve/release_list_params.rb', line 22 def initialize( currency: nil, ending_before: nil, expand: nil, limit: nil, reserve_hold: nil, reserve_plan: nil, starting_after: nil ) @currency = currency @ending_before = ending_before @expand = @limit = limit @reserve_hold = reserve_hold @reserve_plan = reserve_plan @starting_after = starting_after end |
Instance Attribute Details
#currency ⇒ Object
Only return ReserveReleases associated with the currency specified by this currency code. Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
8 9 10 |
# File 'lib/stripe/params/reserve/release_list_params.rb', line 8 def currency @currency end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
10 11 12 |
# File 'lib/stripe/params/reserve/release_list_params.rb', line 10 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
12 13 14 |
# File 'lib/stripe/params/reserve/release_list_params.rb', line 12 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
14 15 16 |
# File 'lib/stripe/params/reserve/release_list_params.rb', line 14 def limit @limit end |
#reserve_hold ⇒ Object
Only return ReserveReleases associated with the ReserveHold specified by this ReserveHold ID.
16 17 18 |
# File 'lib/stripe/params/reserve/release_list_params.rb', line 16 def reserve_hold @reserve_hold end |
#reserve_plan ⇒ Object
Only return ReserveReleases associated with the ReservePlan specified by this ReservePlan ID.
18 19 20 |
# File 'lib/stripe/params/reserve/release_list_params.rb', line 18 def reserve_plan @reserve_plan end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
20 21 22 |
# File 'lib/stripe/params/reserve/release_list_params.rb', line 20 def starting_after @starting_after end |