Class: Stripe::Review

Inherits:
APIResource show all
Extended by:
APIOperations::List
Defined in:
lib/stripe/resources/review.rb

Overview

Reviews can be used to supplement automated fraud detection with human expertise.

Learn more about [Radar](docs.stripe.com/radar) and reviewing payments [here](stripe.com/docs/radar/reviews).

Defined Under Namespace

Classes: ApproveParams, IpAddressLocation, ListParams, Session

Constant Summary collapse

OBJECT_NAME =
"review"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::List

list

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#billing_zipObject (readonly)

The ZIP or postal code of the card used, if applicable.



104
105
106
# File 'lib/stripe/resources/review.rb', line 104

def billing_zip
  @billing_zip
end

#chargeObject (readonly)

The charge associated with this review.



106
107
108
# File 'lib/stripe/resources/review.rb', line 106

def charge
  @charge
end

#closed_reasonObject (readonly)

The reason the review was closed, or null if it has not yet been closed. One of ‘approved`, `refunded`, `refunded_as_fraud`, `disputed`, `redacted`, `canceled`, `payment_never_settled`, or `acknowledged`.



108
109
110
# File 'lib/stripe/resources/review.rb', line 108

def closed_reason
  @closed_reason
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



110
111
112
# File 'lib/stripe/resources/review.rb', line 110

def created
  @created
end

#idObject (readonly)

Unique identifier for the object.



112
113
114
# File 'lib/stripe/resources/review.rb', line 112

def id
  @id
end

#ip_addressObject (readonly)

The IP address where the payment originated.



114
115
116
# File 'lib/stripe/resources/review.rb', line 114

def ip_address
  @ip_address
end

#ip_address_locationObject (readonly)

Information related to the location of the payment. Note that this information is an approximation and attempts to locate the nearest population center - it should not be used to determine a specific address.



116
117
118
# File 'lib/stripe/resources/review.rb', line 116

def ip_address_location
  @ip_address_location
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



118
119
120
# File 'lib/stripe/resources/review.rb', line 118

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



120
121
122
# File 'lib/stripe/resources/review.rb', line 120

def object
  @object
end

#openObject (readonly)

If ‘true`, the review needs action.



122
123
124
# File 'lib/stripe/resources/review.rb', line 122

def open
  @open
end

#opened_reasonObject (readonly)

The reason the review was opened. One of ‘rule` or `manual`.



124
125
126
# File 'lib/stripe/resources/review.rb', line 124

def opened_reason
  @opened_reason
end

#payment_intentObject (readonly)

The PaymentIntent ID associated with this review, if one exists.



126
127
128
# File 'lib/stripe/resources/review.rb', line 126

def payment_intent
  @payment_intent
end

#reasonObject (readonly)

The reason the review is currently open or closed. One of ‘rule`, `manual`, `approved`, `refunded`, `refunded_as_fraud`, `disputed`, `redacted`, `canceled`, `payment_never_settled`, or `acknowledged`.



128
129
130
# File 'lib/stripe/resources/review.rb', line 128

def reason
  @reason
end

#sessionObject (readonly)

Information related to the browsing session of the user who initiated the payment.



130
131
132
# File 'lib/stripe/resources/review.rb', line 130

def session
  @session
end

Class Method Details

.approve(review, params = {}, opts = {}) ⇒ Object

Approves a Review object, closing it and removing it from the list of reviews.



143
144
145
146
147
148
149
150
# File 'lib/stripe/resources/review.rb', line 143

def self.approve(review, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/reviews/%<review>s/approve", { review: CGI.escape(review) }),
    params: params,
    opts: opts
  )
end

.field_remappingsObject



161
162
163
# File 'lib/stripe/resources/review.rb', line 161

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



157
158
159
# File 'lib/stripe/resources/review.rb', line 157

def self.inner_class_types
  @inner_class_types = { ip_address_location: IpAddressLocation, session: Session }
end

.list(params = {}, opts = {}) ⇒ Object

Returns a list of Review objects that have open set to true. The objects are sorted in descending order by creation date, with the most recently created object appearing first.



153
154
155
# File 'lib/stripe/resources/review.rb', line 153

def self.list(params = {}, opts = {})
  request_stripe_object(method: :get, path: "/v1/reviews", params: params, opts: opts)
end

.object_nameObject



13
14
15
# File 'lib/stripe/resources/review.rb', line 13

def self.object_name
  "review"
end

Instance Method Details

#approve(params = {}, opts = {}) ⇒ Object

Approves a Review object, closing it and removing it from the list of reviews.



133
134
135
136
137
138
139
140
# File 'lib/stripe/resources/review.rb', line 133

def approve(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/reviews/%<review>s/approve", { review: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end