Class: Stripe::Review::RetrieveParams
- Inherits:
-
Stripe::RequestParams
- Object
- Stripe::RequestParams
- Stripe::Review::RetrieveParams
- Defined in:
- lib/stripe/resources/review.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ RetrieveParams
constructor
A new instance of RetrieveParams.
Methods inherited from Stripe::RequestParams
Constructor Details
#initialize(expand: nil) ⇒ RetrieveParams
Returns a new instance of RetrieveParams.
97 98 99 |
# File 'lib/stripe/resources/review.rb', line 97 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
95 96 97 |
# File 'lib/stripe/resources/review.rb', line 95 def @expand end |