Class: Stripe::Review::Session
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Review::Session
- Defined in:
- lib/stripe/resources/review.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#browser ⇒ Object
readonly
The browser used in this browser session (e.g., ‘Chrome`).
-
#device ⇒ Object
readonly
Information about the device used for the browser session (e.g., ‘Samsung SM-G930T`).
-
#platform ⇒ Object
readonly
The platform for the browser session (e.g., ‘Macintosh`).
-
#version ⇒ Object
readonly
The version for the browser session (e.g., ‘61.0.3163.100`).
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#browser ⇒ Object (readonly)
The browser used in this browser session (e.g., ‘Chrome`).
32 33 34 |
# File 'lib/stripe/resources/review.rb', line 32 def browser @browser end |
#device ⇒ Object (readonly)
Information about the device used for the browser session (e.g., ‘Samsung SM-G930T`).
34 35 36 |
# File 'lib/stripe/resources/review.rb', line 34 def device @device end |
#platform ⇒ Object (readonly)
The platform for the browser session (e.g., ‘Macintosh`).
36 37 38 |
# File 'lib/stripe/resources/review.rb', line 36 def platform @platform end |
#version ⇒ Object (readonly)
The version for the browser session (e.g., ‘61.0.3163.100`).
38 39 40 |
# File 'lib/stripe/resources/review.rb', line 38 def version @version end |