Class: Stripe::SetupAttempt::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/setup_attempt.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(created: nil, ending_before: nil, expand: nil, limit: nil, setup_intent: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
# File 'lib/stripe/resources/setup_attempt.rb', line 356

def initialize(
  created: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  setup_intent: nil,
  starting_after: nil
)
  @created = created
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @setup_intent = setup_intent
  @starting_after = starting_after
end

Instance Attribute Details

#createdObject

A filter on the list, based on the object ‘created` field. The value can be a string with an integer Unix timestamp or a dictionary with a number of different query options.



343
344
345
# File 'lib/stripe/resources/setup_attempt.rb', line 343

def created
  @created
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



345
346
347
# File 'lib/stripe/resources/setup_attempt.rb', line 345

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



347
348
349
# File 'lib/stripe/resources/setup_attempt.rb', line 347

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



349
350
351
# File 'lib/stripe/resources/setup_attempt.rb', line 349

def limit
  @limit
end

#setup_intentObject

Only return SetupAttempts created by the SetupIntent specified by this ID.



352
353
354
# File 'lib/stripe/resources/setup_attempt.rb', line 352

def setup_intent
  @setup_intent
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



354
355
356
# File 'lib/stripe/resources/setup_attempt.rb', line 354

def starting_after
  @starting_after
end