Class: Stripe::SetupAttempt::PaymentMethodDetails
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::SetupAttempt::PaymentMethodDetails
- Defined in:
- lib/stripe/resources/setup_attempt.rb
Defined Under Namespace
Classes: AcssDebit, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Boleto, Card, CardPresent, Cashapp, IdBankTransfer, Ideal, KakaoPay, Klarna, KrCard, Link, NaverPay, NzBankAccount, Paypal, Paypay, Payto, Pix, RevolutPay, Satispay, SepaDebit, Sofort, StripeBalance, Twint, Upi, UsBankAccount
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
readonly
Attribute for field acss_debit.
-
#amazon_pay ⇒ Object
readonly
Attribute for field amazon_pay.
-
#au_becs_debit ⇒ Object
readonly
Attribute for field au_becs_debit.
-
#bacs_debit ⇒ Object
readonly
Attribute for field bacs_debit.
-
#bancontact ⇒ Object
readonly
Attribute for field bancontact.
-
#boleto ⇒ Object
readonly
Attribute for field boleto.
-
#card ⇒ Object
readonly
Attribute for field card.
-
#card_present ⇒ Object
readonly
Attribute for field card_present.
-
#cashapp ⇒ Object
readonly
Attribute for field cashapp.
-
#id_bank_transfer ⇒ Object
readonly
Attribute for field id_bank_transfer.
-
#ideal ⇒ Object
readonly
Attribute for field ideal.
-
#kakao_pay ⇒ Object
readonly
Attribute for field kakao_pay.
-
#klarna ⇒ Object
readonly
Attribute for field klarna.
-
#kr_card ⇒ Object
readonly
Attribute for field kr_card.
-
#link ⇒ Object
readonly
Attribute for field link.
-
#naver_pay ⇒ Object
readonly
Attribute for field naver_pay.
-
#nz_bank_account ⇒ Object
readonly
Attribute for field nz_bank_account.
-
#paypal ⇒ Object
readonly
Attribute for field paypal.
-
#paypay ⇒ Object
readonly
Attribute for field paypay.
-
#payto ⇒ Object
readonly
Attribute for field payto.
-
#pix ⇒ Object
readonly
Attribute for field pix.
-
#revolut_pay ⇒ Object
readonly
Attribute for field revolut_pay.
-
#satispay ⇒ Object
readonly
Attribute for field satispay.
-
#sepa_debit ⇒ Object
readonly
Attribute for field sepa_debit.
-
#sofort ⇒ Object
readonly
Attribute for field sofort.
-
#stripe_balance ⇒ Object
readonly
Attribute for field stripe_balance.
-
#twint ⇒ Object
readonly
Attribute for field twint.
-
#type ⇒ Object
readonly
The type of the payment method used in the SetupIntent (e.g.,
card). -
#upi ⇒ Object
readonly
Attribute for field upi.
-
#us_bank_account ⇒ Object
readonly
Attribute for field us_bank_account.
Attributes inherited from Stripe::StripeObject
Class Method Summary collapse
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#acss_debit ⇒ Object (readonly)
Attribute for field acss_debit
506 507 508 |
# File 'lib/stripe/resources/setup_attempt.rb', line 506 def acss_debit @acss_debit end |
#amazon_pay ⇒ Object (readonly)
Attribute for field amazon_pay
508 509 510 |
# File 'lib/stripe/resources/setup_attempt.rb', line 508 def amazon_pay @amazon_pay end |
#au_becs_debit ⇒ Object (readonly)
Attribute for field au_becs_debit
510 511 512 |
# File 'lib/stripe/resources/setup_attempt.rb', line 510 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object (readonly)
Attribute for field bacs_debit
512 513 514 |
# File 'lib/stripe/resources/setup_attempt.rb', line 512 def bacs_debit @bacs_debit end |
#bancontact ⇒ Object (readonly)
Attribute for field bancontact
514 515 516 |
# File 'lib/stripe/resources/setup_attempt.rb', line 514 def bancontact @bancontact end |
#boleto ⇒ Object (readonly)
Attribute for field boleto
516 517 518 |
# File 'lib/stripe/resources/setup_attempt.rb', line 516 def boleto @boleto end |
#card ⇒ Object (readonly)
Attribute for field card
518 519 520 |
# File 'lib/stripe/resources/setup_attempt.rb', line 518 def card @card end |
#card_present ⇒ Object (readonly)
Attribute for field card_present
520 521 522 |
# File 'lib/stripe/resources/setup_attempt.rb', line 520 def card_present @card_present end |
#cashapp ⇒ Object (readonly)
Attribute for field cashapp
522 523 524 |
# File 'lib/stripe/resources/setup_attempt.rb', line 522 def cashapp @cashapp end |
#id_bank_transfer ⇒ Object (readonly)
Attribute for field id_bank_transfer
524 525 526 |
# File 'lib/stripe/resources/setup_attempt.rb', line 524 def id_bank_transfer @id_bank_transfer end |
#ideal ⇒ Object (readonly)
Attribute for field ideal
526 527 528 |
# File 'lib/stripe/resources/setup_attempt.rb', line 526 def ideal @ideal end |
#kakao_pay ⇒ Object (readonly)
Attribute for field kakao_pay
528 529 530 |
# File 'lib/stripe/resources/setup_attempt.rb', line 528 def kakao_pay @kakao_pay end |
#klarna ⇒ Object (readonly)
Attribute for field klarna
530 531 532 |
# File 'lib/stripe/resources/setup_attempt.rb', line 530 def klarna @klarna end |
#kr_card ⇒ Object (readonly)
Attribute for field kr_card
532 533 534 |
# File 'lib/stripe/resources/setup_attempt.rb', line 532 def kr_card @kr_card end |
#link ⇒ Object (readonly)
Attribute for field link
534 535 536 |
# File 'lib/stripe/resources/setup_attempt.rb', line 534 def link @link end |
#naver_pay ⇒ Object (readonly)
Attribute for field naver_pay
536 537 538 |
# File 'lib/stripe/resources/setup_attempt.rb', line 536 def naver_pay @naver_pay end |
#nz_bank_account ⇒ Object (readonly)
Attribute for field nz_bank_account
538 539 540 |
# File 'lib/stripe/resources/setup_attempt.rb', line 538 def nz_bank_account @nz_bank_account end |
#paypal ⇒ Object (readonly)
Attribute for field paypal
540 541 542 |
# File 'lib/stripe/resources/setup_attempt.rb', line 540 def paypal @paypal end |
#paypay ⇒ Object (readonly)
Attribute for field paypay
542 543 544 |
# File 'lib/stripe/resources/setup_attempt.rb', line 542 def paypay @paypay end |
#payto ⇒ Object (readonly)
Attribute for field payto
544 545 546 |
# File 'lib/stripe/resources/setup_attempt.rb', line 544 def payto @payto end |
#pix ⇒ Object (readonly)
Attribute for field pix
546 547 548 |
# File 'lib/stripe/resources/setup_attempt.rb', line 546 def pix @pix end |
#revolut_pay ⇒ Object (readonly)
Attribute for field revolut_pay
548 549 550 |
# File 'lib/stripe/resources/setup_attempt.rb', line 548 def revolut_pay @revolut_pay end |
#satispay ⇒ Object (readonly)
Attribute for field satispay
550 551 552 |
# File 'lib/stripe/resources/setup_attempt.rb', line 550 def satispay @satispay end |
#sepa_debit ⇒ Object (readonly)
Attribute for field sepa_debit
552 553 554 |
# File 'lib/stripe/resources/setup_attempt.rb', line 552 def sepa_debit @sepa_debit end |
#sofort ⇒ Object (readonly)
Attribute for field sofort
554 555 556 |
# File 'lib/stripe/resources/setup_attempt.rb', line 554 def sofort @sofort end |
#stripe_balance ⇒ Object (readonly)
Attribute for field stripe_balance
556 557 558 |
# File 'lib/stripe/resources/setup_attempt.rb', line 556 def stripe_balance @stripe_balance end |
#twint ⇒ Object (readonly)
Attribute for field twint
558 559 560 |
# File 'lib/stripe/resources/setup_attempt.rb', line 558 def twint @twint end |
#type ⇒ Object (readonly)
The type of the payment method used in the SetupIntent (e.g., card). An additional hash is included on payment_method_details with a name matching this value. It contains confirmation-specific information for the payment method.
560 561 562 |
# File 'lib/stripe/resources/setup_attempt.rb', line 560 def type @type end |
#upi ⇒ Object (readonly)
Attribute for field upi
562 563 564 |
# File 'lib/stripe/resources/setup_attempt.rb', line 562 def upi @upi end |
#us_bank_account ⇒ Object (readonly)
Attribute for field us_bank_account
564 565 566 |
# File 'lib/stripe/resources/setup_attempt.rb', line 564 def us_bank_account @us_bank_account end |
Class Method Details
.field_remappings ⇒ Object
600 601 602 |
# File 'lib/stripe/resources/setup_attempt.rb', line 600 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 |
# File 'lib/stripe/resources/setup_attempt.rb', line 566 def self.inner_class_types @inner_class_types = { acss_debit: AcssDebit, amazon_pay: AmazonPay, au_becs_debit: AuBecsDebit, bacs_debit: BacsDebit, bancontact: Bancontact, boleto: Boleto, card: Card, card_present: CardPresent, cashapp: Cashapp, id_bank_transfer: IdBankTransfer, ideal: Ideal, kakao_pay: KakaoPay, klarna: Klarna, kr_card: KrCard, link: Link, naver_pay: NaverPay, nz_bank_account: NzBankAccount, paypal: Paypal, paypay: Paypay, payto: Payto, pix: Pix, revolut_pay: RevolutPay, satispay: Satispay, sepa_debit: SepaDebit, sofort: Sofort, stripe_balance: StripeBalance, twint: Twint, upi: Upi, us_bank_account: UsBankAccount, } end |