Class: Stripe::SetupAttempt::PaymentMethodDetails::Card::Wallet
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::SetupAttempt::PaymentMethodDetails::Card::Wallet
- Defined in:
- lib/stripe/resources/setup_attempt.rb
Defined Under Namespace
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#apple_pay ⇒ Object
readonly
Attribute for field apple_pay.
-
#google_pay ⇒ Object
readonly
Attribute for field google_pay.
-
#type ⇒ Object
readonly
The type of the card wallet, one of ‘apple_pay`, `google_pay`, or `link`.
Attributes inherited from Stripe::StripeObject
Method Summary
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#apple_pay ⇒ Object (readonly)
Attribute for field apple_pay
79 80 81 |
# File 'lib/stripe/resources/setup_attempt.rb', line 79 def apple_pay @apple_pay end |
#google_pay ⇒ Object (readonly)
Attribute for field google_pay
81 82 83 |
# File 'lib/stripe/resources/setup_attempt.rb', line 81 def google_pay @google_pay end |
#type ⇒ Object (readonly)
The type of the card wallet, one of ‘apple_pay`, `google_pay`, or `link`. An additional hash is included on the Wallet subhash with a name matching this value. It contains additional information specific to the card wallet type.
83 84 85 |
# File 'lib/stripe/resources/setup_attempt.rb', line 83 def type @type end |