Class: Stripe::SetupIntent

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List
Includes:
APIOperations::Save
Defined in:
lib/stripe/resources/setup_intent.rb

Overview

A SetupIntent guides you through the process of setting up and saving a customer's payment credentials for future payments. For example, you can use a SetupIntent to set up and save your customer's card without immediately collecting a payment. Later, you can use PaymentIntents to drive the payment flow.

Create a SetupIntent when you're ready to collect your customer's payment credentials. Don't maintain long-lived, unconfirmed SetupIntents because they might not be valid. The SetupIntent transitions through multiple statuses as it guides you through the setup process.

Successful SetupIntents result in payment credentials that are optimized for future payments. For example, cardholders in certain regions might need to be run through Strong Customer Authentication during payment method collection to streamline later off-session payments. If you use the SetupIntent with a Customer, it automatically attaches the resulting payment method to that Customer after successful setup. We recommend using SetupIntents or setup_future_usage on PaymentIntents to save payment methods to prevent saving invalid or unoptimized payment methods.

By using SetupIntents, you can reduce friction for your customers, even as regulations change over time.

Related guide: Setup Intents API

Defined Under Namespace

Classes: AutomaticPaymentMethods, LastSetupError, ManagedPayments, NextAction, PaymentMethodConfigurationDetails, PaymentMethodOptions, Redaction, SetupDetails

Constant Summary collapse

OBJECT_NAME =
"setup_intent"

Constants inherited from StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods included from APIOperations::Save

included, #save

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#allowed_payment_method_typesObject (readonly)

The list of payment method types to allow for this SetupIntent. Stripe will only use methods in this list when determining the payment methods to offer.



868
869
870
# File 'lib/stripe/resources/setup_intent.rb', line 868

def allowed_payment_method_types
  @allowed_payment_method_types
end

#applicationObject (readonly)

ID of the Connect application that created the SetupIntent.



870
871
872
# File 'lib/stripe/resources/setup_intent.rb', line 870

def application
  @application
end

#attach_to_selfObject (readonly)

If present, the SetupIntent's payment method will be attached to the in-context Stripe Account.

It can only be used for this Stripe Account’s own money movement flows like InboundTransfer and OutboundTransfers. It cannot be set to true when setting up a PaymentMethod for a Customer, and defaults to false when attaching a PaymentMethod to a Customer.



874
875
876
# File 'lib/stripe/resources/setup_intent.rb', line 874

def attach_to_self
  @attach_to_self
end

#automatic_payment_methodsObject (readonly)

Settings for dynamic payment methods compatible with this Setup Intent



876
877
878
# File 'lib/stripe/resources/setup_intent.rb', line 876

def automatic_payment_methods
  @automatic_payment_methods
end

#cancellation_reasonObject (readonly)

Reason for cancellation of this SetupIntent, one of abandoned, requested_by_customer, or duplicate.



878
879
880
# File 'lib/stripe/resources/setup_intent.rb', line 878

def cancellation_reason
  @cancellation_reason
end

#client_secretObject (readonly)

The client secret of this SetupIntent. Used for client-side retrieval using a publishable key.

The client secret can be used to complete payment setup from your frontend. It should not be stored, logged, or exposed to anyone other than the customer. Make sure that you have TLS enabled on any page that includes the client secret.



882
883
884
# File 'lib/stripe/resources/setup_intent.rb', line 882

def client_secret
  @client_secret
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



884
885
886
# File 'lib/stripe/resources/setup_intent.rb', line 884

def created
  @created
end

#customerObject (readonly)

ID of the Customer this SetupIntent belongs to, if one exists.

If present, the SetupIntent's payment method will be attached to the Customer on successful setup. Payment methods attached to other Customers cannot be used with this SetupIntent.



888
889
890
# File 'lib/stripe/resources/setup_intent.rb', line 888

def customer
  @customer
end

#customer_accountObject (readonly)

ID of the Account this SetupIntent belongs to, if one exists.

If present, the SetupIntent's payment method will be attached to the Account on successful setup. Payment methods attached to other Accounts cannot be used with this SetupIntent.



892
893
894
# File 'lib/stripe/resources/setup_intent.rb', line 892

def 
  @customer_account
end

#descriptionObject (readonly)

An arbitrary string attached to the object. Often useful for displaying to users.



894
895
896
# File 'lib/stripe/resources/setup_intent.rb', line 894

def description
  @description
end

#excluded_payment_method_typesObject (readonly)

Payment method types that are excluded from this SetupIntent.



896
897
898
# File 'lib/stripe/resources/setup_intent.rb', line 896

def excluded_payment_method_types
  @excluded_payment_method_types
end

#flow_directionsObject (readonly)

Indicates the directions of money movement for which this payment method is intended to be used.

Include inbound if you intend to use the payment method as the origin to pull funds from. Include outbound if you intend to use the payment method as the destination to send funds to. You can include both if you intend to use the payment method for both purposes.



900
901
902
# File 'lib/stripe/resources/setup_intent.rb', line 900

def flow_directions
  @flow_directions
end

#idObject (readonly)

Unique identifier for the object.



902
903
904
# File 'lib/stripe/resources/setup_intent.rb', line 902

def id
  @id
end

#last_setup_errorObject (readonly)

The error encountered in the previous SetupIntent confirmation.



904
905
906
# File 'lib/stripe/resources/setup_intent.rb', line 904

def last_setup_error
  @last_setup_error
end

#latest_attemptObject (readonly)

The most recent SetupAttempt for this SetupIntent.



906
907
908
# File 'lib/stripe/resources/setup_intent.rb', line 906

def latest_attempt
  @latest_attempt
end

#livemodeObject (readonly)

If the object exists in live mode, the value is true. If the object exists in test mode, the value is false.



908
909
910
# File 'lib/stripe/resources/setup_intent.rb', line 908

def livemode
  @livemode
end

#managed_paymentsObject (readonly)

Attribute for field managed_payments



910
911
912
# File 'lib/stripe/resources/setup_intent.rb', line 910

def managed_payments
  @managed_payments
end

#mandateObject (readonly)

ID of the multi use Mandate generated by the SetupIntent.



912
913
914
# File 'lib/stripe/resources/setup_intent.rb', line 912

def mandate
  @mandate
end

#metadataObject (readonly)

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



914
915
916
# File 'lib/stripe/resources/setup_intent.rb', line 914

def 
  @metadata
end

#next_actionObject (readonly)

If present, this property tells you what actions you need to take in order for your customer to continue payment setup.



916
917
918
# File 'lib/stripe/resources/setup_intent.rb', line 916

def next_action
  @next_action
end

#objectObject (readonly)

String representing the object's type. Objects of the same type share the same value.



918
919
920
# File 'lib/stripe/resources/setup_intent.rb', line 918

def object
  @object
end

#on_behalf_ofObject (readonly)

The account (if any) for which the setup is intended.



920
921
922
# File 'lib/stripe/resources/setup_intent.rb', line 920

def on_behalf_of
  @on_behalf_of
end

#payment_methodObject (readonly)

ID of the payment method used with this SetupIntent. If the payment method is card_present and isn't a digital wallet, then the generated_card associated with the latest_attempt is attached to the Customer instead.



922
923
924
# File 'lib/stripe/resources/setup_intent.rb', line 922

def payment_method
  @payment_method
end

#payment_method_configuration_detailsObject (readonly)

Information about the payment method configuration used for this Setup Intent.



924
925
926
# File 'lib/stripe/resources/setup_intent.rb', line 924

def payment_method_configuration_details
  @payment_method_configuration_details
end

#payment_method_optionsObject (readonly)

Payment method-specific configuration for this SetupIntent.



926
927
928
# File 'lib/stripe/resources/setup_intent.rb', line 926

def payment_method_options
  @payment_method_options
end

#payment_method_typesObject (readonly)

The list of payment method types (e.g. card) that this SetupIntent is allowed to set up. A list of valid payment method types can be found here.



928
929
930
# File 'lib/stripe/resources/setup_intent.rb', line 928

def payment_method_types
  @payment_method_types
end

#redactionObject (readonly)

Redaction status of this SetupIntent. If the SetupIntent isn't redacted, this field is null.



930
931
932
# File 'lib/stripe/resources/setup_intent.rb', line 930

def redaction
  @redaction
end

#setup_detailsObject (readonly)

Attribute for field setup_details



932
933
934
# File 'lib/stripe/resources/setup_intent.rb', line 932

def setup_details
  @setup_details
end

#single_use_mandateObject (readonly)

ID of the single_use Mandate generated by the SetupIntent.



934
935
936
# File 'lib/stripe/resources/setup_intent.rb', line 934

def single_use_mandate
  @single_use_mandate
end

#statusObject (readonly)

Status of this SetupIntent, one of requires_payment_method, requires_confirmation, requires_action, processing, canceled, or succeeded.



936
937
938
# File 'lib/stripe/resources/setup_intent.rb', line 936

def status
  @status
end

#usageObject (readonly)

Indicates how the payment method is intended to be used in the future.

Use on_session if you intend to only reuse the payment method when the customer is in your checkout flow. Use off_session if your customer may or may not be in your checkout flow. If not provided, this value defaults to off_session.



940
941
942
# File 'lib/stripe/resources/setup_intent.rb', line 940

def usage
  @usage
end

Class Method Details

.cancel(intent, params = {}, opts = {}) ⇒ Object

You can cancel a SetupIntent object when it's in one of these statuses: requires_payment_method, requires_confirmation, or requires_action.

After you cancel it, setup is abandoned and any operations on the SetupIntent fail with an error. You can't cancel the SetupIntent for a Checkout Session. Expire the Checkout Session instead.



957
958
959
960
961
962
963
964
# File 'lib/stripe/resources/setup_intent.rb', line 957

def self.cancel(intent, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/setup_intents/%<intent>s/cancel", { intent: CGI.escape(intent) }),
    params: params,
    opts: opts
  )
end

.confirm(intent, params = {}, opts = {}) ⇒ Object

Confirm that your customer intends to set up the current or provided payment method. For example, you would confirm a SetupIntent when a customer hits the “Save” button on a payment method management page on your website.

If the selected payment method does not require any additional steps from the customer, the SetupIntent will transition to the succeeded status.

Otherwise, it will transition to the requires_action status and suggest additional actions via next_action. If setup fails, the SetupIntent will transition to the requires_payment_method status or the canceled status if the confirmation limit is reached.



1003
1004
1005
1006
1007
1008
1009
1010
# File 'lib/stripe/resources/setup_intent.rb', line 1003

def self.confirm(intent, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/setup_intents/%<intent>s/confirm", { intent: CGI.escape(intent) }),
    params: params,
    opts: opts
  )
end

.create(params = {}, opts = {}) ⇒ Object

Creates a SetupIntent object.

After you create the SetupIntent, attach a payment method and confirm it to collect any required permissions to charge the payment method later.



1016
1017
1018
# File 'lib/stripe/resources/setup_intent.rb', line 1016

def self.create(params = {}, opts = {})
  request_stripe_object(method: :post, path: "/v1/setup_intents", params: params, opts: opts)
end

.field_remappingsObject



1068
1069
1070
# File 'lib/stripe/resources/setup_intent.rb', line 1068

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
# File 'lib/stripe/resources/setup_intent.rb', line 1055

def self.inner_class_types
  @inner_class_types = {
    automatic_payment_methods: AutomaticPaymentMethods,
    last_setup_error: LastSetupError,
    managed_payments: ManagedPayments,
    next_action: NextAction,
    payment_method_configuration_details: PaymentMethodConfigurationDetails,
    payment_method_options: PaymentMethodOptions,
    redaction: Redaction,
    setup_details: SetupDetails,
  }
end

.list(params = {}, opts = {}) ⇒ Object

Returns a list of SetupIntents.



1021
1022
1023
# File 'lib/stripe/resources/setup_intent.rb', line 1021

def self.list(params = {}, opts = {})
  request_stripe_object(method: :get, path: "/v1/setup_intents", params: params, opts: opts)
end

.object_nameObject



32
33
34
# File 'lib/stripe/resources/setup_intent.rb', line 32

def self.object_name
  "setup_intent"
end

.update(intent, params = {}, opts = {}) ⇒ Object

Updates a SetupIntent object.



1026
1027
1028
1029
1030
1031
1032
1033
# File 'lib/stripe/resources/setup_intent.rb', line 1026

def self.update(intent, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/setup_intents/%<intent>s", { intent: CGI.escape(intent) }),
    params: params,
    opts: opts
  )
end

.verify_microdeposits(intent, params = {}, opts = {}) ⇒ Object

Verifies microdeposits on a SetupIntent object.



1046
1047
1048
1049
1050
1051
1052
1053
# File 'lib/stripe/resources/setup_intent.rb', line 1046

def self.verify_microdeposits(intent, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/setup_intents/%<intent>s/verify_microdeposits", { intent: CGI.escape(intent) }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#cancel(params = {}, opts = {}) ⇒ Object

You can cancel a SetupIntent object when it's in one of these statuses: requires_payment_method, requires_confirmation, or requires_action.

After you cancel it, setup is abandoned and any operations on the SetupIntent fail with an error. You can't cancel the SetupIntent for a Checkout Session. Expire the Checkout Session instead.



945
946
947
948
949
950
951
952
# File 'lib/stripe/resources/setup_intent.rb', line 945

def cancel(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/setup_intents/%<intent>s/cancel", { intent: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#confirm(params = {}, opts = {}) ⇒ Object

Confirm that your customer intends to set up the current or provided payment method. For example, you would confirm a SetupIntent when a customer hits the “Save” button on a payment method management page on your website.

If the selected payment method does not require any additional steps from the customer, the SetupIntent will transition to the succeeded status.

Otherwise, it will transition to the requires_action status and suggest additional actions via next_action. If setup fails, the SetupIntent will transition to the requires_payment_method status or the canceled status if the confirmation limit is reached.



980
981
982
983
984
985
986
987
# File 'lib/stripe/resources/setup_intent.rb', line 980

def confirm(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/setup_intents/%<intent>s/confirm", { intent: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#verify_microdeposits(params = {}, opts = {}) ⇒ Object

Verifies microdeposits on a SetupIntent object.



1036
1037
1038
1039
1040
1041
1042
1043
# File 'lib/stripe/resources/setup_intent.rb', line 1036

def verify_microdeposits(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/setup_intents/%<intent>s/verify_microdeposits", { intent: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end