Class: Stripe::SetupIntent::CancelParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntent::CancelParams
- Defined in:
- lib/stripe/resources/setup_intent.rb
Instance Attribute Summary collapse
-
#cancellation_reason ⇒ Object
Reason for canceling this SetupIntent.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(cancellation_reason: nil, expand: nil) ⇒ CancelParams
constructor
A new instance of CancelParams.
Methods inherited from RequestParams
Constructor Details
#initialize(cancellation_reason: nil, expand: nil) ⇒ CancelParams
Returns a new instance of CancelParams.
2694 2695 2696 2697 |
# File 'lib/stripe/resources/setup_intent.rb', line 2694 def initialize(cancellation_reason: nil, expand: nil) @cancellation_reason = cancellation_reason @expand = end |
Instance Attribute Details
#cancellation_reason ⇒ Object
Reason for canceling this SetupIntent. Possible values are: ‘abandoned`, `requested_by_customer`, or `duplicate`
2690 2691 2692 |
# File 'lib/stripe/resources/setup_intent.rb', line 2690 def cancellation_reason @cancellation_reason end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2692 2693 2694 |
# File 'lib/stripe/resources/setup_intent.rb', line 2692 def @expand end |