Class: Stripe::SetupIntent::ConfirmParams::MandateData::CustomerAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Defined Under Namespace

Classes: Offline, Online

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(accepted_at: nil, offline: nil, online: nil, type: nil) ⇒ CustomerAcceptance

Returns a new instance of CustomerAcceptance.



3352
3353
3354
3355
3356
3357
# File 'lib/stripe/resources/setup_intent.rb', line 3352

def initialize(accepted_at: nil, offline: nil, online: nil, type: nil)
  @accepted_at = accepted_at
  @offline = offline
  @online = online
  @type = type
end

Instance Attribute Details

#accepted_atObject

The time at which the customer accepted the Mandate.



3344
3345
3346
# File 'lib/stripe/resources/setup_intent.rb', line 3344

def accepted_at
  @accepted_at
end

#offlineObject

If this is a Mandate accepted offline, this hash contains details about the offline acceptance.



3346
3347
3348
# File 'lib/stripe/resources/setup_intent.rb', line 3346

def offline
  @offline
end

#onlineObject

If this is a Mandate accepted online, this hash contains details about the online acceptance.



3348
3349
3350
# File 'lib/stripe/resources/setup_intent.rb', line 3348

def online
  @online
end

#typeObject

The type of customer acceptance information included with the Mandate. One of ‘online` or `offline`.



3350
3351
3352
# File 'lib/stripe/resources/setup_intent.rb', line 3350

def type
  @type
end