Class: Stripe::SetupIntent::ConfirmParams::MandateData::CustomerAcceptance::Online

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(ip_address: nil, user_agent: nil) ⇒ Online

Returns a new instance of Online.



3338
3339
3340
3341
# File 'lib/stripe/resources/setup_intent.rb', line 3338

def initialize(ip_address: nil, user_agent: nil)
  @ip_address = ip_address
  @user_agent = user_agent
end

Instance Attribute Details

#ip_addressObject

The IP address from which the Mandate was accepted by the customer.



3334
3335
3336
# File 'lib/stripe/resources/setup_intent.rb', line 3334

def ip_address
  @ip_address
end

#user_agentObject

The user agent of the browser from which the Mandate was accepted by the customer.



3336
3337
3338
# File 'lib/stripe/resources/setup_intent.rb', line 3336

def user_agent
  @user_agent
end