Class: Stripe::SetupIntent::ConfirmParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



3581
3582
3583
3584
3585
3586
3587
3588
3589
3590
3591
3592
3593
3594
3595
# File 'lib/stripe/resources/setup_intent.rb', line 3581

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



3569
3570
3571
# File 'lib/stripe/resources/setup_intent.rb', line 3569

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



3571
3572
3573
# File 'lib/stripe/resources/setup_intent.rb', line 3571

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



3573
3574
3575
# File 'lib/stripe/resources/setup_intent.rb', line 3573

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



3575
3576
3577
# File 'lib/stripe/resources/setup_intent.rb', line 3575

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



3577
3578
3579
# File 'lib/stripe/resources/setup_intent.rb', line 3577

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



3579
3580
3581
# File 'lib/stripe/resources/setup_intent.rb', line 3579

def suffix
  @suffix
end