Class: Stripe::SetupIntent::ConfirmParams::PaymentMethodData::Sofort
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntent::ConfirmParams::PaymentMethodData::Sofort
- Defined in:
- lib/stripe/resources/setup_intent.rb
Instance Attribute Summary collapse
-
#country ⇒ Object
Two-letter ISO code representing the country the bank account is located in.
Instance Method Summary collapse
-
#initialize(country: nil) ⇒ Sofort
constructor
A new instance of Sofort.
Methods inherited from RequestParams
Constructor Details
#initialize(country: nil) ⇒ Sofort
Returns a new instance of Sofort.
3073 3074 3075 |
# File 'lib/stripe/resources/setup_intent.rb', line 3073 def initialize(country: nil) @country = country end |
Instance Attribute Details
#country ⇒ Object
Two-letter ISO code representing the country the bank account is located in.
3071 3072 3073 |
# File 'lib/stripe/resources/setup_intent.rb', line 3071 def country @country end |