Class: Stripe::SetupIntent::ConfirmParams::PaymentMethodData::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntent::ConfirmParams::PaymentMethodData::UsBankAccount
- Defined in:
- lib/stripe/resources/setup_intent.rb
Instance Attribute Summary collapse
-
#account_holder_type ⇒ Object
Account holder type: individual or company.
-
#account_number ⇒ Object
Account number of the bank account.
-
#account_type ⇒ Object
Account type: checkings or savings.
-
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
-
#routing_number ⇒ Object
Routing number of the bank account.
Instance Method Summary collapse
-
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
3716 3717 3718 3719 3720 3721 3722 3723 3724 3725 3726 3727 3728 |
# File 'lib/stripe/resources/setup_intent.rb', line 3716 def initialize( account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil ) @account_holder_type = account_holder_type @account_number = account_number @account_type = account_type @financial_connections_account = financial_connections_account @routing_number = routing_number end |
Instance Attribute Details
#account_holder_type ⇒ Object
Account holder type: individual or company.
3706 3707 3708 |
# File 'lib/stripe/resources/setup_intent.rb', line 3706 def account_holder_type @account_holder_type end |
#account_number ⇒ Object
Account number of the bank account.
3708 3709 3710 |
# File 'lib/stripe/resources/setup_intent.rb', line 3708 def account_number @account_number end |
#account_type ⇒ Object
Account type: checkings or savings. Defaults to checking if omitted.
3710 3711 3712 |
# File 'lib/stripe/resources/setup_intent.rb', line 3710 def account_type @account_type end |
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
3712 3713 3714 |
# File 'lib/stripe/resources/setup_intent.rb', line 3712 def financial_connections_account @financial_connections_account end |
#routing_number ⇒ Object
Routing number of the bank account.
3714 3715 3716 |
# File 'lib/stripe/resources/setup_intent.rb', line 3714 def routing_number @routing_number end |