Class: Stripe::SetupIntent::ConfirmParams::PaymentMethodOptions::AcssDebit::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(custom_mandate_url: nil, default_for: nil, interval_description: nil, payment_schedule: nil, transaction_type: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



3722
3723
3724
3725
3726
3727
3728
3729
3730
3731
3732
3733
3734
# File 'lib/stripe/resources/setup_intent.rb', line 3722

def initialize(
  custom_mandate_url: nil,
  default_for: nil,
  interval_description: nil,
  payment_schedule: nil,
  transaction_type: nil
)
  @custom_mandate_url = custom_mandate_url
  @default_for = default_for
  @interval_description = interval_description
  @payment_schedule = payment_schedule
  @transaction_type = transaction_type
end

Instance Attribute Details

#custom_mandate_urlObject

A URL for custom mandate text to render during confirmation step. The URL will be rendered with additional GET parameters ‘payment_intent` and `payment_intent_client_secret` when confirming a Payment Intent, or `setup_intent` and `setup_intent_client_secret` when confirming a Setup Intent.



3712
3713
3714
# File 'lib/stripe/resources/setup_intent.rb', line 3712

def custom_mandate_url
  @custom_mandate_url
end

#default_forObject

List of Stripe products where this mandate can be selected automatically.



3714
3715
3716
# File 'lib/stripe/resources/setup_intent.rb', line 3714

def default_for
  @default_for
end

#interval_descriptionObject

Description of the mandate interval. Only required if ‘payment_schedule’ parameter is ‘interval’ or ‘combined’.



3716
3717
3718
# File 'lib/stripe/resources/setup_intent.rb', line 3716

def interval_description
  @interval_description
end

#payment_scheduleObject

Payment schedule for the mandate.



3718
3719
3720
# File 'lib/stripe/resources/setup_intent.rb', line 3718

def payment_schedule
  @payment_schedule
end

#transaction_typeObject

Transaction type of the mandate.



3720
3721
3722
# File 'lib/stripe/resources/setup_intent.rb', line 3720

def transaction_type
  @transaction_type
end