Class: Stripe::SetupIntent::ConfirmParams::PaymentMethodOptions::Klarna

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Defined Under Namespace

Classes: OnDemand, Subscription

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(currency: nil, on_demand: nil, preferred_locale: nil, subscriptions: nil) ⇒ Klarna

Returns a new instance of Klarna.



4269
4270
4271
4272
4273
4274
# File 'lib/stripe/resources/setup_intent.rb', line 4269

def initialize(currency: nil, on_demand: nil, preferred_locale: nil, subscriptions: nil)
  @currency = currency
  @on_demand = on_demand
  @preferred_locale = preferred_locale
  @subscriptions = subscriptions
end

Instance Attribute Details

#currencyObject

The currency of the SetupIntent. Three letter ISO currency code.



4261
4262
4263
# File 'lib/stripe/resources/setup_intent.rb', line 4261

def currency
  @currency
end

#on_demandObject

On-demand details if setting up a payment method for on-demand payments.



4263
4264
4265
# File 'lib/stripe/resources/setup_intent.rb', line 4263

def on_demand
  @on_demand
end

#preferred_localeObject

Preferred language of the Klarna authorization page that the customer is redirected to



4265
4266
4267
# File 'lib/stripe/resources/setup_intent.rb', line 4265

def preferred_locale
  @preferred_locale
end

#subscriptionsObject

Subscription details if setting up or charging a subscription



4267
4268
4269
# File 'lib/stripe/resources/setup_intent.rb', line 4267

def subscriptions
  @subscriptions
end