Class: Stripe::SetupIntent::ConfirmParams::PaymentMethodOptions::Klarna::Subscription
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntent::ConfirmParams::PaymentMethodOptions::Klarna::Subscription
- Defined in:
- lib/stripe/resources/setup_intent.rb
Defined Under Namespace
Classes: NextBilling
Instance Attribute Summary collapse
-
#interval ⇒ Object
Unit of time between subscription charges.
-
#interval_count ⇒ Object
The number of intervals (specified in the ‘interval` attribute) between subscription charges.
-
#name ⇒ Object
Name for subscription.
-
#next_billing ⇒ Object
Describes the upcoming charge for this subscription.
-
#reference ⇒ Object
A non-customer-facing reference to correlate subscription charges in the Klarna app.
Instance Method Summary collapse
-
#initialize(interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil) ⇒ Subscription
constructor
A new instance of Subscription.
Methods inherited from RequestParams
Constructor Details
#initialize(interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil) ⇒ Subscription
Returns a new instance of Subscription.
3827 3828 3829 3830 3831 3832 3833 3834 3835 3836 3837 3838 3839 |
# File 'lib/stripe/resources/setup_intent.rb', line 3827 def initialize( interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil ) @interval = interval @interval_count = interval_count @name = name @next_billing = next_billing @reference = reference end |
Instance Attribute Details
#interval ⇒ Object
Unit of time between subscription charges.
3817 3818 3819 |
# File 'lib/stripe/resources/setup_intent.rb', line 3817 def interval @interval end |
#interval_count ⇒ Object
The number of intervals (specified in the ‘interval` attribute) between subscription charges. For example, `interval=month` and `interval_count=3` charges every 3 months.
3819 3820 3821 |
# File 'lib/stripe/resources/setup_intent.rb', line 3819 def interval_count @interval_count end |
#name ⇒ Object
Name for subscription.
3821 3822 3823 |
# File 'lib/stripe/resources/setup_intent.rb', line 3821 def name @name end |
#next_billing ⇒ Object
Describes the upcoming charge for this subscription.
3823 3824 3825 |
# File 'lib/stripe/resources/setup_intent.rb', line 3823 def next_billing @next_billing end |
#reference ⇒ Object
A non-customer-facing reference to correlate subscription charges in the Klarna app. Use a value that persists across subscription charges.
3825 3826 3827 |
# File 'lib/stripe/resources/setup_intent.rb', line 3825 def reference @reference end |