Class: Stripe::SetupIntent::ConfirmParams::PaymentMethodOptions::Paypal

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_agreement_id: nil, currency: nil, subsellers: nil) ⇒ Paypal

Returns a new instance of Paypal.



3875
3876
3877
3878
3879
# File 'lib/stripe/resources/setup_intent.rb', line 3875

def initialize(billing_agreement_id: nil, currency: nil, subsellers: nil)
  @billing_agreement_id = billing_agreement_id
  @currency = currency
  @subsellers = subsellers
end

Instance Attribute Details

#billing_agreement_idObject

The PayPal Billing Agreement ID (BAID). This is an ID generated by PayPal which represents the mandate between the merchant and the customer.



3869
3870
3871
# File 'lib/stripe/resources/setup_intent.rb', line 3869

def billing_agreement_id
  @billing_agreement_id
end

#currencyObject

Attribute for param field currency



3871
3872
3873
# File 'lib/stripe/resources/setup_intent.rb', line 3871

def currency
  @currency
end

#subsellersObject

The Stripe connected account IDs of the sellers on the platform for this transaction (optional). Only allowed when [separate charges and transfers](stripe.com/docs/connect/separate-charges-and-transfers) are used.



3873
3874
3875
# File 'lib/stripe/resources/setup_intent.rb', line 3873

def subsellers
  @subsellers
end