Class: Stripe::SetupIntent::ConfirmParams::PaymentMethodOptions::UsBankAccount::FinancialConnections

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Defined Under Namespace

Classes: Filters, ManualEntry

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections

Returns a new instance of FinancialConnections.



4441
4442
4443
4444
4445
4446
4447
4448
4449
4450
4451
4452
4453
# File 'lib/stripe/resources/setup_intent.rb', line 4441

def initialize(
  filters: nil,
  manual_entry: nil,
  permissions: nil,
  prefetch: nil,
  return_url: nil
)
  @filters = filters
  @manual_entry = manual_entry
  @permissions = permissions
  @prefetch = prefetch
  @return_url = return_url
end

Instance Attribute Details

#filtersObject

Provide filters for the linked accounts that the customer can select for the payment method.



4431
4432
4433
# File 'lib/stripe/resources/setup_intent.rb', line 4431

def filters
  @filters
end

#manual_entryObject

Customize manual entry behavior



4433
4434
4435
# File 'lib/stripe/resources/setup_intent.rb', line 4433

def manual_entry
  @manual_entry
end

#permissionsObject

The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.



4435
4436
4437
# File 'lib/stripe/resources/setup_intent.rb', line 4435

def permissions
  @permissions
end

#prefetchObject

List of data features that you would like to retrieve upon account creation.



4437
4438
4439
# File 'lib/stripe/resources/setup_intent.rb', line 4437

def prefetch
  @prefetch
end

#return_urlObject

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



4439
4440
4441
# File 'lib/stripe/resources/setup_intent.rb', line 4439

def return_url
  @return_url
end