Class: Stripe::SetupIntent::CreateParams::MandateData::CustomerAcceptance::Online
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntent::CreateParams::MandateData::CustomerAcceptance::Online
- Defined in:
- lib/stripe/resources/setup_intent.rb
Instance Attribute Summary collapse
-
#ip_address ⇒ Object
The IP address from which the Mandate was accepted by the customer.
-
#user_agent ⇒ Object
The user agent of the browser from which the Mandate was accepted by the customer.
Instance Method Summary collapse
-
#initialize(ip_address: nil, user_agent: nil) ⇒ Online
constructor
A new instance of Online.
Methods inherited from RequestParams
Constructor Details
#initialize(ip_address: nil, user_agent: nil) ⇒ Online
Returns a new instance of Online.
422 423 424 425 |
# File 'lib/stripe/resources/setup_intent.rb', line 422 def initialize(ip_address: nil, user_agent: nil) @ip_address = ip_address @user_agent = user_agent end |
Instance Attribute Details
#ip_address ⇒ Object
The IP address from which the Mandate was accepted by the customer.
418 419 420 |
# File 'lib/stripe/resources/setup_intent.rb', line 418 def ip_address @ip_address end |
#user_agent ⇒ Object
The user agent of the browser from which the Mandate was accepted by the customer.
420 421 422 |
# File 'lib/stripe/resources/setup_intent.rb', line 420 def user_agent @user_agent end |