Class: Stripe::SetupIntent::CreateParams::PaymentMethodData::BacsDebit
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntent::CreateParams::PaymentMethodData::BacsDebit
- Defined in:
- lib/stripe/resources/setup_intent.rb
Instance Attribute Summary collapse
-
#account_number ⇒ Object
Account number of the bank account that the funds will be debited from.
-
#sort_code ⇒ Object
Sort code of the bank account.
Instance Method Summary collapse
-
#initialize(account_number: nil, sort_code: nil) ⇒ BacsDebit
constructor
A new instance of BacsDebit.
Methods inherited from RequestParams
Constructor Details
#initialize(account_number: nil, sort_code: nil) ⇒ BacsDebit
Returns a new instance of BacsDebit.
459 460 461 462 |
# File 'lib/stripe/resources/setup_intent.rb', line 459 def initialize(account_number: nil, sort_code: nil) @account_number = account_number @sort_code = sort_code end |
Instance Attribute Details
#account_number ⇒ Object
Account number of the bank account that the funds will be debited from.
455 456 457 |
# File 'lib/stripe/resources/setup_intent.rb', line 455 def account_number @account_number end |
#sort_code ⇒ Object
Sort code of the bank account. (e.g., ‘10-20-30`)
457 458 459 |
# File 'lib/stripe/resources/setup_intent.rb', line 457 def sort_code @sort_code end |