Class: Stripe::SetupIntent::CreateParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
# File 'lib/stripe/resources/setup_intent.rb', line 713

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



701
702
703
# File 'lib/stripe/resources/setup_intent.rb', line 701

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



703
704
705
# File 'lib/stripe/resources/setup_intent.rb', line 703

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



705
706
707
# File 'lib/stripe/resources/setup_intent.rb', line 705

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



707
708
709
# File 'lib/stripe/resources/setup_intent.rb', line 707

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



709
710
711
# File 'lib/stripe/resources/setup_intent.rb', line 709

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



711
712
713
# File 'lib/stripe/resources/setup_intent.rb', line 711

def suffix
  @suffix
end