Class: Stripe::SetupIntent::CreateParams::PaymentMethodData::Sofort
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntent::CreateParams::PaymentMethodData::Sofort
- Defined in:
- lib/stripe/resources/setup_intent.rb
Instance Attribute Summary collapse
-
#country ⇒ Object
Two-letter ISO code representing the country the bank account is located in.
Instance Method Summary collapse
-
#initialize(country: nil) ⇒ Sofort
constructor
A new instance of Sofort.
Methods inherited from RequestParams
Constructor Details
#initialize(country: nil) ⇒ Sofort
Returns a new instance of Sofort.
673 674 675 |
# File 'lib/stripe/resources/setup_intent.rb', line 673 def initialize(country: nil) @country = country end |
Instance Attribute Details
#country ⇒ Object
Two-letter ISO code representing the country the bank account is located in.
671 672 673 |
# File 'lib/stripe/resources/setup_intent.rb', line 671 def country @country end |