Class: Stripe::SetupIntent::CreateParams::PaymentMethodOptions::Klarna

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Defined Under Namespace

Classes: OnDemand, Subscription

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(currency: nil, on_demand: nil, preferred_locale: nil, subscriptions: nil) ⇒ Klarna

Returns a new instance of Klarna.



1401
1402
1403
1404
1405
1406
# File 'lib/stripe/resources/setup_intent.rb', line 1401

def initialize(currency: nil, on_demand: nil, preferred_locale: nil, subscriptions: nil)
  @currency = currency
  @on_demand = on_demand
  @preferred_locale = preferred_locale
  @subscriptions = subscriptions
end

Instance Attribute Details

#currencyObject

The currency of the SetupIntent. Three letter ISO currency code.



1393
1394
1395
# File 'lib/stripe/resources/setup_intent.rb', line 1393

def currency
  @currency
end

#on_demandObject

On-demand details if setting up a payment method for on-demand payments.



1395
1396
1397
# File 'lib/stripe/resources/setup_intent.rb', line 1395

def on_demand
  @on_demand
end

#preferred_localeObject

Preferred language of the Klarna authorization page that the customer is redirected to



1397
1398
1399
# File 'lib/stripe/resources/setup_intent.rb', line 1397

def preferred_locale
  @preferred_locale
end

#subscriptionsObject

Subscription details if setting up or charging a subscription



1399
1400
1401
# File 'lib/stripe/resources/setup_intent.rb', line 1399

def subscriptions
  @subscriptions
end