Class: Stripe::SetupIntent::CreateParams::PaymentMethodOptions::Klarna::Subscription
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntent::CreateParams::PaymentMethodOptions::Klarna::Subscription
- Defined in:
- lib/stripe/resources/setup_intent.rb
Defined Under Namespace
Classes: NextBilling
Instance Attribute Summary collapse
-
#interval ⇒ Object
Unit of time between subscription charges.
-
#interval_count ⇒ Object
The number of intervals (specified in the ‘interval` attribute) between subscription charges.
-
#name ⇒ Object
Name for subscription.
-
#next_billing ⇒ Object
Describes the upcoming charge for this subscription.
-
#reference ⇒ Object
A non-customer-facing reference to correlate subscription charges in the Klarna app.
Instance Method Summary collapse
-
#initialize(interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil) ⇒ Subscription
constructor
A new instance of Subscription.
Methods inherited from RequestParams
Constructor Details
#initialize(interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil) ⇒ Subscription
Returns a new instance of Subscription.
1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 |
# File 'lib/stripe/resources/setup_intent.rb', line 1338 def initialize( interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil ) @interval = interval @interval_count = interval_count @name = name @next_billing = next_billing @reference = reference end |
Instance Attribute Details
#interval ⇒ Object
Unit of time between subscription charges.
1328 1329 1330 |
# File 'lib/stripe/resources/setup_intent.rb', line 1328 def interval @interval end |
#interval_count ⇒ Object
The number of intervals (specified in the ‘interval` attribute) between subscription charges. For example, `interval=month` and `interval_count=3` charges every 3 months.
1330 1331 1332 |
# File 'lib/stripe/resources/setup_intent.rb', line 1330 def interval_count @interval_count end |
#name ⇒ Object
Name for subscription.
1332 1333 1334 |
# File 'lib/stripe/resources/setup_intent.rb', line 1332 def name @name end |
#next_billing ⇒ Object
Describes the upcoming charge for this subscription.
1334 1335 1336 |
# File 'lib/stripe/resources/setup_intent.rb', line 1334 def next_billing @next_billing end |
#reference ⇒ Object
A non-customer-facing reference to correlate subscription charges in the Klarna app. Use a value that persists across subscription charges.
1336 1337 1338 |
# File 'lib/stripe/resources/setup_intent.rb', line 1336 def reference @reference end |