Class: Stripe::SetupIntent::CreateParams::PaymentMethodOptions::Klarna::Subscription::NextBilling

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, date: nil) ⇒ NextBilling

Returns a new instance of NextBilling.



1185
1186
1187
1188
# File 'lib/stripe/resources/setup_intent.rb', line 1185

def initialize(amount: nil, date: nil)
  @amount = amount
  @date = date
end

Instance Attribute Details

#amountObject

The amount of the next charge for the subscription.



1181
1182
1183
# File 'lib/stripe/resources/setup_intent.rb', line 1181

def amount
  @amount
end

#dateObject

The date of the next charge for the subscription in YYYY-MM-DD format.



1183
1184
1185
# File 'lib/stripe/resources/setup_intent.rb', line 1183

def date
  @date
end