Class: Stripe::SetupIntent::CreateParams::PaymentMethodOptions::Paypal
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntent::CreateParams::PaymentMethodOptions::Paypal
- Defined in:
- lib/stripe/resources/setup_intent.rb
Instance Attribute Summary collapse
-
#billing_agreement_id ⇒ Object
The PayPal Billing Agreement ID (BAID).
-
#currency ⇒ Object
Attribute for param field currency.
-
#subsellers ⇒ Object
The Stripe connected account IDs of the sellers on the platform for this transaction (optional).
Instance Method Summary collapse
-
#initialize(billing_agreement_id: nil, currency: nil, subsellers: nil) ⇒ Paypal
constructor
A new instance of Paypal.
Methods inherited from RequestParams
Constructor Details
#initialize(billing_agreement_id: nil, currency: nil, subsellers: nil) ⇒ Paypal
Returns a new instance of Paypal.
1703 1704 1705 1706 1707 |
# File 'lib/stripe/resources/setup_intent.rb', line 1703 def initialize(billing_agreement_id: nil, currency: nil, subsellers: nil) @billing_agreement_id = billing_agreement_id @currency = currency @subsellers = subsellers end |
Instance Attribute Details
#billing_agreement_id ⇒ Object
The PayPal Billing Agreement ID (BAID). This is an ID generated by PayPal which represents the mandate between the merchant and the customer.
1697 1698 1699 |
# File 'lib/stripe/resources/setup_intent.rb', line 1697 def billing_agreement_id @billing_agreement_id end |
#currency ⇒ Object
Attribute for param field currency
1699 1700 1701 |
# File 'lib/stripe/resources/setup_intent.rb', line 1699 def currency @currency end |
#subsellers ⇒ Object
The Stripe connected account IDs of the sellers on the platform for this transaction (optional). Only allowed when [separate charges and transfers](stripe.com/docs/connect/separate-charges-and-transfers) are used.
1701 1702 1703 |
# File 'lib/stripe/resources/setup_intent.rb', line 1701 def subsellers @subsellers end |