Class: Stripe::SetupIntent::CreateParams::PaymentMethodOptions::Payto::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, end_date: nil, payment_schedule: nil, payments_per_period: nil, purpose: nil, start_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
# File 'lib/stripe/resources/setup_intent.rb', line 1727

def initialize(
  amount: nil,
  amount_type: nil,
  end_date: nil,
  payment_schedule: nil,
  payments_per_period: nil,
  purpose: nil,
  start_date: nil
)
  @amount = amount
  @amount_type = amount_type
  @end_date = end_date
  @payment_schedule = payment_schedule
  @payments_per_period = payments_per_period
  @purpose = purpose
  @start_date = start_date
end

Instance Attribute Details

#amountObject

Amount that will be collected. It is required when ‘amount_type` is `fixed`.



1713
1714
1715
# File 'lib/stripe/resources/setup_intent.rb', line 1713

def amount
  @amount
end

#amount_typeObject

The type of amount that will be collected. The amount charged must be exact or up to the value of ‘amount` param for `fixed` or `maximum` type respectively.



1715
1716
1717
# File 'lib/stripe/resources/setup_intent.rb', line 1715

def amount_type
  @amount_type
end

#end_dateObject

Date, in YYYY-MM-DD format, after which payments will not be collected. Defaults to no end date.



1717
1718
1719
# File 'lib/stripe/resources/setup_intent.rb', line 1717

def end_date
  @end_date
end

#payment_scheduleObject

The periodicity at which payments will be collected.



1719
1720
1721
# File 'lib/stripe/resources/setup_intent.rb', line 1719

def payment_schedule
  @payment_schedule
end

#payments_per_periodObject

The number of payments that will be made during a payment period. Defaults to 1 except for when ‘payment_schedule` is `adhoc`. In that case, it defaults to no limit.



1721
1722
1723
# File 'lib/stripe/resources/setup_intent.rb', line 1721

def payments_per_period
  @payments_per_period
end

#purposeObject

The purpose for which payments are made. Defaults to retail.



1723
1724
1725
# File 'lib/stripe/resources/setup_intent.rb', line 1723

def purpose
  @purpose
end

#start_dateObject

Date, in YYYY-MM-DD format, from which payments will be collected. Defaults to confirmation time.



1725
1726
1727
# File 'lib/stripe/resources/setup_intent.rb', line 1725

def start_date
  @start_date
end