Class: Stripe::SetupIntent::CreateParams::PaymentMethodOptions::UsBankAccount::FinancialConnections

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Defined Under Namespace

Classes: Filters, ManualEntry

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections

Returns a new instance of FinancialConnections.



1850
1851
1852
1853
1854
1855
1856
1857
1858
1859
1860
1861
1862
# File 'lib/stripe/resources/setup_intent.rb', line 1850

def initialize(
  filters: nil,
  manual_entry: nil,
  permissions: nil,
  prefetch: nil,
  return_url: nil
)
  @filters = filters
  @manual_entry = manual_entry
  @permissions = permissions
  @prefetch = prefetch
  @return_url = return_url
end

Instance Attribute Details

#filtersObject

Provide filters for the linked accounts that the customer can select for the payment method.



1840
1841
1842
# File 'lib/stripe/resources/setup_intent.rb', line 1840

def filters
  @filters
end

#manual_entryObject

Customize manual entry behavior



1842
1843
1844
# File 'lib/stripe/resources/setup_intent.rb', line 1842

def manual_entry
  @manual_entry
end

#permissionsObject

The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.



1844
1845
1846
# File 'lib/stripe/resources/setup_intent.rb', line 1844

def permissions
  @permissions
end

#prefetchObject

List of data features that you would like to retrieve upon account creation.



1846
1847
1848
# File 'lib/stripe/resources/setup_intent.rb', line 1846

def prefetch
  @prefetch
end

#return_urlObject

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



1848
1849
1850
# File 'lib/stripe/resources/setup_intent.rb', line 1848

def return_url
  @return_url
end