Class: Stripe::SetupIntent::CreateParams::PaymentMethodOptions::UsBankAccount::MandateOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntent::CreateParams::PaymentMethodOptions::UsBankAccount::MandateOptions
- Defined in:
- lib/stripe/resources/setup_intent.rb
Instance Attribute Summary collapse
-
#collection_method ⇒ Object
The method used to collect offline mandate customer acceptance.
Instance Method Summary collapse
-
#initialize(collection_method: nil) ⇒ MandateOptions
constructor
A new instance of MandateOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(collection_method: nil) ⇒ MandateOptions
Returns a new instance of MandateOptions.
1505 1506 1507 |
# File 'lib/stripe/resources/setup_intent.rb', line 1505 def initialize(collection_method: nil) @collection_method = collection_method end |
Instance Attribute Details
#collection_method ⇒ Object
The method used to collect offline mandate customer acceptance.
1503 1504 1505 |
# File 'lib/stripe/resources/setup_intent.rb', line 1503 def collection_method @collection_method end |