Class: Stripe::SetupIntent::LastSetupError

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/setup_intent.rb

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Class Method Summary collapse

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#advice_codeObject (readonly)

For card errors resulting from a card issuer decline, a short string indicating how to proceed with an error if they provide one.



55
56
57
# File 'lib/stripe/resources/setup_intent.rb', line 55

def advice_code
  @advice_code
end

#chargeObject (readonly)

For card errors, the ID of the failed charge.



57
58
59
# File 'lib/stripe/resources/setup_intent.rb', line 57

def charge
  @charge
end

#codeObject (readonly)

For some errors that could be handled programmatically, a short string indicating the error code reported.



59
60
61
# File 'lib/stripe/resources/setup_intent.rb', line 59

def code
  @code
end

#decline_codeObject (readonly)

For card errors resulting from a card issuer decline, a short string indicating the card issuer's reason for the decline if they provide one.



61
62
63
# File 'lib/stripe/resources/setup_intent.rb', line 61

def decline_code
  @decline_code
end

#doc_urlObject (readonly)

A URL to more information about the error code reported.



63
64
65
# File 'lib/stripe/resources/setup_intent.rb', line 63

def doc_url
  @doc_url
end

#gift_card_operationObject (readonly)

A GiftCardOperation represents an operation performed on a third-party gift card, such as activation, reload, cashout, balance check, or void.



66
67
68
# File 'lib/stripe/resources/setup_intent.rb', line 66

def gift_card_operation
  @gift_card_operation
end

#messageObject (readonly)

A human-readable message providing more details about the error. For card errors, these messages can be shown to your users.



68
69
70
# File 'lib/stripe/resources/setup_intent.rb', line 68

def message
  @message
end

#network_advice_codeObject (readonly)

For card errors resulting from a card issuer decline, a 2 digit code which indicates the advice given to merchant by the card network on how to proceed with an error.



70
71
72
# File 'lib/stripe/resources/setup_intent.rb', line 70

def network_advice_code
  @network_advice_code
end

#network_decline_codeObject (readonly)

For payments declined by the network, an alphanumeric code which indicates the reason the payment failed.



72
73
74
# File 'lib/stripe/resources/setup_intent.rb', line 72

def network_decline_code
  @network_decline_code
end

#paramObject (readonly)

If the error is parameter-specific, the parameter related to the error. For example, you can use this to display a message near the correct form field.



74
75
76
# File 'lib/stripe/resources/setup_intent.rb', line 74

def param
  @param
end

#payment_intentObject (readonly)

A PaymentIntent guides you through the process of collecting a payment from your customer. We recommend that you create exactly one PaymentIntent for each order or customer session in your system. You can reference the PaymentIntent later to see the history of payment attempts for a particular session.

A PaymentIntent transitions through multiple statuses throughout its lifetime as it interfaces with Stripe.js to perform authentication flows and ultimately creates at most one successful charge.

Related guide: Payment Intents API



86
87
88
# File 'lib/stripe/resources/setup_intent.rb', line 86

def payment_intent
  @payment_intent
end

#payment_methodObject (readonly)

PaymentMethod objects represent your customer's payment instruments. You can use them with PaymentIntents to collect payments or save them to Customer objects to store instrument details for future payments.

Related guides: Payment Methods and More Payment Scenarios.



92
93
94
# File 'lib/stripe/resources/setup_intent.rb', line 92

def payment_method
  @payment_method
end

#payment_method_typeObject (readonly)

If the error is specific to the type of payment method, the payment method type that had a problem. This field is only populated for invoice-related errors.



94
95
96
# File 'lib/stripe/resources/setup_intent.rb', line 94

def payment_method_type
  @payment_method_type
end

#request_log_urlObject (readonly)

A URL to the request log entry in your dashboard.



96
97
98
# File 'lib/stripe/resources/setup_intent.rb', line 96

def request_log_url
  @request_log_url
end

#setup_intentObject (readonly)

A SetupIntent guides you through the process of setting up and saving a customer's payment credentials for future payments. For example, you can use a SetupIntent to set up and save your customer's card without immediately collecting a payment. Later, you can use PaymentIntents to drive the payment flow.

Create a SetupIntent when you're ready to collect your customer's payment credentials. Don't maintain long-lived, unconfirmed SetupIntents because they might not be valid. The SetupIntent transitions through multiple statuses as it guides you through the setup process.

Successful SetupIntents result in payment credentials that are optimized for future payments. For example, cardholders in certain regions might need to be run through Strong Customer Authentication during payment method collection to streamline later off-session payments. If you use the SetupIntent with a Customer, it automatically attaches the resulting payment method to that Customer after successful setup. We recommend using SetupIntents or setup_future_usage on PaymentIntents to save payment methods to prevent saving invalid or unoptimized payment methods.

By using SetupIntents, you can reduce friction for your customers, even as regulations change over time.

Related guide: Setup Intents API



118
119
120
# File 'lib/stripe/resources/setup_intent.rb', line 118

def setup_intent
  @setup_intent
end

#sourceObject (readonly)

Attribute for field source



120
121
122
# File 'lib/stripe/resources/setup_intent.rb', line 120

def source
  @source
end

#typeObject (readonly)

The type of error returned. One of api_error, card_error, idempotency_error, or invalid_request_error



122
123
124
# File 'lib/stripe/resources/setup_intent.rb', line 122

def type
  @type
end

Class Method Details

.field_remappingsObject



128
129
130
# File 'lib/stripe/resources/setup_intent.rb', line 128

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



124
125
126
# File 'lib/stripe/resources/setup_intent.rb', line 124

def self.inner_class_types
  @inner_class_types = {}
end