Class: Stripe::SetupIntent::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/setup_intent.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(attach_to_self: nil, created: nil, customer: nil, customer_account: nil, ending_before: nil, expand: nil, limit: nil, payment_method: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
# File 'lib/stripe/resources/setup_intent.rb', line 699

def initialize(
  attach_to_self: nil,
  created: nil,
  customer: nil,
  customer_account: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  payment_method: nil,
  starting_after: nil
)
  @attach_to_self = attach_to_self
  @created = created
  @customer = customer
  @customer_account = 
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @payment_method = payment_method
  @starting_after = starting_after
end

Instance Attribute Details

#attach_to_selfObject

If present, the SetupIntent’s payment method will be attached to the in-context Stripe Account.

It can only be used for this Stripe Account’s own money movement flows like InboundTransfer and OutboundTransfers. It cannot be set to true when setting up a PaymentMethod for a Customer, and defaults to false when attaching a PaymentMethod to a Customer.



681
682
683
# File 'lib/stripe/resources/setup_intent.rb', line 681

def attach_to_self
  @attach_to_self
end

#createdObject

A filter on the list, based on the object ‘created` field. The value can be a string with an integer Unix timestamp, or it can be a dictionary with a number of different query options.



683
684
685
# File 'lib/stripe/resources/setup_intent.rb', line 683

def created
  @created
end

#customerObject

Only return SetupIntents for the customer specified by this customer ID.



685
686
687
# File 'lib/stripe/resources/setup_intent.rb', line 685

def customer
  @customer
end

#customer_accountObject

Only return SetupIntents for the account specified by this customer ID.



687
688
689
# File 'lib/stripe/resources/setup_intent.rb', line 687

def 
  @customer_account
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



689
690
691
# File 'lib/stripe/resources/setup_intent.rb', line 689

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



691
692
693
# File 'lib/stripe/resources/setup_intent.rb', line 691

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



693
694
695
# File 'lib/stripe/resources/setup_intent.rb', line 693

def limit
  @limit
end

#payment_methodObject

Only return SetupIntents that associate with the specified payment method.



695
696
697
# File 'lib/stripe/resources/setup_intent.rb', line 695

def payment_method
  @payment_method
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



697
698
699
# File 'lib/stripe/resources/setup_intent.rb', line 697

def starting_after
  @starting_after
end