Class: Stripe::SetupIntent::NextAction::RedirectToUrl
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::SetupIntent::NextAction::RedirectToUrl
- Defined in:
- lib/stripe/resources/setup_intent.rb
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#return_url ⇒ Object
readonly
If the customer does not exit their browser while authenticating, they will be redirected to this specified URL after completion.
-
#url ⇒ Object
readonly
The URL you must redirect your customer to in order to authenticate.
Attributes inherited from Stripe::StripeObject
Class Method Summary collapse
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#return_url ⇒ Object (readonly)
If the customer does not exit their browser while authenticating, they will be redirected to this specified URL after completion.
200 201 202 |
# File 'lib/stripe/resources/setup_intent.rb', line 200 def return_url @return_url end |
#url ⇒ Object (readonly)
The URL you must redirect your customer to in order to authenticate.
202 203 204 |
# File 'lib/stripe/resources/setup_intent.rb', line 202 def url @url end |
Class Method Details
.field_remappings ⇒ Object
208 209 210 |
# File 'lib/stripe/resources/setup_intent.rb', line 208 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
204 205 206 |
# File 'lib/stripe/resources/setup_intent.rb', line 204 def self.inner_class_types @inner_class_types = {} end |