Class: Stripe::SetupIntent::NextAction::VerifyWithMicrodeposits

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/setup_intent.rb

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Method Summary

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#arrival_dateObject (readonly)

The timestamp when the microdeposits are expected to land.



159
160
161
# File 'lib/stripe/resources/setup_intent.rb', line 159

def arrival_date
  @arrival_date
end

#hosted_verification_urlObject (readonly)

The URL for the hosted verification page, which allows customers to verify their bank account.



162
163
164
# File 'lib/stripe/resources/setup_intent.rb', line 162

def hosted_verification_url
  @hosted_verification_url
end

#microdeposit_typeObject (readonly)

The type of the microdeposit sent to the customer. Used to distinguish between different verification methods.



165
166
167
# File 'lib/stripe/resources/setup_intent.rb', line 165

def microdeposit_type
  @microdeposit_type
end