Class: Stripe::SetupIntent::PaymentMethodOptions::AcssDebit::MandateOptions
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::SetupIntent::PaymentMethodOptions::AcssDebit::MandateOptions
- Defined in:
- lib/stripe/resources/setup_intent.rb
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#custom_mandate_url ⇒ Object
readonly
A URL for custom mandate text.
-
#default_for ⇒ Object
readonly
List of Stripe products where this mandate can be selected automatically.
-
#interval_description ⇒ Object
readonly
Description of the interval.
-
#payment_schedule ⇒ Object
readonly
Payment schedule for the mandate.
-
#transaction_type ⇒ Object
readonly
Transaction type of the mandate.
Attributes inherited from Stripe::StripeObject
Method Summary
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#custom_mandate_url ⇒ Object (readonly)
A URL for custom mandate text
195 196 197 |
# File 'lib/stripe/resources/setup_intent.rb', line 195 def custom_mandate_url @custom_mandate_url end |
#default_for ⇒ Object (readonly)
List of Stripe products where this mandate can be selected automatically.
198 199 200 |
# File 'lib/stripe/resources/setup_intent.rb', line 198 def default_for @default_for end |
#interval_description ⇒ Object (readonly)
Description of the interval. Only required if the ‘payment_schedule’ parameter is ‘interval’ or ‘combined’.
201 202 203 |
# File 'lib/stripe/resources/setup_intent.rb', line 201 def interval_description @interval_description end |
#payment_schedule ⇒ Object (readonly)
Payment schedule for the mandate.
204 205 206 |
# File 'lib/stripe/resources/setup_intent.rb', line 204 def payment_schedule @payment_schedule end |
#transaction_type ⇒ Object (readonly)
Transaction type of the mandate.
207 208 209 |
# File 'lib/stripe/resources/setup_intent.rb', line 207 def transaction_type @transaction_type end |