Class: Stripe::SetupIntent::PaymentMethodOptions::Card::MandateOptions

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/setup_intent.rb

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Class Method Summary collapse

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Amount to be charged for future payments, specified in the presentment currency.



423
424
425
# File 'lib/stripe/resources/setup_intent.rb', line 423

def amount
  @amount
end

#amount_typeObject (readonly)

One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.



425
426
427
# File 'lib/stripe/resources/setup_intent.rb', line 425

def amount_type
  @amount_type
end

#currencyObject (readonly)

Three-letter ISO currency code, in lowercase. Must be a supported currency.



427
428
429
# File 'lib/stripe/resources/setup_intent.rb', line 427

def currency
  @currency
end

#descriptionObject (readonly)

A description of the mandate or subscription that is meant to be displayed to the customer.



429
430
431
# File 'lib/stripe/resources/setup_intent.rb', line 429

def description
  @description
end

#end_dateObject (readonly)

End date of the mandate or subscription. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.



431
432
433
# File 'lib/stripe/resources/setup_intent.rb', line 431

def end_date
  @end_date
end

#intervalObject (readonly)

Specifies payment frequency. One of day, week, month, year, or sporadic.



433
434
435
# File 'lib/stripe/resources/setup_intent.rb', line 433

def interval
  @interval
end

#interval_countObject (readonly)

The number of intervals between payments. For example, interval=month and interval_count=3 indicates one payment every three months. Maximum of one year interval allowed (1 year, 12 months, or 52 weeks). This parameter is optional when interval=sporadic.



435
436
437
# File 'lib/stripe/resources/setup_intent.rb', line 435

def interval_count
  @interval_count
end

#referenceObject (readonly)

Unique identifier for the mandate or subscription.



437
438
439
# File 'lib/stripe/resources/setup_intent.rb', line 437

def reference
  @reference
end

#start_dateObject (readonly)

Start date of the mandate or subscription. Start date should not be lesser than yesterday.



439
440
441
# File 'lib/stripe/resources/setup_intent.rb', line 439

def start_date
  @start_date
end

#supported_typesObject (readonly)

Specifies the type of mandates supported. Possible values are india.



441
442
443
# File 'lib/stripe/resources/setup_intent.rb', line 441

def supported_types
  @supported_types
end

Class Method Details

.field_remappingsObject



447
448
449
# File 'lib/stripe/resources/setup_intent.rb', line 447

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



443
444
445
# File 'lib/stripe/resources/setup_intent.rb', line 443

def self.inner_class_types
  @inner_class_types = {}
end