Class: Stripe::SetupIntent::PaymentMethodOptions::Klarna
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::SetupIntent::PaymentMethodOptions::Klarna
- Defined in:
- lib/stripe/resources/setup_intent.rb
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#currency ⇒ Object
readonly
The currency of the setup intent.
-
#preferred_locale ⇒ Object
readonly
Preferred locale of the Klarna checkout page that the customer is redirected to.
Attributes inherited from Stripe::StripeObject
Method Summary
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#currency ⇒ Object (readonly)
The currency of the setup intent. Three letter ISO currency code.
234 235 236 |
# File 'lib/stripe/resources/setup_intent.rb', line 234 def currency @currency end |
#preferred_locale ⇒ Object (readonly)
Preferred locale of the Klarna checkout page that the customer is redirected to.
236 237 238 |
# File 'lib/stripe/resources/setup_intent.rb', line 236 def preferred_locale @preferred_locale end |