Class: Stripe::SetupIntent::PaymentMethodOptions::Paypal

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/setup_intent.rb

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Class Method Summary collapse

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#billing_agreement_idObject (readonly)

The PayPal Billing Agreement ID (BAID). This is an ID generated by PayPal which represents the mandate between the merchant and the customer.



488
489
490
# File 'lib/stripe/resources/setup_intent.rb', line 488

def billing_agreement_id
  @billing_agreement_id
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



490
491
492
# File 'lib/stripe/resources/setup_intent.rb', line 490

def currency
  @currency
end

#subsellersObject (readonly)

The Stripe connected account IDs of the sellers on the platform for this transaction (optional). Only allowed when [separate charges and transfers](stripe.com/docs/connect/separate-charges-and-transfers) are used.



492
493
494
# File 'lib/stripe/resources/setup_intent.rb', line 492

def subsellers
  @subsellers
end

Class Method Details

.field_remappingsObject



498
499
500
# File 'lib/stripe/resources/setup_intent.rb', line 498

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



494
495
496
# File 'lib/stripe/resources/setup_intent.rb', line 494

def self.inner_class_types
  @inner_class_types = {}
end