Class: Stripe::SetupIntent::PaymentMethodOptions::Pix::MandateOptions

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/setup_intent.rb

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Class Method Summary collapse

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Amount to be charged for future payments.



520
521
522
# File 'lib/stripe/resources/setup_intent.rb', line 520

def amount
  @amount
end

#amount_includes_iofObject (readonly)

Determines if the amount includes the IOF tax.



522
523
524
# File 'lib/stripe/resources/setup_intent.rb', line 522

def amount_includes_iof
  @amount_includes_iof
end

#amount_typeObject (readonly)

Type of amount.



524
525
526
# File 'lib/stripe/resources/setup_intent.rb', line 524

def amount_type
  @amount_type
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.



526
527
528
# File 'lib/stripe/resources/setup_intent.rb', line 526

def currency
  @currency
end

#end_dateObject (readonly)

Date when the mandate expires and no further payments will be charged, in ‘YYYY-MM-DD`.



528
529
530
# File 'lib/stripe/resources/setup_intent.rb', line 528

def end_date
  @end_date
end

#payment_scheduleObject (readonly)

Schedule at which the future payments will be charged.



530
531
532
# File 'lib/stripe/resources/setup_intent.rb', line 530

def payment_schedule
  @payment_schedule
end

#referenceObject (readonly)

Subscription name displayed to buyers in their bank app.



532
533
534
# File 'lib/stripe/resources/setup_intent.rb', line 532

def reference
  @reference
end

#start_dateObject (readonly)

Start date of the mandate, in ‘YYYY-MM-DD`.



534
535
536
# File 'lib/stripe/resources/setup_intent.rb', line 534

def start_date
  @start_date
end

Class Method Details

.field_remappingsObject



540
541
542
# File 'lib/stripe/resources/setup_intent.rb', line 540

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



536
537
538
# File 'lib/stripe/resources/setup_intent.rb', line 536

def self.inner_class_types
  @inner_class_types = {}
end