Class: Stripe::SetupIntent::PaymentMethodOptions::Upi::MandateOptions

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/setup_intent.rb

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Class Method Summary collapse

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Amount to be charged for future payments.



651
652
653
# File 'lib/stripe/resources/setup_intent.rb', line 651

def amount
  @amount
end

#amount_typeObject (readonly)

One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.



653
654
655
# File 'lib/stripe/resources/setup_intent.rb', line 653

def amount_type
  @amount_type
end

#descriptionObject (readonly)

A description of the mandate or subscription that is meant to be displayed to the customer.



655
656
657
# File 'lib/stripe/resources/setup_intent.rb', line 655

def description
  @description
end

#end_dateObject (readonly)

End date of the mandate or subscription.



657
658
659
# File 'lib/stripe/resources/setup_intent.rb', line 657

def end_date
  @end_date
end

Class Method Details

.field_remappingsObject



663
664
665
# File 'lib/stripe/resources/setup_intent.rb', line 663

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



659
660
661
# File 'lib/stripe/resources/setup_intent.rb', line 659

def self.inner_class_types
  @inner_class_types = {}
end