Class: Stripe::SetupIntent::PaymentMethodOptions::UsBankAccount::FinancialConnections

Inherits:
Stripe::StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Defined Under Namespace

Classes: Filters, ManualEntry

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Method Summary

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#filtersObject (readonly)

Attribute for field filters



297
298
299
# File 'lib/stripe/resources/setup_intent.rb', line 297

def filters
  @filters
end

#manual_entryObject (readonly)

Attribute for field manual_entry



299
300
301
# File 'lib/stripe/resources/setup_intent.rb', line 299

def manual_entry
  @manual_entry
end

#permissionsObject (readonly)

The list of permissions to request. The ‘payment_method` permission must be included.



301
302
303
# File 'lib/stripe/resources/setup_intent.rb', line 301

def permissions
  @permissions
end

#prefetchObject (readonly)

Data features requested to be retrieved upon account creation.



303
304
305
# File 'lib/stripe/resources/setup_intent.rb', line 303

def prefetch
  @prefetch
end

#return_urlObject (readonly)

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



305
306
307
# File 'lib/stripe/resources/setup_intent.rb', line 305

def return_url
  @return_url
end