Class: Stripe::SetupIntent::UpdateParams::PaymentMethodData::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntent::UpdateParams::PaymentMethodData::UsBankAccount
- Defined in:
- lib/stripe/resources/setup_intent.rb
Instance Attribute Summary collapse
-
#account_holder_type ⇒ Object
Account holder type: individual or company.
-
#account_number ⇒ Object
Account number of the bank account.
-
#account_type ⇒ Object
Account type: checkings or savings.
-
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
-
#routing_number ⇒ Object
Routing number of the bank account.
Instance Method Summary collapse
-
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
1670 1671 1672 1673 1674 1675 1676 1677 1678 1679 1680 1681 1682 |
# File 'lib/stripe/resources/setup_intent.rb', line 1670 def initialize( account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil ) @account_holder_type = account_holder_type @account_number = account_number @account_type = account_type @financial_connections_account = financial_connections_account @routing_number = routing_number end |
Instance Attribute Details
#account_holder_type ⇒ Object
Account holder type: individual or company.
1660 1661 1662 |
# File 'lib/stripe/resources/setup_intent.rb', line 1660 def account_holder_type @account_holder_type end |
#account_number ⇒ Object
Account number of the bank account.
1662 1663 1664 |
# File 'lib/stripe/resources/setup_intent.rb', line 1662 def account_number @account_number end |
#account_type ⇒ Object
Account type: checkings or savings. Defaults to checking if omitted.
1664 1665 1666 |
# File 'lib/stripe/resources/setup_intent.rb', line 1664 def account_type @account_type end |
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
1666 1667 1668 |
# File 'lib/stripe/resources/setup_intent.rb', line 1666 def financial_connections_account @financial_connections_account end |
#routing_number ⇒ Object
Routing number of the bank account.
1668 1669 1670 |
# File 'lib/stripe/resources/setup_intent.rb', line 1668 def routing_number @routing_number end |