Class: Stripe::SetupIntent::UpdateParams::PaymentMethodOptions::AcssDebit::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(custom_mandate_url: nil, default_for: nil, interval_description: nil, payment_schedule: nil, transaction_type: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



2704
2705
2706
2707
2708
2709
2710
2711
2712
2713
2714
2715
2716
# File 'lib/stripe/resources/setup_intent.rb', line 2704

def initialize(
  custom_mandate_url: nil,
  default_for: nil,
  interval_description: nil,
  payment_schedule: nil,
  transaction_type: nil
)
  @custom_mandate_url = custom_mandate_url
  @default_for = default_for
  @interval_description = interval_description
  @payment_schedule = payment_schedule
  @transaction_type = transaction_type
end

Instance Attribute Details

#custom_mandate_urlObject

A URL for custom mandate text to render during confirmation step. The URL will be rendered with additional GET parameters ‘payment_intent` and `payment_intent_client_secret` when confirming a Payment Intent, or `setup_intent` and `setup_intent_client_secret` when confirming a Setup Intent.



2694
2695
2696
# File 'lib/stripe/resources/setup_intent.rb', line 2694

def custom_mandate_url
  @custom_mandate_url
end

#default_forObject

List of Stripe products where this mandate can be selected automatically.



2696
2697
2698
# File 'lib/stripe/resources/setup_intent.rb', line 2696

def default_for
  @default_for
end

#interval_descriptionObject

Description of the mandate interval. Only required if ‘payment_schedule’ parameter is ‘interval’ or ‘combined’.



2698
2699
2700
# File 'lib/stripe/resources/setup_intent.rb', line 2698

def interval_description
  @interval_description
end

#payment_scheduleObject

Payment schedule for the mandate.



2700
2701
2702
# File 'lib/stripe/resources/setup_intent.rb', line 2700

def payment_schedule
  @payment_schedule
end

#transaction_typeObject

Transaction type of the mandate.



2702
2703
2704
# File 'lib/stripe/resources/setup_intent.rb', line 2702

def transaction_type
  @transaction_type
end