Class: Stripe::SetupIntent::UpdateParams::PaymentMethodOptions::Card
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntent::UpdateParams::PaymentMethodOptions::Card
- Defined in:
- lib/stripe/resources/setup_intent.rb
Defined Under Namespace
Classes: MandateOptions, ThreeDSecure
Instance Attribute Summary collapse
-
#mandate_options ⇒ Object
Configuration options for setting up an eMandate for cards issued in India.
-
#moto ⇒ Object
When specified, this parameter signals that a card has been collected as MOTO (Mail Order Telephone Order) and thus out of scope for SCA.
-
#network ⇒ Object
Selected network to process this SetupIntent on.
-
#request_three_d_secure ⇒ Object
We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and [other requirements](stripe.com/docs/strong-customer-authentication).
-
#three_d_secure ⇒ Object
If 3D Secure authentication was performed with a third-party provider, the authentication details to use for this setup.
Instance Method Summary collapse
-
#initialize(mandate_options: nil, moto: nil, network: nil, request_three_d_secure: nil, three_d_secure: nil) ⇒ Card
constructor
A new instance of Card.
Methods inherited from RequestParams
Constructor Details
#initialize(mandate_options: nil, moto: nil, network: nil, request_three_d_secure: nil, three_d_secure: nil) ⇒ Card
Returns a new instance of Card.
2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 |
# File 'lib/stripe/resources/setup_intent.rb', line 2883 def initialize( mandate_options: nil, moto: nil, network: nil, request_three_d_secure: nil, three_d_secure: nil ) @mandate_options = @moto = moto @network = network @request_three_d_secure = request_three_d_secure @three_d_secure = three_d_secure end |
Instance Attribute Details
#mandate_options ⇒ Object
Configuration options for setting up an eMandate for cards issued in India.
2870 2871 2872 |
# File 'lib/stripe/resources/setup_intent.rb', line 2870 def @mandate_options end |
#moto ⇒ Object
When specified, this parameter signals that a card has been collected as MOTO (Mail Order Telephone Order) and thus out of scope for SCA. This parameter can only be provided during confirmation.
2874 2875 2876 |
# File 'lib/stripe/resources/setup_intent.rb', line 2874 def moto @moto end |
#network ⇒ Object
Selected network to process this SetupIntent on. Depends on the available networks of the card attached to the SetupIntent. Can be only set confirm-time.
2876 2877 2878 |
# File 'lib/stripe/resources/setup_intent.rb', line 2876 def network @network end |
#request_three_d_secure ⇒ Object
We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and [other requirements](stripe.com/docs/strong-customer-authentication). However, if you wish to request 3D Secure based on logic from your own fraud engine, provide this option. If not provided, this value defaults to ‘automatic`. Read our guide on [manually requesting 3D Secure](stripe.com/docs/payments/3d-secure/authentication-flow#manual-three-ds) for more information on how this configuration interacts with Radar and our SCA Engine.
2878 2879 2880 |
# File 'lib/stripe/resources/setup_intent.rb', line 2878 def request_three_d_secure @request_three_d_secure end |
#three_d_secure ⇒ Object
If 3D Secure authentication was performed with a third-party provider, the authentication details to use for this setup.
2881 2882 2883 |
# File 'lib/stripe/resources/setup_intent.rb', line 2881 def three_d_secure @three_d_secure end |