Class: Stripe::SetupIntent::UpdateParams::PaymentMethodOptions::Klarna

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Defined Under Namespace

Classes: OnDemand, Subscription

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(currency: nil, on_demand: nil, preferred_locale: nil, subscriptions: nil) ⇒ Klarna

Returns a new instance of Klarna.



2974
2975
2976
2977
2978
2979
# File 'lib/stripe/resources/setup_intent.rb', line 2974

def initialize(currency: nil, on_demand: nil, preferred_locale: nil, subscriptions: nil)
  @currency = currency
  @on_demand = on_demand
  @preferred_locale = preferred_locale
  @subscriptions = subscriptions
end

Instance Attribute Details

#currencyObject

The currency of the SetupIntent. Three letter ISO currency code.



2966
2967
2968
# File 'lib/stripe/resources/setup_intent.rb', line 2966

def currency
  @currency
end

#on_demandObject

On-demand details if setting up a payment method for on-demand payments.



2968
2969
2970
# File 'lib/stripe/resources/setup_intent.rb', line 2968

def on_demand
  @on_demand
end

#preferred_localeObject

Preferred language of the Klarna authorization page that the customer is redirected to



2970
2971
2972
# File 'lib/stripe/resources/setup_intent.rb', line 2970

def preferred_locale
  @preferred_locale
end

#subscriptionsObject

Subscription details if setting up or charging a subscription



2972
2973
2974
# File 'lib/stripe/resources/setup_intent.rb', line 2972

def subscriptions
  @subscriptions
end