Class: Stripe::SetupIntent::UpdateParams::PaymentMethodOptions::Paypal

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_agreement_id: nil, currency: nil, subsellers: nil) ⇒ Paypal

Returns a new instance of Paypal.



2569
2570
2571
2572
2573
# File 'lib/stripe/resources/setup_intent.rb', line 2569

def initialize(billing_agreement_id: nil, currency: nil, subsellers: nil)
  @billing_agreement_id = billing_agreement_id
  @currency = currency
  @subsellers = subsellers
end

Instance Attribute Details

#billing_agreement_idObject

The PayPal Billing Agreement ID (BAID). This is an ID generated by PayPal which represents the mandate between the merchant and the customer.



2563
2564
2565
# File 'lib/stripe/resources/setup_intent.rb', line 2563

def billing_agreement_id
  @billing_agreement_id
end

#currencyObject

Attribute for param field currency



2565
2566
2567
# File 'lib/stripe/resources/setup_intent.rb', line 2565

def currency
  @currency
end

#subsellersObject

The Stripe connected account IDs of the sellers on the platform for this transaction (optional). Only allowed when [separate charges and transfers](stripe.com/docs/connect/separate-charges-and-transfers) are used.



2567
2568
2569
# File 'lib/stripe/resources/setup_intent.rb', line 2567

def subsellers
  @subsellers
end