Class: Stripe::SetupIntent::VerifyMicrodepositsParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amounts: nil, descriptor_code: nil, expand: nil) ⇒ VerifyMicrodepositsParams

Returns a new instance of VerifyMicrodepositsParams.



4598
4599
4600
4601
4602
# File 'lib/stripe/resources/setup_intent.rb', line 4598

def initialize(amounts: nil, descriptor_code: nil, expand: nil)
  @amounts = amounts
  @descriptor_code = descriptor_code
  @expand = expand
end

Instance Attribute Details

#amountsObject

Two positive integers, in cents, equal to the values of the microdeposits sent to the bank account.



4592
4593
4594
# File 'lib/stripe/resources/setup_intent.rb', line 4592

def amounts
  @amounts
end

#descriptor_codeObject

A six-character code starting with SM present in the microdeposit sent to the bank account.



4594
4595
4596
# File 'lib/stripe/resources/setup_intent.rb', line 4594

def descriptor_code
  @descriptor_code
end

#expandObject

Specifies which fields in the response should be expanded.



4596
4597
4598
# File 'lib/stripe/resources/setup_intent.rb', line 4596

def expand
  @expand
end