Class: Stripe::SetupIntentConfirmParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentConfirmParams
- Defined in:
- lib/stripe/params/setup_intent_confirm_params.rb
Defined Under Namespace
Classes: MandateData, PaymentMethodData, PaymentMethodOptions, SetupDetails
Instance Attribute Summary collapse
-
#allowed_payment_method_types ⇒ Object
The list of payment method types to allow for this SetupIntent.
-
#confirmation_token ⇒ Object
ID of the ConfirmationToken used to confirm this SetupIntent.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#mandate_data ⇒ Object
Attribute for param field mandate_data.
-
#payment_method ⇒ Object
ID of the payment method (a PaymentMethod, Card, or saved Source object) to attach to this SetupIntent.
-
#payment_method_data ⇒ Object
When included, this hash creates a PaymentMethod that is set as the
payment_methodvalue in the SetupIntent. -
#payment_method_options ⇒ Object
Payment method-specific configuration for this SetupIntent.
-
#return_url ⇒ Object
The URL to redirect your customer back to after they authenticate on the payment method's app or site.
-
#setup_details ⇒ Object
Provides industry-specific information about the SetupIntent.
-
#use_stripe_sdk ⇒ Object
Set to
truewhen confirming server-side and using Stripe.js, iOS, or Android client-side SDKs to handle the next actions.
Instance Method Summary collapse
-
#initialize(allowed_payment_method_types: nil, confirmation_token: nil, expand: nil, mandate_data: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, return_url: nil, setup_details: nil, use_stripe_sdk: nil) ⇒ SetupIntentConfirmParams
constructor
A new instance of SetupIntentConfirmParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(allowed_payment_method_types: nil, confirmation_token: nil, expand: nil, mandate_data: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, return_url: nil, setup_details: nil, use_stripe_sdk: nil) ⇒ SetupIntentConfirmParams
Returns a new instance of SetupIntentConfirmParams.
1416 1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1416 def initialize( allowed_payment_method_types: nil, confirmation_token: nil, expand: nil, mandate_data: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, return_url: nil, setup_details: nil, use_stripe_sdk: nil ) @allowed_payment_method_types = allowed_payment_method_types @confirmation_token = confirmation_token @expand = @mandate_data = mandate_data @payment_method = payment_method @payment_method_data = payment_method_data @payment_method_options = @return_url = return_url @setup_details = setup_details @use_stripe_sdk = use_stripe_sdk end |
Instance Attribute Details
#allowed_payment_method_types ⇒ Object
The list of payment method types to allow for this SetupIntent. Stripe will only use methods in this list when determining the payment methods to offer. A list of valid payment method types can be found here.
1391 1392 1393 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1391 def allowed_payment_method_types @allowed_payment_method_types end |
#confirmation_token ⇒ Object
ID of the ConfirmationToken used to confirm this SetupIntent.
If the provided ConfirmationToken contains properties that are also being provided in this request, such as payment_method, then the values in this request will take precedence.
1395 1396 1397 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1395 def confirmation_token @confirmation_token end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1397 1398 1399 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1397 def @expand end |
#mandate_data ⇒ Object
Attribute for param field mandate_data
1399 1400 1401 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1399 def mandate_data @mandate_data end |
#payment_method ⇒ Object
ID of the payment method (a PaymentMethod, Card, or saved Source object) to attach to this SetupIntent.
1401 1402 1403 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1401 def payment_method @payment_method end |
#payment_method_data ⇒ Object
When included, this hash creates a PaymentMethod that is set as the payment_method
value in the SetupIntent.
1404 1405 1406 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1404 def payment_method_data @payment_method_data end |
#payment_method_options ⇒ Object
Payment method-specific configuration for this SetupIntent.
1406 1407 1408 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1406 def @payment_method_options end |
#return_url ⇒ Object
The URL to redirect your customer back to after they authenticate on the payment method's app or site. If you'd prefer to redirect to a mobile application, you can alternatively supply an application URI scheme. This parameter is only used for cards and other redirect-based payment methods.
1410 1411 1412 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1410 def return_url @return_url end |
#setup_details ⇒ Object
Provides industry-specific information about the SetupIntent.
1412 1413 1414 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1412 def setup_details @setup_details end |
#use_stripe_sdk ⇒ Object
Set to true when confirming server-side and using Stripe.js, iOS, or Android client-side SDKs to handle the next actions.
1414 1415 1416 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1414 def use_stripe_sdk @use_stripe_sdk end |