Class: Stripe::SetupIntentConfirmParams::PaymentMethodData::Upi::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/setup_intent_confirm_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



404
405
406
407
408
409
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 404

def initialize(amount: nil, amount_type: nil, description: nil, end_date: nil)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



396
397
398
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 396

def amount
  @amount
end

#amount_typeObject

One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.



398
399
400
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 398

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



400
401
402
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 400

def description
  @description
end

#end_dateObject

End date of the mandate or subscription.



402
403
404
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 402

def end_date
  @end_date
end