Class: Stripe::SetupIntentConfirmParams::PaymentMethodOptions::Card
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentConfirmParams::PaymentMethodOptions::Card
- Defined in:
- lib/stripe/params/setup_intent_confirm_params.rb
Defined Under Namespace
Classes: MandateOptions, ThreeDSecure
Instance Attribute Summary collapse
-
#mandate_options ⇒ Object
Configuration options for setting up an eMandate for cards issued in India.
-
#moto ⇒ Object
When specified, this parameter signals that a card has been collected as MOTO (Mail Order Telephone Order) and thus out of scope for SCA.
-
#network ⇒ Object
Selected network to process this SetupIntent on.
-
#request_three_d_secure ⇒ Object
We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and other requirements.
-
#three_d_secure ⇒ Object
If 3D Secure authentication was performed with a third-party provider, the authentication details to use for this setup.
Instance Method Summary collapse
-
#initialize(mandate_options: nil, moto: nil, network: nil, request_three_d_secure: nil, three_d_secure: nil) ⇒ Card
constructor
A new instance of Card.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(mandate_options: nil, moto: nil, network: nil, request_three_d_secure: nil, three_d_secure: nil) ⇒ Card
Returns a new instance of Card.
932 933 934 935 936 937 938 939 940 941 942 943 944 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 932 def initialize( mandate_options: nil, moto: nil, network: nil, request_three_d_secure: nil, three_d_secure: nil ) @mandate_options = @moto = moto @network = network @request_three_d_secure = request_three_d_secure @three_d_secure = three_d_secure end |
Instance Attribute Details
#mandate_options ⇒ Object
Configuration options for setting up an eMandate for cards issued in India.
919 920 921 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 919 def @mandate_options end |
#moto ⇒ Object
When specified, this parameter signals that a card has been collected as MOTO (Mail Order Telephone Order) and thus out of scope for SCA. This parameter can only be provided during confirmation.
923 924 925 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 923 def moto @moto end |
#network ⇒ Object
Selected network to process this SetupIntent on. Depends on the available networks of the card attached to the SetupIntent. Can be only set confirm-time.
925 926 927 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 925 def network @network end |
#request_three_d_secure ⇒ Object
We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and other requirements. However, if you wish to request 3D Secure based on logic from your own fraud engine, provide this option. If not provided, this value defaults to automatic. Read our guide on manually requesting 3D Secure for more information on how this configuration interacts with Radar and our SCA Engine.
927 928 929 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 927 def request_three_d_secure @request_three_d_secure end |
#three_d_secure ⇒ Object
If 3D Secure authentication was performed with a third-party provider, the authentication details to use for this setup.
930 931 932 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 930 def three_d_secure @three_d_secure end |