Class: Stripe::SetupIntentConfirmParams::PaymentMethodOptions::Card::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/setup_intent_confirm_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, currency: nil, description: nil, end_date: nil, interval: nil, interval_count: nil, reference: nil, start_date: nil, supported_types: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
841
842
843
844
845
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 823

def initialize(
  amount: nil,
  amount_type: nil,
  currency: nil,
  description: nil,
  end_date: nil,
  interval: nil,
  interval_count: nil,
  reference: nil,
  start_date: nil,
  supported_types: nil
)
  @amount = amount
  @amount_type = amount_type
  @currency = currency
  @description = description
  @end_date = end_date
  @interval = interval
  @interval_count = interval_count
  @reference = reference
  @start_date = start_date
  @supported_types = supported_types
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments, specified in the presentment currency.



803
804
805
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 803

def amount
  @amount
end

#amount_typeObject

One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.



805
806
807
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 805

def amount_type
  @amount_type
end

#currencyObject

Currency in which future payments will be charged. Three-letter ISO currency code, in lowercase. Must be a supported currency.



807
808
809
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 807

def currency
  @currency
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



809
810
811
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 809

def description
  @description
end

#end_dateObject

End date of the mandate or subscription. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.



811
812
813
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 811

def end_date
  @end_date
end

#intervalObject

Specifies payment frequency. One of day, week, month, year, or sporadic.



813
814
815
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 813

def interval
  @interval
end

#interval_countObject

The number of intervals between payments. For example, interval=month and interval_count=3 indicates one payment every three months. Maximum of one year interval allowed (1 year, 12 months, or 52 weeks). This parameter is optional when interval=sporadic.



815
816
817
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 815

def interval_count
  @interval_count
end

#referenceObject

Unique identifier for the mandate or subscription.



817
818
819
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 817

def reference
  @reference
end

#start_dateObject

Start date of the mandate or subscription. Start date should not be lesser than yesterday.



819
820
821
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 819

def start_date
  @start_date
end

#supported_typesObject

Specifies the type of mandates supported. Possible values are india.



821
822
823
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 821

def supported_types
  @supported_types
end