Class: Stripe::SetupIntentConfirmParams::PaymentMethodOptions::Klarna
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentConfirmParams::PaymentMethodOptions::Klarna
- Defined in:
- lib/stripe/params/setup_intent_confirm_params.rb
Defined Under Namespace
Classes: OnDemand, Subscription
Instance Attribute Summary collapse
-
#currency ⇒ Object
The currency of the SetupIntent.
-
#on_demand ⇒ Object
On-demand details if setting up a payment method for on-demand payments.
-
#preferred_locale ⇒ Object
Preferred language of the Klarna authorization page that the customer is redirected to.
-
#subscriptions ⇒ Object
Subscription details if setting up or charging a subscription.
Instance Method Summary collapse
-
#initialize(currency: nil, on_demand: nil, preferred_locale: nil, subscriptions: nil) ⇒ Klarna
constructor
A new instance of Klarna.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(currency: nil, on_demand: nil, preferred_locale: nil, subscriptions: nil) ⇒ Klarna
Returns a new instance of Klarna.
988 989 990 991 992 993 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 988 def initialize(currency: nil, on_demand: nil, preferred_locale: nil, subscriptions: nil) @currency = currency @on_demand = on_demand @preferred_locale = preferred_locale @subscriptions = subscriptions end |
Instance Attribute Details
#currency ⇒ Object
The currency of the SetupIntent. Three letter ISO currency code.
980 981 982 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 980 def currency @currency end |
#on_demand ⇒ Object
On-demand details if setting up a payment method for on-demand payments.
982 983 984 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 982 def on_demand @on_demand end |
#preferred_locale ⇒ Object
Preferred language of the Klarna authorization page that the customer is redirected to
984 985 986 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 984 def preferred_locale @preferred_locale end |
#subscriptions ⇒ Object
Subscription details if setting up or charging a subscription
986 987 988 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 986 def subscriptions @subscriptions end |