Class: Stripe::SetupIntentConfirmParams::PaymentMethodOptions::Klarna::Subscription
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentConfirmParams::PaymentMethodOptions::Klarna::Subscription
- Defined in:
- lib/stripe/params/setup_intent_confirm_params.rb
Defined Under Namespace
Classes: NextBilling
Instance Attribute Summary collapse
-
#interval ⇒ Object
Unit of time between subscription charges.
-
#interval_count ⇒ Object
The number of intervals (specified in the ‘interval` attribute) between subscription charges.
-
#name ⇒ Object
Name for subscription.
-
#next_billing ⇒ Object
Describes the upcoming charge for this subscription.
-
#reference ⇒ Object
A non-customer-facing reference to correlate subscription charges in the Klarna app.
Instance Method Summary collapse
-
#initialize(interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil) ⇒ Subscription
constructor
A new instance of Subscription.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil) ⇒ Subscription
Returns a new instance of Subscription.
965 966 967 968 969 970 971 972 973 974 975 976 977 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 965 def initialize( interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil ) @interval = interval @interval_count = interval_count @name = name @next_billing = next_billing @reference = reference end |
Instance Attribute Details
#interval ⇒ Object
Unit of time between subscription charges.
955 956 957 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 955 def interval @interval end |
#interval_count ⇒ Object
The number of intervals (specified in the ‘interval` attribute) between subscription charges. For example, `interval=month` and `interval_count=3` charges every 3 months.
957 958 959 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 957 def interval_count @interval_count end |
#name ⇒ Object
Name for subscription.
959 960 961 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 959 def name @name end |
#next_billing ⇒ Object
Describes the upcoming charge for this subscription.
961 962 963 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 961 def next_billing @next_billing end |
#reference ⇒ Object
A non-customer-facing reference to correlate subscription charges in the Klarna app. Use a value that persists across subscription charges.
963 964 965 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 963 def reference @reference end |