Class: Stripe::SetupIntentConfirmParams::PaymentMethodOptions::Paypal

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/setup_intent_confirm_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(billing_agreement_id: nil, currency: nil, subsellers: nil) ⇒ Paypal

Returns a new instance of Paypal.



1048
1049
1050
1051
1052
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1048

def initialize(billing_agreement_id: nil, currency: nil, subsellers: nil)
  @billing_agreement_id = billing_agreement_id
  @currency = currency
  @subsellers = subsellers
end

Instance Attribute Details

#billing_agreement_idObject

The PayPal Billing Agreement ID (BAID). This is an ID generated by PayPal which represents the mandate between the merchant and the customer.



1042
1043
1044
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1042

def billing_agreement_id
  @billing_agreement_id
end

#currencyObject

Attribute for param field currency



1044
1045
1046
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1044

def currency
  @currency
end

#subsellersObject

The Stripe connected account IDs of the sellers on the platform for this transaction (optional). Only allowed when separate charges and transfers are used.



1046
1047
1048
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1046

def subsellers
  @subsellers
end