Class: Stripe::SetupIntentConfirmParams::PaymentMethodOptions::Payto::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/setup_intent_confirm_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, end_date: nil, payment_schedule: nil, payments_per_period: nil, purpose: nil, start_date: nil) ⇒ MandateOptions



996
997
998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 996

def initialize(
  amount: nil,
  amount_type: nil,
  end_date: nil,
  payment_schedule: nil,
  payments_per_period: nil,
  purpose: nil,
  start_date: nil
)
  @amount = amount
  @amount_type = amount_type
  @end_date = end_date
  @payment_schedule = payment_schedule
  @payments_per_period = payments_per_period
  @purpose = purpose
  @start_date = start_date
end

Instance Attribute Details

#amount ⇒ Object

Amount that will be collected. It is required when amount_type is fixed.



982
983
984
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 982

def amount
  @amount
end

#amount_type ⇒ Object

The type of amount that will be collected. The amount charged must be exact or up to the value of amount param for fixed or maximum type respectively. Defaults to maximum.



984
985
986
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 984

def amount_type
  @amount_type
end

#end_date ⇒ Object

Date, in YYYY-MM-DD format, after which payments will not be collected. Defaults to no end date.



986
987
988
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 986

def end_date
  @end_date
end

#payment_schedule ⇒ Object

The periodicity at which payments will be collected. Defaults to adhoc.



988
989
990
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 988

def payment_schedule
  @payment_schedule
end

#payments_per_period ⇒ Object

The number of payments that will be made during a payment period. Defaults to 1 except for when payment_schedule is adhoc. In that case, it defaults to no limit.



990
991
992
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 990

def payments_per_period
  @payments_per_period
end

#purpose ⇒ Object

The purpose for which payments are made. Has a default value based on your merchant category code.



992
993
994
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 992

def purpose
  @purpose
end

#start_date ⇒ Object

Date, in YYYY-MM-DD format, from which payments will be collected. Defaults to confirmation time.



994
995
996
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 994

def start_date
  @start_date
end