Class: Stripe::SetupIntentConfirmParams::PaymentMethodOptions::Pix::MandateOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentConfirmParams::PaymentMethodOptions::Pix::MandateOptions
- Defined in:
- lib/stripe/params/setup_intent_confirm_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount to be charged for future payments.
-
#amount_includes_iof ⇒ Object
Determines if the amount includes the IOF tax.
-
#amount_type ⇒ Object
Type of amount.
-
#currency ⇒ Object
Three-letter ISO currency code, in lowercase.
-
#end_date ⇒ Object
Date when the mandate expires and no further payments will be charged, in
YYYY-MM-DD. -
#payment_schedule ⇒ Object
Schedule at which the future payments will be charged.
-
#reference ⇒ Object
Subscription name displayed to buyers in their bank app.
-
#start_date ⇒ Object
Start date of the mandate, in
YYYY-MM-DD.
Instance Method Summary collapse
-
#initialize(amount: nil, amount_includes_iof: nil, amount_type: nil, currency: nil, end_date: nil, payment_schedule: nil, reference: nil, start_date: nil) ⇒ MandateOptions
constructor
A new instance of MandateOptions.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, amount_includes_iof: nil, amount_type: nil, currency: nil, end_date: nil, payment_schedule: nil, reference: nil, start_date: nil) ⇒ MandateOptions
Returns a new instance of MandateOptions.
1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1094 def initialize( amount: nil, amount_includes_iof: nil, amount_type: nil, currency: nil, end_date: nil, payment_schedule: nil, reference: nil, start_date: nil ) @amount = amount @amount_includes_iof = amount_includes_iof @amount_type = amount_type @currency = currency @end_date = end_date @payment_schedule = payment_schedule @reference = reference @start_date = start_date end |
Instance Attribute Details
#amount ⇒ Object
Amount to be charged for future payments. Required when amount_type=fixed. If not provided for amount_type=maximum, defaults to 40000.
1078 1079 1080 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1078 def amount @amount end |
#amount_includes_iof ⇒ Object
Determines if the amount includes the IOF tax. Defaults to never.
1080 1081 1082 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1080 def amount_includes_iof @amount_includes_iof end |
#amount_type ⇒ Object
Type of amount. Defaults to maximum.
1082 1083 1084 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1082 def amount_type @amount_type end |
#currency ⇒ Object
Three-letter ISO currency code, in lowercase. Only brl is supported currently.
1084 1085 1086 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1084 def currency @currency end |
#end_date ⇒ Object
Date when the mandate expires and no further payments will be charged, in YYYY-MM-DD. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.
1086 1087 1088 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1086 def end_date @end_date end |
#payment_schedule ⇒ Object
Schedule at which the future payments will be charged. Defaults to monthly.
1088 1089 1090 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1088 def payment_schedule @payment_schedule end |
#reference ⇒ Object
Subscription name displayed to buyers in their bank app. Defaults to the displayable business name.
1090 1091 1092 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1090 def reference @reference end |
#start_date ⇒ Object
Start date of the mandate, in YYYY-MM-DD. Start date should be at least 3 days in the future. Defaults to 3 days after the current date.
1092 1093 1094 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1092 def start_date @start_date end |