Class: Stripe::SetupIntentCreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/setup_intent_create_params.rb

Defined Under Namespace

Classes: AutomaticPaymentMethods, MandateData, PaymentMethodData, PaymentMethodOptions, SetupDetails, SingleUse

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(allowed_payment_method_types: nil, attach_to_self: nil, automatic_payment_methods: nil, confirm: nil, confirmation_token: nil, customer: nil, customer_account: nil, description: nil, excluded_payment_method_types: nil, expand: nil, flow_directions: nil, mandate_data: nil, metadata: nil, on_behalf_of: nil, payment_method: nil, payment_method_configuration: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil, return_url: nil, setup_details: nil, single_use: nil, usage: nil, use_stripe_sdk: nil) ⇒ SetupIntentCreateParams

Returns a new instance of SetupIntentCreateParams.



1478
1479
1480
1481
1482
1483
1484
1485
1486
1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1478

def initialize(
  allowed_payment_method_types: nil,
  attach_to_self: nil,
  automatic_payment_methods: nil,
  confirm: nil,
  confirmation_token: nil,
  customer: nil,
  customer_account: nil,
  description: nil,
  excluded_payment_method_types: nil,
  expand: nil,
  flow_directions: nil,
  mandate_data: nil,
  metadata: nil,
  on_behalf_of: nil,
  payment_method: nil,
  payment_method_configuration: nil,
  payment_method_data: nil,
  payment_method_options: nil,
  payment_method_types: nil,
  return_url: nil,
  setup_details: nil,
  single_use: nil,
  usage: nil,
  use_stripe_sdk: nil
)
  @allowed_payment_method_types = allowed_payment_method_types
  @attach_to_self = attach_to_self
  @automatic_payment_methods = automatic_payment_methods
  @confirm = confirm
  @confirmation_token = confirmation_token
  @customer = customer
  @customer_account = 
  @description = description
  @excluded_payment_method_types = excluded_payment_method_types
  @expand = expand
  @flow_directions = flow_directions
  @mandate_data = mandate_data
  @metadata = 
  @on_behalf_of = on_behalf_of
  @payment_method = payment_method
  @payment_method_configuration = payment_method_configuration
  @payment_method_data = payment_method_data
  @payment_method_options = payment_method_options
  @payment_method_types = payment_method_types
  @return_url = return_url
  @setup_details = setup_details
  @single_use = single_use
  @usage = usage
  @use_stripe_sdk = use_stripe_sdk
end

Instance Attribute Details

#allowed_payment_method_typesObject

The list of payment method types to allow for this SetupIntent. Stripe will only use methods in this list when determining the payment methods to offer. A list of valid payment method types can be found here.



1417
1418
1419
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1417

def allowed_payment_method_types
  @allowed_payment_method_types
end

#attach_to_selfObject

If present, the SetupIntent's payment method will be attached to the in-context Stripe Account.

It can only be used for this Stripe Account’s own money movement flows like InboundTransfer and OutboundTransfers. It cannot be set to true when setting up a PaymentMethod for a Customer, and defaults to false when attaching a PaymentMethod to a Customer.



1421
1422
1423
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1421

def attach_to_self
  @attach_to_self
end

#automatic_payment_methodsObject

When you enable this parameter, this SetupIntent accepts payment methods that you enable in the Dashboard and that are compatible with its other parameters.



1423
1424
1425
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1423

def automatic_payment_methods
  @automatic_payment_methods
end

#confirmObject

Set to true to attempt to confirm this SetupIntent immediately. This parameter defaults to false. If a card is the attached payment method, you can provide a return_url in case further authentication is necessary.



1425
1426
1427
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1425

def confirm
  @confirm
end

#confirmation_tokenObject

ID of the ConfirmationToken used to confirm this SetupIntent.

If the provided ConfirmationToken contains properties that are also being provided in this request, such as payment_method, then the values in this request will take precedence.



1429
1430
1431
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1429

def confirmation_token
  @confirmation_token
end

#customerObject

ID of the Customer this SetupIntent belongs to, if one exists.

If present, the SetupIntent's payment method will be attached to the Customer on successful setup. Payment methods attached to other Customers cannot be used with this SetupIntent.



1433
1434
1435
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1433

def customer
  @customer
end

#customer_accountObject

ID of the Account this SetupIntent belongs to, if one exists.

If present, the SetupIntent's payment method will be attached to the Account on successful setup. Payment methods attached to other Accounts cannot be used with this SetupIntent.



1437
1438
1439
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1437

def 
  @customer_account
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



1439
1440
1441
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1439

def description
  @description
end

#excluded_payment_method_typesObject

The list of payment method types to exclude from use with this SetupIntent.



1441
1442
1443
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1441

def excluded_payment_method_types
  @excluded_payment_method_types
end

#expandObject

Specifies which fields in the response should be expanded.



1443
1444
1445
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1443

def expand
  @expand
end

#flow_directionsObject

Indicates the directions of money movement for which this payment method is intended to be used.

Include inbound if you intend to use the payment method as the origin to pull funds from. Include outbound if you intend to use the payment method as the destination to send funds to. You can include both if you intend to use the payment method for both purposes.



1447
1448
1449
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1447

def flow_directions
  @flow_directions
end

#mandate_dataObject

This hash contains details about the mandate to create. This parameter can only be used with confirm=true.



1449
1450
1451
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1449

def mandate_data
  @mandate_data
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.



1451
1452
1453
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1451

def 
  @metadata
end

#on_behalf_ofObject

The Stripe account ID created for this SetupIntent.



1453
1454
1455
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1453

def on_behalf_of
  @on_behalf_of
end

#payment_methodObject

ID of the payment method (a PaymentMethod, Card, or saved Source object) to attach to this SetupIntent.



1455
1456
1457
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1455

def payment_method
  @payment_method
end

#payment_method_configurationObject

The ID of the payment method configuration to use with this SetupIntent.



1457
1458
1459
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1457

def payment_method_configuration
  @payment_method_configuration
end

#payment_method_dataObject

When included, this hash creates a PaymentMethod that is set as the payment_method value in the SetupIntent.



1460
1461
1462
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1460

def payment_method_data
  @payment_method_data
end

#payment_method_optionsObject

Payment method-specific configuration for this SetupIntent.



1462
1463
1464
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1462

def payment_method_options
  @payment_method_options
end

#payment_method_typesObject

The list of payment method types (for example, card) that this SetupIntent can use. If you don't provide this, Stripe will dynamically show relevant payment methods from your payment method settings. A list of valid payment method types can be found here.



1464
1465
1466
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1464

def payment_method_types
  @payment_method_types
end

#return_urlObject

The URL to redirect your customer back to after they authenticate or cancel their payment on the payment method's app or site. To redirect to a mobile application, you can alternatively supply an application URI scheme. This parameter can only be used with confirm=true.



1466
1467
1468
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1466

def return_url
  @return_url
end

#setup_detailsObject

Provides industry-specific information about the SetupIntent.



1468
1469
1470
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1468

def setup_details
  @setup_details
end

#single_useObject

If you populate this hash, this SetupIntent generates a single_use mandate after successful completion.

Single-use mandates are only valid for the following payment methods: acss_debit, alipay, au_becs_debit, bacs_debit, bancontact, boleto, ideal, link, sepa_debit, and us_bank_account.



1472
1473
1474
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1472

def single_use
  @single_use
end

#usageObject

Indicates how the payment method is intended to be used in the future. If not provided, this value defaults to off_session.



1474
1475
1476
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1474

def usage
  @usage
end

#use_stripe_sdkObject

Set to true when confirming server-side and using Stripe.js, iOS, or Android client-side SDKs to handle the next actions.



1476
1477
1478
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1476

def use_stripe_sdk
  @use_stripe_sdk
end