Class: Stripe::SetupIntentCreateParams::PaymentMethodData::StripeBalance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentCreateParams::PaymentMethodData::StripeBalance
- Defined in:
- lib/stripe/params/setup_intent_create_params.rb
Instance Attribute Summary collapse
-
#account ⇒ Object
The connected account ID whose Stripe balance to use as the source of payment.
Instance Method Summary collapse
-
#initialize(account: nil) ⇒ StripeBalance
constructor
A new instance of StripeBalance.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(account: nil) ⇒ StripeBalance
Returns a new instance of StripeBalance.
386 387 388 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 386 def initialize(account: nil) @account = account end |
Instance Attribute Details
#account ⇒ Object
The connected account ID whose Stripe balance to use as the source of payment
384 385 386 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 384 def account @account end |