Class: Stripe::SetupIntentCreateParams::PaymentMethodData::Upi::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/setup_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



418
419
420
421
422
423
# File 'lib/stripe/params/setup_intent_create_params.rb', line 418

def initialize(amount: nil, amount_type: nil, description: nil, end_date: nil)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



410
411
412
# File 'lib/stripe/params/setup_intent_create_params.rb', line 410

def amount
  @amount
end

#amount_typeObject

One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.



412
413
414
# File 'lib/stripe/params/setup_intent_create_params.rb', line 412

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



414
415
416
# File 'lib/stripe/params/setup_intent_create_params.rb', line 414

def description
  @description
end

#end_dateObject

End date of the mandate or subscription.



416
417
418
# File 'lib/stripe/params/setup_intent_create_params.rb', line 416

def end_date
  @end_date
end