Class: Stripe::SetupIntentCreateParams::PaymentMethodOptions::AcssDebit::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/setup_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(custom_mandate_url: nil, default_for: nil, interval_description: nil, payment_schedule: nil, transaction_type: nil) ⇒ MandateOptions



649
650
651
652
653
654
655
656
657
658
659
660
661
# File 'lib/stripe/params/setup_intent_create_params.rb', line 649

def initialize(
  custom_mandate_url: nil,
  default_for: nil,
  interval_description: nil,
  payment_schedule: nil,
  transaction_type: nil
)
  @custom_mandate_url = custom_mandate_url
  @default_for = default_for
  @interval_description = interval_description
  @payment_schedule = payment_schedule
  @transaction_type = transaction_type
end

Instance Attribute Details

#custom_mandate_urlObject

A URL for custom mandate text to render during confirmation step. The URL will be rendered with additional GET parameters payment_intent and payment_intent_client_secret when confirming a Payment Intent, or setup_intent and setup_intent_client_secret when confirming a Setup Intent.



639
640
641
# File 'lib/stripe/params/setup_intent_create_params.rb', line 639

def custom_mandate_url
  @custom_mandate_url
end

#default_forObject

List of Stripe products where this mandate can be selected automatically.



641
642
643
# File 'lib/stripe/params/setup_intent_create_params.rb', line 641

def default_for
  @default_for
end

#interval_descriptionObject

Description of the mandate interval. Only required if ‘payment_schedule’ parameter is ‘interval’ or ‘combined’.



643
644
645
# File 'lib/stripe/params/setup_intent_create_params.rb', line 643

def interval_description
  @interval_description
end

#payment_scheduleObject

Payment schedule for the mandate.



645
646
647
# File 'lib/stripe/params/setup_intent_create_params.rb', line 645

def payment_schedule
  @payment_schedule
end

#transaction_typeObject

Transaction type of the mandate.



647
648
649
# File 'lib/stripe/params/setup_intent_create_params.rb', line 647

def transaction_type
  @transaction_type
end