Class: Stripe::SetupIntentCreateParams::PaymentMethodOptions::Blik
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentCreateParams::PaymentMethodOptions::Blik
- Defined in:
- lib/stripe/params/setup_intent_create_params.rb
Defined Under Namespace
Classes: MandateOptions
Instance Attribute Summary collapse
-
#code ⇒ Object
The 6-digit BLIK code that a customer has generated using their banking application.
-
#mandate_options ⇒ Object
Details of the BLIK mandate.
Instance Method Summary collapse
-
#initialize(code: nil, mandate_options: nil) ⇒ Blik
constructor
A new instance of Blik.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(code: nil, mandate_options: nil) ⇒ Blik
738 739 740 741 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 738 def initialize(code: nil, mandate_options: nil) @code = code @mandate_options = end |
Instance Attribute Details
#code ⇒ Object
The 6-digit BLIK code that a customer has generated using their banking application. Can only be set on confirmation.
734 735 736 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 734 def code @code end |
#mandate_options ⇒ Object
Details of the BLIK mandate
736 737 738 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 736 def @mandate_options end |