Class: Stripe::SetupIntentCreateParams::PaymentMethodOptions::Card::ThreeDSecure

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/setup_intent_create_params.rb

Defined Under Namespace

Classes: NetworkOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h

Constructor Details

#initialize(ares_trans_status: nil, cryptogram: nil, electronic_commerce_indicator: nil, network_options: nil, requestor_challenge_indicator: nil, transaction_id: nil, version: nil) ⇒ ThreeDSecure

Returns a new instance of ThreeDSecure.



844
845
846
847
848
849
850
851
852
853
854
855
856
857
858
859
860
# File 'lib/stripe/params/setup_intent_create_params.rb', line 844

def initialize(
  ares_trans_status: nil,
  cryptogram: nil,
  electronic_commerce_indicator: nil,
  network_options: nil,
  requestor_challenge_indicator: nil,
  transaction_id: nil,
  version: nil
)
  @ares_trans_status = ares_trans_status
  @cryptogram = cryptogram
  @electronic_commerce_indicator = electronic_commerce_indicator
  @network_options = network_options
  @requestor_challenge_indicator = requestor_challenge_indicator
  @transaction_id = transaction_id
  @version = version
end

Instance Attribute Details

#ares_trans_status ⇒ Object

The transStatus returned from the card Issuer’s ACS in the ARes.



822
823
824
# File 'lib/stripe/params/setup_intent_create_params.rb', line 822

def ares_trans_status
  @ares_trans_status
end

#cryptogram ⇒ Object

The cryptogram, also known as the "authentication value" (AAV, CAVV or AEVV). This value is 20 bytes, base64-encoded into a 28-character string. (Most 3D Secure providers will return the base64-encoded version, which is what you should specify here.)



827
828
829
# File 'lib/stripe/params/setup_intent_create_params.rb', line 827

def cryptogram
  @cryptogram
end

#electronic_commerce_indicator ⇒ Object

The Electronic Commerce Indicator (ECI) is returned by your 3D Secure provider and indicates what degree of authentication was performed.



830
831
832
# File 'lib/stripe/params/setup_intent_create_params.rb', line 830

def electronic_commerce_indicator
  @electronic_commerce_indicator
end

#network_options ⇒ Object

Network specific 3DS fields. Network specific arguments require an explicit card brand choice. The parameter `payment_method_options.card.network`` must be populated accordingly



834
835
836
# File 'lib/stripe/params/setup_intent_create_params.rb', line 834

def network_options
  @network_options
end

#requestor_challenge_indicator ⇒ Object

The challenge indicator (threeDSRequestorChallengeInd) which was requested in the AReq sent to the card Issuer's ACS. A string containing 2 digits from 01-99.



837
838
839
# File 'lib/stripe/params/setup_intent_create_params.rb', line 837

def requestor_challenge_indicator
  @requestor_challenge_indicator
end

#transaction_id ⇒ Object

For 3D Secure 1, the XID. For 3D Secure 2, the Directory Server Transaction ID (dsTransID).



840
841
842
# File 'lib/stripe/params/setup_intent_create_params.rb', line 840

def transaction_id
  @transaction_id
end

#version ⇒ Object

The version of 3D Secure that was performed.



842
843
844
# File 'lib/stripe/params/setup_intent_create_params.rb', line 842

def version
  @version
end