Class: Stripe::SetupIntentCreateParams::PaymentMethodOptions::Klarna::Subscription
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentCreateParams::PaymentMethodOptions::Klarna::Subscription
- Defined in:
- lib/stripe/params/setup_intent_create_params.rb
Defined Under Namespace
Classes: NextBilling
Instance Attribute Summary collapse
-
#interval ⇒ Object
Unit of time between subscription charges.
-
#interval_count ⇒ Object
The number of intervals (specified in the
intervalattribute) between subscription charges. -
#name ⇒ Object
Name for subscription.
-
#next_billing ⇒ Object
Describes the upcoming charge for this subscription.
-
#reference ⇒ Object
A non-customer-facing reference to correlate subscription charges in the Klarna app.
Instance Method Summary collapse
-
#initialize(interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil) ⇒ Subscription
constructor
A new instance of Subscription.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil) ⇒ Subscription
Returns a new instance of Subscription.
896 897 898 899 900 901 902 903 904 905 906 907 908 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 896 def initialize( interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil ) @interval = interval @interval_count = interval_count @name = name @next_billing = next_billing @reference = reference end |
Instance Attribute Details
#interval ⇒ Object
Unit of time between subscription charges.
886 887 888 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 886 def interval @interval end |
#interval_count ⇒ Object
The number of intervals (specified in the interval attribute) between subscription charges. For example, ‘interval=month` and `interval_count=3` charges every 3 months.
888 889 890 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 888 def interval_count @interval_count end |
#name ⇒ Object
Name for subscription.
890 891 892 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 890 def name @name end |
#next_billing ⇒ Object
Describes the upcoming charge for this subscription.
892 893 894 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 892 def next_billing @next_billing end |
#reference ⇒ Object
A non-customer-facing reference to correlate subscription charges in the Klarna app. Use a value that persists across subscription charges.
894 895 896 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 894 def reference @reference end |