Class: Stripe::SetupIntentCreateParams::PaymentMethodOptions::Link
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentCreateParams::PaymentMethodOptions::Link
- Defined in:
- lib/stripe/params/setup_intent_create_params.rb
Instance Attribute Summary collapse
-
#persistent_token ⇒ Object
- Deprecated
-
This is a legacy parameter that no longer has any function.
Instance Method Summary collapse
-
#initialize(persistent_token: nil) ⇒ Link
constructor
A new instance of Link.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(persistent_token: nil) ⇒ Link
Returns a new instance of Link.
931 932 933 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 931 def initialize(persistent_token: nil) @persistent_token = persistent_token end |
Instance Attribute Details
#persistent_token ⇒ Object
- Deprecated
-
This is a legacy parameter that no longer has any function.
929 930 931 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 929 def persistent_token @persistent_token end |