Class: Stripe::SetupIntentCreateParams::PaymentMethodOptions::Upi::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/setup_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions



1016
1017
1018
1019
1020
1021
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1016

def initialize(amount: nil, amount_type: nil, description: nil, end_date: nil)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



1008
1009
1010
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1008

def amount
  @amount
end

#amount_typeObject

One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.



1010
1011
1012
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1010

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



1012
1013
1014
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1012

def description
  @description
end

#end_dateObject

End date of the mandate or subscription.



1014
1015
1016
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1014

def end_date
  @end_date
end