Class: Stripe::SetupIntentCreateParams::PaymentMethodOptions::UsBankAccount::FinancialConnections

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/setup_intent_create_params.rb

Defined Under Namespace

Classes: Filters, ManualEntry

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections

Returns a new instance of FinancialConnections.



1245
1246
1247
1248
1249
1250
1251
1252
1253
1254
1255
1256
1257
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1245

def initialize(
  filters: nil,
  manual_entry: nil,
  permissions: nil,
  prefetch: nil,
  return_url: nil
)
  @filters = filters
  @manual_entry = manual_entry
  @permissions = permissions
  @prefetch = prefetch
  @return_url = return_url
end

Instance Attribute Details

#filtersObject

Provide filters for the linked accounts that the customer can select for the payment method.



1235
1236
1237
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1235

def filters
  @filters
end

#manual_entryObject

Customize manual entry behavior



1237
1238
1239
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1237

def manual_entry
  @manual_entry
end

#permissionsObject

The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.



1239
1240
1241
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1239

def permissions
  @permissions
end

#prefetchObject

List of data features that you would like to retrieve upon account creation.



1241
1242
1243
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1241

def prefetch
  @prefetch
end

#return_urlObject

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



1243
1244
1245
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1243

def return_url
  @return_url
end