Class: Stripe::SetupIntentCreateParams::PaymentMethodOptions::UsBankAccount::MandateOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentCreateParams::PaymentMethodOptions::UsBankAccount::MandateOptions
- Defined in:
- lib/stripe/params/setup_intent_create_params.rb
Instance Attribute Summary collapse
-
#collection_method ⇒ Object
The method used to collect offline mandate customer acceptance.
Instance Method Summary collapse
-
#initialize(collection_method: nil) ⇒ MandateOptions
constructor
A new instance of MandateOptions.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(collection_method: nil) ⇒ MandateOptions
1065 1066 1067 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1065 def initialize(collection_method: nil) @collection_method = collection_method end |
Instance Attribute Details
#collection_method ⇒ Object
The method used to collect offline mandate customer acceptance.
1063 1064 1065 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1063 def collection_method @collection_method end |