Class: Stripe::SetupIntentService::ConfirmParams::MandateData::CustomerAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/setup_intent_service.rb

Defined Under Namespace

Classes: Offline, Online

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(accepted_at: nil, offline: nil, online: nil, type: nil) ⇒ CustomerAcceptance

Returns a new instance of CustomerAcceptance.



2426
2427
2428
2429
2430
2431
# File 'lib/stripe/services/setup_intent_service.rb', line 2426

def initialize(accepted_at: nil, offline: nil, online: nil, type: nil)
  @accepted_at = accepted_at
  @offline = offline
  @online = online
  @type = type
end

Instance Attribute Details

#accepted_atObject

The time at which the customer accepted the Mandate.



2418
2419
2420
# File 'lib/stripe/services/setup_intent_service.rb', line 2418

def accepted_at
  @accepted_at
end

#offlineObject

If this is a Mandate accepted offline, this hash contains details about the offline acceptance.



2420
2421
2422
# File 'lib/stripe/services/setup_intent_service.rb', line 2420

def offline
  @offline
end

#onlineObject

If this is a Mandate accepted online, this hash contains details about the online acceptance.



2422
2423
2424
# File 'lib/stripe/services/setup_intent_service.rb', line 2422

def online
  @online
end

#typeObject

The type of customer acceptance information included with the Mandate. One of ‘online` or `offline`.



2424
2425
2426
# File 'lib/stripe/services/setup_intent_service.rb', line 2424

def type
  @type
end