Class: Stripe::SetupIntentService::ConfirmParams::MandateData::CustomerAcceptance::Online

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/setup_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(ip_address: nil, user_agent: nil) ⇒ Online

Returns a new instance of Online.



2696
2697
2698
2699
# File 'lib/stripe/services/setup_intent_service.rb', line 2696

def initialize(ip_address: nil, user_agent: nil)
  @ip_address = ip_address
  @user_agent = user_agent
end

Instance Attribute Details

#ip_addressObject

The IP address from which the Mandate was accepted by the customer.



2692
2693
2694
# File 'lib/stripe/services/setup_intent_service.rb', line 2692

def ip_address
  @ip_address
end

#user_agentObject

The user agent of the browser from which the Mandate was accepted by the customer.



2694
2695
2696
# File 'lib/stripe/services/setup_intent_service.rb', line 2694

def user_agent
  @user_agent
end