Class: Stripe::SetupIntentService::ConfirmParams::PaymentMethodData::BacsDebit
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentService::ConfirmParams::PaymentMethodData::BacsDebit
- Defined in:
- lib/stripe/services/setup_intent_service.rb
Instance Attribute Summary collapse
-
#account_number ⇒ Object
Account number of the bank account that the funds will be debited from.
-
#sort_code ⇒ Object
Sort code of the bank account.
Instance Method Summary collapse
-
#initialize(account_number: nil, sort_code: nil) ⇒ BacsDebit
constructor
A new instance of BacsDebit.
Methods inherited from RequestParams
Constructor Details
#initialize(account_number: nil, sort_code: nil) ⇒ BacsDebit
Returns a new instance of BacsDebit.
2305 2306 2307 2308 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2305 def initialize(account_number: nil, sort_code: nil) @account_number = account_number @sort_code = sort_code end |
Instance Attribute Details
#account_number ⇒ Object
Account number of the bank account that the funds will be debited from.
2301 2302 2303 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2301 def account_number @account_number end |
#sort_code ⇒ Object
Sort code of the bank account. (e.g., ‘10-20-30`)
2303 2304 2305 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2303 def sort_code @sort_code end |