Class: Stripe::SetupIntentService::ConfirmParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentService::ConfirmParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/services/setup_intent_service.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
2939 2940 2941 2942 2943 2944 2945 2946 2947 2948 2949 2950 2951 2952 2953 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2939 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
2927 2928 2929 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2927 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
2929 2930 2931 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2929 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
2931 2932 2933 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2931 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
2933 2934 2935 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2933 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
2935 2936 2937 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2935 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
2937 2938 2939 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2937 def suffix @suffix end |