Class: Stripe::SetupIntentService::ConfirmParams::PaymentMethodData::StripeBalance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentService::ConfirmParams::PaymentMethodData::StripeBalance
- Defined in:
- lib/stripe/services/setup_intent_service.rb
Instance Attribute Summary collapse
-
#account ⇒ Object
The connected account ID whose Stripe balance to use as the source of payment.
-
#source_type ⇒ Object
The [source_type](docs.stripe.com/api/balance/balance_object#balance_object-available-source_types) of the balance.
Instance Method Summary collapse
-
#initialize(account: nil, source_type: nil) ⇒ StripeBalance
constructor
A new instance of StripeBalance.
Methods inherited from RequestParams
Constructor Details
#initialize(account: nil, source_type: nil) ⇒ StripeBalance
Returns a new instance of StripeBalance.
2768 2769 2770 2771 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2768 def initialize(account: nil, source_type: nil) @account = account @source_type = source_type end |
Instance Attribute Details
#account ⇒ Object
The connected account ID whose Stripe balance to use as the source of payment
2764 2765 2766 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2764 def account @account end |
#source_type ⇒ Object
The [source_type](docs.stripe.com/api/balance/balance_object#balance_object-available-source_types) of the balance
2766 2767 2768 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2766 def source_type @source_type end |