Class: Stripe::SetupIntentService::ConfirmParams::PaymentMethodData::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentService::ConfirmParams::PaymentMethodData::UsBankAccount
- Defined in:
- lib/stripe/services/setup_intent_service.rb
Instance Attribute Summary collapse
-
#account_holder_type ⇒ Object
Account holder type: individual or company.
-
#account_number ⇒ Object
Account number of the bank account.
-
#account_type ⇒ Object
Account type: checkings or savings.
-
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
-
#routing_number ⇒ Object
Routing number of the bank account.
Instance Method Summary collapse
-
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
3074 3075 3076 3077 3078 3079 3080 3081 3082 3083 3084 3085 3086 |
# File 'lib/stripe/services/setup_intent_service.rb', line 3074 def initialize( account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil ) @account_holder_type = account_holder_type @account_number = account_number @account_type = account_type @financial_connections_account = financial_connections_account @routing_number = routing_number end |
Instance Attribute Details
#account_holder_type ⇒ Object
Account holder type: individual or company.
3064 3065 3066 |
# File 'lib/stripe/services/setup_intent_service.rb', line 3064 def account_holder_type @account_holder_type end |
#account_number ⇒ Object
Account number of the bank account.
3066 3067 3068 |
# File 'lib/stripe/services/setup_intent_service.rb', line 3066 def account_number @account_number end |
#account_type ⇒ Object
Account type: checkings or savings. Defaults to checking if omitted.
3068 3069 3070 |
# File 'lib/stripe/services/setup_intent_service.rb', line 3068 def account_type @account_type end |
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
3070 3071 3072 |
# File 'lib/stripe/services/setup_intent_service.rb', line 3070 def financial_connections_account @financial_connections_account end |
#routing_number ⇒ Object
Routing number of the bank account.
3072 3073 3074 |
# File 'lib/stripe/services/setup_intent_service.rb', line 3072 def routing_number @routing_number end |