Class: Stripe::SetupIntentService::ConfirmParams::PaymentMethodOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentService::ConfirmParams::PaymentMethodOptions
- Defined in:
- lib/stripe/services/setup_intent_service.rb
Defined Under Namespace
Classes: AcssDebit, AmazonPay, BacsDebit, Card, CardPresent, Klarna, Link, Paypal, Payto, Pix, SepaDebit, UsBankAccount
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
If this is a ‘acss_debit` SetupIntent, this sub-hash contains details about the ACSS Debit payment method options.
-
#amazon_pay ⇒ Object
If this is a ‘amazon_pay` SetupIntent, this sub-hash contains details about the AmazonPay payment method options.
-
#bacs_debit ⇒ Object
If this is a ‘bacs_debit` SetupIntent, this sub-hash contains details about the Bacs Debit payment method options.
-
#card ⇒ Object
Configuration for any card setup attempted on this SetupIntent.
-
#card_present ⇒ Object
If this is a ‘card_present` PaymentMethod, this sub-hash contains details about the card-present payment method options.
-
#klarna ⇒ Object
If this is a ‘klarna` PaymentMethod, this hash contains details about the Klarna payment method options.
-
#link ⇒ Object
If this is a ‘link` PaymentMethod, this sub-hash contains details about the Link payment method options.
-
#paypal ⇒ Object
If this is a ‘paypal` PaymentMethod, this sub-hash contains details about the PayPal payment method options.
-
#payto ⇒ Object
If this is a ‘payto` SetupIntent, this sub-hash contains details about the PayTo payment method options.
-
#pix ⇒ Object
If this is a ‘pix` SetupIntent, this sub-hash contains details about the Pix payment method options.
-
#sepa_debit ⇒ Object
If this is a ‘sepa_debit` SetupIntent, this sub-hash contains details about the SEPA Debit payment method options.
-
#us_bank_account ⇒ Object
If this is a ‘us_bank_account` SetupIntent, this sub-hash contains details about the US bank account payment method options.
Instance Method Summary collapse
-
#initialize(acss_debit: nil, amazon_pay: nil, bacs_debit: nil, card: nil, card_present: nil, klarna: nil, link: nil, paypal: nil, payto: nil, pix: nil, sepa_debit: nil, us_bank_account: nil) ⇒ PaymentMethodOptions
constructor
A new instance of PaymentMethodOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(acss_debit: nil, amazon_pay: nil, bacs_debit: nil, card: nil, card_present: nil, klarna: nil, link: nil, paypal: nil, payto: nil, pix: nil, sepa_debit: nil, us_bank_account: nil) ⇒ PaymentMethodOptions
Returns a new instance of PaymentMethodOptions.
3877 3878 3879 3880 3881 3882 3883 3884 3885 3886 3887 3888 3889 3890 3891 3892 3893 3894 3895 3896 3897 3898 3899 3900 3901 3902 3903 |
# File 'lib/stripe/services/setup_intent_service.rb', line 3877 def initialize( acss_debit: nil, amazon_pay: nil, bacs_debit: nil, card: nil, card_present: nil, klarna: nil, link: nil, paypal: nil, payto: nil, pix: nil, sepa_debit: nil, us_bank_account: nil ) @acss_debit = acss_debit @amazon_pay = amazon_pay @bacs_debit = bacs_debit @card = card @card_present = card_present @klarna = klarna @link = link @paypal = paypal @payto = payto @pix = pix @sepa_debit = sepa_debit @us_bank_account = us_bank_account end |
Instance Attribute Details
#acss_debit ⇒ Object
If this is a ‘acss_debit` SetupIntent, this sub-hash contains details about the ACSS Debit payment method options.
3853 3854 3855 |
# File 'lib/stripe/services/setup_intent_service.rb', line 3853 def acss_debit @acss_debit end |
#amazon_pay ⇒ Object
If this is a ‘amazon_pay` SetupIntent, this sub-hash contains details about the AmazonPay payment method options.
3855 3856 3857 |
# File 'lib/stripe/services/setup_intent_service.rb', line 3855 def amazon_pay @amazon_pay end |
#bacs_debit ⇒ Object
If this is a ‘bacs_debit` SetupIntent, this sub-hash contains details about the Bacs Debit payment method options.
3857 3858 3859 |
# File 'lib/stripe/services/setup_intent_service.rb', line 3857 def bacs_debit @bacs_debit end |
#card ⇒ Object
Configuration for any card setup attempted on this SetupIntent.
3859 3860 3861 |
# File 'lib/stripe/services/setup_intent_service.rb', line 3859 def card @card end |
#card_present ⇒ Object
If this is a ‘card_present` PaymentMethod, this sub-hash contains details about the card-present payment method options.
3861 3862 3863 |
# File 'lib/stripe/services/setup_intent_service.rb', line 3861 def card_present @card_present end |
#klarna ⇒ Object
If this is a ‘klarna` PaymentMethod, this hash contains details about the Klarna payment method options.
3863 3864 3865 |
# File 'lib/stripe/services/setup_intent_service.rb', line 3863 def klarna @klarna end |
#link ⇒ Object
If this is a ‘link` PaymentMethod, this sub-hash contains details about the Link payment method options.
3865 3866 3867 |
# File 'lib/stripe/services/setup_intent_service.rb', line 3865 def link @link end |
#paypal ⇒ Object
If this is a ‘paypal` PaymentMethod, this sub-hash contains details about the PayPal payment method options.
3867 3868 3869 |
# File 'lib/stripe/services/setup_intent_service.rb', line 3867 def paypal @paypal end |
#payto ⇒ Object
If this is a ‘payto` SetupIntent, this sub-hash contains details about the PayTo payment method options.
3869 3870 3871 |
# File 'lib/stripe/services/setup_intent_service.rb', line 3869 def payto @payto end |
#pix ⇒ Object
If this is a ‘pix` SetupIntent, this sub-hash contains details about the Pix payment method options.
3871 3872 3873 |
# File 'lib/stripe/services/setup_intent_service.rb', line 3871 def pix @pix end |
#sepa_debit ⇒ Object
If this is a ‘sepa_debit` SetupIntent, this sub-hash contains details about the SEPA Debit payment method options.
3873 3874 3875 |
# File 'lib/stripe/services/setup_intent_service.rb', line 3873 def sepa_debit @sepa_debit end |
#us_bank_account ⇒ Object
If this is a ‘us_bank_account` SetupIntent, this sub-hash contains details about the US bank account payment method options.
3875 3876 3877 |
# File 'lib/stripe/services/setup_intent_service.rb', line 3875 def us_bank_account @us_bank_account end |