Class: Stripe::SetupIntentService::ConfirmParams::PaymentMethodOptions::AcssDebit::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/setup_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(custom_mandate_url: nil, default_for: nil, interval_description: nil, payment_schedule: nil, transaction_type: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



3357
3358
3359
3360
3361
3362
3363
3364
3365
3366
3367
3368
3369
# File 'lib/stripe/services/setup_intent_service.rb', line 3357

def initialize(
  custom_mandate_url: nil,
  default_for: nil,
  interval_description: nil,
  payment_schedule: nil,
  transaction_type: nil
)
  @custom_mandate_url = custom_mandate_url
  @default_for = default_for
  @interval_description = interval_description
  @payment_schedule = payment_schedule
  @transaction_type = transaction_type
end

Instance Attribute Details

#custom_mandate_urlObject

A URL for custom mandate text to render during confirmation step. The URL will be rendered with additional GET parameters ‘payment_intent` and `payment_intent_client_secret` when confirming a Payment Intent, or `setup_intent` and `setup_intent_client_secret` when confirming a Setup Intent.



3347
3348
3349
# File 'lib/stripe/services/setup_intent_service.rb', line 3347

def custom_mandate_url
  @custom_mandate_url
end

#default_forObject

List of Stripe products where this mandate can be selected automatically.



3349
3350
3351
# File 'lib/stripe/services/setup_intent_service.rb', line 3349

def default_for
  @default_for
end

#interval_descriptionObject

Description of the mandate interval. Only required if ‘payment_schedule’ parameter is ‘interval’ or ‘combined’.



3351
3352
3353
# File 'lib/stripe/services/setup_intent_service.rb', line 3351

def interval_description
  @interval_description
end

#payment_scheduleObject

Payment schedule for the mandate.



3353
3354
3355
# File 'lib/stripe/services/setup_intent_service.rb', line 3353

def payment_schedule
  @payment_schedule
end

#transaction_typeObject

Transaction type of the mandate.



3355
3356
3357
# File 'lib/stripe/services/setup_intent_service.rb', line 3355

def transaction_type
  @transaction_type
end