Class: Stripe::SetupIntentService::ConfirmParams::PaymentMethodOptions::Card::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/setup_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, currency: nil, description: nil, end_date: nil, interval: nil, interval_count: nil, reference: nil, start_date: nil, supported_types: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



2683
2684
2685
2686
2687
2688
2689
2690
2691
2692
2693
2694
2695
2696
2697
2698
2699
2700
2701
2702
2703
2704
2705
# File 'lib/stripe/services/setup_intent_service.rb', line 2683

def initialize(
  amount: nil,
  amount_type: nil,
  currency: nil,
  description: nil,
  end_date: nil,
  interval: nil,
  interval_count: nil,
  reference: nil,
  start_date: nil,
  supported_types: nil
)
  @amount = amount
  @amount_type = amount_type
  @currency = currency
  @description = description
  @end_date = end_date
  @interval = interval
  @interval_count = interval_count
  @reference = reference
  @start_date = start_date
  @supported_types = supported_types
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



2663
2664
2665
# File 'lib/stripe/services/setup_intent_service.rb', line 2663

def amount
  @amount
end

#amount_typeObject

One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.



2665
2666
2667
# File 'lib/stripe/services/setup_intent_service.rb', line 2665

def amount_type
  @amount_type
end

#currencyObject

Currency in which future payments will be charged. Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



2667
2668
2669
# File 'lib/stripe/services/setup_intent_service.rb', line 2667

def currency
  @currency
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



2669
2670
2671
# File 'lib/stripe/services/setup_intent_service.rb', line 2669

def description
  @description
end

#end_dateObject

End date of the mandate or subscription. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.



2671
2672
2673
# File 'lib/stripe/services/setup_intent_service.rb', line 2671

def end_date
  @end_date
end

#intervalObject

Specifies payment frequency. One of ‘day`, `week`, `month`, `year`, or `sporadic`.



2673
2674
2675
# File 'lib/stripe/services/setup_intent_service.rb', line 2673

def interval
  @interval
end

#interval_countObject

The number of intervals between payments. For example, ‘interval=month` and `interval_count=3` indicates one payment every three months. Maximum of one year interval allowed (1 year, 12 months, or 52 weeks). This parameter is optional when `interval=sporadic`.



2675
2676
2677
# File 'lib/stripe/services/setup_intent_service.rb', line 2675

def interval_count
  @interval_count
end

#referenceObject

Unique identifier for the mandate or subscription.



2677
2678
2679
# File 'lib/stripe/services/setup_intent_service.rb', line 2677

def reference
  @reference
end

#start_dateObject

Start date of the mandate or subscription. Start date should not be lesser than yesterday.



2679
2680
2681
# File 'lib/stripe/services/setup_intent_service.rb', line 2679

def start_date
  @start_date
end

#supported_typesObject

Specifies the type of mandates supported. Possible values are ‘india`.



2681
2682
2683
# File 'lib/stripe/services/setup_intent_service.rb', line 2681

def supported_types
  @supported_types
end