Class: Stripe::SetupIntentService::ConfirmParams::PaymentMethodOptions::Card::ThreeDSecure::NetworkOptions::CartesBancaires

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/setup_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(cb_avalgo: nil, cb_exemption: nil, cb_score: nil) ⇒ CartesBancaires

Returns a new instance of CartesBancaires.



3468
3469
3470
3471
3472
# File 'lib/stripe/services/setup_intent_service.rb', line 3468

def initialize(cb_avalgo: nil, cb_exemption: nil, cb_score: nil)
  @cb_avalgo = cb_avalgo
  @cb_exemption = cb_exemption
  @cb_score = cb_score
end

Instance Attribute Details

#cb_avalgoObject

The cryptogram calculation algorithm used by the card Issuer’s ACS to calculate the Authentication cryptogram. Also known as ‘cavvAlgorithm`. messageExtension: CB-AVALGO



3458
3459
3460
# File 'lib/stripe/services/setup_intent_service.rb', line 3458

def cb_avalgo
  @cb_avalgo
end

#cb_exemptionObject

The exemption indicator returned from Cartes Bancaires in the ARes. message extension: CB-EXEMPTION; string (4 characters) This is a 3 byte bitmap (low significant byte first and most significant bit first) that has been Base64 encoded



3463
3464
3465
# File 'lib/stripe/services/setup_intent_service.rb', line 3463

def cb_exemption
  @cb_exemption
end

#cb_scoreObject

The risk score returned from Cartes Bancaires in the ARes. message extension: CB-SCORE; numeric value 0-99



3466
3467
3468
# File 'lib/stripe/services/setup_intent_service.rb', line 3466

def cb_score
  @cb_score
end