Class: Stripe::SetupIntentService::ConfirmParams::PaymentMethodOptions::Paypal

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/setup_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_agreement_id: nil, currency: nil, subsellers: nil) ⇒ Paypal

Returns a new instance of Paypal.



3281
3282
3283
3284
3285
# File 'lib/stripe/services/setup_intent_service.rb', line 3281

def initialize(billing_agreement_id: nil, currency: nil, subsellers: nil)
  @billing_agreement_id = billing_agreement_id
  @currency = currency
  @subsellers = subsellers
end

Instance Attribute Details

#billing_agreement_idObject

The PayPal Billing Agreement ID (BAID). This is an ID generated by PayPal which represents the mandate between the merchant and the customer.



3275
3276
3277
# File 'lib/stripe/services/setup_intent_service.rb', line 3275

def billing_agreement_id
  @billing_agreement_id
end

#currencyObject

Attribute for param field currency



3277
3278
3279
# File 'lib/stripe/services/setup_intent_service.rb', line 3277

def currency
  @currency
end

#subsellersObject

The Stripe connected account IDs of the sellers on the platform for this transaction (optional). Only allowed when [separate charges and transfers](stripe.com/docs/connect/separate-charges-and-transfers) are used.



3279
3280
3281
# File 'lib/stripe/services/setup_intent_service.rb', line 3279

def subsellers
  @subsellers
end