Class: Stripe::SetupIntentService::ConfirmParams::PaymentMethodOptions::Payto::MandateOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentService::ConfirmParams::PaymentMethodOptions::Payto::MandateOptions
- Defined in:
- lib/stripe/services/setup_intent_service.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount that will be collected.
-
#amount_type ⇒ Object
The type of amount that will be collected.
-
#end_date ⇒ Object
Date, in YYYY-MM-DD format, after which payments will not be collected.
-
#payment_schedule ⇒ Object
The periodicity at which payments will be collected.
-
#payments_per_period ⇒ Object
The number of payments that will be made during a payment period.
-
#purpose ⇒ Object
The purpose for which payments are made.
-
#start_date ⇒ Object
Date, in YYYY-MM-DD format, from which payments will be collected.
Instance Method Summary collapse
-
#initialize(amount: nil, amount_type: nil, end_date: nil, payment_schedule: nil, payments_per_period: nil, purpose: nil, start_date: nil) ⇒ MandateOptions
constructor
A new instance of MandateOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, amount_type: nil, end_date: nil, payment_schedule: nil, payments_per_period: nil, purpose: nil, start_date: nil) ⇒ MandateOptions
Returns a new instance of MandateOptions.
3676 3677 3678 3679 3680 3681 3682 3683 3684 3685 3686 3687 3688 3689 3690 3691 3692 |
# File 'lib/stripe/services/setup_intent_service.rb', line 3676 def initialize( amount: nil, amount_type: nil, end_date: nil, payment_schedule: nil, payments_per_period: nil, purpose: nil, start_date: nil ) @amount = amount @amount_type = amount_type @end_date = end_date @payment_schedule = payment_schedule @payments_per_period = payments_per_period @purpose = purpose @start_date = start_date end |
Instance Attribute Details
#amount ⇒ Object
Amount that will be collected. It is required when ‘amount_type` is `fixed`.
3662 3663 3664 |
# File 'lib/stripe/services/setup_intent_service.rb', line 3662 def amount @amount end |
#amount_type ⇒ Object
The type of amount that will be collected. The amount charged must be exact or up to the value of ‘amount` param for `fixed` or `maximum` type respectively.
3664 3665 3666 |
# File 'lib/stripe/services/setup_intent_service.rb', line 3664 def amount_type @amount_type end |
#end_date ⇒ Object
Date, in YYYY-MM-DD format, after which payments will not be collected. Defaults to no end date.
3666 3667 3668 |
# File 'lib/stripe/services/setup_intent_service.rb', line 3666 def end_date @end_date end |
#payment_schedule ⇒ Object
The periodicity at which payments will be collected.
3668 3669 3670 |
# File 'lib/stripe/services/setup_intent_service.rb', line 3668 def payment_schedule @payment_schedule end |
#payments_per_period ⇒ Object
The number of payments that will be made during a payment period. Defaults to 1 except for when ‘payment_schedule` is `adhoc`. In that case, it defaults to no limit.
3670 3671 3672 |
# File 'lib/stripe/services/setup_intent_service.rb', line 3670 def payments_per_period @payments_per_period end |
#purpose ⇒ Object
The purpose for which payments are made. Defaults to retail.
3672 3673 3674 |
# File 'lib/stripe/services/setup_intent_service.rb', line 3672 def purpose @purpose end |
#start_date ⇒ Object
Date, in YYYY-MM-DD format, from which payments will be collected. Defaults to confirmation time.
3674 3675 3676 |
# File 'lib/stripe/services/setup_intent_service.rb', line 3674 def start_date @start_date end |