Class: Stripe::SetupIntentService::ConfirmParams::PaymentMethodOptions::UsBankAccount::FinancialConnections

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/setup_intent_service.rb

Defined Under Namespace

Classes: Filters, ManualEntry

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections

Returns a new instance of FinancialConnections.



3381
3382
3383
3384
3385
3386
3387
3388
3389
3390
3391
3392
3393
# File 'lib/stripe/services/setup_intent_service.rb', line 3381

def initialize(
  filters: nil,
  manual_entry: nil,
  permissions: nil,
  prefetch: nil,
  return_url: nil
)
  @filters = filters
  @manual_entry = manual_entry
  @permissions = permissions
  @prefetch = prefetch
  @return_url = return_url
end

Instance Attribute Details

#filtersObject

Provide filters for the linked accounts that the customer can select for the payment method.



3371
3372
3373
# File 'lib/stripe/services/setup_intent_service.rb', line 3371

def filters
  @filters
end

#manual_entryObject

Customize manual entry behavior



3373
3374
3375
# File 'lib/stripe/services/setup_intent_service.rb', line 3373

def manual_entry
  @manual_entry
end

#permissionsObject

The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.



3375
3376
3377
# File 'lib/stripe/services/setup_intent_service.rb', line 3375

def permissions
  @permissions
end

#prefetchObject

List of data features that you would like to retrieve upon account creation.



3377
3378
3379
# File 'lib/stripe/services/setup_intent_service.rb', line 3377

def prefetch
  @prefetch
end

#return_urlObject

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



3379
3380
3381
# File 'lib/stripe/services/setup_intent_service.rb', line 3379

def return_url
  @return_url
end