Class: Stripe::SetupIntentService::CreateParams::MandateData::CustomerAcceptance::Online

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/setup_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(ip_address: nil, user_agent: nil) ⇒ Online

Returns a new instance of Online.



102
103
104
105
# File 'lib/stripe/services/setup_intent_service.rb', line 102

def initialize(ip_address: nil, user_agent: nil)
  @ip_address = ip_address
  @user_agent = user_agent
end

Instance Attribute Details

#ip_addressObject

The IP address from which the Mandate was accepted by the customer.



97
98
99
# File 'lib/stripe/services/setup_intent_service.rb', line 97

def ip_address
  @ip_address
end

#user_agentObject

The user agent of the browser from which the Mandate was accepted by the customer.



100
101
102
# File 'lib/stripe/services/setup_intent_service.rb', line 100

def user_agent
  @user_agent
end