Class: Stripe::SetupIntentService::CreateParams::PaymentMethodData::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentService::CreateParams::PaymentMethodData::UsBankAccount
- Defined in:
- lib/stripe/services/setup_intent_service.rb
Instance Attribute Summary collapse
-
#account_holder_type ⇒ Object
Account holder type: individual or company.
-
#account_number ⇒ Object
Account number of the bank account.
-
#account_type ⇒ Object
Account type: checkings or savings.
-
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
-
#routing_number ⇒ Object
Routing number of the bank account.
Instance Method Summary collapse
-
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
471 472 473 474 475 476 477 478 479 480 481 482 483 |
# File 'lib/stripe/services/setup_intent_service.rb', line 471 def initialize( account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil ) @account_holder_type = account_holder_type @account_number = account_number @account_type = account_type @financial_connections_account = financial_connections_account @routing_number = routing_number end |
Instance Attribute Details
#account_holder_type ⇒ Object
Account holder type: individual or company.
461 462 463 |
# File 'lib/stripe/services/setup_intent_service.rb', line 461 def account_holder_type @account_holder_type end |
#account_number ⇒ Object
Account number of the bank account.
463 464 465 |
# File 'lib/stripe/services/setup_intent_service.rb', line 463 def account_number @account_number end |
#account_type ⇒ Object
Account type: checkings or savings. Defaults to checking if omitted.
465 466 467 |
# File 'lib/stripe/services/setup_intent_service.rb', line 465 def account_type @account_type end |
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
467 468 469 |
# File 'lib/stripe/services/setup_intent_service.rb', line 467 def financial_connections_account @financial_connections_account end |
#routing_number ⇒ Object
Routing number of the bank account.
469 470 471 |
# File 'lib/stripe/services/setup_intent_service.rb', line 469 def routing_number @routing_number end |