Class: Stripe::SetupIntentService::CreateParams::PaymentMethodOptions::Card

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/setup_intent_service.rb

Defined Under Namespace

Classes: MandateOptions, ThreeDSecure

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(mandate_options: nil, moto: nil, network: nil, request_three_d_secure: nil, three_d_secure: nil) ⇒ Card

Returns a new instance of Card.



1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
# File 'lib/stripe/services/setup_intent_service.rb', line 1030

def initialize(
  mandate_options: nil,
  moto: nil,
  network: nil,
  request_three_d_secure: nil,
  three_d_secure: nil
)
  @mandate_options = mandate_options
  @moto = moto
  @network = network
  @request_three_d_secure = request_three_d_secure
  @three_d_secure = three_d_secure
end

Instance Attribute Details

#mandate_optionsObject

Configuration options for setting up an eMandate for cards issued in India.



1013
1014
1015
# File 'lib/stripe/services/setup_intent_service.rb', line 1013

def mandate_options
  @mandate_options
end

#motoObject

When specified, this parameter signals that a card has been collected as MOTO (Mail Order Telephone Order) and thus out of scope for SCA. This parameter can only be provided during confirmation.



1018
1019
1020
# File 'lib/stripe/services/setup_intent_service.rb', line 1018

def moto
  @moto
end

#networkObject

Selected network to process this SetupIntent on. Depends on the available networks of the card attached to the SetupIntent. Can be only set confirm-time.



1021
1022
1023
# File 'lib/stripe/services/setup_intent_service.rb', line 1021

def network
  @network
end

#request_three_d_secureObject

We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and [other requirements](stripe.com/docs/strong-customer-authentication). However, if you wish to request 3D Secure based on logic from your own fraud engine, provide this option. If not provided, this value defaults to ‘automatic`. Read our guide on [manually requesting 3D Secure](stripe.com/docs/payments/3d-secure/authentication-flow#manual-three-ds) for more information on how this configuration interacts with Radar and our SCA Engine.



1024
1025
1026
# File 'lib/stripe/services/setup_intent_service.rb', line 1024

def request_three_d_secure
  @request_three_d_secure
end

#three_d_secureObject

If 3D Secure authentication was performed with a third-party provider, the authentication details to use for this setup.



1028
1029
1030
# File 'lib/stripe/services/setup_intent_service.rb', line 1028

def three_d_secure
  @three_d_secure
end