Class: Stripe::SetupIntentService::CreateParams::PaymentMethodOptions::Klarna::OnDemand
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentService::CreateParams::PaymentMethodOptions::Klarna::OnDemand
- Defined in:
- lib/stripe/services/setup_intent_service.rb
Instance Attribute Summary collapse
-
#average_amount ⇒ Object
Your average amount value.
-
#maximum_amount ⇒ Object
The maximum value you may charge a customer per purchase.
-
#minimum_amount ⇒ Object
The lowest or minimum value you may charge a customer per purchase.
-
#purchase_interval ⇒ Object
Interval at which the customer is making purchases.
-
#purchase_interval_count ⇒ Object
The number of ‘purchase_interval` between charges.
Instance Method Summary collapse
-
#initialize(average_amount: nil, maximum_amount: nil, minimum_amount: nil, purchase_interval: nil, purchase_interval_count: nil) ⇒ OnDemand
constructor
A new instance of OnDemand.
Methods inherited from RequestParams
Constructor Details
#initialize(average_amount: nil, maximum_amount: nil, minimum_amount: nil, purchase_interval: nil, purchase_interval_count: nil) ⇒ OnDemand
Returns a new instance of OnDemand.
963 964 965 966 967 968 969 970 971 972 973 974 975 |
# File 'lib/stripe/services/setup_intent_service.rb', line 963 def initialize( average_amount: nil, maximum_amount: nil, minimum_amount: nil, purchase_interval: nil, purchase_interval_count: nil ) @average_amount = average_amount @maximum_amount = maximum_amount @minimum_amount = minimum_amount @purchase_interval = purchase_interval @purchase_interval_count = purchase_interval_count end |
Instance Attribute Details
#average_amount ⇒ Object
Your average amount value. You can use a value across your customer base, or segment based on customer type, country, etc.
953 954 955 |
# File 'lib/stripe/services/setup_intent_service.rb', line 953 def average_amount @average_amount end |
#maximum_amount ⇒ Object
The maximum value you may charge a customer per purchase. You can use a value across your customer base, or segment based on customer type, country, etc.
955 956 957 |
# File 'lib/stripe/services/setup_intent_service.rb', line 955 def maximum_amount @maximum_amount end |
#minimum_amount ⇒ Object
The lowest or minimum value you may charge a customer per purchase. You can use a value across your customer base, or segment based on customer type, country, etc.
957 958 959 |
# File 'lib/stripe/services/setup_intent_service.rb', line 957 def minimum_amount @minimum_amount end |
#purchase_interval ⇒ Object
Interval at which the customer is making purchases
959 960 961 |
# File 'lib/stripe/services/setup_intent_service.rb', line 959 def purchase_interval @purchase_interval end |
#purchase_interval_count ⇒ Object
The number of ‘purchase_interval` between charges
961 962 963 |
# File 'lib/stripe/services/setup_intent_service.rb', line 961 def purchase_interval_count @purchase_interval_count end |