Class: Stripe::SetupIntentService::CreateParams::PaymentMethodOptions::Klarna::Subscription
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentService::CreateParams::PaymentMethodOptions::Klarna::Subscription
- Defined in:
- lib/stripe/services/setup_intent_service.rb
Defined Under Namespace
Classes: NextBilling
Instance Attribute Summary collapse
-
#interval ⇒ Object
Unit of time between subscription charges.
-
#interval_count ⇒ Object
The number of intervals (specified in the ‘interval` attribute) between subscription charges.
-
#name ⇒ Object
Name for subscription.
-
#next_billing ⇒ Object
Describes the upcoming charge for this subscription.
-
#reference ⇒ Object
A non-customer-facing reference to correlate subscription charges in the Klarna app.
Instance Method Summary collapse
-
#initialize(interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil) ⇒ Subscription
constructor
A new instance of Subscription.
Methods inherited from RequestParams
Constructor Details
#initialize(interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil) ⇒ Subscription
Returns a new instance of Subscription.
1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 |
# File 'lib/stripe/services/setup_intent_service.rb', line 1001 def initialize( interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil ) @interval = interval @interval_count = interval_count @name = name @next_billing = next_billing @reference = reference end |
Instance Attribute Details
#interval ⇒ Object
Unit of time between subscription charges.
991 992 993 |
# File 'lib/stripe/services/setup_intent_service.rb', line 991 def interval @interval end |
#interval_count ⇒ Object
The number of intervals (specified in the ‘interval` attribute) between subscription charges. For example, `interval=month` and `interval_count=3` charges every 3 months.
993 994 995 |
# File 'lib/stripe/services/setup_intent_service.rb', line 993 def interval_count @interval_count end |
#name ⇒ Object
Name for subscription.
995 996 997 |
# File 'lib/stripe/services/setup_intent_service.rb', line 995 def name @name end |
#next_billing ⇒ Object
Describes the upcoming charge for this subscription.
997 998 999 |
# File 'lib/stripe/services/setup_intent_service.rb', line 997 def next_billing @next_billing end |
#reference ⇒ Object
A non-customer-facing reference to correlate subscription charges in the Klarna app. Use a value that persists across subscription charges.
999 1000 1001 |
# File 'lib/stripe/services/setup_intent_service.rb', line 999 def reference @reference end |