Class: Stripe::SetupIntentService::CreateParams::PaymentMethodOptions::Klarna::Subscription::NextBilling

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/setup_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, date: nil) ⇒ NextBilling

Returns a new instance of NextBilling.



985
986
987
988
# File 'lib/stripe/services/setup_intent_service.rb', line 985

def initialize(amount: nil, date: nil)
  @amount = amount
  @date = date
end

Instance Attribute Details

#amountObject

The amount of the next charge for the subscription.



981
982
983
# File 'lib/stripe/services/setup_intent_service.rb', line 981

def amount
  @amount
end

#dateObject

The date of the next charge for the subscription in YYYY-MM-DD format.



983
984
985
# File 'lib/stripe/services/setup_intent_service.rb', line 983

def date
  @date
end