Class: Stripe::SetupIntentService::CreateParams::PaymentMethodOptions::Paypal

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/setup_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_agreement_id: nil, currency: nil, subsellers: nil) ⇒ Paypal

Returns a new instance of Paypal.



1049
1050
1051
1052
1053
# File 'lib/stripe/services/setup_intent_service.rb', line 1049

def initialize(billing_agreement_id: nil, currency: nil, subsellers: nil)
  @billing_agreement_id = billing_agreement_id
  @currency = currency
  @subsellers = subsellers
end

Instance Attribute Details

#billing_agreement_idObject

The PayPal Billing Agreement ID (BAID). This is an ID generated by PayPal which represents the mandate between the merchant and the customer.



1043
1044
1045
# File 'lib/stripe/services/setup_intent_service.rb', line 1043

def billing_agreement_id
  @billing_agreement_id
end

#currencyObject

Attribute for param field currency



1045
1046
1047
# File 'lib/stripe/services/setup_intent_service.rb', line 1045

def currency
  @currency
end

#subsellersObject

The Stripe connected account IDs of the sellers on the platform for this transaction (optional). Only allowed when [separate charges and transfers](stripe.com/docs/connect/separate-charges-and-transfers) are used.



1047
1048
1049
# File 'lib/stripe/services/setup_intent_service.rb', line 1047

def subsellers
  @subsellers
end