Class: Stripe::SetupIntentService::CreateParams::PaymentMethodOptions::UsBankAccount::FinancialConnections

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/setup_intent_service.rb

Defined Under Namespace

Classes: Filters, ManualEntry

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections

Returns a new instance of FinancialConnections.



1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
1160
1161
# File 'lib/stripe/services/setup_intent_service.rb', line 1149

def initialize(
  filters: nil,
  manual_entry: nil,
  permissions: nil,
  prefetch: nil,
  return_url: nil
)
  @filters = filters
  @manual_entry = manual_entry
  @permissions = permissions
  @prefetch = prefetch
  @return_url = return_url
end

Instance Attribute Details

#filtersObject

Provide filters for the linked accounts that the customer can select for the payment method.



1139
1140
1141
# File 'lib/stripe/services/setup_intent_service.rb', line 1139

def filters
  @filters
end

#manual_entryObject

Customize manual entry behavior



1141
1142
1143
# File 'lib/stripe/services/setup_intent_service.rb', line 1141

def manual_entry
  @manual_entry
end

#permissionsObject

The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.



1143
1144
1145
# File 'lib/stripe/services/setup_intent_service.rb', line 1143

def permissions
  @permissions
end

#prefetchObject

List of data features that you would like to retrieve upon account creation.



1145
1146
1147
# File 'lib/stripe/services/setup_intent_service.rb', line 1145

def prefetch
  @prefetch
end

#return_urlObject

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



1147
1148
1149
# File 'lib/stripe/services/setup_intent_service.rb', line 1147

def return_url
  @return_url
end