Class: Stripe::SetupIntentService::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentService::ListParams
- Defined in:
- lib/stripe/services/setup_intent_service.rb
Defined Under Namespace
Classes: Created
Instance Attribute Summary collapse
-
#attach_to_self ⇒ Object
If present, the SetupIntent’s payment method will be attached to the in-context Stripe Account.
-
#created ⇒ Object
A filter on the list, based on the object ‘created` field.
-
#customer ⇒ Object
Only return SetupIntents for the customer specified by this customer ID.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#payment_method ⇒ Object
Only return SetupIntents that associate with the specified payment method.
-
#starting_after ⇒ Object
A cursor for use in pagination.
Instance Method Summary collapse
-
#initialize(attach_to_self: nil, created: nil, customer: nil, ending_before: nil, expand: nil, limit: nil, payment_method: nil, starting_after: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(attach_to_self: nil, created: nil, customer: nil, ending_before: nil, expand: nil, limit: nil, payment_method: nil, starting_after: nil) ⇒ ListParams
Returns a new instance of ListParams.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/stripe/services/setup_intent_service.rb', line 53 def initialize( attach_to_self: nil, created: nil, customer: nil, ending_before: nil, expand: nil, limit: nil, payment_method: nil, starting_after: nil ) @attach_to_self = attach_to_self @created = created @customer = customer @ending_before = ending_before @expand = @limit = limit @payment_method = payment_method @starting_after = starting_after end |
Instance Attribute Details
#attach_to_self ⇒ Object
If present, the SetupIntent’s payment method will be attached to the in-context Stripe Account.
It can only be used for this Stripe Account’s own money movement flows like InboundTransfer and OutboundTransfers. It cannot be set to true when setting up a PaymentMethod for a Customer, and defaults to false when attaching a PaymentMethod to a Customer.
30 31 32 |
# File 'lib/stripe/services/setup_intent_service.rb', line 30 def attach_to_self @attach_to_self end |
#created ⇒ Object
A filter on the list, based on the object ‘created` field. The value can be a string with an integer Unix timestamp, or it can be a dictionary with a number of different query options.
33 34 35 |
# File 'lib/stripe/services/setup_intent_service.rb', line 33 def created @created end |
#customer ⇒ Object
Only return SetupIntents for the customer specified by this customer ID.
36 37 38 |
# File 'lib/stripe/services/setup_intent_service.rb', line 36 def customer @customer end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
39 40 41 |
# File 'lib/stripe/services/setup_intent_service.rb', line 39 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
42 43 44 |
# File 'lib/stripe/services/setup_intent_service.rb', line 42 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
45 46 47 |
# File 'lib/stripe/services/setup_intent_service.rb', line 45 def limit @limit end |
#payment_method ⇒ Object
Only return SetupIntents that associate with the specified payment method.
48 49 50 |
# File 'lib/stripe/services/setup_intent_service.rb', line 48 def payment_method @payment_method end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
51 52 53 |
# File 'lib/stripe/services/setup_intent_service.rb', line 51 def starting_after @starting_after end |