Class: Stripe::SetupIntentService::RetrieveParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/setup_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(client_secret: nil, expand: nil) ⇒ RetrieveParams

Returns a new instance of RetrieveParams.



1423
1424
1425
1426
# File 'lib/stripe/services/setup_intent_service.rb', line 1423

def initialize(client_secret: nil, expand: nil)
  @client_secret = client_secret
  @expand = expand
end

Instance Attribute Details

#client_secretObject

The client secret of the SetupIntent. We require this string if you use a publishable key to retrieve the SetupIntent.



1419
1420
1421
# File 'lib/stripe/services/setup_intent_service.rb', line 1419

def client_secret
  @client_secret
end

#expandObject

Specifies which fields in the response should be expanded.



1421
1422
1423
# File 'lib/stripe/services/setup_intent_service.rb', line 1421

def expand
  @expand
end