Class: Stripe::SetupIntentService::UpdateParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/setup_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



1644
1645
1646
1647
1648
1649
1650
1651
1652
1653
1654
1655
1656
1657
1658
# File 'lib/stripe/services/setup_intent_service.rb', line 1644

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



1632
1633
1634
# File 'lib/stripe/services/setup_intent_service.rb', line 1632

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



1634
1635
1636
# File 'lib/stripe/services/setup_intent_service.rb', line 1634

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



1636
1637
1638
# File 'lib/stripe/services/setup_intent_service.rb', line 1636

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



1638
1639
1640
# File 'lib/stripe/services/setup_intent_service.rb', line 1638

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



1640
1641
1642
# File 'lib/stripe/services/setup_intent_service.rb', line 1640

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



1642
1643
1644
# File 'lib/stripe/services/setup_intent_service.rb', line 1642

def suffix
  @suffix
end