Class: Stripe::SetupIntentService::UpdateParams::PaymentMethodOptions::AcssDebit::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/setup_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(custom_mandate_url: nil, default_for: nil, interval_description: nil, payment_schedule: nil, transaction_type: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



2062
2063
2064
2065
2066
2067
2068
2069
2070
2071
2072
2073
2074
# File 'lib/stripe/services/setup_intent_service.rb', line 2062

def initialize(
  custom_mandate_url: nil,
  default_for: nil,
  interval_description: nil,
  payment_schedule: nil,
  transaction_type: nil
)
  @custom_mandate_url = custom_mandate_url
  @default_for = default_for
  @interval_description = interval_description
  @payment_schedule = payment_schedule
  @transaction_type = transaction_type
end

Instance Attribute Details

#custom_mandate_urlObject

A URL for custom mandate text to render during confirmation step. The URL will be rendered with additional GET parameters ‘payment_intent` and `payment_intent_client_secret` when confirming a Payment Intent, or `setup_intent` and `setup_intent_client_secret` when confirming a Setup Intent.



2052
2053
2054
# File 'lib/stripe/services/setup_intent_service.rb', line 2052

def custom_mandate_url
  @custom_mandate_url
end

#default_forObject

List of Stripe products where this mandate can be selected automatically.



2054
2055
2056
# File 'lib/stripe/services/setup_intent_service.rb', line 2054

def default_for
  @default_for
end

#interval_descriptionObject

Description of the mandate interval. Only required if ‘payment_schedule’ parameter is ‘interval’ or ‘combined’.



2056
2057
2058
# File 'lib/stripe/services/setup_intent_service.rb', line 2056

def interval_description
  @interval_description
end

#payment_scheduleObject

Payment schedule for the mandate.



2058
2059
2060
# File 'lib/stripe/services/setup_intent_service.rb', line 2058

def payment_schedule
  @payment_schedule
end

#transaction_typeObject

Transaction type of the mandate.



2060
2061
2062
# File 'lib/stripe/services/setup_intent_service.rb', line 2060

def transaction_type
  @transaction_type
end