Class: Stripe::SetupIntentService::UpdateParams::PaymentMethodOptions::Card

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/setup_intent_service.rb

Defined Under Namespace

Classes: MandateOptions, ThreeDSecure

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(mandate_options: nil, moto: nil, network: nil, request_three_d_secure: nil, three_d_secure: nil) ⇒ Card

Returns a new instance of Card.



2241
2242
2243
2244
2245
2246
2247
2248
2249
2250
2251
2252
2253
# File 'lib/stripe/services/setup_intent_service.rb', line 2241

def initialize(
  mandate_options: nil,
  moto: nil,
  network: nil,
  request_three_d_secure: nil,
  three_d_secure: nil
)
  @mandate_options = mandate_options
  @moto = moto
  @network = network
  @request_three_d_secure = request_three_d_secure
  @three_d_secure = three_d_secure
end

Instance Attribute Details

#mandate_optionsObject

Configuration options for setting up an eMandate for cards issued in India.



2228
2229
2230
# File 'lib/stripe/services/setup_intent_service.rb', line 2228

def mandate_options
  @mandate_options
end

#motoObject

When specified, this parameter signals that a card has been collected as MOTO (Mail Order Telephone Order) and thus out of scope for SCA. This parameter can only be provided during confirmation.



2232
2233
2234
# File 'lib/stripe/services/setup_intent_service.rb', line 2232

def moto
  @moto
end

#networkObject

Selected network to process this SetupIntent on. Depends on the available networks of the card attached to the SetupIntent. Can be only set confirm-time.



2234
2235
2236
# File 'lib/stripe/services/setup_intent_service.rb', line 2234

def network
  @network
end

#request_three_d_secureObject

We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and [other requirements](stripe.com/docs/strong-customer-authentication). However, if you wish to request 3D Secure based on logic from your own fraud engine, provide this option. If not provided, this value defaults to ‘automatic`. Read our guide on [manually requesting 3D Secure](stripe.com/docs/payments/3d-secure/authentication-flow#manual-three-ds) for more information on how this configuration interacts with Radar and our SCA Engine.



2236
2237
2238
# File 'lib/stripe/services/setup_intent_service.rb', line 2236

def request_three_d_secure
  @request_three_d_secure
end

#three_d_secureObject

If 3D Secure authentication was performed with a third-party provider, the authentication details to use for this setup.



2239
2240
2241
# File 'lib/stripe/services/setup_intent_service.rb', line 2239

def three_d_secure
  @three_d_secure
end