Class: Stripe::SetupIntentService::UpdateParams::PaymentMethodOptions::Card::ThreeDSecure
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentService::UpdateParams::PaymentMethodOptions::Card::ThreeDSecure
- Defined in:
- lib/stripe/services/setup_intent_service.rb
Defined Under Namespace
Classes: NetworkOptions
Instance Attribute Summary collapse
-
#ares_trans_status ⇒ Object
The ‘transStatus` returned from the card Issuer’s ACS in the ARes.
-
#cryptogram ⇒ Object
The cryptogram, also known as the “authentication value” (AAV, CAVV or AEVV).
-
#electronic_commerce_indicator ⇒ Object
The Electronic Commerce Indicator (ECI) is returned by your 3D Secure provider and indicates what degree of authentication was performed.
-
#network_options ⇒ Object
Network specific 3DS fields.
-
#requestor_challenge_indicator ⇒ Object
The challenge indicator (‘threeDSRequestorChallengeInd`) which was requested in the AReq sent to the card Issuer’s ACS.
-
#transaction_id ⇒ Object
For 3D Secure 1, the XID.
-
#version ⇒ Object
The version of 3D Secure that was performed.
Instance Method Summary collapse
-
#initialize(ares_trans_status: nil, cryptogram: nil, electronic_commerce_indicator: nil, network_options: nil, requestor_challenge_indicator: nil, transaction_id: nil, version: nil) ⇒ ThreeDSecure
constructor
A new instance of ThreeDSecure.
Methods inherited from RequestParams
Constructor Details
#initialize(ares_trans_status: nil, cryptogram: nil, electronic_commerce_indicator: nil, network_options: nil, requestor_challenge_indicator: nil, transaction_id: nil, version: nil) ⇒ ThreeDSecure
Returns a new instance of ThreeDSecure.
1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 |
# File 'lib/stripe/services/setup_intent_service.rb', line 1784 def initialize( ares_trans_status: nil, cryptogram: nil, electronic_commerce_indicator: nil, network_options: nil, requestor_challenge_indicator: nil, transaction_id: nil, version: nil ) @ares_trans_status = ares_trans_status @cryptogram = cryptogram @electronic_commerce_indicator = electronic_commerce_indicator @network_options = @requestor_challenge_indicator = requestor_challenge_indicator @transaction_id = transaction_id @version = version end |
Instance Attribute Details
#ares_trans_status ⇒ Object
The ‘transStatus` returned from the card Issuer’s ACS in the ARes.
1762 1763 1764 |
# File 'lib/stripe/services/setup_intent_service.rb', line 1762 def ares_trans_status @ares_trans_status end |
#cryptogram ⇒ Object
The cryptogram, also known as the “authentication value” (AAV, CAVV or AEVV). This value is 20 bytes, base64-encoded into a 28-character string. (Most 3D Secure providers will return the base64-encoded version, which is what you should specify here.)
1767 1768 1769 |
# File 'lib/stripe/services/setup_intent_service.rb', line 1767 def cryptogram @cryptogram end |
#electronic_commerce_indicator ⇒ Object
The Electronic Commerce Indicator (ECI) is returned by your 3D Secure provider and indicates what degree of authentication was performed.
1770 1771 1772 |
# File 'lib/stripe/services/setup_intent_service.rb', line 1770 def electronic_commerce_indicator @electronic_commerce_indicator end |
#network_options ⇒ Object
Network specific 3DS fields. Network specific arguments require an explicit card brand choice. The parameter ‘payment_method_options.card.network“ must be populated accordingly
1774 1775 1776 |
# File 'lib/stripe/services/setup_intent_service.rb', line 1774 def @network_options end |
#requestor_challenge_indicator ⇒ Object
The challenge indicator (‘threeDSRequestorChallengeInd`) which was requested in the AReq sent to the card Issuer’s ACS. A string containing 2 digits from 01-99.
1777 1778 1779 |
# File 'lib/stripe/services/setup_intent_service.rb', line 1777 def requestor_challenge_indicator @requestor_challenge_indicator end |
#transaction_id ⇒ Object
For 3D Secure 1, the XID. For 3D Secure 2, the Directory Server Transaction ID (dsTransID).
1780 1781 1782 |
# File 'lib/stripe/services/setup_intent_service.rb', line 1780 def transaction_id @transaction_id end |
#version ⇒ Object
The version of 3D Secure that was performed.
1782 1783 1784 |
# File 'lib/stripe/services/setup_intent_service.rb', line 1782 def version @version end |