Class: Stripe::SetupIntentService::UpdateParams::PaymentMethodOptions::Klarna
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentService::UpdateParams::PaymentMethodOptions::Klarna
- Defined in:
- lib/stripe/services/setup_intent_service.rb
Defined Under Namespace
Classes: OnDemand, Subscription
Instance Attribute Summary collapse
-
#currency ⇒ Object
The currency of the SetupIntent.
-
#on_demand ⇒ Object
On-demand details if setting up a payment method for on-demand payments.
-
#preferred_locale ⇒ Object
Preferred language of the Klarna authorization page that the customer is redirected to.
-
#subscriptions ⇒ Object
Subscription details if setting up or charging a subscription.
Instance Method Summary collapse
-
#initialize(currency: nil, on_demand: nil, preferred_locale: nil, subscriptions: nil) ⇒ Klarna
constructor
A new instance of Klarna.
Methods inherited from RequestParams
Constructor Details
#initialize(currency: nil, on_demand: nil, preferred_locale: nil, subscriptions: nil) ⇒ Klarna
Returns a new instance of Klarna.
2281 2282 2283 2284 2285 2286 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2281 def initialize(currency: nil, on_demand: nil, preferred_locale: nil, subscriptions: nil) @currency = currency @on_demand = on_demand @preferred_locale = preferred_locale @subscriptions = subscriptions end |
Instance Attribute Details
#currency ⇒ Object
The currency of the SetupIntent. Three letter ISO currency code.
2273 2274 2275 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2273 def currency @currency end |
#on_demand ⇒ Object
On-demand details if setting up a payment method for on-demand payments.
2275 2276 2277 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2275 def on_demand @on_demand end |
#preferred_locale ⇒ Object
Preferred language of the Klarna authorization page that the customer is redirected to
2277 2278 2279 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2277 def preferred_locale @preferred_locale end |
#subscriptions ⇒ Object
Subscription details if setting up or charging a subscription
2279 2280 2281 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2279 def subscriptions @subscriptions end |