Class: Stripe::SetupIntentService::UpdateParams::PaymentMethodOptions::Klarna::Subscription
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentService::UpdateParams::PaymentMethodOptions::Klarna::Subscription
- Defined in:
- lib/stripe/services/setup_intent_service.rb
Defined Under Namespace
Classes: NextBilling
Instance Attribute Summary collapse
-
#interval ⇒ Object
Unit of time between subscription charges.
-
#interval_count ⇒ Object
The number of intervals (specified in the ‘interval` attribute) between subscription charges.
-
#name ⇒ Object
Name for subscription.
-
#next_billing ⇒ Object
Describes the upcoming charge for this subscription.
-
#reference ⇒ Object
A non-customer-facing reference to correlate subscription charges in the Klarna app.
Instance Method Summary collapse
-
#initialize(interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil) ⇒ Subscription
constructor
A new instance of Subscription.
Methods inherited from RequestParams
Constructor Details
#initialize(interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil) ⇒ Subscription
Returns a new instance of Subscription.
2309 2310 2311 2312 2313 2314 2315 2316 2317 2318 2319 2320 2321 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2309 def initialize( interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil ) @interval = interval @interval_count = interval_count @name = name @next_billing = next_billing @reference = reference end |
Instance Attribute Details
#interval ⇒ Object
Unit of time between subscription charges.
2299 2300 2301 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2299 def interval @interval end |
#interval_count ⇒ Object
The number of intervals (specified in the ‘interval` attribute) between subscription charges. For example, `interval=month` and `interval_count=3` charges every 3 months.
2301 2302 2303 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2301 def interval_count @interval_count end |
#name ⇒ Object
Name for subscription.
2303 2304 2305 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2303 def name @name end |
#next_billing ⇒ Object
Describes the upcoming charge for this subscription.
2305 2306 2307 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2305 def next_billing @next_billing end |
#reference ⇒ Object
A non-customer-facing reference to correlate subscription charges in the Klarna app. Use a value that persists across subscription charges.
2307 2308 2309 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2307 def reference @reference end |