Class: Stripe::SetupIntentService::UpdateParams::PaymentMethodOptions::Klarna::Subscription::NextBilling

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/setup_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, date: nil) ⇒ NextBilling

Returns a new instance of NextBilling.



2293
2294
2295
2296
# File 'lib/stripe/services/setup_intent_service.rb', line 2293

def initialize(amount: nil, date: nil)
  @amount = amount
  @date = date
end

Instance Attribute Details

#amountObject

The amount of the next charge for the subscription.



2289
2290
2291
# File 'lib/stripe/services/setup_intent_service.rb', line 2289

def amount
  @amount
end

#dateObject

The date of the next charge for the subscription in YYYY-MM-DD format.



2291
2292
2293
# File 'lib/stripe/services/setup_intent_service.rb', line 2291

def date
  @date
end