Class: Stripe::SetupIntentService::UpdateParams::PaymentMethodOptions::Paypal

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/setup_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_agreement_id: nil, currency: nil, subsellers: nil) ⇒ Paypal

Returns a new instance of Paypal.



2357
2358
2359
2360
2361
# File 'lib/stripe/services/setup_intent_service.rb', line 2357

def initialize(billing_agreement_id: nil, currency: nil, subsellers: nil)
  @billing_agreement_id = billing_agreement_id
  @currency = currency
  @subsellers = subsellers
end

Instance Attribute Details

#billing_agreement_idObject

The PayPal Billing Agreement ID (BAID). This is an ID generated by PayPal which represents the mandate between the merchant and the customer.



2351
2352
2353
# File 'lib/stripe/services/setup_intent_service.rb', line 2351

def billing_agreement_id
  @billing_agreement_id
end

#currencyObject

Attribute for param field currency



2353
2354
2355
# File 'lib/stripe/services/setup_intent_service.rb', line 2353

def currency
  @currency
end

#subsellersObject

The Stripe connected account IDs of the sellers on the platform for this transaction (optional). Only allowed when [separate charges and transfers](stripe.com/docs/connect/separate-charges-and-transfers) are used.



2355
2356
2357
# File 'lib/stripe/services/setup_intent_service.rb', line 2355

def subsellers
  @subsellers
end