Class: Stripe::SetupIntentUpdateParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentUpdateParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/params/setup_intent_update_params.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 230 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
218 219 220 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 218 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
220 221 222 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 220 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
222 223 224 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 222 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
224 225 226 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 224 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
226 227 228 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 226 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
228 229 230 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 228 def suffix @suffix end |