Class: Stripe::SetupIntentUpdateParams::PaymentMethodData::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentUpdateParams::PaymentMethodData::UsBankAccount
- Defined in:
- lib/stripe/params/setup_intent_update_params.rb
Instance Attribute Summary collapse
-
#account_holder_type ⇒ Object
Account holder type: individual or company.
-
#account_number ⇒ Object
Account number of the bank account.
-
#account_type ⇒ Object
Account type: checkings or savings.
-
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
-
#routing_number ⇒ Object
Routing number of the bank account.
Instance Method Summary collapse
-
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
333 334 335 336 337 338 339 340 341 342 343 344 345 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 333 def initialize( account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil ) @account_holder_type = account_holder_type @account_number = account_number @account_type = account_type @financial_connections_account = financial_connections_account @routing_number = routing_number end |
Instance Attribute Details
#account_holder_type ⇒ Object
Account holder type: individual or company.
323 324 325 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 323 def account_holder_type @account_holder_type end |
#account_number ⇒ Object
Account number of the bank account.
325 326 327 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 325 def account_number @account_number end |
#account_type ⇒ Object
Account type: checkings or savings. Defaults to checking if omitted.
327 328 329 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 327 def account_type @account_type end |
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
329 330 331 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 329 def financial_connections_account @financial_connections_account end |
#routing_number ⇒ Object
Routing number of the bank account.
331 332 333 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 331 def routing_number @routing_number end |