Class: Stripe::SetupIntentUpdateParams::PaymentMethodOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentUpdateParams::PaymentMethodOptions
- Defined in:
- lib/stripe/params/setup_intent_update_params.rb
Defined Under Namespace
Classes: AcssDebit, AmazonPay, BacsDebit, Bizum, Card, CardPresent, Klarna, Link, Paypal, Payto, Pix, SepaDebit, StripeBalance, Upi, UsBankAccount
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
If this is a
acss_debitSetupIntent, this sub-hash contains details about the ACSS Debit payment method options. -
#amazon_pay ⇒ Object
If this is a
amazon_paySetupIntent, this sub-hash contains details about the AmazonPay payment method options. -
#bacs_debit ⇒ Object
If this is a
bacs_debitSetupIntent, this sub-hash contains details about the Bacs Debit payment method options. -
#bizum ⇒ Object
If this is a
bizumSetupIntent, this sub-hash contains details about the Bizum payment method options. -
#card ⇒ Object
Configuration for any card setup attempted on this SetupIntent.
-
#card_present ⇒ Object
If this is a
card_presentPaymentMethod, this sub-hash contains details about the card-present payment method options. -
#klarna ⇒ Object
If this is a
klarnaPaymentMethod, this hash contains details about the Klarna payment method options. -
#link ⇒ Object
If this is a
linkPaymentMethod, this sub-hash contains details about the Link payment method options (Link is also known as Onelink in the UK). -
#paypal ⇒ Object
If this is a
paypalPaymentMethod, this sub-hash contains details about the PayPal payment method options. -
#payto ⇒ Object
If this is a
paytoSetupIntent, this sub-hash contains details about the PayTo payment method options. -
#pix ⇒ Object
If this is a
pixSetupIntent, this sub-hash contains details about the Pix payment method options. -
#sepa_debit ⇒ Object
If this is a
sepa_debitSetupIntent, this sub-hash contains details about the SEPA Debit payment method options. -
#stripe_balance ⇒ Object
If this is a
stripe_balancePaymentMethod, this sub-hash contains details about the Stripe Balance payment method options. -
#upi ⇒ Object
If this is a
upiSetupIntent, this sub-hash contains details about the UPI payment method options. -
#us_bank_account ⇒ Object
If this is a
us_bank_accountSetupIntent, this sub-hash contains details about the US bank account payment method options.
Instance Method Summary collapse
-
#initialize(acss_debit: nil, amazon_pay: nil, bacs_debit: nil, bizum: nil, card: nil, card_present: nil, klarna: nil, link: nil, paypal: nil, payto: nil, pix: nil, sepa_debit: nil, stripe_balance: nil, upi: nil, us_bank_account: nil) ⇒ PaymentMethodOptions
constructor
A new instance of PaymentMethodOptions.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(acss_debit: nil, amazon_pay: nil, bacs_debit: nil, bizum: nil, card: nil, card_present: nil, klarna: nil, link: nil, paypal: nil, payto: nil, pix: nil, sepa_debit: nil, stripe_balance: nil, upi: nil, us_bank_account: nil) ⇒ PaymentMethodOptions
Returns a new instance of PaymentMethodOptions.
1286 1287 1288 1289 1290 1291 1292 1293 1294 1295 1296 1297 1298 1299 1300 1301 1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1286 def initialize( acss_debit: nil, amazon_pay: nil, bacs_debit: nil, bizum: nil, card: nil, card_present: nil, klarna: nil, link: nil, paypal: nil, payto: nil, pix: nil, sepa_debit: nil, stripe_balance: nil, upi: nil, us_bank_account: nil ) @acss_debit = acss_debit @amazon_pay = amazon_pay @bacs_debit = bacs_debit @bizum = bizum @card = card @card_present = card_present @klarna = klarna @link = link @paypal = paypal @payto = payto @pix = pix @sepa_debit = sepa_debit @stripe_balance = stripe_balance @upi = upi @us_bank_account = us_bank_account end |
Instance Attribute Details
#acss_debit ⇒ Object
If this is a acss_debit SetupIntent, this sub-hash contains details about the ACSS Debit payment method options.
1256 1257 1258 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1256 def acss_debit @acss_debit end |
#amazon_pay ⇒ Object
If this is a amazon_pay SetupIntent, this sub-hash contains details about the AmazonPay payment method options.
1258 1259 1260 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1258 def amazon_pay @amazon_pay end |
#bacs_debit ⇒ Object
If this is a bacs_debit SetupIntent, this sub-hash contains details about the Bacs Debit payment method options.
1260 1261 1262 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1260 def bacs_debit @bacs_debit end |
#bizum ⇒ Object
If this is a bizum SetupIntent, this sub-hash contains details about the Bizum payment method options.
1262 1263 1264 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1262 def bizum @bizum end |
#card ⇒ Object
Configuration for any card setup attempted on this SetupIntent.
1264 1265 1266 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1264 def card @card end |
#card_present ⇒ Object
If this is a card_present PaymentMethod, this sub-hash contains details about the card-present payment method options.
1266 1267 1268 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1266 def card_present @card_present end |
#klarna ⇒ Object
If this is a klarna PaymentMethod, this hash contains details about the Klarna payment method options.
1268 1269 1270 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1268 def klarna @klarna end |
#link ⇒ Object
If this is a link PaymentMethod, this sub-hash contains details about the Link payment method options (Link is also known as Onelink in the UK).
1270 1271 1272 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1270 def link @link end |
#paypal ⇒ Object
If this is a paypal PaymentMethod, this sub-hash contains details about the PayPal payment method options.
1272 1273 1274 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1272 def paypal @paypal end |
#payto ⇒ Object
If this is a payto SetupIntent, this sub-hash contains details about the PayTo payment method options.
1274 1275 1276 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1274 def payto @payto end |
#pix ⇒ Object
If this is a pix SetupIntent, this sub-hash contains details about the Pix payment method options.
1276 1277 1278 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1276 def pix @pix end |
#sepa_debit ⇒ Object
If this is a sepa_debit SetupIntent, this sub-hash contains details about the SEPA Debit payment method options.
1278 1279 1280 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1278 def sepa_debit @sepa_debit end |
#stripe_balance ⇒ Object
If this is a stripe_balance PaymentMethod, this sub-hash contains details about the Stripe Balance payment method options.
1280 1281 1282 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1280 def stripe_balance @stripe_balance end |
#upi ⇒ Object
If this is a upi SetupIntent, this sub-hash contains details about the UPI payment method options.
1282 1283 1284 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1282 def upi @upi end |
#us_bank_account ⇒ Object
If this is a us_bank_account SetupIntent, this sub-hash contains details about the US bank account payment method options.
1284 1285 1286 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1284 def us_bank_account @us_bank_account end |