Class: Stripe::SetupIntentUpdateParams::PaymentMethodOptions::AcssDebit::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/setup_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(custom_mandate_url: nil, default_for: nil, interval_description: nil, payment_schedule: nil, transaction_type: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



679
680
681
682
683
684
685
686
687
688
689
690
691
# File 'lib/stripe/params/setup_intent_update_params.rb', line 679

def initialize(
  custom_mandate_url: nil,
  default_for: nil,
  interval_description: nil,
  payment_schedule: nil,
  transaction_type: nil
)
  @custom_mandate_url = custom_mandate_url
  @default_for = default_for
  @interval_description = interval_description
  @payment_schedule = payment_schedule
  @transaction_type = transaction_type
end

Instance Attribute Details

#custom_mandate_urlObject

A URL for custom mandate text to render during confirmation step. The URL will be rendered with additional GET parameters ‘payment_intent` and `payment_intent_client_secret` when confirming a Payment Intent, or `setup_intent` and `setup_intent_client_secret` when confirming a Setup Intent.



669
670
671
# File 'lib/stripe/params/setup_intent_update_params.rb', line 669

def custom_mandate_url
  @custom_mandate_url
end

#default_forObject

List of Stripe products where this mandate can be selected automatically.



671
672
673
# File 'lib/stripe/params/setup_intent_update_params.rb', line 671

def default_for
  @default_for
end

#interval_descriptionObject

Description of the mandate interval. Only required if ‘payment_schedule’ parameter is ‘interval’ or ‘combined’.



673
674
675
# File 'lib/stripe/params/setup_intent_update_params.rb', line 673

def interval_description
  @interval_description
end

#payment_scheduleObject

Payment schedule for the mandate.



675
676
677
# File 'lib/stripe/params/setup_intent_update_params.rb', line 675

def payment_schedule
  @payment_schedule
end

#transaction_typeObject

Transaction type of the mandate.



677
678
679
# File 'lib/stripe/params/setup_intent_update_params.rb', line 677

def transaction_type
  @transaction_type
end