Class: Stripe::SetupIntentUpdateParams::PaymentMethodOptions::Card

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/setup_intent_update_params.rb

Defined Under Namespace

Classes: MandateOptions, ThreeDSecure

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(mandate_options: nil, moto: nil, network: nil, request_three_d_secure: nil, three_d_secure: nil) ⇒ Card

Returns a new instance of Card.



893
894
895
896
897
898
899
900
901
902
903
904
905
# File 'lib/stripe/params/setup_intent_update_params.rb', line 893

def initialize(
  mandate_options: nil,
  moto: nil,
  network: nil,
  request_three_d_secure: nil,
  three_d_secure: nil
)
  @mandate_options = mandate_options
  @moto = moto
  @network = network
  @request_three_d_secure = request_three_d_secure
  @three_d_secure = three_d_secure
end

Instance Attribute Details

#mandate_optionsObject

Configuration options for setting up an eMandate for cards issued in India.



880
881
882
# File 'lib/stripe/params/setup_intent_update_params.rb', line 880

def mandate_options
  @mandate_options
end

#motoObject

When specified, this parameter signals that a card has been collected as MOTO (Mail Order Telephone Order) and thus out of scope for SCA. This parameter can only be provided during confirmation.



884
885
886
# File 'lib/stripe/params/setup_intent_update_params.rb', line 884

def moto
  @moto
end

#networkObject

Selected network to process this SetupIntent on. Depends on the available networks of the card attached to the SetupIntent. Can be only set confirm-time.



886
887
888
# File 'lib/stripe/params/setup_intent_update_params.rb', line 886

def network
  @network
end

#request_three_d_secureObject

We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and other requirements. However, if you wish to request 3D Secure based on logic from your own fraud engine, provide this option. If not provided, this value defaults to automatic. Read our guide on manually requesting 3D Secure for more information on how this configuration interacts with Radar and our SCA Engine.



888
889
890
# File 'lib/stripe/params/setup_intent_update_params.rb', line 888

def request_three_d_secure
  @request_three_d_secure
end

#three_d_secureObject

If 3D Secure authentication was performed with a third-party provider, the authentication details to use for this setup.



891
892
893
# File 'lib/stripe/params/setup_intent_update_params.rb', line 891

def three_d_secure
  @three_d_secure
end