Class: Stripe::SetupIntentUpdateParams::PaymentMethodOptions::Card::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/setup_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, currency: nil, description: nil, end_date: nil, interval: nil, interval_count: nil, reference: nil, start_date: nil, supported_types: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
# File 'lib/stripe/params/setup_intent_update_params.rb', line 666

def initialize(
  amount: nil,
  amount_type: nil,
  currency: nil,
  description: nil,
  end_date: nil,
  interval: nil,
  interval_count: nil,
  reference: nil,
  start_date: nil,
  supported_types: nil
)
  @amount = amount
  @amount_type = amount_type
  @currency = currency
  @description = description
  @end_date = end_date
  @interval = interval
  @interval_count = interval_count
  @reference = reference
  @start_date = start_date
  @supported_types = supported_types
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments, specified in the presentment currency.



646
647
648
# File 'lib/stripe/params/setup_intent_update_params.rb', line 646

def amount
  @amount
end

#amount_typeObject

One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.



648
649
650
# File 'lib/stripe/params/setup_intent_update_params.rb', line 648

def amount_type
  @amount_type
end

#currencyObject

Currency in which future payments will be charged. Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



650
651
652
# File 'lib/stripe/params/setup_intent_update_params.rb', line 650

def currency
  @currency
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



652
653
654
# File 'lib/stripe/params/setup_intent_update_params.rb', line 652

def description
  @description
end

#end_dateObject

End date of the mandate or subscription. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.



654
655
656
# File 'lib/stripe/params/setup_intent_update_params.rb', line 654

def end_date
  @end_date
end

#intervalObject

Specifies payment frequency. One of day, week, month, year, or sporadic.



656
657
658
# File 'lib/stripe/params/setup_intent_update_params.rb', line 656

def interval
  @interval
end

#interval_countObject

The number of intervals between payments. For example, ‘interval=month` and `interval_count=3` indicates one payment every three months. Maximum of one year interval allowed (1 year, 12 months, or 52 weeks). This parameter is optional when `interval=sporadic`.



658
659
660
# File 'lib/stripe/params/setup_intent_update_params.rb', line 658

def interval_count
  @interval_count
end

#referenceObject

Unique identifier for the mandate or subscription.



660
661
662
# File 'lib/stripe/params/setup_intent_update_params.rb', line 660

def reference
  @reference
end

#start_dateObject

Start date of the mandate or subscription. Start date should not be lesser than yesterday.



662
663
664
# File 'lib/stripe/params/setup_intent_update_params.rb', line 662

def start_date
  @start_date
end

#supported_typesObject

Specifies the type of mandates supported. Possible values are india.



664
665
666
# File 'lib/stripe/params/setup_intent_update_params.rb', line 664

def supported_types
  @supported_types
end