Class: Stripe::SetupIntentUpdateParams::PaymentMethodOptions::Klarna

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/setup_intent_update_params.rb

Defined Under Namespace

Classes: OnDemand, Subscription

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(currency: nil, on_demand: nil, preferred_locale: nil, subscriptions: nil) ⇒ Klarna

Returns a new instance of Klarna.



866
867
868
869
870
871
# File 'lib/stripe/params/setup_intent_update_params.rb', line 866

def initialize(currency: nil, on_demand: nil, preferred_locale: nil, subscriptions: nil)
  @currency = currency
  @on_demand = on_demand
  @preferred_locale = preferred_locale
  @subscriptions = subscriptions
end

Instance Attribute Details

#currencyObject

The currency of the SetupIntent. Three letter ISO currency code.



858
859
860
# File 'lib/stripe/params/setup_intent_update_params.rb', line 858

def currency
  @currency
end

#on_demandObject

On-demand details if setting up a payment method for on-demand payments.



860
861
862
# File 'lib/stripe/params/setup_intent_update_params.rb', line 860

def on_demand
  @on_demand
end

#preferred_localeObject

Preferred language of the Klarna authorization page that the customer is redirected to



862
863
864
# File 'lib/stripe/params/setup_intent_update_params.rb', line 862

def preferred_locale
  @preferred_locale
end

#subscriptionsObject

Subscription details if setting up or charging a subscription



864
865
866
# File 'lib/stripe/params/setup_intent_update_params.rb', line 864

def subscriptions
  @subscriptions
end