Class: Stripe::SetupIntentUpdateParams::PaymentMethodOptions::Klarna::Subscription
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentUpdateParams::PaymentMethodOptions::Klarna::Subscription
- Defined in:
- lib/stripe/params/setup_intent_update_params.rb
Defined Under Namespace
Classes: NextBilling
Instance Attribute Summary collapse
-
#interval ⇒ Object
Unit of time between subscription charges.
-
#interval_count ⇒ Object
The number of intervals (specified in the ‘interval` attribute) between subscription charges.
-
#name ⇒ Object
Name for subscription.
-
#next_billing ⇒ Object
Describes the upcoming charge for this subscription.
-
#reference ⇒ Object
A non-customer-facing reference to correlate subscription charges in the Klarna app.
Instance Method Summary collapse
-
#initialize(interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil) ⇒ Subscription
constructor
A new instance of Subscription.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil) ⇒ Subscription
Returns a new instance of Subscription.
921 922 923 924 925 926 927 928 929 930 931 932 933 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 921 def initialize( interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil ) @interval = interval @interval_count = interval_count @name = name @next_billing = next_billing @reference = reference end |
Instance Attribute Details
#interval ⇒ Object
Unit of time between subscription charges.
911 912 913 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 911 def interval @interval end |
#interval_count ⇒ Object
The number of intervals (specified in the ‘interval` attribute) between subscription charges. For example, `interval=month` and `interval_count=3` charges every 3 months.
913 914 915 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 913 def interval_count @interval_count end |
#name ⇒ Object
Name for subscription.
915 916 917 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 915 def name @name end |
#next_billing ⇒ Object
Describes the upcoming charge for this subscription.
917 918 919 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 917 def next_billing @next_billing end |
#reference ⇒ Object
A non-customer-facing reference to correlate subscription charges in the Klarna app. Use a value that persists across subscription charges.
919 920 921 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 919 def reference @reference end |