Class: Stripe::SetupIntentUpdateParams::PaymentMethodOptions::Klarna::Subscription::NextBilling

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/setup_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, date: nil) ⇒ NextBilling

Returns a new instance of NextBilling.



922
923
924
925
# File 'lib/stripe/params/setup_intent_update_params.rb', line 922

def initialize(amount: nil, date: nil)
  @amount = amount
  @date = date
end

Instance Attribute Details

#amountObject

The amount of the next charge for the subscription.



918
919
920
# File 'lib/stripe/params/setup_intent_update_params.rb', line 918

def amount
  @amount
end

#dateObject

The date of the next charge for the subscription in YYYY-MM-DD format.



920
921
922
# File 'lib/stripe/params/setup_intent_update_params.rb', line 920

def date
  @date
end