Class: Stripe::SetupIntentUpdateParams::PaymentMethodOptions::Upi::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/setup_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



963
964
965
966
967
968
# File 'lib/stripe/params/setup_intent_update_params.rb', line 963

def initialize(amount: nil, amount_type: nil, description: nil, end_date: nil)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



955
956
957
# File 'lib/stripe/params/setup_intent_update_params.rb', line 955

def amount
  @amount
end

#amount_typeObject

One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.



957
958
959
# File 'lib/stripe/params/setup_intent_update_params.rb', line 957

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



959
960
961
# File 'lib/stripe/params/setup_intent_update_params.rb', line 959

def description
  @description
end

#end_dateObject

End date of the mandate or subscription.



961
962
963
# File 'lib/stripe/params/setup_intent_update_params.rb', line 961

def end_date
  @end_date
end