Class: Stripe::SharedPayment::GrantedToken::PaymentMethodDetails

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/shared_payment/granted_token.rb

Defined Under Namespace

Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, BillingDetails, Bizum, Blik, Boleto, Card, CardPresent, Cashapp, Crypto, CustomerBalance, Eps, Fpx, GiftCard, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Paypay, Payto, Pix, Promptpay, Qris, Rechnung, RevolutPay, SamsungPay, Satispay, Scalapay, SepaDebit, Shopeepay, Sofort, StripeBalance, Sunbit, Swish, Twint, Upi, UsBankAccount, WechatPay, Zip

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Class Method Summary collapse

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#acss_debitObject (readonly)

Attribute for field acss_debit



1376
1377
1378
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1376

def acss_debit
  @acss_debit
end

#affirmObject (readonly)

Attribute for field affirm



1378
1379
1380
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1378

def affirm
  @affirm
end

#afterpay_clearpayObject (readonly)

Attribute for field afterpay_clearpay



1380
1381
1382
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1380

def afterpay_clearpay
  @afterpay_clearpay
end

#alipayObject (readonly)

Attribute for field alipay



1382
1383
1384
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1382

def alipay
  @alipay
end

#almaObject (readonly)

Attribute for field alma



1384
1385
1386
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1384

def alma
  @alma
end

#amazon_payObject (readonly)

Attribute for field amazon_pay



1386
1387
1388
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1386

def amazon_pay
  @amazon_pay
end

#au_becs_debitObject (readonly)

Attribute for field au_becs_debit



1388
1389
1390
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1388

def au_becs_debit
  @au_becs_debit
end

#bacs_debitObject (readonly)

Attribute for field bacs_debit



1390
1391
1392
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1390

def bacs_debit
  @bacs_debit
end

#bancontactObject (readonly)

Attribute for field bancontact



1392
1393
1394
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1392

def bancontact
  @bancontact
end

#billieObject (readonly)

Attribute for field billie



1394
1395
1396
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1394

def billie
  @billie
end

#billing_detailsObject (readonly)

Billing information associated with the PaymentMethod that may be used or required by particular types of payment methods.



1396
1397
1398
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1396

def billing_details
  @billing_details
end

#bizumObject (readonly)

Attribute for field bizum



1398
1399
1400
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1398

def bizum
  @bizum
end

#blikObject (readonly)

Attribute for field blik



1400
1401
1402
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1400

def blik
  @blik
end

#boletoObject (readonly)

Attribute for field boleto



1402
1403
1404
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1402

def boleto
  @boleto
end

#cardObject (readonly)

Attribute for field card



1404
1405
1406
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1404

def card
  @card
end

#card_presentObject (readonly)

Attribute for field card_present



1406
1407
1408
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1406

def card_present
  @card_present
end

#cashappObject (readonly)

Attribute for field cashapp



1408
1409
1410
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1408

def cashapp
  @cashapp
end

#cryptoObject (readonly)

Attribute for field crypto



1410
1411
1412
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1410

def crypto
  @crypto
end

#customer_balanceObject (readonly)

Attribute for field customer_balance



1412
1413
1414
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1412

def customer_balance
  @customer_balance
end

#epsObject (readonly)

Attribute for field eps



1414
1415
1416
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1414

def eps
  @eps
end

#fpxObject (readonly)

Attribute for field fpx



1416
1417
1418
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1416

def fpx
  @fpx
end

#gift_cardObject (readonly)

Attribute for field gift_card



1418
1419
1420
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1418

def gift_card
  @gift_card
end

#giropayObject (readonly)

Attribute for field giropay



1420
1421
1422
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1420

def giropay
  @giropay
end

#gopayObject (readonly)

Attribute for field gopay



1422
1423
1424
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1422

def gopay
  @gopay
end

#grabpayObject (readonly)

Attribute for field grabpay



1424
1425
1426
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1424

def grabpay
  @grabpay
end

#id_bank_transferObject (readonly)

Attribute for field id_bank_transfer



1426
1427
1428
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1426

def id_bank_transfer
  @id_bank_transfer
end

#idealObject (readonly)

Attribute for field ideal



1428
1429
1430
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1428

def ideal
  @ideal
end

#interac_presentObject (readonly)

Attribute for field interac_present



1430
1431
1432
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1430

def interac_present
  @interac_present
end

#kakao_payObject (readonly)

Attribute for field kakao_pay



1432
1433
1434
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1432

def kakao_pay
  @kakao_pay
end

#klarnaObject (readonly)

Attribute for field klarna



1434
1435
1436
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1434

def klarna
  @klarna
end

#konbiniObject (readonly)

Attribute for field konbini



1436
1437
1438
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1436

def konbini
  @konbini
end

#kr_cardObject (readonly)

Attribute for field kr_card



1438
1439
1440
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1438

def kr_card
  @kr_card
end

Attribute for field link



1440
1441
1442
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1440

def link
  @link
end

#mb_wayObject (readonly)

Attribute for field mb_way



1442
1443
1444
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1442

def mb_way
  @mb_way
end

#mobilepayObject (readonly)

Attribute for field mobilepay



1444
1445
1446
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1444

def mobilepay
  @mobilepay
end

#multibancoObject (readonly)

Attribute for field multibanco



1446
1447
1448
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1446

def multibanco
  @multibanco
end

Attribute for field naver_pay



1448
1449
1450
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1448

def naver_pay
  @naver_pay
end

#nz_bank_accountObject (readonly)

Attribute for field nz_bank_account



1450
1451
1452
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1450

def 
  @nz_bank_account
end

#oxxoObject (readonly)

Attribute for field oxxo



1452
1453
1454
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1452

def oxxo
  @oxxo
end

#p24Object (readonly)

Attribute for field p24



1454
1455
1456
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1454

def p24
  @p24
end

#pay_by_bankObject (readonly)

Attribute for field pay_by_bank



1456
1457
1458
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1456

def pay_by_bank
  @pay_by_bank
end

#paycoObject (readonly)

Attribute for field payco



1458
1459
1460
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1458

def payco
  @payco
end

#paynowObject (readonly)

Attribute for field paynow



1460
1461
1462
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1460

def paynow
  @paynow
end

#paypalObject (readonly)

Attribute for field paypal



1462
1463
1464
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1462

def paypal
  @paypal
end

#paypayObject (readonly)

Attribute for field paypay



1464
1465
1466
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1464

def paypay
  @paypay
end

#paytoObject (readonly)

Attribute for field payto



1466
1467
1468
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1466

def payto
  @payto
end

#pixObject (readonly)

Attribute for field pix



1468
1469
1470
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1468

def pix
  @pix
end

#promptpayObject (readonly)

Attribute for field promptpay



1470
1471
1472
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1470

def promptpay
  @promptpay
end

#qrisObject (readonly)

Attribute for field qris



1472
1473
1474
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1472

def qris
  @qris
end

#rechnungObject (readonly)

Attribute for field rechnung



1474
1475
1476
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1474

def rechnung
  @rechnung
end

#revolut_payObject (readonly)

Attribute for field revolut_pay



1476
1477
1478
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1476

def revolut_pay
  @revolut_pay
end

#samsung_payObject (readonly)

Attribute for field samsung_pay



1478
1479
1480
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1478

def samsung_pay
  @samsung_pay
end

#satispayObject (readonly)

Attribute for field satispay



1480
1481
1482
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1480

def satispay
  @satispay
end

#scalapayObject (readonly)

Attribute for field scalapay



1482
1483
1484
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1482

def scalapay
  @scalapay
end

#sepa_debitObject (readonly)

Attribute for field sepa_debit



1484
1485
1486
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1484

def sepa_debit
  @sepa_debit
end

#shopeepayObject (readonly)

Attribute for field shopeepay



1486
1487
1488
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1486

def shopeepay
  @shopeepay
end

#sofortObject (readonly)

Attribute for field sofort



1488
1489
1490
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1488

def sofort
  @sofort
end

#stripe_balanceObject (readonly)

Attribute for field stripe_balance



1490
1491
1492
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1490

def stripe_balance
  @stripe_balance
end

#sunbitObject (readonly)

Attribute for field sunbit



1492
1493
1494
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1492

def sunbit
  @sunbit
end

#swishObject (readonly)

Attribute for field swish



1494
1495
1496
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1494

def swish
  @swish
end

#twintObject (readonly)

Attribute for field twint



1496
1497
1498
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1496

def twint
  @twint
end

#typeObject (readonly)

The type of the PaymentMethod. An additional hash is included on the PaymentMethod with a name matching this value. It contains additional information specific to the PaymentMethod type.



1498
1499
1500
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1498

def type
  @type
end

#upiObject (readonly)

Attribute for field upi



1500
1501
1502
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1500

def upi
  @upi
end

#us_bank_accountObject (readonly)

Attribute for field us_bank_account



1502
1503
1504
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1502

def 
  @us_bank_account
end

#wechat_payObject (readonly)

Attribute for field wechat_pay



1504
1505
1506
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1504

def wechat_pay
  @wechat_pay
end

#zipObject (readonly)

Attribute for field zip



1506
1507
1508
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1506

def zip
  @zip
end

Class Method Details

.field_remappingsObject



1578
1579
1580
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1578

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1508
1509
1510
1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
1538
1539
1540
1541
1542
1543
1544
1545
1546
1547
1548
1549
1550
1551
1552
1553
1554
1555
1556
1557
1558
1559
1560
1561
1562
1563
1564
1565
1566
1567
1568
1569
1570
1571
1572
1573
1574
1575
1576
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1508

def self.inner_class_types
  @inner_class_types = {
    acss_debit: AcssDebit,
    affirm: Affirm,
    afterpay_clearpay: AfterpayClearpay,
    alipay: Alipay,
    alma: Alma,
    amazon_pay: AmazonPay,
    au_becs_debit: AuBecsDebit,
    bacs_debit: BacsDebit,
    bancontact: Bancontact,
    billie: Billie,
    billing_details: BillingDetails,
    bizum: Bizum,
    blik: Blik,
    boleto: Boleto,
    card: Card,
    card_present: CardPresent,
    cashapp: Cashapp,
    crypto: Crypto,
    customer_balance: CustomerBalance,
    eps: Eps,
    fpx: Fpx,
    gift_card: GiftCard,
    giropay: Giropay,
    gopay: Gopay,
    grabpay: Grabpay,
    id_bank_transfer: IdBankTransfer,
    ideal: Ideal,
    interac_present: InteracPresent,
    kakao_pay: KakaoPay,
    klarna: Klarna,
    konbini: Konbini,
    kr_card: KrCard,
    link: Link,
    mb_way: MbWay,
    mobilepay: Mobilepay,
    multibanco: Multibanco,
    naver_pay: NaverPay,
    nz_bank_account: NzBankAccount,
    oxxo: Oxxo,
    p24: P24,
    pay_by_bank: PayByBank,
    payco: Payco,
    paynow: Paynow,
    paypal: Paypal,
    paypay: Paypay,
    payto: Payto,
    pix: Pix,
    promptpay: Promptpay,
    qris: Qris,
    rechnung: Rechnung,
    revolut_pay: RevolutPay,
    samsung_pay: SamsungPay,
    satispay: Satispay,
    scalapay: Scalapay,
    sepa_debit: SepaDebit,
    shopeepay: Shopeepay,
    sofort: Sofort,
    stripe_balance: StripeBalance,
    sunbit: Sunbit,
    swish: Swish,
    twint: Twint,
    upi: Upi,
    us_bank_account: UsBankAccount,
    wechat_pay: WechatPay,
    zip: Zip,
  }
end