Class: Stripe::SharedPayment::GrantedToken::PaymentMethodDetails::AcssDebit

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/shared_payment/granted_token.rb

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Class Method Summary collapse

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_numberObject (readonly)

Account number of the bank account.



30
31
32
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 30

def 
  @account_number
end

#bank_nameObject (readonly)

Name of the bank associated with the bank account.



32
33
34
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 32

def bank_name
  @bank_name
end

#fingerprintObject (readonly)

Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.



34
35
36
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 34

def fingerprint
  @fingerprint
end

#institution_numberObject (readonly)

Institution number of the bank account.



36
37
38
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 36

def institution_number
  @institution_number
end

#last4Object (readonly)

Last four digits of the bank account number.



38
39
40
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 38

def last4
  @last4
end

#transit_numberObject (readonly)

Transit number of the bank account.



40
41
42
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 40

def transit_number
  @transit_number
end

Class Method Details

.field_remappingsObject



46
47
48
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 46

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



42
43
44
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 42

def self.inner_class_types
  @inner_class_types = {}
end