Class: Stripe::SharedPayment::GrantedToken::PaymentMethodDetails::AuBecsDebit
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::SharedPayment::GrantedToken::PaymentMethodDetails::AuBecsDebit
- Defined in:
- lib/stripe/resources/shared_payment/granted_token.rb
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bsb_number ⇒ Object
readonly
Six-digit number identifying bank and branch associated with this bank account.
-
#fingerprint ⇒ Object
readonly
Uniquely identifies this particular bank account.
-
#last4 ⇒ Object
readonly
Last four digits of the bank account number.
Attributes inherited from Stripe::StripeObject
Class Method Summary collapse
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bsb_number ⇒ Object (readonly)
Six-digit number identifying bank and branch associated with this bank account.
103 104 105 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 103 def bsb_number @bsb_number end |
#fingerprint ⇒ Object (readonly)
Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.
105 106 107 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 105 def fingerprint @fingerprint end |
#last4 ⇒ Object (readonly)
Last four digits of the bank account number.
107 108 109 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 107 def last4 @last4 end |
Class Method Details
.field_remappings ⇒ Object
113 114 115 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 113 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
109 110 111 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 109 def self.inner_class_types @inner_class_types = {} end |