Class: Stripe::SharedPayment::GrantedToken::PaymentMethodDetails::Card::Wallet::VisaCheckout

Inherits:
Stripe::StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/shared_payment/granted_token.rb

Defined Under Namespace

Classes: BillingAddress, ShippingAddress

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Class Method Summary collapse

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#billing_addressObject (readonly)

Owner's verified billing address. Values are verified or provided by the wallet directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



279
280
281
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 279

def billing_address
  @billing_address
end

#emailObject (readonly)

Owner's verified email. Values are verified or provided by the wallet directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



281
282
283
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 281

def email
  @email
end

#nameObject (readonly)

Owner's verified full name. Values are verified or provided by the wallet directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



283
284
285
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 283

def name
  @name
end

#shipping_addressObject (readonly)

Owner's verified shipping address. Values are verified or provided by the wallet directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



285
286
287
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 285

def shipping_address
  @shipping_address
end

Class Method Details

.field_remappingsObject



294
295
296
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 294

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



287
288
289
290
291
292
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 287

def self.inner_class_types
  @inner_class_types = {
    billing_address: BillingAddress,
    shipping_address: ShippingAddress,
  }
end