Class: Stripe::SharedPayment::GrantedToken::PaymentMethodDetails::GiftCard

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/shared_payment/granted_token.rb

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Class Method Summary collapse

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#brandObject (readonly)

The brand of the gift card.



677
678
679
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 677

def brand
  @brand
end

#exp_monthObject (readonly)

The expiration month of the gift card.



679
680
681
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 679

def exp_month
  @exp_month
end

#exp_yearObject (readonly)

The expiration year of the gift card.



681
682
683
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 681

def exp_year
  @exp_year
end

#fingerprintObject (readonly)

Uniquely identifies the gift card.



683
684
685
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 683

def fingerprint
  @fingerprint
end

#first6Object (readonly)

The first six digits of the gift card number.



685
686
687
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 685

def first6
  @first6
end

#last4Object (readonly)

The last four digits of the gift card number.



687
688
689
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 687

def last4
  @last4
end

Class Method Details

.field_remappingsObject



693
694
695
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 693

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



689
690
691
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 689

def self.inner_class_types
  @inner_class_types = {}
end