Class: Stripe::SharedPayment::GrantedToken::PaymentMethodDetails::Link
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::SharedPayment::GrantedToken::PaymentMethodDetails::Link
- Defined in:
- lib/stripe/resources/shared_payment/granted_token.rb
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#email ⇒ Object
readonly
Account owner’s email address.
-
#persistent_token ⇒ Object
readonly
- Deprecated
-
This is a legacy parameter that no longer has any function.
Attributes inherited from Stripe::StripeObject
Class Method Summary collapse
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#email ⇒ Object (readonly)
Account owner’s email address.
850 851 852 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 850 def email @email end |
#persistent_token ⇒ Object (readonly)
- Deprecated
-
This is a legacy parameter that no longer has any function.
852 853 854 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 852 def persistent_token @persistent_token end |
Class Method Details
.field_remappings ⇒ Object
858 859 860 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 858 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
854 855 856 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 854 def self.inner_class_types @inner_class_types = {} end |