Class: Stripe::SharedPayment::GrantedToken::PaymentMethodDetails::SepaDebit

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/shared_payment/granted_token.rb

Defined Under Namespace

Classes: GeneratedFrom

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Class Method Summary collapse

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_codeObject (readonly)

Bank code of bank associated with the bank account.



1184
1185
1186
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1184

def bank_code
  @bank_code
end

#branch_codeObject (readonly)

Branch code of bank associated with the bank account.



1186
1187
1188
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1186

def branch_code
  @branch_code
end

#countryObject (readonly)

Two-letter ISO code representing the country the bank account is located in.



1188
1189
1190
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1188

def country
  @country
end

#fingerprintObject (readonly)

Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.



1190
1191
1192
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1190

def fingerprint
  @fingerprint
end

#generated_fromObject (readonly)

Information about the object that generated this PaymentMethod.



1192
1193
1194
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1192

def generated_from
  @generated_from
end

#last4Object (readonly)

Last four characters of the IBAN.



1194
1195
1196
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1194

def last4
  @last4
end

Class Method Details

.field_remappingsObject



1200
1201
1202
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1200

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1196
1197
1198
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1196

def self.inner_class_types
  @inner_class_types = { generated_from: GeneratedFrom }
end