Class: Stripe::SharedPayment::GrantedToken::UsageLimits

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/shared_payment/granted_token.rb

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Class Method Summary collapse

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



1725
1726
1727
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1725

def currency
  @currency
end

#expires_atObject (readonly)

Time at which this SharedPaymentToken expires and can no longer be used to confirm a PaymentIntent.



1727
1728
1729
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1727

def expires_at
  @expires_at
end

#max_amountObject (readonly)

Max amount that can be captured using this SharedPaymentToken.



1729
1730
1731
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1729

def max_amount
  @max_amount
end

#recurring_intervalObject (readonly)

The recurring interval at which the shared payment token’s amount usage restrictions reset.



1731
1732
1733
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1731

def recurring_interval
  @recurring_interval
end

Class Method Details

.field_remappingsObject



1737
1738
1739
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1737

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1733
1734
1735
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1733

def self.inner_class_types
  @inner_class_types = {}
end