Class: Stripe::SharedPayment::IssuedToken::SellerDetails
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::SharedPayment::IssuedToken::SellerDetails
- Defined in:
- lib/stripe/resources/shared_payment/issued_token.rb
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#external_id ⇒ Object
readonly
A unique id within a network that identifies a logical seller.
-
#network_business_profile ⇒ Object
readonly
The unique and logical string that identifies the seller platform that this SharedToken is being created for.
Attributes inherited from Stripe::StripeObject
Class Method Summary collapse
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#external_id ⇒ Object (readonly)
A unique id within a network that identifies a logical seller. This should usually be the merchant id on the seller platform.
157 158 159 |
# File 'lib/stripe/resources/shared_payment/issued_token.rb', line 157 def external_id @external_id end |
#network_business_profile ⇒ Object (readonly)
The unique and logical string that identifies the seller platform that this SharedToken is being created for.
159 160 161 |
# File 'lib/stripe/resources/shared_payment/issued_token.rb', line 159 def network_business_profile @network_business_profile end |
Class Method Details
.field_remappings ⇒ Object
165 166 167 |
# File 'lib/stripe/resources/shared_payment/issued_token.rb', line 165 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
161 162 163 |
# File 'lib/stripe/resources/shared_payment/issued_token.rb', line 161 def self.inner_class_types @inner_class_types = {} end |