Class: Stripe::SharedPayment::IssuedToken::UsageDetails::AmountCaptured
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::SharedPayment::IssuedToken::UsageDetails::AmountCaptured
- Defined in:
- lib/stripe/resources/shared_payment/issued_token.rb
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#currency ⇒ Object
readonly
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#value ⇒ Object
readonly
Integer value of the amount in the smallest currency unit.
Attributes inherited from Stripe::StripeObject
Class Method Summary collapse
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#currency ⇒ Object (readonly)
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
173 174 175 |
# File 'lib/stripe/resources/shared_payment/issued_token.rb', line 173 def currency @currency end |
#value ⇒ Object (readonly)
Integer value of the amount in the smallest currency unit.
175 176 177 |
# File 'lib/stripe/resources/shared_payment/issued_token.rb', line 175 def value @value end |
Class Method Details
.field_remappings ⇒ Object
181 182 183 |
# File 'lib/stripe/resources/shared_payment/issued_token.rb', line 181 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
177 178 179 |
# File 'lib/stripe/resources/shared_payment/issued_token.rb', line 177 def self.inner_class_types @inner_class_types = {} end |