Class: Stripe::SharedPayment::IssuedTokenCreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/shared_payment/issued_token_create_params.rb

Defined Under Namespace

Classes: SellerDetails, UsageLimits

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(expand: nil, payment_method: nil, return_url: nil, seller_details: nil, setup_future_usage: nil, shared_metadata: nil, usage_limits: nil) ⇒ IssuedTokenCreateParams

Returns a new instance of IssuedTokenCreateParams.



48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/stripe/params/shared_payment/issued_token_create_params.rb', line 48

def initialize(
  expand: nil,
  payment_method: nil,
  return_url: nil,
  seller_details: nil,
  setup_future_usage: nil,
  shared_metadata: nil,
  usage_limits: nil
)
  @expand = expand
  @payment_method = payment_method
  @return_url = return_url
  @seller_details = seller_details
  @setup_future_usage = setup_future_usage
  @shared_metadata = 
  @usage_limits = usage_limits
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



34
35
36
# File 'lib/stripe/params/shared_payment/issued_token_create_params.rb', line 34

def expand
  @expand
end

#payment_methodObject

The PaymentMethod that is going to be shared by the SharedPaymentIssuedToken.



36
37
38
# File 'lib/stripe/params/shared_payment/issued_token_create_params.rb', line 36

def payment_method
  @payment_method
end

#return_urlObject

If the customer does not exit their browser while authenticating, they will be redirected to this specified URL after completion.



38
39
40
# File 'lib/stripe/params/shared_payment/issued_token_create_params.rb', line 38

def return_url
  @return_url
end

#seller_detailsObject

Seller details of the SharedPaymentIssuedToken, including network_id and external_id.



40
41
42
# File 'lib/stripe/params/shared_payment/issued_token_create_params.rb', line 40

def seller_details
  @seller_details
end

#setup_future_usageObject

Indicates that you intend to save the PaymentMethod of this SharedPaymentToken to a customer later.



42
43
44
# File 'lib/stripe/params/shared_payment/issued_token_create_params.rb', line 42

def setup_future_usage
  @setup_future_usage
end

#shared_metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to the SharedPaymentIssuedToken. The values here are visible by default with the party that you share this SharedPaymentIssuedToken with.



44
45
46
# File 'lib/stripe/params/shared_payment/issued_token_create_params.rb', line 44

def 
  @shared_metadata
end

#usage_limitsObject

Limits on how this SharedPaymentToken can be used.



46
47
48
# File 'lib/stripe/params/shared_payment/issued_token_create_params.rb', line 46

def usage_limits
  @usage_limits
end