Class: Stripe::ShippingRate::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ShippingRate::CreateParams
- Defined in:
- lib/stripe/resources/shipping_rate.rb
Defined Under Namespace
Classes: DeliveryEstimate, FixedAmount
Instance Attribute Summary collapse
-
#delivery_estimate ⇒ Object
The estimated range for how long shipping will take, meant to be displayable to the customer.
-
#display_name ⇒ Object
The name of the shipping rate, meant to be displayable to the customer.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#fixed_amount ⇒ Object
Describes a fixed amount to charge for shipping.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#tax_behavior ⇒ Object
Specifies whether the rate is considered inclusive of taxes or exclusive of taxes.
-
#tax_code ⇒ Object
A [tax code](stripe.com/docs/tax/tax-categories) ID.
-
#type ⇒ Object
The type of calculation to use on the shipping rate.
Instance Method Summary collapse
-
#initialize(delivery_estimate: nil, display_name: nil, expand: nil, fixed_amount: nil, metadata: nil, tax_behavior: nil, tax_code: nil, type: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(delivery_estimate: nil, display_name: nil, expand: nil, fixed_amount: nil, metadata: nil, tax_behavior: nil, tax_code: nil, type: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 |
# File 'lib/stripe/resources/shipping_rate.rb', line 222 def initialize( delivery_estimate: nil, display_name: nil, expand: nil, fixed_amount: nil, metadata: nil, tax_behavior: nil, tax_code: nil, type: nil ) @delivery_estimate = delivery_estimate @display_name = display_name @expand = @fixed_amount = fixed_amount @metadata = @tax_behavior = tax_behavior @tax_code = tax_code @type = type end |
Instance Attribute Details
#delivery_estimate ⇒ Object
The estimated range for how long shipping will take, meant to be displayable to the customer. This will appear on CheckoutSessions.
206 207 208 |
# File 'lib/stripe/resources/shipping_rate.rb', line 206 def delivery_estimate @delivery_estimate end |
#display_name ⇒ Object
The name of the shipping rate, meant to be displayable to the customer. This will appear on CheckoutSessions.
208 209 210 |
# File 'lib/stripe/resources/shipping_rate.rb', line 208 def display_name @display_name end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
210 211 212 |
# File 'lib/stripe/resources/shipping_rate.rb', line 210 def @expand end |
#fixed_amount ⇒ Object
Describes a fixed amount to charge for shipping. Must be present if type is ‘fixed_amount`.
212 213 214 |
# File 'lib/stripe/resources/shipping_rate.rb', line 212 def fixed_amount @fixed_amount end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
214 215 216 |
# File 'lib/stripe/resources/shipping_rate.rb', line 214 def @metadata end |
#tax_behavior ⇒ Object
Specifies whether the rate is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`.
216 217 218 |
# File 'lib/stripe/resources/shipping_rate.rb', line 216 def tax_behavior @tax_behavior end |
#tax_code ⇒ Object
A [tax code](stripe.com/docs/tax/tax-categories) ID. The Shipping tax code is ‘txcd_92010001`.
218 219 220 |
# File 'lib/stripe/resources/shipping_rate.rb', line 218 def tax_code @tax_code end |
#type ⇒ Object
The type of calculation to use on the shipping rate.
220 221 222 |
# File 'lib/stripe/resources/shipping_rate.rb', line 220 def type @type end |