Class: Stripe::ShippingRate::CreateParams::FixedAmount::CurrencyOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/shipping_rate.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, tax_behavior: nil) ⇒ CurrencyOptions

Returns a new instance of CurrencyOptions.



187
188
189
190
# File 'lib/stripe/resources/shipping_rate.rb', line 187

def initialize(amount: nil, tax_behavior: nil)
  @amount = amount
  @tax_behavior = tax_behavior
end

Instance Attribute Details

#amountObject

A non-negative integer in cents representing how much to charge.



183
184
185
# File 'lib/stripe/resources/shipping_rate.rb', line 183

def amount
  @amount
end

#tax_behaviorObject

Specifies whether the rate is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`.



185
186
187
# File 'lib/stripe/resources/shipping_rate.rb', line 185

def tax_behavior
  @tax_behavior
end