Class: Stripe::ShippingRate::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ShippingRate::ListParams
- Defined in:
- lib/stripe/resources/shipping_rate.rb
Defined Under Namespace
Classes: Created
Instance Attribute Summary collapse
-
#active ⇒ Object
Only return shipping rates that are active or inactive.
-
#created ⇒ Object
A filter on the list, based on the object ‘created` field.
-
#currency ⇒ Object
Only return shipping rates for the given currency.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#starting_after ⇒ Object
A cursor for use in pagination.
Instance Method Summary collapse
-
#initialize(active: nil, created: nil, currency: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(active: nil, created: nil, currency: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams
Returns a new instance of ListParams.
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/stripe/resources/shipping_rate.rb', line 85 def initialize( active: nil, created: nil, currency: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil ) @active = active @created = created @currency = currency @ending_before = ending_before @expand = @limit = limit @starting_after = starting_after end |
Instance Attribute Details
#active ⇒ Object
Only return shipping rates that are active or inactive.
71 72 73 |
# File 'lib/stripe/resources/shipping_rate.rb', line 71 def active @active end |
#created ⇒ Object
A filter on the list, based on the object ‘created` field. The value can be a string with an integer Unix timestamp, or it can be a dictionary with a number of different query options.
73 74 75 |
# File 'lib/stripe/resources/shipping_rate.rb', line 73 def created @created end |
#currency ⇒ Object
Only return shipping rates for the given currency.
75 76 77 |
# File 'lib/stripe/resources/shipping_rate.rb', line 75 def currency @currency end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
77 78 79 |
# File 'lib/stripe/resources/shipping_rate.rb', line 77 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
79 80 81 |
# File 'lib/stripe/resources/shipping_rate.rb', line 79 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
81 82 83 |
# File 'lib/stripe/resources/shipping_rate.rb', line 81 def limit @limit end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
83 84 85 |
# File 'lib/stripe/resources/shipping_rate.rb', line 83 def starting_after @starting_after end |