Class: Stripe::ShippingRate::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/shipping_rate.rb

Defined Under Namespace

Classes: FixedAmount

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(active: nil, expand: nil, fixed_amount: nil, metadata: nil, tax_behavior: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



274
275
276
277
278
279
280
# File 'lib/stripe/resources/shipping_rate.rb', line 274

def initialize(active: nil, expand: nil, fixed_amount: nil, metadata: nil, tax_behavior: nil)
  @active = active
  @expand = expand
  @fixed_amount = fixed_amount
  @metadata = 
  @tax_behavior = tax_behavior
end

Instance Attribute Details

#activeObject

Whether the shipping rate can be used for new purchases. Defaults to ‘true`.



264
265
266
# File 'lib/stripe/resources/shipping_rate.rb', line 264

def active
  @active
end

#expandObject

Specifies which fields in the response should be expanded.



266
267
268
# File 'lib/stripe/resources/shipping_rate.rb', line 266

def expand
  @expand
end

#fixed_amountObject

Describes a fixed amount to charge for shipping. Must be present if type is ‘fixed_amount`.



268
269
270
# File 'lib/stripe/resources/shipping_rate.rb', line 268

def fixed_amount
  @fixed_amount
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



270
271
272
# File 'lib/stripe/resources/shipping_rate.rb', line 270

def 
  @metadata
end

#tax_behaviorObject

Specifies whether the rate is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`.



272
273
274
# File 'lib/stripe/resources/shipping_rate.rb', line 272

def tax_behavior
  @tax_behavior
end