Class: Stripe::ShippingRate::UpdateParams::FixedAmount::CurrencyOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/shipping_rate.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, tax_behavior: nil) ⇒ CurrencyOptions

Returns a new instance of CurrencyOptions.



249
250
251
252
# File 'lib/stripe/resources/shipping_rate.rb', line 249

def initialize(amount: nil, tax_behavior: nil)
  @amount = amount
  @tax_behavior = tax_behavior
end

Instance Attribute Details

#amountObject

A non-negative integer in cents representing how much to charge.



244
245
246
# File 'lib/stripe/resources/shipping_rate.rb', line 244

def amount
  @amount
end

#tax_behaviorObject

Specifies whether the rate is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`.



247
248
249
# File 'lib/stripe/resources/shipping_rate.rb', line 247

def tax_behavior
  @tax_behavior
end