Class: Stripe::ShippingRateService::CreateParams::FixedAmount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ShippingRateService::CreateParams::FixedAmount
- Defined in:
- lib/stripe/services/shipping_rate_service.rb
Defined Under Namespace
Classes: CurrencyOptions
Instance Attribute Summary collapse
-
#amount ⇒ Object
A non-negative integer in cents representing how much to charge.
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#currency_options ⇒ Object
Shipping rates defined in each available currency option.
Instance Method Summary collapse
-
#initialize(amount: nil, currency: nil, currency_options: nil) ⇒ FixedAmount
constructor
A new instance of FixedAmount.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, currency: nil, currency_options: nil) ⇒ FixedAmount
Returns a new instance of FixedAmount.
128 129 130 131 132 |
# File 'lib/stripe/services/shipping_rate_service.rb', line 128 def initialize(amount: nil, currency: nil, currency_options: nil) @amount = amount @currency = currency @currency_options = end |
Instance Attribute Details
#amount ⇒ Object
A non-negative integer in cents representing how much to charge.
120 121 122 |
# File 'lib/stripe/services/shipping_rate_service.rb', line 120 def amount @amount end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
123 124 125 |
# File 'lib/stripe/services/shipping_rate_service.rb', line 123 def currency @currency end |
#currency_options ⇒ Object
Shipping rates defined in each available currency option. Each key must be a three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html) and a [supported currency](stripe.com/docs/currencies).
126 127 128 |
# File 'lib/stripe/services/shipping_rate_service.rb', line 126 def @currency_options end |