Class: Stripe::ShippingRateService::CreateParams::FixedAmount::CurrencyOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/shipping_rate_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, tax_behavior: nil) ⇒ CurrencyOptions

Returns a new instance of CurrencyOptions.



114
115
116
117
# File 'lib/stripe/services/shipping_rate_service.rb', line 114

def initialize(amount: nil, tax_behavior: nil)
  @amount = amount
  @tax_behavior = tax_behavior
end

Instance Attribute Details

#amountObject

A non-negative integer in cents representing how much to charge.



109
110
111
# File 'lib/stripe/services/shipping_rate_service.rb', line 109

def amount
  @amount
end

#tax_behaviorObject

Specifies whether the rate is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`.



112
113
114
# File 'lib/stripe/services/shipping_rate_service.rb', line 112

def tax_behavior
  @tax_behavior
end