Class: Stripe::ShippingRateService::RetrieveParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ShippingRateService::RetrieveParams
- Defined in:
- lib/stripe/services/shipping_rate_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ RetrieveParams
constructor
A new instance of RetrieveParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ RetrieveParams
Returns a new instance of RetrieveParams.
183 184 185 |
# File 'lib/stripe/services/shipping_rate_service.rb', line 183 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
181 182 183 |
# File 'lib/stripe/services/shipping_rate_service.rb', line 181 def @expand end |