Class: Stripe::Sigma::ScheduledQueryRun
- Inherits:
-
APIResource
- Object
- Stripe::StripeObject
- APIResource
- Stripe::Sigma::ScheduledQueryRun
- Extended by:
- APIOperations::List
- Defined in:
- lib/stripe/resources/sigma/scheduled_query_run.rb
Overview
If you have [scheduled a Sigma query](stripe.com/docs/sigma/scheduled-queries), you’ll receive a ‘sigma.scheduled_query_run.created` webhook each time the query runs. The webhook contains a `ScheduledQueryRun` object, which you can use to retrieve the query results.
Defined Under Namespace
Classes: Error, ListParams
Constant Summary collapse
- OBJECT_NAME =
"scheduled_query_run"
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#data_load_time ⇒ Object
readonly
When the query was run, Sigma contained a snapshot of your Stripe data at this time.
-
#error ⇒ Object
readonly
Attribute for field error.
-
#file ⇒ Object
readonly
The file object representing the results of the query.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#result_available_until ⇒ Object
readonly
Time at which the result expires and is no longer available for download.
-
#sql ⇒ Object
readonly
SQL for the query.
-
#status ⇒ Object
readonly
The query’s execution status, which will be ‘completed` for successful runs, and `canceled`, `failed`, or `timed_out` otherwise.
-
#title ⇒ Object
readonly
Title of the query.
Attributes inherited from APIResource
Attributes inherited from Stripe::StripeObject
Class Method Summary collapse
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
-
.list(params = {}, opts = {}) ⇒ Object
Returns a list of scheduled query runs.
- .object_name ⇒ Object
- .resource_url ⇒ Object
Methods included from APIOperations::List
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
49 50 51 |
# File 'lib/stripe/resources/sigma/scheduled_query_run.rb', line 49 def created @created end |
#data_load_time ⇒ Object (readonly)
When the query was run, Sigma contained a snapshot of your Stripe data at this time.
51 52 53 |
# File 'lib/stripe/resources/sigma/scheduled_query_run.rb', line 51 def data_load_time @data_load_time end |
#error ⇒ Object (readonly)
Attribute for field error
53 54 55 |
# File 'lib/stripe/resources/sigma/scheduled_query_run.rb', line 53 def error @error end |
#file ⇒ Object (readonly)
The file object representing the results of the query.
55 56 57 |
# File 'lib/stripe/resources/sigma/scheduled_query_run.rb', line 55 def file @file end |
#id ⇒ Object (readonly)
Unique identifier for the object.
57 58 59 |
# File 'lib/stripe/resources/sigma/scheduled_query_run.rb', line 57 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
59 60 61 |
# File 'lib/stripe/resources/sigma/scheduled_query_run.rb', line 59 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
61 62 63 |
# File 'lib/stripe/resources/sigma/scheduled_query_run.rb', line 61 def object @object end |
#result_available_until ⇒ Object (readonly)
Time at which the result expires and is no longer available for download.
63 64 65 |
# File 'lib/stripe/resources/sigma/scheduled_query_run.rb', line 63 def result_available_until @result_available_until end |
#sql ⇒ Object (readonly)
SQL for the query.
65 66 67 |
# File 'lib/stripe/resources/sigma/scheduled_query_run.rb', line 65 def sql @sql end |
#status ⇒ Object (readonly)
The query’s execution status, which will be ‘completed` for successful runs, and `canceled`, `failed`, or `timed_out` otherwise.
67 68 69 |
# File 'lib/stripe/resources/sigma/scheduled_query_run.rb', line 67 def status @status end |
#title ⇒ Object (readonly)
Title of the query.
69 70 71 |
# File 'lib/stripe/resources/sigma/scheduled_query_run.rb', line 69 def title @title end |
Class Method Details
.field_remappings ⇒ Object
89 90 91 |
# File 'lib/stripe/resources/sigma/scheduled_query_run.rb', line 89 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
85 86 87 |
# File 'lib/stripe/resources/sigma/scheduled_query_run.rb', line 85 def self.inner_class_types @inner_class_types = { error: Error } end |
.list(params = {}, opts = {}) ⇒ Object
Returns a list of scheduled query runs.
72 73 74 75 76 77 78 79 |
# File 'lib/stripe/resources/sigma/scheduled_query_run.rb', line 72 def self.list(params = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/sigma/scheduled_query_runs", params: params, opts: opts ) end |
.object_name ⇒ Object
14 15 16 |
# File 'lib/stripe/resources/sigma/scheduled_query_run.rb', line 14 def self.object_name "scheduled_query_run" end |
.resource_url ⇒ Object
81 82 83 |
# File 'lib/stripe/resources/sigma/scheduled_query_run.rb', line 81 def self.resource_url "/v1/sigma/scheduled_query_runs" end |