Class: Stripe::Sigma::ScheduledQueryRun::RetrieveParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Sigma::ScheduledQueryRun::RetrieveParams
- Defined in:
- lib/stripe/resources/sigma/scheduled_query_run.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ RetrieveParams
constructor
A new instance of RetrieveParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ RetrieveParams
Returns a new instance of RetrieveParams.
45 46 47 |
# File 'lib/stripe/resources/sigma/scheduled_query_run.rb', line 45 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
43 44 45 |
# File 'lib/stripe/resources/sigma/scheduled_query_run.rb', line 43 def @expand end |