Class: Stripe::Source::CreateParams::Mandate

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/source.rb

Defined Under Namespace

Classes: Acceptance

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(acceptance: nil, amount: nil, currency: nil, interval: nil, notification_method: nil) ⇒ Mandate

Returns a new instance of Mandate.



919
920
921
922
923
924
925
926
927
928
929
930
931
# File 'lib/stripe/resources/source.rb', line 919

def initialize(
  acceptance: nil,
  amount: nil,
  currency: nil,
  interval: nil,
  notification_method: nil
)
  @acceptance = acceptance
  @amount = amount
  @currency = currency
  @interval = interval
  @notification_method = notification_method
end

Instance Attribute Details

#acceptanceObject

The parameters required to notify Stripe of a mandate acceptance or refusal by the customer.



909
910
911
# File 'lib/stripe/resources/source.rb', line 909

def acceptance
  @acceptance
end

#amountObject

The amount specified by the mandate. (Leave null for a mandate covering all amounts)



911
912
913
# File 'lib/stripe/resources/source.rb', line 911

def amount
  @amount
end

#currencyObject

The currency specified by the mandate. (Must match ‘currency` of the source)



913
914
915
# File 'lib/stripe/resources/source.rb', line 913

def currency
  @currency
end

#intervalObject

The interval of debits permitted by the mandate. Either ‘one_time` (just permitting a single debit), `scheduled` (with debits on an agreed schedule or for clearly-defined events), or `variable`(for debits with any frequency)



915
916
917
# File 'lib/stripe/resources/source.rb', line 915

def interval
  @interval
end

#notification_methodObject

The method Stripe should use to notify the customer of upcoming debit instructions and/or mandate confirmation as required by the underlying debit network. Either ‘email` (an email is sent directly to the customer), `manual` (a `source.mandate_notification` event is sent to your webhooks endpoint and you should handle the notification) or `none` (the underlying debit network does not require any notification).



917
918
919
# File 'lib/stripe/resources/source.rb', line 917

def notification_method
  @notification_method
end