Class: Stripe::Source::CreateParams::Mandate::Acceptance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Source::CreateParams::Mandate::Acceptance
- Defined in:
- lib/stripe/resources/source.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp (in seconds) when the mandate was accepted or refused by the customer.
-
#ip ⇒ Object
The IP address from which the mandate was accepted or refused by the customer.
-
#offline ⇒ Object
The parameters required to store a mandate accepted offline.
-
#online ⇒ Object
The parameters required to store a mandate accepted online.
-
#status ⇒ Object
The status of the mandate acceptance.
-
#type ⇒ Object
The type of acceptance information included with the mandate.
-
#user_agent ⇒ Object
The user agent of the browser from which the mandate was accepted or refused by the customer.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, offline: nil, online: nil, status: nil, type: nil, user_agent: nil) ⇒ Acceptance
constructor
A new instance of Acceptance.
Methods inherited from RequestParams
Constructor Details
#initialize(date: nil, ip: nil, offline: nil, online: nil, status: nil, type: nil, user_agent: nil) ⇒ Acceptance
Returns a new instance of Acceptance.
1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 |
# File 'lib/stripe/resources/source.rb', line 1130 def initialize( date: nil, ip: nil, offline: nil, online: nil, status: nil, type: nil, user_agent: nil ) @date = date @ip = ip @offline = offline @online = online @status = status @type = type @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp (in seconds) when the mandate was accepted or refused by the customer.
1116 1117 1118 |
# File 'lib/stripe/resources/source.rb', line 1116 def date @date end |
#ip ⇒ Object
The IP address from which the mandate was accepted or refused by the customer.
1118 1119 1120 |
# File 'lib/stripe/resources/source.rb', line 1118 def ip @ip end |
#offline ⇒ Object
The parameters required to store a mandate accepted offline. Should only be set if ‘mandate` is `offline`
1120 1121 1122 |
# File 'lib/stripe/resources/source.rb', line 1120 def offline @offline end |
#online ⇒ Object
The parameters required to store a mandate accepted online. Should only be set if ‘mandate` is `online`
1122 1123 1124 |
# File 'lib/stripe/resources/source.rb', line 1122 def online @online end |
#status ⇒ Object
The status of the mandate acceptance. Either ‘accepted` (the mandate was accepted) or `refused` (the mandate was refused).
1124 1125 1126 |
# File 'lib/stripe/resources/source.rb', line 1124 def status @status end |
#type ⇒ Object
The type of acceptance information included with the mandate. Either ‘online` or `offline`
1126 1127 1128 |
# File 'lib/stripe/resources/source.rb', line 1126 def type @type end |
#user_agent ⇒ Object
The user agent of the browser from which the mandate was accepted or refused by the customer.
1128 1129 1130 |
# File 'lib/stripe/resources/source.rb', line 1128 def user_agent @user_agent end |