Class: Stripe::Source::CreateParams::Mandate::Acceptance::Offline
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Source::CreateParams::Mandate::Acceptance::Offline
- Defined in:
- lib/stripe/resources/source.rb
Instance Attribute Summary collapse
-
#contact_email ⇒ Object
An email to contact you with if a copy of the mandate is requested, required if ‘type` is `offline`.
Instance Method Summary collapse
-
#initialize(contact_email: nil) ⇒ Offline
constructor
A new instance of Offline.
Methods inherited from RequestParams
Constructor Details
#initialize(contact_email: nil) ⇒ Offline
Returns a new instance of Offline.
829 830 831 |
# File 'lib/stripe/resources/source.rb', line 829 def initialize(contact_email: nil) @contact_email = contact_email end |
Instance Attribute Details
#contact_email ⇒ Object
An email to contact you with if a copy of the mandate is requested, required if ‘type` is `offline`.
827 828 829 |
# File 'lib/stripe/resources/source.rb', line 827 def contact_email @contact_email end |