Class: Stripe::Source::CreateParams::Mandate::Acceptance::Online

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/source.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ Online

Returns a new instance of Online.



1125
1126
1127
1128
1129
# File 'lib/stripe/resources/source.rb', line 1125

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp (in seconds) when the mandate was accepted or refused by the customer.



1117
1118
1119
# File 'lib/stripe/resources/source.rb', line 1117

def date
  @date
end

#ipObject

The IP address from which the mandate was accepted or refused by the customer.



1120
1121
1122
# File 'lib/stripe/resources/source.rb', line 1120

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the mandate was accepted or refused by the customer.



1123
1124
1125
# File 'lib/stripe/resources/source.rb', line 1123

def user_agent
  @user_agent
end