Class: Stripe::Source::CreateParams::Receiver

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/source.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(refund_attributes_method: nil) ⇒ Receiver

Returns a new instance of Receiver.



1260
1261
1262
# File 'lib/stripe/resources/source.rb', line 1260

def initialize(refund_attributes_method: nil)
  @refund_attributes_method = refund_attributes_method
end

Instance Attribute Details

#refund_attributes_methodObject

The method Stripe should use to request information needed to process a refund or mispayment. Either ‘email` (an email is sent directly to the customer) or `manual` (a `source.refund_attributes_required` event is sent to your webhooks endpoint). Refer to each payment method’s documentation to learn which refund attributes may be required.



1258
1259
1260
# File 'lib/stripe/resources/source.rb', line 1258

def refund_attributes_method
  @refund_attributes_method
end