Class: Stripe::Source::CreateParams::Redirect
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Source::CreateParams::Redirect
- Defined in:
- lib/stripe/resources/source.rb
Instance Attribute Summary collapse
-
#return_url ⇒ Object
The URL you provide to redirect the customer back to you after they authenticated their payment.
Instance Method Summary collapse
-
#initialize(return_url: nil) ⇒ Redirect
constructor
A new instance of Redirect.
Methods inherited from RequestParams
Constructor Details
#initialize(return_url: nil) ⇒ Redirect
Returns a new instance of Redirect.
1235 1236 1237 |
# File 'lib/stripe/resources/source.rb', line 1235 def initialize(return_url: nil) @return_url = return_url end |
Instance Attribute Details
#return_url ⇒ Object
The URL you provide to redirect the customer back to you after they authenticated their payment. It can use your application URI scheme in the context of a mobile application.
1233 1234 1235 |
# File 'lib/stripe/resources/source.rb', line 1233 def return_url @return_url end |