Class: Stripe::Source::Redirect

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/source.rb

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Class Method Summary collapse

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#failure_reasonObject (readonly)

The failure reason for the redirect, either ‘user_abort` (the customer aborted or dropped out of the redirect flow), `declined` (the authentication failed or the transaction was declined), or `processing_error` (the redirect failed due to a technical error). Present only if the redirect status is `failed`.



578
579
580
# File 'lib/stripe/resources/source.rb', line 578

def failure_reason
  @failure_reason
end

#return_urlObject (readonly)

The URL you provide to redirect the customer to after they authenticated their payment.



580
581
582
# File 'lib/stripe/resources/source.rb', line 580

def return_url
  @return_url
end

#statusObject (readonly)

The status of the redirect, either ‘pending` (ready to be used by your customer to authenticate the transaction), `succeeded` (successful authentication, cannot be reused) or `not_required` (redirect should not be used) or `failed` (failed authentication, cannot be reused).



582
583
584
# File 'lib/stripe/resources/source.rb', line 582

def status
  @status
end

#urlObject (readonly)

The URL provided to you to redirect a customer to as part of a ‘redirect` authentication flow.



584
585
586
# File 'lib/stripe/resources/source.rb', line 584

def url
  @url
end

Class Method Details

.field_remappingsObject



590
591
592
# File 'lib/stripe/resources/source.rb', line 590

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



586
587
588
# File 'lib/stripe/resources/source.rb', line 586

def self.inner_class_types
  @inner_class_types = {}
end