Class: Stripe::Source::RetrieveParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/source.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(client_secret: nil, expand: nil) ⇒ RetrieveParams

Returns a new instance of RetrieveParams.



802
803
804
805
# File 'lib/stripe/resources/source.rb', line 802

def initialize(client_secret: nil, expand: nil)
  @client_secret = client_secret
  @expand = expand
end

Instance Attribute Details

#client_secretObject

The client secret of the source. Required if a publishable key is used to retrieve the source.



797
798
799
# File 'lib/stripe/resources/source.rb', line 797

def client_secret
  @client_secret
end

#expandObject

Specifies which fields in the response should be expanded.



800
801
802
# File 'lib/stripe/resources/source.rb', line 800

def expand
  @expand
end