Class: Stripe::Source::SourceOrder::Item
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::Source::SourceOrder::Item
- Defined in:
- lib/stripe/resources/source.rb
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The amount (price) for this order item.
-
#currency ⇒ Object
readonly
This currency of this order item.
-
#description ⇒ Object
readonly
Human-readable description for this order item.
-
#parent ⇒ Object
readonly
The ID of the associated object for this line item.
-
#quantity ⇒ Object
readonly
The quantity of this order item.
-
#type ⇒ Object
readonly
The type of this order item.
Attributes inherited from Stripe::StripeObject
Class Method Summary collapse
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The amount (price) for this order item.
694 695 696 |
# File 'lib/stripe/resources/source.rb', line 694 def amount @amount end |
#currency ⇒ Object (readonly)
This currency of this order item. Required when ‘amount` is present.
696 697 698 |
# File 'lib/stripe/resources/source.rb', line 696 def currency @currency end |
#description ⇒ Object (readonly)
Human-readable description for this order item.
698 699 700 |
# File 'lib/stripe/resources/source.rb', line 698 def description @description end |
#parent ⇒ Object (readonly)
The ID of the associated object for this line item. Expandable if not null (e.g., expandable to a SKU).
700 701 702 |
# File 'lib/stripe/resources/source.rb', line 700 def parent @parent end |
#quantity ⇒ Object (readonly)
The quantity of this order item. When type is ‘sku`, this is the number of instances of the SKU to be ordered.
702 703 704 |
# File 'lib/stripe/resources/source.rb', line 702 def quantity @quantity end |
#type ⇒ Object (readonly)
The type of this order item. Must be ‘sku`, `tax`, or `shipping`.
704 705 706 |
# File 'lib/stripe/resources/source.rb', line 704 def type @type end |
Class Method Details
.field_remappings ⇒ Object
710 711 712 |
# File 'lib/stripe/resources/source.rb', line 710 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
706 707 708 |
# File 'lib/stripe/resources/source.rb', line 706 def self.inner_class_types @inner_class_types = {} end |