Class: Stripe::Source::SourceOrder::Shipping

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/source.rb

Defined Under Namespace

Classes: Address

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Class Method Summary collapse

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#addressObject (readonly)

Attribute for field address



739
740
741
# File 'lib/stripe/resources/source.rb', line 739

def address
  @address
end

#carrierObject (readonly)

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



741
742
743
# File 'lib/stripe/resources/source.rb', line 741

def carrier
  @carrier
end

#nameObject (readonly)

Recipient name.



743
744
745
# File 'lib/stripe/resources/source.rb', line 743

def name
  @name
end

#phoneObject (readonly)

Recipient phone (including extension).



745
746
747
# File 'lib/stripe/resources/source.rb', line 745

def phone
  @phone
end

#tracking_numberObject (readonly)

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



747
748
749
# File 'lib/stripe/resources/source.rb', line 747

def tracking_number
  @tracking_number
end

Class Method Details

.field_remappingsObject



753
754
755
# File 'lib/stripe/resources/source.rb', line 753

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



749
750
751
# File 'lib/stripe/resources/source.rb', line 749

def self.inner_class_types
  @inner_class_types = { address: Address }
end