Class: Stripe::Source::UpdateParams::Mandate
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Source::UpdateParams::Mandate
- Defined in:
- lib/stripe/resources/source.rb
Defined Under Namespace
Classes: Acceptance
Instance Attribute Summary collapse
-
#acceptance ⇒ Object
The parameters required to notify Stripe of a mandate acceptance or refusal by the customer.
-
#amount ⇒ Object
The amount specified by the mandate.
-
#currency ⇒ Object
The currency specified by the mandate.
-
#interval ⇒ Object
The interval of debits permitted by the mandate.
-
#notification_method ⇒ Object
The method Stripe should use to notify the customer of upcoming debit instructions and/or mandate confirmation as required by the underlying debit network.
Instance Method Summary collapse
-
#initialize(acceptance: nil, amount: nil, currency: nil, interval: nil, notification_method: nil) ⇒ Mandate
constructor
A new instance of Mandate.
Methods inherited from RequestParams
Constructor Details
#initialize(acceptance: nil, amount: nil, currency: nil, interval: nil, notification_method: nil) ⇒ Mandate
Returns a new instance of Mandate.
664 665 666 667 668 669 670 671 672 673 674 675 676 |
# File 'lib/stripe/resources/source.rb', line 664 def initialize( acceptance: nil, amount: nil, currency: nil, interval: nil, notification_method: nil ) @acceptance = acceptance @amount = amount @currency = currency @interval = interval @notification_method = notification_method end |
Instance Attribute Details
#acceptance ⇒ Object
The parameters required to notify Stripe of a mandate acceptance or refusal by the customer.
654 655 656 |
# File 'lib/stripe/resources/source.rb', line 654 def acceptance @acceptance end |
#amount ⇒ Object
The amount specified by the mandate. (Leave null for a mandate covering all amounts)
656 657 658 |
# File 'lib/stripe/resources/source.rb', line 656 def amount @amount end |
#currency ⇒ Object
The currency specified by the mandate. (Must match ‘currency` of the source)
658 659 660 |
# File 'lib/stripe/resources/source.rb', line 658 def currency @currency end |
#interval ⇒ Object
The interval of debits permitted by the mandate. Either ‘one_time` (just permitting a single debit), `scheduled` (with debits on an agreed schedule or for clearly-defined events), or `variable`(for debits with any frequency)
660 661 662 |
# File 'lib/stripe/resources/source.rb', line 660 def interval @interval end |
#notification_method ⇒ Object
The method Stripe should use to notify the customer of upcoming debit instructions and/or mandate confirmation as required by the underlying debit network. Either ‘email` (an email is sent directly to the customer), `manual` (a `source.mandate_notification` event is sent to your webhooks endpoint and you should handle the notification) or `none` (the underlying debit network does not require any notification).
662 663 664 |
# File 'lib/stripe/resources/source.rb', line 662 def notification_method @notification_method end |