Class: Stripe::Source::UpdateParams::Mandate::Acceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/source.rb

Defined Under Namespace

Classes: Offline, Online

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, offline: nil, online: nil, status: nil, type: nil, user_agent: nil) ⇒ Acceptance

Returns a new instance of Acceptance.



875
876
877
878
879
880
881
882
883
884
885
886
887
888
889
890
891
# File 'lib/stripe/resources/source.rb', line 875

def initialize(
  date: nil,
  ip: nil,
  offline: nil,
  online: nil,
  status: nil,
  type: nil,
  user_agent: nil
)
  @date = date
  @ip = ip
  @offline = offline
  @online = online
  @status = status
  @type = type
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp (in seconds) when the mandate was accepted or refused by the customer.



861
862
863
# File 'lib/stripe/resources/source.rb', line 861

def date
  @date
end

#ipObject

The IP address from which the mandate was accepted or refused by the customer.



863
864
865
# File 'lib/stripe/resources/source.rb', line 863

def ip
  @ip
end

#offlineObject

The parameters required to store a mandate accepted offline. Should only be set if ‘mandate` is `offline`



865
866
867
# File 'lib/stripe/resources/source.rb', line 865

def offline
  @offline
end

#onlineObject

The parameters required to store a mandate accepted online. Should only be set if ‘mandate` is `online`



867
868
869
# File 'lib/stripe/resources/source.rb', line 867

def online
  @online
end

#statusObject

The status of the mandate acceptance. Either ‘accepted` (the mandate was accepted) or `refused` (the mandate was refused).



869
870
871
# File 'lib/stripe/resources/source.rb', line 869

def status
  @status
end

#typeObject

The type of acceptance information included with the mandate. Either ‘online` or `offline`



871
872
873
# File 'lib/stripe/resources/source.rb', line 871

def type
  @type
end

#user_agentObject

The user agent of the browser from which the mandate was accepted or refused by the customer.



873
874
875
# File 'lib/stripe/resources/source.rb', line 873

def user_agent
  @user_agent
end