Class: Stripe::Source::VerifyParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Source::VerifyParams
- Defined in:
- lib/stripe/resources/source.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#values ⇒ Object
The values needed to verify the source.
Instance Method Summary collapse
-
#initialize(expand: nil, values: nil) ⇒ VerifyParams
constructor
A new instance of VerifyParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, values: nil) ⇒ VerifyParams
Returns a new instance of VerifyParams.
1408 1409 1410 1411 |
# File 'lib/stripe/resources/source.rb', line 1408 def initialize(expand: nil, values: nil) @expand = @values = values end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1404 1405 1406 |
# File 'lib/stripe/resources/source.rb', line 1404 def @expand end |
#values ⇒ Object
The values needed to verify the source.
1406 1407 1408 |
# File 'lib/stripe/resources/source.rb', line 1406 def values @values end |