Class: Stripe::SourceService::CreateParams::Mandate::Acceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/source_service.rb

Defined Under Namespace

Classes: Offline, Online

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, offline: nil, online: nil, status: nil, type: nil, user_agent: nil) ⇒ Acceptance

Returns a new instance of Acceptance.



379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
# File 'lib/stripe/services/source_service.rb', line 379

def initialize(
  date: nil,
  ip: nil,
  offline: nil,
  online: nil,
  status: nil,
  type: nil,
  user_agent: nil
)
  @date = date
  @ip = ip
  @offline = offline
  @online = online
  @status = status
  @type = type
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp (in seconds) when the mandate was accepted or refused by the customer.



359
360
361
# File 'lib/stripe/services/source_service.rb', line 359

def date
  @date
end

#ipObject

The IP address from which the mandate was accepted or refused by the customer.



362
363
364
# File 'lib/stripe/services/source_service.rb', line 362

def ip
  @ip
end

#offlineObject

The parameters required to store a mandate accepted offline. Should only be set if ‘mandate` is `offline`



365
366
367
# File 'lib/stripe/services/source_service.rb', line 365

def offline
  @offline
end

#onlineObject

The parameters required to store a mandate accepted online. Should only be set if ‘mandate` is `online`



368
369
370
# File 'lib/stripe/services/source_service.rb', line 368

def online
  @online
end

#statusObject

The status of the mandate acceptance. Either ‘accepted` (the mandate was accepted) or `refused` (the mandate was refused).



371
372
373
# File 'lib/stripe/services/source_service.rb', line 371

def status
  @status
end

#typeObject

The type of acceptance information included with the mandate. Either ‘online` or `offline`



374
375
376
# File 'lib/stripe/services/source_service.rb', line 374

def type
  @type
end

#user_agentObject

The user agent of the browser from which the mandate was accepted or refused by the customer.



377
378
379
# File 'lib/stripe/services/source_service.rb', line 377

def user_agent
  @user_agent
end