Class: Stripe::SourceService::CreateParams::Mandate::Acceptance::Online

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/source_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ Online

Returns a new instance of Online.



352
353
354
355
356
# File 'lib/stripe/services/source_service.rb', line 352

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp (in seconds) when the mandate was accepted or refused by the customer.



344
345
346
# File 'lib/stripe/services/source_service.rb', line 344

def date
  @date
end

#ipObject

The IP address from which the mandate was accepted or refused by the customer.



347
348
349
# File 'lib/stripe/services/source_service.rb', line 347

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the mandate was accepted or refused by the customer.



350
351
352
# File 'lib/stripe/services/source_service.rb', line 350

def user_agent
  @user_agent
end