Class: Stripe::SourceService::CreateParams::SourceOrder::Shipping
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SourceService::CreateParams::SourceOrder::Shipping
- Defined in:
- lib/stripe/services/source_service.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Shipping address.
-
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
-
#name ⇒ Object
Recipient name.
-
#phone ⇒ Object
Recipient phone (including extension).
-
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service.
Instance Method Summary collapse
-
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
constructor
A new instance of Shipping.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
Returns a new instance of Shipping.
589 590 591 592 593 594 595 |
# File 'lib/stripe/services/source_service.rb', line 589 def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) @address = address @carrier = carrier @name = name @phone = phone @tracking_number = tracking_number end |
Instance Attribute Details
#address ⇒ Object
Shipping address.
575 576 577 |
# File 'lib/stripe/services/source_service.rb', line 575 def address @address end |
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
578 579 580 |
# File 'lib/stripe/services/source_service.rb', line 578 def carrier @carrier end |
#name ⇒ Object
Recipient name.
581 582 583 |
# File 'lib/stripe/services/source_service.rb', line 581 def name @name end |
#phone ⇒ Object
Recipient phone (including extension).
584 585 586 |
# File 'lib/stripe/services/source_service.rb', line 584 def phone @phone end |
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
587 588 589 |
# File 'lib/stripe/services/source_service.rb', line 587 def tracking_number @tracking_number end |