Class: Stripe::SourceService::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/source_service.rb

Defined Under Namespace

Classes: Mandate, Owner, SourceOrder

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, expand: nil, mandate: nil, metadata: nil, owner: nil, source_order: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
# File 'lib/stripe/services/source_service.rb', line 313

def initialize(
  amount: nil,
  expand: nil,
  mandate: nil,
  metadata: nil,
  owner: nil,
  source_order: nil
)
  @amount = amount
  @expand = expand
  @mandate = mandate
  @metadata = 
  @owner = owner
  @source_order = source_order
end

Instance Attribute Details

#amountObject

Amount associated with the source.



296
297
298
# File 'lib/stripe/services/source_service.rb', line 296

def amount
  @amount
end

#expandObject

Specifies which fields in the response should be expanded.



299
300
301
# File 'lib/stripe/services/source_service.rb', line 299

def expand
  @expand
end

#mandateObject

Information about a mandate possibility attached to a source object (generally for bank debits) as well as its acceptance status.



302
303
304
# File 'lib/stripe/services/source_service.rb', line 302

def mandate
  @mandate
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



305
306
307
# File 'lib/stripe/services/source_service.rb', line 305

def 
  @metadata
end

#ownerObject

Information about the owner of the payment instrument that may be used or required by particular source types.



308
309
310
# File 'lib/stripe/services/source_service.rb', line 308

def owner
  @owner
end

#source_orderObject

Information about the items and shipping associated with the source. Required for transactional credit (for example Klarna) sources before you can charge it.



311
312
313
# File 'lib/stripe/services/source_service.rb', line 311

def source_order
  @source_order
end