Class: Stripe::SourceService::UpdateParams::Mandate::Acceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/source_service.rb

Defined Under Namespace

Classes: Offline, Online

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, offline: nil, online: nil, status: nil, type: nil, user_agent: nil) ⇒ Acceptance

Returns a new instance of Acceptance.



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/stripe/services/source_service.rb', line 84

def initialize(
  date: nil,
  ip: nil,
  offline: nil,
  online: nil,
  status: nil,
  type: nil,
  user_agent: nil
)
  @date = date
  @ip = ip
  @offline = offline
  @online = online
  @status = status
  @type = type
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp (in seconds) when the mandate was accepted or refused by the customer.



64
65
66
# File 'lib/stripe/services/source_service.rb', line 64

def date
  @date
end

#ipObject

The IP address from which the mandate was accepted or refused by the customer.



67
68
69
# File 'lib/stripe/services/source_service.rb', line 67

def ip
  @ip
end

#offlineObject

The parameters required to store a mandate accepted offline. Should only be set if ‘mandate` is `offline`



70
71
72
# File 'lib/stripe/services/source_service.rb', line 70

def offline
  @offline
end

#onlineObject

The parameters required to store a mandate accepted online. Should only be set if ‘mandate` is `online`



73
74
75
# File 'lib/stripe/services/source_service.rb', line 73

def online
  @online
end

#statusObject

The status of the mandate acceptance. Either ‘accepted` (the mandate was accepted) or `refused` (the mandate was refused).



76
77
78
# File 'lib/stripe/services/source_service.rb', line 76

def status
  @status
end

#typeObject

The type of acceptance information included with the mandate. Either ‘online` or `offline`



79
80
81
# File 'lib/stripe/services/source_service.rb', line 79

def type
  @type
end

#user_agentObject

The user agent of the browser from which the mandate was accepted or refused by the customer.



82
83
84
# File 'lib/stripe/services/source_service.rb', line 82

def user_agent
  @user_agent
end