Class: Stripe::SourceService::UpdateParams::SourceOrder::Shipping
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SourceService::UpdateParams::SourceOrder::Shipping
- Defined in:
- lib/stripe/services/source_service.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Shipping address.
-
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
-
#name ⇒ Object
Recipient name.
-
#phone ⇒ Object
Recipient phone (including extension).
-
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service.
Instance Method Summary collapse
-
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
constructor
A new instance of Shipping.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
Returns a new instance of Shipping.
276 277 278 279 280 281 282 |
# File 'lib/stripe/services/source_service.rb', line 276 def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) @address = address @carrier = carrier @name = name @phone = phone @tracking_number = tracking_number end |
Instance Attribute Details
#address ⇒ Object
Shipping address.
262 263 264 |
# File 'lib/stripe/services/source_service.rb', line 262 def address @address end |
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
265 266 267 |
# File 'lib/stripe/services/source_service.rb', line 265 def carrier @carrier end |
#name ⇒ Object
Recipient name.
268 269 270 |
# File 'lib/stripe/services/source_service.rb', line 268 def name @name end |
#phone ⇒ Object
Recipient phone (including extension).
271 272 273 |
# File 'lib/stripe/services/source_service.rb', line 271 def phone @phone end |
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
274 275 276 |
# File 'lib/stripe/services/source_service.rb', line 274 def tracking_number @tracking_number end |