Class: Stripe::SourceService::VerifyParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SourceService::VerifyParams
- Defined in:
- lib/stripe/services/source_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#values ⇒ Object
The values needed to verify the source.
Instance Method Summary collapse
-
#initialize(expand: nil, values: nil) ⇒ VerifyParams
constructor
A new instance of VerifyParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, values: nil) ⇒ VerifyParams
Returns a new instance of VerifyParams.
608 609 610 611 |
# File 'lib/stripe/services/source_service.rb', line 608 def initialize(expand: nil, values: nil) @expand = @values = values end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
604 605 606 |
# File 'lib/stripe/services/source_service.rb', line 604 def @expand end |
#values ⇒ Object
The values needed to verify the source.
606 607 608 |
# File 'lib/stripe/services/source_service.rb', line 606 def values @values end |