Class: Stripe::SourceTransaction::GbpCreditTransfer
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::SourceTransaction::GbpCreditTransfer
- Defined in:
- lib/stripe/resources/source_transaction.rb
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#fingerprint ⇒ Object
readonly
Bank account fingerprint associated with the Stripe owned bank account receiving the transfer.
-
#funding_method ⇒ Object
readonly
The credit transfer rails the sender used to push this transfer.
-
#last4 ⇒ Object
readonly
Last 4 digits of sender account number associated with the transfer.
-
#reference ⇒ Object
readonly
Sender entered arbitrary information about the transfer.
-
#sender_account_number ⇒ Object
readonly
Sender account number associated with the transfer.
-
#sender_name ⇒ Object
readonly
Sender name associated with the transfer.
-
#sender_sort_code ⇒ Object
readonly
Sender sort code associated with the transfer.
Attributes inherited from Stripe::StripeObject
Method Summary
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#fingerprint ⇒ Object (readonly)
Bank account fingerprint associated with the Stripe owned bank account receiving the transfer.
48 49 50 |
# File 'lib/stripe/resources/source_transaction.rb', line 48 def fingerprint @fingerprint end |
#funding_method ⇒ Object (readonly)
The credit transfer rails the sender used to push this transfer. The possible rails are: Faster Payments, BACS, CHAPS, and wire transfers. Currently only Faster Payments is supported.
51 52 53 |
# File 'lib/stripe/resources/source_transaction.rb', line 51 def funding_method @funding_method end |
#last4 ⇒ Object (readonly)
Last 4 digits of sender account number associated with the transfer.
54 55 56 |
# File 'lib/stripe/resources/source_transaction.rb', line 54 def last4 @last4 end |
#reference ⇒ Object (readonly)
Sender entered arbitrary information about the transfer.
57 58 59 |
# File 'lib/stripe/resources/source_transaction.rb', line 57 def reference @reference end |
#sender_account_number ⇒ Object (readonly)
Sender account number associated with the transfer.
60 61 62 |
# File 'lib/stripe/resources/source_transaction.rb', line 60 def sender_account_number @sender_account_number end |
#sender_name ⇒ Object (readonly)
Sender name associated with the transfer.
63 64 65 |
# File 'lib/stripe/resources/source_transaction.rb', line 63 def sender_name @sender_name end |
#sender_sort_code ⇒ Object (readonly)
Sender sort code associated with the transfer.
66 67 68 |
# File 'lib/stripe/resources/source_transaction.rb', line 66 def sender_sort_code @sender_sort_code end |