Class: Stripe::Subscription::AttachCadenceParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/subscription.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_cadence: nil, expand: nil) ⇒ AttachCadenceParams

Returns a new instance of AttachCadenceParams.



2124
2125
2126
2127
# File 'lib/stripe/resources/subscription.rb', line 2124

def initialize(billing_cadence: nil, expand: nil)
  @billing_cadence = billing_cadence
  @expand = expand
end

Instance Attribute Details

#billing_cadenceObject

The Billing Cadence which controls the timing of recurring invoice generation for this subscription. If unset, the subscription will bill according to its own configured schedule and create its own invoices. If set, this subscription will be billed by the cadence instead, potentially sharing invoices with the other subscriptions linked to that Cadence.



2120
2121
2122
# File 'lib/stripe/resources/subscription.rb', line 2120

def billing_cadence
  @billing_cadence
end

#expandObject

Specifies which fields in the response should be expanded.



2122
2123
2124
# File 'lib/stripe/resources/subscription.rb', line 2122

def expand
  @expand
end