Class: Stripe::Subscription::BillingSchedule::BillFrom
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::Subscription::BillingSchedule::BillFrom
- Defined in:
- lib/stripe/resources/subscription.rb
Defined Under Namespace
Classes: AmendmentStart, LineStartsAt, Relative
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amendment_start ⇒ Object
readonly
Use an index to specify the position of an amendment to start prebilling with.
-
#computed_timestamp ⇒ Object
readonly
The time the billing schedule applies from.
-
#line_starts_at ⇒ Object
readonly
Lets you bill the period starting from a particular Quote line.
-
#relative ⇒ Object
readonly
Timestamp is calculated from the request time.
-
#timestamp ⇒ Object
readonly
Use a precise Unix timestamp for prebilling to start.
-
#type ⇒ Object
readonly
Describes how the billing schedule determines the start date.
Attributes inherited from Stripe::StripeObject
Class Method Summary collapse
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amendment_start ⇒ Object (readonly)
Use an index to specify the position of an amendment to start prebilling with.
158 159 160 |
# File 'lib/stripe/resources/subscription.rb', line 158 def amendment_start @amendment_start end |
#computed_timestamp ⇒ Object (readonly)
The time the billing schedule applies from.
160 161 162 |
# File 'lib/stripe/resources/subscription.rb', line 160 def @computed_timestamp end |
#line_starts_at ⇒ Object (readonly)
Lets you bill the period starting from a particular Quote line.
162 163 164 |
# File 'lib/stripe/resources/subscription.rb', line 162 def line_starts_at @line_starts_at end |
#relative ⇒ Object (readonly)
Timestamp is calculated from the request time.
164 165 166 |
# File 'lib/stripe/resources/subscription.rb', line 164 def relative @relative end |
#timestamp ⇒ Object (readonly)
Use a precise Unix timestamp for prebilling to start. Must be earlier than ‘bill_until`.
166 167 168 |
# File 'lib/stripe/resources/subscription.rb', line 166 def @timestamp end |
#type ⇒ Object (readonly)
Describes how the billing schedule determines the start date. Possible values are ‘timestamp`, `relative`, `amendment_start`, `now`, `quote_acceptance_date`, `line_starts_at`, or `pause_collection_start`.
168 169 170 |
# File 'lib/stripe/resources/subscription.rb', line 168 def type @type end |
Class Method Details
.field_remappings ⇒ Object
178 179 180 |
# File 'lib/stripe/resources/subscription.rb', line 178 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
170 171 172 173 174 175 176 |
# File 'lib/stripe/resources/subscription.rb', line 170 def self.inner_class_types @inner_class_types = { amendment_start: AmendmentStart, line_starts_at: LineStartsAt, relative: Relative, } end |