Class: Stripe::Subscription::BillingSchedule::BillUntil

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/subscription.rb

Defined Under Namespace

Classes: Duration

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Class Method Summary collapse

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#computed_timestampObject (readonly)

The timestamp the billing schedule will apply until.



132
133
134
# File 'lib/stripe/resources/subscription.rb', line 132

def computed_timestamp
  @computed_timestamp
end

#durationObject (readonly)

Specifies the billing period.



134
135
136
# File 'lib/stripe/resources/subscription.rb', line 134

def duration
  @duration
end

#timestampObject (readonly)

If specified, the billing schedule will apply until the specified timestamp.



136
137
138
# File 'lib/stripe/resources/subscription.rb', line 136

def timestamp
  @timestamp
end

#typeObject (readonly)

Describes how the billing schedule will determine the end date. Either ‘duration` or `timestamp`.



138
139
140
# File 'lib/stripe/resources/subscription.rb', line 138

def type
  @type
end

Class Method Details

.field_remappingsObject



144
145
146
# File 'lib/stripe/resources/subscription.rb', line 144

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



140
141
142
# File 'lib/stripe/resources/subscription.rb', line 140

def self.inner_class_types
  @inner_class_types = { duration: Duration }
end