Class: Stripe::Subscription::CancelParams::CancellationDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(comment: nil, feedback: nil) ⇒ CancellationDetails

Returns a new instance of CancellationDetails.



229
230
231
232
# File 'lib/stripe/resources/subscription.rb', line 229

def initialize(comment: nil, feedback: nil)
  @comment = comment
  @feedback = feedback
end

Instance Attribute Details

#commentObject

Additional comments about why the user canceled the subscription, if the subscription was canceled explicitly by the user.



225
226
227
# File 'lib/stripe/resources/subscription.rb', line 225

def comment
  @comment
end

#feedbackObject

The customer submitted reason for why they canceled, if the subscription was canceled explicitly by the user.



227
228
229
# File 'lib/stripe/resources/subscription.rb', line 227

def feedback
  @feedback
end