Class: Stripe::Subscription::CancellationDetails

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/subscription.rb

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Class Method Summary collapse

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#commentObject (readonly)

Additional comments about why the user canceled the subscription, if the subscription was canceled explicitly by the user.



181
182
183
# File 'lib/stripe/resources/subscription.rb', line 181

def comment
  @comment
end

#feedbackObject (readonly)

The customer submitted reason for why they canceled, if the subscription was canceled explicitly by the user.



183
184
185
# File 'lib/stripe/resources/subscription.rb', line 183

def feedback
  @feedback
end

#reasonObject (readonly)

Why this subscription was canceled.



185
186
187
# File 'lib/stripe/resources/subscription.rb', line 185

def reason
  @reason
end

Class Method Details

.field_remappingsObject



191
192
193
# File 'lib/stripe/resources/subscription.rb', line 191

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



187
188
189
# File 'lib/stripe/resources/subscription.rb', line 187

def self.inner_class_types
  @inner_class_types = {}
end