Class: Stripe::Subscription::CreateParams::AddInvoiceItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription.rb

Defined Under Namespace

Classes: Discount, Period, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discounts: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ AddInvoiceItem

Returns a new instance of AddInvoiceItem.



1662
1663
1664
1665
1666
1667
1668
1669
1670
1671
1672
1673
1674
1675
1676
1677
1678
# File 'lib/stripe/resources/subscription.rb', line 1662

def initialize(
  discounts: nil,
  metadata: nil,
  period: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @discounts = discounts
  @metadata = 
  @period = period
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#discountsObject

The coupons to redeem into discounts for the item.



1648
1649
1650
# File 'lib/stripe/resources/subscription.rb', line 1648

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1650
1651
1652
# File 'lib/stripe/resources/subscription.rb', line 1650

def 
  @metadata
end

#periodObject

The period associated with this invoice item. Defaults to the current period of the subscription.



1652
1653
1654
# File 'lib/stripe/resources/subscription.rb', line 1652

def period
  @period
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required.



1654
1655
1656
# File 'lib/stripe/resources/subscription.rb', line 1654

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.



1656
1657
1658
# File 'lib/stripe/resources/subscription.rb', line 1656

def price_data
  @price_data
end

#quantityObject

Quantity for this item. Defaults to 1.



1658
1659
1660
# File 'lib/stripe/resources/subscription.rb', line 1658

def quantity
  @quantity
end

#tax_ratesObject

The tax rates which apply to the item. When set, the ‘default_tax_rates` do not apply to this item.



1660
1661
1662
# File 'lib/stripe/resources/subscription.rb', line 1660

def tax_rates
  @tax_rates
end