Class: Stripe::Subscription::CreateParams::AddInvoiceItem::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Subscription::CreateParams::AddInvoiceItem::Discount
- Defined in:
- lib/stripe/resources/subscription.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
1578 1579 1580 1581 1582 1583 |
# File 'lib/stripe/resources/subscription.rb', line 1578 def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
1570 1571 1572 |
# File 'lib/stripe/resources/subscription.rb', line 1570 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
1572 1573 1574 |
# File 'lib/stripe/resources/subscription.rb', line 1572 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
1574 1575 1576 |
# File 'lib/stripe/resources/subscription.rb', line 1574 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
1576 1577 1578 |
# File 'lib/stripe/resources/subscription.rb', line 1576 def promotion_code @promotion_code end |