Class: Stripe::Subscription::CreateParams::AddInvoiceItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



1563
1564
1565
1566
1567
# File 'lib/stripe/resources/subscription.rb', line 1563

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



1557
1558
1559
# File 'lib/stripe/resources/subscription.rb', line 1557

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



1559
1560
1561
# File 'lib/stripe/resources/subscription.rb', line 1559

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



1561
1562
1563
# File 'lib/stripe/resources/subscription.rb', line 1561

def type
  @type
end