Class: Stripe::Subscription::CreateParams::AddInvoiceItem::Period::End
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Subscription::CreateParams::AddInvoiceItem::Period::End
- Defined in:
- lib/stripe/resources/subscription.rb
Instance Attribute Summary collapse
-
#timestamp ⇒ Object
A precise Unix timestamp for the end of the invoice item period.
-
#type ⇒ Object
Select how to calculate the end of the invoice item period.
Instance Method Summary collapse
-
#initialize(timestamp: nil, type: nil) ⇒ End
constructor
A new instance of End.
Methods inherited from RequestParams
Constructor Details
#initialize(timestamp: nil, type: nil) ⇒ End
Returns a new instance of End.
1301 1302 1303 1304 |
# File 'lib/stripe/resources/subscription.rb', line 1301 def initialize(timestamp: nil, type: nil) @timestamp = @type = type end |
Instance Attribute Details
#timestamp ⇒ Object
A precise Unix timestamp for the end of the invoice item period. Must be greater than or equal to ‘period.start`.
1297 1298 1299 |
# File 'lib/stripe/resources/subscription.rb', line 1297 def @timestamp end |
#type ⇒ Object
Select how to calculate the end of the invoice item period.
1299 1300 1301 |
# File 'lib/stripe/resources/subscription.rb', line 1299 def type @type end |