Class: Stripe::Subscription::CreateParams::AddInvoiceItem::Period::Start

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(timestamp: nil, type: nil) ⇒ Start

Returns a new instance of Start.



1313
1314
1315
1316
# File 'lib/stripe/resources/subscription.rb', line 1313

def initialize(timestamp: nil, type: nil)
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#timestampObject

A precise Unix timestamp for the start of the invoice item period. Must be less than or equal to ‘period.end`.



1309
1310
1311
# File 'lib/stripe/resources/subscription.rb', line 1309

def timestamp
  @timestamp
end

#typeObject

Select how to calculate the start of the invoice item period.



1311
1312
1313
# File 'lib/stripe/resources/subscription.rb', line 1311

def type
  @type
end