Class: Stripe::Subscription::CreateParams::BillingCycleAnchorConfig

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ BillingCycleAnchorConfig

Returns a new instance of BillingCycleAnchorConfig.



1716
1717
1718
1719
1720
1721
1722
# File 'lib/stripe/resources/subscription.rb', line 1716

def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil)
  @day_of_month = day_of_month
  @hour = hour
  @minute = minute
  @month = month
  @second = second
end

Instance Attribute Details

#day_of_monthObject

The day of the month the anchor should be. Ranges from 1 to 31.



1706
1707
1708
# File 'lib/stripe/resources/subscription.rb', line 1706

def day_of_month
  @day_of_month
end

#hourObject

The hour of the day the anchor should be. Ranges from 0 to 23.



1708
1709
1710
# File 'lib/stripe/resources/subscription.rb', line 1708

def hour
  @hour
end

#minuteObject

The minute of the hour the anchor should be. Ranges from 0 to 59.



1710
1711
1712
# File 'lib/stripe/resources/subscription.rb', line 1710

def minute
  @minute
end

#monthObject

The month to start full cycle periods. Ranges from 1 to 12.



1712
1713
1714
# File 'lib/stripe/resources/subscription.rb', line 1712

def month
  @month
end

#secondObject

The second of the minute the anchor should be. Ranges from 0 to 59.



1714
1715
1716
# File 'lib/stripe/resources/subscription.rb', line 1714

def second
  @second
end