Class: Stripe::Subscription::CreateParams::BillingThresholds
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Subscription::CreateParams::BillingThresholds
- Defined in:
- lib/stripe/resources/subscription.rb
Instance Attribute Summary collapse
-
#amount_gte ⇒ Object
Monetary threshold that triggers the subscription to advance to a new billing period.
-
#reset_billing_cycle_anchor ⇒ Object
Indicates if the ‘billing_cycle_anchor` should be reset when a threshold is reached.
Instance Method Summary collapse
-
#initialize(amount_gte: nil, reset_billing_cycle_anchor: nil) ⇒ BillingThresholds
constructor
A new instance of BillingThresholds.
Methods inherited from RequestParams
Constructor Details
#initialize(amount_gte: nil, reset_billing_cycle_anchor: nil) ⇒ BillingThresholds
Returns a new instance of BillingThresholds.
1114 1115 1116 1117 |
# File 'lib/stripe/resources/subscription.rb', line 1114 def initialize(amount_gte: nil, reset_billing_cycle_anchor: nil) @amount_gte = amount_gte @reset_billing_cycle_anchor = reset_billing_cycle_anchor end |
Instance Attribute Details
#amount_gte ⇒ Object
Monetary threshold that triggers the subscription to advance to a new billing period
1110 1111 1112 |
# File 'lib/stripe/resources/subscription.rb', line 1110 def amount_gte @amount_gte end |
#reset_billing_cycle_anchor ⇒ Object
Indicates if the ‘billing_cycle_anchor` should be reset when a threshold is reached. If true, `billing_cycle_anchor` will be updated to the date/time the threshold was last reached; otherwise, the value will remain unchanged.
1112 1113 1114 |
# File 'lib/stripe/resources/subscription.rb', line 1112 def reset_billing_cycle_anchor @reset_billing_cycle_anchor end |