Class: Stripe::Subscription::CreateParams::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1781
1782
1783
1784
1785
1786
# File 'lib/stripe/resources/subscription.rb', line 1781

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1773
1774
1775
# File 'lib/stripe/resources/subscription.rb', line 1773

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1775
1776
1777
# File 'lib/stripe/resources/subscription.rb', line 1775

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1777
1778
1779
# File 'lib/stripe/resources/subscription.rb', line 1777

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1779
1780
1781
# File 'lib/stripe/resources/subscription.rb', line 1779

def promotion_code
  @promotion_code
end