Class: Stripe::Subscription::CreateParams::Item

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/subscription.rb

Defined Under Namespace

Classes: BillingThresholds, Discount, PriceData, Trial

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_thresholds: nil, discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Item

Returns a new instance of Item.



1937
1938
1939
1940
1941
1942
1943
1944
1945
1946
1947
1948
1949
1950
1951
1952
1953
1954
1955
1956
1957
# File 'lib/stripe/resources/subscription.rb', line 1937

def initialize(
  billing_thresholds: nil,
  discounts: nil,
  metadata: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil,
  trial: nil
)
  @billing_thresholds = billing_thresholds
  @discounts = discounts
  @metadata = 
  @plan = plan
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
  @trial = trial
end

Instance Attribute Details

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.



1919
1920
1921
# File 'lib/stripe/resources/subscription.rb', line 1919

def billing_thresholds
  @billing_thresholds
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



1921
1922
1923
# File 'lib/stripe/resources/subscription.rb', line 1921

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1923
1924
1925
# File 'lib/stripe/resources/subscription.rb', line 1923

def 
  @metadata
end

#planObject

Plan ID for this item, as a string.



1925
1926
1927
# File 'lib/stripe/resources/subscription.rb', line 1925

def plan
  @plan
end

#priceObject

The ID of the price object.



1927
1928
1929
# File 'lib/stripe/resources/subscription.rb', line 1927

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.



1929
1930
1931
# File 'lib/stripe/resources/subscription.rb', line 1929

def price_data
  @price_data
end

#quantityObject

Quantity for this item.



1931
1932
1933
# File 'lib/stripe/resources/subscription.rb', line 1931

def quantity
  @quantity
end

#tax_ratesObject

A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



1933
1934
1935
# File 'lib/stripe/resources/subscription.rb', line 1933

def tax_rates
  @tax_rates
end

#trialObject

Define options to configure the trial on the subscription item.



1935
1936
1937
# File 'lib/stripe/resources/subscription.rb', line 1935

def trial
  @trial
end