Class: Stripe::Subscription::CreateParams::Item::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1857
1858
1859
1860
1861
1862
# File 'lib/stripe/resources/subscription.rb', line 1857

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1849
1850
1851
# File 'lib/stripe/resources/subscription.rb', line 1849

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1851
1852
1853
# File 'lib/stripe/resources/subscription.rb', line 1851

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1853
1854
1855
# File 'lib/stripe/resources/subscription.rb', line 1853

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1855
1856
1857
# File 'lib/stripe/resources/subscription.rb', line 1855

def promotion_code
  @promotion_code
end