Class: Stripe::Subscription::CreateParams::Item::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Subscription::CreateParams::Item::Discount::DiscountEnd
- Defined in:
- lib/stripe/resources/subscription.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
1842 1843 1844 1845 1846 |
# File 'lib/stripe/resources/subscription.rb', line 1842 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
1836 1837 1838 |
# File 'lib/stripe/resources/subscription.rb', line 1836 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
1838 1839 1840 |
# File 'lib/stripe/resources/subscription.rb', line 1838 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
1840 1841 1842 |
# File 'lib/stripe/resources/subscription.rb', line 1840 def type @type end |