Class: Stripe::Subscription::CreateParams::PaymentSettings::PaymentMethodOptions::Card

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription.rb

Defined Under Namespace

Classes: MandateOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(mandate_options: nil, network: nil, request_three_d_secure: nil) ⇒ Card

Returns a new instance of Card.



1429
1430
1431
1432
1433
# File 'lib/stripe/resources/subscription.rb', line 1429

def initialize(mandate_options: nil, network: nil, request_three_d_secure: nil)
  @mandate_options = mandate_options
  @network = network
  @request_three_d_secure = request_three_d_secure
end

Instance Attribute Details

#mandate_optionsObject

Configuration options for setting up an eMandate for cards issued in India.



1423
1424
1425
# File 'lib/stripe/resources/subscription.rb', line 1423

def mandate_options
  @mandate_options
end

#networkObject

Selected network to process this Subscription on. Depends on the available networks of the card attached to the Subscription. Can be only set confirm-time.



1425
1426
1427
# File 'lib/stripe/resources/subscription.rb', line 1425

def network
  @network
end

#request_three_d_secureObject

We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and [other requirements](stripe.com/docs/strong-customer-authentication). However, if you wish to request 3D Secure based on logic from your own fraud engine, provide this option. Read our guide on [manually requesting 3D Secure](stripe.com/docs/payments/3d-secure/authentication-flow#manual-three-ds) for more information on how this configuration interacts with Radar and our SCA Engine.



1427
1428
1429
# File 'lib/stripe/resources/subscription.rb', line 1427

def request_three_d_secure
  @request_three_d_secure
end