Class: Stripe::Subscription::CreateParams::PaymentSettings::PaymentMethodOptions::Upi::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



1676
1677
1678
1679
1680
1681
# File 'lib/stripe/resources/subscription.rb', line 1676

def initialize(amount: nil, amount_type: nil, description: nil, end_date: nil)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



1668
1669
1670
# File 'lib/stripe/resources/subscription.rb', line 1668

def amount
  @amount
end

#amount_typeObject

One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.



1670
1671
1672
# File 'lib/stripe/resources/subscription.rb', line 1670

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



1672
1673
1674
# File 'lib/stripe/resources/subscription.rb', line 1672

def description
  @description
end

#end_dateObject

End date of the mandate or subscription. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.



1674
1675
1676
# File 'lib/stripe/resources/subscription.rb', line 1674

def end_date
  @end_date
end