Class: Stripe::Subscription::CreateParams::Prebilling
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Subscription::CreateParams::Prebilling
- Defined in:
- lib/stripe/resources/subscription.rb
Instance Attribute Summary collapse
-
#iterations ⇒ Object
This is used to determine the number of billing cycles to prebill.
-
#update_behavior ⇒ Object
Whether to cancel or preserve ‘prebilling` if the subscription is updated during the prebilled period.
Instance Method Summary collapse
-
#initialize(iterations: nil, update_behavior: nil) ⇒ Prebilling
constructor
A new instance of Prebilling.
Methods inherited from RequestParams
Constructor Details
#initialize(iterations: nil, update_behavior: nil) ⇒ Prebilling
Returns a new instance of Prebilling.
1716 1717 1718 1719 |
# File 'lib/stripe/resources/subscription.rb', line 1716 def initialize(iterations: nil, update_behavior: nil) @iterations = iterations @update_behavior = update_behavior end |
Instance Attribute Details
#iterations ⇒ Object
This is used to determine the number of billing cycles to prebill.
1712 1713 1714 |
# File 'lib/stripe/resources/subscription.rb', line 1712 def iterations @iterations end |
#update_behavior ⇒ Object
Whether to cancel or preserve ‘prebilling` if the subscription is updated during the prebilled period. The default value is `reset`.
1714 1715 1716 |
# File 'lib/stripe/resources/subscription.rb', line 1714 def update_behavior @update_behavior end |