Class: Stripe::Subscription::CreateParams::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_percent: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



2206
2207
2208
2209
# File 'lib/stripe/resources/subscription.rb', line 2206

def initialize(amount_percent: nil, destination: nil)
  @amount_percent = amount_percent
  @destination = destination
end

Instance Attribute Details

#amount_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination.



2202
2203
2204
# File 'lib/stripe/resources/subscription.rb', line 2202

def amount_percent
  @amount_percent
end

#destinationObject

ID of an existing, connected Stripe account.



2204
2205
2206
# File 'lib/stripe/resources/subscription.rb', line 2204

def destination
  @destination
end