Class: Stripe::Subscription::ListParams::AutomaticTax
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Subscription::ListParams::AutomaticTax
- Defined in:
- lib/stripe/resources/subscription.rb
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Enabled automatic tax calculation which will automatically compute tax rates on all invoices generated by the subscription.
Instance Method Summary collapse
-
#initialize(enabled: nil) ⇒ AutomaticTax
constructor
A new instance of AutomaticTax.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil) ⇒ AutomaticTax
Returns a new instance of AutomaticTax.
1417 1418 1419 |
# File 'lib/stripe/resources/subscription.rb', line 1417 def initialize(enabled: nil) @enabled = enabled end |
Instance Attribute Details
#enabled ⇒ Object
Enabled automatic tax calculation which will automatically compute tax rates on all invoices generated by the subscription.
1415 1416 1417 |
# File 'lib/stripe/resources/subscription.rb', line 1415 def enabled @enabled end |