Class: Stripe::Subscription::MigrateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/subscription.rb

Defined Under Namespace

Classes: BillingMode

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_mode: nil, expand: nil) ⇒ MigrateParams

Returns a new instance of MigrateParams.



2144
2145
2146
2147
# File 'lib/stripe/resources/subscription.rb', line 2144

def initialize(billing_mode: nil, expand: nil)
  @billing_mode = billing_mode
  @expand = expand
end

Instance Attribute Details

#billing_modeObject

Controls how prorations and invoices for subscriptions are calculated and orchestrated.



2140
2141
2142
# File 'lib/stripe/resources/subscription.rb', line 2140

def billing_mode
  @billing_mode
end

#expandObject

Specifies which fields in the response should be expanded.



2142
2143
2144
# File 'lib/stripe/resources/subscription.rb', line 2142

def expand
  @expand
end