Class: Stripe::Subscription::PaymentSettings::PaymentMethodOptions
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::Subscription::PaymentSettings::PaymentMethodOptions
- Defined in:
- lib/stripe/resources/subscription.rb
Defined Under Namespace
Classes: AcssDebit, Bancontact, Billie, Bizum, Blik, Card, CheckScan, CustomerBalance, IdBankTransfer, Konbini, Payto, Pix, SepaDebit, Upi, UsBankAccount, WechatPay
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
readonly
This sub-hash contains details about the Canadian pre-authorized debit payment method options to pass to invoices created by the subscription.
-
#bancontact ⇒ Object
readonly
This sub-hash contains details about the Bancontact payment method options to pass to invoices created by the subscription.
-
#billie ⇒ Object
readonly
This sub-hash contains details about the Billie payment method options to pass to invoices created by the subscription.
-
#bizum ⇒ Object
readonly
This sub-hash contains details about the Bizum payment method options to pass to invoices created by the subscription.
-
#blik ⇒ Object
readonly
This sub-hash contains details about the Blik payment method options to pass to invoices created by the subscription.
-
#card ⇒ Object
readonly
This sub-hash contains details about the Card payment method options to pass to invoices created by the subscription.
-
#check_scan ⇒ Object
readonly
This sub-hash contains details about the Check Scan payment method options to pass to invoices created by the subscription.
-
#customer_balance ⇒ Object
readonly
This sub-hash contains details about the Bank transfer payment method options to pass to invoices created by the subscription.
-
#id_bank_transfer ⇒ Object
readonly
This sub-hash contains details about the Indonesia bank transfer payment method options to pass to invoices created by the subscription.
-
#konbini ⇒ Object
readonly
This sub-hash contains details about the Konbini payment method options to pass to invoices created by the subscription.
-
#payto ⇒ Object
readonly
This sub-hash contains details about the PayTo payment method options to pass to invoices created by the subscription.
-
#pix ⇒ Object
readonly
This sub-hash contains details about the Pix payment method options to pass to invoices created by the subscription.
-
#sepa_debit ⇒ Object
readonly
This sub-hash contains details about the SEPA Direct Debit payment method options to pass to invoices created by the subscription.
-
#upi ⇒ Object
readonly
This sub-hash contains details about the UPI payment method options to pass to invoices created by the subscription.
-
#us_bank_account ⇒ Object
readonly
This sub-hash contains details about the ACH direct debit payment method options to pass to invoices created by the subscription.
-
#wechat_pay ⇒ Object
readonly
This sub-hash contains details about the WeChat Pay payment method options to pass to invoices created by the subscription.
Attributes inherited from Stripe::StripeObject
Class Method Summary collapse
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#acss_debit ⇒ Object (readonly)
This sub-hash contains details about the Canadian pre-authorized debit payment method options to pass to invoices created by the subscription.
678 679 680 |
# File 'lib/stripe/resources/subscription.rb', line 678 def acss_debit @acss_debit end |
#bancontact ⇒ Object (readonly)
This sub-hash contains details about the Bancontact payment method options to pass to invoices created by the subscription.
680 681 682 |
# File 'lib/stripe/resources/subscription.rb', line 680 def bancontact @bancontact end |
#billie ⇒ Object (readonly)
This sub-hash contains details about the Billie payment method options to pass to invoices created by the subscription.
682 683 684 |
# File 'lib/stripe/resources/subscription.rb', line 682 def billie @billie end |
#bizum ⇒ Object (readonly)
This sub-hash contains details about the Bizum payment method options to pass to invoices created by the subscription.
684 685 686 |
# File 'lib/stripe/resources/subscription.rb', line 684 def bizum @bizum end |
#blik ⇒ Object (readonly)
This sub-hash contains details about the Blik payment method options to pass to invoices created by the subscription.
686 687 688 |
# File 'lib/stripe/resources/subscription.rb', line 686 def blik @blik end |
#card ⇒ Object (readonly)
This sub-hash contains details about the Card payment method options to pass to invoices created by the subscription.
688 689 690 |
# File 'lib/stripe/resources/subscription.rb', line 688 def card @card end |
#check_scan ⇒ Object (readonly)
This sub-hash contains details about the Check Scan payment method options to pass to invoices created by the subscription.
690 691 692 |
# File 'lib/stripe/resources/subscription.rb', line 690 def check_scan @check_scan end |
#customer_balance ⇒ Object (readonly)
This sub-hash contains details about the Bank transfer payment method options to pass to invoices created by the subscription.
692 693 694 |
# File 'lib/stripe/resources/subscription.rb', line 692 def customer_balance @customer_balance end |
#id_bank_transfer ⇒ Object (readonly)
This sub-hash contains details about the Indonesia bank transfer payment method options to pass to invoices created by the subscription.
694 695 696 |
# File 'lib/stripe/resources/subscription.rb', line 694 def id_bank_transfer @id_bank_transfer end |
#konbini ⇒ Object (readonly)
This sub-hash contains details about the Konbini payment method options to pass to invoices created by the subscription.
696 697 698 |
# File 'lib/stripe/resources/subscription.rb', line 696 def konbini @konbini end |
#payto ⇒ Object (readonly)
This sub-hash contains details about the PayTo payment method options to pass to invoices created by the subscription.
698 699 700 |
# File 'lib/stripe/resources/subscription.rb', line 698 def payto @payto end |
#pix ⇒ Object (readonly)
This sub-hash contains details about the Pix payment method options to pass to invoices created by the subscription.
700 701 702 |
# File 'lib/stripe/resources/subscription.rb', line 700 def pix @pix end |
#sepa_debit ⇒ Object (readonly)
This sub-hash contains details about the SEPA Direct Debit payment method options to pass to invoices created by the subscription.
702 703 704 |
# File 'lib/stripe/resources/subscription.rb', line 702 def sepa_debit @sepa_debit end |
#upi ⇒ Object (readonly)
This sub-hash contains details about the UPI payment method options to pass to invoices created by the subscription.
704 705 706 |
# File 'lib/stripe/resources/subscription.rb', line 704 def upi @upi end |
#us_bank_account ⇒ Object (readonly)
This sub-hash contains details about the ACH direct debit payment method options to pass to invoices created by the subscription.
706 707 708 |
# File 'lib/stripe/resources/subscription.rb', line 706 def us_bank_account @us_bank_account end |
#wechat_pay ⇒ Object (readonly)
This sub-hash contains details about the WeChat Pay payment method options to pass to invoices created by the subscription.
708 709 710 |
# File 'lib/stripe/resources/subscription.rb', line 708 def wechat_pay @wechat_pay end |
Class Method Details
.field_remappings ⇒ Object
731 732 733 |
# File 'lib/stripe/resources/subscription.rb', line 731 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 |
# File 'lib/stripe/resources/subscription.rb', line 710 def self.inner_class_types @inner_class_types = { acss_debit: AcssDebit, bancontact: Bancontact, billie: Billie, bizum: Bizum, blik: Blik, card: Card, check_scan: CheckScan, customer_balance: CustomerBalance, id_bank_transfer: IdBankTransfer, konbini: Konbini, payto: Payto, pix: Pix, sepa_debit: SepaDebit, upi: Upi, us_bank_account: UsBankAccount, wechat_pay: WechatPay, } end |