Class: Stripe::Subscription::PaymentSettings::PaymentMethodOptions::Blik::MandateOptions

Inherits:
Stripe::StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/subscription.rb

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Class Method Summary collapse

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#expires_afterObject (readonly)

Date when the mandate expires and no further payments will be charged. If not provided, the mandate will be set to be indefinite.



329
330
331
# File 'lib/stripe/resources/subscription.rb', line 329

def expires_after
  @expires_after
end

Class Method Details

.field_remappingsObject



335
336
337
# File 'lib/stripe/resources/subscription.rb', line 335

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



331
332
333
# File 'lib/stripe/resources/subscription.rb', line 331

def self.inner_class_types
  @inner_class_types = {}
end