Class: Stripe::Subscription::PendingUpdate

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/subscription.rb

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Class Method Summary collapse

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#billing_cycle_anchor ⇒ Object (readonly)

If the update is applied, determines the date of the first full invoice, and, for plans with month or year intervals, the day of the month for subsequent invoices. The timestamp is in UTC format.



706
707
708
# File 'lib/stripe/resources/subscription.rb', line 706

def billing_cycle_anchor
  @billing_cycle_anchor
end

#cancel_at_period_end ⇒ Object (readonly)

Indicates whether this subscription should cancel at the end of the current period if the update is applied.



708
709
710
# File 'lib/stripe/resources/subscription.rb', line 708

def cancel_at_period_end
  @cancel_at_period_end
end

#discount ⇒ Object (readonly)

The pending subscription-level discount that will be applied when the pending update is applied.



710
711
712
# File 'lib/stripe/resources/subscription.rb', line 710

def discount
  @discount
end

#discounts ⇒ Object (readonly)

The discounts that will be applied to the subscription when the pending update is applied. Use expand[]=discounts to expand each discount.



712
713
714
# File 'lib/stripe/resources/subscription.rb', line 712

def discounts
  @discounts
end

#expires_at ⇒ Object (readonly)

The point after which the changes reflected by this update will be discarded and no longer applied.



714
715
716
# File 'lib/stripe/resources/subscription.rb', line 714

def expires_at
  @expires_at
end

#metadata ⇒ Object (readonly)

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



716
717
718
# File 'lib/stripe/resources/subscription.rb', line 716

def 
  @metadata
end

#subscription_items ⇒ Object (readonly)

List of subscription items, each with an attached plan, that will be set if the update is applied.



718
719
720
# File 'lib/stripe/resources/subscription.rb', line 718

def subscription_items
  @subscription_items
end

#trial_end ⇒ Object (readonly)

Unix timestamp representing the end of the trial period the customer will get before being charged for the first time, if the update is applied.



720
721
722
# File 'lib/stripe/resources/subscription.rb', line 720

def trial_end
  @trial_end
end

#trial_from_plan ⇒ Object (readonly)

Indicates if a plan's trial_period_days should be applied to the subscription. Setting trial_end per subscription is preferred, and this defaults to false. Setting this flag to true together with trial_end is not allowed. See Using trial periods on subscriptions to learn more.



722
723
724
# File 'lib/stripe/resources/subscription.rb', line 722

def trial_from_plan
  @trial_from_plan
end

Class Method Details

.field_remappings ⇒ Object



728
729
730
# File 'lib/stripe/resources/subscription.rb', line 728

def self.field_remappings
  @field_remappings = {}
end

.inner_class_types ⇒ Object



724
725
726
# File 'lib/stripe/resources/subscription.rb', line 724

def self.inner_class_types
  @inner_class_types = {}
end