Class: Stripe::Subscription::ResumeParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/subscription.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_cycle_anchor: nil, expand: nil, proration_behavior: nil, proration_date: nil) ⇒ ResumeParams

Returns a new instance of ResumeParams.



2160
2161
2162
2163
2164
2165
2166
2167
2168
2169
2170
# File 'lib/stripe/resources/subscription.rb', line 2160

def initialize(
  billing_cycle_anchor: nil,
  expand: nil,
  proration_behavior: nil,
  proration_date: nil
)
  @billing_cycle_anchor = billing_cycle_anchor
  @expand = expand
  @proration_behavior = proration_behavior
  @proration_date = proration_date
end

Instance Attribute Details

#billing_cycle_anchorObject

The billing cycle anchor that applies when the subscription is resumed. Either ‘now` or `unchanged`. The default is `now`. For more information, see the billing cycle [documentation](stripe.com/docs/billing/subscriptions/billing-cycle).



2152
2153
2154
# File 'lib/stripe/resources/subscription.rb', line 2152

def billing_cycle_anchor
  @billing_cycle_anchor
end

#expandObject

Specifies which fields in the response should be expanded.



2154
2155
2156
# File 'lib/stripe/resources/subscription.rb', line 2154

def expand
  @expand
end

#proration_behaviorObject

Determines how to handle [prorations](stripe.com/docs/billing/subscriptions/prorations) resulting from the ‘billing_cycle_anchor` being `unchanged`. When the `billing_cycle_anchor` is set to `now` (default value), no prorations are generated. If no value is passed, the default is `create_prorations`.



2156
2157
2158
# File 'lib/stripe/resources/subscription.rb', line 2156

def proration_behavior
  @proration_behavior
end

#proration_dateObject

If set, prorations will be calculated as though the subscription was resumed at the given time. This can be used to apply exactly the same prorations that were previewed with the [create preview](stripe.com/docs/api/invoices/create_preview) endpoint.



2158
2159
2160
# File 'lib/stripe/resources/subscription.rb', line 2158

def proration_date
  @proration_date
end