Class: Stripe::Subscription::SearchParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Subscription::SearchParams
- Defined in:
- lib/stripe/resources/subscription.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#page ⇒ Object
A cursor for pagination across multiple pages of results.
-
#query ⇒ Object
The search query string.
Instance Method Summary collapse
-
#initialize(expand: nil, limit: nil, page: nil, query: nil) ⇒ SearchParams
constructor
A new instance of SearchParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, limit: nil, page: nil, query: nil) ⇒ SearchParams
Returns a new instance of SearchParams.
2402 2403 2404 2405 2406 2407 |
# File 'lib/stripe/resources/subscription.rb', line 2402 def initialize(expand: nil, limit: nil, page: nil, query: nil) @expand = @limit = limit @page = page @query = query end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2394 2395 2396 |
# File 'lib/stripe/resources/subscription.rb', line 2394 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
2396 2397 2398 |
# File 'lib/stripe/resources/subscription.rb', line 2396 def limit @limit end |
#page ⇒ Object
A cursor for pagination across multiple pages of results. Don’t include this parameter on the first call. Use the next_page value returned in a previous response to request subsequent results.
2398 2399 2400 |
# File 'lib/stripe/resources/subscription.rb', line 2398 def page @page end |
#query ⇒ Object
The search query string. See [search query language](stripe.com/docs/search#search-query-language) and the list of supported [query fields for subscriptions](stripe.com/docs/search#query-fields-for-subscriptions).
2400 2401 2402 |
# File 'lib/stripe/resources/subscription.rb', line 2400 def query @query end |