Class: Stripe::Subscription::TrialSettings::EndBehavior
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::Subscription::TrialSettings::EndBehavior
- Defined in:
- lib/stripe/resources/subscription.rb
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#missing_payment_method ⇒ Object
readonly
Indicates how the subscription should change when the trial ends if the user did not provide a payment method.
Attributes inherited from Stripe::StripeObject
Method Summary
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#missing_payment_method ⇒ Object (readonly)
Indicates how the subscription should change when the trial ends if the user did not provide a payment method.
216 217 218 |
# File 'lib/stripe/resources/subscription.rb', line 216 def missing_payment_method @missing_payment_method end |