Class: Stripe::Subscription::UpdateParams::AddInvoiceItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Subscription::UpdateParams::AddInvoiceItem
- Defined in:
- lib/stripe/resources/subscription.rb
Defined Under Namespace
Classes: Discount, Period, PriceData
Instance Attribute Summary collapse
-
#discounts ⇒ Object
The coupons to redeem into discounts for the item.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#period ⇒ Object
The period associated with this invoice item.
-
#price ⇒ Object
The ID of the price object.
-
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.
-
#quantity ⇒ Object
Quantity for this item.
-
#tax_rates ⇒ Object
The tax rates which apply to the item.
Instance Method Summary collapse
-
#initialize(discounts: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ AddInvoiceItem
constructor
A new instance of AddInvoiceItem.
Methods inherited from RequestParams
Constructor Details
#initialize(discounts: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ AddInvoiceItem
Returns a new instance of AddInvoiceItem.
344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 |
# File 'lib/stripe/resources/subscription.rb', line 344 def initialize( discounts: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil ) @discounts = discounts @metadata = @period = period @price = price @price_data = price_data @quantity = quantity @tax_rates = tax_rates end |
Instance Attribute Details
#discounts ⇒ Object
The coupons to redeem into discounts for the item.
330 331 332 |
# File 'lib/stripe/resources/subscription.rb', line 330 def discounts @discounts end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
332 333 334 |
# File 'lib/stripe/resources/subscription.rb', line 332 def @metadata end |
#period ⇒ Object
The period associated with this invoice item. Defaults to the current period of the subscription.
334 335 336 |
# File 'lib/stripe/resources/subscription.rb', line 334 def period @period end |
#price ⇒ Object
The ID of the price object. One of ‘price` or `price_data` is required.
336 337 338 |
# File 'lib/stripe/resources/subscription.rb', line 336 def price @price end |
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.
338 339 340 |
# File 'lib/stripe/resources/subscription.rb', line 338 def price_data @price_data end |
#quantity ⇒ Object
Quantity for this item. Defaults to 1.
340 341 342 |
# File 'lib/stripe/resources/subscription.rb', line 340 def quantity @quantity end |
#tax_rates ⇒ Object
The tax rates which apply to the item. When set, the ‘default_tax_rates` do not apply to this item.
342 343 344 |
# File 'lib/stripe/resources/subscription.rb', line 342 def tax_rates @tax_rates end |