Class: Stripe::Subscription::UpdateParams::AddInvoiceItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



338
339
340
341
342
343
# File 'lib/stripe/resources/subscription.rb', line 338

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



330
331
332
# File 'lib/stripe/resources/subscription.rb', line 330

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



332
333
334
# File 'lib/stripe/resources/subscription.rb', line 332

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



334
335
336
# File 'lib/stripe/resources/subscription.rb', line 334

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



336
337
338
# File 'lib/stripe/resources/subscription.rb', line 336

def promotion_code
  @promotion_code
end