Class: Stripe::Subscription::UpdateParams::AddInvoiceItem::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Subscription::UpdateParams::AddInvoiceItem::Discount::DiscountEnd
- Defined in:
- lib/stripe/resources/subscription.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
306 307 308 309 310 |
# File 'lib/stripe/resources/subscription.rb', line 306 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
300 301 302 |
# File 'lib/stripe/resources/subscription.rb', line 300 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
302 303 304 |
# File 'lib/stripe/resources/subscription.rb', line 302 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
304 305 306 |
# File 'lib/stripe/resources/subscription.rb', line 304 def type @type end |