Class: Stripe::Subscription::UpdateParams::AddInvoiceItem::Period::End

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(timestamp: nil, type: nil) ⇒ End

Returns a new instance of End.



275
276
277
278
# File 'lib/stripe/resources/subscription.rb', line 275

def initialize(timestamp: nil, type: nil)
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#timestampObject

A precise Unix timestamp for the end of the invoice item period. Must be greater than or equal to ‘period.start`.



271
272
273
# File 'lib/stripe/resources/subscription.rb', line 271

def timestamp
  @timestamp
end

#typeObject

Select how to calculate the end of the invoice item period.



273
274
275
# File 'lib/stripe/resources/subscription.rb', line 273

def type
  @type
end