Class: Stripe::Subscription::UpdateParams::AddInvoiceItem::Period::Start

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(timestamp: nil, type: nil) ⇒ Start

Returns a new instance of Start.



365
366
367
368
# File 'lib/stripe/resources/subscription.rb', line 365

def initialize(timestamp: nil, type: nil)
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#timestampObject

A precise Unix timestamp for the start of the invoice item period. Must be less than or equal to ‘period.end`.



361
362
363
# File 'lib/stripe/resources/subscription.rb', line 361

def timestamp
  @timestamp
end

#typeObject

Select how to calculate the start of the invoice item period.



363
364
365
# File 'lib/stripe/resources/subscription.rb', line 363

def type
  @type
end