Class: Stripe::Subscription::UpdateParams::CancellationDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(comment: nil, feedback: nil) ⇒ CancellationDetails

Returns a new instance of CancellationDetails.



433
434
435
436
# File 'lib/stripe/resources/subscription.rb', line 433

def initialize(comment: nil, feedback: nil)
  @comment = comment
  @feedback = feedback
end

Instance Attribute Details

#commentObject

Additional comments about why the user canceled the subscription, if the subscription was canceled explicitly by the user.



429
430
431
# File 'lib/stripe/resources/subscription.rb', line 429

def comment
  @comment
end

#feedbackObject

The customer submitted reason for why they canceled, if the subscription was canceled explicitly by the user.



431
432
433
# File 'lib/stripe/resources/subscription.rb', line 431

def feedback
  @feedback
end