Class: Stripe::Subscription::UpdateParams::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



815
816
817
818
819
820
# File 'lib/stripe/resources/subscription.rb', line 815

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



807
808
809
# File 'lib/stripe/resources/subscription.rb', line 807

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



809
810
811
# File 'lib/stripe/resources/subscription.rb', line 809

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



811
812
813
# File 'lib/stripe/resources/subscription.rb', line 811

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



813
814
815
# File 'lib/stripe/resources/subscription.rb', line 813

def promotion_code
  @promotion_code
end