Class: Stripe::Subscription::UpdateParams::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



508
509
510
511
512
# File 'lib/stripe/resources/subscription.rb', line 508

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



502
503
504
# File 'lib/stripe/resources/subscription.rb', line 502

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



504
505
506
# File 'lib/stripe/resources/subscription.rb', line 504

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



506
507
508
# File 'lib/stripe/resources/subscription.rb', line 506

def type
  @type
end