Class: Stripe::Subscription::UpdateParams::Item

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/subscription.rb

Defined Under Namespace

Classes: BillingThresholds, Discount, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_thresholds: nil, clear_usage: nil, deleted: nil, discounts: nil, id: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ Item

Returns a new instance of Item.



963
964
965
966
967
968
969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
# File 'lib/stripe/resources/subscription.rb', line 963

def initialize(
  billing_thresholds: nil,
  clear_usage: nil,
  deleted: nil,
  discounts: nil,
  id: nil,
  metadata: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @billing_thresholds = billing_thresholds
  @clear_usage = clear_usage
  @deleted = deleted
  @discounts = discounts
  @id = id
  @metadata = 
  @plan = plan
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.



941
942
943
# File 'lib/stripe/resources/subscription.rb', line 941

def billing_thresholds
  @billing_thresholds
end

#clear_usageObject

Delete all usage for a given subscription item. You must pass this when deleting a usage records subscription item. ‘clear_usage` has no effect if the plan has a billing meter attached.



943
944
945
# File 'lib/stripe/resources/subscription.rb', line 943

def clear_usage
  @clear_usage
end

#deletedObject

A flag that, if set to ‘true`, will delete the specified item.



945
946
947
# File 'lib/stripe/resources/subscription.rb', line 945

def deleted
  @deleted
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



947
948
949
# File 'lib/stripe/resources/subscription.rb', line 947

def discounts
  @discounts
end

#idObject

Subscription item to update.



949
950
951
# File 'lib/stripe/resources/subscription.rb', line 949

def id
  @id
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



951
952
953
# File 'lib/stripe/resources/subscription.rb', line 951

def 
  @metadata
end

#planObject

Plan ID for this item, as a string.



953
954
955
# File 'lib/stripe/resources/subscription.rb', line 953

def plan
  @plan
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required. When changing a subscription item’s price, ‘quantity` is set to 1 unless a `quantity` parameter is provided.



955
956
957
# File 'lib/stripe/resources/subscription.rb', line 955

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.



957
958
959
# File 'lib/stripe/resources/subscription.rb', line 957

def price_data
  @price_data
end

#quantityObject

Quantity for this item.



959
960
961
# File 'lib/stripe/resources/subscription.rb', line 959

def quantity
  @quantity
end

#tax_ratesObject

A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



961
962
963
# File 'lib/stripe/resources/subscription.rb', line 961

def tax_rates
  @tax_rates
end