Class: Stripe::Subscription::UpdateParams::Item::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



584
585
586
587
588
# File 'lib/stripe/resources/subscription.rb', line 584

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



578
579
580
# File 'lib/stripe/resources/subscription.rb', line 578

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



580
581
582
# File 'lib/stripe/resources/subscription.rb', line 580

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



582
583
584
# File 'lib/stripe/resources/subscription.rb', line 582

def type
  @type
end