Class: Stripe::Subscription::UpdateParams::Item::PriceData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription.rb

Defined Under Namespace

Classes: Recurring

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(currency: nil, product: nil, recurring: nil, tax_behavior: nil, unit_amount: nil, unit_amount_decimal: nil) ⇒ PriceData

Returns a new instance of PriceData.



566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
# File 'lib/stripe/resources/subscription.rb', line 566

def initialize(
  currency: nil,
  product: nil,
  recurring: nil,
  tax_behavior: nil,
  unit_amount: nil,
  unit_amount_decimal: nil
)
  @currency = currency
  @product = product
  @recurring = recurring
  @tax_behavior = tax_behavior
  @unit_amount = unit_amount
  @unit_amount_decimal = unit_amount_decimal
end

Instance Attribute Details

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



554
555
556
# File 'lib/stripe/resources/subscription.rb', line 554

def currency
  @currency
end

#productObject

The ID of the [Product](docs.stripe.com/api/products) that this [Price](docs.stripe.com/api/prices) will belong to.



556
557
558
# File 'lib/stripe/resources/subscription.rb', line 556

def product
  @product
end

#recurringObject

The recurring components of a price such as ‘interval` and `interval_count`.



558
559
560
# File 'lib/stripe/resources/subscription.rb', line 558

def recurring
  @recurring
end

#tax_behaviorObject

Only required if a [default tax behavior](stripe.com/docs/tax/products-prices-tax-categories-tax-behavior#setting-a-default-tax-behavior-(recommended)) was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`. Once specified as either `inclusive` or `exclusive`, it cannot be changed.



560
561
562
# File 'lib/stripe/resources/subscription.rb', line 560

def tax_behavior
  @tax_behavior
end

#unit_amountObject

A positive integer in cents (or local equivalent) (or 0 for a free price) representing how much to charge.



562
563
564
# File 'lib/stripe/resources/subscription.rb', line 562

def unit_amount
  @unit_amount
end

#unit_amount_decimalObject

Same as ‘unit_amount`, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places. Only one of `unit_amount` and `unit_amount_decimal` can be set.



564
565
566
# File 'lib/stripe/resources/subscription.rb', line 564

def unit_amount_decimal
  @unit_amount_decimal
end