Class: Stripe::Subscription::UpdateParams::PaymentSettings::PaymentMethodOptions::Card::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



1042
1043
1044
1045
1046
# File 'lib/stripe/resources/subscription.rb', line 1042

def initialize(amount: nil, amount_type: nil, description: nil)
  @amount = amount
  @amount_type = amount_type
  @description = description
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



1036
1037
1038
# File 'lib/stripe/resources/subscription.rb', line 1036

def amount
  @amount
end

#amount_typeObject

One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.



1038
1039
1040
# File 'lib/stripe/resources/subscription.rb', line 1038

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



1040
1041
1042
# File 'lib/stripe/resources/subscription.rb', line 1040

def description
  @description
end