Class: Stripe::Subscription::UpdateParams::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_percent: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



956
957
958
959
# File 'lib/stripe/resources/subscription.rb', line 956

def initialize(amount_percent: nil, destination: nil)
  @amount_percent = amount_percent
  @destination = destination
end

Instance Attribute Details

#amount_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination.



952
953
954
# File 'lib/stripe/resources/subscription.rb', line 952

def amount_percent
  @amount_percent
end

#destinationObject

ID of an existing, connected Stripe account.



954
955
956
# File 'lib/stripe/resources/subscription.rb', line 954

def destination
  @destination
end