Class: Stripe::SubscriptionCreateParams::BillingCycleAnchorConfig
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionCreateParams::BillingCycleAnchorConfig
- Defined in:
- lib/stripe/params/subscription_create_params.rb
Instance Attribute Summary collapse
-
#day_of_month ⇒ Object
The day of the month the anchor should be.
-
#hour ⇒ Object
The hour of the day the anchor should be.
-
#minute ⇒ Object
The minute of the hour the anchor should be.
-
#month ⇒ Object
The month to start full cycle periods.
-
#second ⇒ Object
The second of the minute the anchor should be.
Instance Method Summary collapse
-
#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ BillingCycleAnchorConfig
constructor
A new instance of BillingCycleAnchorConfig.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ BillingCycleAnchorConfig
Returns a new instance of BillingCycleAnchorConfig.
162 163 164 165 166 167 168 |
# File 'lib/stripe/params/subscription_create_params.rb', line 162 def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) @day_of_month = day_of_month @hour = hour @minute = minute @month = month @second = second end |
Instance Attribute Details
#day_of_month ⇒ Object
The day of the month the anchor should be. Ranges from 1 to 31.
152 153 154 |
# File 'lib/stripe/params/subscription_create_params.rb', line 152 def day_of_month @day_of_month end |
#hour ⇒ Object
The hour of the day the anchor should be. Ranges from 0 to 23.
154 155 156 |
# File 'lib/stripe/params/subscription_create_params.rb', line 154 def hour @hour end |
#minute ⇒ Object
The minute of the hour the anchor should be. Ranges from 0 to 59.
156 157 158 |
# File 'lib/stripe/params/subscription_create_params.rb', line 156 def minute @minute end |
#month ⇒ Object
The month to start full cycle periods. Ranges from 1 to 12.
158 159 160 |
# File 'lib/stripe/params/subscription_create_params.rb', line 158 def month @month end |
#second ⇒ Object
The second of the minute the anchor should be. Ranges from 0 to 59.
160 161 162 |
# File 'lib/stripe/params/subscription_create_params.rb', line 160 def second @second end |