Class: Stripe::SubscriptionCreateParams::BillingSchedule

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_create_params.rb

Defined Under Namespace

Classes: AppliesTo, BillUntil

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(applies_to: nil, bill_until: nil, key: nil) ⇒ BillingSchedule

Returns a new instance of BillingSchedule.



254
255
256
257
258
# File 'lib/stripe/params/subscription_create_params.rb', line 254

def initialize(applies_to: nil, bill_until: nil, key: nil)
  @applies_to = applies_to
  @bill_until = bill_until
  @key = key
end

Instance Attribute Details

#applies_toObject

Configure billing schedule differently for individual subscription items.



248
249
250
# File 'lib/stripe/params/subscription_create_params.rb', line 248

def applies_to
  @applies_to
end

#bill_untilObject

The end date for the billing schedule.



250
251
252
# File 'lib/stripe/params/subscription_create_params.rb', line 250

def bill_until
  @bill_until
end

#keyObject

Specify a key for the billing schedule. Must be unique to this field, alphanumeric, and up to 200 characters. If not provided, a unique key will be generated.



252
253
254
# File 'lib/stripe/params/subscription_create_params.rb', line 252

def key
  @key
end