Class: Stripe::SubscriptionCreateParams::BillingSchedule::AppliesTo
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionCreateParams::BillingSchedule::AppliesTo
- Defined in:
- lib/stripe/params/subscription_create_params.rb
Instance Attribute Summary collapse
-
#price ⇒ Object
The ID of the price object.
-
#type ⇒ Object
Controls which subscription items the billing schedule applies to.
Instance Method Summary collapse
-
#initialize(price: nil, type: nil) ⇒ AppliesTo
constructor
A new instance of AppliesTo.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(price: nil, type: nil) ⇒ AppliesTo
Returns a new instance of AppliesTo.
226 227 228 229 |
# File 'lib/stripe/params/subscription_create_params.rb', line 226 def initialize(price: nil, type: nil) @price = price @type = type end |
Instance Attribute Details
#price ⇒ Object
The ID of the price object.
222 223 224 |
# File 'lib/stripe/params/subscription_create_params.rb', line 222 def price @price end |
#type ⇒ Object
Controls which subscription items the billing schedule applies to.
224 225 226 |
# File 'lib/stripe/params/subscription_create_params.rb', line 224 def type @type end |