Class: Stripe::SubscriptionCreateParams::BillingSchedule::BillUntil
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionCreateParams::BillingSchedule::BillUntil
- Defined in:
- lib/stripe/params/subscription_create_params.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Specifies the billing period.
-
#timestamp ⇒ Object
The end date of the billing schedule.
-
#type ⇒ Object
Describes how the billing schedule will determine the end date.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ BillUntil
constructor
A new instance of BillUntil.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ BillUntil
Returns a new instance of BillUntil.
251 252 253 254 255 |
# File 'lib/stripe/params/subscription_create_params.rb', line 251 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Specifies the billing period.
245 246 247 |
# File 'lib/stripe/params/subscription_create_params.rb', line 245 def duration @duration end |
#timestamp ⇒ Object
The end date of the billing schedule.
247 248 249 |
# File 'lib/stripe/params/subscription_create_params.rb', line 247 def @timestamp end |
#type ⇒ Object
Describes how the billing schedule will determine the end date. Either ‘duration` or `timestamp`.
249 250 251 |
# File 'lib/stripe/params/subscription_create_params.rb', line 249 def type @type end |