Class: Stripe::SubscriptionCreateParams::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount



211
212
213
214
215
# File 'lib/stripe/params/subscription_create_params.rb', line 211

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



205
206
207
# File 'lib/stripe/params/subscription_create_params.rb', line 205

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



207
208
209
# File 'lib/stripe/params/subscription_create_params.rb', line 207

def discount
  @discount
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



209
210
211
# File 'lib/stripe/params/subscription_create_params.rb', line 209

def promotion_code
  @promotion_code
end