Class: Stripe::SubscriptionCreateParams::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_create_params.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



307
308
309
310
311
# File 'lib/stripe/params/subscription_create_params.rb', line 307

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



301
302
303
# File 'lib/stripe/params/subscription_create_params.rb', line 301

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



303
304
305
# File 'lib/stripe/params/subscription_create_params.rb', line 303

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



305
306
307
# File 'lib/stripe/params/subscription_create_params.rb', line 305

def type
  @type
end