Class: Stripe::SubscriptionCreateParams::Discount::Settings::ServicePeriodAnchorConfig::Custom
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionCreateParams::Discount::Settings::ServicePeriodAnchorConfig::Custom
- Defined in:
- lib/stripe/params/subscription_create_params.rb
Instance Attribute Summary collapse
-
#day_of_month ⇒ Object
The day of the month the anchor should be.
-
#hour ⇒ Object
The hour of the day the anchor should be.
-
#minute ⇒ Object
The minute of the hour the anchor should be.
-
#month ⇒ Object
The month to start full cycle periods.
-
#second ⇒ Object
The second of the minute the anchor should be.
Instance Method Summary collapse
-
#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom
constructor
A new instance of Custom.
Methods inherited from RequestParams
Constructor Details
#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom
Returns a new instance of Custom.
314 315 316 317 318 319 320 |
# File 'lib/stripe/params/subscription_create_params.rb', line 314 def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) @day_of_month = day_of_month @hour = hour @minute = minute @month = month @second = second end |
Instance Attribute Details
#day_of_month ⇒ Object
The day of the month the anchor should be. Ranges from 1 to 31.
304 305 306 |
# File 'lib/stripe/params/subscription_create_params.rb', line 304 def day_of_month @day_of_month end |
#hour ⇒ Object
The hour of the day the anchor should be. Ranges from 0 to 23.
306 307 308 |
# File 'lib/stripe/params/subscription_create_params.rb', line 306 def hour @hour end |
#minute ⇒ Object
The minute of the hour the anchor should be. Ranges from 0 to 59.
308 309 310 |
# File 'lib/stripe/params/subscription_create_params.rb', line 308 def minute @minute end |
#month ⇒ Object
The month to start full cycle periods. Ranges from 1 to 12.
310 311 312 |
# File 'lib/stripe/params/subscription_create_params.rb', line 310 def month @month end |
#second ⇒ Object
The second of the minute the anchor should be. Ranges from 0 to 59.
312 313 314 |
# File 'lib/stripe/params/subscription_create_params.rb', line 312 def second @second end |