Class: Stripe::SubscriptionCreateParams::InvoiceSettings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionCreateParams::InvoiceSettings
- Defined in:
- lib/stripe/params/subscription_create_params.rb
Defined Under Namespace
Classes: CustomField, Issuer
Instance Attribute Summary collapse
-
#account_tax_ids ⇒ Object
The account tax IDs associated with the subscription.
-
#custom_fields ⇒ Object
A list of up to 4 custom fields to be displayed on the invoice.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#footer ⇒ Object
Footer to be displayed on the invoice.
-
#issuer ⇒ Object
The connected account that issues the invoice.
Instance Method Summary collapse
-
#initialize(account_tax_ids: nil, custom_fields: nil, description: nil, footer: nil, issuer: nil) ⇒ InvoiceSettings
constructor
A new instance of InvoiceSettings.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(account_tax_ids: nil, custom_fields: nil, description: nil, footer: nil, issuer: nil) ⇒ InvoiceSettings
Returns a new instance of InvoiceSettings.
309 310 311 312 313 314 315 316 317 318 319 320 321 |
# File 'lib/stripe/params/subscription_create_params.rb', line 309 def initialize( account_tax_ids: nil, custom_fields: nil, description: nil, footer: nil, issuer: nil ) @account_tax_ids = account_tax_ids @custom_fields = custom_fields @description = description @footer = @issuer = issuer end |
Instance Attribute Details
#account_tax_ids ⇒ Object
The account tax IDs associated with the subscription. Will be set on invoices generated by the subscription.
299 300 301 |
# File 'lib/stripe/params/subscription_create_params.rb', line 299 def account_tax_ids @account_tax_ids end |
#custom_fields ⇒ Object
A list of up to 4 custom fields to be displayed on the invoice.
301 302 303 |
# File 'lib/stripe/params/subscription_create_params.rb', line 301 def custom_fields @custom_fields end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
303 304 305 |
# File 'lib/stripe/params/subscription_create_params.rb', line 303 def description @description end |
#footer ⇒ Object
Footer to be displayed on the invoice.
305 306 307 |
# File 'lib/stripe/params/subscription_create_params.rb', line 305 def @footer end |
#issuer ⇒ Object
The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.
307 308 309 |
# File 'lib/stripe/params/subscription_create_params.rb', line 307 def issuer @issuer end |