Class: Stripe::SubscriptionCreateParams::Item

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/subscription_create_params.rb

Defined Under Namespace

Classes: BillingThresholds, Discount, PriceData

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(billing_thresholds: nil, discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ Item



328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
# File 'lib/stripe/params/subscription_create_params.rb', line 328

def initialize(
  billing_thresholds: nil,
  discounts: nil,
  metadata: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @billing_thresholds = billing_thresholds
  @discounts = discounts
  @metadata = 
  @plan = plan
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.



312
313
314
# File 'lib/stripe/params/subscription_create_params.rb', line 312

def billing_thresholds
  @billing_thresholds
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



314
315
316
# File 'lib/stripe/params/subscription_create_params.rb', line 314

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.



316
317
318
# File 'lib/stripe/params/subscription_create_params.rb', line 316

def 
  @metadata
end

#planObject

Plan ID for this item, as a string.



318
319
320
# File 'lib/stripe/params/subscription_create_params.rb', line 318

def plan
  @plan
end

#priceObject

The ID of the price object.



320
321
322
# File 'lib/stripe/params/subscription_create_params.rb', line 320

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](docs.stripe.com/api/prices) object inline.



322
323
324
# File 'lib/stripe/params/subscription_create_params.rb', line 322

def price_data
  @price_data
end

#quantityObject

Quantity for this item.



324
325
326
# File 'lib/stripe/params/subscription_create_params.rb', line 324

def quantity
  @quantity
end

#tax_ratesObject

A list of [Tax Rate](docs.stripe.com/api/tax_rates) ids. These Tax Rates will override the [default_tax_rates](docs.stripe.com/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



326
327
328
# File 'lib/stripe/params/subscription_create_params.rb', line 326

def tax_rates
  @tax_rates
end

Class Method Details

.field_encodingsObject



348
349
350
351
352
# File 'lib/stripe/params/subscription_create_params.rb', line 348

def self.field_encodings
  @field_encodings = {
    price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } },
  }
end