Class: Stripe::SubscriptionCreateParams::Item::BillingThresholds
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionCreateParams::Item::BillingThresholds
- Defined in:
- lib/stripe/params/subscription_create_params.rb
Instance Attribute Summary collapse
-
#usage_gte ⇒ Object
Number of units that meets the billing threshold to advance the subscription to a new billing period (e.g., it takes 10 $5 units to meet a $50 [monetary threshold](docs.stripe.com/api/subscriptions/update#update_subscription-billing_thresholds-amount_gte)).
Instance Method Summary collapse
-
#initialize(usage_gte: nil) ⇒ BillingThresholds
constructor
A new instance of BillingThresholds.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(usage_gte: nil) ⇒ BillingThresholds
Returns a new instance of BillingThresholds.
354 355 356 |
# File 'lib/stripe/params/subscription_create_params.rb', line 354 def initialize(usage_gte: nil) @usage_gte = usage_gte end |
Instance Attribute Details
#usage_gte ⇒ Object
Number of units that meets the billing threshold to advance the subscription to a new billing period (e.g., it takes 10 $5 units to meet a $50 [monetary threshold](docs.stripe.com/api/subscriptions/update#update_subscription-billing_thresholds-amount_gte))
352 353 354 |
# File 'lib/stripe/params/subscription_create_params.rb', line 352 def usage_gte @usage_gte end |