Class: Stripe::SubscriptionCreateParams::Item::CurrentTrial
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionCreateParams::Item::CurrentTrial
- Defined in:
- lib/stripe/params/subscription_create_params.rb
Instance Attribute Summary collapse
-
#trial_offer ⇒ Object
The ID of the trial offer to apply to the subscription item.
Instance Method Summary collapse
-
#initialize(trial_offer: nil) ⇒ CurrentTrial
constructor
A new instance of CurrentTrial.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(trial_offer: nil) ⇒ CurrentTrial
Returns a new instance of CurrentTrial.
338 339 340 |
# File 'lib/stripe/params/subscription_create_params.rb', line 338 def initialize(trial_offer: nil) @trial_offer = trial_offer end |
Instance Attribute Details
#trial_offer ⇒ Object
The ID of the trial offer to apply to the subscription item.
336 337 338 |
# File 'lib/stripe/params/subscription_create_params.rb', line 336 def trial_offer @trial_offer end |