Class: Stripe::SubscriptionCreateParams::Item::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_create_params.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



437
438
439
440
441
442
# File 'lib/stripe/params/subscription_create_params.rb', line 437

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



429
430
431
# File 'lib/stripe/params/subscription_create_params.rb', line 429

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



431
432
433
# File 'lib/stripe/params/subscription_create_params.rb', line 431

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



433
434
435
# File 'lib/stripe/params/subscription_create_params.rb', line 433

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



435
436
437
# File 'lib/stripe/params/subscription_create_params.rb', line 435

def promotion_code
  @promotion_code
end