Class: Stripe::SubscriptionCreateParams::Item::Discount::Settings::ServicePeriodAnchorConfig::Custom

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom

Returns a new instance of Custom.



495
496
497
498
499
500
501
# File 'lib/stripe/params/subscription_create_params.rb', line 495

def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil)
  @day_of_month = day_of_month
  @hour = hour
  @minute = minute
  @month = month
  @second = second
end

Instance Attribute Details

#day_of_monthObject

The day of the month the anchor should be. Ranges from 1 to 31.



485
486
487
# File 'lib/stripe/params/subscription_create_params.rb', line 485

def day_of_month
  @day_of_month
end

#hourObject

The hour of the day the anchor should be. Ranges from 0 to 23.



487
488
489
# File 'lib/stripe/params/subscription_create_params.rb', line 487

def hour
  @hour
end

#minuteObject

The minute of the hour the anchor should be. Ranges from 0 to 59.



489
490
491
# File 'lib/stripe/params/subscription_create_params.rb', line 489

def minute
  @minute
end

#monthObject

The month to start full cycle periods. Ranges from 1 to 12.



491
492
493
# File 'lib/stripe/params/subscription_create_params.rb', line 491

def month
  @month
end

#secondObject

The second of the minute the anchor should be. Ranges from 0 to 59.



493
494
495
# File 'lib/stripe/params/subscription_create_params.rb', line 493

def second
  @second
end