Class: Stripe::SubscriptionCreateParams::Item::Trial
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionCreateParams::Item::Trial
- Defined in:
- lib/stripe/params/subscription_create_params.rb
Instance Attribute Summary collapse
-
#converts_to ⇒ Object
List of price IDs which, if present on the subscription following a paid trial, constitute opting-in to the paid trial.
-
#type ⇒ Object
Determines the type of trial for this item.
Instance Method Summary collapse
-
#initialize(converts_to: nil, type: nil) ⇒ Trial
constructor
A new instance of Trial.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(converts_to: nil, type: nil) ⇒ Trial
Returns a new instance of Trial.
466 467 468 469 |
# File 'lib/stripe/params/subscription_create_params.rb', line 466 def initialize(converts_to: nil, type: nil) @converts_to = converts_to @type = type end |
Instance Attribute Details
#converts_to ⇒ Object
List of price IDs which, if present on the subscription following a paid trial, constitute opting-in to the paid trial. Currently only supports at most 1 price ID.
462 463 464 |
# File 'lib/stripe/params/subscription_create_params.rb', line 462 def converts_to @converts_to end |
#type ⇒ Object
Determines the type of trial for this item.
464 465 466 |
# File 'lib/stripe/params/subscription_create_params.rb', line 464 def type @type end |