Class: Stripe::SubscriptionCreateParams::PaymentSettings::PaymentMethodOptions::Billie::CompanyDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionCreateParams::PaymentSettings::PaymentMethodOptions::Billie::CompanyDetails
- Defined in:
- lib/stripe/params/subscription_create_params.rb
Defined Under Namespace
Classes: RegisteredAddress
Instance Attribute Summary collapse
-
#registered_address ⇒ Object
The address the company or entity is registered with.
-
#registered_name ⇒ Object
Company or entity name.
-
#registration_number ⇒ Object
The official registration number for the given registration type.
-
#registration_type ⇒ Object
Type of registration the company or entity holds in their registered country.
-
#vat ⇒ Object
VAT ID number.
Instance Method Summary collapse
-
#initialize(registered_address: nil, registered_name: nil, registration_number: nil, registration_type: nil, vat: nil) ⇒ CompanyDetails
constructor
A new instance of CompanyDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(registered_address: nil, registered_name: nil, registration_number: nil, registration_type: nil, vat: nil) ⇒ CompanyDetails
Returns a new instance of CompanyDetails.
525 526 527 528 529 530 531 532 533 534 535 536 537 |
# File 'lib/stripe/params/subscription_create_params.rb', line 525 def initialize( registered_address: nil, registered_name: nil, registration_number: nil, registration_type: nil, vat: nil ) @registered_address = registered_address @registered_name = registered_name @registration_number = registration_number @registration_type = registration_type @vat = vat end |
Instance Attribute Details
#registered_address ⇒ Object
The address the company or entity is registered with.
515 516 517 |
# File 'lib/stripe/params/subscription_create_params.rb', line 515 def registered_address @registered_address end |
#registered_name ⇒ Object
Company or entity name.
517 518 519 |
# File 'lib/stripe/params/subscription_create_params.rb', line 517 def registered_name @registered_name end |
#registration_number ⇒ Object
The official registration number for the given registration type.
519 520 521 |
# File 'lib/stripe/params/subscription_create_params.rb', line 519 def registration_number @registration_number end |
#registration_type ⇒ Object
Type of registration the company or entity holds in their registered country.
521 522 523 |
# File 'lib/stripe/params/subscription_create_params.rb', line 521 def registration_type @registration_type end |
#vat ⇒ Object
VAT ID number.
523 524 525 |
# File 'lib/stripe/params/subscription_create_params.rb', line 523 def vat @vat end |