Class: Stripe::SubscriptionCreateParams::PaymentSettings::PaymentMethodOptions::Blik::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h

Constructor Details

#initialize(expires_at: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



552
553
554
# File 'lib/stripe/params/subscription_create_params.rb', line 552

def initialize(expires_at: nil)
  @expires_at = expires_at
end

Instance Attribute Details

#expires_at ⇒ Object

Date when the mandate expires and no further payments will be charged. If not provided, the mandate will be set to be indefinite.



550
551
552
# File 'lib/stripe/params/subscription_create_params.rb', line 550

def expires_at
  @expires_at
end