Class: Stripe::SubscriptionCreateParams::PaymentSettings::PaymentMethodOptions::Card

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_create_params.rb

Defined Under Namespace

Classes: MandateOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(mandate_options: nil, network: nil, request_three_d_secure: nil) ⇒ Card

Returns a new instance of Card.



748
749
750
751
752
# File 'lib/stripe/params/subscription_create_params.rb', line 748

def initialize(mandate_options: nil, network: nil, request_three_d_secure: nil)
  @mandate_options = mandate_options
  @network = network
  @request_three_d_secure = request_three_d_secure
end

Instance Attribute Details

#mandate_optionsObject

Configuration options for setting up an eMandate for cards issued in India.



742
743
744
# File 'lib/stripe/params/subscription_create_params.rb', line 742

def mandate_options
  @mandate_options
end

#networkObject

Selected network to process this Subscription on. Depends on the available networks of the card attached to the Subscription. Can be only set confirm-time.



744
745
746
# File 'lib/stripe/params/subscription_create_params.rb', line 744

def network
  @network
end

#request_three_d_secureObject

We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and other requirements. However, if you wish to request 3D Secure based on logic from your own fraud engine, provide this option. Read our guide on manually requesting 3D Secure for more information on how this configuration interacts with Radar and our SCA Engine.



746
747
748
# File 'lib/stripe/params/subscription_create_params.rb', line 746

def request_three_d_secure
  @request_three_d_secure
end