Class: Stripe::SubscriptionCreateParams::PaymentSettings::PaymentMethodOptions::Payto::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, purpose: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



787
788
789
790
# File 'lib/stripe/params/subscription_create_params.rb', line 787

def initialize(amount: nil, purpose: nil)
  @amount = amount
  @purpose = purpose
end

Instance Attribute Details

#amountObject

The maximum amount that can be collected in a single invoice. If you don’t specify a maximum, then there is no limit.



783
784
785
# File 'lib/stripe/params/subscription_create_params.rb', line 783

def amount
  @amount
end

#purposeObject

The purpose for which payments are made. Has a default value based on your merchant category code.



785
786
787
# File 'lib/stripe/params/subscription_create_params.rb', line 785

def purpose
  @purpose
end