Class: Stripe::SubscriptionCreateParams::PaymentSettings::PaymentMethodOptions::Upi::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



858
859
860
861
862
863
# File 'lib/stripe/params/subscription_create_params.rb', line 858

def initialize(amount: nil, amount_type: nil, description: nil, end_date: nil)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



850
851
852
# File 'lib/stripe/params/subscription_create_params.rb', line 850

def amount
  @amount
end

#amount_typeObject

One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.



852
853
854
# File 'lib/stripe/params/subscription_create_params.rb', line 852

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



854
855
856
# File 'lib/stripe/params/subscription_create_params.rb', line 854

def description
  @description
end

#end_dateObject

End date of the mandate or subscription.



856
857
858
# File 'lib/stripe/params/subscription_create_params.rb', line 856

def end_date
  @end_date
end