Class: Stripe::SubscriptionCreateParams::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount_percent: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



1007
1008
1009
1010
# File 'lib/stripe/params/subscription_create_params.rb', line 1007

def initialize(amount_percent: nil, destination: nil)
  @amount_percent = amount_percent
  @destination = destination
end

Instance Attribute Details

#amount_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination.



1003
1004
1005
# File 'lib/stripe/params/subscription_create_params.rb', line 1003

def amount_percent
  @amount_percent
end

#destinationObject

ID of an existing, connected Stripe account.



1005
1006
1007
# File 'lib/stripe/params/subscription_create_params.rb', line 1005

def destination
  @destination
end