Class: Stripe::SubscriptionCreateParams::TrialSettings::EndBehavior
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionCreateParams::TrialSettings::EndBehavior
- Defined in:
- lib/stripe/params/subscription_create_params.rb
Instance Attribute Summary collapse
-
#missing_payment_method ⇒ Object
Indicates how the subscription should change when the trial ends if the user did not provide a payment method.
Instance Method Summary collapse
-
#initialize(missing_payment_method: nil) ⇒ EndBehavior
constructor
A new instance of EndBehavior.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(missing_payment_method: nil) ⇒ EndBehavior
Returns a new instance of EndBehavior.
744 745 746 |
# File 'lib/stripe/params/subscription_create_params.rb', line 744 def initialize(missing_payment_method: nil) @missing_payment_method = missing_payment_method end |
Instance Attribute Details
#missing_payment_method ⇒ Object
Indicates how the subscription should change when the trial ends if the user did not provide a payment method.
742 743 744 |
# File 'lib/stripe/params/subscription_create_params.rb', line 742 def missing_payment_method @missing_payment_method end |