Class: Stripe::SubscriptionItem::CreateParams::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionItem::CreateParams::Discount
- Defined in:
- lib/stripe/resources/subscription_item.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
291 292 293 294 295 296 |
# File 'lib/stripe/resources/subscription_item.rb', line 291 def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
283 284 285 |
# File 'lib/stripe/resources/subscription_item.rb', line 283 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
285 286 287 |
# File 'lib/stripe/resources/subscription_item.rb', line 285 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
287 288 289 |
# File 'lib/stripe/resources/subscription_item.rb', line 287 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
289 290 291 |
# File 'lib/stripe/resources/subscription_item.rb', line 289 def promotion_code @promotion_code end |