Class: Stripe::SubscriptionItem::CreateParams::Trial
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionItem::CreateParams::Trial
- Defined in:
- lib/stripe/resources/subscription_item.rb
Instance Attribute Summary collapse
-
#converts_to ⇒ Object
List of price IDs which, if present on the subscription following a paid trial, constitute opting-in to the paid trial.
-
#type ⇒ Object
Determines the type of trial for this item.
Instance Method Summary collapse
-
#initialize(converts_to: nil, type: nil) ⇒ Trial
constructor
A new instance of Trial.
Methods inherited from RequestParams
Constructor Details
#initialize(converts_to: nil, type: nil) ⇒ Trial
Returns a new instance of Trial.
304 305 306 307 |
# File 'lib/stripe/resources/subscription_item.rb', line 304 def initialize(converts_to: nil, type: nil) @converts_to = converts_to @type = type end |
Instance Attribute Details
#converts_to ⇒ Object
List of price IDs which, if present on the subscription following a paid trial, constitute opting-in to the paid trial. Currently only supports at most 1 price ID.
300 301 302 |
# File 'lib/stripe/resources/subscription_item.rb', line 300 def converts_to @converts_to end |
#type ⇒ Object
Determines the type of trial for this item.
302 303 304 |
# File 'lib/stripe/resources/subscription_item.rb', line 302 def type @type end |