Class: Stripe::SubscriptionItem::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionItem::UpdateParams
- Defined in:
- lib/stripe/resources/subscription_item.rb
Defined Under Namespace
Classes: BillingThresholds, Discount, PriceData
Instance Attribute Summary collapse
-
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period.
-
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription item.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#off_session ⇒ Object
Indicates if a customer is on or off-session while an invoice payment is attempted.
-
#payment_behavior ⇒ Object
Use ‘allow_incomplete` to transition the subscription to `status=past_due` if a payment is required but cannot be paid.
-
#plan ⇒ Object
The identifier of the new plan for this subscription item.
-
#price ⇒ Object
The ID of the price object.
-
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.
-
#proration_behavior ⇒ Object
Determines how to handle [prorations](stripe.com/docs/billing/subscriptions/prorations) when the billing cycle changes (e.g., when switching plans, resetting ‘billing_cycle_anchor=now`, or starting a trial), or if an item’s ‘quantity` changes.
-
#proration_date ⇒ Object
If set, the proration will be calculated as though the subscription was updated at the given time.
-
#quantity ⇒ Object
The quantity you’d like to apply to the subscription item you’re creating.
-
#tax_rates ⇒ Object
A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids.
Instance Method Summary collapse
-
#initialize(billing_thresholds: nil, discounts: nil, expand: nil, metadata: nil, off_session: nil, payment_behavior: nil, plan: nil, price: nil, price_data: nil, proration_behavior: nil, proration_date: nil, quantity: nil, tax_rates: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(billing_thresholds: nil, discounts: nil, expand: nil, metadata: nil, off_session: nil, payment_behavior: nil, plan: nil, price: nil, price_data: nil, proration_behavior: nil, proration_date: nil, quantity: nil, tax_rates: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/stripe/resources/subscription_item.rb', line 137 def initialize( billing_thresholds: nil, discounts: nil, expand: nil, metadata: nil, off_session: nil, payment_behavior: nil, plan: nil, price: nil, price_data: nil, proration_behavior: nil, proration_date: nil, quantity: nil, tax_rates: nil ) @billing_thresholds = billing_thresholds @discounts = discounts @expand = @metadata = @off_session = off_session @payment_behavior = payment_behavior @plan = plan @price = price @price_data = price_data @proration_behavior = proration_behavior @proration_date = proration_date @quantity = quantity @tax_rates = tax_rates end |
Instance Attribute Details
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.
105 106 107 |
# File 'lib/stripe/resources/subscription_item.rb', line 105 def billing_thresholds @billing_thresholds end |
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription item.
107 108 109 |
# File 'lib/stripe/resources/subscription_item.rb', line 107 def discounts @discounts end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
109 110 111 |
# File 'lib/stripe/resources/subscription_item.rb', line 109 def @expand end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
111 112 113 |
# File 'lib/stripe/resources/subscription_item.rb', line 111 def @metadata end |
#off_session ⇒ Object
Indicates if a customer is on or off-session while an invoice payment is attempted. Defaults to ‘false` (on-session).
113 114 115 |
# File 'lib/stripe/resources/subscription_item.rb', line 113 def off_session @off_session end |
#payment_behavior ⇒ Object
Use ‘allow_incomplete` to transition the subscription to `status=past_due` if a payment is required but cannot be paid. This allows you to manage scenarios where additional user actions are needed to pay a subscription’s invoice. For example, SCA regulation may require 3DS authentication to complete payment. See the [SCA Migration Guide](stripe.com/docs/billing/migration/strong-customer-authentication) for Billing to learn more. This is the default behavior.
Use ‘default_incomplete` to transition the subscription to `status=past_due` when payment is required and await explicit confirmation of the invoice’s payment intent. This allows simpler management of scenarios where additional user actions are needed to pay a subscription’s invoice. Such as failed payments, [SCA regulation](stripe.com/docs/billing/migration/strong-customer-authentication), or collecting a mandate for a bank debit payment method.
Use ‘pending_if_incomplete` to update the subscription using [pending updates](stripe.com/docs/billing/subscriptions/pending-updates). When you use `pending_if_incomplete` you can only pass the parameters [supported by pending updates](stripe.com/docs/billing/pending-updates-reference#supported-attributes).
Use ‘error_if_incomplete` if you want Stripe to return an HTTP 402 status code if a subscription’s invoice cannot be paid. For example, if a payment method requires 3DS authentication due to SCA regulation and further user action is needed, this parameter does not update the subscription and returns an error instead. This was the default behavior for API versions prior to 2019-03-14. See the [changelog](docs.stripe.com/changelog/2019-03-14) to learn more.
121 122 123 |
# File 'lib/stripe/resources/subscription_item.rb', line 121 def payment_behavior @payment_behavior end |
#plan ⇒ Object
The identifier of the new plan for this subscription item.
123 124 125 |
# File 'lib/stripe/resources/subscription_item.rb', line 123 def plan @plan end |
#price ⇒ Object
The ID of the price object. One of ‘price` or `price_data` is required. When changing a subscription item’s price, ‘quantity` is set to 1 unless a `quantity` parameter is provided.
125 126 127 |
# File 'lib/stripe/resources/subscription_item.rb', line 125 def price @price end |
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.
127 128 129 |
# File 'lib/stripe/resources/subscription_item.rb', line 127 def price_data @price_data end |
#proration_behavior ⇒ Object
Determines how to handle [prorations](stripe.com/docs/billing/subscriptions/prorations) when the billing cycle changes (e.g., when switching plans, resetting ‘billing_cycle_anchor=now`, or starting a trial), or if an item’s ‘quantity` changes. The default value is `create_prorations`.
129 130 131 |
# File 'lib/stripe/resources/subscription_item.rb', line 129 def proration_behavior @proration_behavior end |
#proration_date ⇒ Object
If set, the proration will be calculated as though the subscription was updated at the given time. This can be used to apply the same proration that was previewed with the [upcoming invoice](stripe.com/docs/api#retrieve_customer_invoice) endpoint.
131 132 133 |
# File 'lib/stripe/resources/subscription_item.rb', line 131 def proration_date @proration_date end |
#quantity ⇒ Object
The quantity you’d like to apply to the subscription item you’re creating.
133 134 135 |
# File 'lib/stripe/resources/subscription_item.rb', line 133 def quantity @quantity end |
#tax_rates ⇒ Object
A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.
135 136 137 |
# File 'lib/stripe/resources/subscription_item.rb', line 135 def tax_rates @tax_rates end |