Class: Stripe::SubscriptionItem::UpdateParams::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionItem::UpdateParams::Discount
- Defined in:
- lib/stripe/resources/subscription_item.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
106 107 108 109 110 111 |
# File 'lib/stripe/resources/subscription_item.rb', line 106 def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
98 99 100 |
# File 'lib/stripe/resources/subscription_item.rb', line 98 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
100 101 102 |
# File 'lib/stripe/resources/subscription_item.rb', line 100 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
102 103 104 |
# File 'lib/stripe/resources/subscription_item.rb', line 102 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
104 105 106 |
# File 'lib/stripe/resources/subscription_item.rb', line 104 def promotion_code @promotion_code end |