Class: Stripe::SubscriptionItemCreateParams::CurrentTrial
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionItemCreateParams::CurrentTrial
- Defined in:
- lib/stripe/params/subscription_item_create_params.rb
Instance Attribute Summary collapse
-
#trial_end ⇒ Object
Unix timestamp representing the end of the trial offer period.
-
#trial_offer ⇒ Object
The ID of the trial offer to apply to the subscription item.
Instance Method Summary collapse
-
#initialize(trial_end: nil, trial_offer: nil) ⇒ CurrentTrial
constructor
A new instance of CurrentTrial.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(trial_end: nil, trial_offer: nil) ⇒ CurrentTrial
Returns a new instance of CurrentTrial.
21 22 23 24 |
# File 'lib/stripe/params/subscription_item_create_params.rb', line 21 def initialize(trial_end: nil, trial_offer: nil) @trial_end = trial_end @trial_offer = trial_offer end |
Instance Attribute Details
#trial_end ⇒ Object
Unix timestamp representing the end of the trial offer period. Required when the trial offer has ‘duration.type=timestamp`. Cannot be specified when `duration.type=relative`.
17 18 19 |
# File 'lib/stripe/params/subscription_item_create_params.rb', line 17 def trial_end @trial_end end |
#trial_offer ⇒ Object
The ID of the trial offer to apply to the subscription item.
19 20 21 |
# File 'lib/stripe/params/subscription_item_create_params.rb', line 19 def trial_offer @trial_offer end |