Class: Stripe::SubscriptionItemCreateParams::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_item_create_params.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



47
48
49
50
51
# File 'lib/stripe/params/subscription_item_create_params.rb', line 47

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



41
42
43
# File 'lib/stripe/params/subscription_item_create_params.rb', line 41

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



43
44
45
# File 'lib/stripe/params/subscription_item_create_params.rb', line 43

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



45
46
47
# File 'lib/stripe/params/subscription_item_create_params.rb', line 45

def type
  @type
end