Class: Stripe::SubscriptionItemCreateParams::Discount::Settings::ServicePeriodAnchorConfig::Custom

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_item_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom

Returns a new instance of Custom.



68
69
70
71
72
73
74
# File 'lib/stripe/params/subscription_item_create_params.rb', line 68

def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil)
  @day_of_month = day_of_month
  @hour = hour
  @minute = minute
  @month = month
  @second = second
end

Instance Attribute Details

#day_of_monthObject

The day of the month the anchor should be. Ranges from 1 to 31.



58
59
60
# File 'lib/stripe/params/subscription_item_create_params.rb', line 58

def day_of_month
  @day_of_month
end

#hourObject

The hour of the day the anchor should be. Ranges from 0 to 23.



60
61
62
# File 'lib/stripe/params/subscription_item_create_params.rb', line 60

def hour
  @hour
end

#minuteObject

The minute of the hour the anchor should be. Ranges from 0 to 59.



62
63
64
# File 'lib/stripe/params/subscription_item_create_params.rb', line 62

def minute
  @minute
end

#monthObject

The month to start full cycle periods. Ranges from 1 to 12.



64
65
66
# File 'lib/stripe/params/subscription_item_create_params.rb', line 64

def month
  @month
end

#secondObject

The second of the minute the anchor should be. Ranges from 0 to 59.



66
67
68
# File 'lib/stripe/params/subscription_item_create_params.rb', line 66

def second
  @second
end