Class: Stripe::SubscriptionItemCreateParams::Trial
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionItemCreateParams::Trial
- Defined in:
- lib/stripe/params/subscription_item_create_params.rb
Instance Attribute Summary collapse
-
#converts_to ⇒ Object
List of price IDs which, if present on the subscription following a paid trial, constitute opting-in to the paid trial.
-
#type ⇒ Object
Determines the type of trial for this item.
Instance Method Summary collapse
-
#initialize(converts_to: nil, type: nil) ⇒ Trial
constructor
A new instance of Trial.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(converts_to: nil, type: nil) ⇒ Trial
Returns a new instance of Trial.
122 123 124 125 |
# File 'lib/stripe/params/subscription_item_create_params.rb', line 122 def initialize(converts_to: nil, type: nil) @converts_to = converts_to @type = type end |
Instance Attribute Details
#converts_to ⇒ Object
List of price IDs which, if present on the subscription following a paid trial, constitute opting-in to the paid trial. Currently only supports at most 1 price ID.
118 119 120 |
# File 'lib/stripe/params/subscription_item_create_params.rb', line 118 def converts_to @converts_to end |
#type ⇒ Object
Determines the type of trial for this item.
120 121 122 |
# File 'lib/stripe/params/subscription_item_create_params.rb', line 120 def type @type end |