Class: Stripe::SubscriptionItemDeleteParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/subscription_item_delete_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(clear_usage: nil, payment_behavior: nil, proration_behavior: nil, proration_date: nil) ⇒ SubscriptionItemDeleteParams



21
22
23
24
25
26
27
28
29
30
31
# File 'lib/stripe/params/subscription_item_delete_params.rb', line 21

def initialize(
  clear_usage: nil,
  payment_behavior: nil,
  proration_behavior: nil,
  proration_date: nil
)
  @clear_usage = clear_usage
  @payment_behavior = payment_behavior
  @proration_behavior = proration_behavior
  @proration_date = proration_date
end

Instance Attribute Details

#clear_usageObject

Delete all usage for the given subscription item. Allowed only when the current plan’s usage_type is metered.



7
8
9
# File 'lib/stripe/params/subscription_item_delete_params.rb', line 7

def clear_usage
  @clear_usage
end

#payment_behaviorObject

Use allow_incomplete to transition the subscription to ‘status=past_due` if a payment is required but cannot be paid. This allows you to manage scenarios where additional user actions are needed to pay a subscription’s invoice. For example, SCA regulation may require 3DS authentication to complete payment. See the [SCA Migration Guide](docs.stripe.com/billing/migration/strong-customer-authentication) for Billing to learn more. This is the default behavior.

Use default_incomplete to transition the subscription to ‘status=past_due` when payment is required and await explicit confirmation of the invoice’s payment intent. This allows simpler management of scenarios where additional user actions are needed to pay a subscription’s invoice. Such as failed payments, [SCA regulation](docs.stripe.com/billing/migration/strong-customer-authentication), or collecting a mandate for a bank debit payment method.

Use pending_if_incomplete to update the subscription using [pending updates](docs.stripe.com/billing/subscriptions/pending-updates). When you use pending_if_incomplete you can only pass the parameters [supported by pending updates](docs.stripe.com/billing/pending-updates-reference#supported-attributes).

Use error_if_incomplete if you want Stripe to return an HTTP 402 status code if a subscription’s invoice cannot be paid. For example, if a payment method requires 3DS authentication due to SCA regulation and further user action is needed, this parameter does not update the subscription and returns an error instead. This was the default behavior for API versions prior to 2019-03-14. See the [changelog](docs.stripe.com/changelog/2019-03-14) to learn more.



15
16
17
# File 'lib/stripe/params/subscription_item_delete_params.rb', line 15

def payment_behavior
  @payment_behavior
end

#proration_behaviorObject

Determines how to handle [prorations](docs.stripe.com/billing/subscriptions/prorations) when the billing cycle changes (e.g., when switching plans, resetting ‘billing_cycle_anchor=now`, or starting a trial), or if an item’s quantity changes. The default value is create_prorations.



17
18
19
# File 'lib/stripe/params/subscription_item_delete_params.rb', line 17

def proration_behavior
  @proration_behavior
end

#proration_dateObject

If set, the proration will be calculated as though the subscription was updated at the given time. This can be used to apply the same proration that was previewed with the [upcoming invoice](api.stripe.com#retrieve_customer_invoice) endpoint.



19
20
21
# File 'lib/stripe/params/subscription_item_delete_params.rb', line 19

def proration_date
  @proration_date
end