Class: Stripe::SubscriptionItemService::CreateParams::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionItemService::CreateParams::Discount::DiscountEnd
- Defined in:
- lib/stripe/services/subscription_item_service.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
286 287 288 289 290 |
# File 'lib/stripe/services/subscription_item_service.rb', line 286 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
278 279 280 |
# File 'lib/stripe/services/subscription_item_service.rb', line 278 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
281 282 283 |
# File 'lib/stripe/services/subscription_item_service.rb', line 281 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
284 285 286 |
# File 'lib/stripe/services/subscription_item_service.rb', line 284 def type @type end |