Class: Stripe::SubscriptionItemService::ListParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_item_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(ending_before: nil, expand: nil, limit: nil, starting_after: nil, subscription: nil) ⇒ ListParams

Returns a new instance of ListParams.



200
201
202
203
204
205
206
207
208
209
210
211
212
# File 'lib/stripe/services/subscription_item_service.rb', line 200

def initialize(
  ending_before: nil,
  expand: nil,
  limit: nil,
  starting_after: nil,
  subscription: nil
)
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
  @subscription = subscription
end

Instance Attribute Details

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



190
191
192
# File 'lib/stripe/services/subscription_item_service.rb', line 190

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



192
193
194
# File 'lib/stripe/services/subscription_item_service.rb', line 192

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



194
195
196
# File 'lib/stripe/services/subscription_item_service.rb', line 194

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



196
197
198
# File 'lib/stripe/services/subscription_item_service.rb', line 196

def starting_after
  @starting_after
end

#subscriptionObject

The ID of the subscription whose items will be retrieved.



198
199
200
# File 'lib/stripe/services/subscription_item_service.rb', line 198

def subscription
  @subscription
end