Class: Stripe::SubscriptionItemService::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_item_service.rb

Defined Under Namespace

Classes: BillingThresholds, Discount, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_thresholds: nil, discounts: nil, expand: nil, metadata: nil, off_session: nil, payment_behavior: nil, plan: nil, price: nil, price_data: nil, proration_behavior: nil, proration_date: nil, quantity: nil, tax_rates: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/stripe/services/subscription_item_service.rb', line 191

def initialize(
  billing_thresholds: nil,
  discounts: nil,
  expand: nil,
  metadata: nil,
  off_session: nil,
  payment_behavior: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  proration_behavior: nil,
  proration_date: nil,
  quantity: nil,
  tax_rates: nil
)
  @billing_thresholds = billing_thresholds
  @discounts = discounts
  @expand = expand
  @metadata = 
  @off_session = off_session
  @payment_behavior = payment_behavior
  @plan = plan
  @price = price
  @price_data = price_data
  @proration_behavior = proration_behavior
  @proration_date = proration_date
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. When updating, pass an empty string to remove previously-defined thresholds.



147
148
149
# File 'lib/stripe/services/subscription_item_service.rb', line 147

def billing_thresholds
  @billing_thresholds
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



150
151
152
# File 'lib/stripe/services/subscription_item_service.rb', line 150

def discounts
  @discounts
end

#expandObject

Specifies which fields in the response should be expanded.



153
154
155
# File 'lib/stripe/services/subscription_item_service.rb', line 153

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



156
157
158
# File 'lib/stripe/services/subscription_item_service.rb', line 156

def 
  @metadata
end

#off_sessionObject

Indicates if a customer is on or off-session while an invoice payment is attempted. Defaults to ‘false` (on-session).



159
160
161
# File 'lib/stripe/services/subscription_item_service.rb', line 159

def off_session
  @off_session
end

#payment_behaviorObject

Use ‘allow_incomplete` to transition the subscription to `status=past_due` if a payment is required but cannot be paid. This allows you to manage scenarios where additional user actions are needed to pay a subscription’s invoice. For example, SCA regulation may require 3DS authentication to complete payment. See the [SCA Migration Guide](stripe.com/docs/billing/migration/strong-customer-authentication) for Billing to learn more. This is the default behavior.

Use ‘default_incomplete` to transition the subscription to `status=past_due` when payment is required and await explicit confirmation of the invoice’s payment intent. This allows simpler management of scenarios where additional user actions are needed to pay a subscription’s invoice. Such as failed payments, [SCA regulation](stripe.com/docs/billing/migration/strong-customer-authentication), or collecting a mandate for a bank debit payment method.

Use ‘pending_if_incomplete` to update the subscription using [pending updates](stripe.com/docs/billing/subscriptions/pending-updates). When you use `pending_if_incomplete` you can only pass the parameters [supported by pending updates](stripe.com/docs/billing/pending-updates-reference#supported-attributes).

Use ‘error_if_incomplete` if you want Stripe to return an HTTP 402 status code if a subscription’s invoice cannot be paid. For example, if a payment method requires 3DS authentication due to SCA regulation and further user action is needed, this parameter does not update the subscription and returns an error instead. This was the default behavior for API versions prior to 2019-03-14. See the [changelog](stripe.com/docs/upgrades#2019-03-14) to learn more.



168
169
170
# File 'lib/stripe/services/subscription_item_service.rb', line 168

def payment_behavior
  @payment_behavior
end

#planObject

The identifier of the new plan for this subscription item.



171
172
173
# File 'lib/stripe/services/subscription_item_service.rb', line 171

def plan
  @plan
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required. When changing a subscription item’s price, ‘quantity` is set to 1 unless a `quantity` parameter is provided.



174
175
176
# File 'lib/stripe/services/subscription_item_service.rb', line 174

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.



177
178
179
# File 'lib/stripe/services/subscription_item_service.rb', line 177

def price_data
  @price_data
end

#proration_behaviorObject

Determines how to handle [prorations](stripe.com/docs/billing/subscriptions/prorations) when the billing cycle changes (e.g., when switching plans, resetting ‘billing_cycle_anchor=now`, or starting a trial), or if an item’s ‘quantity` changes. The default value is `create_prorations`.



180
181
182
# File 'lib/stripe/services/subscription_item_service.rb', line 180

def proration_behavior
  @proration_behavior
end

#proration_dateObject

If set, the proration will be calculated as though the subscription was updated at the given time. This can be used to apply the same proration that was previewed with the [upcoming invoice](stripe.com/docs/api#retrieve_customer_invoice) endpoint.



183
184
185
# File 'lib/stripe/services/subscription_item_service.rb', line 183

def proration_date
  @proration_date
end

#quantityObject

The quantity you’d like to apply to the subscription item you’re creating.



186
187
188
# File 'lib/stripe/services/subscription_item_service.rb', line 186

def quantity
  @quantity
end

#tax_ratesObject

A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



189
190
191
# File 'lib/stripe/services/subscription_item_service.rb', line 189

def tax_rates
  @tax_rates
end