Class: Stripe::SubscriptionItemService::UpdateParams::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_item_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



48
49
50
51
52
# File 'lib/stripe/services/subscription_item_service.rb', line 48

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



42
43
44
# File 'lib/stripe/services/subscription_item_service.rb', line 42

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



44
45
46
# File 'lib/stripe/services/subscription_item_service.rb', line 44

def discount
  @discount
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



46
47
48
# File 'lib/stripe/services/subscription_item_service.rb', line 46

def promotion_code
  @promotion_code
end