Class: Stripe::SubscriptionItemService::UpdateParams::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionItemService::UpdateParams::Discount::DiscountEnd
- Defined in:
- lib/stripe/services/subscription_item_service.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
51 52 53 54 55 |
# File 'lib/stripe/services/subscription_item_service.rb', line 51 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
45 46 47 |
# File 'lib/stripe/services/subscription_item_service.rb', line 45 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
47 48 49 |
# File 'lib/stripe/services/subscription_item_service.rb', line 47 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
49 50 51 |
# File 'lib/stripe/services/subscription_item_service.rb', line 49 def type @type end |