Class: Stripe::SubscriptionItemUpdateParams::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionItemUpdateParams::Discount
- Defined in:
- lib/stripe/params/subscription_item_update_params.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
62 63 64 65 66 67 |
# File 'lib/stripe/params/subscription_item_update_params.rb', line 62 def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
54 55 56 |
# File 'lib/stripe/params/subscription_item_update_params.rb', line 54 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
56 57 58 |
# File 'lib/stripe/params/subscription_item_update_params.rb', line 56 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
58 59 60 |
# File 'lib/stripe/params/subscription_item_update_params.rb', line 58 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
60 61 62 |
# File 'lib/stripe/params/subscription_item_update_params.rb', line 60 def promotion_code @promotion_code end |