Class: Stripe::SubscriptionPauseParams::BillFor::OutstandingUsageThrough
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionPauseParams::BillFor::OutstandingUsageThrough
- Defined in:
- lib/stripe/params/subscription_pause_params.rb
Instance Attribute Summary collapse
-
#type ⇒ Object
When to bill metered usage in the current period.
Instance Method Summary collapse
-
#initialize(type: nil) ⇒ OutstandingUsageThrough
constructor
A new instance of OutstandingUsageThrough.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(type: nil) ⇒ OutstandingUsageThrough
Returns a new instance of OutstandingUsageThrough.
11 12 13 |
# File 'lib/stripe/params/subscription_pause_params.rb', line 11 def initialize(type: nil) @type = type end |
Instance Attribute Details
#type ⇒ Object
When to bill metered usage in the current period.
9 10 11 |
# File 'lib/stripe/params/subscription_pause_params.rb', line 9 def type @type end |