Class: Stripe::SubscriptionResumeParams::BillingCycleAnchor
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionResumeParams::BillingCycleAnchor
- Defined in:
- lib/stripe/params/subscription_resume_params.rb
Instance Attribute Summary collapse
-
#type ⇒ Object
Determines how the billing cycle anchor changes when the subscription resumes.
Instance Method Summary collapse
-
#initialize(type: nil) ⇒ BillingCycleAnchor
constructor
A new instance of BillingCycleAnchor.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(type: nil) ⇒ BillingCycleAnchor
Returns a new instance of BillingCycleAnchor.
10 11 12 |
# File 'lib/stripe/params/subscription_resume_params.rb', line 10 def initialize(type: nil) @type = type end |
Instance Attribute Details
#type ⇒ Object
Determines how the billing cycle anchor changes when the subscription resumes.
8 9 10 |
# File 'lib/stripe/params/subscription_resume_params.rb', line 8 def type @type end |