Class: Stripe::SubscriptionSchedule::AmendParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: Amendment, Prebilling, ScheduleSettings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendments: nil, expand: nil, prebilling: nil, proration_behavior: nil, schedule_settings: nil) ⇒ AmendParams

Returns a new instance of AmendParams.



2479
2480
2481
2482
2483
2484
2485
2486
2487
2488
2489
2490
2491
# File 'lib/stripe/resources/subscription_schedule.rb', line 2479

def initialize(
  amendments: nil,
  expand: nil,
  prebilling: nil,
  proration_behavior: nil,
  schedule_settings: nil
)
  @amendments = amendments
  @expand = expand
  @prebilling = prebilling
  @proration_behavior = proration_behavior
  @schedule_settings = schedule_settings
end

Instance Attribute Details

#amendmentsObject

Changes to apply to the phases of the subscription schedule, in the order provided.



2468
2469
2470
# File 'lib/stripe/resources/subscription_schedule.rb', line 2468

def amendments
  @amendments
end

#expandObject

Specifies which fields in the response should be expanded.



2470
2471
2472
# File 'lib/stripe/resources/subscription_schedule.rb', line 2470

def expand
  @expand
end

#prebillingObject

Provide any time periods to bill in advance.



2472
2473
2474
# File 'lib/stripe/resources/subscription_schedule.rb', line 2472

def prebilling
  @prebilling
end

#proration_behaviorObject

In cases where the amendment changes the currently active phase,

specifies if and how to prorate at the time of the request.


2475
2476
2477
# File 'lib/stripe/resources/subscription_schedule.rb', line 2475

def proration_behavior
  @proration_behavior
end

#schedule_settingsObject

Changes to apply to the subscription schedule.



2477
2478
2479
# File 'lib/stripe/resources/subscription_schedule.rb', line 2477

def schedule_settings
  @schedule_settings
end