Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::AmendmentStart

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: AmendmentEnd, DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendment_end: nil, discount_end: nil, timestamp: nil, type: nil) ⇒ AmendmentStart

Returns a new instance of AmendmentStart.



2294
2295
2296
2297
2298
2299
# File 'lib/stripe/resources/subscription_schedule.rb', line 2294

def initialize(amendment_end: nil, discount_end: nil, timestamp: nil, type: nil)
  @amendment_end = amendment_end
  @discount_end = discount_end
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#amendment_endObject

Details of another amendment in the same array, immediately after which this amendment should begin.



2286
2287
2288
# File 'lib/stripe/resources/subscription_schedule.rb', line 2286

def amendment_end
  @amendment_end
end

#discount_endObject

Use the ‘end` time of a given discount.



2288
2289
2290
# File 'lib/stripe/resources/subscription_schedule.rb', line 2288

def discount_end
  @discount_end
end

#timestampObject

A precise Unix timestamp for the amendment to start.



2290
2291
2292
# File 'lib/stripe/resources/subscription_schedule.rb', line 2290

def timestamp
  @timestamp
end

#typeObject

Select one of three ways to pass the ‘amendment_start`.



2292
2293
2294
# File 'lib/stripe/resources/subscription_schedule.rb', line 2292

def type
  @type
end