Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::AmendmentStart::AmendmentEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(index: nil) ⇒ AmendmentEnd

Returns a new instance of AmendmentEnd.



2272
2273
2274
# File 'lib/stripe/resources/subscription_schedule.rb', line 2272

def initialize(index: nil)
  @index = index
end

Instance Attribute Details

#indexObject

The position of the previous amendment in the ‘amendments` array after which this amendment should begin. Indexes start from 0 and must be less than the index of the current amendment in the array.



2270
2271
2272
# File 'lib/stripe/resources/subscription_schedule.rb', line 2270

def index
  @index
end