Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::DiscountAction
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::AmendParams::Amendment::DiscountAction
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#add ⇒ Object
Details of the discount to add.
-
#remove ⇒ Object
Details of the discount to remove.
-
#set ⇒ Object
Details of the discount to replace the existing discounts with.
-
#type ⇒ Object
Determines the type of discount action.
Instance Method Summary collapse
-
#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ DiscountAction
constructor
A new instance of DiscountAction.
Methods inherited from RequestParams
Constructor Details
#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ DiscountAction
Returns a new instance of DiscountAction.
2077 2078 2079 2080 2081 2082 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2077 def initialize(add: nil, remove: nil, set: nil, type: nil) @add = add @remove = remove @set = set @type = type end |
Instance Attribute Details
#add ⇒ Object
Details of the discount to add.
2069 2070 2071 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2069 def add @add end |
#remove ⇒ Object
Details of the discount to remove.
2071 2072 2073 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2071 def remove @remove end |
#set ⇒ Object
Details of the discount to replace the existing discounts with.
2073 2074 2075 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2073 def set @set end |
#type ⇒ Object
Determines the type of discount action.
2075 2076 2077 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2075 def type @type end |