Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::DiscountAction::Remove

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Remove

Returns a new instance of Remove.



2047
2048
2049
2050
2051
# File 'lib/stripe/resources/subscription_schedule.rb', line 2047

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to remove from the ‘discounts` array.



2041
2042
2043
# File 'lib/stripe/resources/subscription_schedule.rb', line 2041

def coupon
  @coupon
end

#discountObject

The ID of a discount to remove from the ‘discounts` array.



2043
2044
2045
# File 'lib/stripe/resources/subscription_schedule.rb', line 2043

def discount
  @discount
end

#promotion_codeObject

The ID of a promotion code to remove from the ‘discounts` array.



2045
2046
2047
# File 'lib/stripe/resources/subscription_schedule.rb', line 2045

def promotion_code
  @promotion_code
end