Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::DiscountAction::Set

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Set

Returns a new instance of Set.



2062
2063
2064
2065
2066
# File 'lib/stripe/resources/subscription_schedule.rb', line 2062

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to replace the ‘discounts` array with.



2056
2057
2058
# File 'lib/stripe/resources/subscription_schedule.rb', line 2056

def coupon
  @coupon
end

#discountObject

An ID of an existing discount to replace the ‘discounts` array with.



2058
2059
2060
# File 'lib/stripe/resources/subscription_schedule.rb', line 2058

def discount
  @discount
end

#promotion_codeObject

An ID of an existing promotion code to replace the ‘discounts` array with.



2060
2061
2062
# File 'lib/stripe/resources/subscription_schedule.rb', line 2060

def promotion_code
  @promotion_code
end