Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::ItemAction

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: Add, Remove, Set

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ ItemAction

Returns a new instance of ItemAction.



2572
2573
2574
2575
2576
2577
# File 'lib/stripe/resources/subscription_schedule.rb', line 2572

def initialize(add: nil, remove: nil, set: nil, type: nil)
  @add = add
  @remove = remove
  @set = set
  @type = type
end

Instance Attribute Details

#addObject

Details of the subscription item to add. If an item with the same ‘price` exists, it will be replaced by this new item. Otherwise, it adds the new item.



2564
2565
2566
# File 'lib/stripe/resources/subscription_schedule.rb', line 2564

def add
  @add
end

#removeObject

Details of the subscription item to remove.



2566
2567
2568
# File 'lib/stripe/resources/subscription_schedule.rb', line 2566

def remove
  @remove
end

#setObject

Details of the subscription item to replace the existing items with. If an item with the ‘set` already exists, the `items` array is not cleared. Instead, all of the other `set` properties that are passed in this request will replace the existing values for the configuration item.



2568
2569
2570
# File 'lib/stripe/resources/subscription_schedule.rb', line 2568

def set
  @set
end

#typeObject

Determines the type of item action.



2570
2571
2572
# File 'lib/stripe/resources/subscription_schedule.rb', line 2570

def type
  @type
end