Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::ItemAction::Add
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::AmendParams::Amendment::ItemAction::Add
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#discounts ⇒ Object
The discounts applied to the item.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#price ⇒ Object
The ID of the price object.
-
#quantity ⇒ Object
Quantity for this item.
-
#tax_rates ⇒ Object
The tax rates that apply to this subscription item.
-
#trial ⇒ Object
Options that configure the trial on the subscription item.
Instance Method Summary collapse
-
#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Add
constructor
A new instance of Add.
Methods inherited from RequestParams
Constructor Details
#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Add
Returns a new instance of Add.
2453 2454 2455 2456 2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2453 def initialize( discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil ) @discounts = discounts @metadata = @price = price @quantity = quantity @tax_rates = tax_rates @trial = trial end |
Instance Attribute Details
#discounts ⇒ Object
The discounts applied to the item. Subscription item discounts are applied before subscription discounts.
2441 2442 2443 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2441 def discounts @discounts end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
2443 2444 2445 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2443 def @metadata end |
#price ⇒ Object
The ID of the price object.
2445 2446 2447 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2445 def price @price end |
#quantity ⇒ Object
Quantity for this item.
2447 2448 2449 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2447 def quantity @quantity end |
#tax_rates ⇒ Object
The tax rates that apply to this subscription item. When set, the ‘default_tax_rates` on the subscription do not apply to this `subscription_item`.
2449 2450 2451 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2449 def tax_rates @tax_rates end |
#trial ⇒ Object
Options that configure the trial on the subscription item.
2451 2452 2453 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2451 def trial @trial end |