Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::ItemAction::Add::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



2122
2123
2124
2125
2126
2127
# File 'lib/stripe/resources/subscription_schedule.rb', line 2122

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



2114
2115
2116
# File 'lib/stripe/resources/subscription_schedule.rb', line 2114

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



2116
2117
2118
# File 'lib/stripe/resources/subscription_schedule.rb', line 2116

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



2118
2119
2120
# File 'lib/stripe/resources/subscription_schedule.rb', line 2118

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



2120
2121
2122
# File 'lib/stripe/resources/subscription_schedule.rb', line 2120

def promotion_code
  @promotion_code
end