Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::ItemAction::Add::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



2406
2407
2408
2409
2410
# File 'lib/stripe/resources/subscription_schedule.rb', line 2406

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



2400
2401
2402
# File 'lib/stripe/resources/subscription_schedule.rb', line 2400

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



2402
2403
2404
# File 'lib/stripe/resources/subscription_schedule.rb', line 2402

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



2404
2405
2406
# File 'lib/stripe/resources/subscription_schedule.rb', line 2404

def type
  @type
end