Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::ItemAction::Add::Trial
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::AmendParams::Amendment::ItemAction::Add::Trial
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Instance Attribute Summary collapse
-
#converts_to ⇒ Object
List of price IDs which, if present on the subscription following a paid trial, constitute opting-in to the paid trial.
-
#type ⇒ Object
Determines the type of trial for this item.
Instance Method Summary collapse
-
#initialize(converts_to: nil, type: nil) ⇒ Trial
constructor
A new instance of Trial.
Methods inherited from RequestParams
Constructor Details
#initialize(converts_to: nil, type: nil) ⇒ Trial
Returns a new instance of Trial.
1847 1848 1849 1850 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1847 def initialize(converts_to: nil, type: nil) @converts_to = converts_to @type = type end |
Instance Attribute Details
#converts_to ⇒ Object
List of price IDs which, if present on the subscription following a paid trial, constitute opting-in to the paid trial. Currently only supports at most 1 price ID.
1843 1844 1845 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1843 def converts_to @converts_to end |
#type ⇒ Object
Determines the type of trial for this item.
1845 1846 1847 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1845 def type @type end |