Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::ItemAction::Set::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



2515
2516
2517
2518
2519
2520
# File 'lib/stripe/resources/subscription_schedule.rb', line 2515

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



2507
2508
2509
# File 'lib/stripe/resources/subscription_schedule.rb', line 2507

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



2509
2510
2511
# File 'lib/stripe/resources/subscription_schedule.rb', line 2509

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



2511
2512
2513
# File 'lib/stripe/resources/subscription_schedule.rb', line 2511

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



2513
2514
2515
# File 'lib/stripe/resources/subscription_schedule.rb', line 2513

def promotion_code
  @promotion_code
end