Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::ItemAction::Set::Trial
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::AmendParams::Amendment::ItemAction::Set::Trial
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Instance Attribute Summary collapse
-
#converts_to ⇒ Object
List of price IDs which, if present on the subscription following a paid trial, constitute opting-in to the paid trial.
-
#type ⇒ Object
Determines the type of trial for this item.
Instance Method Summary collapse
-
#initialize(converts_to: nil, type: nil) ⇒ Trial
constructor
A new instance of Trial.
Methods inherited from RequestParams
Constructor Details
#initialize(converts_to: nil, type: nil) ⇒ Trial
Returns a new instance of Trial.
2398 2399 2400 2401 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2398 def initialize(converts_to: nil, type: nil) @converts_to = converts_to @type = type end |
Instance Attribute Details
#converts_to ⇒ Object
List of price IDs which, if present on the subscription following a paid trial, constitute opting-in to the paid trial. Currently only supports at most 1 price ID.
2393 2394 2395 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2393 def converts_to @converts_to end |
#type ⇒ Object
Determines the type of trial for this item.
2396 2397 2398 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2396 def type @type end |