Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::SetPauseCollection::Set
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::AmendParams::Amendment::SetPauseCollection::Set
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Instance Attribute Summary collapse
-
#behavior ⇒ Object
The payment collection behavior for this subscription while paused.
Instance Method Summary collapse
-
#initialize(behavior: nil) ⇒ Set
constructor
A new instance of Set.
Methods inherited from RequestParams
Constructor Details
#initialize(behavior: nil) ⇒ Set
Returns a new instance of Set.
2603 2604 2605 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2603 def initialize(behavior: nil) @behavior = behavior end |
Instance Attribute Details
#behavior ⇒ Object
The payment collection behavior for this subscription while paused. One of ‘keep_as_draft`, `mark_uncollectible`, or `void`.
2601 2602 2603 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2601 def behavior @behavior end |