Class: Stripe::SubscriptionSchedule::AmendParams::Prebilling
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::AmendParams::Prebilling
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#bill_from ⇒ Object
The beginning of the prebilled time period.
-
#bill_until ⇒ Object
The end of the prebilled time period.
-
#invoice_at ⇒ Object
When the prebilling invoice should be created.
-
#update_behavior ⇒ Object
Whether to cancel or preserve ‘prebilling` if the subscription is updated during the prebilled period.
Instance Method Summary collapse
-
#initialize(bill_from: nil, bill_until: nil, invoice_at: nil, update_behavior: nil) ⇒ Prebilling
constructor
A new instance of Prebilling.
Methods inherited from RequestParams
Constructor Details
#initialize(bill_from: nil, bill_until: nil, invoice_at: nil, update_behavior: nil) ⇒ Prebilling
Returns a new instance of Prebilling.
2451 2452 2453 2454 2455 2456 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2451 def initialize(bill_from: nil, bill_until: nil, invoice_at: nil, update_behavior: nil) @bill_from = bill_from @bill_until = bill_until @invoice_at = invoice_at @update_behavior = update_behavior end |
Instance Attribute Details
#bill_from ⇒ Object
The beginning of the prebilled time period. The default value is ‘now`.
2443 2444 2445 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2443 def bill_from @bill_from end |
#bill_until ⇒ Object
The end of the prebilled time period.
2445 2446 2447 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2445 def bill_until @bill_until end |
#invoice_at ⇒ Object
When the prebilling invoice should be created. The default value is ‘now`.
2447 2448 2449 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2447 def invoice_at @invoice_at end |
#update_behavior ⇒ Object
Whether to cancel or preserve ‘prebilling` if the subscription is updated during the prebilled period. The default value is `reset`.
2449 2450 2451 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2449 def update_behavior @update_behavior end |