Class: Stripe::SubscriptionSchedule::AmendParams::Prebilling::BillFrom

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: AmendmentStart

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendment_start: nil, timestamp: nil, type: nil) ⇒ BillFrom

Returns a new instance of BillFrom.



2697
2698
2699
2700
2701
# File 'lib/stripe/resources/subscription_schedule.rb', line 2697

def initialize(amendment_start: nil, timestamp: nil, type: nil)
  @amendment_start = amendment_start
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#amendment_startObject

Start the prebilled period when a specified amendment begins.



2691
2692
2693
# File 'lib/stripe/resources/subscription_schedule.rb', line 2691

def amendment_start
  @amendment_start
end

#timestampObject

Start the prebilled period at a precise integer timestamp, starting from the Unix epoch.



2693
2694
2695
# File 'lib/stripe/resources/subscription_schedule.rb', line 2693

def timestamp
  @timestamp
end

#typeObject

Select one of several ways to pass the ‘bill_from` value.



2695
2696
2697
# File 'lib/stripe/resources/subscription_schedule.rb', line 2695

def type
  @type
end