Class: Stripe::SubscriptionSchedule::AmendParams::Prebilling::BillUntil

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: AmendmentEnd, Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ BillUntil

Returns a new instance of BillUntil.



2734
2735
2736
2737
2738
2739
# File 'lib/stripe/resources/subscription_schedule.rb', line 2734

def initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil)
  @amendment_end = amendment_end
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#amendment_endObject

End the prebilled period when a specified amendment ends.



2726
2727
2728
# File 'lib/stripe/resources/subscription_schedule.rb', line 2726

def amendment_end
  @amendment_end
end

#durationObject

Time span for prebilling, starting from ‘bill_from`.



2728
2729
2730
# File 'lib/stripe/resources/subscription_schedule.rb', line 2728

def duration
  @duration
end

#timestampObject

End the prebilled period at a precise integer timestamp, starting from the Unix epoch.



2730
2731
2732
# File 'lib/stripe/resources/subscription_schedule.rb', line 2730

def timestamp
  @timestamp
end

#typeObject

Select one of several ways to pass the ‘bill_until` value.



2732
2733
2734
# File 'lib/stripe/resources/subscription_schedule.rb', line 2732

def type
  @type
end