Class: Stripe::SubscriptionSchedule::AmendParams::Prebilling::BillUntil::Duration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(interval: nil, interval_count: nil) ⇒ Duration

Returns a new instance of Duration.



2421
2422
2423
2424
# File 'lib/stripe/resources/subscription_schedule.rb', line 2421

def initialize(interval: nil, interval_count: nil)
  @interval = interval
  @interval_count = interval_count
end

Instance Attribute Details

#intervalObject

Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.



2417
2418
2419
# File 'lib/stripe/resources/subscription_schedule.rb', line 2417

def interval
  @interval
end

#interval_countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



2419
2420
2421
# File 'lib/stripe/resources/subscription_schedule.rb', line 2419

def interval_count
  @interval_count
end