Class: Stripe::SubscriptionSchedule::AmendParams::ScheduleSettings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::AmendParams::ScheduleSettings
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Instance Attribute Summary collapse
-
#end_behavior ⇒ Object
Behavior of the subscription schedule and underlying subscription when it ends.
Instance Method Summary collapse
-
#initialize(end_behavior: nil) ⇒ ScheduleSettings
constructor
A new instance of ScheduleSettings.
Methods inherited from RequestParams
Constructor Details
#initialize(end_behavior: nil) ⇒ ScheduleSettings
Returns a new instance of ScheduleSettings.
2463 2464 2465 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2463 def initialize(end_behavior: nil) @end_behavior = end_behavior end |
Instance Attribute Details
#end_behavior ⇒ Object
Behavior of the subscription schedule and underlying subscription when it ends.
2461 2462 2463 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2461 def end_behavior @end_behavior end |