Class: Stripe::SubscriptionSchedule::BillingSchedule::AppliesTo

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Class Method Summary collapse

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#priceObject (readonly)

The billing schedule will apply to the subscription item with the given price ID.



667
668
669
# File 'lib/stripe/resources/subscription_schedule.rb', line 667

def price
  @price
end

#typeObject (readonly)

Controls which subscription items the billing schedule applies to.



669
670
671
# File 'lib/stripe/resources/subscription_schedule.rb', line 669

def type
  @type
end

Class Method Details

.field_remappingsObject



675
676
677
# File 'lib/stripe/resources/subscription_schedule.rb', line 675

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



671
672
673
# File 'lib/stripe/resources/subscription_schedule.rb', line 671

def self.inner_class_types
  @inner_class_types = {}
end