Class: Stripe::SubscriptionSchedule::BillingSchedule::BillUntil

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: Duration

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Class Method Summary collapse

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#computed_timestampObject (readonly)

The timestamp the billing schedule will apply until.



96
97
98
# File 'lib/stripe/resources/subscription_schedule.rb', line 96

def computed_timestamp
  @computed_timestamp
end

#durationObject (readonly)

Specifies the billing period.



98
99
100
# File 'lib/stripe/resources/subscription_schedule.rb', line 98

def duration
  @duration
end

#timestampObject (readonly)

If specified, the billing schedule will apply until the specified timestamp.



100
101
102
# File 'lib/stripe/resources/subscription_schedule.rb', line 100

def timestamp
  @timestamp
end

#typeObject (readonly)

Describes how the billing schedule will determine the end date. Either ‘duration` or `timestamp`.



102
103
104
# File 'lib/stripe/resources/subscription_schedule.rb', line 102

def type
  @type
end

Class Method Details

.field_remappingsObject



108
109
110
# File 'lib/stripe/resources/subscription_schedule.rb', line 108

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



104
105
106
# File 'lib/stripe/resources/subscription_schedule.rb', line 104

def self.inner_class_types
  @inner_class_types = { duration: Duration }
end