Class: Stripe::SubscriptionSchedule::CancelParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, invoice_now: nil, prorate: nil) ⇒ CancelParams

Returns a new instance of CancelParams.



2801
2802
2803
2804
2805
# File 'lib/stripe/resources/subscription_schedule.rb', line 2801

def initialize(expand: nil, invoice_now: nil, prorate: nil)
  @expand = expand
  @invoice_now = invoice_now
  @prorate = prorate
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



2795
2796
2797
# File 'lib/stripe/resources/subscription_schedule.rb', line 2795

def expand
  @expand
end

#invoice_nowObject

If the subscription schedule is ‘active`, indicates if a final invoice will be generated that contains any un-invoiced metered usage and new/pending proration invoice items. Defaults to `true`.



2797
2798
2799
# File 'lib/stripe/resources/subscription_schedule.rb', line 2797

def invoice_now
  @invoice_now
end

#prorateObject

If the subscription schedule is ‘active`, indicates if the cancellation should be prorated. Defaults to `true`.



2799
2800
2801
# File 'lib/stripe/resources/subscription_schedule.rb', line 2799

def prorate
  @prorate
end