Class: Stripe::SubscriptionSchedule::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: BillingMode, DefaultSettings, Phase, Prebilling

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_behavior: nil, billing_mode: nil, customer: nil, customer_account: nil, default_settings: nil, end_behavior: nil, expand: nil, from_subscription: nil, metadata: nil, phases: nil, prebilling: nil, start_date: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



1179
1180
1181
1182
1183
1184
1185
1186
1187
1188
1189
1190
1191
1192
1193
1194
1195
1196
1197
1198
1199
1200
1201
1202
1203
1204
1205
# File 'lib/stripe/resources/subscription_schedule.rb', line 1179

def initialize(
  billing_behavior: nil,
  billing_mode: nil,
  customer: nil,
  customer_account: nil,
  default_settings: nil,
  end_behavior: nil,
  expand: nil,
  from_subscription: nil,
  metadata: nil,
  phases: nil,
  prebilling: nil,
  start_date: nil
)
  @billing_behavior = billing_behavior
  @billing_mode = billing_mode
  @customer = customer
  @customer_account = 
  @default_settings = default_settings
  @end_behavior = end_behavior
  @expand = expand
  @from_subscription = from_subscription
  @metadata = 
  @phases = phases
  @prebilling = prebilling
  @start_date = start_date
end

Instance Attribute Details

#billing_behaviorObject

Configures when the subscription schedule generates prorations for phase transitions. Possible values are ‘prorate_on_next_phase` or `prorate_up_front` with the default being `prorate_on_next_phase`. `prorate_on_next_phase` will apply phase changes and generate prorations at transition time. `prorate_up_front` will bill for all phases within the current billing cycle up front.



1155
1156
1157
# File 'lib/stripe/resources/subscription_schedule.rb', line 1155

def billing_behavior
  @billing_behavior
end

#billing_modeObject

Controls how prorations and invoices for subscriptions are calculated and orchestrated.



1157
1158
1159
# File 'lib/stripe/resources/subscription_schedule.rb', line 1157

def billing_mode
  @billing_mode
end

#customerObject

The identifier of the customer to create the subscription schedule for.



1159
1160
1161
# File 'lib/stripe/resources/subscription_schedule.rb', line 1159

def customer
  @customer
end

#customer_accountObject

The identifier of the account to create the subscription schedule for.



1161
1162
1163
# File 'lib/stripe/resources/subscription_schedule.rb', line 1161

def 
  @customer_account
end

#default_settingsObject

Object representing the subscription schedule’s default settings.



1163
1164
1165
# File 'lib/stripe/resources/subscription_schedule.rb', line 1163

def default_settings
  @default_settings
end

#end_behaviorObject

Behavior of the subscription schedule and underlying subscription when it ends. Possible values are ‘release` or `cancel` with the default being `release`. `release` will end the subscription schedule and keep the underlying subscription running. `cancel` will end the subscription schedule and cancel the underlying subscription.



1165
1166
1167
# File 'lib/stripe/resources/subscription_schedule.rb', line 1165

def end_behavior
  @end_behavior
end

#expandObject

Specifies which fields in the response should be expanded.



1167
1168
1169
# File 'lib/stripe/resources/subscription_schedule.rb', line 1167

def expand
  @expand
end

#from_subscriptionObject

Migrate an existing subscription to be managed by a subscription schedule. If this parameter is set, a subscription schedule will be created using the subscription’s item(s), set to auto-renew using the subscription’s interval. When using this parameter, other parameters (such as phase values) cannot be set. To create a subscription schedule with other modifications, we recommend making two separate API calls.



1169
1170
1171
# File 'lib/stripe/resources/subscription_schedule.rb', line 1169

def from_subscription
  @from_subscription
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1171
1172
1173
# File 'lib/stripe/resources/subscription_schedule.rb', line 1171

def 
  @metadata
end

#phasesObject

List representing phases of the subscription schedule. Each phase can be customized to have different durations, plans, and coupons. If there are multiple phases, the ‘end_date` of one phase will always equal the `start_date` of the next phase.



1173
1174
1175
# File 'lib/stripe/resources/subscription_schedule.rb', line 1173

def phases
  @phases
end

#prebillingObject

If specified, the invoicing for the given billing cycle iterations will be processed now.



1175
1176
1177
# File 'lib/stripe/resources/subscription_schedule.rb', line 1175

def prebilling
  @prebilling
end

#start_dateObject

When the subscription schedule starts. We recommend using ‘now` so that it starts the subscription immediately. You can also use a Unix timestamp to backdate the subscription so that it starts on a past date, or set a future date for the subscription to start on.



1177
1178
1179
# File 'lib/stripe/resources/subscription_schedule.rb', line 1177

def start_date
  @start_date
end