Class: Stripe::SubscriptionSchedule::CreateParams::Phase::AddInvoiceItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: Discount, Period, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discounts: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ AddInvoiceItem

Returns a new instance of AddInvoiceItem.



717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
# File 'lib/stripe/resources/subscription_schedule.rb', line 717

def initialize(
  discounts: nil,
  metadata: nil,
  period: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @discounts = discounts
  @metadata = 
  @period = period
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#discountsObject

The coupons to redeem into discounts for the item.



703
704
705
# File 'lib/stripe/resources/subscription_schedule.rb', line 703

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



705
706
707
# File 'lib/stripe/resources/subscription_schedule.rb', line 705

def 
  @metadata
end

#periodObject

The period associated with this invoice item. Defaults to the period of the underlying subscription that surrounds the start of the phase.



707
708
709
# File 'lib/stripe/resources/subscription_schedule.rb', line 707

def period
  @period
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required.



709
710
711
# File 'lib/stripe/resources/subscription_schedule.rb', line 709

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.



711
712
713
# File 'lib/stripe/resources/subscription_schedule.rb', line 711

def price_data
  @price_data
end

#quantityObject

Quantity for this item. Defaults to 1.



713
714
715
# File 'lib/stripe/resources/subscription_schedule.rb', line 713

def quantity
  @quantity
end

#tax_ratesObject

The tax rates which apply to the item. When set, the ‘default_tax_rates` do not apply to this item.



715
716
717
# File 'lib/stripe/resources/subscription_schedule.rb', line 715

def tax_rates
  @tax_rates
end