Class: Stripe::SubscriptionSchedule::CreateParams::Phase::AddInvoiceItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



932
933
934
935
936
937
# File 'lib/stripe/resources/subscription_schedule.rb', line 932

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



924
925
926
# File 'lib/stripe/resources/subscription_schedule.rb', line 924

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



926
927
928
# File 'lib/stripe/resources/subscription_schedule.rb', line 926

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



928
929
930
# File 'lib/stripe/resources/subscription_schedule.rb', line 928

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



930
931
932
# File 'lib/stripe/resources/subscription_schedule.rb', line 930

def promotion_code
  @promotion_code
end