Class: Stripe::SubscriptionSchedule::CreateParams::Phase::AddInvoiceItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



618
619
620
621
622
# File 'lib/stripe/resources/subscription_schedule.rb', line 618

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



612
613
614
# File 'lib/stripe/resources/subscription_schedule.rb', line 612

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



614
615
616
# File 'lib/stripe/resources/subscription_schedule.rb', line 614

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



616
617
618
# File 'lib/stripe/resources/subscription_schedule.rb', line 616

def type
  @type
end