Class: Stripe::SubscriptionSchedule::CreateParams::Phase::AddInvoiceItem::Period::End

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(timestamp: nil, type: nil) ⇒ End

Returns a new instance of End.



947
948
949
950
# File 'lib/stripe/resources/subscription_schedule.rb', line 947

def initialize(timestamp: nil, type: nil)
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#timestampObject

A precise Unix timestamp for the end of the invoice item period. Must be greater than or equal to ‘period.start`.



943
944
945
# File 'lib/stripe/resources/subscription_schedule.rb', line 943

def timestamp
  @timestamp
end

#typeObject

Select how to calculate the end of the invoice item period.



945
946
947
# File 'lib/stripe/resources/subscription_schedule.rb', line 945

def type
  @type
end