Class: Stripe::SubscriptionSchedule::CreateParams::Phase::AddInvoiceItem::Period::Start

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(timestamp: nil, type: nil) ⇒ Start

Returns a new instance of Start.



959
960
961
962
# File 'lib/stripe/resources/subscription_schedule.rb', line 959

def initialize(timestamp: nil, type: nil)
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#timestampObject

A precise Unix timestamp for the start of the invoice item period. Must be less than or equal to ‘period.end`.



955
956
957
# File 'lib/stripe/resources/subscription_schedule.rb', line 955

def timestamp
  @timestamp
end

#typeObject

Select how to calculate the start of the invoice item period.



957
958
959
# File 'lib/stripe/resources/subscription_schedule.rb', line 957

def type
  @type
end