Class: Stripe::SubscriptionSchedule::CreateParams::Phase::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



806
807
808
809
810
811
# File 'lib/stripe/resources/subscription_schedule.rb', line 806

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



798
799
800
# File 'lib/stripe/resources/subscription_schedule.rb', line 798

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



800
801
802
# File 'lib/stripe/resources/subscription_schedule.rb', line 800

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



802
803
804
# File 'lib/stripe/resources/subscription_schedule.rb', line 802

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



804
805
806
# File 'lib/stripe/resources/subscription_schedule.rb', line 804

def promotion_code
  @promotion_code
end