Class: Stripe::SubscriptionSchedule::CreateParams::Phase::Item::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



897
898
899
900
901
902
# File 'lib/stripe/resources/subscription_schedule.rb', line 897

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



889
890
891
# File 'lib/stripe/resources/subscription_schedule.rb', line 889

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



891
892
893
# File 'lib/stripe/resources/subscription_schedule.rb', line 891

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



893
894
895
# File 'lib/stripe/resources/subscription_schedule.rb', line 893

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



895
896
897
# File 'lib/stripe/resources/subscription_schedule.rb', line 895

def promotion_code
  @promotion_code
end