Class: Stripe::SubscriptionSchedule::CreateParams::Phase::Item::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::CreateParams::Phase::Item::Discount::DiscountEnd
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
809 810 811 812 813 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 809 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
803 804 805 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 803 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
805 806 807 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 805 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
807 808 809 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 807 def type @type end |