Class: Stripe::SubscriptionSchedule::CreateParams::Phase::Item::PriceData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: Recurring

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(currency: nil, product: nil, recurring: nil, tax_behavior: nil, unit_amount: nil, unit_amount_decimal: nil) ⇒ PriceData

Returns a new instance of PriceData.



980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
# File 'lib/stripe/resources/subscription_schedule.rb', line 980

def initialize(
  currency: nil,
  product: nil,
  recurring: nil,
  tax_behavior: nil,
  unit_amount: nil,
  unit_amount_decimal: nil
)
  @currency = currency
  @product = product
  @recurring = recurring
  @tax_behavior = tax_behavior
  @unit_amount = unit_amount
  @unit_amount_decimal = unit_amount_decimal
end

Instance Attribute Details

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



963
964
965
# File 'lib/stripe/resources/subscription_schedule.rb', line 963

def currency
  @currency
end

#productObject

The ID of the product that this price will belong to.



966
967
968
# File 'lib/stripe/resources/subscription_schedule.rb', line 966

def product
  @product
end

#recurringObject

The recurring components of a price such as ‘interval` and `interval_count`.



969
970
971
# File 'lib/stripe/resources/subscription_schedule.rb', line 969

def recurring
  @recurring
end

#tax_behaviorObject

Only required if a [default tax behavior](stripe.com/docs/tax/products-prices-tax-categories-tax-behavior#setting-a-default-tax-behavior-(recommended)) was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`. Once specified as either `inclusive` or `exclusive`, it cannot be changed.



972
973
974
# File 'lib/stripe/resources/subscription_schedule.rb', line 972

def tax_behavior
  @tax_behavior
end

#unit_amountObject

A positive integer in cents (or local equivalent) (or 0 for a free price) representing how much to charge.



975
976
977
# File 'lib/stripe/resources/subscription_schedule.rb', line 975

def unit_amount
  @unit_amount
end

#unit_amount_decimalObject

Same as ‘unit_amount`, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places. Only one of `unit_amount` and `unit_amount_decimal` can be set.



978
979
980
# File 'lib/stripe/resources/subscription_schedule.rb', line 978

def unit_amount_decimal
  @unit_amount_decimal
end