Class: Stripe::SubscriptionSchedule::CreateParams::Phase::TransferData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::CreateParams::Phase::TransferData
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Instance Attribute Summary collapse
-
#amount_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places.
-
#destination ⇒ Object
ID of an existing, connected Stripe account.
Instance Method Summary collapse
-
#initialize(amount_percent: nil, destination: nil) ⇒ TransferData
constructor
A new instance of TransferData.
Methods inherited from RequestParams
Constructor Details
#initialize(amount_percent: nil, destination: nil) ⇒ TransferData
Returns a new instance of TransferData.
1314 1315 1316 1317 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1314 def initialize(amount_percent: nil, destination: nil) @amount_percent = amount_percent @destination = destination end |
Instance Attribute Details
#amount_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination.
1310 1311 1312 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1310 def amount_percent @amount_percent end |
#destination ⇒ Object
ID of an existing, connected Stripe account.
1312 1313 1314 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1312 def destination @destination end |