Class: Stripe::SubscriptionSchedule::CreateParams::Prebilling
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::CreateParams::Prebilling
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Instance Attribute Summary collapse
-
#iterations ⇒ Object
This is used to determine the number of billing cycles to prebill.
-
#update_behavior ⇒ Object
Whether to cancel or preserve ‘prebilling` if the subscription is updated during the prebilled period.
Instance Method Summary collapse
-
#initialize(iterations: nil, update_behavior: nil) ⇒ Prebilling
constructor
A new instance of Prebilling.
Methods inherited from RequestParams
Constructor Details
#initialize(iterations: nil, update_behavior: nil) ⇒ Prebilling
Returns a new instance of Prebilling.
1060 1061 1062 1063 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1060 def initialize(iterations: nil, update_behavior: nil) @iterations = iterations @update_behavior = update_behavior end |
Instance Attribute Details
#iterations ⇒ Object
This is used to determine the number of billing cycles to prebill.
1056 1057 1058 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1056 def iterations @iterations end |
#update_behavior ⇒ Object
Whether to cancel or preserve ‘prebilling` if the subscription is updated during the prebilled period. The default value is `reset`.
1058 1059 1060 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1058 def update_behavior @update_behavior end |