Class: Stripe::SubscriptionSchedule::CurrentPhase
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::SubscriptionSchedule::CurrentPhase
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#end_date ⇒ Object
readonly
The end of this phase of the subscription schedule.
-
#start_date ⇒ Object
readonly
The start of this phase of the subscription schedule.
Attributes inherited from Stripe::StripeObject
Class Method Summary collapse
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#end_date ⇒ Object (readonly)
The end of this phase of the subscription schedule.
113 114 115 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 113 def end_date @end_date end |
#start_date ⇒ Object (readonly)
The start of this phase of the subscription schedule.
115 116 117 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 115 def start_date @start_date end |
Class Method Details
.field_remappings ⇒ Object
121 122 123 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 121 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
117 118 119 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 117 def self.inner_class_types @inner_class_types = {} end |