Class: Stripe::SubscriptionSchedule::DefaultSettings::InvoiceSettings

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: CustomField, Issuer

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Class Method Summary collapse

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_tax_idsObject (readonly)

The account tax IDs associated with the subscription schedule. Will be set on invoices generated by the subscription schedule.



140
141
142
# File 'lib/stripe/resources/subscription_schedule.rb', line 140

def 
  @account_tax_ids
end

#custom_fieldsObject (readonly)

A list of up to 4 custom fields to be displayed on the invoice.



142
143
144
# File 'lib/stripe/resources/subscription_schedule.rb', line 142

def custom_fields
  @custom_fields
end

#days_until_dueObject (readonly)

Number of days within which a customer must pay invoices generated by this subscription schedule. This value will be null for subscription schedules where billing=charge_automatically.



144
145
146
# File 'lib/stripe/resources/subscription_schedule.rb', line 144

def days_until_due
  @days_until_due
end

#descriptionObject (readonly)

An arbitrary string attached to the object. Often useful for displaying to users.



146
147
148
# File 'lib/stripe/resources/subscription_schedule.rb', line 146

def description
  @description
end

Footer to be displayed on the invoice.



148
149
150
# File 'lib/stripe/resources/subscription_schedule.rb', line 148

def footer
  @footer
end

#issuerObject (readonly)

Attribute for field issuer



150
151
152
# File 'lib/stripe/resources/subscription_schedule.rb', line 150

def issuer
  @issuer
end

Class Method Details

.field_remappingsObject



156
157
158
# File 'lib/stripe/resources/subscription_schedule.rb', line 156

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



152
153
154
# File 'lib/stripe/resources/subscription_schedule.rb', line 152

def self.inner_class_types
  @inner_class_types = { custom_fields: CustomField, issuer: Issuer }
end