Class: Stripe::SubscriptionSchedule::LastPriceMigrationError
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::SubscriptionSchedule::LastPriceMigrationError
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Defined Under Namespace
Classes: FailedTransition
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#errored_at ⇒ Object
readonly
The time at which the price migration encountered an error.
-
#failed_transitions ⇒ Object
readonly
The involved price pairs in each failed transition.
-
#type ⇒ Object
readonly
The type of error encountered by the price migration.
Attributes inherited from Stripe::StripeObject
Class Method Summary collapse
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#errored_at ⇒ Object (readonly)
The time at which the price migration encountered an error.
191 192 193 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 191 def errored_at @errored_at end |
#failed_transitions ⇒ Object (readonly)
The involved price pairs in each failed transition.
193 194 195 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 193 def failed_transitions @failed_transitions end |
#type ⇒ Object (readonly)
The type of error encountered by the price migration.
195 196 197 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 195 def type @type end |
Class Method Details
.field_remappings ⇒ Object
201 202 203 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 201 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
197 198 199 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 197 def self.inner_class_types @inner_class_types = { failed_transitions: FailedTransition } end |