Class: Stripe::SubscriptionSchedule::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::ListParams
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Defined Under Namespace
Classes: CanceledAt, CompletedAt, Created, ReleasedAt
Instance Attribute Summary collapse
-
#canceled_at ⇒ Object
Only return subscription schedules that were created canceled the given date interval.
-
#completed_at ⇒ Object
Only return subscription schedules that completed during the given date interval.
-
#created ⇒ Object
Only return subscription schedules that were created during the given date interval.
-
#customer ⇒ Object
Only return subscription schedules for the given customer.
-
#customer_account ⇒ Object
Only return subscription schedules for the given account.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#released_at ⇒ Object
Only return subscription schedules that were released during the given date interval.
-
#scheduled ⇒ Object
Only return subscription schedules that have not started yet.
-
#starting_after ⇒ Object
A cursor for use in pagination.
Instance Method Summary collapse
-
#initialize(canceled_at: nil, completed_at: nil, created: nil, customer: nil, customer_account: nil, ending_before: nil, expand: nil, limit: nil, released_at: nil, scheduled: nil, starting_after: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(canceled_at: nil, completed_at: nil, created: nil, customer: nil, customer_account: nil, ending_before: nil, expand: nil, limit: nil, released_at: nil, scheduled: nil, starting_after: nil) ⇒ ListParams
Returns a new instance of ListParams.
739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 739 def initialize( canceled_at: nil, completed_at: nil, created: nil, customer: nil, customer_account: nil, ending_before: nil, expand: nil, limit: nil, released_at: nil, scheduled: nil, starting_after: nil ) @canceled_at = canceled_at @completed_at = completed_at @created = created @customer = customer @customer_account = customer_account @ending_before = ending_before @expand = @limit = limit @released_at = released_at @scheduled = scheduled @starting_after = starting_after end |
Instance Attribute Details
#canceled_at ⇒ Object
Only return subscription schedules that were created canceled the given date interval.
717 718 719 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 717 def canceled_at @canceled_at end |
#completed_at ⇒ Object
Only return subscription schedules that completed during the given date interval.
719 720 721 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 719 def completed_at @completed_at end |
#created ⇒ Object
Only return subscription schedules that were created during the given date interval.
721 722 723 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 721 def created @created end |
#customer ⇒ Object
Only return subscription schedules for the given customer.
723 724 725 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 723 def customer @customer end |
#customer_account ⇒ Object
Only return subscription schedules for the given account.
725 726 727 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 725 def customer_account @customer_account end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
727 728 729 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 727 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
729 730 731 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 729 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
731 732 733 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 731 def limit @limit end |
#released_at ⇒ Object
Only return subscription schedules that were released during the given date interval.
733 734 735 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 733 def released_at @released_at end |
#scheduled ⇒ Object
Only return subscription schedules that have not started yet.
735 736 737 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 735 def scheduled @scheduled end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
737 738 739 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 737 def starting_after @starting_after end |