Class: Stripe::SubscriptionSchedule::PauseSchedule::Pause::Settings
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::SubscriptionSchedule::PauseSchedule::Pause::Settings
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Defined Under Namespace
Classes: BillFor
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bill_for ⇒ Object
readonly
Attribute for field bill_for.
-
#invoicing_behavior ⇒ Object
readonly
Determines how to handle debits and credits when pausing.
-
#type ⇒ Object
readonly
The type of pause settings.
Attributes inherited from Stripe::StripeObject
Class Method Summary collapse
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bill_for ⇒ Object (readonly)
Attribute for field bill_for
256 257 258 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 256 def bill_for @bill_for end |
#invoicing_behavior ⇒ Object (readonly)
Determines how to handle debits and credits when pausing.
258 259 260 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 258 def invoicing_behavior @invoicing_behavior end |
#type ⇒ Object (readonly)
The type of pause settings.
260 261 262 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 260 def type @type end |
Class Method Details
.field_remappings ⇒ Object
266 267 268 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 266 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
262 263 264 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 262 def self.inner_class_types @inner_class_types = { bill_for: BillFor } end |