Class: Stripe::SubscriptionSchedule::PauseSchedule::Resume::Settings

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Class Method Summary collapse

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#billing_cycle_anchorObject (readonly)

The billing cycle anchor that applies when the subscription is resumed.



415
416
417
# File 'lib/stripe/resources/subscription_schedule.rb', line 415

def billing_cycle_anchor
  @billing_cycle_anchor
end

#payment_behaviorObject (readonly)

Controls whether Stripe attempts payment on the resumption invoice and how that affects the subscription's status.



417
418
419
# File 'lib/stripe/resources/subscription_schedule.rb', line 417

def payment_behavior
  @payment_behavior
end

#proration_behaviorObject (readonly)

Determines how to handle prorations resulting from the billing_cycle_anchor change on resume.



419
420
421
# File 'lib/stripe/resources/subscription_schedule.rb', line 419

def proration_behavior
  @proration_behavior
end

Class Method Details

.field_remappingsObject



425
426
427
# File 'lib/stripe/resources/subscription_schedule.rb', line 425

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



421
422
423
# File 'lib/stripe/resources/subscription_schedule.rb', line 421

def self.inner_class_types
  @inner_class_types = {}
end