Class: Stripe::SubscriptionSchedule::Phase::AddInvoiceItem

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: Discount, Period

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Class Method Summary collapse

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#discountableObject (readonly)

Controls whether discounts apply to this invoice item. Defaults to true if no value is provided.



365
366
367
# File 'lib/stripe/resources/subscription_schedule.rb', line 365

def discountable
  @discountable
end

#discountsObject (readonly)

The stackable discounts that will be applied to the item.



367
368
369
# File 'lib/stripe/resources/subscription_schedule.rb', line 367

def discounts
  @discounts
end

#metadataObject (readonly)

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



369
370
371
# File 'lib/stripe/resources/subscription_schedule.rb', line 369

def 
  @metadata
end

#periodObject (readonly)

Attribute for field period



371
372
373
# File 'lib/stripe/resources/subscription_schedule.rb', line 371

def period
  @period
end

#priceObject (readonly)

ID of the price used to generate the invoice item.



373
374
375
# File 'lib/stripe/resources/subscription_schedule.rb', line 373

def price
  @price
end

#quantityObject (readonly)

The quantity of the invoice item.



375
376
377
# File 'lib/stripe/resources/subscription_schedule.rb', line 375

def quantity
  @quantity
end

#tax_ratesObject (readonly)

The tax rates which apply to the item. When set, the ‘default_tax_rates` do not apply to this item.



377
378
379
# File 'lib/stripe/resources/subscription_schedule.rb', line 377

def tax_rates
  @tax_rates
end

Class Method Details

.field_remappingsObject



383
384
385
# File 'lib/stripe/resources/subscription_schedule.rb', line 383

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



379
380
381
# File 'lib/stripe/resources/subscription_schedule.rb', line 379

def self.inner_class_types
  @inner_class_types = { discounts: Discount, period: Period }
end