Class: Stripe::SubscriptionSchedule::Phase::AutomaticTax
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::SubscriptionSchedule::Phase::AutomaticTax
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Defined Under Namespace
Classes: Liability
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#disabled_reason ⇒ Object
readonly
If Stripe disabled automatic tax, this enum describes why.
-
#enabled ⇒ Object
readonly
Whether Stripe automatically computes tax on invoices created during this phase.
-
#liability ⇒ Object
readonly
The account that's liable for tax.
Attributes inherited from Stripe::StripeObject
Class Method Summary collapse
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#disabled_reason ⇒ Object (readonly)
If Stripe disabled automatic tax, this enum describes why.
607 608 609 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 607 def disabled_reason @disabled_reason end |
#enabled ⇒ Object (readonly)
Whether Stripe automatically computes tax on invoices created during this phase.
609 610 611 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 609 def enabled @enabled end |
#liability ⇒ Object (readonly)
The account that's liable for tax. If set, the business address and tax registrations required to perform the tax calculation are loaded from this account. The tax transaction is returned in the report of the connected account.
611 612 613 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 611 def liability @liability end |
Class Method Details
.field_remappings ⇒ Object
617 618 619 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 617 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
613 614 615 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 613 def self.inner_class_types @inner_class_types = { liability: Liability } end |