Class: Stripe::SubscriptionSchedule::Phase::BillingThresholds
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::SubscriptionSchedule::Phase::BillingThresholds
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount_gte ⇒ Object
readonly
Monetary threshold that triggers the subscription to create an invoice.
-
#reset_billing_cycle_anchor ⇒ Object
readonly
Indicates if the ‘billing_cycle_anchor` should be reset when a threshold is reached.
Attributes inherited from Stripe::StripeObject
Class Method Summary collapse
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount_gte ⇒ Object (readonly)
Monetary threshold that triggers the subscription to create an invoice
353 354 355 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 353 def amount_gte @amount_gte end |
#reset_billing_cycle_anchor ⇒ Object (readonly)
Indicates if the ‘billing_cycle_anchor` should be reset when a threshold is reached. If true, `billing_cycle_anchor` will be updated to the date/time the threshold was last reached; otherwise, the value will remain unchanged. This value may not be `true` if the subscription contains items with plans that have `aggregate_usage=last_ever`.
355 356 357 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 355 def reset_billing_cycle_anchor @reset_billing_cycle_anchor end |
Class Method Details
.field_remappings ⇒ Object
361 362 363 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 361 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
357 358 359 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 357 def self.inner_class_types @inner_class_types = {} end |