Class: Stripe::SubscriptionSchedule::Phase::Discount

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: DiscountEnd, Settings

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Class Method Summary collapse

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#couponObject (readonly)

ID of the coupon to create a new discount for.



499
500
501
# File 'lib/stripe/resources/subscription_schedule.rb', line 499

def coupon
  @coupon
end

#discountObject (readonly)

ID of an existing discount on the object (or one of its ancestors) to reuse.



501
502
503
# File 'lib/stripe/resources/subscription_schedule.rb', line 501

def discount
  @discount
end

#discount_endObject (readonly)

Details to determine how long the discount should be applied for.



503
504
505
# File 'lib/stripe/resources/subscription_schedule.rb', line 503

def discount_end
  @discount_end
end

#promotion_codeObject (readonly)

ID of the promotion code to create a new discount for.



505
506
507
# File 'lib/stripe/resources/subscription_schedule.rb', line 505

def promotion_code
  @promotion_code
end

#settingsObject (readonly)

Attribute for field settings



507
508
509
# File 'lib/stripe/resources/subscription_schedule.rb', line 507

def settings
  @settings
end

Class Method Details

.field_remappingsObject



513
514
515
# File 'lib/stripe/resources/subscription_schedule.rb', line 513

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



509
510
511
# File 'lib/stripe/resources/subscription_schedule.rb', line 509

def self.inner_class_types
  @inner_class_types = { discount_end: DiscountEnd, settings: Settings }
end