Class: Stripe::SubscriptionSchedule::Phase::Item

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: BillingThresholds, Discount

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Class Method Summary collapse

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#billing_thresholds ⇒ Object (readonly)

Define thresholds at which an invoice will be sent, and the related subscription advanced to a new billing period



624
625
626
# File 'lib/stripe/resources/subscription_schedule.rb', line 624

def billing_thresholds
  @billing_thresholds
end

#discounts ⇒ Object (readonly)

The discounts applied to the subscription item. Subscription item discounts are applied before subscription discounts. Use expand[]=discounts to expand each discount.



626
627
628
# File 'lib/stripe/resources/subscription_schedule.rb', line 626

def discounts
  @discounts
end

#metadata ⇒ Object (readonly)

Set of key-value pairs that you can attach to an item. Metadata on this item will update the underlying subscription item's metadata when the phase is entered.



628
629
630
# File 'lib/stripe/resources/subscription_schedule.rb', line 628

def 
  @metadata
end

#plan ⇒ Object (readonly)

ID of the plan to which the customer should be subscribed.



630
631
632
# File 'lib/stripe/resources/subscription_schedule.rb', line 630

def plan
  @plan
end

#price ⇒ Object (readonly)

ID of the price to which the customer should be subscribed.



632
633
634
# File 'lib/stripe/resources/subscription_schedule.rb', line 632

def price
  @price
end

#quantity ⇒ Object (readonly)

Quantity of the plan to which the customer should be subscribed.



634
635
636
# File 'lib/stripe/resources/subscription_schedule.rb', line 634

def quantity
  @quantity
end

#tax_rates ⇒ Object (readonly)

The tax rates which apply to this phase_item. When set, the default_tax_rates on the phase do not apply to this phase_item.



636
637
638
# File 'lib/stripe/resources/subscription_schedule.rb', line 636

def tax_rates
  @tax_rates
end

Class Method Details

.field_remappings ⇒ Object



642
643
644
# File 'lib/stripe/resources/subscription_schedule.rb', line 642

def self.field_remappings
  @field_remappings = {}
end

.inner_class_types ⇒ Object



638
639
640
# File 'lib/stripe/resources/subscription_schedule.rb', line 638

def self.inner_class_types
  @inner_class_types = { billing_thresholds: BillingThresholds, discounts: Discount }
end