Class: Stripe::SubscriptionSchedule::Phase::Item::Discount
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::SubscriptionSchedule::Phase::Item::Discount
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Defined Under Namespace
Classes: DiscountEnd, Settings
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#coupon ⇒ Object
readonly
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
readonly
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
readonly
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
readonly
ID of the promotion code to create a new discount for.
-
#settings ⇒ Object
readonly
Attribute for field settings.
Attributes inherited from Stripe::StripeObject
Class Method Summary collapse
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#coupon ⇒ Object (readonly)
ID of the coupon to create a new discount for.
852 853 854 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 852 def coupon @coupon end |
#discount ⇒ Object (readonly)
ID of an existing discount on the object (or one of its ancestors) to reuse.
854 855 856 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 854 def discount @discount end |
#discount_end ⇒ Object (readonly)
Details to determine how long the discount should be applied for.
856 857 858 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 856 def discount_end @discount_end end |
#promotion_code ⇒ Object (readonly)
ID of the promotion code to create a new discount for.
858 859 860 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 858 def promotion_code @promotion_code end |
#settings ⇒ Object (readonly)
Attribute for field settings
860 861 862 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 860 def settings @settings end |
Class Method Details
.field_remappings ⇒ Object
866 867 868 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 866 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
862 863 864 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 862 def self.inner_class_types @inner_class_types = { discount_end: DiscountEnd, settings: Settings } end |