Class: Stripe::SubscriptionSchedule::Phase::Item::Discount::Settings::ServicePeriodAnchorConfig::Custom
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::SubscriptionSchedule::Phase::Item::Discount::Settings::ServicePeriodAnchorConfig::Custom
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#day_of_month ⇒ Object
readonly
The day of the month the anchor should be.
-
#hour ⇒ Object
readonly
The hour of the day the anchor should be.
-
#minute ⇒ Object
readonly
The minute of the hour the anchor should be.
-
#month ⇒ Object
readonly
The month to start full cycle periods.
-
#second ⇒ Object
readonly
The second of the minute the anchor should be.
Attributes inherited from Stripe::StripeObject
Class Method Summary collapse
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#day_of_month ⇒ Object (readonly)
The day of the month the anchor should be. Ranges from 1 to 31.
600 601 602 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 600 def day_of_month @day_of_month end |
#hour ⇒ Object (readonly)
The hour of the day the anchor should be. Ranges from 0 to 23.
602 603 604 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 602 def hour @hour end |
#minute ⇒ Object (readonly)
The minute of the hour the anchor should be. Ranges from 0 to 59.
604 605 606 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 604 def minute @minute end |
#month ⇒ Object (readonly)
The month to start full cycle periods. Ranges from 1 to 12.
606 607 608 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 606 def month @month end |
#second ⇒ Object (readonly)
The second of the minute the anchor should be. Ranges from 0 to 59.
608 609 610 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 608 def second @second end |
Class Method Details
.field_remappings ⇒ Object
614 615 616 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 614 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
610 611 612 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 610 def self.inner_class_types @inner_class_types = {} end |