Class: Stripe::SubscriptionSchedule::Prebilling

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Class Method Summary collapse

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#invoiceObject (readonly)

ID of the prebilling invoice.



643
644
645
# File 'lib/stripe/resources/subscription_schedule.rb', line 643

def invoice
  @invoice
end

#period_endObject (readonly)

The end of the last period for which the invoice pre-bills.



645
646
647
# File 'lib/stripe/resources/subscription_schedule.rb', line 645

def period_end
  @period_end
end

#period_startObject (readonly)

The start of the first period for which the invoice pre-bills.



647
648
649
# File 'lib/stripe/resources/subscription_schedule.rb', line 647

def period_start
  @period_start
end

#update_behaviorObject (readonly)

Whether to cancel or preserve ‘prebilling` if the subscription is updated during the prebilled period.



649
650
651
# File 'lib/stripe/resources/subscription_schedule.rb', line 649

def update_behavior
  @update_behavior
end

Class Method Details

.field_remappingsObject



655
656
657
# File 'lib/stripe/resources/subscription_schedule.rb', line 655

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



651
652
653
# File 'lib/stripe/resources/subscription_schedule.rb', line 651

def self.inner_class_types
  @inner_class_types = {}
end