Class: Stripe::SubscriptionSchedule::ReleaseParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::ReleaseParams
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#preserve_cancel_date ⇒ Object
Keep any cancellation on the subscription that the schedule has set.
Instance Method Summary collapse
-
#initialize(expand: nil, preserve_cancel_date: nil) ⇒ ReleaseParams
constructor
A new instance of ReleaseParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, preserve_cancel_date: nil) ⇒ ReleaseParams
Returns a new instance of ReleaseParams.
2814 2815 2816 2817 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2814 def initialize(expand: nil, preserve_cancel_date: nil) @expand = @preserve_cancel_date = preserve_cancel_date end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2810 2811 2812 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2810 def @expand end |
#preserve_cancel_date ⇒ Object
Keep any cancellation on the subscription that the schedule has set
2812 2813 2814 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2812 def preserve_cancel_date @preserve_cancel_date end |