Class: Stripe::SubscriptionSchedule::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: DefaultSettings, Phase, Prebilling

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_behavior: nil, default_settings: nil, end_behavior: nil, expand: nil, metadata: nil, phases: nil, prebilling: nil, proration_behavior: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



1907
1908
1909
1910
1911
1912
1913
1914
1915
1916
1917
1918
1919
1920
1921
1922
1923
1924
1925
# File 'lib/stripe/resources/subscription_schedule.rb', line 1907

def initialize(
  billing_behavior: nil,
  default_settings: nil,
  end_behavior: nil,
  expand: nil,
  metadata: nil,
  phases: nil,
  prebilling: nil,
  proration_behavior: nil
)
  @billing_behavior = billing_behavior
  @default_settings = default_settings
  @end_behavior = end_behavior
  @expand = expand
  @metadata = 
  @phases = phases
  @prebilling = prebilling
  @proration_behavior = proration_behavior
end

Instance Attribute Details

#billing_behaviorObject

Configures when the subscription schedule generates prorations for phase transitions. Possible values are ‘prorate_on_next_phase` or `prorate_up_front` with the default being `prorate_on_next_phase`. `prorate_on_next_phase` will apply phase changes and generate prorations at transition time. `prorate_up_front` will bill for all phases within the current billing cycle up front.



1891
1892
1893
# File 'lib/stripe/resources/subscription_schedule.rb', line 1891

def billing_behavior
  @billing_behavior
end

#default_settingsObject

Object representing the subscription schedule’s default settings.



1893
1894
1895
# File 'lib/stripe/resources/subscription_schedule.rb', line 1893

def default_settings
  @default_settings
end

#end_behaviorObject

Behavior of the subscription schedule and underlying subscription when it ends. Possible values are ‘release` or `cancel` with the default being `release`. `release` will end the subscription schedule and keep the underlying subscription running. `cancel` will end the subscription schedule and cancel the underlying subscription.



1895
1896
1897
# File 'lib/stripe/resources/subscription_schedule.rb', line 1895

def end_behavior
  @end_behavior
end

#expandObject

Specifies which fields in the response should be expanded.



1897
1898
1899
# File 'lib/stripe/resources/subscription_schedule.rb', line 1897

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1899
1900
1901
# File 'lib/stripe/resources/subscription_schedule.rb', line 1899

def 
  @metadata
end

#phasesObject

List representing phases of the subscription schedule. Each phase can be customized to have different durations, plans, and coupons. If there are multiple phases, the ‘end_date` of one phase will always equal the `start_date` of the next phase. Note that past phases can be omitted.



1901
1902
1903
# File 'lib/stripe/resources/subscription_schedule.rb', line 1901

def phases
  @phases
end

#prebillingObject

If specified, the invoicing for the given billing cycle iterations will be processed now.



1903
1904
1905
# File 'lib/stripe/resources/subscription_schedule.rb', line 1903

def prebilling
  @prebilling
end

#proration_behaviorObject

If the update changes the billing configuration (item price, quantity, etc.) of the current phase, indicates how prorations from this change should be handled. The default value is ‘create_prorations`.



1905
1906
1907
# File 'lib/stripe/resources/subscription_schedule.rb', line 1905

def proration_behavior
  @proration_behavior
end