Class: Stripe::SubscriptionSchedule::UpdateParams::DefaultSettings::InvoiceSettings

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: Issuer

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_tax_ids: nil, days_until_due: nil, issuer: nil) ⇒ InvoiceSettings

Returns a new instance of InvoiceSettings.



1264
1265
1266
1267
1268
# File 'lib/stripe/resources/subscription_schedule.rb', line 1264

def initialize(account_tax_ids: nil, days_until_due: nil, issuer: nil)
  @account_tax_ids = 
  @days_until_due = days_until_due
  @issuer = issuer
end

Instance Attribute Details

#account_tax_idsObject

The account tax IDs associated with the subscription schedule. Will be set on invoices generated by the subscription schedule.



1258
1259
1260
# File 'lib/stripe/resources/subscription_schedule.rb', line 1258

def 
  @account_tax_ids
end

#days_until_dueObject

Number of days within which a customer must pay invoices generated by this subscription schedule. This value will be ‘null` for subscription schedules where `collection_method=charge_automatically`.



1260
1261
1262
# File 'lib/stripe/resources/subscription_schedule.rb', line 1260

def days_until_due
  @days_until_due
end

#issuerObject

The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.



1262
1263
1264
# File 'lib/stripe/resources/subscription_schedule.rb', line 1262

def issuer
  @issuer
end