Class: Stripe::SubscriptionSchedule::UpdateParams::Phase::AddInvoiceItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: Discount, Period, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discounts: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ AddInvoiceItem

Returns a new instance of AddInvoiceItem.



1449
1450
1451
1452
1453
1454
1455
1456
1457
1458
1459
1460
1461
1462
1463
1464
1465
# File 'lib/stripe/resources/subscription_schedule.rb', line 1449

def initialize(
  discounts: nil,
  metadata: nil,
  period: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @discounts = discounts
  @metadata = 
  @period = period
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#discountsObject

The coupons to redeem into discounts for the item.



1435
1436
1437
# File 'lib/stripe/resources/subscription_schedule.rb', line 1435

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1437
1438
1439
# File 'lib/stripe/resources/subscription_schedule.rb', line 1437

def 
  @metadata
end

#periodObject

The period associated with this invoice item. Defaults to the period of the underlying subscription that surrounds the start of the phase.



1439
1440
1441
# File 'lib/stripe/resources/subscription_schedule.rb', line 1439

def period
  @period
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required.



1441
1442
1443
# File 'lib/stripe/resources/subscription_schedule.rb', line 1441

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.



1443
1444
1445
# File 'lib/stripe/resources/subscription_schedule.rb', line 1443

def price_data
  @price_data
end

#quantityObject

Quantity for this item. Defaults to 1.



1445
1446
1447
# File 'lib/stripe/resources/subscription_schedule.rb', line 1445

def quantity
  @quantity
end

#tax_ratesObject

The tax rates which apply to the item. When set, the ‘default_tax_rates` do not apply to this item.



1447
1448
1449
# File 'lib/stripe/resources/subscription_schedule.rb', line 1447

def tax_rates
  @tax_rates
end