Class: Stripe::SubscriptionSchedule::UpdateParams::Phase::AddInvoiceItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1664
1665
1666
1667
1668
1669
# File 'lib/stripe/resources/subscription_schedule.rb', line 1664

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1656
1657
1658
# File 'lib/stripe/resources/subscription_schedule.rb', line 1656

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1658
1659
1660
# File 'lib/stripe/resources/subscription_schedule.rb', line 1658

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1660
1661
1662
# File 'lib/stripe/resources/subscription_schedule.rb', line 1660

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1662
1663
1664
# File 'lib/stripe/resources/subscription_schedule.rb', line 1662

def promotion_code
  @promotion_code
end