Class: Stripe::SubscriptionSchedule::UpdateParams::Phase::AddInvoiceItem::Period::End

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(timestamp: nil, type: nil) ⇒ End

Returns a new instance of End.



1380
1381
1382
1383
# File 'lib/stripe/resources/subscription_schedule.rb', line 1380

def initialize(timestamp: nil, type: nil)
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#timestampObject

A precise Unix timestamp for the end of the invoice item period. Must be greater than or equal to ‘period.start`.



1376
1377
1378
# File 'lib/stripe/resources/subscription_schedule.rb', line 1376

def timestamp
  @timestamp
end

#typeObject

Select how to calculate the end of the invoice item period.



1378
1379
1380
# File 'lib/stripe/resources/subscription_schedule.rb', line 1378

def type
  @type
end