Class: Stripe::SubscriptionSchedule::UpdateParams::Phase::AddInvoiceItem::Period::Start

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(timestamp: nil, type: nil) ⇒ Start

Returns a new instance of Start.



1119
1120
1121
1122
# File 'lib/stripe/resources/subscription_schedule.rb', line 1119

def initialize(timestamp: nil, type: nil)
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#timestampObject

A precise Unix timestamp for the start of the invoice item period. Must be less than or equal to ‘period.end`.



1115
1116
1117
# File 'lib/stripe/resources/subscription_schedule.rb', line 1115

def timestamp
  @timestamp
end

#typeObject

Select how to calculate the start of the invoice item period.



1117
1118
1119
# File 'lib/stripe/resources/subscription_schedule.rb', line 1117

def type
  @type
end