Class: Stripe::SubscriptionSchedule::UpdateParams::Phase::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1837
1838
1839
1840
1841
1842
# File 'lib/stripe/resources/subscription_schedule.rb', line 1837

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1829
1830
1831
# File 'lib/stripe/resources/subscription_schedule.rb', line 1829

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1831
1832
1833
# File 'lib/stripe/resources/subscription_schedule.rb', line 1831

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1833
1834
1835
# File 'lib/stripe/resources/subscription_schedule.rb', line 1833

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1835
1836
1837
# File 'lib/stripe/resources/subscription_schedule.rb', line 1835

def promotion_code
  @promotion_code
end