Class: Stripe::SubscriptionSchedule::UpdateParams::Phase::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



1401
1402
1403
1404
1405
# File 'lib/stripe/resources/subscription_schedule.rb', line 1401

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



1395
1396
1397
# File 'lib/stripe/resources/subscription_schedule.rb', line 1395

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



1397
1398
1399
# File 'lib/stripe/resources/subscription_schedule.rb', line 1397

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



1399
1400
1401
# File 'lib/stripe/resources/subscription_schedule.rb', line 1399

def type
  @type
end