Class: Stripe::SubscriptionSchedule::UpdateParams::Phase::Item::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1179
1180
1181
1182
1183
# File 'lib/stripe/resources/subscription_schedule.rb', line 1179

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1173
1174
1175
# File 'lib/stripe/resources/subscription_schedule.rb', line 1173

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1175
1176
1177
# File 'lib/stripe/resources/subscription_schedule.rb', line 1175

def discount
  @discount
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1177
1178
1179
# File 'lib/stripe/resources/subscription_schedule.rb', line 1177

def promotion_code
  @promotion_code
end