Class: Stripe::SubscriptionSchedule::UpdateParams::Phase::Item::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::UpdateParams::Phase::Item::Discount::DiscountEnd
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
1614 1615 1616 1617 1618 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1614 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
1608 1609 1610 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1608 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
1610 1611 1612 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1610 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
1612 1613 1614 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1612 def type @type end |