Class: Stripe::SubscriptionSchedule::UpdateParams::Phase::PauseCollection
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::UpdateParams::Phase::PauseCollection
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Instance Attribute Summary collapse
-
#behavior ⇒ Object
The payment collection behavior for this subscription while paused.
Instance Method Summary collapse
-
#initialize(behavior: nil) ⇒ PauseCollection
constructor
A new instance of PauseCollection.
Methods inherited from RequestParams
Constructor Details
#initialize(behavior: nil) ⇒ PauseCollection
Returns a new instance of PauseCollection.
1833 1834 1835 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1833 def initialize(behavior: nil) @behavior = behavior end |
Instance Attribute Details
#behavior ⇒ Object
The payment collection behavior for this subscription while paused. One of ‘keep_as_draft`, `mark_uncollectible`, or `void`.
1831 1832 1833 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1831 def behavior @behavior end |