Class: Stripe::SubscriptionSchedule::UpdateParams::Prebilling

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(iterations: nil, update_behavior: nil) ⇒ Prebilling

Returns a new instance of Prebilling.



2184
2185
2186
2187
# File 'lib/stripe/resources/subscription_schedule.rb', line 2184

def initialize(iterations: nil, update_behavior: nil)
  @iterations = iterations
  @update_behavior = update_behavior
end

Instance Attribute Details

#iterationsObject

This is used to determine the number of billing cycles to prebill.



2180
2181
2182
# File 'lib/stripe/resources/subscription_schedule.rb', line 2180

def iterations
  @iterations
end

#update_behaviorObject

Whether to cancel or preserve ‘prebilling` if the subscription is updated during the prebilled period. The default value is `reset`.



2182
2183
2184
# File 'lib/stripe/resources/subscription_schedule.rb', line 2182

def update_behavior
  @update_behavior
end