Class: Stripe::SubscriptionScheduleAmendParams::Amendment::AmendmentEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_amend_params.rb

Defined Under Namespace

Classes: DiscountEnd, Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ AmendmentEnd

Returns a new instance of AmendmentEnd.



37
38
39
40
41
42
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 37

def initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil)
  @discount_end = discount_end
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#discount_endObject

Use the ‘end` time of a given discount.



29
30
31
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 29

def discount_end
  @discount_end
end

#durationObject

Time span for the amendment starting from the ‘amendment_start`.



31
32
33
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 31

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the amendment to end. Must be after the ‘amendment_start`.



33
34
35
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 33

def timestamp
  @timestamp
end

#typeObject

Select one of three ways to pass the ‘amendment_end`.



35
36
37
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 35

def type
  @type
end