Class: Stripe::SubscriptionScheduleAmendParams::Amendment::AmendmentStart

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_amend_params.rb

Defined Under Namespace

Classes: AmendmentEnd, DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amendment_end: nil, discount_end: nil, timestamp: nil, type: nil) ⇒ AmendmentStart

Returns a new instance of AmendmentStart.



72
73
74
75
76
77
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 72

def initialize(amendment_end: nil, discount_end: nil, timestamp: nil, type: nil)
  @amendment_end = amendment_end
  @discount_end = discount_end
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#amendment_endObject

Details of another amendment in the same array, immediately after which this amendment should begin.



64
65
66
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 64

def amendment_end
  @amendment_end
end

#discount_endObject

Use the ‘end` time of a given discount.



66
67
68
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 66

def discount_end
  @discount_end
end

#timestampObject

A precise Unix timestamp for the amendment to start.



68
69
70
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 68

def timestamp
  @timestamp
end

#typeObject

Select one of three ways to pass the ‘amendment_start`.



70
71
72
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 70

def type
  @type
end