Class: Stripe::SubscriptionScheduleAmendParams::Amendment::BillingSchedulesAction
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleAmendParams::Amendment::BillingSchedulesAction
- Defined in:
- lib/stripe/params/subscription_schedule_amend_params.rb
Defined Under Namespace
Classes: AppliesTo
Instance Attribute Summary collapse
-
#applies_to ⇒ Object
Specify which subscription items the billing schedule applies to.
-
#type ⇒ Object
Select the action.
Instance Method Summary collapse
-
#initialize(applies_to: nil, type: nil) ⇒ BillingSchedulesAction
constructor
A new instance of BillingSchedulesAction.
Methods inherited from RequestParams
Constructor Details
#initialize(applies_to: nil, type: nil) ⇒ BillingSchedulesAction
Returns a new instance of BillingSchedulesAction.
97 98 99 100 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 97 def initialize(applies_to: nil, type: nil) @applies_to = applies_to @type = type end |
Instance Attribute Details
#applies_to ⇒ Object
Specify which subscription items the billing schedule applies to.
93 94 95 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 93 def applies_to @applies_to end |
#type ⇒ Object
Select the action.
95 96 97 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 95 def type @type end |