Class: Stripe::SubscriptionScheduleAmendParams::Amendment::DiscountAction
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleAmendParams::Amendment::DiscountAction
- Defined in:
- lib/stripe/params/subscription_schedule_amend_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#add ⇒ Object
Details of the discount to add.
-
#remove ⇒ Object
Details of the discount to remove.
-
#set ⇒ Object
Details of the discount to replace the existing discounts with.
-
#type ⇒ Object
Determines the type of discount action.
Instance Method Summary collapse
-
#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ DiscountAction
constructor
A new instance of DiscountAction.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ DiscountAction
Returns a new instance of DiscountAction.
154 155 156 157 158 159 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 154 def initialize(add: nil, remove: nil, set: nil, type: nil) @add = add @remove = remove @set = set @type = type end |
Instance Attribute Details
#add ⇒ Object
Details of the discount to add.
146 147 148 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 146 def add @add end |
#remove ⇒ Object
Details of the discount to remove.
148 149 150 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 148 def remove @remove end |
#set ⇒ Object
Details of the discount to replace the existing discounts with.
150 151 152 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 150 def set @set end |
#type ⇒ Object
Determines the type of discount action.
152 153 154 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 152 def type @type end |