Class: Stripe::SubscriptionScheduleAmendParams::Amendment::DiscountAction::Add::Settings::ServicePeriodAnchorConfig::Custom
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleAmendParams::Amendment::DiscountAction::Add::Settings::ServicePeriodAnchorConfig::Custom
- Defined in:
- lib/stripe/params/subscription_schedule_amend_params.rb
Instance Attribute Summary collapse
-
#day_of_month ⇒ Object
The day of the month the anchor should be.
-
#hour ⇒ Object
The hour of the day the anchor should be.
-
#minute ⇒ Object
The minute of the hour the anchor should be.
-
#month ⇒ Object
The month to start full cycle periods.
-
#second ⇒ Object
The second of the minute the anchor should be.
Instance Method Summary collapse
-
#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom
constructor
A new instance of Custom.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom
Returns a new instance of Custom.
128 129 130 131 132 133 134 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 128 def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) @day_of_month = day_of_month @hour = hour @minute = minute @month = month @second = second end |
Instance Attribute Details
#day_of_month ⇒ Object
The day of the month the anchor should be. Ranges from 1 to 31.
118 119 120 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 118 def day_of_month @day_of_month end |
#hour ⇒ Object
The hour of the day the anchor should be. Ranges from 0 to 23.
120 121 122 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 120 def hour @hour end |
#minute ⇒ Object
The minute of the hour the anchor should be. Ranges from 0 to 59.
122 123 124 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 122 def minute @minute end |
#month ⇒ Object
The month to start full cycle periods. Ranges from 1 to 12.
124 125 126 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 124 def month @month end |
#second ⇒ Object
The second of the minute the anchor should be. Ranges from 0 to 59.
126 127 128 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 126 def second @second end |