Class: Stripe::SubscriptionScheduleAmendParams::Amendment::DiscountAction::Set
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleAmendParams::Amendment::DiscountAction::Set
- Defined in:
- lib/stripe/params/subscription_schedule_amend_params.rb
Defined Under Namespace
Classes: Settings
Instance Attribute Summary collapse
-
#coupon ⇒ Object
The coupon code to replace the ‘discounts` array with.
-
#discount ⇒ Object
An ID of an existing discount to replace the ‘discounts` array with.
-
#promotion_code ⇒ Object
An ID of an existing promotion code to replace the ‘discounts` array with.
-
#settings ⇒ Object
Settings for discount application including service period anchoring.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, promotion_code: nil, settings: nil) ⇒ Set
constructor
A new instance of Set.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(coupon: nil, discount: nil, promotion_code: nil, settings: nil) ⇒ Set
Returns a new instance of Set.
253 254 255 256 257 258 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 253 def initialize(coupon: nil, discount: nil, promotion_code: nil, settings: nil) @coupon = coupon @discount = discount @promotion_code = promotion_code @settings = settings end |
Instance Attribute Details
#coupon ⇒ Object
The coupon code to replace the ‘discounts` array with.
245 246 247 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 245 def coupon @coupon end |
#discount ⇒ Object
An ID of an existing discount to replace the ‘discounts` array with.
247 248 249 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 247 def discount @discount end |
#promotion_code ⇒ Object
An ID of an existing promotion code to replace the ‘discounts` array with.
249 250 251 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 249 def promotion_code @promotion_code end |
#settings ⇒ Object
Settings for discount application including service period anchoring.
251 252 253 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 251 def settings @settings end |