Class: Stripe::SubscriptionScheduleAmendParams::Amendment::ItemAction

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_amend_params.rb

Defined Under Namespace

Classes: Add, Remove, Set

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ ItemAction

Returns a new instance of ItemAction.



577
578
579
580
581
582
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 577

def initialize(add: nil, remove: nil, set: nil, type: nil)
  @add = add
  @remove = remove
  @set = set
  @type = type
end

Instance Attribute Details

#addObject

Details of the subscription item to add. If an item with the same price exists, it will be replaced by this new item. Otherwise, it adds the new item.



569
570
571
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 569

def add
  @add
end

#removeObject

Details of the subscription item to remove.



571
572
573
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 571

def remove
  @remove
end

#setObject

Details of the subscription item to replace the existing items with. If an item with the set[price] already exists, the items array is not cleared. Instead, all of the other set properties that are passed in this request will replace the existing values for the configuration item.



573
574
575
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 573

def set
  @set
end

#typeObject

Determines the type of item action.



575
576
577
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 575

def type
  @type
end