Class: Stripe::SubscriptionScheduleAmendParams::Amendment::ItemAction::Add

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_amend_params.rb

Defined Under Namespace

Classes: Discount, Trial

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil) ⇒ Add

Returns a new instance of Add.



233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 233

def initialize(
  discounts: nil,
  metadata: nil,
  price: nil,
  quantity: nil,
  tax_rates: nil,
  trial: nil,
  trial_offer: nil
)
  @discounts = discounts
  @metadata = 
  @price = price
  @quantity = quantity
  @tax_rates = tax_rates
  @trial = trial
  @trial_offer = trial_offer
end

Instance Attribute Details

#discountsObject

The discounts applied to the item. Subscription item discounts are applied before subscription discounts.



219
220
221
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 219

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



221
222
223
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 221

def 
  @metadata
end

#priceObject

The ID of the price object.



223
224
225
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 223

def price
  @price
end

#quantityObject

Quantity for this item.



225
226
227
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 225

def quantity
  @quantity
end

#tax_ratesObject

The tax rates that apply to this subscription item. When set, the ‘default_tax_rates` on the subscription do not apply to this `subscription_item`.



227
228
229
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 227

def tax_rates
  @tax_rates
end

#trialObject

Options that configure the trial on the subscription item.



229
230
231
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 229

def trial
  @trial
end

#trial_offerObject

The ID of the trial offer to apply to the configuration item.



231
232
233
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 231

def trial_offer
  @trial_offer
end