Class: Stripe::SubscriptionScheduleAmendParams::Amendment::ItemAction::Add::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_amend_params.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



184
185
186
187
188
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 184

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



178
179
180
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 178

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



180
181
182
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 180

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



182
183
184
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 182

def type
  @type
end