Class: Stripe::SubscriptionScheduleAmendParams::Amendment::ItemAction::Add::Discount::Settings::ServicePeriodAnchorConfig::Custom

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_amend_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom

Returns a new instance of Custom.



320
321
322
323
324
325
326
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 320

def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil)
  @day_of_month = day_of_month
  @hour = hour
  @minute = minute
  @month = month
  @second = second
end

Instance Attribute Details

#day_of_monthObject

The day of the month the anchor should be. Ranges from 1 to 31.



310
311
312
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 310

def day_of_month
  @day_of_month
end

#hourObject

The hour of the day the anchor should be. Ranges from 0 to 23.



312
313
314
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 312

def hour
  @hour
end

#minuteObject

The minute of the hour the anchor should be. Ranges from 0 to 59.



314
315
316
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 314

def minute
  @minute
end

#monthObject

The month to start full cycle periods. Ranges from 1 to 12.



316
317
318
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 316

def month
  @month
end

#secondObject

The second of the minute the anchor should be. Ranges from 0 to 59.



318
319
320
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 318

def second
  @second
end