Class: Stripe::SubscriptionScheduleAmendParams::Amendment::ItemAction::Set::Discount::Settings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleAmendParams::Amendment::ItemAction::Set::Discount::Settings
- Defined in:
- lib/stripe/params/subscription_schedule_amend_params.rb
Defined Under Namespace
Classes: ServicePeriodAnchorConfig
Instance Attribute Summary collapse
-
#service_period_anchor_config ⇒ Object
Configures service period cycle anchoring.
-
#start_date ⇒ Object
The start date of the discount’s service period when applying a coupon or promotion code with a service period duration.
Instance Method Summary collapse
-
#initialize(service_period_anchor_config: nil, start_date: nil) ⇒ Settings
constructor
A new instance of Settings.
Methods inherited from RequestParams
Constructor Details
#initialize(service_period_anchor_config: nil, start_date: nil) ⇒ Settings
Returns a new instance of Settings.
493 494 495 496 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 493 def initialize(service_period_anchor_config: nil, start_date: nil) @service_period_anchor_config = service_period_anchor_config @start_date = start_date end |
Instance Attribute Details
#service_period_anchor_config ⇒ Object
Configures service period cycle anchoring.
489 490 491 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 489 def service_period_anchor_config @service_period_anchor_config end |
#start_date ⇒ Object
The start date of the discount’s service period when applying a coupon or promotion code with a service period duration. Defaults to ‘amendment_start` if omitted.
491 492 493 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 491 def start_date @start_date end |