Class: Stripe::SubscriptionScheduleAmendParams::Amendment::SetPauseCollection::Set
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleAmendParams::Amendment::SetPauseCollection::Set
- Defined in:
- lib/stripe/params/subscription_schedule_amend_params.rb
Instance Attribute Summary collapse
-
#behavior ⇒ Object
The payment collection behavior for this subscription while paused.
Instance Method Summary collapse
-
#initialize(behavior: nil) ⇒ Set
constructor
A new instance of Set.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(behavior: nil) ⇒ Set
Returns a new instance of Set.
389 390 391 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 389 def initialize(behavior: nil) @behavior = behavior end |
Instance Attribute Details
#behavior ⇒ Object
The payment collection behavior for this subscription while paused.
387 388 389 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 387 def behavior @behavior end |