Class: Stripe::SubscriptionScheduleAmendParams::Prebilling::BillUntil

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_amend_params.rb

Defined Under Namespace

Classes: AmendmentEnd, Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ BillUntil

Returns a new instance of BillUntil.



520
521
522
523
524
525
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 520

def initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil)
  @amendment_end = amendment_end
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#amendment_endObject

End the prebilled period when a specified amendment ends.



512
513
514
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 512

def amendment_end
  @amendment_end
end

#durationObject

Time span for prebilling, starting from ‘bill_from`.



514
515
516
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 514

def duration
  @duration
end

#timestampObject

End the prebilled period at a precise integer timestamp, starting from the Unix epoch.



516
517
518
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 516

def timestamp
  @timestamp
end

#typeObject

Select one of several ways to pass the ‘bill_until` value.



518
519
520
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 518

def type
  @type
end