Class: Stripe::SubscriptionScheduleCreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/subscription_schedule_create_params.rb

Defined Under Namespace

Classes: BillingMode, DefaultSettings, Phase

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(billing_mode: nil, customer: nil, customer_account: nil, default_settings: nil, end_behavior: nil, expand: nil, from_subscription: nil, metadata: nil, phases: nil, start_date: nil) ⇒ SubscriptionScheduleCreateParams



609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 609

def initialize(
  billing_mode: nil,
  customer: nil,
  customer_account: nil,
  default_settings: nil,
  end_behavior: nil,
  expand: nil,
  from_subscription: nil,
  metadata: nil,
  phases: nil,
  start_date: nil
)
  @billing_mode = billing_mode
  @customer = customer
   = 
  @default_settings = default_settings
  @end_behavior = end_behavior
  @expand = expand
  @from_subscription = from_subscription
   = 
  @phases = phases
  @start_date = start_date
end

Instance Attribute Details

#billing_modeObject

Controls how prorations and invoices for subscriptions are calculated and orchestrated.



589
590
591
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 589

def billing_mode
  @billing_mode
end

#customerObject

The identifier of the customer to create the subscription schedule for.



591
592
593
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 591

def customer
  @customer
end

#customer_accountObject

The identifier of the account to create the subscription schedule for.



593
594
595
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 593

def 
  
end

#default_settingsObject

Object representing the subscription schedule’s default settings.



595
596
597
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 595

def default_settings
  @default_settings
end

#end_behaviorObject

Behavior of the subscription schedule and underlying subscription when it ends. Possible values are release or cancel with the default being release. release will end the subscription schedule and keep the underlying subscription running. cancel will end the subscription schedule and cancel the underlying subscription.



597
598
599
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 597

def end_behavior
  @end_behavior
end

#expandObject

Specifies which fields in the response should be expanded.



599
600
601
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 599

def expand
  @expand
end

#from_subscriptionObject

Migrate an existing subscription to be managed by a subscription schedule. If this parameter is set, a subscription schedule will be created using the subscription’s item(s), set to auto-renew using the subscription’s interval. When using this parameter, other parameters (such as phase values) cannot be set. To create a subscription schedule with other modifications, we recommend making two separate API calls.



601
602
603
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 601

def from_subscription
  @from_subscription
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.



603
604
605
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 603

def 
  
end

#phasesObject

List representing phases of the subscription schedule. Each phase can be customized to have different durations, plans, and coupons. If there are multiple phases, the end_date of one phase will always equal the start_date of the next phase.



605
606
607
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 605

def phases
  @phases
end

#start_dateObject

When the subscription schedule starts. We recommend using now so that it starts the subscription immediately. You can also use a Unix timestamp to backdate the subscription so that it starts on a past date, or set a future date for the subscription to start on.



607
608
609
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 607

def start_date
  @start_date
end

Class Method Details

.field_encodingsObject



633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 633

def self.field_encodings
  @field_encodings = {
    phases: {
      kind: :array,
      element: {
        kind: :object,
        fields: {
          add_invoice_items: {
            kind: :array,
            element: {
              kind: :object,
              fields: {
                price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } },
              },
            },
          },
          items: {
            kind: :array,
            element: {
              kind: :object,
              fields: {
                price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } },
              },
            },
          },
        },
      },
    },
  }
end