Class: Stripe::SubscriptionScheduleCreateParams::BillingSchedule

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_create_params.rb

Defined Under Namespace

Classes: AppliesTo, BillUntil

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(applies_to: nil, bill_until: nil, key: nil) ⇒ BillingSchedule

Returns a new instance of BillingSchedule.



71
72
73
74
75
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 71

def initialize(applies_to: nil, bill_until: nil, key: nil)
  @applies_to = applies_to
  @bill_until = bill_until
  @key = key
end

Instance Attribute Details

#applies_toObject

Configure billing schedule differently for individual subscription items.



65
66
67
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 65

def applies_to
  @applies_to
end

#bill_untilObject

The end date for the billing schedule.



67
68
69
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 67

def bill_until
  @bill_until
end

#keyObject

Specify a key for the billing schedule. Must be unique to this field, alphanumeric, and up to 200 characters. If not provided, a unique key will be generated.



69
70
71
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 69

def key
  @key
end