Class: Stripe::SubscriptionScheduleCreateParams::DefaultSettings::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount_percent: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



122
123
124
125
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 122

def initialize(amount_percent: nil, destination: nil)
  @amount_percent = amount_percent
  @destination = destination
end

Instance Attribute Details

#amount_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination.



118
119
120
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 118

def amount_percent
  @amount_percent
end

#destinationObject

ID of an existing, connected Stripe account.



120
121
122
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 120

def destination
  @destination
end