Class: Stripe::SubscriptionScheduleCreateParams::PauseSchedule::Pause::Settings::BillFor

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_create_params.rb

Defined Under Namespace

Classes: OutstandingUsageThrough, UnusedTimeFrom

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h

Constructor Details

#initialize(outstanding_usage_through: nil, unused_time_from: nil) ⇒ BillFor

Returns a new instance of BillFor.



211
212
213
214
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 211

def initialize(outstanding_usage_through: nil, unused_time_from: nil)
  @outstanding_usage_through = outstanding_usage_through
  @unused_time_from = unused_time_from
end

Instance Attribute Details

#outstanding_usage_through ⇒ Object

Controls whether to collect metered usage accrued up to the pause date.



207
208
209
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 207

def outstanding_usage_through
  @outstanding_usage_through
end

#unused_time_from ⇒ Object

Controls how unused time on subscription items is credited when pausing.



209
210
211
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 209

def unused_time_from
  @unused_time_from
end