Class: Stripe::SubscriptionScheduleCreateParams::PauseSchedule::Pause::Settings::BillFor::OutstandingUsageThrough
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleCreateParams::PauseSchedule::Pause::Settings::BillFor::OutstandingUsageThrough
- Defined in:
- lib/stripe/params/subscription_schedule_create_params.rb
Instance Attribute Summary collapse
-
#type ⇒ Object
Determines whether to collect metered usage accrued up to the pause date.
Instance Method Summary collapse
-
#initialize(type: nil) ⇒ OutstandingUsageThrough
constructor
A new instance of OutstandingUsageThrough.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(type: nil) ⇒ OutstandingUsageThrough
Returns a new instance of OutstandingUsageThrough.
249 250 251 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 249 def initialize(type: nil) @type = type end |
Instance Attribute Details
#type ⇒ Object
Determines whether to collect metered usage accrued up to the pause date.
247 248 249 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 247 def type @type end |