Class: Stripe::SubscriptionScheduleCreateParams::PauseSchedule::Pause::Settings::BillFor::UnusedTimeFrom
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleCreateParams::PauseSchedule::Pause::Settings::BillFor::UnusedTimeFrom
- Defined in:
- lib/stripe/params/subscription_schedule_create_params.rb
Instance Attribute Summary collapse
-
#type ⇒ Object
Determines which point in the billing period unused time is credited from.
Instance Method Summary collapse
-
#initialize(type: nil) ⇒ UnusedTimeFrom
constructor
A new instance of UnusedTimeFrom.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(type: nil) ⇒ UnusedTimeFrom
Returns a new instance of UnusedTimeFrom.
258 259 260 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 258 def initialize(type: nil) @type = type end |
Instance Attribute Details
#type ⇒ Object
Determines which point in the billing period unused time is credited from.
256 257 258 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 256 def type @type end |