Class: Stripe::SubscriptionScheduleCreateParams::Phase::AddInvoiceItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_create_params.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



398
399
400
401
402
403
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 398

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



390
391
392
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 390

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



392
393
394
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 392

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



394
395
396
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 394

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



396
397
398
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 396

def promotion_code
  @promotion_code
end