Class: Stripe::SubscriptionScheduleCreateParams::Phase::AddInvoiceItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_create_params.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



195
196
197
198
199
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 195

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



189
190
191
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 189

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



191
192
193
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 191

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



193
194
195
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 193

def type
  @type
end