Class: Stripe::SubscriptionScheduleCreateParams::Phase::AddInvoiceItem::Period::End
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleCreateParams::Phase::AddInvoiceItem::Period::End
- Defined in:
- lib/stripe/params/subscription_schedule_create_params.rb
Instance Attribute Summary collapse
-
#timestamp ⇒ Object
A precise Unix timestamp for the end of the invoice item period.
-
#type ⇒ Object
Select how to calculate the end of the invoice item period.
Instance Method Summary collapse
-
#initialize(timestamp: nil, type: nil) ⇒ End
constructor
A new instance of End.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(timestamp: nil, type: nil) ⇒ End
Returns a new instance of End.
197 198 199 200 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 197 def initialize(timestamp: nil, type: nil) @timestamp = @type = type end |
Instance Attribute Details
#timestamp ⇒ Object
A precise Unix timestamp for the end of the invoice item period. Must be greater than or equal to ‘period.start`.
193 194 195 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 193 def @timestamp end |
#type ⇒ Object
Select how to calculate the end of the invoice item period.
195 196 197 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 195 def type @type end |