Class: Stripe::SubscriptionScheduleCreateParams::Phase::AddInvoiceItem::PriceData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_create_params.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(currency: nil, product: nil, tax_behavior: nil, unit_amount: nil, unit_amount_decimal: nil) ⇒ PriceData

Returns a new instance of PriceData.



453
454
455
456
457
458
459
460
461
462
463
464
465
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 453

def initialize(
  currency: nil,
  product: nil,
  tax_behavior: nil,
  unit_amount: nil,
  unit_amount_decimal: nil
)
  @currency = currency
  @product = product
  @tax_behavior = tax_behavior
  @unit_amount = unit_amount
  @unit_amount_decimal = unit_amount_decimal
end

Instance Attribute Details

#currencyObject

Three-letter ISO currency code, in lowercase. Must be a supported currency.



443
444
445
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 443

def currency
  @currency
end

#productObject

The ID of the Product that this Price will belong to.



445
446
447
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 445

def product
  @product
end

#tax_behaviorObject

Only required if a default tax behavior was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One of inclusive, exclusive, or unspecified. Once specified as either inclusive or exclusive, it cannot be changed.



447
448
449
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 447

def tax_behavior
  @tax_behavior
end

#unit_amountObject

A positive integer in cents (or local equivalent) (or 0 for a free price) representing how much to charge or a negative integer representing the amount to credit to the customer.



449
450
451
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 449

def unit_amount
  @unit_amount
end

#unit_amount_decimalObject

Same as unit_amount, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places. Only one of unit_amount and unit_amount_decimal can be set.



451
452
453
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 451

def unit_amount_decimal
  @unit_amount_decimal
end

Class Method Details

.field_encodingsObject



467
468
469
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 467

def self.field_encodings
  @field_encodings = { unit_amount_decimal: :decimal_string }
end