Class: Stripe::SubscriptionScheduleCreateParams::Phase::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_create_params.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



410
411
412
413
414
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 410

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



404
405
406
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 404

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



406
407
408
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 406

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



408
409
410
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 408

def type
  @type
end