Class: Stripe::SubscriptionScheduleCreateParams::Phase::Discount::DiscountEnd::Duration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(interval: nil, interval_count: nil) ⇒ Duration

Returns a new instance of Duration.



338
339
340
341
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 338

def initialize(interval: nil, interval_count: nil)
  @interval = interval
  @interval_count = interval_count
end

Instance Attribute Details

#intervalObject

Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.



334
335
336
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 334

def interval
  @interval
end

#interval_countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



336
337
338
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 336

def interval_count
  @interval_count
end