Class: Stripe::SubscriptionScheduleCreateParams::Phase::Discount::Settings::ServicePeriodAnchorConfig::Custom

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom

Returns a new instance of Custom.



431
432
433
434
435
436
437
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 431

def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil)
  @day_of_month = day_of_month
  @hour = hour
  @minute = minute
  @month = month
  @second = second
end

Instance Attribute Details

#day_of_monthObject

The day of the month the anchor should be. Ranges from 1 to 31.



421
422
423
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 421

def day_of_month
  @day_of_month
end

#hourObject

The hour of the day the anchor should be. Ranges from 0 to 23.



423
424
425
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 423

def hour
  @hour
end

#minuteObject

The minute of the hour the anchor should be. Ranges from 0 to 59.



425
426
427
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 425

def minute
  @minute
end

#monthObject

The month to start full cycle periods. Ranges from 1 to 12.



427
428
429
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 427

def month
  @month
end

#secondObject

The second of the minute the anchor should be. Ranges from 0 to 59.



429
430
431
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 429

def second
  @second
end