Class: Stripe::SubscriptionScheduleCreateParams::Phase::Item::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



373
374
375
376
377
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 373

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



367
368
369
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 367

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



369
370
371
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 369

def discount
  @discount
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



371
372
373
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 371

def promotion_code
  @promotion_code
end