Class: Stripe::SubscriptionScheduleCreateParams::Phase::Item::Discount::DiscountEnd::Duration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(interval: nil, interval_count: nil) ⇒ Duration

Returns a new instance of Duration.



489
490
491
492
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 489

def initialize(interval: nil, interval_count: nil)
  @interval = interval
  @interval_count = interval_count
end

Instance Attribute Details

#intervalObject

Specifies a type of interval unit. Either day, week, month or year.



485
486
487
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 485

def interval
  @interval
end

#interval_countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



487
488
489
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 487

def interval_count
  @interval_count
end