Class: Stripe::SubscriptionScheduleCreateParams::Phase::Item::Discount::Settings::ServicePeriodAnchorConfig::Custom

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom

Returns a new instance of Custom.



762
763
764
765
766
767
768
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 762

def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil)
  @day_of_month = day_of_month
  @hour = hour
  @minute = minute
  @month = month
  @second = second
end

Instance Attribute Details

#day_of_monthObject

The day of the month the anchor should be. Ranges from 1 to 31.



752
753
754
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 752

def day_of_month
  @day_of_month
end

#hourObject

The hour of the day the anchor should be. Ranges from 0 to 23.



754
755
756
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 754

def hour
  @hour
end

#minuteObject

The minute of the hour the anchor should be. Ranges from 0 to 59.



756
757
758
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 756

def minute
  @minute
end

#monthObject

The month to start full cycle periods. Ranges from 1 to 12.



758
759
760
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 758

def month
  @month
end

#secondObject

The second of the minute the anchor should be. Ranges from 0 to 59.



760
761
762
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 760

def second
  @second
end