Class: Stripe::SubscriptionScheduleCreateParams::Phase::Item::Trial
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleCreateParams::Phase::Item::Trial
- Defined in:
- lib/stripe/params/subscription_schedule_create_params.rb
Instance Attribute Summary collapse
-
#converts_to ⇒ Object
List of price IDs which, if present on the subscription following a paid trial, constitute opting-in to the paid trial.
-
#type ⇒ Object
Determines the type of trial for this item.
Instance Method Summary collapse
-
#initialize(converts_to: nil, type: nil) ⇒ Trial
constructor
A new instance of Trial.
Methods inherited from RequestParams
Constructor Details
#initialize(converts_to: nil, type: nil) ⇒ Trial
Returns a new instance of Trial.
502 503 504 505 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 502 def initialize(converts_to: nil, type: nil) @converts_to = converts_to @type = type end |
Instance Attribute Details
#converts_to ⇒ Object
List of price IDs which, if present on the subscription following a paid trial, constitute opting-in to the paid trial. Currently only supports at most 1 price ID.
498 499 500 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 498 def converts_to @converts_to end |
#type ⇒ Object
Determines the type of trial for this item.
500 501 502 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 500 def type @type end |