Class: Stripe::SubscriptionScheduleCreateParams::Prebilling

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(iterations: nil, update_behavior: nil) ⇒ Prebilling

Returns a new instance of Prebilling.



737
738
739
740
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 737

def initialize(iterations: nil, update_behavior: nil)
  @iterations = iterations
  @update_behavior = update_behavior
end

Instance Attribute Details

#iterationsObject

This is used to determine the number of billing cycles to prebill.



733
734
735
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 733

def iterations
  @iterations
end

#update_behaviorObject

Whether to cancel or preserve ‘prebilling` if the subscription is updated during the prebilled period. The default value is `reset`.



735
736
737
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 735

def update_behavior
  @update_behavior
end