Class: Stripe::SubscriptionScheduleService::AmendParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Defined Under Namespace

Classes: Amendment, Prebilling, ScheduleSettings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendments: nil, expand: nil, prebilling: nil, proration_behavior: nil, schedule_settings: nil) ⇒ AmendParams

Returns a new instance of AmendParams.



2149
2150
2151
2152
2153
2154
2155
2156
2157
2158
2159
2160
2161
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2149

def initialize(
  amendments: nil,
  expand: nil,
  prebilling: nil,
  proration_behavior: nil,
  schedule_settings: nil
)
  @amendments = amendments
  @expand = expand
  @prebilling = prebilling
  @proration_behavior = proration_behavior
  @schedule_settings = schedule_settings
end

Instance Attribute Details

#amendmentsObject

Changes to apply to the phases of the subscription schedule, in the order provided.



2138
2139
2140
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2138

def amendments
  @amendments
end

#expandObject

Specifies which fields in the response should be expanded.



2140
2141
2142
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2140

def expand
  @expand
end

#prebillingObject

Provide any time periods to bill in advance.



2142
2143
2144
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2142

def prebilling
  @prebilling
end

#proration_behaviorObject

In cases where the amendment changes the currently active phase,

specifies if and how to prorate at the time of the request.


2145
2146
2147
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2145

def proration_behavior
  @proration_behavior
end

#schedule_settingsObject

Changes to apply to the subscription schedule.



2147
2148
2149
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2147

def schedule_settings
  @schedule_settings
end