Class: Stripe::SubscriptionScheduleService::AmendParams::Amendment

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Defined Under Namespace

Classes: AmendmentEnd, AmendmentStart, DiscountAction, ItemAction, MetadataAction, SetPauseCollection, TrialSettings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendment_end: nil, amendment_start: nil, billing_cycle_anchor: nil, discount_actions: nil, item_actions: nil, metadata_actions: nil, proration_behavior: nil, set_pause_collection: nil, set_schedule_end: nil, trial_settings: nil) ⇒ Amendment

Returns a new instance of Amendment.



2026
2027
2028
2029
2030
2031
2032
2033
2034
2035
2036
2037
2038
2039
2040
2041
2042
2043
2044
2045
2046
2047
2048
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2026

def initialize(
  amendment_end: nil,
  amendment_start: nil,
  billing_cycle_anchor: nil,
  discount_actions: nil,
  item_actions: nil,
  metadata_actions: nil,
  proration_behavior: nil,
  set_pause_collection: nil,
  set_schedule_end: nil,
  trial_settings: nil
)
  @amendment_end = amendment_end
  @amendment_start = amendment_start
  @billing_cycle_anchor = billing_cycle_anchor
  @discount_actions = discount_actions
  @item_actions = item_actions
  @metadata_actions = 
  @proration_behavior = proration_behavior
  @set_pause_collection = set_pause_collection
  @set_schedule_end = set_schedule_end
  @trial_settings = trial_settings
end

Instance Attribute Details

#amendment_endObject

Details to identify the end of the time range modified by the proposed change. If not supplied, the amendment is considered a point-in-time operation that only affects the exact timestamp at ‘amendment_start`, and a restricted set of attributes is supported on the amendment.



2006
2007
2008
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2006

def amendment_end
  @amendment_end
end

#amendment_startObject

Details to identify the earliest timestamp where the proposed change should take effect.



2008
2009
2010
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2008

def amendment_start
  @amendment_start
end

#billing_cycle_anchorObject

For point-in-time amendments (having no ‘amendment_end`), this attribute lets you set or remove whether the subscription’s billing cycle anchor is reset at the ‘amendment_start` timestamp.For time-span based amendments (having both `amendment_start` and `amendment_end`), the only value valid is `automatic`, which removes any previously configured billing cycle anchor resets scheduled to occur during the window of time spanned by the amendment.



2010
2011
2012
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2010

def billing_cycle_anchor
  @billing_cycle_anchor
end

#discount_actionsObject

Changes to the coupons being redeemed or discounts being applied during the amendment time span.



2012
2013
2014
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2012

def discount_actions
  @discount_actions
end

#item_actionsObject

Changes to the subscription items during the amendment time span.



2014
2015
2016
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2014

def item_actions
  @item_actions
end

#metadata_actionsObject

Instructions for how to modify phase metadata



2016
2017
2018
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2016

def 
  @metadata_actions
end

#proration_behaviorObject

Changes to how Stripe handles prorations during the amendment time span. Affects if and how prorations are created when a future phase starts. In cases where the amendment changes the currently active phase, it is used to determine whether or how to prorate now, at the time of the request. Also supported as a point-in-time operation when ‘amendment_end` is `null`.



2018
2019
2020
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2018

def proration_behavior
  @proration_behavior
end

#set_pause_collectionObject

Defines how to pause collection for the underlying subscription throughout the duration of the amendment.



2020
2021
2022
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2020

def set_pause_collection
  @set_pause_collection
end

#set_schedule_endObject

Ends the subscription schedule early as dictated by either the accompanying amendment’s start or end.



2022
2023
2024
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2022

def set_schedule_end
  @set_schedule_end
end

#trial_settingsObject

Settings related to subscription trials.



2024
2025
2026
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2024

def trial_settings
  @trial_settings
end