Class: Stripe::SubscriptionScheduleService::AmendParams::Amendment::AmendmentEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Defined Under Namespace

Classes: DiscountEnd, Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ AmendmentEnd

Returns a new instance of AmendmentEnd.



1532
1533
1534
1535
1536
1537
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1532

def initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil)
  @discount_end = discount_end
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#discount_endObject

Use the ‘end` time of a given discount.



1524
1525
1526
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1524

def discount_end
  @discount_end
end

#durationObject

Time span for the amendment starting from the ‘amendment_start`.



1526
1527
1528
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1526

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the amendment to end. Must be after the ‘amendment_start`.



1528
1529
1530
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1528

def timestamp
  @timestamp
end

#typeObject

Select one of three ways to pass the ‘amendment_end`.



1530
1531
1532
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1530

def type
  @type
end