Class: Stripe::SubscriptionScheduleService::AmendParams::Amendment::AmendmentStart

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Defined Under Namespace

Classes: AmendmentEnd, DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendment_end: nil, discount_end: nil, timestamp: nil, type: nil) ⇒ AmendmentStart

Returns a new instance of AmendmentStart.



1665
1666
1667
1668
1669
1670
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1665

def initialize(amendment_end: nil, discount_end: nil, timestamp: nil, type: nil)
  @amendment_end = amendment_end
  @discount_end = discount_end
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#amendment_endObject

Details of another amendment in the same array, immediately after which this amendment should begin.



1657
1658
1659
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1657

def amendment_end
  @amendment_end
end

#discount_endObject

Use the ‘end` time of a given discount.



1659
1660
1661
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1659

def discount_end
  @discount_end
end

#timestampObject

A precise Unix timestamp for the amendment to start.



1661
1662
1663
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1661

def timestamp
  @timestamp
end

#typeObject

Select one of three ways to pass the ‘amendment_start`.



1663
1664
1665
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1663

def type
  @type
end