Class: Stripe::SubscriptionScheduleService::AmendParams::Amendment::AmendmentStart::AmendmentEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(index: nil) ⇒ AmendmentEnd

Returns a new instance of AmendmentEnd.



1513
1514
1515
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1513

def initialize(index: nil)
  @index = index
end

Instance Attribute Details

#indexObject

The position of the previous amendment in the ‘amendments` array after which this amendment should begin. Indexes start from 0 and must be less than the index of the current amendment in the array.



1511
1512
1513
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1511

def index
  @index
end