Class: Stripe::SubscriptionScheduleService::AmendParams::Amendment::DiscountAction
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::AmendParams::Amendment::DiscountAction
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#add ⇒ Object
Details of the discount to add.
-
#remove ⇒ Object
Details of the discount to remove.
-
#set ⇒ Object
Details of the discount to replace the existing discounts with.
-
#type ⇒ Object
Determines the type of discount action.
Instance Method Summary collapse
-
#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ DiscountAction
constructor
A new instance of DiscountAction.
Methods inherited from RequestParams
Constructor Details
#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ DiscountAction
Returns a new instance of DiscountAction.
1747 1748 1749 1750 1751 1752 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1747 def initialize(add: nil, remove: nil, set: nil, type: nil) @add = add @remove = remove @set = set @type = type end |
Instance Attribute Details
#add ⇒ Object
Details of the discount to add.
1739 1740 1741 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1739 def add @add end |
#remove ⇒ Object
Details of the discount to remove.
1741 1742 1743 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1741 def remove @remove end |
#set ⇒ Object
Details of the discount to replace the existing discounts with.
1743 1744 1745 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1743 def set @set end |
#type ⇒ Object
Determines the type of discount action.
1745 1746 1747 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1745 def type @type end |