Class: Stripe::SubscriptionScheduleService::AmendParams::Amendment::DiscountAction::Add

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ Add

Returns a new instance of Add.



1694
1695
1696
1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1694

def initialize(
  coupon: nil,
  discount: nil,
  discount_end: nil,
  index: nil,
  promotion_code: nil
)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @index = index
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to redeem.



1684
1685
1686
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1684

def coupon
  @coupon
end

#discountObject

An ID of an existing discount for a coupon that was already redeemed.



1686
1687
1688
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1686

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1688
1689
1690
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1688

def discount_end
  @discount_end
end

#indexObject

The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the ‘discounts` array.



1690
1691
1692
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1690

def index
  @index
end

#promotion_codeObject

The promotion code to redeem.



1692
1693
1694
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1692

def promotion_code
  @promotion_code
end