Class: Stripe::SubscriptionScheduleService::AmendParams::Amendment::DiscountAction::Add::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::AmendParams::Amendment::DiscountAction::Add::DiscountEnd
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Instance Attribute Summary collapse
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
1450 1451 1452 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1450 def initialize(type: nil) @type = type end |
Instance Attribute Details
#type ⇒ Object
The type of calculation made to determine when the discount ends.
1448 1449 1450 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1448 def type @type end |