Class: Stripe::SubscriptionScheduleService::AmendParams::Amendment::DiscountAction::Set

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Set

Returns a new instance of Set.



1732
1733
1734
1735
1736
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1732

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to replace the ‘discounts` array with.



1726
1727
1728
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1726

def coupon
  @coupon
end

#discountObject

An ID of an existing discount to replace the ‘discounts` array with.



1728
1729
1730
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1728

def discount
  @discount
end

#promotion_codeObject

An ID of an existing promotion code to replace the ‘discounts` array with.



1730
1731
1732
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1730

def promotion_code
  @promotion_code
end