Class: Stripe::SubscriptionScheduleService::AmendParams::Amendment::ItemAction::Add

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Defined Under Namespace

Classes: Discount, Trial

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Add

Returns a new instance of Add.



1824
1825
1826
1827
1828
1829
1830
1831
1832
1833
1834
1835
1836
1837
1838
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1824

def initialize(
  discounts: nil,
  metadata: nil,
  price: nil,
  quantity: nil,
  tax_rates: nil,
  trial: nil
)
  @discounts = discounts
  @metadata = 
  @price = price
  @quantity = quantity
  @tax_rates = tax_rates
  @trial = trial
end

Instance Attribute Details

#discountsObject

The discounts applied to the item. Subscription item discounts are applied before subscription discounts.



1812
1813
1814
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1812

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1814
1815
1816
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1814

def 
  @metadata
end

#priceObject

The ID of the price object.



1816
1817
1818
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1816

def price
  @price
end

#quantityObject

Quantity for this item.



1818
1819
1820
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1818

def quantity
  @quantity
end

#tax_ratesObject

The tax rates that apply to this subscription item. When set, the ‘default_tax_rates` on the subscription do not apply to this `subscription_item`.



1820
1821
1822
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1820

def tax_rates
  @tax_rates
end

#trialObject

Options that configure the trial on the subscription item.



1822
1823
1824
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1822

def trial
  @trial
end