Class: Stripe::SubscriptionScheduleService::AmendParams::Amendment::ItemAction::Add::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1694
1695
1696
1697
1698
1699
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1694

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1686
1687
1688
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1686

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1688
1689
1690
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1688

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1690
1691
1692
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1690

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1692
1693
1694
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1692

def promotion_code
  @promotion_code
end