Class: Stripe::SubscriptionScheduleService::AmendParams::Amendment::TrialSettings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::AmendParams::Amendment::TrialSettings
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Defined Under Namespace
Classes: EndBehavior
Instance Attribute Summary collapse
-
#end_behavior ⇒ Object
Defines how the subscription should behave when a trial ends.
Instance Method Summary collapse
-
#initialize(end_behavior: nil) ⇒ TrialSettings
constructor
A new instance of TrialSettings.
Methods inherited from RequestParams
Constructor Details
#initialize(end_behavior: nil) ⇒ TrialSettings
Returns a new instance of TrialSettings.
1871 1872 1873 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1871 def initialize(end_behavior: nil) @end_behavior = end_behavior end |
Instance Attribute Details
#end_behavior ⇒ Object
Defines how the subscription should behave when a trial ends.
1869 1870 1871 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1869 def end_behavior @end_behavior end |