Class: Stripe::SubscriptionScheduleService::AmendParams::Prebilling
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::AmendParams::Prebilling
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#bill_from ⇒ Object
The beginning of the prebilled time period.
-
#bill_until ⇒ Object
The end of the prebilled time period.
-
#invoice_at ⇒ Object
When the prebilling invoice should be created.
-
#update_behavior ⇒ Object
Whether to cancel or preserve ‘prebilling` if the subscription is updated during the prebilled period.
Instance Method Summary collapse
-
#initialize(bill_from: nil, bill_until: nil, invoice_at: nil, update_behavior: nil) ⇒ Prebilling
constructor
A new instance of Prebilling.
Methods inherited from RequestParams
Constructor Details
#initialize(bill_from: nil, bill_until: nil, invoice_at: nil, update_behavior: nil) ⇒ Prebilling
Returns a new instance of Prebilling.
1991 1992 1993 1994 1995 1996 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1991 def initialize(bill_from: nil, bill_until: nil, invoice_at: nil, update_behavior: nil) @bill_from = bill_from @bill_until = bill_until @invoice_at = invoice_at @update_behavior = update_behavior end |
Instance Attribute Details
#bill_from ⇒ Object
The beginning of the prebilled time period. The default value is ‘now`.
1983 1984 1985 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1983 def bill_from @bill_from end |
#bill_until ⇒ Object
The end of the prebilled time period.
1985 1986 1987 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1985 def bill_until @bill_until end |
#invoice_at ⇒ Object
When the prebilling invoice should be created. The default value is ‘now`.
1987 1988 1989 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1987 def invoice_at @invoice_at end |
#update_behavior ⇒ Object
Whether to cancel or preserve ‘prebilling` if the subscription is updated during the prebilled period. The default value is `reset`.
1989 1990 1991 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1989 def update_behavior @update_behavior end |