Class: Stripe::SubscriptionScheduleService::AmendParams::Prebilling::BillFrom
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::AmendParams::Prebilling::BillFrom
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Defined Under Namespace
Classes: AmendmentStart
Instance Attribute Summary collapse
-
#amendment_start ⇒ Object
Start the prebilled period when a specified amendment begins.
-
#timestamp ⇒ Object
Start the prebilled period at a precise integer timestamp, starting from the Unix epoch.
-
#type ⇒ Object
Select one of several ways to pass the ‘bill_from` value.
Instance Method Summary collapse
-
#initialize(amendment_start: nil, timestamp: nil, type: nil) ⇒ BillFrom
constructor
A new instance of BillFrom.
Methods inherited from RequestParams
Constructor Details
#initialize(amendment_start: nil, timestamp: nil, type: nil) ⇒ BillFrom
Returns a new instance of BillFrom.
2068 2069 2070 2071 2072 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2068 def initialize(amendment_start: nil, timestamp: nil, type: nil) @amendment_start = amendment_start @timestamp = @type = type end |
Instance Attribute Details
#amendment_start ⇒ Object
Start the prebilled period when a specified amendment begins.
2062 2063 2064 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2062 def amendment_start @amendment_start end |
#timestamp ⇒ Object
Start the prebilled period at a precise integer timestamp, starting from the Unix epoch.
2064 2065 2066 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2064 def @timestamp end |
#type ⇒ Object
Select one of several ways to pass the ‘bill_from` value.
2066 2067 2068 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2066 def type @type end |