Class: Stripe::SubscriptionScheduleService::AmendParams::Prebilling::BillUntil
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::AmendParams::Prebilling::BillUntil
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Defined Under Namespace
Classes: AmendmentEnd, Duration
Instance Attribute Summary collapse
-
#amendment_end ⇒ Object
End the prebilled period when a specified amendment ends.
-
#duration ⇒ Object
Time span for prebilling, starting from ‘bill_from`.
-
#timestamp ⇒ Object
End the prebilled period at a precise integer timestamp, starting from the Unix epoch.
-
#type ⇒ Object
Select one of several ways to pass the ‘bill_until` value.
Instance Method Summary collapse
-
#initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ BillUntil
constructor
A new instance of BillUntil.
Methods inherited from RequestParams
Constructor Details
#initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ BillUntil
Returns a new instance of BillUntil.
2105 2106 2107 2108 2109 2110 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2105 def initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil) @amendment_end = amendment_end @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#amendment_end ⇒ Object
End the prebilled period when a specified amendment ends.
2097 2098 2099 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2097 def amendment_end @amendment_end end |
#duration ⇒ Object
Time span for prebilling, starting from ‘bill_from`.
2099 2100 2101 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2099 def duration @duration end |
#timestamp ⇒ Object
End the prebilled period at a precise integer timestamp, starting from the Unix epoch.
2101 2102 2103 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2101 def @timestamp end |
#type ⇒ Object
Select one of several ways to pass the ‘bill_until` value.
2103 2104 2105 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2103 def type @type end |