Class: Stripe::SubscriptionScheduleService::AmendParams::Prebilling::BillUntil::Duration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(interval: nil, interval_count: nil) ⇒ Duration

Returns a new instance of Duration.



1993
1994
1995
1996
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1993

def initialize(interval: nil, interval_count: nil)
  @interval = interval
  @interval_count = interval_count
end

Instance Attribute Details

#intervalObject

Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.



1989
1990
1991
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1989

def interval
  @interval
end

#interval_countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



1991
1992
1993
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1991

def interval_count
  @interval_count
end