Class: Stripe::SubscriptionScheduleService::AmendParams::ScheduleSettings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::AmendParams::ScheduleSettings
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Instance Attribute Summary collapse
-
#end_behavior ⇒ Object
Behavior of the subscription schedule and underlying subscription when it ends.
Instance Method Summary collapse
-
#initialize(end_behavior: nil) ⇒ ScheduleSettings
constructor
A new instance of ScheduleSettings.
Methods inherited from RequestParams
Constructor Details
#initialize(end_behavior: nil) ⇒ ScheduleSettings
Returns a new instance of ScheduleSettings.
2133 2134 2135 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2133 def initialize(end_behavior: nil) @end_behavior = end_behavior end |
Instance Attribute Details
#end_behavior ⇒ Object
Behavior of the subscription schedule and underlying subscription when it ends.
2131 2132 2133 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2131 def end_behavior @end_behavior end |