Class: Stripe::SubscriptionScheduleService::CancelParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, invoice_now: nil, prorate: nil) ⇒ CancelParams

Returns a new instance of CancelParams.



2172
2173
2174
2175
2176
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2172

def initialize(expand: nil, invoice_now: nil, prorate: nil)
  @expand = expand
  @invoice_now = invoice_now
  @prorate = prorate
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



2166
2167
2168
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2166

def expand
  @expand
end

#invoice_nowObject

If the subscription schedule is ‘active`, indicates if a final invoice will be generated that contains any un-invoiced metered usage and new/pending proration invoice items. Defaults to `true`.



2168
2169
2170
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2168

def invoice_now
  @invoice_now
end

#prorateObject

If the subscription schedule is ‘active`, indicates if the cancellation should be prorated. Defaults to `true`.



2170
2171
2172
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2170

def prorate
  @prorate
end