Class: Stripe::SubscriptionScheduleService::CreateParams::Phase::AddInvoiceItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



238
239
240
241
242
# File 'lib/stripe/services/subscription_schedule_service.rb', line 238

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



232
233
234
# File 'lib/stripe/services/subscription_schedule_service.rb', line 232

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



234
235
236
# File 'lib/stripe/services/subscription_schedule_service.rb', line 234

def discount
  @discount
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



236
237
238
# File 'lib/stripe/services/subscription_schedule_service.rb', line 236

def promotion_code
  @promotion_code
end