Class: Stripe::SubscriptionScheduleService::CreateParams::Phase::AddInvoiceItem::Period::End

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(timestamp: nil, type: nil) ⇒ End

Returns a new instance of End.



309
310
311
312
# File 'lib/stripe/services/subscription_schedule_service.rb', line 309

def initialize(timestamp: nil, type: nil)
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#timestampObject

A precise Unix timestamp for the end of the invoice item period. Must be greater than or equal to ‘period.start`.



305
306
307
# File 'lib/stripe/services/subscription_schedule_service.rb', line 305

def timestamp
  @timestamp
end

#typeObject

Select how to calculate the end of the invoice item period.



307
308
309
# File 'lib/stripe/services/subscription_schedule_service.rb', line 307

def type
  @type
end