Class: Stripe::SubscriptionScheduleService::CreateParams::Phase::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::CreateParams::Phase::Discount
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
408 409 410 411 412 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 408 def initialize(coupon: nil, discount: nil, promotion_code: nil) @coupon = coupon @discount = discount @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
402 403 404 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 402 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
404 405 406 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 404 def discount @discount end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
406 407 408 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 406 def promotion_code @promotion_code end |