Class: Stripe::SubscriptionScheduleService::CreateParams::Phase::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



452
453
454
455
456
# File 'lib/stripe/services/subscription_schedule_service.rb', line 452

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



446
447
448
# File 'lib/stripe/services/subscription_schedule_service.rb', line 446

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



448
449
450
# File 'lib/stripe/services/subscription_schedule_service.rb', line 448

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



450
451
452
# File 'lib/stripe/services/subscription_schedule_service.rb', line 450

def type
  @type
end