Class: Stripe::SubscriptionScheduleService::CreateParams::Phase::Item::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::CreateParams::Phase::Item::Discount
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
553 554 555 556 557 558 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 553 def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
542 543 544 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 542 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
545 546 547 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 545 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
548 549 550 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 548 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
551 552 553 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 551 def promotion_code @promotion_code end |