Class: Stripe::SubscriptionScheduleService::CreateParams::Phase::Item::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::CreateParams::Phase::Item::Discount::DiscountEnd
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
535 536 537 538 539 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 535 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
527 528 529 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 527 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
530 531 532 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 530 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
533 534 535 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 533 def type @type end |