Class: Stripe::SubscriptionScheduleService::CreateParams::Prebilling
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::CreateParams::Prebilling
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Instance Attribute Summary collapse
-
#iterations ⇒ Object
This is used to determine the number of billing cycles to prebill.
-
#update_behavior ⇒ Object
Whether to cancel or preserve ‘prebilling` if the subscription is updated during the prebilled period.
Instance Method Summary collapse
-
#initialize(iterations: nil, update_behavior: nil) ⇒ Prebilling
constructor
A new instance of Prebilling.
Methods inherited from RequestParams
Constructor Details
#initialize(iterations: nil, update_behavior: nil) ⇒ Prebilling
Returns a new instance of Prebilling.
691 692 693 694 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 691 def initialize(iterations: nil, update_behavior: nil) @iterations = iterations @update_behavior = update_behavior end |
Instance Attribute Details
#iterations ⇒ Object
This is used to determine the number of billing cycles to prebill.
687 688 689 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 687 def iterations @iterations end |
#update_behavior ⇒ Object
Whether to cancel or preserve ‘prebilling` if the subscription is updated during the prebilled period. The default value is `reset`.
689 690 691 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 689 def update_behavior @update_behavior end |