Class: Stripe::SubscriptionScheduleService::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::ListParams
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Defined Under Namespace
Classes: CanceledAt, CompletedAt, Created, ReleasedAt
Instance Attribute Summary collapse
-
#canceled_at ⇒ Object
Only return subscription schedules that were created canceled the given date interval.
-
#completed_at ⇒ Object
Only return subscription schedules that completed during the given date interval.
-
#created ⇒ Object
Only return subscription schedules that were created during the given date interval.
-
#customer ⇒ Object
Only return subscription schedules for the given customer.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#released_at ⇒ Object
Only return subscription schedules that were released during the given date interval.
-
#scheduled ⇒ Object
Only return subscription schedules that have not started yet.
-
#starting_after ⇒ Object
A cursor for use in pagination.
Instance Method Summary collapse
-
#initialize(canceled_at: nil, completed_at: nil, created: nil, customer: nil, ending_before: nil, expand: nil, limit: nil, released_at: nil, scheduled: nil, starting_after: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(canceled_at: nil, completed_at: nil, created: nil, customer: nil, ending_before: nil, expand: nil, limit: nil, released_at: nil, scheduled: nil, starting_after: nil) ⇒ ListParams
Returns a new instance of ListParams.
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 120 def initialize( canceled_at: nil, completed_at: nil, created: nil, customer: nil, ending_before: nil, expand: nil, limit: nil, released_at: nil, scheduled: nil, starting_after: nil ) @canceled_at = canceled_at @completed_at = completed_at @created = created @customer = customer @ending_before = ending_before @expand = @limit = limit @released_at = released_at @scheduled = scheduled @starting_after = starting_after end |
Instance Attribute Details
#canceled_at ⇒ Object
Only return subscription schedules that were created canceled the given date interval.
91 92 93 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 91 def canceled_at @canceled_at end |
#completed_at ⇒ Object
Only return subscription schedules that completed during the given date interval.
94 95 96 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 94 def completed_at @completed_at end |
#created ⇒ Object
Only return subscription schedules that were created during the given date interval.
97 98 99 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 97 def created @created end |
#customer ⇒ Object
Only return subscription schedules for the given customer.
100 101 102 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 100 def customer @customer end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
103 104 105 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 103 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
106 107 108 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 106 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
109 110 111 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 109 def limit @limit end |
#released_at ⇒ Object
Only return subscription schedules that were released during the given date interval.
112 113 114 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 112 def released_at @released_at end |
#scheduled ⇒ Object
Only return subscription schedules that have not started yet.
115 116 117 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 115 def scheduled @scheduled end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
118 119 120 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 118 def starting_after @starting_after end |