Class: Stripe::SubscriptionScheduleService::ReleaseParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, preserve_cancel_date: nil) ⇒ ReleaseParams

Returns a new instance of ReleaseParams.



2185
2186
2187
2188
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2185

def initialize(expand: nil, preserve_cancel_date: nil)
  @expand = expand
  @preserve_cancel_date = preserve_cancel_date
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



2181
2182
2183
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2181

def expand
  @expand
end

#preserve_cancel_dateObject

Keep any cancellation on the subscription that the schedule has set



2183
2184
2185
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2183

def preserve_cancel_date
  @preserve_cancel_date
end