Class: Stripe::SubscriptionScheduleService::UpdateParams::DefaultSettings::InvoiceSettings

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Defined Under Namespace

Classes: Issuer

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_tax_ids: nil, days_until_due: nil, issuer: nil) ⇒ InvoiceSettings

Returns a new instance of InvoiceSettings.



803
804
805
806
807
# File 'lib/stripe/services/subscription_schedule_service.rb', line 803

def initialize(account_tax_ids: nil, days_until_due: nil, issuer: nil)
  @account_tax_ids = 
  @days_until_due = days_until_due
  @issuer = issuer
end

Instance Attribute Details

#account_tax_idsObject

The account tax IDs associated with the subscription schedule. Will be set on invoices generated by the subscription schedule.



797
798
799
# File 'lib/stripe/services/subscription_schedule_service.rb', line 797

def 
  @account_tax_ids
end

#days_until_dueObject

Number of days within which a customer must pay invoices generated by this subscription schedule. This value will be ‘null` for subscription schedules where `collection_method=charge_automatically`.



799
800
801
# File 'lib/stripe/services/subscription_schedule_service.rb', line 799

def days_until_due
  @days_until_due
end

#issuerObject

The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.



801
802
803
# File 'lib/stripe/services/subscription_schedule_service.rb', line 801

def issuer
  @issuer
end