Class: Stripe::SubscriptionScheduleService::UpdateParams::Phase::AddInvoiceItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



1020
1021
1022
1023
1024
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1020

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



1014
1015
1016
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1014

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



1016
1017
1018
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1016

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



1018
1019
1020
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1018

def type
  @type
end