Class: Stripe::SubscriptionScheduleService::UpdateParams::Phase::AddInvoiceItem::Period::End
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::UpdateParams::Phase::AddInvoiceItem::Period::End
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Instance Attribute Summary collapse
-
#timestamp ⇒ Object
A precise Unix timestamp for the end of the invoice item period.
-
#type ⇒ Object
Select how to calculate the end of the invoice item period.
Instance Method Summary collapse
-
#initialize(timestamp: nil, type: nil) ⇒ End
constructor
A new instance of End.
Methods inherited from RequestParams
Constructor Details
#initialize(timestamp: nil, type: nil) ⇒ End
Returns a new instance of End.
1050 1051 1052 1053 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1050 def initialize(timestamp: nil, type: nil) @timestamp = @type = type end |
Instance Attribute Details
#timestamp ⇒ Object
A precise Unix timestamp for the end of the invoice item period. Must be greater than or equal to ‘period.start`.
1046 1047 1048 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1046 def @timestamp end |
#type ⇒ Object
Select how to calculate the end of the invoice item period.
1048 1049 1050 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1048 def type @type end |