Class: Stripe::SubscriptionScheduleService::UpdateParams::Phase::BillingThresholds
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::UpdateParams::Phase::BillingThresholds
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Instance Attribute Summary collapse
-
#amount_gte ⇒ Object
Monetary threshold that triggers the subscription to advance to a new billing period.
-
#reset_billing_cycle_anchor ⇒ Object
Indicates if the ‘billing_cycle_anchor` should be reset when a threshold is reached.
Instance Method Summary collapse
-
#initialize(amount_gte: nil, reset_billing_cycle_anchor: nil) ⇒ BillingThresholds
constructor
A new instance of BillingThresholds.
Methods inherited from RequestParams
Constructor Details
#initialize(amount_gte: nil, reset_billing_cycle_anchor: nil) ⇒ BillingThresholds
Returns a new instance of BillingThresholds.
973 974 975 976 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 973 def initialize(amount_gte: nil, reset_billing_cycle_anchor: nil) @amount_gte = amount_gte @reset_billing_cycle_anchor = reset_billing_cycle_anchor end |
Instance Attribute Details
#amount_gte ⇒ Object
Monetary threshold that triggers the subscription to advance to a new billing period
969 970 971 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 969 def amount_gte @amount_gte end |
#reset_billing_cycle_anchor ⇒ Object
Indicates if the ‘billing_cycle_anchor` should be reset when a threshold is reached. If true, `billing_cycle_anchor` will be updated to the date/time the threshold was last reached; otherwise, the value will remain unchanged.
971 972 973 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 971 def reset_billing_cycle_anchor @reset_billing_cycle_anchor end |