Class: Stripe::SubscriptionScheduleService::UpdateParams::Phase::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::UpdateParams::Phase::Discount
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
1012 1013 1014 1015 1016 1017 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1012 def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
1004 1005 1006 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1004 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
1006 1007 1008 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1006 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
1008 1009 1010 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1008 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
1010 1011 1012 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1010 def promotion_code @promotion_code end |