Class: Stripe::SubscriptionScheduleService::UpdateParams::Phase::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



1070
1071
1072
1073
1074
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1070

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



1064
1065
1066
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1064

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



1066
1067
1068
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1066

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



1068
1069
1070
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1068

def type
  @type
end