Class: Stripe::SubscriptionScheduleService::UpdateParams::Phase::Item::BillingThresholds
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::UpdateParams::Phase::Item::BillingThresholds
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Instance Attribute Summary collapse
-
#usage_gte ⇒ Object
Number of units that meets the billing threshold to advance the subscription to a new billing period (e.g., it takes 10 $5 units to meet a $50 [monetary threshold](stripe.com/docs/api/subscriptions/update#update_subscription-billing_thresholds-amount_gte)).
Instance Method Summary collapse
-
#initialize(usage_gte: nil) ⇒ BillingThresholds
constructor
A new instance of BillingThresholds.
Methods inherited from RequestParams
Constructor Details
#initialize(usage_gte: nil) ⇒ BillingThresholds
Returns a new instance of BillingThresholds.
1037 1038 1039 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1037 def initialize(usage_gte: nil) @usage_gte = usage_gte end |
Instance Attribute Details
#usage_gte ⇒ Object
Number of units that meets the billing threshold to advance the subscription to a new billing period (e.g., it takes 10 $5 units to meet a $50 [monetary threshold](stripe.com/docs/api/subscriptions/update#update_subscription-billing_thresholds-amount_gte))
1035 1036 1037 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1035 def usage_gte @usage_gte end |