Class: Stripe::SubscriptionScheduleService::UpdateParams::Phase::Item::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1050
1051
1052
1053
1054
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1050

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1044
1045
1046
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1044

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1046
1047
1048
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1046

def discount
  @discount
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1048
1049
1050
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1048

def promotion_code
  @promotion_code
end