Class: Stripe::SubscriptionScheduleService::UpdateParams::Phase::Item::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::UpdateParams::Phase::Item::Discount::DiscountEnd
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
1141 1142 1143 1144 1145 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1141 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
1135 1136 1137 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1135 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
1137 1138 1139 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1137 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
1139 1140 1141 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1139 def type @type end |