Class: Stripe::SubscriptionScheduleUpdateParams::BillingSchedule::BillUntil
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleUpdateParams::BillingSchedule::BillUntil
- Defined in:
- lib/stripe/params/subscription_schedule_update_params.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Specifies the billing period.
-
#timestamp ⇒ Object
The end date of the billing schedule.
-
#type ⇒ Object
Describes how the billing schedule will determine the end date.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ BillUntil
constructor
A new instance of BillUntil.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ BillUntil
Returns a new instance of BillUntil.
38 39 40 41 42 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 38 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Specifies the billing period.
32 33 34 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 32 def duration @duration end |
#timestamp ⇒ Object
The end date of the billing schedule.
34 35 36 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 34 def @timestamp end |
#type ⇒ Object
Describes how the billing schedule will determine the end date. Either ‘duration` or `timestamp`.
36 37 38 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 36 def type @type end |