Class: Stripe::SubscriptionScheduleUpdateParams::PauseSchedule::Pause::Settings::BillFor
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleUpdateParams::PauseSchedule::Pause::Settings::BillFor
- Defined in:
- lib/stripe/params/subscription_schedule_update_params.rb
Defined Under Namespace
Classes: OutstandingUsageThrough, UnusedTimeFrom
Instance Attribute Summary collapse
-
#outstanding_usage_through ⇒ Object
Controls whether to collect metered usage accrued up to the pause date.
-
#unused_time_from ⇒ Object
Controls how unused time on subscription items is credited when pausing.
Instance Method Summary collapse
-
#initialize(outstanding_usage_through: nil, unused_time_from: nil) ⇒ BillFor
constructor
A new instance of BillFor.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(outstanding_usage_through: nil, unused_time_from: nil) ⇒ BillFor
Returns a new instance of BillFor.
247 248 249 250 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 247 def initialize(outstanding_usage_through: nil, unused_time_from: nil) @outstanding_usage_through = outstanding_usage_through @unused_time_from = unused_time_from end |
Instance Attribute Details
#outstanding_usage_through ⇒ Object
Controls whether to collect metered usage accrued up to the pause date.
243 244 245 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 243 def outstanding_usage_through @outstanding_usage_through end |
#unused_time_from ⇒ Object
Controls how unused time on subscription items is credited when pausing.
245 246 247 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 245 def unused_time_from @unused_time_from end |