Class: Stripe::SubscriptionScheduleUpdateParams::PauseSchedule::Resume::ResumeAt

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_update_params.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ ResumeAt

Returns a new instance of ResumeAt.



240
241
242
243
244
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 240

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#duration ⇒ Object

The duration after which to resume the subscription. Required when type is duration.



234
235
236
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 234

def duration
  @duration
end

#timestamp ⇒ Object

The Unix timestamp at which to resume the subscription. Required when type is timestamp.



236
237
238
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 236

def timestamp
  @timestamp
end

#type ⇒ Object

When to resume the subscription. Use now to resume immediately, duration to resume after a set duration, or timestamp to resume at a specific time.



238
239
240
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 238

def type
  @type
end