Class: Stripe::SubscriptionScheduleUpdateParams::PauseSchedule::Resume::Settings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleUpdateParams::PauseSchedule::Resume::Settings
- Defined in:
- lib/stripe/params/subscription_schedule_update_params.rb
Instance Attribute Summary collapse
-
#billing_cycle_anchor ⇒ Object
Controls the billing cycle anchor when the subscription resumes.
-
#payment_behavior ⇒ Object
Controls whether Stripe attempts payment on the resumption invoice and how payment affects the subscription's status.
-
#proration_behavior ⇒ Object
Determines how to handle prorations when the subscription resumes.
Instance Method Summary collapse
-
#initialize(billing_cycle_anchor: nil, payment_behavior: nil, proration_behavior: nil) ⇒ Settings
constructor
A new instance of Settings.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(billing_cycle_anchor: nil, payment_behavior: nil, proration_behavior: nil) ⇒ Settings
255 256 257 258 259 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 255 def initialize(billing_cycle_anchor: nil, payment_behavior: nil, proration_behavior: nil) @billing_cycle_anchor = billing_cycle_anchor @payment_behavior = payment_behavior @proration_behavior = proration_behavior end |
Instance Attribute Details
#billing_cycle_anchor ⇒ Object
Controls the billing cycle anchor when the subscription resumes. When adding a pause schedule, defaults to resume_at. On updates, the existing value is preserved if not provided.
249 250 251 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 249 def billing_cycle_anchor @billing_cycle_anchor end |
#payment_behavior ⇒ Object
Controls whether Stripe attempts payment on the resumption invoice and how payment affects the subscription's status. When adding a pause schedule, defaults to resume_on_payment_success. On updates, the existing value is preserved if not provided.
251 252 253 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 251 def payment_behavior @payment_behavior end |
#proration_behavior ⇒ Object
Determines how to handle prorations when the subscription resumes. When adding a pause schedule, defaults to create_prorations. On updates, the existing value is preserved if not provided.
253 254 255 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 253 def proration_behavior @proration_behavior end |