Class: Stripe::SubscriptionScheduleUpdateParams::Phase

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_update_params.rb

Defined Under Namespace

Classes: AddInvoiceItem, AutomaticTax, BillingThresholds, Discount, Duration, InvoiceSettings, Item, PauseCollection, TransferData, TrialSettings

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(add_invoice_items: nil, application_fee_percent: nil, automatic_tax: nil, billing_cycle_anchor: nil, billing_thresholds: nil, collection_method: nil, currency: nil, default_payment_method: nil, default_tax_rates: nil, description: nil, discounts: nil, duration: nil, effective_at: nil, end_date: nil, invoice_settings: nil, items: nil, metadata: nil, on_behalf_of: nil, pause_collection: nil, proration_behavior: nil, start_date: nil, transfer_data: nil, trial: nil, trial_continuation: nil, trial_end: nil, trial_settings: nil) ⇒ Phase

Returns a new instance of Phase.



995
996
997
998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 995

def initialize(
  add_invoice_items: nil,
  application_fee_percent: nil,
  automatic_tax: nil,
  billing_cycle_anchor: nil,
  billing_thresholds: nil,
  collection_method: nil,
  currency: nil,
  default_payment_method: nil,
  default_tax_rates: nil,
  description: nil,
  discounts: nil,
  duration: nil,
  effective_at: nil,
  end_date: nil,
  invoice_settings: nil,
  items: nil,
  metadata: nil,
  on_behalf_of: nil,
  pause_collection: nil,
  proration_behavior: nil,
  start_date: nil,
  transfer_data: nil,
  trial: nil,
  trial_continuation: nil,
  trial_end: nil,
  trial_settings: nil
)
  @add_invoice_items = add_invoice_items
  @application_fee_percent = application_fee_percent
  @automatic_tax = automatic_tax
  @billing_cycle_anchor = billing_cycle_anchor
  @billing_thresholds = billing_thresholds
  @collection_method = collection_method
  @currency = currency
  @default_payment_method = default_payment_method
  @default_tax_rates = default_tax_rates
  @description = description
  @discounts = discounts
  @duration = duration
  @effective_at = effective_at
  @end_date = end_date
  @invoice_settings = invoice_settings
  @items = items
  @metadata = 
  @on_behalf_of = on_behalf_of
  @pause_collection = pause_collection
  @proration_behavior = proration_behavior
  @start_date = start_date
  @transfer_data = transfer_data
  @trial = trial
  @trial_continuation = trial_continuation
  @trial_end = trial_end
  @trial_settings = trial_settings
end

Instance Attribute Details

#add_invoice_itemsObject

A list of prices and quantities that will generate invoice items appended to the next invoice for this phase. You may pass up to 20 items.



943
944
945
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 943

def add_invoice_items
  @add_invoice_items
end

#application_fee_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the application owner's Stripe account. The request must be made by a platform account on a connected account in order to set an application fee percentage. For more information, see the application fees documentation.



945
946
947
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 945

def application_fee_percent
  @application_fee_percent
end

#automatic_taxObject

Automatic tax settings for this phase.



947
948
949
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 947

def automatic_tax
  @automatic_tax
end

#billing_cycle_anchorObject

Can be set to phase_start to set the anchor to the start of the phase or automatic to automatically change it if needed. Cannot be set to phase_start if this phase specifies a trial. For more information, see the billing cycle documentation.



949
950
951
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 949

def billing_cycle_anchor
  @billing_cycle_anchor
end

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.



951
952
953
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 951

def billing_thresholds
  @billing_thresholds
end

#collection_methodObject

Either charge_automatically, or send_invoice. When charging automatically, Stripe will attempt to pay the underlying subscription at the end of each billing cycle using the default source attached to the customer. When sending an invoice, Stripe will email your customer an invoice with payment instructions and mark the subscription as active. Defaults to charge_automatically on creation.



953
954
955
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 953

def collection_method
  @collection_method
end

#currencyObject

Three-letter ISO currency code, in lowercase. Must be a supported currency.



955
956
957
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 955

def currency
  @currency
end

#default_payment_methodObject

ID of the default payment method for the subscription schedule. It must belong to the customer associated with the subscription schedule. If not set, invoices will use the default payment method in the customer's invoice settings.



957
958
959
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 957

def default_payment_method
  @default_payment_method
end

#default_tax_ratesObject

A list of Tax Rate ids. These Tax Rates will set the Subscription's default_tax_rates, which means they will be the Invoice's default_tax_rates for any Invoices issued by the Subscription during this Phase.



959
960
961
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 959

def default_tax_rates
  @default_tax_rates
end

#descriptionObject

Subscription description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.



961
962
963
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 961

def description
  @description
end

#discountsObject

The coupons to redeem into discounts for the schedule phase. If not specified, inherits the discount from the subscription's customer. Pass an empty string to avoid inheriting any discounts.



963
964
965
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 963

def discounts
  @discounts
end

#durationObject

The number of intervals the phase should last. If set, end_date must not be set.



965
966
967
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 965

def duration
  @duration
end

#effective_atObject

Configures how the subscription schedule handles billing for phase transitions.



967
968
969
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 967

def effective_at
  @effective_at
end

#end_dateObject

The date at which this phase of the subscription schedule ends. If set, duration must not be set.



969
970
971
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 969

def end_date
  @end_date
end

#invoice_settingsObject

All invoices will be billed using the specified settings.



971
972
973
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 971

def invoice_settings
  @invoice_settings
end

#itemsObject

List of configuration items, each with an attached price, to apply during this phase of the subscription schedule.



973
974
975
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 973

def items
  @items
end

#metadataObject

Set of key-value pairs that you can attach to a phase. Metadata on a schedule's phase will update the underlying subscription's metadata when the phase is entered, adding new keys and replacing existing keys in the subscription's metadata. Individual keys in the subscription's metadata can be unset by posting an empty value to them in the phase's metadata. To unset all keys in the subscription's metadata, update the subscription directly or unset every key individually from the phase's metadata.



975
976
977
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 975

def 
  @metadata
end

#on_behalf_ofObject

The account on behalf of which to charge, for each of the associated subscription's invoices.



977
978
979
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 977

def on_behalf_of
  @on_behalf_of
end

#pause_collectionObject

If specified, payment collection for this subscription will be paused. Note that the subscription status will be unchanged and will not be updated to paused. Learn more about pausing collection.



979
980
981
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 979

def pause_collection
  @pause_collection
end

#proration_behaviorObject

Controls whether the subscription schedule should create prorations when transitioning to this phase if there is a difference in billing configuration. It's different from the request-level proration_behavior parameter which controls what happens if the update request affects the billing configuration (item price, quantity, etc.) of the current phase.



981
982
983
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 981

def proration_behavior
  @proration_behavior
end

#start_dateObject

The date at which this phase of the subscription schedule starts or now. Must be set on the first phase. Prefer to specify now over an explicit timestamp when appropriate to avoid unexpected behavior due to request delays or clock skew resulting in the phase being slightly backdated or postdated.



983
984
985
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 983

def start_date
  @start_date
end

#transfer_dataObject

The data with which to automatically create a Transfer for each of the associated subscription's invoices.



985
986
987
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 985

def transfer_data
  @transfer_data
end

#trialObject

If set to true the entire phase is counted as a trial and the customer will not be charged for any fees.



987
988
989
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 987

def trial
  @trial
end

#trial_continuationObject

Specify trial behavior when crossing phase boundaries



989
990
991
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 989

def trial_continuation
  @trial_continuation
end

#trial_endObject

Sets the phase to trialing from the start date to this date. Must be within the phase. When combined with trial=true, it must match the phase end date.



991
992
993
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 991

def trial_end
  @trial_end
end

#trial_settingsObject

Settings related to subscription trials.



993
994
995
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 993

def trial_settings
  @trial_settings
end

Class Method Details

.field_encodingsObject



1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 1051

def self.field_encodings
  @field_encodings = {
    add_invoice_items: {
      kind: :array,
      element: {
        kind: :object,
        fields: { price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } } },
      },
    },
    items: {
      kind: :array,
      element: {
        kind: :object,
        fields: { price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } } },
      },
    },
  }
end