Class: Stripe::SubscriptionScheduleUpdateParams::Phase::AddInvoiceItem::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleUpdateParams::Phase::AddInvoiceItem::Discount
- Defined in:
- lib/stripe/params/subscription_schedule_update_params.rb
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
163 164 165 166 167 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 163 def initialize(coupon: nil, discount: nil, promotion_code: nil) @coupon = coupon @discount = discount @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
157 158 159 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 157 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
159 160 161 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 159 def discount @discount end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
161 162 163 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 161 def promotion_code @promotion_code end |