Class: Stripe::SubscriptionScheduleUpdateParams::Phase::AddInvoiceItem::Period::End

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(timestamp: nil, type: nil) ⇒ End

Returns a new instance of End.



205
206
207
208
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 205

def initialize(timestamp: nil, type: nil)
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#timestampObject

A precise Unix timestamp for the end of the invoice item period. Must be greater than or equal to period.start.



201
202
203
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 201

def timestamp
  @timestamp
end

#typeObject

Select how to calculate the end of the invoice item period.



203
204
205
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 203

def type
  @type
end