Class: Stripe::SubscriptionScheduleUpdateParams::Phase::AddInvoiceItem::Period::Start
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleUpdateParams::Phase::AddInvoiceItem::Period::Start
- Defined in:
- lib/stripe/params/subscription_schedule_update_params.rb
Instance Attribute Summary collapse
-
#timestamp ⇒ Object
A precise Unix timestamp for the start of the invoice item period.
-
#type ⇒ Object
Select how to calculate the start of the invoice item period.
Instance Method Summary collapse
-
#initialize(timestamp: nil, type: nil) ⇒ Start
constructor
A new instance of Start.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(timestamp: nil, type: nil) ⇒ Start
Returns a new instance of Start.
217 218 219 220 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 217 def initialize(timestamp: nil, type: nil) @timestamp = @type = type end |
Instance Attribute Details
#timestamp ⇒ Object
A precise Unix timestamp for the start of the invoice item period. Must be less than or equal to period.end.
213 214 215 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 213 def @timestamp end |
#type ⇒ Object
Select how to calculate the start of the invoice item period.
215 216 217 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 215 def type @type end |