Class: Stripe::SubscriptionScheduleUpdateParams::Phase::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleUpdateParams::Phase::Discount
- Defined in:
- lib/stripe/params/subscription_schedule_update_params.rb
Defined Under Namespace
Classes: DiscountEnd, Settings
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
-
#settings ⇒ Object
Settings for discount application including service period anchoring.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil, settings: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil, settings: nil) ⇒ Discount
Returns a new instance of Discount.
610 611 612 613 614 615 616 617 618 619 620 621 622 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 610 def initialize( coupon: nil, discount: nil, discount_end: nil, promotion_code: nil, settings: nil ) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code @settings = settings end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
600 601 602 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 600 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
602 603 604 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 602 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
604 605 606 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 604 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
606 607 608 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 606 def promotion_code @promotion_code end |
#settings ⇒ Object
Settings for discount application including service period anchoring.
608 609 610 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 608 def settings @settings end |