Class: Stripe::SubscriptionScheduleUpdateParams::Phase::Discount::Settings::ServicePeriodAnchorConfig::Custom
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleUpdateParams::Phase::Discount::Settings::ServicePeriodAnchorConfig::Custom
- Defined in:
- lib/stripe/params/subscription_schedule_update_params.rb
Instance Attribute Summary collapse
-
#day_of_month ⇒ Object
The day of the month the anchor should be.
-
#hour ⇒ Object
The hour of the day the anchor should be.
-
#minute ⇒ Object
The minute of the hour the anchor should be.
-
#month ⇒ Object
The month to start full cycle periods.
-
#second ⇒ Object
The second of the minute the anchor should be.
Instance Method Summary collapse
-
#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom
constructor
A new instance of Custom.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom
Returns a new instance of Custom.
571 572 573 574 575 576 577 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 571 def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) @day_of_month = day_of_month @hour = hour @minute = minute @month = month @second = second end |
Instance Attribute Details
#day_of_month ⇒ Object
The day of the month the anchor should be. Ranges from 1 to 31.
561 562 563 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 561 def day_of_month @day_of_month end |
#hour ⇒ Object
The hour of the day the anchor should be. Ranges from 0 to 23.
563 564 565 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 563 def hour @hour end |
#minute ⇒ Object
The minute of the hour the anchor should be. Ranges from 0 to 59.
565 566 567 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 565 def minute @minute end |
#month ⇒ Object
The month to start full cycle periods. Ranges from 1 to 12.
567 568 569 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 567 def month @month end |
#second ⇒ Object
The second of the minute the anchor should be. Ranges from 0 to 59.
569 570 571 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 569 def second @second end |