Class: Stripe::SubscriptionScheduleUpdateParams::Phase::Item::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleUpdateParams::Phase::Item::Discount::DiscountEnd
- Defined in:
- lib/stripe/params/subscription_schedule_update_params.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
421 422 423 424 425 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 421 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
415 416 417 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 415 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
417 418 419 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 417 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
419 420 421 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 419 def type @type end |