Class: Stripe::SubscriptionScheduleUpdateParams::Phase::Item::Discount::Settings::ServicePeriodAnchorConfig::Custom

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom

Returns a new instance of Custom.



742
743
744
745
746
747
748
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 742

def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil)
  @day_of_month = day_of_month
  @hour = hour
  @minute = minute
  @month = month
  @second = second
end

Instance Attribute Details

#day_of_monthObject

The day of the month the anchor should be. Ranges from 1 to 31.



732
733
734
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 732

def day_of_month
  @day_of_month
end

#hourObject

The hour of the day the anchor should be. Ranges from 0 to 23.



734
735
736
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 734

def hour
  @hour
end

#minuteObject

The minute of the hour the anchor should be. Ranges from 0 to 59.



736
737
738
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 736

def minute
  @minute
end

#monthObject

The month to start full cycle periods. Ranges from 1 to 12.



738
739
740
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 738

def month
  @month
end

#secondObject

The second of the minute the anchor should be. Ranges from 0 to 59.



740
741
742
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 740

def second
  @second
end