Class: Stripe::SubscriptionScheduleUpdateParams::Prebilling

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(iterations: nil, update_behavior: nil) ⇒ Prebilling

Returns a new instance of Prebilling.



1077
1078
1079
1080
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 1077

def initialize(iterations: nil, update_behavior: nil)
  @iterations = iterations
  @update_behavior = update_behavior
end

Instance Attribute Details

#iterationsObject

This is used to determine the number of billing cycles to prebill.



1073
1074
1075
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 1073

def iterations
  @iterations
end

#update_behaviorObject

Whether to cancel or preserve prebilling if the subscription is updated during the prebilled period. The default value is reset.



1075
1076
1077
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 1075

def update_behavior
  @update_behavior
end