Class: Stripe::SubscriptionService::CancelParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionService::CancelParams
- Defined in:
- lib/stripe/services/subscription_service.rb
Defined Under Namespace
Classes: CancellationDetails
Instance Attribute Summary collapse
-
#cancellation_details ⇒ Object
Details about why this subscription was cancelled.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#invoice_now ⇒ Object
Will generate a final invoice that invoices for any un-invoiced metered usage and new/pending proration invoice items.
-
#prorate ⇒ Object
Will generate a proration invoice item that credits remaining unused time until the subscription period end.
Instance Method Summary collapse
-
#initialize(cancellation_details: nil, expand: nil, invoice_now: nil, prorate: nil) ⇒ CancelParams
constructor
A new instance of CancelParams.
Methods inherited from RequestParams
Constructor Details
#initialize(cancellation_details: nil, expand: nil, invoice_now: nil, prorate: nil) ⇒ CancelParams
Returns a new instance of CancelParams.
27 28 29 30 31 32 |
# File 'lib/stripe/services/subscription_service.rb', line 27 def initialize(cancellation_details: nil, expand: nil, invoice_now: nil, prorate: nil) @cancellation_details = cancellation_details @expand = @invoice_now = invoice_now @prorate = prorate end |
Instance Attribute Details
#cancellation_details ⇒ Object
Details about why this subscription was cancelled
19 20 21 |
# File 'lib/stripe/services/subscription_service.rb', line 19 def cancellation_details @cancellation_details end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
21 22 23 |
# File 'lib/stripe/services/subscription_service.rb', line 21 def @expand end |
#invoice_now ⇒ Object
Will generate a final invoice that invoices for any un-invoiced metered usage and new/pending proration invoice items. Defaults to ‘false`.
23 24 25 |
# File 'lib/stripe/services/subscription_service.rb', line 23 def invoice_now @invoice_now end |
#prorate ⇒ Object
Will generate a proration invoice item that credits remaining unused time until the subscription period end. Defaults to ‘false`.
25 26 27 |
# File 'lib/stripe/services/subscription_service.rb', line 25 def prorate @prorate end |