Class: Stripe::SubscriptionService::CreateParams::AddInvoiceItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_service.rb

Defined Under Namespace

Classes: Discount, Period, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discounts: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ AddInvoiceItem

Returns a new instance of AddInvoiceItem.



1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
1126
1127
1128
1129
# File 'lib/stripe/services/subscription_service.rb', line 1113

def initialize(
  discounts: nil,
  metadata: nil,
  period: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @discounts = discounts
  @metadata = 
  @period = period
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#discountsObject

The coupons to redeem into discounts for the item.



1099
1100
1101
# File 'lib/stripe/services/subscription_service.rb', line 1099

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1101
1102
1103
# File 'lib/stripe/services/subscription_service.rb', line 1101

def 
  @metadata
end

#periodObject

The period associated with this invoice item. Defaults to the current period of the subscription.



1103
1104
1105
# File 'lib/stripe/services/subscription_service.rb', line 1103

def period
  @period
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required.



1105
1106
1107
# File 'lib/stripe/services/subscription_service.rb', line 1105

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.



1107
1108
1109
# File 'lib/stripe/services/subscription_service.rb', line 1107

def price_data
  @price_data
end

#quantityObject

Quantity for this item. Defaults to 1.



1109
1110
1111
# File 'lib/stripe/services/subscription_service.rb', line 1109

def quantity
  @quantity
end

#tax_ratesObject

The tax rates which apply to the item. When set, the ‘default_tax_rates` do not apply to this item.



1111
1112
1113
# File 'lib/stripe/services/subscription_service.rb', line 1111

def tax_rates
  @tax_rates
end