Class: Stripe::SubscriptionService::CreateParams::AddInvoiceItem::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionService::CreateParams::AddInvoiceItem::Discount::DiscountEnd
- Defined in:
- lib/stripe/services/subscription_service.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
1014 1015 1016 1017 1018 |
# File 'lib/stripe/services/subscription_service.rb', line 1014 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
1008 1009 1010 |
# File 'lib/stripe/services/subscription_service.rb', line 1008 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
1010 1011 1012 |
# File 'lib/stripe/services/subscription_service.rb', line 1010 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
1012 1013 1014 |
# File 'lib/stripe/services/subscription_service.rb', line 1012 def type @type end |