Class: Stripe::SubscriptionService::CreateParams::AddInvoiceItem::Period::End

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(timestamp: nil, type: nil) ⇒ End

Returns a new instance of End.



1044
1045
1046
1047
# File 'lib/stripe/services/subscription_service.rb', line 1044

def initialize(timestamp: nil, type: nil)
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#timestampObject

A precise Unix timestamp for the end of the invoice item period. Must be greater than or equal to ‘period.start`.



1040
1041
1042
# File 'lib/stripe/services/subscription_service.rb', line 1040

def timestamp
  @timestamp
end

#typeObject

Select how to calculate the end of the invoice item period.



1042
1043
1044
# File 'lib/stripe/services/subscription_service.rb', line 1042

def type
  @type
end