Class: Stripe::SubscriptionService::CreateParams::AddInvoiceItem::Period::Start
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionService::CreateParams::AddInvoiceItem::Period::Start
- Defined in:
- lib/stripe/services/subscription_service.rb
Instance Attribute Summary collapse
-
#timestamp ⇒ Object
A precise Unix timestamp for the start of the invoice item period.
-
#type ⇒ Object
Select how to calculate the start of the invoice item period.
Instance Method Summary collapse
-
#initialize(timestamp: nil, type: nil) ⇒ Start
constructor
A new instance of Start.
Methods inherited from RequestParams
Constructor Details
#initialize(timestamp: nil, type: nil) ⇒ Start
Returns a new instance of Start.
1056 1057 1058 1059 |
# File 'lib/stripe/services/subscription_service.rb', line 1056 def initialize(timestamp: nil, type: nil) @timestamp = @type = type end |
Instance Attribute Details
#timestamp ⇒ Object
A precise Unix timestamp for the start of the invoice item period. Must be less than or equal to ‘period.end`.
1052 1053 1054 |
# File 'lib/stripe/services/subscription_service.rb', line 1052 def @timestamp end |
#type ⇒ Object
Select how to calculate the start of the invoice item period.
1054 1055 1056 |
# File 'lib/stripe/services/subscription_service.rb', line 1054 def type @type end |