Class: Stripe::SubscriptionService::CreateParams::AutomaticTax

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_service.rb

Defined Under Namespace

Classes: Liability

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(enabled: nil, liability: nil) ⇒ AutomaticTax

Returns a new instance of AutomaticTax.



1149
1150
1151
1152
# File 'lib/stripe/services/subscription_service.rb', line 1149

def initialize(enabled: nil, liability: nil)
  @enabled = enabled
  @liability = liability
end

Instance Attribute Details

#enabledObject

Enabled automatic tax calculation which will automatically compute tax rates on all invoices generated by the subscription.



1145
1146
1147
# File 'lib/stripe/services/subscription_service.rb', line 1145

def enabled
  @enabled
end

#liabilityObject

The account that’s liable for tax. If set, the business address and tax registrations required to perform the tax calculation are loaded from this account. The tax transaction is returned in the report of the connected account.



1147
1148
1149
# File 'lib/stripe/services/subscription_service.rb', line 1147

def liability
  @liability
end