Class: Stripe::SubscriptionService::CreateParams::BillingCycleAnchorConfig

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ BillingCycleAnchorConfig

Returns a new instance of BillingCycleAnchorConfig.



1167
1168
1169
1170
1171
1172
1173
# File 'lib/stripe/services/subscription_service.rb', line 1167

def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil)
  @day_of_month = day_of_month
  @hour = hour
  @minute = minute
  @month = month
  @second = second
end

Instance Attribute Details

#day_of_monthObject

The day of the month the anchor should be. Ranges from 1 to 31.



1157
1158
1159
# File 'lib/stripe/services/subscription_service.rb', line 1157

def day_of_month
  @day_of_month
end

#hourObject

The hour of the day the anchor should be. Ranges from 0 to 23.



1159
1160
1161
# File 'lib/stripe/services/subscription_service.rb', line 1159

def hour
  @hour
end

#minuteObject

The minute of the hour the anchor should be. Ranges from 0 to 59.



1161
1162
1163
# File 'lib/stripe/services/subscription_service.rb', line 1161

def minute
  @minute
end

#monthObject

The month to start full cycle periods. Ranges from 1 to 12.



1163
1164
1165
# File 'lib/stripe/services/subscription_service.rb', line 1163

def month
  @month
end

#secondObject

The second of the minute the anchor should be. Ranges from 0 to 59.



1165
1166
1167
# File 'lib/stripe/services/subscription_service.rb', line 1165

def second
  @second
end