Class: Stripe::SubscriptionService::CreateParams::BillingMode
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionService::CreateParams::BillingMode
- Defined in:
- lib/stripe/services/subscription_service.rb
Instance Attribute Summary collapse
-
#type ⇒ Object
Controls the calculation and orchestration of prorations and invoices for subscriptions.
Instance Method Summary collapse
-
#initialize(type: nil) ⇒ BillingMode
constructor
A new instance of BillingMode.
Methods inherited from RequestParams
Constructor Details
#initialize(type: nil) ⇒ BillingMode
Returns a new instance of BillingMode.
1010 1011 1012 |
# File 'lib/stripe/services/subscription_service.rb', line 1010 def initialize(type: nil) @type = type end |
Instance Attribute Details
#type ⇒ Object
Controls the calculation and orchestration of prorations and invoices for subscriptions.
1008 1009 1010 |
# File 'lib/stripe/services/subscription_service.rb', line 1008 def type @type end |