Class: Stripe::SubscriptionService::CreateParams::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1035
1036
1037
1038
1039
# File 'lib/stripe/services/subscription_service.rb', line 1035

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1029
1030
1031
# File 'lib/stripe/services/subscription_service.rb', line 1029

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1031
1032
1033
# File 'lib/stripe/services/subscription_service.rb', line 1031

def discount
  @discount
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1033
1034
1035
# File 'lib/stripe/services/subscription_service.rb', line 1033

def promotion_code
  @promotion_code
end