Class: Stripe::SubscriptionService::CreateParams::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionService::CreateParams::Discount::DiscountEnd
- Defined in:
- lib/stripe/services/subscription_service.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
1217 1218 1219 1220 1221 |
# File 'lib/stripe/services/subscription_service.rb', line 1217 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
1211 1212 1213 |
# File 'lib/stripe/services/subscription_service.rb', line 1211 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
1213 1214 1215 |
# File 'lib/stripe/services/subscription_service.rb', line 1213 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
1215 1216 1217 |
# File 'lib/stripe/services/subscription_service.rb', line 1215 def type @type end |