Class: Stripe::SubscriptionService::CreateParams::InvoiceSettings

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_service.rb

Defined Under Namespace

Classes: Issuer

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_tax_ids: nil, issuer: nil) ⇒ InvoiceSettings

Returns a new instance of InvoiceSettings.



961
962
963
964
# File 'lib/stripe/services/subscription_service.rb', line 961

def initialize(account_tax_ids: nil, issuer: nil)
  @account_tax_ids = 
  @issuer = issuer
end

Instance Attribute Details

#account_tax_idsObject

The account tax IDs associated with the subscription. Will be set on invoices generated by the subscription.



957
958
959
# File 'lib/stripe/services/subscription_service.rb', line 957

def 
  @account_tax_ids
end

#issuerObject

The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.



959
960
961
# File 'lib/stripe/services/subscription_service.rb', line 959

def issuer
  @issuer
end