Class: Stripe::SubscriptionService::CreateParams::Item

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_service.rb

Defined Under Namespace

Classes: BillingThresholds, Discount, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_thresholds: nil, discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ Item

Returns a new instance of Item.



1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
1160
1161
1162
1163
1164
1165
1166
# File 'lib/stripe/services/subscription_service.rb', line 1148

def initialize(
  billing_thresholds: nil,
  discounts: nil,
  metadata: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @billing_thresholds = billing_thresholds
  @discounts = discounts
  @metadata = 
  @plan = plan
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.



1132
1133
1134
# File 'lib/stripe/services/subscription_service.rb', line 1132

def billing_thresholds
  @billing_thresholds
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



1134
1135
1136
# File 'lib/stripe/services/subscription_service.rb', line 1134

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1136
1137
1138
# File 'lib/stripe/services/subscription_service.rb', line 1136

def 
  @metadata
end

#planObject

Plan ID for this item, as a string.



1138
1139
1140
# File 'lib/stripe/services/subscription_service.rb', line 1138

def plan
  @plan
end

#priceObject

The ID of the price object.



1140
1141
1142
# File 'lib/stripe/services/subscription_service.rb', line 1140

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.



1142
1143
1144
# File 'lib/stripe/services/subscription_service.rb', line 1142

def price_data
  @price_data
end

#quantityObject

Quantity for this item.



1144
1145
1146
# File 'lib/stripe/services/subscription_service.rb', line 1144

def quantity
  @quantity
end

#tax_ratesObject

A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



1146
1147
1148
# File 'lib/stripe/services/subscription_service.rb', line 1146

def tax_rates
  @tax_rates
end