Class: Stripe::SubscriptionService::CreateParams::Item::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



1165
1166
1167
1168
1169
# File 'lib/stripe/services/subscription_service.rb', line 1165

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



1159
1160
1161
# File 'lib/stripe/services/subscription_service.rb', line 1159

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



1161
1162
1163
# File 'lib/stripe/services/subscription_service.rb', line 1161

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



1163
1164
1165
# File 'lib/stripe/services/subscription_service.rb', line 1163

def type
  @type
end