Class: Stripe::SubscriptionService::CreateParams::PaymentSettings::PaymentMethodOptions::CustomerBalance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_service.rb

Defined Under Namespace

Classes: BankTransfer

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bank_transfer: nil, funding_type: nil) ⇒ CustomerBalance

Returns a new instance of CustomerBalance.



1359
1360
1361
1362
# File 'lib/stripe/services/subscription_service.rb', line 1359

def initialize(bank_transfer: nil, funding_type: nil)
  @bank_transfer = bank_transfer
  @funding_type = funding_type
end

Instance Attribute Details

#bank_transferObject

Configuration for the bank transfer funding type, if the ‘funding_type` is set to `bank_transfer`.



1355
1356
1357
# File 'lib/stripe/services/subscription_service.rb', line 1355

def bank_transfer
  @bank_transfer
end

#funding_typeObject

The funding method type to be used when there are not enough funds in the customer balance. Permitted values include: ‘bank_transfer`.



1357
1358
1359
# File 'lib/stripe/services/subscription_service.rb', line 1357

def funding_type
  @funding_type
end