Class: Stripe::SubscriptionService::CreateParams::PaymentSettings::PaymentMethodOptions::UsBankAccount::FinancialConnections
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionService::CreateParams::PaymentSettings::PaymentMethodOptions::UsBankAccount::FinancialConnections
- Defined in:
- lib/stripe/services/subscription_service.rb
Defined Under Namespace
Classes: Filters
Instance Attribute Summary collapse
-
#filters ⇒ Object
Provide filters for the linked accounts that the customer can select for the payment method.
-
#permissions ⇒ Object
The list of permissions to request.
-
#prefetch ⇒ Object
List of data features that you would like to retrieve upon account creation.
Instance Method Summary collapse
-
#initialize(filters: nil, permissions: nil, prefetch: nil) ⇒ FinancialConnections
constructor
A new instance of FinancialConnections.
Methods inherited from RequestParams
Constructor Details
#initialize(filters: nil, permissions: nil, prefetch: nil) ⇒ FinancialConnections
Returns a new instance of FinancialConnections.
1280 1281 1282 1283 1284 |
# File 'lib/stripe/services/subscription_service.rb', line 1280 def initialize(filters: nil, permissions: nil, prefetch: nil) @filters = filters @permissions = @prefetch = prefetch end |
Instance Attribute Details
#filters ⇒ Object
Provide filters for the linked accounts that the customer can select for the payment method.
1274 1275 1276 |
# File 'lib/stripe/services/subscription_service.rb', line 1274 def filters @filters end |
#permissions ⇒ Object
The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.
1276 1277 1278 |
# File 'lib/stripe/services/subscription_service.rb', line 1276 def @permissions end |
#prefetch ⇒ Object
List of data features that you would like to retrieve upon account creation.
1278 1279 1280 |
# File 'lib/stripe/services/subscription_service.rb', line 1278 def prefetch @prefetch end |