Class: Stripe::SubscriptionService::CreateParams::Prebilling

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(iterations: nil, update_behavior: nil) ⇒ Prebilling

Returns a new instance of Prebilling.



1493
1494
1495
1496
# File 'lib/stripe/services/subscription_service.rb', line 1493

def initialize(iterations: nil, update_behavior: nil)
  @iterations = iterations
  @update_behavior = update_behavior
end

Instance Attribute Details

#iterationsObject

This is used to determine the number of billing cycles to prebill.



1489
1490
1491
# File 'lib/stripe/services/subscription_service.rb', line 1489

def iterations
  @iterations
end

#update_behaviorObject

Whether to cancel or preserve ‘prebilling` if the subscription is updated during the prebilled period. The default value is `reset`.



1491
1492
1493
# File 'lib/stripe/services/subscription_service.rb', line 1491

def update_behavior
  @update_behavior
end