Class: Stripe::SubscriptionService::ListParams::AutomaticTax

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(enabled: nil) ⇒ AutomaticTax

Returns a new instance of AutomaticTax.



730
731
732
# File 'lib/stripe/services/subscription_service.rb', line 730

def initialize(enabled: nil)
  @enabled = enabled
end

Instance Attribute Details

#enabledObject

Enabled automatic tax calculation which will automatically compute tax rates on all invoices generated by the subscription.



728
729
730
# File 'lib/stripe/services/subscription_service.rb', line 728

def enabled
  @enabled
end