Class: Stripe::SubscriptionService::SearchParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionService::SearchParams
- Defined in:
- lib/stripe/services/subscription_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#page ⇒ Object
A cursor for pagination across multiple pages of results.
-
#query ⇒ Object
The search query string.
Instance Method Summary collapse
-
#initialize(expand: nil, limit: nil, page: nil, query: nil) ⇒ SearchParams
constructor
A new instance of SearchParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, limit: nil, page: nil, query: nil) ⇒ SearchParams
Returns a new instance of SearchParams.
1751 1752 1753 1754 1755 1756 |
# File 'lib/stripe/services/subscription_service.rb', line 1751 def initialize(expand: nil, limit: nil, page: nil, query: nil) @expand = @limit = limit @page = page @query = query end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1743 1744 1745 |
# File 'lib/stripe/services/subscription_service.rb', line 1743 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
1745 1746 1747 |
# File 'lib/stripe/services/subscription_service.rb', line 1745 def limit @limit end |
#page ⇒ Object
A cursor for pagination across multiple pages of results. Don’t include this parameter on the first call. Use the next_page value returned in a previous response to request subsequent results.
1747 1748 1749 |
# File 'lib/stripe/services/subscription_service.rb', line 1747 def page @page end |
#query ⇒ Object
The search query string. See [search query language](stripe.com/docs/search#search-query-language) and the list of supported [query fields for subscriptions](stripe.com/docs/search#query-fields-for-subscriptions).
1749 1750 1751 |
# File 'lib/stripe/services/subscription_service.rb', line 1749 def query @query end |