Class: Stripe::SubscriptionService::UpdateParams::AddInvoiceItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



81
82
83
84
85
86
# File 'lib/stripe/services/subscription_service.rb', line 81

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



73
74
75
# File 'lib/stripe/services/subscription_service.rb', line 73

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



75
76
77
# File 'lib/stripe/services/subscription_service.rb', line 75

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



77
78
79
# File 'lib/stripe/services/subscription_service.rb', line 77

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



79
80
81
# File 'lib/stripe/services/subscription_service.rb', line 79

def promotion_code
  @promotion_code
end