Class: Stripe::SubscriptionService::UpdateParams::AddInvoiceItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



66
67
68
69
70
# File 'lib/stripe/services/subscription_service.rb', line 66

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



60
61
62
# File 'lib/stripe/services/subscription_service.rb', line 60

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



62
63
64
# File 'lib/stripe/services/subscription_service.rb', line 62

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



64
65
66
# File 'lib/stripe/services/subscription_service.rb', line 64

def type
  @type
end