Class: Stripe::SubscriptionService::UpdateParams::AddInvoiceItem::Period::End
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionService::UpdateParams::AddInvoiceItem::Period::End
- Defined in:
- lib/stripe/services/subscription_service.rb
Instance Attribute Summary collapse
-
#timestamp ⇒ Object
A precise Unix timestamp for the end of the invoice item period.
-
#type ⇒ Object
Select how to calculate the end of the invoice item period.
Instance Method Summary collapse
-
#initialize(timestamp: nil, type: nil) ⇒ End
constructor
A new instance of End.
Methods inherited from RequestParams
Constructor Details
#initialize(timestamp: nil, type: nil) ⇒ End
Returns a new instance of End.
96 97 98 99 |
# File 'lib/stripe/services/subscription_service.rb', line 96 def initialize(timestamp: nil, type: nil) @timestamp = @type = type end |
Instance Attribute Details
#timestamp ⇒ Object
A precise Unix timestamp for the end of the invoice item period. Must be greater than or equal to ‘period.start`.
92 93 94 |
# File 'lib/stripe/services/subscription_service.rb', line 92 def @timestamp end |
#type ⇒ Object
Select how to calculate the end of the invoice item period.
94 95 96 |
# File 'lib/stripe/services/subscription_service.rb', line 94 def type @type end |