Class: Stripe::SubscriptionService::UpdateParams::CancellationDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(comment: nil, feedback: nil) ⇒ CancellationDetails

Returns a new instance of CancellationDetails.



225
226
227
228
# File 'lib/stripe/services/subscription_service.rb', line 225

def initialize(comment: nil, feedback: nil)
  @comment = comment
  @feedback = feedback
end

Instance Attribute Details

#commentObject

Additional comments about why the user canceled the subscription, if the subscription was canceled explicitly by the user.



221
222
223
# File 'lib/stripe/services/subscription_service.rb', line 221

def comment
  @comment
end

#feedbackObject

The customer submitted reason for why they canceled, if the subscription was canceled explicitly by the user.



223
224
225
# File 'lib/stripe/services/subscription_service.rb', line 223

def feedback
  @feedback
end