Class: Stripe::SubscriptionService::UpdateParams::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionService::UpdateParams::Discount
- Defined in:
- lib/stripe/services/subscription_service.rb
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
150 151 152 153 154 |
# File 'lib/stripe/services/subscription_service.rb', line 150 def initialize(coupon: nil, discount: nil, promotion_code: nil) @coupon = coupon @discount = discount @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
144 145 146 |
# File 'lib/stripe/services/subscription_service.rb', line 144 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
146 147 148 |
# File 'lib/stripe/services/subscription_service.rb', line 146 def discount @discount end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
148 149 150 |
# File 'lib/stripe/services/subscription_service.rb', line 148 def promotion_code @promotion_code end |