Class: Stripe::SubscriptionService::UpdateParams::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionService::UpdateParams::Discount::DiscountEnd
- Defined in:
- lib/stripe/services/subscription_service.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
190 191 192 193 194 |
# File 'lib/stripe/services/subscription_service.rb', line 190 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
184 185 186 |
# File 'lib/stripe/services/subscription_service.rb', line 184 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
186 187 188 |
# File 'lib/stripe/services/subscription_service.rb', line 186 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
188 189 190 |
# File 'lib/stripe/services/subscription_service.rb', line 188 def type @type end |