Class: Stripe::SubscriptionService::UpdateParams::Item

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_service.rb

Defined Under Namespace

Classes: BillingThresholds, Discount, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_thresholds: nil, clear_usage: nil, deleted: nil, discounts: nil, id: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ Item

Returns a new instance of Item.



330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
# File 'lib/stripe/services/subscription_service.rb', line 330

def initialize(
  billing_thresholds: nil,
  clear_usage: nil,
  deleted: nil,
  discounts: nil,
  id: nil,
  metadata: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @billing_thresholds = billing_thresholds
  @clear_usage = clear_usage
  @deleted = deleted
  @discounts = discounts
  @id = id
  @metadata = 
  @plan = plan
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.



308
309
310
# File 'lib/stripe/services/subscription_service.rb', line 308

def billing_thresholds
  @billing_thresholds
end

#clear_usageObject

Delete all usage for a given subscription item. You must pass this when deleting a usage records subscription item. ‘clear_usage` has no effect if the plan has a billing meter attached.



310
311
312
# File 'lib/stripe/services/subscription_service.rb', line 310

def clear_usage
  @clear_usage
end

#deletedObject

A flag that, if set to ‘true`, will delete the specified item.



312
313
314
# File 'lib/stripe/services/subscription_service.rb', line 312

def deleted
  @deleted
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



314
315
316
# File 'lib/stripe/services/subscription_service.rb', line 314

def discounts
  @discounts
end

#idObject

Subscription item to update.



316
317
318
# File 'lib/stripe/services/subscription_service.rb', line 316

def id
  @id
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



318
319
320
# File 'lib/stripe/services/subscription_service.rb', line 318

def 
  @metadata
end

#planObject

Plan ID for this item, as a string.



320
321
322
# File 'lib/stripe/services/subscription_service.rb', line 320

def plan
  @plan
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required. When changing a subscription item’s price, ‘quantity` is set to 1 unless a `quantity` parameter is provided.



322
323
324
# File 'lib/stripe/services/subscription_service.rb', line 322

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.



324
325
326
# File 'lib/stripe/services/subscription_service.rb', line 324

def price_data
  @price_data
end

#quantityObject

Quantity for this item.



326
327
328
# File 'lib/stripe/services/subscription_service.rb', line 326

def quantity
  @quantity
end

#tax_ratesObject

A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



328
329
330
# File 'lib/stripe/services/subscription_service.rb', line 328

def tax_rates
  @tax_rates
end