Class: Stripe::SubscriptionService::UpdateParams::Item::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



342
343
344
345
346
347
# File 'lib/stripe/services/subscription_service.rb', line 342

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



334
335
336
# File 'lib/stripe/services/subscription_service.rb', line 334

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



336
337
338
# File 'lib/stripe/services/subscription_service.rb', line 336

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



338
339
340
# File 'lib/stripe/services/subscription_service.rb', line 338

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



340
341
342
# File 'lib/stripe/services/subscription_service.rb', line 340

def promotion_code
  @promotion_code
end