Class: Stripe::SubscriptionUpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/subscription_update_params.rb

Defined Under Namespace

Classes: AddInvoiceItem, AutomaticTax, BillingSchedule, BillingThresholds, CancellationDetails, Discount, InvoiceSettings, Item, PauseCollection, PaymentSettings, PendingInvoiceItemInterval, Prebilling, TransferData, TrialSettings

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, new, #to_h

Constructor Details

#initialize(add_invoice_items: nil, application_fee_percent: nil, automatic_tax: nil, billing_cycle_anchor: nil, billing_schedules: nil, billing_thresholds: nil, cancel_at: nil, cancel_at_period_end: nil, cancellation_details: nil, collection_method: nil, days_until_due: nil, default_payment_method: nil, default_source: nil, default_tax_rates: nil, description: nil, discounts: nil, expand: nil, invoice_settings: nil, items: nil, metadata: nil, off_session: nil, on_behalf_of: nil, pause_collection: nil, payment_behavior: nil, payment_settings: nil, pending_invoice_item_interval: nil, prebilling: nil, proration_behavior: nil, proration_date: nil, transfer_data: nil, trial_end: nil, trial_from_plan: nil, trial_settings: nil) ⇒ SubscriptionUpdateParams

Returns a new instance of SubscriptionUpdateParams.



964
965
966
967
968
969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
995
996
997
998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
# File 'lib/stripe/params/subscription_update_params.rb', line 964

def initialize(
  add_invoice_items: nil,
  application_fee_percent: nil,
  automatic_tax: nil,
  billing_cycle_anchor: nil,
  billing_schedules: nil,
  billing_thresholds: nil,
  cancel_at: nil,
  cancel_at_period_end: nil,
  cancellation_details: nil,
  collection_method: nil,
  days_until_due: nil,
  default_payment_method: nil,
  default_source: nil,
  default_tax_rates: nil,
  description: nil,
  discounts: nil,
  expand: nil,
  invoice_settings: nil,
  items: nil,
  metadata: nil,
  off_session: nil,
  on_behalf_of: nil,
  pause_collection: nil,
  payment_behavior: nil,
  payment_settings: nil,
  pending_invoice_item_interval: nil,
  prebilling: nil,
  proration_behavior: nil,
  proration_date: nil,
  transfer_data: nil,
  trial_end: nil,
  trial_from_plan: nil,
  trial_settings: nil
)
  @add_invoice_items = add_invoice_items
  @application_fee_percent = application_fee_percent
  @automatic_tax = automatic_tax
  @billing_cycle_anchor = billing_cycle_anchor
  @billing_schedules = billing_schedules
  @billing_thresholds = billing_thresholds
  @cancel_at = cancel_at
  @cancel_at_period_end = cancel_at_period_end
  @cancellation_details = cancellation_details
  @collection_method = collection_method
  @days_until_due = days_until_due
  @default_payment_method = default_payment_method
  @default_source = default_source
  @default_tax_rates = default_tax_rates
  @description = description
  @discounts = discounts
  @expand = expand
  @invoice_settings = invoice_settings
  @items = items
  @metadata = 
  @off_session = off_session
  @on_behalf_of = on_behalf_of
  @pause_collection = pause_collection
  @payment_behavior = payment_behavior
  @payment_settings = payment_settings
  @pending_invoice_item_interval = pending_invoice_item_interval
  @prebilling = prebilling
  @proration_behavior = proration_behavior
  @proration_date = proration_date
  @transfer_data = transfer_data
  @trial_end = trial_end
  @trial_from_plan = trial_from_plan
  @trial_settings = trial_settings
end

Instance Attribute Details

#add_invoice_itemsObject

A list of prices and quantities that will generate invoice items appended to the next invoice for this subscription. You may pass up to 20 items.



898
899
900
# File 'lib/stripe/params/subscription_update_params.rb', line 898

def add_invoice_items
  @add_invoice_items
end

#application_fee_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the application owner's Stripe account. The request must be made by a platform account on a connected account in order to set an application fee percentage. For more information, see the application fees documentation.



900
901
902
# File 'lib/stripe/params/subscription_update_params.rb', line 900

def application_fee_percent
  @application_fee_percent
end

#automatic_taxObject

Automatic tax settings for this subscription. We recommend you only include this parameter when the existing value is being changed.



902
903
904
# File 'lib/stripe/params/subscription_update_params.rb', line 902

def automatic_tax
  @automatic_tax
end

#billing_cycle_anchorObject

Either now or unchanged. Setting the value to now resets the subscription's billing cycle anchor to the current time (in UTC). For more information, see the billing cycle documentation.



904
905
906
# File 'lib/stripe/params/subscription_update_params.rb', line 904

def billing_cycle_anchor
  @billing_cycle_anchor
end

#billing_schedulesObject

An array of billing schedules, which allow you to bill customers in advance for multiple service periods. Requires flexible billing mode and API version 2026-05-27.dahlia or later. Learn more about prebilling.



906
907
908
# File 'lib/stripe/params/subscription_update_params.rb', line 906

def billing_schedules
  @billing_schedules
end

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. When updating, pass an empty string to remove previously-defined thresholds.



908
909
910
# File 'lib/stripe/params/subscription_update_params.rb', line 908

def billing_thresholds
  @billing_thresholds
end

#cancel_atObject

A timestamp at which the subscription should cancel. If set to a date before the current period ends, this will cause a proration if prorations have been enabled using proration_behavior. If set during a future period, this will always cause a proration for that period.



910
911
912
# File 'lib/stripe/params/subscription_update_params.rb', line 910

def cancel_at
  @cancel_at
end

#cancel_at_period_endObject

Indicate whether this subscription should cancel at the end of the current period (current_period_end).



912
913
914
# File 'lib/stripe/params/subscription_update_params.rb', line 912

def cancel_at_period_end
  @cancel_at_period_end
end

#cancellation_detailsObject

Details about why this subscription was cancelled



914
915
916
# File 'lib/stripe/params/subscription_update_params.rb', line 914

def cancellation_details
  @cancellation_details
end

#collection_methodObject

Either charge_automatically, or send_invoice. When charging automatically, Stripe will attempt to pay this subscription at the end of the cycle using the default source attached to the customer. When sending an invoice, Stripe will email your customer an invoice with payment instructions and mark the subscription as active. Defaults to charge_automatically.



916
917
918
# File 'lib/stripe/params/subscription_update_params.rb', line 916

def collection_method
  @collection_method
end

#days_until_dueObject

Number of days a customer has to pay invoices generated by this subscription. Valid only for subscriptions where collection_method is set to send_invoice.



918
919
920
# File 'lib/stripe/params/subscription_update_params.rb', line 918

def days_until_due
  @days_until_due
end

#default_payment_methodObject

ID of the default payment method for the subscription. It must belong to the customer associated with the subscription. This takes precedence over default_source. If neither are set, invoices will use the customer's invoice_settings.default_payment_method or default_source.



920
921
922
# File 'lib/stripe/params/subscription_update_params.rb', line 920

def default_payment_method
  @default_payment_method
end

#default_sourceObject

ID of the default payment source for the subscription. It must belong to the customer associated with the subscription and be in a chargeable state. If default_payment_method is also set, default_payment_method will take precedence. If neither are set, invoices will use the customer's invoice_settings.default_payment_method or default_source.



922
923
924
# File 'lib/stripe/params/subscription_update_params.rb', line 922

def default_source
  @default_source
end

#default_tax_ratesObject

The tax rates that will apply to any subscription item that does not have tax_rates set. Invoices created will have their default_tax_rates populated from the subscription. Pass an empty string to remove previously-defined tax rates.



924
925
926
# File 'lib/stripe/params/subscription_update_params.rb', line 924

def default_tax_rates
  @default_tax_rates
end

#descriptionObject

The subscription's description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.



926
927
928
# File 'lib/stripe/params/subscription_update_params.rb', line 926

def description
  @description
end

#discountsObject

The coupons to redeem into discounts for the subscription. A populated array overwrites the existing discounts on the subscription. If not specified or empty array, it leaves the subscription's discounts unchanged. If empty string, it clears the subscription's discounts.



928
929
930
# File 'lib/stripe/params/subscription_update_params.rb', line 928

def discounts
  @discounts
end

#expandObject

Specifies which fields in the response should be expanded.



930
931
932
# File 'lib/stripe/params/subscription_update_params.rb', line 930

def expand
  @expand
end

#invoice_settingsObject

All invoices will be billed using the specified settings.



932
933
934
# File 'lib/stripe/params/subscription_update_params.rb', line 932

def invoice_settings
  @invoice_settings
end

#itemsObject

A list of up to 20 subscription items, each with an attached price.



934
935
936
# File 'lib/stripe/params/subscription_update_params.rb', line 934

def items
  @items
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.



936
937
938
# File 'lib/stripe/params/subscription_update_params.rb', line 936

def 
  @metadata
end

#off_sessionObject

Indicates if a customer is on or off-session while an invoice payment is attempted. Defaults to false (on-session).



938
939
940
# File 'lib/stripe/params/subscription_update_params.rb', line 938

def off_session
  @off_session
end

#on_behalf_ofObject

The account on behalf of which to charge, for each of the subscription's invoices.



940
941
942
# File 'lib/stripe/params/subscription_update_params.rb', line 940

def on_behalf_of
  @on_behalf_of
end

#pause_collectionObject

If specified, payment collection for this subscription will be paused. Note that the subscription status will be unchanged and will not be updated to paused. Learn more about pausing collection.



942
943
944
# File 'lib/stripe/params/subscription_update_params.rb', line 942

def pause_collection
  @pause_collection
end

#payment_behaviorObject

Controls how Stripe handles payment when a subscription update requires payment and collection_method=charge_automatically.



944
945
946
# File 'lib/stripe/params/subscription_update_params.rb', line 944

def payment_behavior
  @payment_behavior
end

#payment_settingsObject

Payment settings to pass to invoices created by the subscription.



946
947
948
# File 'lib/stripe/params/subscription_update_params.rb', line 946

def payment_settings
  @payment_settings
end

#pending_invoice_item_intervalObject

Specifies an interval for how often to bill for any pending invoice items. It is analogous to calling Create an invoice for the given subscription at the specified interval.



948
949
950
# File 'lib/stripe/params/subscription_update_params.rb', line 948

def pending_invoice_item_interval
  @pending_invoice_item_interval
end

#prebillingObject

If specified, the invoicing for the given billing cycle iterations will be processed now.



950
951
952
# File 'lib/stripe/params/subscription_update_params.rb', line 950

def prebilling
  @prebilling
end

#proration_behaviorObject

Determines how to handle prorations when the billing cycle changes (e.g., when switching plans, resetting billing_cycle_anchor=now, or starting a trial), or if an item's quantity changes. The default value is create_prorations.



952
953
954
# File 'lib/stripe/params/subscription_update_params.rb', line 952

def proration_behavior
  @proration_behavior
end

#proration_dateObject

If set, prorations will be calculated as though the subscription was updated at the given time. This can be used to apply exactly the same prorations that were previewed with the create preview endpoint. proration_date can also be used to implement custom proration logic, such as prorating by day instead of by second, by providing the time that you wish to use for proration calculations.



954
955
956
# File 'lib/stripe/params/subscription_update_params.rb', line 954

def proration_date
  @proration_date
end

#transfer_dataObject

If specified, the funds from the subscription's invoices will be transferred to the destination and the ID of the resulting transfers will be found on the resulting charges. This will be unset if you POST an empty value.



956
957
958
# File 'lib/stripe/params/subscription_update_params.rb', line 956

def transfer_data
  @transfer_data
end

#trial_endObject

Unix timestamp representing the end of the trial period the customer will get before being charged for the first time. This will always overwrite any trials that might apply via a subscribed plan. If set, trial_end will override the default trial period of the plan the customer is being subscribed to. The billing_cycle_anchor will be updated to the trial_end value. The special value now can be provided to end the customer's trial immediately. Can be at most two years from billing_cycle_anchor.



958
959
960
# File 'lib/stripe/params/subscription_update_params.rb', line 958

def trial_end
  @trial_end
end

#trial_from_planObject

Indicates if a plan's trial_period_days should be applied to the subscription. Setting trial_end per subscription is preferred, and this defaults to false. Setting this flag to true together with trial_end is not allowed. See Using trial periods on subscriptions to learn more.



960
961
962
# File 'lib/stripe/params/subscription_update_params.rb', line 960

def trial_from_plan
  @trial_from_plan
end

#trial_settingsObject

Settings related to subscription trials.



962
963
964
# File 'lib/stripe/params/subscription_update_params.rb', line 962

def trial_settings
  @trial_settings
end

Class Method Details

.field_encodingsObject



1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
# File 'lib/stripe/params/subscription_update_params.rb', line 1034

def self.field_encodings
  @field_encodings = {
    add_invoice_items: {
      kind: :array,
      element: {
        kind: :object,
        fields: { price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } } },
      },
    },
    items: {
      kind: :array,
      element: {
        kind: :object,
        fields: { price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } } },
      },
    },
  }
end