Class: Stripe::SubscriptionUpdateParams::AddInvoiceItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionUpdateParams::AddInvoiceItem
- Defined in:
- lib/stripe/params/subscription_update_params.rb
Defined Under Namespace
Classes: Discount, Period, PriceData
Instance Attribute Summary collapse
-
#discounts ⇒ Object
The coupons to redeem into discounts for the item.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#period ⇒ Object
The period associated with this invoice item.
-
#price ⇒ Object
The ID of the price object.
-
#price_data ⇒ Object
Data used to generate a new [Price](docs.stripe.com/api/prices) object inline.
-
#quantity ⇒ Object
Quantity for this item.
-
#tax_rates ⇒ Object
The tax rates which apply to the item.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(discounts: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ AddInvoiceItem
constructor
A new instance of AddInvoiceItem.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(discounts: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ AddInvoiceItem
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/stripe/params/subscription_update_params.rb', line 102 def initialize( discounts: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil ) @discounts = discounts = @period = period @price = price @price_data = price_data @quantity = quantity @tax_rates = tax_rates end |
Instance Attribute Details
#discounts ⇒ Object
The coupons to redeem into discounts for the item.
88 89 90 |
# File 'lib/stripe/params/subscription_update_params.rb', line 88 def discounts @discounts end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
90 91 92 |
# File 'lib/stripe/params/subscription_update_params.rb', line 90 def end |
#period ⇒ Object
The period associated with this invoice item. If not set, period.start.type defaults to max_item_period_start and period.end.type defaults to min_item_period_end.
92 93 94 |
# File 'lib/stripe/params/subscription_update_params.rb', line 92 def period @period end |
#price ⇒ Object
The ID of the price object. One of price or price_data is required.
94 95 96 |
# File 'lib/stripe/params/subscription_update_params.rb', line 94 def price @price end |
#price_data ⇒ Object
Data used to generate a new [Price](docs.stripe.com/api/prices) object inline. One of price or price_data is required.
96 97 98 |
# File 'lib/stripe/params/subscription_update_params.rb', line 96 def price_data @price_data end |
#quantity ⇒ Object
Quantity for this item. Defaults to 1.
98 99 100 |
# File 'lib/stripe/params/subscription_update_params.rb', line 98 def quantity @quantity end |
#tax_rates ⇒ Object
The tax rates which apply to the item. When set, the default_tax_rates do not apply to this item.
100 101 102 |
# File 'lib/stripe/params/subscription_update_params.rb', line 100 def tax_rates @tax_rates end |
Class Method Details
.field_encodings ⇒ Object
120 121 122 123 124 |
# File 'lib/stripe/params/subscription_update_params.rb', line 120 def self.field_encodings @field_encodings = { price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } }, } end |