Class: Stripe::SubscriptionUpdateParams::AddInvoiceItem::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionUpdateParams::AddInvoiceItem::Discount::DiscountEnd
- Defined in:
- lib/stripe/params/subscription_update_params.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
27 28 29 30 31 |
# File 'lib/stripe/params/subscription_update_params.rb', line 27 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
21 22 23 |
# File 'lib/stripe/params/subscription_update_params.rb', line 21 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
23 24 25 |
# File 'lib/stripe/params/subscription_update_params.rb', line 23 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
25 26 27 |
# File 'lib/stripe/params/subscription_update_params.rb', line 25 def type @type end |