Class: Stripe::SubscriptionUpdateParams::AddInvoiceItem::Period::Start
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionUpdateParams::AddInvoiceItem::Period::Start
- Defined in:
- lib/stripe/params/subscription_update_params.rb
Instance Attribute Summary collapse
-
#timestamp ⇒ Object
A precise Unix timestamp for the start of the invoice item period.
-
#type ⇒ Object
Select how to calculate the start of the invoice item period.
Instance Method Summary collapse
-
#initialize(timestamp: nil, type: nil) ⇒ Start
constructor
A new instance of Start.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(timestamp: nil, type: nil) ⇒ Start
Returns a new instance of Start.
69 70 71 72 |
# File 'lib/stripe/params/subscription_update_params.rb', line 69 def initialize(timestamp: nil, type: nil) @timestamp = @type = type end |
Instance Attribute Details
#timestamp ⇒ Object
A precise Unix timestamp for the start of the invoice item period. Must be less than or equal to ‘period.end`.
65 66 67 |
# File 'lib/stripe/params/subscription_update_params.rb', line 65 def @timestamp end |
#type ⇒ Object
Select how to calculate the start of the invoice item period.
67 68 69 |
# File 'lib/stripe/params/subscription_update_params.rb', line 67 def type @type end |