Class: Stripe::SubscriptionUpdateParams::BillingCycleAnchor
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionUpdateParams::BillingCycleAnchor
- Defined in:
- lib/stripe/params/subscription_update_params.rb
Instance Attribute Summary collapse
-
#type ⇒ Object
Determines how the billing cycle anchor changes when the subscription is updated.
Instance Method Summary collapse
-
#initialize(type: nil) ⇒ BillingCycleAnchor
constructor
A new instance of BillingCycleAnchor.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(type: nil) ⇒ BillingCycleAnchor
158 159 160 |
# File 'lib/stripe/params/subscription_update_params.rb', line 158 def initialize(type: nil) @type = type end |
Instance Attribute Details
#type ⇒ Object
Determines how the billing cycle anchor changes when the subscription is updated.
156 157 158 |
# File 'lib/stripe/params/subscription_update_params.rb', line 156 def type @type end |