Class: Stripe::SubscriptionUpdateParams::BillingSchedule::AppliesTo
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionUpdateParams::BillingSchedule::AppliesTo
- Defined in:
- lib/stripe/params/subscription_update_params.rb
Instance Attribute Summary collapse
-
#price ⇒ Object
The ID of the price object.
-
#type ⇒ Object
Controls which subscription items the billing schedule applies to.
Instance Method Summary collapse
-
#initialize(price: nil, type: nil) ⇒ AppliesTo
constructor
A new instance of AppliesTo.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(price: nil, type: nil) ⇒ AppliesTo
Returns a new instance of AppliesTo.
185 186 187 188 |
# File 'lib/stripe/params/subscription_update_params.rb', line 185 def initialize(price: nil, type: nil) @price = price @type = type end |
Instance Attribute Details
#price ⇒ Object
The ID of the price object.
181 182 183 |
# File 'lib/stripe/params/subscription_update_params.rb', line 181 def price @price end |
#type ⇒ Object
Controls which subscription items the billing schedule applies to.
183 184 185 |
# File 'lib/stripe/params/subscription_update_params.rb', line 183 def type @type end |