Class: Stripe::SubscriptionUpdateParams::BillingSchedule::BillUntil
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionUpdateParams::BillingSchedule::BillUntil
- Defined in:
- lib/stripe/params/subscription_update_params.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Specifies the billing period.
-
#timestamp ⇒ Object
The end date of the billing schedule.
-
#type ⇒ Object
Describes how the billing schedule will determine the end date.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ BillUntil
constructor
A new instance of BillUntil.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ BillUntil
Returns a new instance of BillUntil.
210 211 212 213 214 |
# File 'lib/stripe/params/subscription_update_params.rb', line 210 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Specifies the billing period.
204 205 206 |
# File 'lib/stripe/params/subscription_update_params.rb', line 204 def duration @duration end |
#timestamp ⇒ Object
The end date of the billing schedule.
206 207 208 |
# File 'lib/stripe/params/subscription_update_params.rb', line 206 def @timestamp end |
#type ⇒ Object
Describes how the billing schedule will determine the end date. Either ‘duration` or `timestamp`.
208 209 210 |
# File 'lib/stripe/params/subscription_update_params.rb', line 208 def type @type end |