Class: Stripe::SubscriptionUpdateParams::CancellationDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionUpdateParams::CancellationDetails
- Defined in:
- lib/stripe/params/subscription_update_params.rb
Instance Attribute Summary collapse
-
#comment ⇒ Object
Additional comments about why the user canceled the subscription, if the subscription was canceled explicitly by the user.
-
#feedback ⇒ Object
The customer submitted reason for why they canceled, if the subscription was canceled explicitly by the user.
Instance Method Summary collapse
-
#initialize(comment: nil, feedback: nil) ⇒ CancellationDetails
constructor
A new instance of CancellationDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(comment: nil, feedback: nil) ⇒ CancellationDetails
Returns a new instance of CancellationDetails.
248 249 250 251 |
# File 'lib/stripe/params/subscription_update_params.rb', line 248 def initialize(comment: nil, feedback: nil) @comment = comment @feedback = feedback end |
Instance Attribute Details
#comment ⇒ Object
Additional comments about why the user canceled the subscription, if the subscription was canceled explicitly by the user.
244 245 246 |
# File 'lib/stripe/params/subscription_update_params.rb', line 244 def comment @comment end |
#feedback ⇒ Object
The customer submitted reason for why they canceled, if the subscription was canceled explicitly by the user.
246 247 248 |
# File 'lib/stripe/params/subscription_update_params.rb', line 246 def feedback @feedback end |