Class: Stripe::SubscriptionUpdateParams::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionUpdateParams::Discount
- Defined in:
- lib/stripe/params/subscription_update_params.rb
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
241 242 243 244 245 |
# File 'lib/stripe/params/subscription_update_params.rb', line 241 def initialize(coupon: nil, discount: nil, promotion_code: nil) @coupon = coupon @discount = discount @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
235 236 237 |
# File 'lib/stripe/params/subscription_update_params.rb', line 235 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
237 238 239 |
# File 'lib/stripe/params/subscription_update_params.rb', line 237 def discount @discount end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
239 240 241 |
# File 'lib/stripe/params/subscription_update_params.rb', line 239 def promotion_code @promotion_code end |