Class: Stripe::SubscriptionUpdateParams::Discount::Settings::ServicePeriodAnchorConfig::Custom
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionUpdateParams::Discount::Settings::ServicePeriodAnchorConfig::Custom
- Defined in:
- lib/stripe/params/subscription_update_params.rb
Instance Attribute Summary collapse
-
#day_of_month ⇒ Object
The day of the month the anchor should be.
-
#hour ⇒ Object
The hour of the day the anchor should be.
-
#minute ⇒ Object
The minute of the hour the anchor should be.
-
#month ⇒ Object
The month to start full cycle periods.
-
#second ⇒ Object
The second of the minute the anchor should be.
Instance Method Summary collapse
-
#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom
constructor
A new instance of Custom.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom
Returns a new instance of Custom.
299 300 301 302 303 304 305 |
# File 'lib/stripe/params/subscription_update_params.rb', line 299 def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) @day_of_month = day_of_month @hour = hour @minute = minute @month = month @second = second end |
Instance Attribute Details
#day_of_month ⇒ Object
The day of the month the anchor should be. Ranges from 1 to 31.
289 290 291 |
# File 'lib/stripe/params/subscription_update_params.rb', line 289 def day_of_month @day_of_month end |
#hour ⇒ Object
The hour of the day the anchor should be. Ranges from 0 to 23.
291 292 293 |
# File 'lib/stripe/params/subscription_update_params.rb', line 291 def hour @hour end |
#minute ⇒ Object
The minute of the hour the anchor should be. Ranges from 0 to 59.
293 294 295 |
# File 'lib/stripe/params/subscription_update_params.rb', line 293 def minute @minute end |
#month ⇒ Object
The month to start full cycle periods. Ranges from 1 to 12.
295 296 297 |
# File 'lib/stripe/params/subscription_update_params.rb', line 295 def month @month end |
#second ⇒ Object
The second of the minute the anchor should be. Ranges from 0 to 59.
297 298 299 |
# File 'lib/stripe/params/subscription_update_params.rb', line 297 def second @second end |