Class: Stripe::SubscriptionUpdateParams::Item::BillingThresholds

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(usage_gte: nil) ⇒ BillingThresholds

Returns a new instance of BillingThresholds.



367
368
369
# File 'lib/stripe/params/subscription_update_params.rb', line 367

def initialize(usage_gte: nil)
  @usage_gte = usage_gte
end

Instance Attribute Details

#usage_gteObject

Number of units that meets the billing threshold to advance the subscription to a new billing period (e.g., it takes 10 $5 units to meet a $50 [monetary threshold](docs.stripe.com/api/subscriptions/update#update_subscription-billing_thresholds-amount_gte))



365
366
367
# File 'lib/stripe/params/subscription_update_params.rb', line 365

def usage_gte
  @usage_gte
end