Class: Stripe::SubscriptionUpdateParams::Item::CurrentTrial
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionUpdateParams::Item::CurrentTrial
- Defined in:
- lib/stripe/params/subscription_update_params.rb
Instance Attribute Summary collapse
-
#trial_offer ⇒ Object
The ID of the trial offer to apply to the subscription item.
Instance Method Summary collapse
-
#initialize(trial_offer: nil) ⇒ CurrentTrial
constructor
A new instance of CurrentTrial.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(trial_offer: nil) ⇒ CurrentTrial
Returns a new instance of CurrentTrial.
321 322 323 |
# File 'lib/stripe/params/subscription_update_params.rb', line 321 def initialize(trial_offer: nil) @trial_offer = trial_offer end |
Instance Attribute Details
#trial_offer ⇒ Object
The ID of the trial offer to apply to the subscription item.
319 320 321 |
# File 'lib/stripe/params/subscription_update_params.rb', line 319 def trial_offer @trial_offer end |