Class: Stripe::SubscriptionUpdateParams::Item::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionUpdateParams::Item::Discount
- Defined in:
- lib/stripe/params/subscription_update_params.rb
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
230 231 232 233 234 |
# File 'lib/stripe/params/subscription_update_params.rb', line 230 def initialize(coupon: nil, discount: nil, promotion_code: nil) @coupon = coupon @discount = discount @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
224 225 226 |
# File 'lib/stripe/params/subscription_update_params.rb', line 224 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
226 227 228 |
# File 'lib/stripe/params/subscription_update_params.rb', line 226 def discount @discount end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
228 229 230 |
# File 'lib/stripe/params/subscription_update_params.rb', line 228 def promotion_code @promotion_code end |