Class: Stripe::SubscriptionUpdateParams::Item::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_update_params.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



393
394
395
396
397
# File 'lib/stripe/params/subscription_update_params.rb', line 393

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



387
388
389
# File 'lib/stripe/params/subscription_update_params.rb', line 387

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



389
390
391
# File 'lib/stripe/params/subscription_update_params.rb', line 389

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



391
392
393
# File 'lib/stripe/params/subscription_update_params.rb', line 391

def type
  @type
end