Class: Stripe::SubscriptionUpdateParams::Item::Discount::Settings::ServicePeriodAnchorConfig::Custom
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionUpdateParams::Item::Discount::Settings::ServicePeriodAnchorConfig::Custom
- Defined in:
- lib/stripe/params/subscription_update_params.rb
Instance Attribute Summary collapse
-
#day_of_month ⇒ Object
The day of the month the anchor should be.
-
#hour ⇒ Object
The hour of the day the anchor should be.
-
#minute ⇒ Object
The minute of the hour the anchor should be.
-
#month ⇒ Object
The month to start full cycle periods.
-
#second ⇒ Object
The second of the minute the anchor should be.
Instance Method Summary collapse
-
#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom
constructor
A new instance of Custom.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom
Returns a new instance of Custom.
439 440 441 442 443 444 445 |
# File 'lib/stripe/params/subscription_update_params.rb', line 439 def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) @day_of_month = day_of_month @hour = hour @minute = minute @month = month @second = second end |
Instance Attribute Details
#day_of_month ⇒ Object
The day of the month the anchor should be. Ranges from 1 to 31.
429 430 431 |
# File 'lib/stripe/params/subscription_update_params.rb', line 429 def day_of_month @day_of_month end |
#hour ⇒ Object
The hour of the day the anchor should be. Ranges from 0 to 23.
431 432 433 |
# File 'lib/stripe/params/subscription_update_params.rb', line 431 def hour @hour end |
#minute ⇒ Object
The minute of the hour the anchor should be. Ranges from 0 to 59.
433 434 435 |
# File 'lib/stripe/params/subscription_update_params.rb', line 433 def minute @minute end |
#month ⇒ Object
The month to start full cycle periods. Ranges from 1 to 12.
435 436 437 |
# File 'lib/stripe/params/subscription_update_params.rb', line 435 def month @month end |
#second ⇒ Object
The second of the minute the anchor should be. Ranges from 0 to 59.
437 438 439 |
# File 'lib/stripe/params/subscription_update_params.rb', line 437 def second @second end |