Class: Stripe::SubscriptionUpdateParams::PaymentSettings

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_update_params.rb

Defined Under Namespace

Classes: PaymentMethodOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h

Constructor Details

#initialize(payment_method_options: nil, payment_method_types: nil, save_default_payment_method: nil) ⇒ PaymentSettings

Returns a new instance of PaymentSettings.



702
703
704
705
706
707
708
709
710
# File 'lib/stripe/params/subscription_update_params.rb', line 702

def initialize(
  payment_method_options: nil,
  payment_method_types: nil,
  save_default_payment_method: nil
)
  @payment_method_options = payment_method_options
  @payment_method_types = payment_method_types
  @save_default_payment_method = save_default_payment_method
end

Instance Attribute Details

#payment_method_optionsObject

Payment-method-specific configuration to provide to invoices created by the subscription.



696
697
698
# File 'lib/stripe/params/subscription_update_params.rb', line 696

def payment_method_options
  @payment_method_options
end

#payment_method_typesObject

The list of payment method types (e.g. card) to provide to the invoice’s PaymentIntent. If not set, Stripe attempts to automatically determine the types to use by looking at the invoice’s default payment method, the subscription’s default payment method, the customer’s default payment method, and your invoice template settings. Should not be specified with payment_method_configuration



698
699
700
# File 'lib/stripe/params/subscription_update_params.rb', line 698

def payment_method_types
  @payment_method_types
end

#save_default_payment_methodObject

Configure whether Stripe updates subscription.default_payment_method when payment succeeds. Defaults to off if unspecified.



700
701
702
# File 'lib/stripe/params/subscription_update_params.rb', line 700

def save_default_payment_method
  @save_default_payment_method
end