Class: Stripe::SubscriptionUpdateParams::PaymentSettings::PaymentMethodOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_update_params.rb

Defined Under Namespace

Classes: AcssDebit, Bancontact, Billie, Blik, Card, CustomerBalance, IdBankTransfer, Konbini, Payto, Pix, SepaDebit, Upi, UsBankAccount

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h

Constructor Details

#initialize(acss_debit: nil, bancontact: nil, billie: nil, blik: nil, card: nil, customer_balance: nil, id_bank_transfer: nil, konbini: nil, payto: nil, pix: nil, sepa_debit: nil, upi: nil, us_bank_account: nil) ⇒ PaymentMethodOptions

Returns a new instance of PaymentMethodOptions.



794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
# File 'lib/stripe/params/subscription_update_params.rb', line 794

def initialize(
  acss_debit: nil,
  bancontact: nil,
  billie: nil,
  blik: nil,
  card: nil,
  customer_balance: nil,
  id_bank_transfer: nil,
  konbini: nil,
  payto: nil,
  pix: nil,
  sepa_debit: nil,
  upi: nil,
  us_bank_account: nil
)
  @acss_debit = acss_debit
  @bancontact = bancontact
  @billie = billie
  @blik = blik
  @card = card
  @customer_balance = customer_balance
  @id_bank_transfer = id_bank_transfer
  @konbini = konbini
  @payto = payto
  @pix = pix
  @sepa_debit = sepa_debit
  @upi = upi
  @us_bank_account = 
end

Instance Attribute Details

#acss_debitObject

This sub-hash contains details about the Canadian pre-authorized debit payment method options to pass to the invoice’s PaymentIntent.



768
769
770
# File 'lib/stripe/params/subscription_update_params.rb', line 768

def acss_debit
  @acss_debit
end

#bancontactObject

This sub-hash contains details about the Bancontact payment method options to pass to the invoice’s PaymentIntent.



770
771
772
# File 'lib/stripe/params/subscription_update_params.rb', line 770

def bancontact
  @bancontact
end

#billieObject

This sub-hash contains details about the Billie payment method options to pass to the invoice’s PaymentIntent.



772
773
774
# File 'lib/stripe/params/subscription_update_params.rb', line 772

def billie
  @billie
end

#blikObject

This sub-hash contains details about the Blik payment method options to pass to the invoice’s PaymentIntent.



774
775
776
# File 'lib/stripe/params/subscription_update_params.rb', line 774

def blik
  @blik
end

#cardObject

This sub-hash contains details about the Card payment method options to pass to the invoice’s PaymentIntent.



776
777
778
# File 'lib/stripe/params/subscription_update_params.rb', line 776

def card
  @card
end

#customer_balanceObject

This sub-hash contains details about the Bank transfer payment method options to pass to the invoice’s PaymentIntent.



778
779
780
# File 'lib/stripe/params/subscription_update_params.rb', line 778

def customer_balance
  @customer_balance
end

#id_bank_transferObject

This sub-hash contains details about the Indonesia bank transfer payment method options to pass to the invoice’s PaymentIntent.



780
781
782
# File 'lib/stripe/params/subscription_update_params.rb', line 780

def id_bank_transfer
  @id_bank_transfer
end

#konbiniObject

This sub-hash contains details about the Konbini payment method options to pass to the invoice’s PaymentIntent.



782
783
784
# File 'lib/stripe/params/subscription_update_params.rb', line 782

def konbini
  @konbini
end

#paytoObject

This sub-hash contains details about the PayTo payment method options to pass to the invoice’s PaymentIntent.



784
785
786
# File 'lib/stripe/params/subscription_update_params.rb', line 784

def payto
  @payto
end

#pixObject

This sub-hash contains details about the Pix payment method options to pass to the invoice’s PaymentIntent.



786
787
788
# File 'lib/stripe/params/subscription_update_params.rb', line 786

def pix
  @pix
end

#sepa_debitObject

This sub-hash contains details about the SEPA Direct Debit payment method options to pass to the invoice’s PaymentIntent.



788
789
790
# File 'lib/stripe/params/subscription_update_params.rb', line 788

def sepa_debit
  @sepa_debit
end

#upiObject

This sub-hash contains details about the UPI payment method options to pass to the invoice’s PaymentIntent.



790
791
792
# File 'lib/stripe/params/subscription_update_params.rb', line 790

def upi
  @upi
end

#us_bank_accountObject

This sub-hash contains details about the ACH direct debit payment method options to pass to the invoice’s PaymentIntent.



792
793
794
# File 'lib/stripe/params/subscription_update_params.rb', line 792

def 
  @us_bank_account
end