Class: Stripe::SubscriptionUpdateParams::PaymentSettings::PaymentMethodOptions::Billie::CompanyDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_update_params.rb

Defined Under Namespace

Classes: RegisteredAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h

Constructor Details

#initialize(registered_address: nil, registered_name: nil, registration_number: nil, registration_type: nil, vat: nil) ⇒ CompanyDetails

Returns a new instance of CompanyDetails.



532
533
534
535
536
537
538
539
540
541
542
543
544
# File 'lib/stripe/params/subscription_update_params.rb', line 532

def initialize(
  registered_address: nil,
  registered_name: nil,
  registration_number: nil,
  registration_type: nil,
  vat: nil
)
  @registered_address = registered_address
  @registered_name = registered_name
  @registration_number = registration_number
  @registration_type = registration_type
  @vat = vat
end

Instance Attribute Details

#registered_address ⇒ Object

The address the company or entity is registered with.



522
523
524
# File 'lib/stripe/params/subscription_update_params.rb', line 522

def registered_address
  @registered_address
end

#registered_name ⇒ Object

Company or entity name.



524
525
526
# File 'lib/stripe/params/subscription_update_params.rb', line 524

def registered_name
  @registered_name
end

#registration_number ⇒ Object

The official registration number for the given registration type.



526
527
528
# File 'lib/stripe/params/subscription_update_params.rb', line 526

def registration_number
  @registration_number
end

#registration_type ⇒ Object

Type of registration the company or entity holds in their registered country.



528
529
530
# File 'lib/stripe/params/subscription_update_params.rb', line 528

def registration_type
  @registration_type
end

#vat ⇒ Object

VAT ID number.



530
531
532
# File 'lib/stripe/params/subscription_update_params.rb', line 530

def vat
  @vat
end