Class: Stripe::SubscriptionUpdateParams::PaymentSettings::PaymentMethodOptions::CustomerBalance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_update_params.rb

Defined Under Namespace

Classes: BankTransfer

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(bank_transfer: nil, funding_type: nil) ⇒ CustomerBalance

Returns a new instance of CustomerBalance.



608
609
610
611
# File 'lib/stripe/params/subscription_update_params.rb', line 608

def initialize(bank_transfer: nil, funding_type: nil)
  @bank_transfer = bank_transfer
  @funding_type = funding_type
end

Instance Attribute Details

#bank_transferObject

Configuration for the bank transfer funding type, if the ‘funding_type` is set to `bank_transfer`.



604
605
606
# File 'lib/stripe/params/subscription_update_params.rb', line 604

def bank_transfer
  @bank_transfer
end

#funding_typeObject

The funding method type to be used when there are not enough funds in the customer balance. Permitted values include: ‘bank_transfer`.



606
607
608
# File 'lib/stripe/params/subscription_update_params.rb', line 606

def funding_type
  @funding_type
end