Class: Stripe::SubscriptionUpdateParams::PaymentSettings::PaymentMethodOptions::Upi::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



837
838
839
840
841
842
# File 'lib/stripe/params/subscription_update_params.rb', line 837

def initialize(amount: nil, amount_type: nil, description: nil, end_date: nil)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



829
830
831
# File 'lib/stripe/params/subscription_update_params.rb', line 829

def amount
  @amount
end

#amount_typeObject

One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.



831
832
833
# File 'lib/stripe/params/subscription_update_params.rb', line 831

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



833
834
835
# File 'lib/stripe/params/subscription_update_params.rb', line 833

def description
  @description
end

#end_dateObject

End date of the mandate or subscription.



835
836
837
# File 'lib/stripe/params/subscription_update_params.rb', line 835

def end_date
  @end_date
end