Class: Stripe::SubscriptionUpdateParams::Prebilling

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(iterations: nil, update_behavior: nil) ⇒ Prebilling

Returns a new instance of Prebilling.



820
821
822
823
# File 'lib/stripe/params/subscription_update_params.rb', line 820

def initialize(iterations: nil, update_behavior: nil)
  @iterations = iterations
  @update_behavior = update_behavior
end

Instance Attribute Details

#iterationsObject

This is used to determine the number of billing cycles to prebill.



816
817
818
# File 'lib/stripe/params/subscription_update_params.rb', line 816

def iterations
  @iterations
end

#update_behaviorObject

Whether to cancel or preserve ‘prebilling` if the subscription is updated during the prebilled period. The default value is `reset`.



818
819
820
# File 'lib/stripe/params/subscription_update_params.rb', line 818

def update_behavior
  @update_behavior
end