Class: Stripe::SubscriptionUpdateParams::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount_percent: nil, destination: nil) ⇒ TransferData



571
572
573
574
# File 'lib/stripe/params/subscription_update_params.rb', line 571

def initialize(amount_percent: nil, destination: nil)
  @amount_percent = amount_percent
  @destination = destination
end

Instance Attribute Details

#amount_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination.



567
568
569
# File 'lib/stripe/params/subscription_update_params.rb', line 567

def amount_percent
  @amount_percent
end

#destinationObject

ID of an existing, connected Stripe account.



569
570
571
# File 'lib/stripe/params/subscription_update_params.rb', line 569

def destination
  @destination
end