Class: Stripe::Tax::Association
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Tax::Association
- Defined in:
- lib/stripe/resources/tax/association.rb
Overview
A Tax Association exposes the Tax Transactions that Stripe attempted to create on your behalf based on the PaymentIntent input
Defined Under Namespace
Classes: FindParams, TaxTransactionAttempt
Constant Summary collapse
- OBJECT_NAME =
"tax.association"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#calculation ⇒ Object
readonly
The [Tax Calculation](stripe.com/docs/api/tax/calculations/object) that was included in PaymentIntent.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#payment_intent ⇒ Object
readonly
The [PaymentIntent](stripe.com/docs/api/payment_intents/object) that this Tax Association is tracking.
-
#tax_transaction_attempts ⇒ Object
readonly
Information about the tax transactions linked to this payment intent.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
- .field_remappings ⇒ Object
-
.find(params = {}, opts = {}) ⇒ Object
Finds a tax association object by PaymentIntent id.
- .inner_class_types ⇒ Object
- .object_name ⇒ Object
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#calculation ⇒ Object (readonly)
The [Tax Calculation](stripe.com/docs/api/tax/calculations/object) that was included in PaymentIntent.
69 70 71 |
# File 'lib/stripe/resources/tax/association.rb', line 69 def calculation @calculation end |
#id ⇒ Object (readonly)
Unique identifier for the object.
71 72 73 |
# File 'lib/stripe/resources/tax/association.rb', line 71 def id @id end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
73 74 75 |
# File 'lib/stripe/resources/tax/association.rb', line 73 def object @object end |
#payment_intent ⇒ Object (readonly)
The [PaymentIntent](stripe.com/docs/api/payment_intents/object) that this Tax Association is tracking.
75 76 77 |
# File 'lib/stripe/resources/tax/association.rb', line 75 def payment_intent @payment_intent end |
#tax_transaction_attempts ⇒ Object (readonly)
Information about the tax transactions linked to this payment intent
77 78 79 |
# File 'lib/stripe/resources/tax/association.rb', line 77 def tax_transaction_attempts @tax_transaction_attempts end |
Class Method Details
.field_remappings ⇒ Object
93 94 95 |
# File 'lib/stripe/resources/tax/association.rb', line 93 def self.field_remappings @field_remappings = {} end |
.find(params = {}, opts = {}) ⇒ Object
Finds a tax association object by PaymentIntent id.
80 81 82 83 84 85 86 87 |
# File 'lib/stripe/resources/tax/association.rb', line 80 def self.find(params = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/tax/associations/find", params: params, opts: opts ) end |
.inner_class_types ⇒ Object
89 90 91 |
# File 'lib/stripe/resources/tax/association.rb', line 89 def self.inner_class_types @inner_class_types = { tax_transaction_attempts: TaxTransactionAttempt } end |
.object_name ⇒ Object
9 10 11 |
# File 'lib/stripe/resources/tax/association.rb', line 9 def self.object_name "tax.association" end |