Class: Stripe::Tax::Association::FindParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Association::FindParams
- Defined in:
- lib/stripe/resources/tax/association.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#payment_intent ⇒ Object
Valid [PaymentIntent](stripe.com/docs/api/payment_intents/object) id.
Instance Method Summary collapse
-
#initialize(expand: nil, payment_intent: nil) ⇒ FindParams
constructor
A new instance of FindParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, payment_intent: nil) ⇒ FindParams
Returns a new instance of FindParams.
39 40 41 42 |
# File 'lib/stripe/resources/tax/association.rb', line 39 def initialize(expand: nil, payment_intent: nil) @expand = @payment_intent = payment_intent end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
35 36 37 |
# File 'lib/stripe/resources/tax/association.rb', line 35 def @expand end |
#payment_intent ⇒ Object
Valid [PaymentIntent](stripe.com/docs/api/payment_intents/object) id
37 38 39 |
# File 'lib/stripe/resources/tax/association.rb', line 37 def payment_intent @payment_intent end |