Class: Stripe::Tax::AssociationService::FindParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::AssociationService::FindParams
- Defined in:
- lib/stripe/services/tax/association_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#payment_intent ⇒ Object
Valid [PaymentIntent](stripe.com/docs/api/payment_intents/object) id.
Instance Method Summary collapse
-
#initialize(expand: nil, payment_intent: nil) ⇒ FindParams
constructor
A new instance of FindParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, payment_intent: nil) ⇒ FindParams
Returns a new instance of FindParams.
13 14 15 16 |
# File 'lib/stripe/services/tax/association_service.rb', line 13 def initialize(expand: nil, payment_intent: nil) @expand = @payment_intent = payment_intent end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
9 10 11 |
# File 'lib/stripe/services/tax/association_service.rb', line 9 def @expand end |
#payment_intent ⇒ Object
Valid [PaymentIntent](stripe.com/docs/api/payment_intents/object) id
11 12 13 |
# File 'lib/stripe/services/tax/association_service.rb', line 11 def payment_intent @payment_intent end |