Class: Stripe::Tax::Calculation::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/tax/calculation.rb

Defined Under Namespace

Classes: CustomerDetails, LineItem, ShipFromDetails, ShippingCost

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(currency: nil, customer: nil, customer_details: nil, expand: nil, line_items: nil, ship_from_details: nil, shipping_cost: nil, tax_date: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
# File 'lib/stripe/resources/tax/calculation.rb', line 444

def initialize(
  currency: nil,
  customer: nil,
  customer_details: nil,
  expand: nil,
  line_items: nil,
  ship_from_details: nil,
  shipping_cost: nil,
  tax_date: nil
)
  @currency = currency
  @customer = customer
  @customer_details = customer_details
  @expand = expand
  @line_items = line_items
  @ship_from_details = ship_from_details
  @shipping_cost = shipping_cost
  @tax_date = tax_date
end

Instance Attribute Details

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



428
429
430
# File 'lib/stripe/resources/tax/calculation.rb', line 428

def currency
  @currency
end

#customerObject

The ID of an existing customer to use for this calculation. If provided, the customer’s address and tax IDs are copied to ‘customer_details`.



430
431
432
# File 'lib/stripe/resources/tax/calculation.rb', line 430

def customer
  @customer
end

#customer_detailsObject

Details about the customer, including address and tax IDs.



432
433
434
# File 'lib/stripe/resources/tax/calculation.rb', line 432

def customer_details
  @customer_details
end

#expandObject

Specifies which fields in the response should be expanded.



434
435
436
# File 'lib/stripe/resources/tax/calculation.rb', line 434

def expand
  @expand
end

#line_itemsObject

A list of items the customer is purchasing.



436
437
438
# File 'lib/stripe/resources/tax/calculation.rb', line 436

def line_items
  @line_items
end

#ship_from_detailsObject

Details about the address from which the goods are being shipped.



438
439
440
# File 'lib/stripe/resources/tax/calculation.rb', line 438

def ship_from_details
  @ship_from_details
end

#shipping_costObject

Shipping cost details to be used for the calculation.



440
441
442
# File 'lib/stripe/resources/tax/calculation.rb', line 440

def shipping_cost
  @shipping_cost
end

#tax_dateObject

Timestamp of date at which the tax rules and rates in effect applies for the calculation. Measured in seconds since the Unix epoch. Can be up to 48 hours in the past, and up to 48 hours in the future.



442
443
444
# File 'lib/stripe/resources/tax/calculation.rb', line 442

def tax_date
  @tax_date
end