Class: Stripe::Tax::Calculation::CreateParams::CustomerDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/tax/calculation.rb

Defined Under Namespace

Classes: Address, TaxId

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, address_source: nil, ip_address: nil, tax_ids: nil, taxability_override: nil) ⇒ CustomerDetails

Returns a new instance of CustomerDetails.



320
321
322
323
324
325
326
327
328
329
330
331
332
# File 'lib/stripe/resources/tax/calculation.rb', line 320

def initialize(
  address: nil,
  address_source: nil,
  ip_address: nil,
  tax_ids: nil,
  taxability_override: nil
)
  @address = address
  @address_source = address_source
  @ip_address = ip_address
  @tax_ids = tax_ids
  @taxability_override = taxability_override
end

Instance Attribute Details

#addressObject

The customer’s postal address (for example, home or business location).



310
311
312
# File 'lib/stripe/resources/tax/calculation.rb', line 310

def address
  @address
end

#address_sourceObject

The type of customer address provided.



312
313
314
# File 'lib/stripe/resources/tax/calculation.rb', line 312

def address_source
  @address_source
end

#ip_addressObject

The customer’s IP address (IPv4 or IPv6).



314
315
316
# File 'lib/stripe/resources/tax/calculation.rb', line 314

def ip_address
  @ip_address
end

#tax_idsObject

The customer’s tax IDs. Stripe Tax might consider a transaction with applicable tax IDs to be B2B, which might affect the tax calculation result. Stripe Tax doesn’t validate tax IDs for correctness.



316
317
318
# File 'lib/stripe/resources/tax/calculation.rb', line 316

def tax_ids
  @tax_ids
end

#taxability_overrideObject

Overrides the tax calculation result to allow you to not collect tax from your customer. Use this if you’ve manually checked your customer’s tax exemptions. Prefer providing the customer’s ‘tax_ids` where possible, which automatically determines whether `reverse_charge` applies.



318
319
320
# File 'lib/stripe/resources/tax/calculation.rb', line 318

def taxability_override
  @taxability_override
end