Class: Stripe::Tax::Calculation::CreateParams::ShipFromDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Calculation::CreateParams::ShipFromDetails
- Defined in:
- lib/stripe/resources/tax/calculation.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
The address from which the goods are being shipped from.
Instance Method Summary collapse
-
#initialize(address: nil) ⇒ ShipFromDetails
constructor
A new instance of ShipFromDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil) ⇒ ShipFromDetails
Returns a new instance of ShipFromDetails.
305 306 307 |
# File 'lib/stripe/resources/tax/calculation.rb', line 305 def initialize(address: nil) @address = address end |
Instance Attribute Details
#address ⇒ Object
The address from which the goods are being shipped from.
303 304 305 |
# File 'lib/stripe/resources/tax/calculation.rb', line 303 def address @address end |