Class: Stripe::Tax::Calculation::TaxBreakdown::TaxRateDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Tax::Calculation::TaxBreakdown::TaxRateDetails
- Defined in:
- lib/stripe/resources/tax/calculation.rb
Defined Under Namespace
Classes: FlatAmount
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#country ⇒ Object
readonly
Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
-
#flat_amount ⇒ Object
readonly
The amount of the tax rate when the ‘rate_type` is `flat_amount`.
-
#percentage_decimal ⇒ Object
readonly
The tax rate percentage as a string.
-
#rate_type ⇒ Object
readonly
Indicates the type of tax rate applied to the taxable amount.
-
#state ⇒ Object
readonly
State, county, province, or region.
-
#tax_type ⇒ Object
readonly
The tax type, such as ‘vat` or `sales_tax`.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#country ⇒ Object (readonly)
Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
158 159 160 |
# File 'lib/stripe/resources/tax/calculation.rb', line 158 def country @country end |
#flat_amount ⇒ Object (readonly)
The amount of the tax rate when the ‘rate_type` is `flat_amount`. Tax rates with `rate_type` `percentage` can vary based on the transaction, resulting in this field being `null`. This field exposes the amount and currency of the flat tax rate.
161 162 163 |
# File 'lib/stripe/resources/tax/calculation.rb', line 161 def flat_amount @flat_amount end |
#percentage_decimal ⇒ Object (readonly)
The tax rate percentage as a string. For example, 8.5% is represented as ‘“8.5”`.
164 165 166 |
# File 'lib/stripe/resources/tax/calculation.rb', line 164 def percentage_decimal @percentage_decimal end |
#rate_type ⇒ Object (readonly)
Indicates the type of tax rate applied to the taxable amount. This value can be ‘null` when no tax applies to the location.
167 168 169 |
# File 'lib/stripe/resources/tax/calculation.rb', line 167 def rate_type @rate_type end |
#state ⇒ Object (readonly)
State, county, province, or region.
170 171 172 |
# File 'lib/stripe/resources/tax/calculation.rb', line 170 def state @state end |
#tax_type ⇒ Object (readonly)
The tax type, such as ‘vat` or `sales_tax`.
173 174 175 |
# File 'lib/stripe/resources/tax/calculation.rb', line 173 def tax_type @tax_type end |