Class: Stripe::Tax::CalculationCreateParams::CustomerDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/tax/calculation_create_params.rb

Defined Under Namespace

Classes: Address, TaxId

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h

Constructor Details

#initialize(address: nil, address_source: nil, ip_address: nil, tax_ids: nil, taxability_override: nil) ⇒ CustomerDetails



61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/stripe/params/tax/calculation_create_params.rb', line 61

def initialize(
  address: nil,
  address_source: nil,
  ip_address: nil,
  tax_ids: nil,
  taxability_override: nil
)
  @address = address
  @address_source = address_source
  @ip_address = ip_address
  @tax_ids = tax_ids
  @taxability_override = taxability_override
end

Instance Attribute Details

#addressObject

The customer's postal address (for example, home or business location).



51
52
53
# File 'lib/stripe/params/tax/calculation_create_params.rb', line 51

def address
  @address
end

#address_sourceObject

The type of customer address provided.



53
54
55
# File 'lib/stripe/params/tax/calculation_create_params.rb', line 53

def address_source
  @address_source
end

#ip_addressObject

The customer's IP address (IPv4 or IPv6).



55
56
57
# File 'lib/stripe/params/tax/calculation_create_params.rb', line 55

def ip_address
  @ip_address
end

#tax_idsObject

The customer's tax IDs. Stripe Tax might consider a transaction with applicable tax IDs to be B2B, which might affect the tax calculation result. Stripe Tax doesn't validate tax IDs for correctness.



57
58
59
# File 'lib/stripe/params/tax/calculation_create_params.rb', line 57

def tax_ids
  @tax_ids
end

#taxability_overrideObject

Overrides the tax calculation result to allow you to not collect tax from your customer. Use this if you've manually checked your customer's tax exemptions. Prefer providing the customer's tax_ids where possible, which automatically determines whether reverse_charge applies.



59
60
61
# File 'lib/stripe/params/tax/calculation_create_params.rb', line 59

def taxability_override
  @taxability_override
end