Class: Stripe::Tax::Form::CaMrdp
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Tax::Form::CaMrdp
- Defined in:
- lib/stripe/resources/tax/form.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#reporting_period_end_date ⇒ Object
readonly
End date of the period represented by the information reported on the tax form.
-
#reporting_period_start_date ⇒ Object
readonly
Start date of the period represented by the information reported on the tax form.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#reporting_period_end_date ⇒ Object (readonly)
End date of the period represented by the information reported on the tax form.
34 35 36 |
# File 'lib/stripe/resources/tax/form.rb', line 34 def reporting_period_end_date @reporting_period_end_date end |
#reporting_period_start_date ⇒ Object (readonly)
Start date of the period represented by the information reported on the tax form.
36 37 38 |
# File 'lib/stripe/resources/tax/form.rb', line 36 def reporting_period_start_date @reporting_period_start_date end |
Class Method Details
.field_remappings ⇒ Object
42 43 44 |
# File 'lib/stripe/resources/tax/form.rb', line 42 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
38 39 40 |
# File 'lib/stripe/resources/tax/form.rb', line 38 def self.inner_class_types @inner_class_types = {} end |