Class: Stripe::Tax::Form::EuDac7
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Tax::Form::EuDac7
- Defined in:
- lib/stripe/resources/tax/form.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#reporting_period_end_date ⇒ Object
readonly
End date of the period represented by the information reported on the tax form.
-
#reporting_period_start_date ⇒ Object
readonly
Start date of the period represented by the information reported on the tax form.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#reporting_period_end_date ⇒ Object (readonly)
End date of the period represented by the information reported on the tax form.
33 34 35 |
# File 'lib/stripe/resources/tax/form.rb', line 33 def reporting_period_end_date @reporting_period_end_date end |
#reporting_period_start_date ⇒ Object (readonly)
Start date of the period represented by the information reported on the tax form.
35 36 37 |
# File 'lib/stripe/resources/tax/form.rb', line 35 def reporting_period_start_date @reporting_period_start_date end |