Class: Stripe::Tax::Form::FilingStatus::Jurisdiction
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Tax::Form::FilingStatus::Jurisdiction
- Defined in:
- lib/stripe/resources/tax/form.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#country ⇒ Object
readonly
Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
-
#level ⇒ Object
readonly
Indicates the level of the jurisdiction where the form was filed.
-
#state ⇒ Object
readonly
[ISO 3166-2 U.S. state code](en.wikipedia.org/wiki/ISO_3166-2:US), without country prefix, if any.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#country ⇒ Object (readonly)
Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
65 66 67 |
# File 'lib/stripe/resources/tax/form.rb', line 65 def country @country end |
#level ⇒ Object (readonly)
Indicates the level of the jurisdiction where the form was filed.
67 68 69 |
# File 'lib/stripe/resources/tax/form.rb', line 67 def level @level end |
#state ⇒ Object (readonly)
[ISO 3166-2 U.S. state code](en.wikipedia.org/wiki/ISO_3166-2:US), without country prefix, if any. For example, “NY” for New York, United States. Null for non-U.S. forms.
69 70 71 |
# File 'lib/stripe/resources/tax/form.rb', line 69 def state @state end |
Class Method Details
.field_remappings ⇒ Object
75 76 77 |
# File 'lib/stripe/resources/tax/form.rb', line 75 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
71 72 73 |
# File 'lib/stripe/resources/tax/form.rb', line 71 def self.inner_class_types @inner_class_types = {} end |