Class: Stripe::Tax::Form::ListParams::Payee

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/tax/form.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account: nil, external_reference: nil, type: nil) ⇒ Payee

Returns a new instance of Payee.



102
103
104
105
106
# File 'lib/stripe/resources/tax/form.rb', line 102

def initialize(account: nil, external_reference: nil, type: nil)
  @account = 
  @external_reference = external_reference
  @type = type
end

Instance Attribute Details

#accountObject

The ID of the Stripe account whose forms will be retrieved.



96
97
98
# File 'lib/stripe/resources/tax/form.rb', line 96

def 
  @account
end

#external_referenceObject

The external reference to the payee whose forms will be retrieved.



98
99
100
# File 'lib/stripe/resources/tax/form.rb', line 98

def external_reference
  @external_reference
end

#typeObject

Specifies the payee type. Either ‘account` or `external_reference`.



100
101
102
# File 'lib/stripe/resources/tax/form.rb', line 100

def type
  @type
end