Class: Stripe::Tax::Form::PdfParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Form::PdfParams
- Defined in:
- lib/stripe/resources/tax/form.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ PdfParams
constructor
A new instance of PdfParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ PdfParams
Returns a new instance of PdfParams.
151 152 153 |
# File 'lib/stripe/resources/tax/form.rb', line 151 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
149 150 151 |
# File 'lib/stripe/resources/tax/form.rb', line 149 def @expand end |