Class: Stripe::Tax::FormListParams::Payee

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/tax/form_list_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(account: nil, external_reference: nil, type: nil) ⇒ Payee

Returns a new instance of Payee.



15
16
17
18
19
# File 'lib/stripe/params/tax/form_list_params.rb', line 15

def initialize(account: nil, external_reference: nil, type: nil)
  @account = 
  @external_reference = external_reference
  @type = type
end

Instance Attribute Details

#accountObject

The ID of the Stripe account whose forms will be retrieved.



9
10
11
# File 'lib/stripe/params/tax/form_list_params.rb', line 9

def 
  @account
end

#external_referenceObject

The external reference to the payee whose forms will be retrieved.



11
12
13
# File 'lib/stripe/params/tax/form_list_params.rb', line 11

def external_reference
  @external_reference
end

#typeObject

Specifies the payee type. Either ‘account` or `external_reference`.



13
14
15
# File 'lib/stripe/params/tax/form_list_params.rb', line 13

def type
  @type
end