Class: Stripe::Tax::FormService::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::FormService::ListParams
- Defined in:
- lib/stripe/services/tax/form_service.rb
Defined Under Namespace
Classes: Payee
Instance Attribute Summary collapse
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#payee ⇒ Object
The payee whose volume is represented on the tax form.
-
#starting_after ⇒ Object
A cursor for use in pagination.
-
#type ⇒ Object
An optional filter on the list, based on the object ‘type` field.
Instance Method Summary collapse
-
#initialize(ending_before: nil, expand: nil, limit: nil, payee: nil, starting_after: nil, type: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(ending_before: nil, expand: nil, limit: nil, payee: nil, starting_after: nil, type: nil) ⇒ ListParams
Returns a new instance of ListParams.
42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/stripe/services/tax/form_service.rb', line 42 def initialize( ending_before: nil, expand: nil, limit: nil, payee: nil, starting_after: nil, type: nil ) @ending_before = ending_before @expand = @limit = limit @payee = payee @starting_after = starting_after @type = type end |
Instance Attribute Details
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
25 26 27 |
# File 'lib/stripe/services/tax/form_service.rb', line 25 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
28 29 30 |
# File 'lib/stripe/services/tax/form_service.rb', line 28 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
31 32 33 |
# File 'lib/stripe/services/tax/form_service.rb', line 31 def limit @limit end |
#payee ⇒ Object
The payee whose volume is represented on the tax form.
34 35 36 |
# File 'lib/stripe/services/tax/form_service.rb', line 34 def payee @payee end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
37 38 39 |
# File 'lib/stripe/services/tax/form_service.rb', line 37 def starting_after @starting_after end |
#type ⇒ Object
An optional filter on the list, based on the object ‘type` field. Without the filter, the list includes all current and future tax form types. If your integration expects only one type of tax form in the response, make sure to provide a type value in the request.
40 41 42 |
# File 'lib/stripe/services/tax/form_service.rb', line 40 def type @type end |