Class: Stripe::Tax::FormService::ListParams::Payee

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/tax/form_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account: nil, external_reference: nil, type: nil) ⇒ Payee

Returns a new instance of Payee.



18
19
20
21
22
# File 'lib/stripe/services/tax/form_service.rb', line 18

def initialize(account: nil, external_reference: nil, type: nil)
  @account = 
  @external_reference = external_reference
  @type = type
end

Instance Attribute Details

#accountObject

The ID of the Stripe account whose forms will be retrieved.



10
11
12
# File 'lib/stripe/services/tax/form_service.rb', line 10

def 
  @account
end

#external_referenceObject

The external reference to the payee whose forms will be retrieved.



13
14
15
# File 'lib/stripe/services/tax/form_service.rb', line 13

def external_reference
  @external_reference
end

#typeObject

Specifies the payee type. Either ‘account` or `external_reference`.



16
17
18
# File 'lib/stripe/services/tax/form_service.rb', line 16

def type
  @type
end