Class: Stripe::Tax::LocationCreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/tax/location_create_params.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(address: nil, description: nil, expand: nil, type: nil) ⇒ LocationCreateParams

Returns a new instance of LocationCreateParams.



46
47
48
49
50
51
# File 'lib/stripe/params/tax/location_create_params.rb', line 46

def initialize(address: nil, description: nil, expand: nil, type: nil)
  @address = address
  @description = description
  @expand = expand
  @type = type
end

Instance Attribute Details

#addressObject

The physical address of the tax location.



38
39
40
# File 'lib/stripe/params/tax/location_create_params.rb', line 38

def address
  @address
end

#descriptionObject

Details to identify the tax location by its venue, types of events held, or available services, such as “A spacious auditorium suitable for large concerts and events.”.



40
41
42
# File 'lib/stripe/params/tax/location_create_params.rb', line 40

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



42
43
44
# File 'lib/stripe/params/tax/location_create_params.rb', line 42

def expand
  @expand
end

#typeObject

The type of tax location. The only supported value is “performance”.



44
45
46
# File 'lib/stripe/params/tax/location_create_params.rb', line 44

def type
  @type
end