Class: Stripe::Tax::Registration::CountryOptions::Us::StateSalesTax::Election
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Tax::Registration::CountryOptions::Us::StateSalesTax::Election
- Defined in:
- lib/stripe/resources/tax/registration.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#jurisdiction ⇒ Object
readonly
A [FIPS code](www.census.gov/library/reference/code-lists/ansi.html) representing the local jurisdiction.
-
#type ⇒ Object
readonly
The type of the election for the state sales tax registration.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#jurisdiction ⇒ Object (readonly)
A [FIPS code](www.census.gov/library/reference/code-lists/ansi.html) representing the local jurisdiction.
1869 1870 1871 |
# File 'lib/stripe/resources/tax/registration.rb', line 1869 def jurisdiction @jurisdiction end |
#type ⇒ Object (readonly)
The type of the election for the state sales tax registration.
1871 1872 1873 |
# File 'lib/stripe/resources/tax/registration.rb', line 1871 def type @type end |
Class Method Details
.field_remappings ⇒ Object
1877 1878 1879 |
# File 'lib/stripe/resources/tax/registration.rb', line 1877 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1873 1874 1875 |
# File 'lib/stripe/resources/tax/registration.rb', line 1873 def self.inner_class_types @inner_class_types = {} end |