Class: Stripe::Tax::Registration::CreateParams::CountryOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/tax/registration.rb

Defined Under Namespace

Classes: Ae, Al, Am, Ao, At, Au, Aw, Az, Ba, Bb, Bd, Be, Bf, Bg, Bh, Bj, Bs, By, Ca, Cd, Ch, Cl, Cm, Co, Cr, Cv, Cy, Cz, De, Dk, Ec, Ee, Eg, Es, Et, Fi, Fr, Gb, Ge, Gn, Gr, Hr, Hu, Id, Ie, In, Is, It, Jp, Ke, Kg, Kh, Kr, Kz, La, Lt, Lu, Lv, Ma, Md, Me, Mk, Mr, Mt, Mx, My, Ng, Nl, No, Np, Nz, Om, Pe, Ph, Pl, Pt, Ro, Rs, Ru, Sa, Se, Sg, Si, Sk, Sn, Sr, Th, Tj, Tr, Tz, Ua, Ug, Us, Uy, Uz, Vn, Za, Zm, Zw

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(ae: nil, al: nil, am: nil, ao: nil, at: nil, au: nil, aw: nil, az: nil, ba: nil, bb: nil, bd: nil, be: nil, bf: nil, bg: nil, bh: nil, bj: nil, bs: nil, by: nil, ca: nil, cd: nil, ch: nil, cl: nil, cm: nil, co: nil, cr: nil, cv: nil, cy: nil, cz: nil, de: nil, dk: nil, ec: nil, ee: nil, eg: nil, es: nil, et: nil, fi: nil, fr: nil, gb: nil, ge: nil, gn: nil, gr: nil, hr: nil, hu: nil, id: nil, ie: nil, in_: nil, is: nil, it: nil, jp: nil, ke: nil, kg: nil, kh: nil, kr: nil, kz: nil, la: nil, lt: nil, lu: nil, lv: nil, ma: nil, md: nil, me: nil, mk: nil, mr: nil, mt: nil, mx: nil, my: nil, ng: nil, nl: nil, no: nil, np: nil, nz: nil, om: nil, pe: nil, ph: nil, pl: nil, pt: nil, ro: nil, rs: nil, ru: nil, sa: nil, se: nil, sg: nil, si: nil, sk: nil, sn: nil, sr: nil, th: nil, tj: nil, tr: nil, tz: nil, ua: nil, ug: nil, us: nil, uy: nil, uz: nil, vn: nil, za: nil, zm: nil, zw: nil) ⇒ CountryOptions

Returns a new instance of CountryOptions.



3995
3996
3997
3998
3999
4000
4001
4002
4003
4004
4005
4006
4007
4008
4009
4010
4011
4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
4032
4033
4034
4035
4036
4037
4038
4039
4040
4041
4042
4043
4044
4045
4046
4047
4048
4049
4050
4051
4052
4053
4054
4055
4056
4057
4058
4059
4060
4061
4062
4063
4064
4065
4066
4067
4068
4069
4070
4071
4072
4073
4074
4075
4076
4077
4078
4079
4080
4081
4082
4083
4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
4094
4095
4096
4097
4098
4099
4100
4101
4102
4103
4104
4105
4106
4107
4108
4109
4110
4111
4112
4113
4114
4115
4116
4117
4118
4119
4120
4121
4122
4123
4124
4125
4126
4127
4128
4129
4130
4131
4132
4133
4134
4135
4136
4137
4138
4139
4140
4141
4142
4143
4144
4145
4146
4147
4148
4149
4150
4151
4152
4153
4154
4155
4156
4157
4158
4159
4160
4161
4162
4163
4164
4165
4166
4167
4168
4169
4170
4171
4172
4173
4174
4175
4176
4177
4178
4179
4180
4181
4182
4183
4184
4185
4186
4187
4188
4189
4190
4191
4192
4193
4194
4195
# File 'lib/stripe/resources/tax/registration.rb', line 3995

def initialize(
  ae: nil,
  al: nil,
  am: nil,
  ao: nil,
  at: nil,
  au: nil,
  aw: nil,
  az: nil,
  ba: nil,
  bb: nil,
  bd: nil,
  be: nil,
  bf: nil,
  bg: nil,
  bh: nil,
  bj: nil,
  bs: nil,
  by: nil,
  ca: nil,
  cd: nil,
  ch: nil,
  cl: nil,
  cm: nil,
  co: nil,
  cr: nil,
  cv: nil,
  cy: nil,
  cz: nil,
  de: nil,
  dk: nil,
  ec: nil,
  ee: nil,
  eg: nil,
  es: nil,
  et: nil,
  fi: nil,
  fr: nil,
  gb: nil,
  ge: nil,
  gn: nil,
  gr: nil,
  hr: nil,
  hu: nil,
  id: nil,
  ie: nil,
  in_: nil,
  is: nil,
  it: nil,
  jp: nil,
  ke: nil,
  kg: nil,
  kh: nil,
  kr: nil,
  kz: nil,
  la: nil,
  lt: nil,
  lu: nil,
  lv: nil,
  ma: nil,
  md: nil,
  me: nil,
  mk: nil,
  mr: nil,
  mt: nil,
  mx: nil,
  my: nil,
  ng: nil,
  nl: nil,
  no: nil,
  np: nil,
  nz: nil,
  om: nil,
  pe: nil,
  ph: nil,
  pl: nil,
  pt: nil,
  ro: nil,
  rs: nil,
  ru: nil,
  sa: nil,
  se: nil,
  sg: nil,
  si: nil,
  sk: nil,
  sn: nil,
  sr: nil,
  th: nil,
  tj: nil,
  tr: nil,
  tz: nil,
  ua: nil,
  ug: nil,
  us: nil,
  uy: nil,
  uz: nil,
  vn: nil,
  za: nil,
  zm: nil,
  zw: nil
)
  @ae = ae
  @al = al
  @am = am
  @ao = ao
  @at = at
  @au = au
  @aw = aw
  @az = az
  @ba = ba
  @bb = bb
  @bd = bd
  @be = be
  @bf = bf
  @bg = bg
  @bh = bh
  @bj = bj
  @bs = bs
  @by = by
  @ca = ca
  @cd = cd
  @ch = ch
  @cl = cl
  @cm = cm
  @co = co
  @cr = cr
  @cv = cv
  @cy = cy
  @cz = cz
  @de = de
  @dk = dk
  @ec = ec
  @ee = ee
  @eg = eg
  @es = es
  @et = et
  @fi = fi
  @fr = fr
  @gb = gb
  @ge = ge
  @gn = gn
  @gr = gr
  @hr = hr
  @hu = hu
  @id = id
  @ie = ie
  @in = in_
  @is = is
  @it = it
  @jp = jp
  @ke = ke
  @kg = kg
  @kh = kh
  @kr = kr
  @kz = kz
  @la = la
  @lt = lt
  @lu = lu
  @lv = lv
  @ma = ma
  @md = md
  @me = me
  @mk = mk
  @mr = mr
  @mt = mt
  @mx = mx
  @my = my
  @ng = ng
  @nl = nl
  @no = no
  @np = np
  @nz = nz
  @om = om
  @pe = pe
  @ph = ph
  @pl = pl
  @pt = pt
  @ro = ro
  @rs = rs
  @ru = ru
  @sa = sa
  @se = se
  @sg = sg
  @si = si
  @sk = sk
  @sn = sn
  @sr = sr
  @th = th
  @tj = tj
  @tr = tr
  @tz = tz
  @ua = ua
  @ug = ug
  @us = us
  @uy = uy
  @uz = uz
  @vn = vn
  @za = za
  @zm = zm
  @zw = zw
end

Instance Attribute Details

#aeObject

Options for the registration in AE.



3797
3798
3799
# File 'lib/stripe/resources/tax/registration.rb', line 3797

def ae
  @ae
end

#alObject

Options for the registration in AL.



3799
3800
3801
# File 'lib/stripe/resources/tax/registration.rb', line 3799

def al
  @al
end

#amObject

Options for the registration in AM.



3801
3802
3803
# File 'lib/stripe/resources/tax/registration.rb', line 3801

def am
  @am
end

#aoObject

Options for the registration in AO.



3803
3804
3805
# File 'lib/stripe/resources/tax/registration.rb', line 3803

def ao
  @ao
end

#atObject

Options for the registration in AT.



3805
3806
3807
# File 'lib/stripe/resources/tax/registration.rb', line 3805

def at
  @at
end

#auObject

Options for the registration in AU.



3807
3808
3809
# File 'lib/stripe/resources/tax/registration.rb', line 3807

def au
  @au
end

#awObject

Options for the registration in AW.



3809
3810
3811
# File 'lib/stripe/resources/tax/registration.rb', line 3809

def aw
  @aw
end

#azObject

Options for the registration in AZ.



3811
3812
3813
# File 'lib/stripe/resources/tax/registration.rb', line 3811

def az
  @az
end

#baObject

Options for the registration in BA.



3813
3814
3815
# File 'lib/stripe/resources/tax/registration.rb', line 3813

def ba
  @ba
end

#bbObject

Options for the registration in BB.



3815
3816
3817
# File 'lib/stripe/resources/tax/registration.rb', line 3815

def bb
  @bb
end

#bdObject

Options for the registration in BD.



3817
3818
3819
# File 'lib/stripe/resources/tax/registration.rb', line 3817

def bd
  @bd
end

#beObject

Options for the registration in BE.



3819
3820
3821
# File 'lib/stripe/resources/tax/registration.rb', line 3819

def be
  @be
end

#bfObject

Options for the registration in BF.



3821
3822
3823
# File 'lib/stripe/resources/tax/registration.rb', line 3821

def bf
  @bf
end

#bgObject

Options for the registration in BG.



3823
3824
3825
# File 'lib/stripe/resources/tax/registration.rb', line 3823

def bg
  @bg
end

#bhObject

Options for the registration in BH.



3825
3826
3827
# File 'lib/stripe/resources/tax/registration.rb', line 3825

def bh
  @bh
end

#bjObject

Options for the registration in BJ.



3827
3828
3829
# File 'lib/stripe/resources/tax/registration.rb', line 3827

def bj
  @bj
end

#bsObject

Options for the registration in BS.



3829
3830
3831
# File 'lib/stripe/resources/tax/registration.rb', line 3829

def bs
  @bs
end

#byObject

Options for the registration in BY.



3831
3832
3833
# File 'lib/stripe/resources/tax/registration.rb', line 3831

def by
  @by
end

#caObject

Options for the registration in CA.



3833
3834
3835
# File 'lib/stripe/resources/tax/registration.rb', line 3833

def ca
  @ca
end

#cdObject

Options for the registration in CD.



3835
3836
3837
# File 'lib/stripe/resources/tax/registration.rb', line 3835

def cd
  @cd
end

#chObject

Options for the registration in CH.



3837
3838
3839
# File 'lib/stripe/resources/tax/registration.rb', line 3837

def ch
  @ch
end

#clObject

Options for the registration in CL.



3839
3840
3841
# File 'lib/stripe/resources/tax/registration.rb', line 3839

def cl
  @cl
end

#cmObject

Options for the registration in CM.



3841
3842
3843
# File 'lib/stripe/resources/tax/registration.rb', line 3841

def cm
  @cm
end

#coObject

Options for the registration in CO.



3843
3844
3845
# File 'lib/stripe/resources/tax/registration.rb', line 3843

def co
  @co
end

#crObject

Options for the registration in CR.



3845
3846
3847
# File 'lib/stripe/resources/tax/registration.rb', line 3845

def cr
  @cr
end

#cvObject

Options for the registration in CV.



3847
3848
3849
# File 'lib/stripe/resources/tax/registration.rb', line 3847

def cv
  @cv
end

#cyObject

Options for the registration in CY.



3849
3850
3851
# File 'lib/stripe/resources/tax/registration.rb', line 3849

def cy
  @cy
end

#czObject

Options for the registration in CZ.



3851
3852
3853
# File 'lib/stripe/resources/tax/registration.rb', line 3851

def cz
  @cz
end

#deObject

Options for the registration in DE.



3853
3854
3855
# File 'lib/stripe/resources/tax/registration.rb', line 3853

def de
  @de
end

#dkObject

Options for the registration in DK.



3855
3856
3857
# File 'lib/stripe/resources/tax/registration.rb', line 3855

def dk
  @dk
end

#ecObject

Options for the registration in EC.



3857
3858
3859
# File 'lib/stripe/resources/tax/registration.rb', line 3857

def ec
  @ec
end

#eeObject

Options for the registration in EE.



3859
3860
3861
# File 'lib/stripe/resources/tax/registration.rb', line 3859

def ee
  @ee
end

#egObject

Options for the registration in EG.



3861
3862
3863
# File 'lib/stripe/resources/tax/registration.rb', line 3861

def eg
  @eg
end

#esObject

Options for the registration in ES.



3863
3864
3865
# File 'lib/stripe/resources/tax/registration.rb', line 3863

def es
  @es
end

#etObject

Options for the registration in ET.



3865
3866
3867
# File 'lib/stripe/resources/tax/registration.rb', line 3865

def et
  @et
end

#fiObject

Options for the registration in FI.



3867
3868
3869
# File 'lib/stripe/resources/tax/registration.rb', line 3867

def fi
  @fi
end

#frObject

Options for the registration in FR.



3869
3870
3871
# File 'lib/stripe/resources/tax/registration.rb', line 3869

def fr
  @fr
end

#gbObject

Options for the registration in GB.



3871
3872
3873
# File 'lib/stripe/resources/tax/registration.rb', line 3871

def gb
  @gb
end

#geObject

Options for the registration in GE.



3873
3874
3875
# File 'lib/stripe/resources/tax/registration.rb', line 3873

def ge
  @ge
end

#gnObject

Options for the registration in GN.



3875
3876
3877
# File 'lib/stripe/resources/tax/registration.rb', line 3875

def gn
  @gn
end

#grObject

Options for the registration in GR.



3877
3878
3879
# File 'lib/stripe/resources/tax/registration.rb', line 3877

def gr
  @gr
end

#hrObject

Options for the registration in HR.



3879
3880
3881
# File 'lib/stripe/resources/tax/registration.rb', line 3879

def hr
  @hr
end

#huObject

Options for the registration in HU.



3881
3882
3883
# File 'lib/stripe/resources/tax/registration.rb', line 3881

def hu
  @hu
end

#idObject

Options for the registration in ID.



3883
3884
3885
# File 'lib/stripe/resources/tax/registration.rb', line 3883

def id
  @id
end

#ieObject

Options for the registration in IE.



3885
3886
3887
# File 'lib/stripe/resources/tax/registration.rb', line 3885

def ie
  @ie
end

#inObject

Options for the registration in IN.



3887
3888
3889
# File 'lib/stripe/resources/tax/registration.rb', line 3887

def in
  @in
end

#isObject

Options for the registration in IS.



3889
3890
3891
# File 'lib/stripe/resources/tax/registration.rb', line 3889

def is
  @is
end

#itObject

Options for the registration in IT.



3891
3892
3893
# File 'lib/stripe/resources/tax/registration.rb', line 3891

def it
  @it
end

#jpObject

Options for the registration in JP.



3893
3894
3895
# File 'lib/stripe/resources/tax/registration.rb', line 3893

def jp
  @jp
end

#keObject

Options for the registration in KE.



3895
3896
3897
# File 'lib/stripe/resources/tax/registration.rb', line 3895

def ke
  @ke
end

#kgObject

Options for the registration in KG.



3897
3898
3899
# File 'lib/stripe/resources/tax/registration.rb', line 3897

def kg
  @kg
end

#khObject

Options for the registration in KH.



3899
3900
3901
# File 'lib/stripe/resources/tax/registration.rb', line 3899

def kh
  @kh
end

#krObject

Options for the registration in KR.



3901
3902
3903
# File 'lib/stripe/resources/tax/registration.rb', line 3901

def kr
  @kr
end

#kzObject

Options for the registration in KZ.



3903
3904
3905
# File 'lib/stripe/resources/tax/registration.rb', line 3903

def kz
  @kz
end

#laObject

Options for the registration in LA.



3905
3906
3907
# File 'lib/stripe/resources/tax/registration.rb', line 3905

def la
  @la
end

#ltObject

Options for the registration in LT.



3907
3908
3909
# File 'lib/stripe/resources/tax/registration.rb', line 3907

def lt
  @lt
end

#luObject

Options for the registration in LU.



3909
3910
3911
# File 'lib/stripe/resources/tax/registration.rb', line 3909

def lu
  @lu
end

#lvObject

Options for the registration in LV.



3911
3912
3913
# File 'lib/stripe/resources/tax/registration.rb', line 3911

def lv
  @lv
end

#maObject

Options for the registration in MA.



3913
3914
3915
# File 'lib/stripe/resources/tax/registration.rb', line 3913

def ma
  @ma
end

#mdObject

Options for the registration in MD.



3915
3916
3917
# File 'lib/stripe/resources/tax/registration.rb', line 3915

def md
  @md
end

#meObject

Options for the registration in ME.



3917
3918
3919
# File 'lib/stripe/resources/tax/registration.rb', line 3917

def me
  @me
end

#mkObject

Options for the registration in MK.



3919
3920
3921
# File 'lib/stripe/resources/tax/registration.rb', line 3919

def mk
  @mk
end

#mrObject

Options for the registration in MR.



3921
3922
3923
# File 'lib/stripe/resources/tax/registration.rb', line 3921

def mr
  @mr
end

#mtObject

Options for the registration in MT.



3923
3924
3925
# File 'lib/stripe/resources/tax/registration.rb', line 3923

def mt
  @mt
end

#mxObject

Options for the registration in MX.



3925
3926
3927
# File 'lib/stripe/resources/tax/registration.rb', line 3925

def mx
  @mx
end

#myObject

Options for the registration in MY.



3927
3928
3929
# File 'lib/stripe/resources/tax/registration.rb', line 3927

def my
  @my
end

#ngObject

Options for the registration in NG.



3929
3930
3931
# File 'lib/stripe/resources/tax/registration.rb', line 3929

def ng
  @ng
end

#nlObject

Options for the registration in NL.



3931
3932
3933
# File 'lib/stripe/resources/tax/registration.rb', line 3931

def nl
  @nl
end

#noObject

Options for the registration in NO.



3933
3934
3935
# File 'lib/stripe/resources/tax/registration.rb', line 3933

def no
  @no
end

#npObject

Options for the registration in NP.



3935
3936
3937
# File 'lib/stripe/resources/tax/registration.rb', line 3935

def np
  @np
end

#nzObject

Options for the registration in NZ.



3937
3938
3939
# File 'lib/stripe/resources/tax/registration.rb', line 3937

def nz
  @nz
end

#omObject

Options for the registration in OM.



3939
3940
3941
# File 'lib/stripe/resources/tax/registration.rb', line 3939

def om
  @om
end

#peObject

Options for the registration in PE.



3941
3942
3943
# File 'lib/stripe/resources/tax/registration.rb', line 3941

def pe
  @pe
end

#phObject

Options for the registration in PH.



3943
3944
3945
# File 'lib/stripe/resources/tax/registration.rb', line 3943

def ph
  @ph
end

#plObject

Options for the registration in PL.



3945
3946
3947
# File 'lib/stripe/resources/tax/registration.rb', line 3945

def pl
  @pl
end

#ptObject

Options for the registration in PT.



3947
3948
3949
# File 'lib/stripe/resources/tax/registration.rb', line 3947

def pt
  @pt
end

#roObject

Options for the registration in RO.



3949
3950
3951
# File 'lib/stripe/resources/tax/registration.rb', line 3949

def ro
  @ro
end

#rsObject

Options for the registration in RS.



3951
3952
3953
# File 'lib/stripe/resources/tax/registration.rb', line 3951

def rs
  @rs
end

#ruObject

Options for the registration in RU.



3953
3954
3955
# File 'lib/stripe/resources/tax/registration.rb', line 3953

def ru
  @ru
end

#saObject

Options for the registration in SA.



3955
3956
3957
# File 'lib/stripe/resources/tax/registration.rb', line 3955

def sa
  @sa
end

#seObject

Options for the registration in SE.



3957
3958
3959
# File 'lib/stripe/resources/tax/registration.rb', line 3957

def se
  @se
end

#sgObject

Options for the registration in SG.



3959
3960
3961
# File 'lib/stripe/resources/tax/registration.rb', line 3959

def sg
  @sg
end

#siObject

Options for the registration in SI.



3961
3962
3963
# File 'lib/stripe/resources/tax/registration.rb', line 3961

def si
  @si
end

#skObject

Options for the registration in SK.



3963
3964
3965
# File 'lib/stripe/resources/tax/registration.rb', line 3963

def sk
  @sk
end

#snObject

Options for the registration in SN.



3965
3966
3967
# File 'lib/stripe/resources/tax/registration.rb', line 3965

def sn
  @sn
end

#srObject

Options for the registration in SR.



3967
3968
3969
# File 'lib/stripe/resources/tax/registration.rb', line 3967

def sr
  @sr
end

#thObject

Options for the registration in TH.



3969
3970
3971
# File 'lib/stripe/resources/tax/registration.rb', line 3969

def th
  @th
end

#tjObject

Options for the registration in TJ.



3971
3972
3973
# File 'lib/stripe/resources/tax/registration.rb', line 3971

def tj
  @tj
end

#trObject

Options for the registration in TR.



3973
3974
3975
# File 'lib/stripe/resources/tax/registration.rb', line 3973

def tr
  @tr
end

#tzObject

Options for the registration in TZ.



3975
3976
3977
# File 'lib/stripe/resources/tax/registration.rb', line 3975

def tz
  @tz
end

#uaObject

Options for the registration in UA.



3977
3978
3979
# File 'lib/stripe/resources/tax/registration.rb', line 3977

def ua
  @ua
end

#ugObject

Options for the registration in UG.



3979
3980
3981
# File 'lib/stripe/resources/tax/registration.rb', line 3979

def ug
  @ug
end

#usObject

Options for the registration in US.



3981
3982
3983
# File 'lib/stripe/resources/tax/registration.rb', line 3981

def us
  @us
end

#uyObject

Options for the registration in UY.



3983
3984
3985
# File 'lib/stripe/resources/tax/registration.rb', line 3983

def uy
  @uy
end

#uzObject

Options for the registration in UZ.



3985
3986
3987
# File 'lib/stripe/resources/tax/registration.rb', line 3985

def uz
  @uz
end

#vnObject

Options for the registration in VN.



3987
3988
3989
# File 'lib/stripe/resources/tax/registration.rb', line 3987

def vn
  @vn
end

#zaObject

Options for the registration in ZA.



3989
3990
3991
# File 'lib/stripe/resources/tax/registration.rb', line 3989

def za
  @za
end

#zmObject

Options for the registration in ZM.



3991
3992
3993
# File 'lib/stripe/resources/tax/registration.rb', line 3991

def zm
  @zm
end

#zwObject

Options for the registration in ZW.



3993
3994
3995
# File 'lib/stripe/resources/tax/registration.rb', line 3993

def zw
  @zw
end