Class: Stripe::Tax::Registration::CreateParams::CountryOptions::At
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Registration::CreateParams::CountryOptions::At
- Defined in:
- lib/stripe/resources/tax/registration.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ At
constructor
A new instance of At.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ At
Returns a new instance of At.
1072 1073 1074 1075 |
# File 'lib/stripe/resources/tax/registration.rb', line 1072 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
1068 1069 1070 |
# File 'lib/stripe/resources/tax/registration.rb', line 1068 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
1070 1071 1072 |
# File 'lib/stripe/resources/tax/registration.rb', line 1070 def type @type end |