Class: Stripe::Tax::Registration::CreateParams::CountryOptions::Bd::Standard
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Registration::CreateParams::CountryOptions::Bd::Standard
- Defined in:
- lib/stripe/resources/tax/registration.rb
Instance Attribute Summary collapse
-
#place_of_supply_scheme ⇒ Object
Place of supply scheme used in an standard registration.
Instance Method Summary collapse
-
#initialize(place_of_supply_scheme: nil) ⇒ Standard
constructor
A new instance of Standard.
Methods inherited from RequestParams
Constructor Details
#initialize(place_of_supply_scheme: nil) ⇒ Standard
Returns a new instance of Standard.
1172 1173 1174 |
# File 'lib/stripe/resources/tax/registration.rb', line 1172 def initialize(place_of_supply_scheme: nil) @place_of_supply_scheme = place_of_supply_scheme end |
Instance Attribute Details
#place_of_supply_scheme ⇒ Object
Place of supply scheme used in an standard registration.
1170 1171 1172 |
# File 'lib/stripe/resources/tax/registration.rb', line 1170 def place_of_supply_scheme @place_of_supply_scheme end |