Class: Stripe::Tax::Registration::CreateParams::CountryOptions::Cy
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Registration::CreateParams::CountryOptions::Cy
- Defined in:
- lib/stripe/resources/tax/registration.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Cy
constructor
A new instance of Cy.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Cy
Returns a new instance of Cy.
2648 2649 2650 2651 |
# File 'lib/stripe/resources/tax/registration.rb', line 2648 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
2644 2645 2646 |
# File 'lib/stripe/resources/tax/registration.rb', line 2644 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
2646 2647 2648 |
# File 'lib/stripe/resources/tax/registration.rb', line 2646 def type @type end |