Class: Stripe::Tax::Registration::CreateParams::CountryOptions::Cz
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Registration::CreateParams::CountryOptions::Cz
- Defined in:
- lib/stripe/resources/tax/registration.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Cz
constructor
A new instance of Cz.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Cz
Returns a new instance of Cz.
1106 1107 1108 1109 |
# File 'lib/stripe/resources/tax/registration.rb', line 1106 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
1102 1103 1104 |
# File 'lib/stripe/resources/tax/registration.rb', line 1102 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
1104 1105 1106 |
# File 'lib/stripe/resources/tax/registration.rb', line 1104 def type @type end |