Class: Stripe::Tax::Registration::CreateParams::CountryOptions::De
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Registration::CreateParams::CountryOptions::De
- Defined in:
- lib/stripe/resources/tax/registration.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ De
constructor
A new instance of De.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ De
Returns a new instance of De.
2688 2689 2690 2691 |
# File 'lib/stripe/resources/tax/registration.rb', line 2688 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
2684 2685 2686 |
# File 'lib/stripe/resources/tax/registration.rb', line 2684 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
2686 2687 2688 |
# File 'lib/stripe/resources/tax/registration.rb', line 2686 def type @type end |