Class: Stripe::Tax::Registration::CreateParams::CountryOptions::Dk
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Registration::CreateParams::CountryOptions::Dk
- Defined in:
- lib/stripe/resources/tax/registration.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Dk
constructor
A new instance of Dk.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Dk
Returns a new instance of Dk.
2708 2709 2710 2711 |
# File 'lib/stripe/resources/tax/registration.rb', line 2708 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
2704 2705 2706 |
# File 'lib/stripe/resources/tax/registration.rb', line 2704 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
2706 2707 2708 |
# File 'lib/stripe/resources/tax/registration.rb', line 2706 def type @type end |