Class: Stripe::Tax::Registration::CreateParams::CountryOptions::Ee
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Registration::CreateParams::CountryOptions::Ee
- Defined in:
- lib/stripe/resources/tax/registration.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Ee
constructor
A new instance of Ee.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Ee
Returns a new instance of Ee.
2737 2738 2739 2740 |
# File 'lib/stripe/resources/tax/registration.rb', line 2737 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
2733 2734 2735 |
# File 'lib/stripe/resources/tax/registration.rb', line 2733 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
2735 2736 2737 |
# File 'lib/stripe/resources/tax/registration.rb', line 2735 def type @type end |