Class: Stripe::Tax::Registration::CreateParams::CountryOptions::Es
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Registration::CreateParams::CountryOptions::Es
- Defined in:
- lib/stripe/resources/tax/registration.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Es
constructor
A new instance of Es.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Es
Returns a new instance of Es.
1296 1297 1298 1299 |
# File 'lib/stripe/resources/tax/registration.rb', line 1296 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
1292 1293 1294 |
# File 'lib/stripe/resources/tax/registration.rb', line 1292 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
1294 1295 1296 |
# File 'lib/stripe/resources/tax/registration.rb', line 1294 def type @type end |