Class: Stripe::Tax::Registration::CreateParams::CountryOptions::Fi
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Registration::CreateParams::CountryOptions::Fi
- Defined in:
- lib/stripe/resources/tax/registration.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Fi
constructor
A new instance of Fi.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Fi
Returns a new instance of Fi.
1325 1326 1327 1328 |
# File 'lib/stripe/resources/tax/registration.rb', line 1325 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
1321 1322 1323 |
# File 'lib/stripe/resources/tax/registration.rb', line 1321 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
1323 1324 1325 |
# File 'lib/stripe/resources/tax/registration.rb', line 1323 def type @type end |