Class: Stripe::Tax::Registration::CreateParams::CountryOptions::Fr
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Registration::CreateParams::CountryOptions::Fr
- Defined in:
- lib/stripe/resources/tax/registration.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Fr
constructor
A new instance of Fr.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Fr
Returns a new instance of Fr.
2826 2827 2828 2829 |
# File 'lib/stripe/resources/tax/registration.rb', line 2826 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
2822 2823 2824 |
# File 'lib/stripe/resources/tax/registration.rb', line 2822 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
2824 2825 2826 |
# File 'lib/stripe/resources/tax/registration.rb', line 2824 def type @type end |