Class: Stripe::Tax::Registration::CreateParams::CountryOptions::Gr
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Registration::CreateParams::CountryOptions::Gr
- Defined in:
- lib/stripe/resources/tax/registration.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Gr
constructor
A new instance of Gr.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Gr
Returns a new instance of Gr.
2895 2896 2897 2898 |
# File 'lib/stripe/resources/tax/registration.rb', line 2895 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
2891 2892 2893 |
# File 'lib/stripe/resources/tax/registration.rb', line 2891 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
2893 2894 2895 |
# File 'lib/stripe/resources/tax/registration.rb', line 2893 def type @type end |