Class: Stripe::Tax::Registration::CreateParams::CountryOptions::Hr
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Registration::CreateParams::CountryOptions::Hr
- Defined in:
- lib/stripe/resources/tax/registration.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Hr
constructor
A new instance of Hr.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Hr
Returns a new instance of Hr.
2915 2916 2917 2918 |
# File 'lib/stripe/resources/tax/registration.rb', line 2915 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
2911 2912 2913 |
# File 'lib/stripe/resources/tax/registration.rb', line 2911 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
2913 2914 2915 |
# File 'lib/stripe/resources/tax/registration.rb', line 2913 def type @type end |