Class: Stripe::Tax::Registration::CreateParams::CountryOptions::Hu
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Registration::CreateParams::CountryOptions::Hu
- Defined in:
- lib/stripe/resources/tax/registration.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Hu
constructor
A new instance of Hu.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Hu
Returns a new instance of Hu.
1331 1332 1333 1334 |
# File 'lib/stripe/resources/tax/registration.rb', line 1331 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
1327 1328 1329 |
# File 'lib/stripe/resources/tax/registration.rb', line 1327 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
1329 1330 1331 |
# File 'lib/stripe/resources/tax/registration.rb', line 1329 def type @type end |