Class: Stripe::Tax::Registration::CreateParams::CountryOptions::Ie
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Registration::CreateParams::CountryOptions::Ie
- Defined in:
- lib/stripe/resources/tax/registration.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Ie
constructor
A new instance of Ie.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Ie
Returns a new instance of Ie.
1251 1252 1253 1254 |
# File 'lib/stripe/resources/tax/registration.rb', line 1251 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
1246 1247 1248 |
# File 'lib/stripe/resources/tax/registration.rb', line 1246 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
1249 1250 1251 |
# File 'lib/stripe/resources/tax/registration.rb', line 1249 def type @type end |