Class: Stripe::Tax::Registration::CreateParams::CountryOptions::It
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Registration::CreateParams::CountryOptions::It
- Defined in:
- lib/stripe/resources/tax/registration.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ It
constructor
A new instance of It.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ It
Returns a new instance of It.
3013 3014 3015 3016 |
# File 'lib/stripe/resources/tax/registration.rb', line 3013 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
3009 3010 3011 |
# File 'lib/stripe/resources/tax/registration.rb', line 3009 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
3011 3012 3013 |
# File 'lib/stripe/resources/tax/registration.rb', line 3011 def type @type end |