Class: Stripe::Tax::Registration::CreateParams::CountryOptions::Lt
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Registration::CreateParams::CountryOptions::Lt
- Defined in:
- lib/stripe/resources/tax/registration.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Lt
constructor
A new instance of Lt.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Lt
Returns a new instance of Lt.
1637 1638 1639 1640 |
# File 'lib/stripe/resources/tax/registration.rb', line 1637 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
1633 1634 1635 |
# File 'lib/stripe/resources/tax/registration.rb', line 1633 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
1635 1636 1637 |
# File 'lib/stripe/resources/tax/registration.rb', line 1635 def type @type end |