Class: Stripe::Tax::Registration::CreateParams::CountryOptions::Lu
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Registration::CreateParams::CountryOptions::Lu
- Defined in:
- lib/stripe/resources/tax/registration.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Lu
constructor
A new instance of Lu.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Lu
Returns a new instance of Lu.
3127 3128 3129 3130 |
# File 'lib/stripe/resources/tax/registration.rb', line 3127 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
3123 3124 3125 |
# File 'lib/stripe/resources/tax/registration.rb', line 3123 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
3125 3126 3127 |
# File 'lib/stripe/resources/tax/registration.rb', line 3125 def type @type end |