Class: Stripe::Tax::Registration::CreateParams::CountryOptions::Lv
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Registration::CreateParams::CountryOptions::Lv
- Defined in:
- lib/stripe/resources/tax/registration.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Lv
constructor
A new instance of Lv.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Lv
Returns a new instance of Lv.
1503 1504 1505 1506 |
# File 'lib/stripe/resources/tax/registration.rb', line 1503 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
1499 1500 1501 |
# File 'lib/stripe/resources/tax/registration.rb', line 1499 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
1501 1502 1503 |
# File 'lib/stripe/resources/tax/registration.rb', line 1501 def type @type end |