Class: Stripe::Tax::Registration::CreateParams::CountryOptions::Nl
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Registration::CreateParams::CountryOptions::Nl
- Defined in:
- lib/stripe/resources/tax/registration.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Nl
constructor
A new instance of Nl.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Nl
Returns a new instance of Nl.
3292 3293 3294 3295 |
# File 'lib/stripe/resources/tax/registration.rb', line 3292 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
3288 3289 3290 |
# File 'lib/stripe/resources/tax/registration.rb', line 3288 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
3290 3291 3292 |
# File 'lib/stripe/resources/tax/registration.rb', line 3290 def type @type end |