Class: Stripe::Tax::Registration::CreateParams::CountryOptions::Pl
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Registration::CreateParams::CountryOptions::Pl
- Defined in:
- lib/stripe/resources/tax/registration.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Pl
constructor
A new instance of Pl.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Pl
Returns a new instance of Pl.
2175 2176 2177 2178 |
# File 'lib/stripe/resources/tax/registration.rb', line 2175 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
2171 2172 2173 |
# File 'lib/stripe/resources/tax/registration.rb', line 2171 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
2173 2174 2175 |
# File 'lib/stripe/resources/tax/registration.rb', line 2173 def type @type end |