Class: Stripe::Tax::Registration::CreateParams::CountryOptions::Ro
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Registration::CreateParams::CountryOptions::Ro
- Defined in:
- lib/stripe/resources/tax/registration.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Ro
constructor
A new instance of Ro.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Ro
Returns a new instance of Ro.
1896 1897 1898 1899 |
# File 'lib/stripe/resources/tax/registration.rb', line 1896 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
1892 1893 1894 |
# File 'lib/stripe/resources/tax/registration.rb', line 1892 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
1894 1895 1896 |
# File 'lib/stripe/resources/tax/registration.rb', line 1894 def type @type end |