Class: Stripe::Tax::Registration::CreateParams::CountryOptions::Se
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Registration::CreateParams::CountryOptions::Se
- Defined in:
- lib/stripe/resources/tax/registration.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Se
constructor
A new instance of Se.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Se
Returns a new instance of Se.
1767 1768 1769 1770 |
# File 'lib/stripe/resources/tax/registration.rb', line 1767 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
1763 1764 1765 |
# File 'lib/stripe/resources/tax/registration.rb', line 1763 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
1765 1766 1767 |
# File 'lib/stripe/resources/tax/registration.rb', line 1765 def type @type end |