Class: Stripe::Tax::Registration::CreateParams::CountryOptions::Si
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Registration::CreateParams::CountryOptions::Si
- Defined in:
- lib/stripe/resources/tax/registration.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Si
constructor
A new instance of Si.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Si
Returns a new instance of Si.
1979 1980 1981 1982 |
# File 'lib/stripe/resources/tax/registration.rb', line 1979 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
1975 1976 1977 |
# File 'lib/stripe/resources/tax/registration.rb', line 1975 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
1977 1978 1979 |
# File 'lib/stripe/resources/tax/registration.rb', line 1977 def type @type end |