Class: Stripe::Tax::Registration::CreateParams::CountryOptions::Sk
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Registration::CreateParams::CountryOptions::Sk
- Defined in:
- lib/stripe/resources/tax/registration.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Sk
constructor
A new instance of Sk.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Sk
Returns a new instance of Sk.
1999 2000 2001 2002 |
# File 'lib/stripe/resources/tax/registration.rb', line 1999 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
1995 1996 1997 |
# File 'lib/stripe/resources/tax/registration.rb', line 1995 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
1997 1998 1999 |
# File 'lib/stripe/resources/tax/registration.rb', line 1997 def type @type end |