Class: Stripe::Tax::Registration::CreateParams::CountryOptions::Us
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Registration::CreateParams::CountryOptions::Us
- Defined in:
- lib/stripe/resources/tax/registration.rb
Defined Under Namespace
Classes: LocalAmusementTax, LocalLeaseTax, StateSalesTax
Instance Attribute Summary collapse
-
#local_amusement_tax ⇒ Object
Options for the local amusement tax registration.
-
#local_lease_tax ⇒ Object
Options for the local lease tax registration.
-
#state ⇒ Object
Two-letter US state code ([ISO 3166-2](en.wikipedia.org/wiki/ISO_3166-2)).
-
#state_sales_tax ⇒ Object
Options for the state sales tax registration.
-
#type ⇒ Object
Type of registration to be created in the US.
Instance Method Summary collapse
-
#initialize(local_amusement_tax: nil, local_lease_tax: nil, state: nil, state_sales_tax: nil, type: nil) ⇒ Us
constructor
A new instance of Us.
Methods inherited from RequestParams
Constructor Details
#initialize(local_amusement_tax: nil, local_lease_tax: nil, state: nil, state_sales_tax: nil, type: nil) ⇒ Us
Returns a new instance of Us.
3695 3696 3697 3698 3699 3700 3701 3702 3703 3704 3705 3706 3707 |
# File 'lib/stripe/resources/tax/registration.rb', line 3695 def initialize( local_amusement_tax: nil, local_lease_tax: nil, state: nil, state_sales_tax: nil, type: nil ) @local_amusement_tax = local_amusement_tax @local_lease_tax = local_lease_tax @state = state @state_sales_tax = state_sales_tax @type = type end |
Instance Attribute Details
#local_amusement_tax ⇒ Object
Options for the local amusement tax registration.
3685 3686 3687 |
# File 'lib/stripe/resources/tax/registration.rb', line 3685 def local_amusement_tax @local_amusement_tax end |
#local_lease_tax ⇒ Object
Options for the local lease tax registration.
3687 3688 3689 |
# File 'lib/stripe/resources/tax/registration.rb', line 3687 def local_lease_tax @local_lease_tax end |
#state ⇒ Object
Two-letter US state code ([ISO 3166-2](en.wikipedia.org/wiki/ISO_3166-2)).
3689 3690 3691 |
# File 'lib/stripe/resources/tax/registration.rb', line 3689 def state @state end |
#state_sales_tax ⇒ Object
Options for the state sales tax registration.
3691 3692 3693 |
# File 'lib/stripe/resources/tax/registration.rb', line 3691 def state_sales_tax @state_sales_tax end |
#type ⇒ Object
Type of registration to be created in the US.
3693 3694 3695 |
# File 'lib/stripe/resources/tax/registration.rb', line 3693 def type @type end |