Class: Stripe::Tax::Registration::CreateParams::CountryOptions::Us::StateSalesTax::Election
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Registration::CreateParams::CountryOptions::Us::StateSalesTax::Election
- Defined in:
- lib/stripe/resources/tax/registration.rb
Instance Attribute Summary collapse
-
#jurisdiction ⇒ Object
A [FIPS code](www.census.gov/library/reference/code-lists/ansi.html) representing the local jurisdiction.
-
#type ⇒ Object
The type of the election for the state sales tax registration.
Instance Method Summary collapse
-
#initialize(jurisdiction: nil, type: nil) ⇒ Election
constructor
A new instance of Election.
Methods inherited from RequestParams
Constructor Details
#initialize(jurisdiction: nil, type: nil) ⇒ Election
Returns a new instance of Election.
2103 2104 2105 2106 |
# File 'lib/stripe/resources/tax/registration.rb', line 2103 def initialize(jurisdiction: nil, type: nil) @jurisdiction = jurisdiction @type = type end |
Instance Attribute Details
#jurisdiction ⇒ Object
A [FIPS code](www.census.gov/library/reference/code-lists/ansi.html) representing the local jurisdiction. Supported FIPS codes are: ‘003` (Allegheny County) and `60000` (Philadelphia City).
2099 2100 2101 |
# File 'lib/stripe/resources/tax/registration.rb', line 2099 def jurisdiction @jurisdiction end |
#type ⇒ Object
The type of the election for the state sales tax registration.
2101 2102 2103 |
# File 'lib/stripe/resources/tax/registration.rb', line 2101 def type @type end |