Class: Stripe::Tax::Registration::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/tax/registration.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(ending_before: nil, expand: nil, limit: nil, starting_after: nil, status: nil) ⇒ ListParams

Returns a new instance of ListParams.



2196
2197
2198
2199
2200
2201
2202
2203
2204
2205
2206
2207
2208
# File 'lib/stripe/resources/tax/registration.rb', line 2196

def initialize(
  ending_before: nil,
  expand: nil,
  limit: nil,
  starting_after: nil,
  status: nil
)
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
  @status = status
end

Instance Attribute Details

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



2186
2187
2188
# File 'lib/stripe/resources/tax/registration.rb', line 2186

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



2188
2189
2190
# File 'lib/stripe/resources/tax/registration.rb', line 2188

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



2190
2191
2192
# File 'lib/stripe/resources/tax/registration.rb', line 2190

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



2192
2193
2194
# File 'lib/stripe/resources/tax/registration.rb', line 2192

def starting_after
  @starting_after
end

#statusObject

The status of the Tax Registration.



2194
2195
2196
# File 'lib/stripe/resources/tax/registration.rb', line 2194

def status
  @status
end