Class: Stripe::Tax::Registration::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/tax/registration.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(active_from: nil, expand: nil, expires_at: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



4231
4232
4233
4234
4235
# File 'lib/stripe/resources/tax/registration.rb', line 4231

def initialize(active_from: nil, expand: nil, expires_at: nil)
  @active_from = active_from
  @expand = expand
  @expires_at = expires_at
end

Instance Attribute Details

#active_fromObject

Time at which the registration becomes active. It can be either ‘now` to indicate the current time, or a timestamp measured in seconds since the Unix epoch.



4225
4226
4227
# File 'lib/stripe/resources/tax/registration.rb', line 4225

def active_from
  @active_from
end

#expandObject

Specifies which fields in the response should be expanded.



4227
4228
4229
# File 'lib/stripe/resources/tax/registration.rb', line 4227

def expand
  @expand
end

#expires_atObject

If set, the registration stops being active at this time. If not set, the registration will be active indefinitely. It can be either ‘now` to indicate the current time, or a timestamp measured in seconds since the Unix epoch.



4229
4230
4231
# File 'lib/stripe/resources/tax/registration.rb', line 4229

def expires_at
  @expires_at
end