Class: Stripe::Tax::RegistrationCreateParams::CountryOptions::At
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationCreateParams::CountryOptions::At
- Defined in:
- lib/stripe/params/tax/registration_create_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#igic ⇒ Object
Options for the IGIC registration.
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(igic: nil, standard: nil, type: nil) ⇒ At
constructor
A new instance of At.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(igic: nil, standard: nil, type: nil) ⇒ At
Returns a new instance of At.
102 103 104 105 106 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 102 def initialize(igic: nil, standard: nil, type: nil) @igic = igic @standard = standard @type = type end |
Instance Attribute Details
#igic ⇒ Object
Options for the IGIC registration.
96 97 98 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 96 def igic @igic end |
#standard ⇒ Object
Options for the standard registration.
98 99 100 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 98 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
100 101 102 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 100 def type @type end |