Class: Stripe::Tax::RegistrationCreateParams::CountryOptions::Be
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationCreateParams::CountryOptions::Be
- Defined in:
- lib/stripe/params/tax/registration_create_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#igic ⇒ Object
Options for the IGIC registration.
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(igic: nil, standard: nil, type: nil) ⇒ Be
constructor
A new instance of Be.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(igic: nil, standard: nil, type: nil) ⇒ Be
Returns a new instance of Be.
243 244 245 246 247 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 243 def initialize(igic: nil, standard: nil, type: nil) @igic = igic @standard = standard @type = type end |
Instance Attribute Details
#igic ⇒ Object
Options for the IGIC registration.
237 238 239 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 237 def igic @igic end |
#standard ⇒ Object
Options for the standard registration.
239 240 241 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 239 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
241 242 243 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 241 def type @type end |