Class: Stripe::Tax::RegistrationCreateParams::CountryOptions::Cy
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationCreateParams::CountryOptions::Cy
- Defined in:
- lib/stripe/params/tax/registration_create_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#igic ⇒ Object
Options for the IGIC registration.
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(igic: nil, standard: nil, type: nil) ⇒ Cy
constructor
A new instance of Cy.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(igic: nil, standard: nil, type: nil) ⇒ Cy
Returns a new instance of Cy.
490 491 492 493 494 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 490 def initialize(igic: nil, standard: nil, type: nil) @igic = igic @standard = standard @type = type end |
Instance Attribute Details
#igic ⇒ Object
Options for the IGIC registration.
484 485 486 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 484 def igic @igic end |
#standard ⇒ Object
Options for the standard registration.
486 487 488 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 486 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
488 489 490 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 488 def type @type end |