Class: Stripe::Tax::RegistrationCreateParams::CountryOptions::Cz
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationCreateParams::CountryOptions::Cz
- Defined in:
- lib/stripe/params/tax/registration_create_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#igic ⇒ Object
Options for the IGIC registration.
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(igic: nil, standard: nil, type: nil) ⇒ Cz
constructor
A new instance of Cz.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(igic: nil, standard: nil, type: nil) ⇒ Cz
Returns a new instance of Cz.
522 523 524 525 526 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 522 def initialize(igic: nil, standard: nil, type: nil) @igic = igic @standard = standard @type = type end |
Instance Attribute Details
#igic ⇒ Object
Options for the IGIC registration.
516 517 518 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 516 def igic @igic end |
#standard ⇒ Object
Options for the standard registration.
518 519 520 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 518 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
520 521 522 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 520 def type @type end |