Class: Stripe::Tax::RegistrationCreateParams::CountryOptions::De
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationCreateParams::CountryOptions::De
- Defined in:
- lib/stripe/params/tax/registration_create_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#igic ⇒ Object
Options for the IGIC registration.
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(igic: nil, standard: nil, type: nil) ⇒ De
constructor
A new instance of De.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(igic: nil, standard: nil, type: nil) ⇒ De
Returns a new instance of De.
554 555 556 557 558 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 554 def initialize(igic: nil, standard: nil, type: nil) @igic = igic @standard = standard @type = type end |
Instance Attribute Details
#igic ⇒ Object
Options for the IGIC registration.
548 549 550 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 548 def igic @igic end |
#standard ⇒ Object
Options for the standard registration.
550 551 552 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 550 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
552 553 554 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 552 def type @type end |