Class: Stripe::Tax::RegistrationCreateParams::CountryOptions::Dk
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationCreateParams::CountryOptions::Dk
- Defined in:
- lib/stripe/params/tax/registration_create_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#igic ⇒ Object
Options for the IGIC registration.
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(igic: nil, standard: nil, type: nil) ⇒ Dk
constructor
A new instance of Dk.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(igic: nil, standard: nil, type: nil) ⇒ Dk
Returns a new instance of Dk.
586 587 588 589 590 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 586 def initialize(igic: nil, standard: nil, type: nil) @igic = igic @standard = standard @type = type end |
Instance Attribute Details
#igic ⇒ Object
Options for the IGIC registration.
580 581 582 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 580 def igic @igic end |
#standard ⇒ Object
Options for the standard registration.
582 583 584 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 582 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
584 585 586 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 584 def type @type end |