Class: Stripe::Tax::RegistrationCreateParams::CountryOptions::Ee
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationCreateParams::CountryOptions::Ee
- Defined in:
- lib/stripe/params/tax/registration_create_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#igic ⇒ Object
Options for the IGIC registration.
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(igic: nil, standard: nil, type: nil) ⇒ Ee
constructor
A new instance of Ee.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(igic: nil, standard: nil, type: nil) ⇒ Ee
Returns a new instance of Ee.
627 628 629 630 631 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 627 def initialize(igic: nil, standard: nil, type: nil) @igic = igic @standard = standard @type = type end |
Instance Attribute Details
#igic ⇒ Object
Options for the IGIC registration.
621 622 623 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 621 def igic @igic end |
#standard ⇒ Object
Options for the standard registration.
623 624 625 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 623 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
625 626 627 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 625 def type @type end |