Class: Stripe::Tax::RegistrationCreateParams::CountryOptions::Es
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationCreateParams::CountryOptions::Es
- Defined in:
- lib/stripe/params/tax/registration_create_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#igic ⇒ Object
Options for the IGIC registration.
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(igic: nil, standard: nil, type: nil) ⇒ Es
constructor
A new instance of Es.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(igic: nil, standard: nil, type: nil) ⇒ Es
Returns a new instance of Es.
668 669 670 671 672 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 668 def initialize(igic: nil, standard: nil, type: nil) @igic = igic @standard = standard @type = type end |
Instance Attribute Details
#igic ⇒ Object
Options for the IGIC registration.
662 663 664 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 662 def igic @igic end |
#standard ⇒ Object
Options for the standard registration.
664 665 666 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 664 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
666 667 668 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 666 def type @type end |