Class: Stripe::Tax::RegistrationCreateParams::CountryOptions::Fi
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationCreateParams::CountryOptions::Fi
- Defined in:
- lib/stripe/params/tax/registration_create_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#igic ⇒ Object
Options for the IGIC registration.
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(igic: nil, standard: nil, type: nil) ⇒ Fi
constructor
A new instance of Fi.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(igic: nil, standard: nil, type: nil) ⇒ Fi
Returns a new instance of Fi.
720 721 722 723 724 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 720 def initialize(igic: nil, standard: nil, type: nil) @igic = igic @standard = standard @type = type end |
Instance Attribute Details
#igic ⇒ Object
Options for the IGIC registration.
714 715 716 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 714 def igic @igic end |
#standard ⇒ Object
Options for the standard registration.
716 717 718 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 716 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
718 719 720 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 718 def type @type end |