Class: Stripe::Tax::RegistrationCreateParams::CountryOptions::Hr
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationCreateParams::CountryOptions::Hr
- Defined in:
- lib/stripe/params/tax/registration_create_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#igic ⇒ Object
Options for the IGIC registration.
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(igic: nil, standard: nil, type: nil) ⇒ Hr
constructor
A new instance of Hr.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(igic: nil, standard: nil, type: nil) ⇒ Hr
Returns a new instance of Hr.
865 866 867 868 869 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 865 def initialize(igic: nil, standard: nil, type: nil) @igic = igic @standard = standard @type = type end |
Instance Attribute Details
#igic ⇒ Object
Options for the IGIC registration.
859 860 861 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 859 def igic @igic end |
#standard ⇒ Object
Options for the standard registration.
861 862 863 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 861 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
863 864 865 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 863 def type @type end |