Class: Stripe::Tax::RegistrationCreateParams::CountryOptions::Hu
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationCreateParams::CountryOptions::Hu
- Defined in:
- lib/stripe/params/tax/registration_create_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#igic ⇒ Object
Options for the IGIC registration.
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(igic: nil, standard: nil, type: nil) ⇒ Hu
constructor
A new instance of Hu.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(igic: nil, standard: nil, type: nil) ⇒ Hu
Returns a new instance of Hu.
897 898 899 900 901 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 897 def initialize(igic: nil, standard: nil, type: nil) @igic = igic @standard = standard @type = type end |
Instance Attribute Details
#igic ⇒ Object
Options for the IGIC registration.
891 892 893 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 891 def igic @igic end |
#standard ⇒ Object
Options for the standard registration.
893 894 895 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 893 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
895 896 897 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 895 def type @type end |