Class: Stripe::Tax::RegistrationCreateParams::CountryOptions::Ie
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationCreateParams::CountryOptions::Ie
- Defined in:
- lib/stripe/params/tax/registration_create_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#igic ⇒ Object
Options for the IGIC registration.
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(igic: nil, standard: nil, type: nil) ⇒ Ie
constructor
A new instance of Ie.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(igic: nil, standard: nil, type: nil) ⇒ Ie
Returns a new instance of Ie.
938 939 940 941 942 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 938 def initialize(igic: nil, standard: nil, type: nil) @igic = igic @standard = standard @type = type end |
Instance Attribute Details
#igic ⇒ Object
Options for the IGIC registration.
932 933 934 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 932 def igic @igic end |
#standard ⇒ Object
Options for the standard registration.
934 935 936 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 934 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
936 937 938 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 936 def type @type end |