Class: Stripe::Tax::RegistrationCreateParams::CountryOptions::Lt
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationCreateParams::CountryOptions::Lt
- Defined in:
- lib/stripe/params/tax/registration_create_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#igic ⇒ Object
Options for the IGIC registration.
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(igic: nil, standard: nil, type: nil) ⇒ Lt
constructor
A new instance of Lt.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(igic: nil, standard: nil, type: nil) ⇒ Lt
Returns a new instance of Lt.
1114 1115 1116 1117 1118 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1114 def initialize(igic: nil, standard: nil, type: nil) @igic = igic @standard = standard @type = type end |
Instance Attribute Details
#igic ⇒ Object
Options for the IGIC registration.
1108 1109 1110 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1108 def igic @igic end |
#standard ⇒ Object
Options for the standard registration.
1110 1111 1112 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1110 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
1112 1113 1114 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1112 def type @type end |