Class: Stripe::Tax::RegistrationCreateParams::CountryOptions::Lu
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationCreateParams::CountryOptions::Lu
- Defined in:
- lib/stripe/params/tax/registration_create_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#igic ⇒ Object
Options for the IGIC registration.
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(igic: nil, standard: nil, type: nil) ⇒ Lu
constructor
A new instance of Lu.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(igic: nil, standard: nil, type: nil) ⇒ Lu
Returns a new instance of Lu.
1146 1147 1148 1149 1150 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1146 def initialize(igic: nil, standard: nil, type: nil) @igic = igic @standard = standard @type = type end |
Instance Attribute Details
#igic ⇒ Object
Options for the IGIC registration.
1140 1141 1142 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1140 def igic @igic end |
#standard ⇒ Object
Options for the standard registration.
1142 1143 1144 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1142 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
1144 1145 1146 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1144 def type @type end |