Class: Stripe::Tax::RegistrationCreateParams::CountryOptions::Lv
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationCreateParams::CountryOptions::Lv
- Defined in:
- lib/stripe/params/tax/registration_create_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#igic ⇒ Object
Options for the IGIC registration.
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(igic: nil, standard: nil, type: nil) ⇒ Lv
constructor
A new instance of Lv.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(igic: nil, standard: nil, type: nil) ⇒ Lv
Returns a new instance of Lv.
1178 1179 1180 1181 1182 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1178 def initialize(igic: nil, standard: nil, type: nil) @igic = igic @standard = standard @type = type end |
Instance Attribute Details
#igic ⇒ Object
Options for the IGIC registration.
1172 1173 1174 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1172 def igic @igic end |
#standard ⇒ Object
Options for the standard registration.
1174 1175 1176 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1174 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
1176 1177 1178 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1176 def type @type end |