Class: Stripe::Tax::RegistrationCreateParams::CountryOptions::Mt
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationCreateParams::CountryOptions::Mt
- Defined in:
- lib/stripe/params/tax/registration_create_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#igic ⇒ Object
Options for the IGIC registration.
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(igic: nil, standard: nil, type: nil) ⇒ Mt
constructor
A new instance of Mt.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(igic: nil, standard: nil, type: nil) ⇒ Mt
Returns a new instance of Mt.
1288 1289 1290 1291 1292 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1288 def initialize(igic: nil, standard: nil, type: nil) @igic = igic @standard = standard @type = type end |
Instance Attribute Details
#igic ⇒ Object
Options for the IGIC registration.
1282 1283 1284 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1282 def igic @igic end |
#standard ⇒ Object
Options for the standard registration.
1284 1285 1286 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1284 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
1286 1287 1288 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1286 def type @type end |