Class: Stripe::Tax::RegistrationCreateParams::CountryOptions::Nl
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationCreateParams::CountryOptions::Nl
- Defined in:
- lib/stripe/params/tax/registration_create_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#igic ⇒ Object
Options for the IGIC registration.
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(igic: nil, standard: nil, type: nil) ⇒ Nl
constructor
A new instance of Nl.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(igic: nil, standard: nil, type: nil) ⇒ Nl
Returns a new instance of Nl.
1347 1348 1349 1350 1351 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1347 def initialize(igic: nil, standard: nil, type: nil) @igic = igic @standard = standard @type = type end |
Instance Attribute Details
#igic ⇒ Object
Options for the IGIC registration.
1341 1342 1343 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1341 def igic @igic end |
#standard ⇒ Object
Options for the standard registration.
1343 1344 1345 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1343 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
1345 1346 1347 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1345 def type @type end |