Class: Stripe::Tax::RegistrationCreateParams::CountryOptions::Pl
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationCreateParams::CountryOptions::Pl
- Defined in:
- lib/stripe/params/tax/registration_create_params.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Pl
constructor
A new instance of Pl.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Pl
Returns a new instance of Pl.
1203 1204 1205 1206 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1203 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
1199 1200 1201 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1199 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
1201 1202 1203 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1201 def type @type end |