Class: Stripe::Tax::RegistrationCreateParams::CountryOptions::Pt
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationCreateParams::CountryOptions::Pt
- Defined in:
- lib/stripe/params/tax/registration_create_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#igic ⇒ Object
Options for the IGIC registration.
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(igic: nil, standard: nil, type: nil) ⇒ Pt
constructor
A new instance of Pt.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(igic: nil, standard: nil, type: nil) ⇒ Pt
Returns a new instance of Pt.
1498 1499 1500 1501 1502 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1498 def initialize(igic: nil, standard: nil, type: nil) @igic = igic @standard = standard @type = type end |
Instance Attribute Details
#igic ⇒ Object
Options for the IGIC registration.
1492 1493 1494 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1492 def igic @igic end |
#standard ⇒ Object
Options for the standard registration.
1494 1495 1496 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1494 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
1496 1497 1498 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1496 def type @type end |