Class: Stripe::Tax::RegistrationCreateParams::CountryOptions::Se
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationCreateParams::CountryOptions::Se
- Defined in:
- lib/stripe/params/tax/registration_create_params.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Se
constructor
A new instance of Se.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Se
Returns a new instance of Se.
1301 1302 1303 1304 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1301 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
1297 1298 1299 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1297 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
1299 1300 1301 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1299 def type @type end |