Class: Stripe::Tax::RegistrationCreateParams::CountryOptions::Si
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationCreateParams::CountryOptions::Si
- Defined in:
- lib/stripe/params/tax/registration_create_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#igic ⇒ Object
Options for the IGIC registration.
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(igic: nil, standard: nil, type: nil) ⇒ Si
constructor
A new instance of Si.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(igic: nil, standard: nil, type: nil) ⇒ Si
Returns a new instance of Si.
1652 1653 1654 1655 1656 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1652 def initialize(igic: nil, standard: nil, type: nil) @igic = igic @standard = standard @type = type end |
Instance Attribute Details
#igic ⇒ Object
Options for the IGIC registration.
1646 1647 1648 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1646 def igic @igic end |
#standard ⇒ Object
Options for the standard registration.
1648 1649 1650 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1648 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
1650 1651 1652 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1650 def type @type end |