Class: Stripe::Tax::RegistrationCreateParams::CountryOptions::Sk
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationCreateParams::CountryOptions::Sk
- Defined in:
- lib/stripe/params/tax/registration_create_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#igic ⇒ Object
Options for the IGIC registration.
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(igic: nil, standard: nil, type: nil) ⇒ Sk
constructor
A new instance of Sk.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(igic: nil, standard: nil, type: nil) ⇒ Sk
Returns a new instance of Sk.
1684 1685 1686 1687 1688 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1684 def initialize(igic: nil, standard: nil, type: nil) @igic = igic @standard = standard @type = type end |
Instance Attribute Details
#igic ⇒ Object
Options for the IGIC registration.
1678 1679 1680 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1678 def igic @igic end |
#standard ⇒ Object
Options for the standard registration.
1680 1681 1682 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1680 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
1682 1683 1684 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1682 def type @type end |