Class: Stripe::Tax::RegistrationCreateParams::CountryOptions::Us
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationCreateParams::CountryOptions::Us
- Defined in:
- lib/stripe/params/tax/registration_create_params.rb
Defined Under Namespace
Classes: LocalAmusementTax, LocalLeaseTax, MassTransitParkingTax, ParkingTax, StateSalesTax
Instance Attribute Summary collapse
-
#local_amusement_tax ⇒ Object
Options for the local amusement tax registration.
-
#local_lease_tax ⇒ Object
Options for the local lease tax registration.
-
#mass_transit_parking_tax ⇒ Object
Options for the mass transit parking tax registration.
-
#parking_tax ⇒ Object
Options for the parking tax registration.
-
#state ⇒ Object
Two-letter US state code (ISO 3166-2).
-
#state_sales_tax ⇒ Object
Options for the state sales tax registration.
-
#type ⇒ Object
Type of registration to be created in the US.
Instance Method Summary collapse
-
#initialize(local_amusement_tax: nil, local_lease_tax: nil, mass_transit_parking_tax: nil, parking_tax: nil, state: nil, state_sales_tax: nil, type: nil) ⇒ Us
constructor
A new instance of Us.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(local_amusement_tax: nil, local_lease_tax: nil, mass_transit_parking_tax: nil, parking_tax: nil, state: nil, state_sales_tax: nil, type: nil) ⇒ Us
Returns a new instance of Us.
1854 1855 1856 1857 1858 1859 1860 1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1854 def initialize( local_amusement_tax: nil, local_lease_tax: nil, mass_transit_parking_tax: nil, parking_tax: nil, state: nil, state_sales_tax: nil, type: nil ) @local_amusement_tax = local_amusement_tax @local_lease_tax = local_lease_tax @mass_transit_parking_tax = mass_transit_parking_tax @parking_tax = parking_tax @state = state @state_sales_tax = state_sales_tax @type = type end |
Instance Attribute Details
#local_amusement_tax ⇒ Object
Options for the local amusement tax registration.
1840 1841 1842 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1840 def local_amusement_tax @local_amusement_tax end |
#local_lease_tax ⇒ Object
Options for the local lease tax registration.
1842 1843 1844 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1842 def local_lease_tax @local_lease_tax end |
#mass_transit_parking_tax ⇒ Object
Options for the mass transit parking tax registration.
1844 1845 1846 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1844 def mass_transit_parking_tax @mass_transit_parking_tax end |
#parking_tax ⇒ Object
Options for the parking tax registration.
1846 1847 1848 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1846 def parking_tax @parking_tax end |
#state ⇒ Object
Two-letter US state code (ISO 3166-2).
1848 1849 1850 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1848 def state @state end |
#state_sales_tax ⇒ Object
Options for the state sales tax registration.
1850 1851 1852 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1850 def state_sales_tax @state_sales_tax end |
#type ⇒ Object
Type of registration to be created in the US.
1852 1853 1854 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1852 def type @type end |