Class: Stripe::Tax::RegistrationCreateParams::CountryOptions::Us::StateSalesTax::Election
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationCreateParams::CountryOptions::Us::StateSalesTax::Election
- Defined in:
- lib/stripe/params/tax/registration_create_params.rb
Instance Attribute Summary collapse
-
#jurisdiction ⇒ Object
A [FIPS code](www.census.gov/library/reference/code-lists/ansi.html) representing the local jurisdiction.
-
#type ⇒ Object
The type of the election for the state sales tax registration.
Instance Method Summary collapse
-
#initialize(jurisdiction: nil, type: nil) ⇒ Election
constructor
A new instance of Election.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(jurisdiction: nil, type: nil) ⇒ Election
Returns a new instance of Election.
1548 1549 1550 1551 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1548 def initialize(jurisdiction: nil, type: nil) @jurisdiction = jurisdiction @type = type end |
Instance Attribute Details
#jurisdiction ⇒ Object
A [FIPS code](www.census.gov/library/reference/code-lists/ansi.html) representing the local jurisdiction. Supported FIPS codes are: ‘003` (Allegheny County) and `60000` (Philadelphia City).
1544 1545 1546 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1544 def jurisdiction @jurisdiction end |
#type ⇒ Object
The type of the election for the state sales tax registration.
1546 1547 1548 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1546 def type @type end |