Class: Stripe::Tax::RegistrationService::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/tax/registration_service.rb

Defined Under Namespace

Classes: CountryOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(active_from: nil, country: nil, country_options: nil, expand: nil, expires_at: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



2031
2032
2033
2034
2035
2036
2037
2038
2039
2040
2041
2042
2043
# File 'lib/stripe/services/tax/registration_service.rb', line 2031

def initialize(
  active_from: nil,
  country: nil,
  country_options: nil,
  expand: nil,
  expires_at: nil
)
  @active_from = active_from
  @country = country
  @country_options = country_options
  @expand = expand
  @expires_at = expires_at
end

Instance Attribute Details

#active_fromObject

Time at which the Tax Registration becomes active. It can be either ‘now` to indicate the current time, or a future timestamp measured in seconds since the Unix epoch.



2021
2022
2023
# File 'lib/stripe/services/tax/registration_service.rb', line 2021

def active_from
  @active_from
end

#countryObject

Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).



2023
2024
2025
# File 'lib/stripe/services/tax/registration_service.rb', line 2023

def country
  @country
end

#country_optionsObject

Specific options for a registration in the specified ‘country`.



2025
2026
2027
# File 'lib/stripe/services/tax/registration_service.rb', line 2025

def country_options
  @country_options
end

#expandObject

Specifies which fields in the response should be expanded.



2027
2028
2029
# File 'lib/stripe/services/tax/registration_service.rb', line 2027

def expand
  @expand
end

#expires_atObject

If set, the Tax Registration stops being active at this time. If not set, the Tax Registration will be active indefinitely. Timestamp measured in seconds since the Unix epoch.



2029
2030
2031
# File 'lib/stripe/services/tax/registration_service.rb', line 2029

def expires_at
  @expires_at
end