Class: Stripe::Tax::RegistrationService::CreateParams::CountryOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/tax/registration_service.rb

Defined Under Namespace

Classes: Ae, Al, Am, Ao, At, Au, Aw, Az, Ba, Bb, Bd, Be, Bf, Bg, Bh, Bj, Bs, By, Ca, Cd, Ch, Cl, Cm, Co, Cr, Cv, Cy, Cz, De, Dk, Ec, Ee, Eg, Es, Et, Fi, Fr, Gb, Ge, Gn, Gr, Hr, Hu, Id, Ie, In, Is, It, Jp, Ke, Kg, Kh, Kr, Kz, La, Lt, Lu, Lv, Ma, Md, Me, Mk, Mr, Mt, Mx, My, Ng, Nl, No, Np, Nz, Om, Pe, Ph, Pl, Pt, Ro, Rs, Ru, Sa, Se, Sg, Si, Sk, Sn, Sr, Th, Tj, Tr, Tz, Ua, Ug, Us, Uy, Uz, Vn, Za, Zm, Zw

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(ae: nil, al: nil, am: nil, ao: nil, at: nil, au: nil, aw: nil, az: nil, ba: nil, bb: nil, bd: nil, be: nil, bf: nil, bg: nil, bh: nil, bj: nil, bs: nil, by: nil, ca: nil, cd: nil, ch: nil, cl: nil, cm: nil, co: nil, cr: nil, cv: nil, cy: nil, cz: nil, de: nil, dk: nil, ec: nil, ee: nil, eg: nil, es: nil, et: nil, fi: nil, fr: nil, gb: nil, ge: nil, gn: nil, gr: nil, hr: nil, hu: nil, id: nil, ie: nil, in_: nil, is: nil, it: nil, jp: nil, ke: nil, kg: nil, kh: nil, kr: nil, kz: nil, la: nil, lt: nil, lu: nil, lv: nil, ma: nil, md: nil, me: nil, mk: nil, mr: nil, mt: nil, mx: nil, my: nil, ng: nil, nl: nil, no: nil, np: nil, nz: nil, om: nil, pe: nil, ph: nil, pl: nil, pt: nil, ro: nil, rs: nil, ru: nil, sa: nil, se: nil, sg: nil, si: nil, sk: nil, sn: nil, sr: nil, th: nil, tj: nil, tr: nil, tz: nil, ua: nil, ug: nil, us: nil, uy: nil, uz: nil, vn: nil, za: nil, zm: nil, zw: nil) ⇒ CountryOptions

Returns a new instance of CountryOptions.



1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
1538
1539
1540
1541
1542
1543
1544
1545
1546
1547
1548
1549
1550
1551
1552
1553
1554
1555
1556
1557
1558
1559
1560
1561
1562
1563
1564
1565
1566
1567
1568
1569
1570
1571
1572
1573
1574
1575
1576
1577
1578
1579
1580
1581
1582
1583
1584
1585
1586
1587
1588
1589
1590
1591
1592
1593
1594
1595
1596
1597
1598
1599
1600
1601
1602
1603
1604
1605
1606
1607
1608
1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
1626
1627
1628
1629
1630
1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
1641
1642
1643
1644
1645
1646
1647
1648
1649
1650
1651
1652
1653
1654
1655
1656
1657
1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
1669
1670
1671
1672
1673
1674
1675
1676
1677
1678
1679
1680
1681
1682
1683
1684
1685
1686
1687
1688
# File 'lib/stripe/services/tax/registration_service.rb', line 1488

def initialize(
  ae: nil,
  al: nil,
  am: nil,
  ao: nil,
  at: nil,
  au: nil,
  aw: nil,
  az: nil,
  ba: nil,
  bb: nil,
  bd: nil,
  be: nil,
  bf: nil,
  bg: nil,
  bh: nil,
  bj: nil,
  bs: nil,
  by: nil,
  ca: nil,
  cd: nil,
  ch: nil,
  cl: nil,
  cm: nil,
  co: nil,
  cr: nil,
  cv: nil,
  cy: nil,
  cz: nil,
  de: nil,
  dk: nil,
  ec: nil,
  ee: nil,
  eg: nil,
  es: nil,
  et: nil,
  fi: nil,
  fr: nil,
  gb: nil,
  ge: nil,
  gn: nil,
  gr: nil,
  hr: nil,
  hu: nil,
  id: nil,
  ie: nil,
  in_: nil,
  is: nil,
  it: nil,
  jp: nil,
  ke: nil,
  kg: nil,
  kh: nil,
  kr: nil,
  kz: nil,
  la: nil,
  lt: nil,
  lu: nil,
  lv: nil,
  ma: nil,
  md: nil,
  me: nil,
  mk: nil,
  mr: nil,
  mt: nil,
  mx: nil,
  my: nil,
  ng: nil,
  nl: nil,
  no: nil,
  np: nil,
  nz: nil,
  om: nil,
  pe: nil,
  ph: nil,
  pl: nil,
  pt: nil,
  ro: nil,
  rs: nil,
  ru: nil,
  sa: nil,
  se: nil,
  sg: nil,
  si: nil,
  sk: nil,
  sn: nil,
  sr: nil,
  th: nil,
  tj: nil,
  tr: nil,
  tz: nil,
  ua: nil,
  ug: nil,
  us: nil,
  uy: nil,
  uz: nil,
  vn: nil,
  za: nil,
  zm: nil,
  zw: nil
)
  @ae = ae
  @al = al
  @am = am
  @ao = ao
  @at = at
  @au = au
  @aw = aw
  @az = az
  @ba = ba
  @bb = bb
  @bd = bd
  @be = be
  @bf = bf
  @bg = bg
  @bh = bh
  @bj = bj
  @bs = bs
  @by = by
  @ca = ca
  @cd = cd
  @ch = ch
  @cl = cl
  @cm = cm
  @co = co
  @cr = cr
  @cv = cv
  @cy = cy
  @cz = cz
  @de = de
  @dk = dk
  @ec = ec
  @ee = ee
  @eg = eg
  @es = es
  @et = et
  @fi = fi
  @fr = fr
  @gb = gb
  @ge = ge
  @gn = gn
  @gr = gr
  @hr = hr
  @hu = hu
  @id = id
  @ie = ie
  @in = in_
  @is = is
  @it = it
  @jp = jp
  @ke = ke
  @kg = kg
  @kh = kh
  @kr = kr
  @kz = kz
  @la = la
  @lt = lt
  @lu = lu
  @lv = lv
  @ma = ma
  @md = md
  @me = me
  @mk = mk
  @mr = mr
  @mt = mt
  @mx = mx
  @my = my
  @ng = ng
  @nl = nl
  @no = no
  @np = np
  @nz = nz
  @om = om
  @pe = pe
  @ph = ph
  @pl = pl
  @pt = pt
  @ro = ro
  @rs = rs
  @ru = ru
  @sa = sa
  @se = se
  @sg = sg
  @si = si
  @sk = sk
  @sn = sn
  @sr = sr
  @th = th
  @tj = tj
  @tr = tr
  @tz = tz
  @ua = ua
  @ug = ug
  @us = us
  @uy = uy
  @uz = uz
  @vn = vn
  @za = za
  @zm = zm
  @zw = zw
end

Instance Attribute Details

#aeObject

Options for the registration in AE.



1290
1291
1292
# File 'lib/stripe/services/tax/registration_service.rb', line 1290

def ae
  @ae
end

#alObject

Options for the registration in AL.



1292
1293
1294
# File 'lib/stripe/services/tax/registration_service.rb', line 1292

def al
  @al
end

#amObject

Options for the registration in AM.



1294
1295
1296
# File 'lib/stripe/services/tax/registration_service.rb', line 1294

def am
  @am
end

#aoObject

Options for the registration in AO.



1296
1297
1298
# File 'lib/stripe/services/tax/registration_service.rb', line 1296

def ao
  @ao
end

#atObject

Options for the registration in AT.



1298
1299
1300
# File 'lib/stripe/services/tax/registration_service.rb', line 1298

def at
  @at
end

#auObject

Options for the registration in AU.



1300
1301
1302
# File 'lib/stripe/services/tax/registration_service.rb', line 1300

def au
  @au
end

#awObject

Options for the registration in AW.



1302
1303
1304
# File 'lib/stripe/services/tax/registration_service.rb', line 1302

def aw
  @aw
end

#azObject

Options for the registration in AZ.



1304
1305
1306
# File 'lib/stripe/services/tax/registration_service.rb', line 1304

def az
  @az
end

#baObject

Options for the registration in BA.



1306
1307
1308
# File 'lib/stripe/services/tax/registration_service.rb', line 1306

def ba
  @ba
end

#bbObject

Options for the registration in BB.



1308
1309
1310
# File 'lib/stripe/services/tax/registration_service.rb', line 1308

def bb
  @bb
end

#bdObject

Options for the registration in BD.



1310
1311
1312
# File 'lib/stripe/services/tax/registration_service.rb', line 1310

def bd
  @bd
end

#beObject

Options for the registration in BE.



1312
1313
1314
# File 'lib/stripe/services/tax/registration_service.rb', line 1312

def be
  @be
end

#bfObject

Options for the registration in BF.



1314
1315
1316
# File 'lib/stripe/services/tax/registration_service.rb', line 1314

def bf
  @bf
end

#bgObject

Options for the registration in BG.



1316
1317
1318
# File 'lib/stripe/services/tax/registration_service.rb', line 1316

def bg
  @bg
end

#bhObject

Options for the registration in BH.



1318
1319
1320
# File 'lib/stripe/services/tax/registration_service.rb', line 1318

def bh
  @bh
end

#bjObject

Options for the registration in BJ.



1320
1321
1322
# File 'lib/stripe/services/tax/registration_service.rb', line 1320

def bj
  @bj
end

#bsObject

Options for the registration in BS.



1322
1323
1324
# File 'lib/stripe/services/tax/registration_service.rb', line 1322

def bs
  @bs
end

#byObject

Options for the registration in BY.



1324
1325
1326
# File 'lib/stripe/services/tax/registration_service.rb', line 1324

def by
  @by
end

#caObject

Options for the registration in CA.



1326
1327
1328
# File 'lib/stripe/services/tax/registration_service.rb', line 1326

def ca
  @ca
end

#cdObject

Options for the registration in CD.



1328
1329
1330
# File 'lib/stripe/services/tax/registration_service.rb', line 1328

def cd
  @cd
end

#chObject

Options for the registration in CH.



1330
1331
1332
# File 'lib/stripe/services/tax/registration_service.rb', line 1330

def ch
  @ch
end

#clObject

Options for the registration in CL.



1332
1333
1334
# File 'lib/stripe/services/tax/registration_service.rb', line 1332

def cl
  @cl
end

#cmObject

Options for the registration in CM.



1334
1335
1336
# File 'lib/stripe/services/tax/registration_service.rb', line 1334

def cm
  @cm
end

#coObject

Options for the registration in CO.



1336
1337
1338
# File 'lib/stripe/services/tax/registration_service.rb', line 1336

def co
  @co
end

#crObject

Options for the registration in CR.



1338
1339
1340
# File 'lib/stripe/services/tax/registration_service.rb', line 1338

def cr
  @cr
end

#cvObject

Options for the registration in CV.



1340
1341
1342
# File 'lib/stripe/services/tax/registration_service.rb', line 1340

def cv
  @cv
end

#cyObject

Options for the registration in CY.



1342
1343
1344
# File 'lib/stripe/services/tax/registration_service.rb', line 1342

def cy
  @cy
end

#czObject

Options for the registration in CZ.



1344
1345
1346
# File 'lib/stripe/services/tax/registration_service.rb', line 1344

def cz
  @cz
end

#deObject

Options for the registration in DE.



1346
1347
1348
# File 'lib/stripe/services/tax/registration_service.rb', line 1346

def de
  @de
end

#dkObject

Options for the registration in DK.



1348
1349
1350
# File 'lib/stripe/services/tax/registration_service.rb', line 1348

def dk
  @dk
end

#ecObject

Options for the registration in EC.



1350
1351
1352
# File 'lib/stripe/services/tax/registration_service.rb', line 1350

def ec
  @ec
end

#eeObject

Options for the registration in EE.



1352
1353
1354
# File 'lib/stripe/services/tax/registration_service.rb', line 1352

def ee
  @ee
end

#egObject

Options for the registration in EG.



1354
1355
1356
# File 'lib/stripe/services/tax/registration_service.rb', line 1354

def eg
  @eg
end

#esObject

Options for the registration in ES.



1356
1357
1358
# File 'lib/stripe/services/tax/registration_service.rb', line 1356

def es
  @es
end

#etObject

Options for the registration in ET.



1358
1359
1360
# File 'lib/stripe/services/tax/registration_service.rb', line 1358

def et
  @et
end

#fiObject

Options for the registration in FI.



1360
1361
1362
# File 'lib/stripe/services/tax/registration_service.rb', line 1360

def fi
  @fi
end

#frObject

Options for the registration in FR.



1362
1363
1364
# File 'lib/stripe/services/tax/registration_service.rb', line 1362

def fr
  @fr
end

#gbObject

Options for the registration in GB.



1364
1365
1366
# File 'lib/stripe/services/tax/registration_service.rb', line 1364

def gb
  @gb
end

#geObject

Options for the registration in GE.



1366
1367
1368
# File 'lib/stripe/services/tax/registration_service.rb', line 1366

def ge
  @ge
end

#gnObject

Options for the registration in GN.



1368
1369
1370
# File 'lib/stripe/services/tax/registration_service.rb', line 1368

def gn
  @gn
end

#grObject

Options for the registration in GR.



1370
1371
1372
# File 'lib/stripe/services/tax/registration_service.rb', line 1370

def gr
  @gr
end

#hrObject

Options for the registration in HR.



1372
1373
1374
# File 'lib/stripe/services/tax/registration_service.rb', line 1372

def hr
  @hr
end

#huObject

Options for the registration in HU.



1374
1375
1376
# File 'lib/stripe/services/tax/registration_service.rb', line 1374

def hu
  @hu
end

#idObject

Options for the registration in ID.



1376
1377
1378
# File 'lib/stripe/services/tax/registration_service.rb', line 1376

def id
  @id
end

#ieObject

Options for the registration in IE.



1378
1379
1380
# File 'lib/stripe/services/tax/registration_service.rb', line 1378

def ie
  @ie
end

#inObject

Options for the registration in IN.



1380
1381
1382
# File 'lib/stripe/services/tax/registration_service.rb', line 1380

def in
  @in
end

#isObject

Options for the registration in IS.



1382
1383
1384
# File 'lib/stripe/services/tax/registration_service.rb', line 1382

def is
  @is
end

#itObject

Options for the registration in IT.



1384
1385
1386
# File 'lib/stripe/services/tax/registration_service.rb', line 1384

def it
  @it
end

#jpObject

Options for the registration in JP.



1386
1387
1388
# File 'lib/stripe/services/tax/registration_service.rb', line 1386

def jp
  @jp
end

#keObject

Options for the registration in KE.



1388
1389
1390
# File 'lib/stripe/services/tax/registration_service.rb', line 1388

def ke
  @ke
end

#kgObject

Options for the registration in KG.



1390
1391
1392
# File 'lib/stripe/services/tax/registration_service.rb', line 1390

def kg
  @kg
end

#khObject

Options for the registration in KH.



1392
1393
1394
# File 'lib/stripe/services/tax/registration_service.rb', line 1392

def kh
  @kh
end

#krObject

Options for the registration in KR.



1394
1395
1396
# File 'lib/stripe/services/tax/registration_service.rb', line 1394

def kr
  @kr
end

#kzObject

Options for the registration in KZ.



1396
1397
1398
# File 'lib/stripe/services/tax/registration_service.rb', line 1396

def kz
  @kz
end

#laObject

Options for the registration in LA.



1398
1399
1400
# File 'lib/stripe/services/tax/registration_service.rb', line 1398

def la
  @la
end

#ltObject

Options for the registration in LT.



1400
1401
1402
# File 'lib/stripe/services/tax/registration_service.rb', line 1400

def lt
  @lt
end

#luObject

Options for the registration in LU.



1402
1403
1404
# File 'lib/stripe/services/tax/registration_service.rb', line 1402

def lu
  @lu
end

#lvObject

Options for the registration in LV.



1404
1405
1406
# File 'lib/stripe/services/tax/registration_service.rb', line 1404

def lv
  @lv
end

#maObject

Options for the registration in MA.



1406
1407
1408
# File 'lib/stripe/services/tax/registration_service.rb', line 1406

def ma
  @ma
end

#mdObject

Options for the registration in MD.



1408
1409
1410
# File 'lib/stripe/services/tax/registration_service.rb', line 1408

def md
  @md
end

#meObject

Options for the registration in ME.



1410
1411
1412
# File 'lib/stripe/services/tax/registration_service.rb', line 1410

def me
  @me
end

#mkObject

Options for the registration in MK.



1412
1413
1414
# File 'lib/stripe/services/tax/registration_service.rb', line 1412

def mk
  @mk
end

#mrObject

Options for the registration in MR.



1414
1415
1416
# File 'lib/stripe/services/tax/registration_service.rb', line 1414

def mr
  @mr
end

#mtObject

Options for the registration in MT.



1416
1417
1418
# File 'lib/stripe/services/tax/registration_service.rb', line 1416

def mt
  @mt
end

#mxObject

Options for the registration in MX.



1418
1419
1420
# File 'lib/stripe/services/tax/registration_service.rb', line 1418

def mx
  @mx
end

#myObject

Options for the registration in MY.



1420
1421
1422
# File 'lib/stripe/services/tax/registration_service.rb', line 1420

def my
  @my
end

#ngObject

Options for the registration in NG.



1422
1423
1424
# File 'lib/stripe/services/tax/registration_service.rb', line 1422

def ng
  @ng
end

#nlObject

Options for the registration in NL.



1424
1425
1426
# File 'lib/stripe/services/tax/registration_service.rb', line 1424

def nl
  @nl
end

#noObject

Options for the registration in NO.



1426
1427
1428
# File 'lib/stripe/services/tax/registration_service.rb', line 1426

def no
  @no
end

#npObject

Options for the registration in NP.



1428
1429
1430
# File 'lib/stripe/services/tax/registration_service.rb', line 1428

def np
  @np
end

#nzObject

Options for the registration in NZ.



1430
1431
1432
# File 'lib/stripe/services/tax/registration_service.rb', line 1430

def nz
  @nz
end

#omObject

Options for the registration in OM.



1432
1433
1434
# File 'lib/stripe/services/tax/registration_service.rb', line 1432

def om
  @om
end

#peObject

Options for the registration in PE.



1434
1435
1436
# File 'lib/stripe/services/tax/registration_service.rb', line 1434

def pe
  @pe
end

#phObject

Options for the registration in PH.



1436
1437
1438
# File 'lib/stripe/services/tax/registration_service.rb', line 1436

def ph
  @ph
end

#plObject

Options for the registration in PL.



1438
1439
1440
# File 'lib/stripe/services/tax/registration_service.rb', line 1438

def pl
  @pl
end

#ptObject

Options for the registration in PT.



1440
1441
1442
# File 'lib/stripe/services/tax/registration_service.rb', line 1440

def pt
  @pt
end

#roObject

Options for the registration in RO.



1442
1443
1444
# File 'lib/stripe/services/tax/registration_service.rb', line 1442

def ro
  @ro
end

#rsObject

Options for the registration in RS.



1444
1445
1446
# File 'lib/stripe/services/tax/registration_service.rb', line 1444

def rs
  @rs
end

#ruObject

Options for the registration in RU.



1446
1447
1448
# File 'lib/stripe/services/tax/registration_service.rb', line 1446

def ru
  @ru
end

#saObject

Options for the registration in SA.



1448
1449
1450
# File 'lib/stripe/services/tax/registration_service.rb', line 1448

def sa
  @sa
end

#seObject

Options for the registration in SE.



1450
1451
1452
# File 'lib/stripe/services/tax/registration_service.rb', line 1450

def se
  @se
end

#sgObject

Options for the registration in SG.



1452
1453
1454
# File 'lib/stripe/services/tax/registration_service.rb', line 1452

def sg
  @sg
end

#siObject

Options for the registration in SI.



1454
1455
1456
# File 'lib/stripe/services/tax/registration_service.rb', line 1454

def si
  @si
end

#skObject

Options for the registration in SK.



1456
1457
1458
# File 'lib/stripe/services/tax/registration_service.rb', line 1456

def sk
  @sk
end

#snObject

Options for the registration in SN.



1458
1459
1460
# File 'lib/stripe/services/tax/registration_service.rb', line 1458

def sn
  @sn
end

#srObject

Options for the registration in SR.



1460
1461
1462
# File 'lib/stripe/services/tax/registration_service.rb', line 1460

def sr
  @sr
end

#thObject

Options for the registration in TH.



1462
1463
1464
# File 'lib/stripe/services/tax/registration_service.rb', line 1462

def th
  @th
end

#tjObject

Options for the registration in TJ.



1464
1465
1466
# File 'lib/stripe/services/tax/registration_service.rb', line 1464

def tj
  @tj
end

#trObject

Options for the registration in TR.



1466
1467
1468
# File 'lib/stripe/services/tax/registration_service.rb', line 1466

def tr
  @tr
end

#tzObject

Options for the registration in TZ.



1468
1469
1470
# File 'lib/stripe/services/tax/registration_service.rb', line 1468

def tz
  @tz
end

#uaObject

Options for the registration in UA.



1470
1471
1472
# File 'lib/stripe/services/tax/registration_service.rb', line 1470

def ua
  @ua
end

#ugObject

Options for the registration in UG.



1472
1473
1474
# File 'lib/stripe/services/tax/registration_service.rb', line 1472

def ug
  @ug
end

#usObject

Options for the registration in US.



1474
1475
1476
# File 'lib/stripe/services/tax/registration_service.rb', line 1474

def us
  @us
end

#uyObject

Options for the registration in UY.



1476
1477
1478
# File 'lib/stripe/services/tax/registration_service.rb', line 1476

def uy
  @uy
end

#uzObject

Options for the registration in UZ.



1478
1479
1480
# File 'lib/stripe/services/tax/registration_service.rb', line 1478

def uz
  @uz
end

#vnObject

Options for the registration in VN.



1480
1481
1482
# File 'lib/stripe/services/tax/registration_service.rb', line 1480

def vn
  @vn
end

#zaObject

Options for the registration in ZA.



1482
1483
1484
# File 'lib/stripe/services/tax/registration_service.rb', line 1482

def za
  @za
end

#zmObject

Options for the registration in ZM.



1484
1485
1486
# File 'lib/stripe/services/tax/registration_service.rb', line 1484

def zm
  @zm
end

#zwObject

Options for the registration in ZW.



1486
1487
1488
# File 'lib/stripe/services/tax/registration_service.rb', line 1486

def zw
  @zw
end