Class: Stripe::Tax::RegistrationService::CreateParams::CountryOptions::At
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationService::CreateParams::CountryOptions::At
- Defined in:
- lib/stripe/services/tax/registration_service.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ At
constructor
A new instance of At.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ At
Returns a new instance of At.
119 120 121 122 |
# File 'lib/stripe/services/tax/registration_service.rb', line 119 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
115 116 117 |
# File 'lib/stripe/services/tax/registration_service.rb', line 115 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
117 118 119 |
# File 'lib/stripe/services/tax/registration_service.rb', line 117 def type @type end |