Class: Stripe::Tax::RegistrationService::CreateParams::CountryOptions::Be
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationService::CreateParams::CountryOptions::Be
- Defined in:
- lib/stripe/services/tax/registration_service.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Be
constructor
A new instance of Be.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Be
Returns a new instance of Be.
248 249 250 251 |
# File 'lib/stripe/services/tax/registration_service.rb', line 248 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
244 245 246 |
# File 'lib/stripe/services/tax/registration_service.rb', line 244 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
246 247 248 |
# File 'lib/stripe/services/tax/registration_service.rb', line 246 def type @type end |