Class: Stripe::Tax::RegistrationService::CreateParams::CountryOptions::Bg
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationService::CreateParams::CountryOptions::Bg
- Defined in:
- lib/stripe/services/tax/registration_service.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Bg
constructor
A new instance of Bg.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Bg
Returns a new instance of Bg.
189 190 191 192 |
# File 'lib/stripe/services/tax/registration_service.rb', line 189 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
185 186 187 |
# File 'lib/stripe/services/tax/registration_service.rb', line 185 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
187 188 189 |
# File 'lib/stripe/services/tax/registration_service.rb', line 187 def type @type end |