Class: Stripe::Tax::RegistrationService::CreateParams::CountryOptions::Cz
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationService::CreateParams::CountryOptions::Cz
- Defined in:
- lib/stripe/services/tax/registration_service.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Cz
constructor
A new instance of Cz.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Cz
Returns a new instance of Cz.
348 349 350 351 |
# File 'lib/stripe/services/tax/registration_service.rb', line 348 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
344 345 346 |
# File 'lib/stripe/services/tax/registration_service.rb', line 344 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
346 347 348 |
# File 'lib/stripe/services/tax/registration_service.rb', line 346 def type @type end |