Class: Stripe::Tax::RegistrationService::CreateParams::CountryOptions::De
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationService::CreateParams::CountryOptions::De
- Defined in:
- lib/stripe/services/tax/registration_service.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ De
constructor
A new instance of De.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ De
Returns a new instance of De.
305 306 307 308 |
# File 'lib/stripe/services/tax/registration_service.rb', line 305 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
301 302 303 |
# File 'lib/stripe/services/tax/registration_service.rb', line 301 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
303 304 305 |
# File 'lib/stripe/services/tax/registration_service.rb', line 303 def type @type end |