Class: Stripe::Tax::RegistrationService::CreateParams::CountryOptions::Dk
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationService::CreateParams::CountryOptions::Dk
- Defined in:
- lib/stripe/services/tax/registration_service.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Dk
constructor
A new instance of Dk.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Dk
Returns a new instance of Dk.
361 362 363 364 |
# File 'lib/stripe/services/tax/registration_service.rb', line 361 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
357 358 359 |
# File 'lib/stripe/services/tax/registration_service.rb', line 357 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
359 360 361 |
# File 'lib/stripe/services/tax/registration_service.rb', line 359 def type @type end |