Class: Stripe::Tax::RegistrationService::CreateParams::CountryOptions::Ee
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationService::CreateParams::CountryOptions::Ee
- Defined in:
- lib/stripe/services/tax/registration_service.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Ee
constructor
A new instance of Ee.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Ee
Returns a new instance of Ee.
560 561 562 563 |
# File 'lib/stripe/services/tax/registration_service.rb', line 560 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
556 557 558 |
# File 'lib/stripe/services/tax/registration_service.rb', line 556 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
558 559 560 |
# File 'lib/stripe/services/tax/registration_service.rb', line 558 def type @type end |