Class: Stripe::Tax::RegistrationService::CreateParams::CountryOptions::Fi
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationService::CreateParams::CountryOptions::Fi
- Defined in:
- lib/stripe/services/tax/registration_service.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Fi
constructor
A new instance of Fi.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Fi
Returns a new instance of Fi.
475 476 477 478 |
# File 'lib/stripe/services/tax/registration_service.rb', line 475 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
471 472 473 |
# File 'lib/stripe/services/tax/registration_service.rb', line 471 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
473 474 475 |
# File 'lib/stripe/services/tax/registration_service.rb', line 473 def type @type end |