Class: Stripe::Tax::RegistrationService::CreateParams::CountryOptions::Fr
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationService::CreateParams::CountryOptions::Fr
- Defined in:
- lib/stripe/services/tax/registration_service.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Fr
constructor
A new instance of Fr.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Fr
Returns a new instance of Fr.
468 469 470 471 |
# File 'lib/stripe/services/tax/registration_service.rb', line 468 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
464 465 466 |
# File 'lib/stripe/services/tax/registration_service.rb', line 464 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
466 467 468 |
# File 'lib/stripe/services/tax/registration_service.rb', line 466 def type @type end |