Class: Stripe::Tax::RegistrationService::CreateParams::CountryOptions::Gr
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationService::CreateParams::CountryOptions::Gr
- Defined in:
- lib/stripe/services/tax/registration_service.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Gr
constructor
A new instance of Gr.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Gr
Returns a new instance of Gr.
415 416 417 418 |
# File 'lib/stripe/services/tax/registration_service.rb', line 415 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
410 411 412 |
# File 'lib/stripe/services/tax/registration_service.rb', line 410 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
413 414 415 |
# File 'lib/stripe/services/tax/registration_service.rb', line 413 def type @type end |