Class: Stripe::Tax::RegistrationService::CreateParams::CountryOptions::Hu
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationService::CreateParams::CountryOptions::Hu
- Defined in:
- lib/stripe/services/tax/registration_service.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Hu
constructor
A new instance of Hu.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Hu
Returns a new instance of Hu.
582 583 584 585 |
# File 'lib/stripe/services/tax/registration_service.rb', line 582 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
578 579 580 |
# File 'lib/stripe/services/tax/registration_service.rb', line 578 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
580 581 582 |
# File 'lib/stripe/services/tax/registration_service.rb', line 580 def type @type end |