Class: Stripe::Tax::RegistrationService::CreateParams::CountryOptions::It
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationService::CreateParams::CountryOptions::It
- Defined in:
- lib/stripe/services/tax/registration_service.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ It
constructor
A new instance of It.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ It
Returns a new instance of It.
649 650 651 652 |
# File 'lib/stripe/services/tax/registration_service.rb', line 649 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
645 646 647 |
# File 'lib/stripe/services/tax/registration_service.rb', line 645 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
647 648 649 |
# File 'lib/stripe/services/tax/registration_service.rb', line 647 def type @type end |