Class: Stripe::Tax::RegistrationService::CreateParams::CountryOptions::Lt
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationService::CreateParams::CountryOptions::Lt
- Defined in:
- lib/stripe/services/tax/registration_service.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Lt
constructor
A new instance of Lt.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Lt
Returns a new instance of Lt.
930 931 932 933 |
# File 'lib/stripe/services/tax/registration_service.rb', line 930 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
926 927 928 |
# File 'lib/stripe/services/tax/registration_service.rb', line 926 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
928 929 930 |
# File 'lib/stripe/services/tax/registration_service.rb', line 928 def type @type end |