Class: Stripe::Tax::RegistrationService::CreateParams::CountryOptions::Lu
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationService::CreateParams::CountryOptions::Lu
- Defined in:
- lib/stripe/services/tax/registration_service.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Lu
constructor
A new instance of Lu.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Lu
Returns a new instance of Lu.
595 596 597 598 |
# File 'lib/stripe/services/tax/registration_service.rb', line 595 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
590 591 592 |
# File 'lib/stripe/services/tax/registration_service.rb', line 590 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
593 594 595 |
# File 'lib/stripe/services/tax/registration_service.rb', line 593 def type @type end |