Class: Stripe::Tax::RegistrationService::CreateParams::CountryOptions::Nl
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationService::CreateParams::CountryOptions::Nl
- Defined in:
- lib/stripe/services/tax/registration_service.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Nl
constructor
A new instance of Nl.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Nl
Returns a new instance of Nl.
1115 1116 1117 1118 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1115 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
1111 1112 1113 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1111 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
1113 1114 1115 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1113 def type @type end |