Class: Stripe::Tax::RegistrationService::CreateParams::CountryOptions::Pl
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationService::CreateParams::CountryOptions::Pl
- Defined in:
- lib/stripe/services/tax/registration_service.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Pl
constructor
A new instance of Pl.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Pl
Returns a new instance of Pl.
1222 1223 1224 1225 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1222 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
1218 1219 1220 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1218 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
1220 1221 1222 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1220 def type @type end |