Class: Stripe::Tax::RegistrationService::CreateParams::CountryOptions::Pt
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationService::CreateParams::CountryOptions::Pt
- Defined in:
- lib/stripe/services/tax/registration_service.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Pt
constructor
A new instance of Pt.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Pt
Returns a new instance of Pt.
879 880 881 882 |
# File 'lib/stripe/services/tax/registration_service.rb', line 879 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
875 876 877 |
# File 'lib/stripe/services/tax/registration_service.rb', line 875 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
877 878 879 |
# File 'lib/stripe/services/tax/registration_service.rb', line 877 def type @type end |