Class: Stripe::Tax::RegistrationService::CreateParams::CountryOptions::Ro
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationService::CreateParams::CountryOptions::Ro
- Defined in:
- lib/stripe/services/tax/registration_service.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Ro
constructor
A new instance of Ro.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Ro
Returns a new instance of Ro.
1262 1263 1264 1265 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1262 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
1258 1259 1260 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1258 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
1260 1261 1262 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1260 def type @type end |