Class: Stripe::Tax::RegistrationService::CreateParams::CountryOptions::Se
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationService::CreateParams::CountryOptions::Se
- Defined in:
- lib/stripe/services/tax/registration_service.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Se
constructor
A new instance of Se.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Se
Returns a new instance of Se.
1045 1046 1047 1048 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1045 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
1041 1042 1043 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1041 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
1043 1044 1045 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1043 def type @type end |