Class: Stripe::Tax::RegistrationService::CreateParams::CountryOptions::Si
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationService::CreateParams::CountryOptions::Si
- Defined in:
- lib/stripe/services/tax/registration_service.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Si
constructor
A new instance of Si.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Si
Returns a new instance of Si.
1360 1361 1362 1363 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1360 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
1356 1357 1358 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1356 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
1358 1359 1360 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1358 def type @type end |