Class: Stripe::Tax::RegistrationService::RetrieveParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationService::RetrieveParams
- Defined in:
- lib/stripe/services/tax/registration_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ RetrieveParams
constructor
A new instance of RetrieveParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ RetrieveParams
Returns a new instance of RetrieveParams.
2050 2051 2052 |
# File 'lib/stripe/services/tax/registration_service.rb', line 2050 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2048 2049 2050 |
# File 'lib/stripe/services/tax/registration_service.rb', line 2048 def @expand end |