Class: Stripe::Tax::RegistrationService::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/tax/registration_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(active_from: nil, expand: nil, expires_at: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



1720
1721
1722
1723
1724
# File 'lib/stripe/services/tax/registration_service.rb', line 1720

def initialize(active_from: nil, expand: nil, expires_at: nil)
  @active_from = active_from
  @expand = expand
  @expires_at = expires_at
end

Instance Attribute Details

#active_fromObject

Time at which the registration becomes active. It can be either ‘now` to indicate the current time, or a timestamp measured in seconds since the Unix epoch.



1714
1715
1716
# File 'lib/stripe/services/tax/registration_service.rb', line 1714

def active_from
  @active_from
end

#expandObject

Specifies which fields in the response should be expanded.



1716
1717
1718
# File 'lib/stripe/services/tax/registration_service.rb', line 1716

def expand
  @expand
end

#expires_atObject

If set, the registration stops being active at this time. If not set, the registration will be active indefinitely. It can be either ‘now` to indicate the current time, or a timestamp measured in seconds since the Unix epoch.



1718
1719
1720
# File 'lib/stripe/services/tax/registration_service.rb', line 1718

def expires_at
  @expires_at
end