Class: Stripe::Tax::Settings

Inherits:
SingletonAPIResource show all
Includes:
APIOperations::SingletonSave
Defined in:
lib/stripe/resources/tax/settings.rb

Overview

You can use Tax ‘Settings` to manage configurations used by Stripe Tax calculations.

Related guide: [Using the Settings API](stripe.com/docs/tax/settings-api)

Defined Under Namespace

Classes: Defaults, HeadOffice, StatusDetails, UpdateParams

Constant Summary collapse

OBJECT_NAME =
"tax.settings"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods included from APIOperations::SingletonSave

included, #save

Methods inherited from SingletonAPIResource

resource_url, #resource_url, retrieve

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#defaultsObject (readonly)

Attribute for field defaults



169
170
171
# File 'lib/stripe/resources/tax/settings.rb', line 169

def defaults
  @defaults
end

#head_officeObject (readonly)

The place where your business is located.



171
172
173
# File 'lib/stripe/resources/tax/settings.rb', line 171

def head_office
  @head_office
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



173
174
175
# File 'lib/stripe/resources/tax/settings.rb', line 173

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



175
176
177
# File 'lib/stripe/resources/tax/settings.rb', line 175

def object
  @object
end

#statusObject (readonly)

The status of the Tax ‘Settings`.



177
178
179
# File 'lib/stripe/resources/tax/settings.rb', line 177

def status
  @status
end

#status_detailsObject (readonly)

Attribute for field status_details



179
180
181
# File 'lib/stripe/resources/tax/settings.rb', line 179

def status_details
  @status_details
end

Class Method Details

.field_remappingsObject



189
190
191
# File 'lib/stripe/resources/tax/settings.rb', line 189

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



181
182
183
184
185
186
187
# File 'lib/stripe/resources/tax/settings.rb', line 181

def self.inner_class_types
  @inner_class_types = {
    defaults: Defaults,
    head_office: HeadOffice,
    status_details: StatusDetails,
  }
end

.object_nameObject



13
14
15
# File 'lib/stripe/resources/tax/settings.rb', line 13

def self.object_name
  "tax.settings"
end