Class: Stripe::Tax::Settings::Defaults
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Tax::Settings::Defaults
- Defined in:
- lib/stripe/resources/tax/settings.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#tax_behavior ⇒ Object
readonly
Default [tax behavior](stripe.com/docs/tax/products-prices-tax-categories-tax-behavior#tax-behavior) used to specify whether the price is considered inclusive of taxes or exclusive of taxes.
-
#tax_code ⇒ Object
readonly
Default [tax code](stripe.com/docs/tax/tax-categories) used to classify your products and prices.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#tax_behavior ⇒ Object (readonly)
Default [tax behavior](stripe.com/docs/tax/products-prices-tax-categories-tax-behavior#tax-behavior) used to specify whether the price is considered inclusive of taxes or exclusive of taxes. If the item’s price has a tax behavior set, it will take precedence over the default tax behavior.
19 20 21 |
# File 'lib/stripe/resources/tax/settings.rb', line 19 def tax_behavior @tax_behavior end |
#tax_code ⇒ Object (readonly)
Default [tax code](stripe.com/docs/tax/tax-categories) used to classify your products and prices.
21 22 23 |
# File 'lib/stripe/resources/tax/settings.rb', line 21 def tax_code @tax_code end |