Class: Stripe::Tax::Settings::StatusDetails::Pending
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Tax::Settings::StatusDetails::Pending
- Defined in:
- lib/stripe/resources/tax/settings.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#missing_fields ⇒ Object
readonly
The list of missing fields that are required to perform calculations.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#missing_fields ⇒ Object (readonly)
The list of missing fields that are required to perform calculations. It includes the entry ‘head_office` when the status is `pending`. It is recommended to set the optional values even if they aren’t listed as required for calculating taxes. Calculations can fail if missing fields aren’t explicitly provided on every call.
80 81 82 |
# File 'lib/stripe/resources/tax/settings.rb', line 80 def missing_fields @missing_fields end |
Class Method Details
.field_remappings ⇒ Object
86 87 88 |
# File 'lib/stripe/resources/tax/settings.rb', line 86 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
82 83 84 |
# File 'lib/stripe/resources/tax/settings.rb', line 82 def self.inner_class_types @inner_class_types = {} end |