Class: Stripe::Tax::Settings::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Settings::UpdateParams
- Defined in:
- lib/stripe/resources/tax/settings.rb
Defined Under Namespace
Classes: Defaults, HeadOffice
Instance Attribute Summary collapse
-
#defaults ⇒ Object
Default configuration to be used on Stripe Tax calculations.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#head_office ⇒ Object
The place where your business is located.
Instance Method Summary collapse
-
#initialize(defaults: nil, expand: nil, head_office: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(defaults: nil, expand: nil, head_office: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
138 139 140 141 142 |
# File 'lib/stripe/resources/tax/settings.rb', line 138 def initialize(defaults: nil, expand: nil, head_office: nil) @defaults = defaults @expand = @head_office = head_office end |
Instance Attribute Details
#defaults ⇒ Object
Default configuration to be used on Stripe Tax calculations.
130 131 132 |
# File 'lib/stripe/resources/tax/settings.rb', line 130 def defaults @defaults end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
133 134 135 |
# File 'lib/stripe/resources/tax/settings.rb', line 133 def @expand end |
#head_office ⇒ Object
The place where your business is located.
136 137 138 |
# File 'lib/stripe/resources/tax/settings.rb', line 136 def head_office @head_office end |