Class: Stripe::Tax::Transaction::CreateReversalParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/tax/transaction.rb

Defined Under Namespace

Classes: LineItem, ShippingCost

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, flat_amount: nil, line_items: nil, metadata: nil, mode: nil, original_transaction: nil, reference: nil, shipping_cost: nil) ⇒ CreateReversalParams

Returns a new instance of CreateReversalParams.



300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
# File 'lib/stripe/resources/tax/transaction.rb', line 300

def initialize(
  expand: nil,
  flat_amount: nil,
  line_items: nil,
  metadata: nil,
  mode: nil,
  original_transaction: nil,
  reference: nil,
  shipping_cost: nil
)
  @expand = expand
  @flat_amount = flat_amount
  @line_items = line_items
  @metadata = 
  @mode = mode
  @original_transaction = original_transaction
  @reference = reference
  @shipping_cost = shipping_cost
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



284
285
286
# File 'lib/stripe/resources/tax/transaction.rb', line 284

def expand
  @expand
end

#flat_amountObject

A flat amount to reverse across the entire transaction, in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal) in negative. This value represents the total amount to refund from the transaction, including taxes.



286
287
288
# File 'lib/stripe/resources/tax/transaction.rb', line 286

def flat_amount
  @flat_amount
end

#line_itemsObject

The line item amounts to reverse.



288
289
290
# File 'lib/stripe/resources/tax/transaction.rb', line 288

def line_items
  @line_items
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



290
291
292
# File 'lib/stripe/resources/tax/transaction.rb', line 290

def 
  @metadata
end

#modeObject

If ‘partial`, the provided line item or shipping cost amounts are reversed. If `full`, the original transaction is fully reversed.



292
293
294
# File 'lib/stripe/resources/tax/transaction.rb', line 292

def mode
  @mode
end

#original_transactionObject

The ID of the Transaction to partially or fully reverse.



294
295
296
# File 'lib/stripe/resources/tax/transaction.rb', line 294

def original_transaction
  @original_transaction
end

#referenceObject

A custom identifier for this reversal, such as ‘myOrder_123-refund_1`, which must be unique across all transactions. The reference helps identify this reversal transaction in exported [tax reports](stripe.com/docs/tax/reports).



296
297
298
# File 'lib/stripe/resources/tax/transaction.rb', line 296

def reference
  @reference
end

#shipping_costObject

The shipping cost to reverse.



298
299
300
# File 'lib/stripe/resources/tax/transaction.rb', line 298

def shipping_cost
  @shipping_cost
end