Class: Stripe::Tax::Transaction::CreateReversalParams::ShippingCost
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Transaction::CreateReversalParams::ShippingCost
- Defined in:
- lib/stripe/resources/tax/transaction.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount to reverse, in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal) in negative.
-
#amount_tax ⇒ Object
The amount of tax to reverse, in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal) in negative.
Instance Method Summary collapse
-
#initialize(amount: nil, amount_tax: nil) ⇒ ShippingCost
constructor
A new instance of ShippingCost.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, amount_tax: nil) ⇒ ShippingCost
Returns a new instance of ShippingCost.
278 279 280 281 |
# File 'lib/stripe/resources/tax/transaction.rb', line 278 def initialize(amount: nil, amount_tax: nil) @amount = amount @amount_tax = amount_tax end |
Instance Attribute Details
#amount ⇒ Object
The amount to reverse, in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal) in negative.
274 275 276 |
# File 'lib/stripe/resources/tax/transaction.rb', line 274 def amount @amount end |
#amount_tax ⇒ Object
The amount of tax to reverse, in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal) in negative.
276 277 278 |
# File 'lib/stripe/resources/tax/transaction.rb', line 276 def amount_tax @amount_tax end |