Class: Stripe::Tax::Transaction::ListLineItemsParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/tax/transaction.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListLineItemsParams

Returns a new instance of ListLineItemsParams.



173
174
175
176
177
178
# File 'lib/stripe/resources/tax/transaction.rb', line 173

def initialize(ending_before: nil, expand: nil, limit: nil, starting_after: nil)
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
end

Instance Attribute Details

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



162
163
164
# File 'lib/stripe/resources/tax/transaction.rb', line 162

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



165
166
167
# File 'lib/stripe/resources/tax/transaction.rb', line 165

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



168
169
170
# File 'lib/stripe/resources/tax/transaction.rb', line 168

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



171
172
173
# File 'lib/stripe/resources/tax/transaction.rb', line 171

def starting_after
  @starting_after
end