Class: Stripe::Tax::Transaction::ShippingCost
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Tax::Transaction::ShippingCost
- Defined in:
- lib/stripe/resources/tax/transaction.rb
Defined Under Namespace
Classes: TaxBreakdown
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The shipping amount in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).
-
#amount_tax ⇒ Object
readonly
The amount of tax calculated for shipping, in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).
-
#shipping_rate ⇒ Object
readonly
The ID of an existing [ShippingRate](stripe.com/docs/api/shipping_rates/object).
-
#tax_behavior ⇒ Object
readonly
Specifies whether the ‘amount` includes taxes.
-
#tax_breakdown ⇒ Object
readonly
Detailed account of taxes relevant to shipping cost.
-
#tax_code ⇒ Object
readonly
The [tax code](stripe.com/docs/tax/tax-categories) ID used for shipping.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The shipping amount in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal). If ‘tax_behavior=inclusive`, then this amount includes taxes. Otherwise, taxes were calculated on top of this amount.
108 109 110 |
# File 'lib/stripe/resources/tax/transaction.rb', line 108 def amount @amount end |
#amount_tax ⇒ Object (readonly)
The amount of tax calculated for shipping, in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).
110 111 112 |
# File 'lib/stripe/resources/tax/transaction.rb', line 110 def amount_tax @amount_tax end |
#shipping_rate ⇒ Object (readonly)
The ID of an existing [ShippingRate](stripe.com/docs/api/shipping_rates/object).
112 113 114 |
# File 'lib/stripe/resources/tax/transaction.rb', line 112 def shipping_rate @shipping_rate end |
#tax_behavior ⇒ Object (readonly)
Specifies whether the ‘amount` includes taxes. If `tax_behavior=inclusive`, then the amount includes taxes.
114 115 116 |
# File 'lib/stripe/resources/tax/transaction.rb', line 114 def tax_behavior @tax_behavior end |
#tax_breakdown ⇒ Object (readonly)
Detailed account of taxes relevant to shipping cost. (It is not populated for the transaction resource object and will be removed in the next API version.)
116 117 118 |
# File 'lib/stripe/resources/tax/transaction.rb', line 116 def tax_breakdown @tax_breakdown end |
#tax_code ⇒ Object (readonly)
The [tax code](stripe.com/docs/tax/tax-categories) ID used for shipping.
118 119 120 |
# File 'lib/stripe/resources/tax/transaction.rb', line 118 def tax_code @tax_code end |