Class: Stripe::Tax::TransactionService::CreateReversalParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::TransactionService::CreateReversalParams
- Defined in:
- lib/stripe/services/tax/transaction_service.rb
Defined Under Namespace
Classes: LineItem, ShippingCost
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#flat_amount ⇒ Object
A flat amount to reverse across the entire transaction, in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal) in negative.
-
#line_items ⇒ Object
The line item amounts to reverse.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#mode ⇒ Object
If ‘partial`, the provided line item or shipping cost amounts are reversed.
-
#original_transaction ⇒ Object
The ID of the Transaction to partially or fully reverse.
-
#reference ⇒ Object
A custom identifier for this reversal, such as ‘myOrder_123-refund_1`, which must be unique across all transactions.
-
#shipping_cost ⇒ Object
The shipping cost to reverse.
Instance Method Summary collapse
-
#initialize(expand: nil, flat_amount: nil, line_items: nil, metadata: nil, mode: nil, original_transaction: nil, reference: nil, shipping_cost: nil) ⇒ CreateReversalParams
constructor
A new instance of CreateReversalParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, flat_amount: nil, line_items: nil, metadata: nil, mode: nil, original_transaction: nil, reference: nil, shipping_cost: nil) ⇒ CreateReversalParams
Returns a new instance of CreateReversalParams.
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/stripe/services/tax/transaction_service.rb', line 121 def initialize( expand: nil, flat_amount: nil, line_items: nil, metadata: nil, mode: nil, original_transaction: nil, reference: nil, shipping_cost: nil ) @expand = @flat_amount = flat_amount @line_items = line_items @metadata = @mode = mode @original_transaction = original_transaction @reference = reference @shipping_cost = shipping_cost end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
98 99 100 |
# File 'lib/stripe/services/tax/transaction_service.rb', line 98 def @expand end |
#flat_amount ⇒ Object
A flat amount to reverse across the entire transaction, in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal) in negative. This value represents the total amount to refund from the transaction, including taxes.
101 102 103 |
# File 'lib/stripe/services/tax/transaction_service.rb', line 101 def flat_amount @flat_amount end |
#line_items ⇒ Object
The line item amounts to reverse.
104 105 106 |
# File 'lib/stripe/services/tax/transaction_service.rb', line 104 def line_items @line_items end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
107 108 109 |
# File 'lib/stripe/services/tax/transaction_service.rb', line 107 def @metadata end |
#mode ⇒ Object
If ‘partial`, the provided line item or shipping cost amounts are reversed. If `full`, the original transaction is fully reversed.
110 111 112 |
# File 'lib/stripe/services/tax/transaction_service.rb', line 110 def mode @mode end |
#original_transaction ⇒ Object
The ID of the Transaction to partially or fully reverse.
113 114 115 |
# File 'lib/stripe/services/tax/transaction_service.rb', line 113 def original_transaction @original_transaction end |
#reference ⇒ Object
A custom identifier for this reversal, such as ‘myOrder_123-refund_1`, which must be unique across all transactions. The reference helps identify this reversal transaction in exported [tax reports](stripe.com/docs/tax/reports).
116 117 118 |
# File 'lib/stripe/services/tax/transaction_service.rb', line 116 def reference @reference end |
#shipping_cost ⇒ Object
The shipping cost to reverse.
119 120 121 |
# File 'lib/stripe/services/tax/transaction_service.rb', line 119 def shipping_cost @shipping_cost end |