Class: Stripe::Tax::TransactionService::CreateReversalParams::ShippingCost
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::TransactionService::CreateReversalParams::ShippingCost
- Defined in:
- lib/stripe/services/tax/transaction_service.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount to reverse, in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal) in negative.
-
#amount_tax ⇒ Object
The amount of tax to reverse, in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal) in negative.
Instance Method Summary collapse
-
#initialize(amount: nil, amount_tax: nil) ⇒ ShippingCost
constructor
A new instance of ShippingCost.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, amount_tax: nil) ⇒ ShippingCost
Returns a new instance of ShippingCost.
92 93 94 95 |
# File 'lib/stripe/services/tax/transaction_service.rb', line 92 def initialize(amount: nil, amount_tax: nil) @amount = amount @amount_tax = amount_tax end |
Instance Attribute Details
#amount ⇒ Object
The amount to reverse, in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal) in negative.
87 88 89 |
# File 'lib/stripe/services/tax/transaction_service.rb', line 87 def amount @amount end |
#amount_tax ⇒ Object
The amount of tax to reverse, in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal) in negative.
90 91 92 |
# File 'lib/stripe/services/tax/transaction_service.rb', line 90 def amount_tax @amount_tax end |