Class: Stripe::TaxFund

Inherits:
APIResource show all
Extended by:
APIOperations::List
Defined in:
lib/stripe/resources/tax_fund.rb

Overview

A TaxFund object represents a single tax float sweep event — funds moved between a merchant's payments balance and their tax fund financial account for Stripe Tax obligations.

Defined Under Namespace

Classes: Context, Destination, Source, Trigger

Constant Summary collapse

OBJECT_NAME =
"tax_fund"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods included from APIOperations::List

list

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Amount swept, in the smallest currency unit. Always positive.



141
142
143
# File 'lib/stripe/resources/tax_fund.rb', line 141

def amount
  @amount
end

#contextObject (readonly)

Associated billing or tax documents for this sweep.



143
144
145
# File 'lib/stripe/resources/tax_fund.rb', line 143

def context
  @context
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



145
146
147
# File 'lib/stripe/resources/tax_fund.rb', line 145

def created
  @created
end

#currencyObject (readonly)

Three-letter ISO currency code, in lowercase. Must be a supported currency.



147
148
149
# File 'lib/stripe/resources/tax_fund.rb', line 147

def currency
  @currency
end

#destinationObject (readonly)

Where funds moved to.



149
150
151
# File 'lib/stripe/resources/tax_fund.rb', line 149

def destination
  @destination
end

#idObject (readonly)

Unique identifier for the object.



151
152
153
# File 'lib/stripe/resources/tax_fund.rb', line 151

def id
  @id
end

#livemodeObject (readonly)

If the object exists in live mode, the value is true. If the object exists in test mode, the value is false.



153
154
155
# File 'lib/stripe/resources/tax_fund.rb', line 153

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object's type. Objects of the same type share the same value.



155
156
157
# File 'lib/stripe/resources/tax_fund.rb', line 155

def object
  @object
end

#sourceObject (readonly)

Where funds moved from.



157
158
159
# File 'lib/stripe/resources/tax_fund.rb', line 157

def source
  @source
end

#triggerObject (readonly)

What caused the sweep.



159
160
161
# File 'lib/stripe/resources/tax_fund.rb', line 159

def trigger
  @trigger
end

Class Method Details

.field_remappingsObject



175
176
177
# File 'lib/stripe/resources/tax_fund.rb', line 175

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



166
167
168
169
170
171
172
173
# File 'lib/stripe/resources/tax_fund.rb', line 166

def self.inner_class_types
  @inner_class_types = {
    context: Context,
    destination: Destination,
    source: Source,
    trigger: Trigger,
  }
end

.list(params = {}, opts = {}) ⇒ Object

Returns a list of tax funds in reverse chronological order.



162
163
164
# File 'lib/stripe/resources/tax_fund.rb', line 162

def self.list(params = {}, opts = {})
  request_stripe_object(method: :get, path: "/v1/tax_funds", params: params, opts: opts)
end

.object_nameObject



11
12
13
# File 'lib/stripe/resources/tax_fund.rb', line 11

def self.object_name
  "tax_fund"
end