Class: Stripe::TaxFund::Destination

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/tax_fund.rb

Defined Under Namespace

Classes: PaymentsBalance, TaxFundAccount

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#payments_balanceObject (readonly)

Details about the payments balance side of the sweep.



67
68
69
# File 'lib/stripe/resources/tax_fund.rb', line 67

def payments_balance
  @payments_balance
end

#tax_fund_accountObject (readonly)

Details about the tax fund financial account side of the sweep.



69
70
71
# File 'lib/stripe/resources/tax_fund.rb', line 69

def 
  @tax_fund_account
end

#typeObject (readonly)

The type of account funds moved to or from. Either payments_balance or tax_fund_account.



71
72
73
# File 'lib/stripe/resources/tax_fund.rb', line 71

def type
  @type
end

Class Method Details

.field_remappingsObject



77
78
79
# File 'lib/stripe/resources/tax_fund.rb', line 77

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



73
74
75
# File 'lib/stripe/resources/tax_fund.rb', line 73

def self.inner_class_types
  @inner_class_types = { payments_balance: PaymentsBalance, tax_fund_account: TaxFundAccount }
end