Class: Stripe::TaxFundService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::TaxFundService
- Defined in:
- lib/stripe/services/tax_fund_service.rb
Instance Method Summary collapse
-
#list(params = {}, opts = {}) ⇒ Object
Returns a list of tax funds in reverse chronological order.
-
#retrieve(tax_fund, params = {}, opts = {}) ⇒ Object
Retrieves a tax fund object by its ID.
Methods inherited from StripeService
#initialize, #request, #request_stream
Constructor Details
This class inherits a constructor from Stripe::StripeService
Instance Method Details
#list(params = {}, opts = {}) ⇒ Object
Returns a list of tax funds in reverse chronological order.
7 8 9 |
# File 'lib/stripe/services/tax_fund_service.rb', line 7 def list(params = {}, opts = {}) request(method: :get, path: "/v1/tax_funds", params: params, opts: opts, base_address: :api) end |
#retrieve(tax_fund, params = {}, opts = {}) ⇒ Object
Retrieves a tax fund object by its ID.
12 13 14 15 16 17 18 19 20 |
# File 'lib/stripe/services/tax_fund_service.rb', line 12 def retrieve(tax_fund, params = {}, opts = {}) request( method: :get, path: format("/v1/tax_funds/%<tax_fund>s", { tax_fund: CGI.escape(tax_fund) }), params: params, opts: opts, base_address: :api ) end |