Class: Stripe::TaxRate::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/tax_rate.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(active: nil, country: nil, description: nil, display_name: nil, expand: nil, inclusive: nil, jurisdiction: nil, metadata: nil, percentage: nil, state: nil, tax_type: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
# File 'lib/stripe/resources/tax_rate.rb', line 109

def initialize(
  active: nil,
  country: nil,
  description: nil,
  display_name: nil,
  expand: nil,
  inclusive: nil,
  jurisdiction: nil,
  metadata: nil,
  percentage: nil,
  state: nil,
  tax_type: nil
)
  @active = active
  @country = country
  @description = description
  @display_name = display_name
  @expand = expand
  @inclusive = inclusive
  @jurisdiction = jurisdiction
  @metadata = 
  @percentage = percentage
  @state = state
  @tax_type = tax_type
end

Instance Attribute Details

#activeObject

Flag determining whether the tax rate is active or inactive (archived). Inactive tax rates cannot be used with new applications or Checkout Sessions, but will still work for subscriptions and invoices that already have it set.



87
88
89
# File 'lib/stripe/resources/tax_rate.rb', line 87

def active
  @active
end

#countryObject

Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).



89
90
91
# File 'lib/stripe/resources/tax_rate.rb', line 89

def country
  @country
end

#descriptionObject

An arbitrary string attached to the tax rate for your internal use only. It will not be visible to your customers.



91
92
93
# File 'lib/stripe/resources/tax_rate.rb', line 91

def description
  @description
end

#display_nameObject

The display name of the tax rate, which will be shown to users.



93
94
95
# File 'lib/stripe/resources/tax_rate.rb', line 93

def display_name
  @display_name
end

#expandObject

Specifies which fields in the response should be expanded.



95
96
97
# File 'lib/stripe/resources/tax_rate.rb', line 95

def expand
  @expand
end

#inclusiveObject

This specifies if the tax rate is inclusive or exclusive.



97
98
99
# File 'lib/stripe/resources/tax_rate.rb', line 97

def inclusive
  @inclusive
end

#jurisdictionObject

The jurisdiction for the tax rate. You can use this label field for tax reporting purposes. It also appears on your customer’s invoice.



99
100
101
# File 'lib/stripe/resources/tax_rate.rb', line 99

def jurisdiction
  @jurisdiction
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



101
102
103
# File 'lib/stripe/resources/tax_rate.rb', line 101

def 
  @metadata
end

#percentageObject

This represents the tax rate percent out of 100.



103
104
105
# File 'lib/stripe/resources/tax_rate.rb', line 103

def percentage
  @percentage
end

#stateObject

[ISO 3166-2 subdivision code](en.wikipedia.org/wiki/ISO_3166-2), without country prefix. For example, “NY” for New York, United States.



105
106
107
# File 'lib/stripe/resources/tax_rate.rb', line 105

def state
  @state
end

#tax_typeObject

The high-level tax type, such as ‘vat` or `sales_tax`.



107
108
109
# File 'lib/stripe/resources/tax_rate.rb', line 107

def tax_type
  @tax_type
end