Class: Stripe::TaxRateService::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/tax_rate_service.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(active: nil, created: nil, ending_before: nil, expand: nil, inclusive: nil, limit: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/stripe/services/tax_rate_service.rb', line 48

def initialize(
  active: nil,
  created: nil,
  ending_before: nil,
  expand: nil,
  inclusive: nil,
  limit: nil,
  starting_after: nil
)
  @active = active
  @created = created
  @ending_before = ending_before
  @expand = expand
  @inclusive = inclusive
  @limit = limit
  @starting_after = starting_after
end

Instance Attribute Details

#activeObject

Optional flag to filter by tax rates that are either active or inactive (archived).



28
29
30
# File 'lib/stripe/services/tax_rate_service.rb', line 28

def active
  @active
end

#createdObject

Optional range for filtering created date.



31
32
33
# File 'lib/stripe/services/tax_rate_service.rb', line 31

def created
  @created
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



34
35
36
# File 'lib/stripe/services/tax_rate_service.rb', line 34

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



37
38
39
# File 'lib/stripe/services/tax_rate_service.rb', line 37

def expand
  @expand
end

#inclusiveObject

Optional flag to filter by tax rates that are inclusive (or those that are not inclusive).



40
41
42
# File 'lib/stripe/services/tax_rate_service.rb', line 40

def inclusive
  @inclusive
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



43
44
45
# File 'lib/stripe/services/tax_rate_service.rb', line 43

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



46
47
48
# File 'lib/stripe/services/tax_rate_service.rb', line 46

def starting_after
  @starting_after
end