Class: Stripe::TaxRateService::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::TaxRateService::UpdateParams
- Defined in:
- lib/stripe/services/tax_rate_service.rb
Instance Attribute Summary collapse
-
#active ⇒ Object
Flag determining whether the tax rate is active or inactive (archived).
-
#country ⇒ Object
Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
-
#description ⇒ Object
An arbitrary string attached to the tax rate for your internal use only.
-
#display_name ⇒ Object
The display name of the tax rate, which will be shown to users.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#jurisdiction ⇒ Object
The jurisdiction for the tax rate.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#state ⇒ Object
[ISO 3166-2 subdivision code](en.wikipedia.org/wiki/ISO_3166-2), without country prefix.
-
#tax_type ⇒ Object
The high-level tax type, such as ‘vat` or `sales_tax`.
Instance Method Summary collapse
-
#initialize(active: nil, country: nil, description: nil, display_name: nil, expand: nil, jurisdiction: nil, metadata: nil, state: nil, tax_type: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(active: nil, country: nil, description: nil, display_name: nil, expand: nil, jurisdiction: nil, metadata: nil, state: nil, tax_type: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/stripe/services/tax_rate_service.rb', line 138 def initialize( active: nil, country: nil, description: nil, display_name: nil, expand: nil, jurisdiction: nil, metadata: nil, state: nil, tax_type: nil ) @active = active @country = country @description = description @display_name = display_name @expand = @jurisdiction = jurisdiction @metadata = @state = state @tax_type = tax_type end |
Instance Attribute Details
#active ⇒ Object
Flag determining whether the tax rate is active or inactive (archived). Inactive tax rates cannot be used with new applications or Checkout Sessions, but will still work for subscriptions and invoices that already have it set.
120 121 122 |
# File 'lib/stripe/services/tax_rate_service.rb', line 120 def active @active end |
#country ⇒ Object
Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
122 123 124 |
# File 'lib/stripe/services/tax_rate_service.rb', line 122 def country @country end |
#description ⇒ Object
An arbitrary string attached to the tax rate for your internal use only. It will not be visible to your customers.
124 125 126 |
# File 'lib/stripe/services/tax_rate_service.rb', line 124 def description @description end |
#display_name ⇒ Object
The display name of the tax rate, which will be shown to users.
126 127 128 |
# File 'lib/stripe/services/tax_rate_service.rb', line 126 def display_name @display_name end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
128 129 130 |
# File 'lib/stripe/services/tax_rate_service.rb', line 128 def @expand end |
#jurisdiction ⇒ Object
The jurisdiction for the tax rate. You can use this label field for tax reporting purposes. It also appears on your customer’s invoice.
130 131 132 |
# File 'lib/stripe/services/tax_rate_service.rb', line 130 def jurisdiction @jurisdiction end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
132 133 134 |
# File 'lib/stripe/services/tax_rate_service.rb', line 132 def @metadata end |
#state ⇒ Object
[ISO 3166-2 subdivision code](en.wikipedia.org/wiki/ISO_3166-2), without country prefix. For example, “NY” for New York, United States.
134 135 136 |
# File 'lib/stripe/services/tax_rate_service.rb', line 134 def state @state end |
#tax_type ⇒ Object
The high-level tax type, such as ‘vat` or `sales_tax`.
136 137 138 |
# File 'lib/stripe/services/tax_rate_service.rb', line 136 def tax_type @tax_type end |