Class: Stripe::Terminal::Configuration::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/terminal/configuration.rb

Defined Under Namespace

Classes: BbposWiseposE, Offline, ReaderSecurity, RebootWindow, StripeS700, Tipping, VerifoneP400, Wifi

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bbpos_wisepos_e: nil, expand: nil, name: nil, offline: nil, reader_security: nil, reboot_window: nil, stripe_s700: nil, tipping: nil, verifone_p400: nil, wifi: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



1785
1786
1787
1788
1789
1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
1807
# File 'lib/stripe/resources/terminal/configuration.rb', line 1785

def initialize(
  bbpos_wisepos_e: nil,
  expand: nil,
  name: nil,
  offline: nil,
  reader_security: nil,
  reboot_window: nil,
  stripe_s700: nil,
  tipping: nil,
  verifone_p400: nil,
  wifi: nil
)
  @bbpos_wisepos_e = bbpos_wisepos_e
  @expand = expand
  @name = name
  @offline = offline
  @reader_security = reader_security
  @reboot_window = reboot_window
  @stripe_s700 = stripe_s700
  @tipping = tipping
  @verifone_p400 = verifone_p400
  @wifi = wifi
end

Instance Attribute Details

#bbpos_wisepos_eObject

An object containing device type specific settings for BBPOS WisePOS E readers



1765
1766
1767
# File 'lib/stripe/resources/terminal/configuration.rb', line 1765

def bbpos_wisepos_e
  @bbpos_wisepos_e
end

#expandObject

Specifies which fields in the response should be expanded.



1767
1768
1769
# File 'lib/stripe/resources/terminal/configuration.rb', line 1767

def expand
  @expand
end

#nameObject

Name of the configuration



1769
1770
1771
# File 'lib/stripe/resources/terminal/configuration.rb', line 1769

def name
  @name
end

#offlineObject

Configurations for collecting transactions offline.



1771
1772
1773
# File 'lib/stripe/resources/terminal/configuration.rb', line 1771

def offline
  @offline
end

#reader_securityObject

Configurations for reader security settings.



1773
1774
1775
# File 'lib/stripe/resources/terminal/configuration.rb', line 1773

def reader_security
  @reader_security
end

#reboot_windowObject

Reboot time settings for readers that support customized reboot time configuration.



1775
1776
1777
# File 'lib/stripe/resources/terminal/configuration.rb', line 1775

def reboot_window
  @reboot_window
end

#stripe_s700Object

An object containing device type specific settings for Stripe S700 readers



1777
1778
1779
# File 'lib/stripe/resources/terminal/configuration.rb', line 1777

def stripe_s700
  @stripe_s700
end

#tippingObject

Tipping configurations for readers supporting on-reader tips



1779
1780
1781
# File 'lib/stripe/resources/terminal/configuration.rb', line 1779

def tipping
  @tipping
end

#verifone_p400Object

An object containing device type specific settings for Verifone P400 readers



1781
1782
1783
# File 'lib/stripe/resources/terminal/configuration.rb', line 1781

def verifone_p400
  @verifone_p400
end

#wifiObject

Configurations for connecting to a WiFi network.



1783
1784
1785
# File 'lib/stripe/resources/terminal/configuration.rb', line 1783

def wifi
  @wifi
end