Class: Stripe::Terminal::Configuration::CreateParams::BbposWiseposE
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::Configuration::CreateParams::BbposWiseposE
- Defined in:
- lib/stripe/resources/terminal/configuration.rb
Instance Attribute Summary collapse
-
#splashscreen ⇒ Object
A File ID representing an image you would like displayed on the reader.
Instance Method Summary collapse
-
#initialize(splashscreen: nil) ⇒ BbposWiseposE
constructor
A new instance of BbposWiseposE.
Methods inherited from RequestParams
Constructor Details
#initialize(splashscreen: nil) ⇒ BbposWiseposE
Returns a new instance of BbposWiseposE.
633 634 635 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 633 def initialize(splashscreen: nil) @splashscreen = splashscreen end |
Instance Attribute Details
#splashscreen ⇒ Object
A File ID representing an image you would like displayed on the reader.
631 632 633 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 631 def splashscreen @splashscreen end |