Class: Stripe::Terminal::Configuration::CreateParams::RebootWindow

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/terminal/configuration.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(end_hour: nil, start_hour: nil) ⇒ RebootWindow

Returns a new instance of RebootWindow.



1257
1258
1259
1260
# File 'lib/stripe/resources/terminal/configuration.rb', line 1257

def initialize(end_hour: nil, start_hour: nil)
  @end_hour = end_hour
  @start_hour = start_hour
end

Instance Attribute Details

#end_hourObject

Integer between 0 to 23 that represents the end hour of the reboot time window. The value must be different than the start_hour.



1253
1254
1255
# File 'lib/stripe/resources/terminal/configuration.rb', line 1253

def end_hour
  @end_hour
end

#start_hourObject

Integer between 0 to 23 that represents the start hour of the reboot time window.



1255
1256
1257
# File 'lib/stripe/resources/terminal/configuration.rb', line 1255

def start_hour
  @start_hour
end