Class: Stripe::Terminal::Configuration::CreateParams::Wifi

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/terminal/configuration.rb

Defined Under Namespace

Classes: EnterpriseEapPeap, EnterpriseEapTls, PersonalPsk

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(enterprise_eap_peap: nil, enterprise_eap_tls: nil, personal_psk: nil, type: nil) ⇒ Wifi

Returns a new instance of Wifi.



1752
1753
1754
1755
1756
1757
1758
1759
1760
1761
1762
# File 'lib/stripe/resources/terminal/configuration.rb', line 1752

def initialize(
  enterprise_eap_peap: nil,
  enterprise_eap_tls: nil,
  personal_psk: nil,
  type: nil
)
  @enterprise_eap_peap = enterprise_eap_peap
  @enterprise_eap_tls = enterprise_eap_tls
  @personal_psk = personal_psk
  @type = type
end

Instance Attribute Details

#enterprise_eap_peapObject

Credentials for a WPA-Enterprise WiFi network using the EAP-PEAP authentication method.



1744
1745
1746
# File 'lib/stripe/resources/terminal/configuration.rb', line 1744

def enterprise_eap_peap
  @enterprise_eap_peap
end

#enterprise_eap_tlsObject

Credentials for a WPA-Enterprise WiFi network using the EAP-TLS authentication method.



1746
1747
1748
# File 'lib/stripe/resources/terminal/configuration.rb', line 1746

def enterprise_eap_tls
  @enterprise_eap_tls
end

#personal_pskObject

Credentials for a WPA-Personal WiFi network.



1748
1749
1750
# File 'lib/stripe/resources/terminal/configuration.rb', line 1748

def personal_psk
  @personal_psk
end

#typeObject

Security type of the WiFi network. Fill out the hash with the corresponding name to provide the set of credentials for this security type.



1750
1751
1752
# File 'lib/stripe/resources/terminal/configuration.rb', line 1750

def type
  @type
end