Class: Stripe::Terminal::Configuration::ListParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/terminal/configuration.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(ending_before: nil, expand: nil, is_account_default: nil, limit: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



1208
1209
1210
1211
1212
1213
1214
1215
1216
1217
1218
1219
1220
# File 'lib/stripe/resources/terminal/configuration.rb', line 1208

def initialize(
  ending_before: nil,
  expand: nil,
  is_account_default: nil,
  limit: nil,
  starting_after: nil
)
  @ending_before = ending_before
  @expand = expand
  @is_account_default = 
  @limit = limit
  @starting_after = starting_after
end

Instance Attribute Details

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



1198
1199
1200
# File 'lib/stripe/resources/terminal/configuration.rb', line 1198

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



1200
1201
1202
# File 'lib/stripe/resources/terminal/configuration.rb', line 1200

def expand
  @expand
end

#is_account_defaultObject

if present, only return the account default or non-default configurations.



1202
1203
1204
# File 'lib/stripe/resources/terminal/configuration.rb', line 1202

def 
  @is_account_default
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



1204
1205
1206
# File 'lib/stripe/resources/terminal/configuration.rb', line 1204

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



1206
1207
1208
# File 'lib/stripe/resources/terminal/configuration.rb', line 1206

def starting_after
  @starting_after
end