Class: Stripe::Terminal::Configuration::RebootWindow
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Terminal::Configuration::RebootWindow
- Defined in:
- lib/stripe/resources/terminal/configuration.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#end_hour ⇒ Object
readonly
Integer between 0 to 23 that represents the end hour of the reboot time window.
-
#start_hour ⇒ Object
readonly
Integer between 0 to 23 that represents the start hour of the reboot time window.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#end_hour ⇒ Object (readonly)
Integer between 0 to 23 that represents the end hour of the reboot time window. The value must be different than the start_hour.
31 32 33 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 31 def end_hour @end_hour end |
#start_hour ⇒ Object (readonly)
Integer between 0 to 23 that represents the start hour of the reboot time window.
33 34 35 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 33 def start_hour @start_hour end |