Class: Stripe::Terminal::Configuration::UpdateParams::BbposWiseposE
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::Configuration::UpdateParams::BbposWiseposE
- Defined in:
- lib/stripe/resources/terminal/configuration.rb
Instance Attribute Summary collapse
-
#splashscreen ⇒ Object
A File ID representing an image to display on the reader.
Instance Method Summary collapse
-
#initialize(splashscreen: nil) ⇒ BbposWiseposE
constructor
A new instance of BbposWiseposE.
Methods inherited from RequestParams
Constructor Details
#initialize(splashscreen: nil) ⇒ BbposWiseposE
Returns a new instance of BbposWiseposE.
614 615 616 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 614 def initialize(splashscreen: nil) @splashscreen = splashscreen end |
Instance Attribute Details
#splashscreen ⇒ Object
A File ID representing an image to display on the reader
612 613 614 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 612 def splashscreen @splashscreen end |