Class: Stripe::Terminal::Configuration::UpdateParams::RebootWindow

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/terminal/configuration.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(end_hour: nil, start_hour: nil) ⇒ RebootWindow

Returns a new instance of RebootWindow.



643
644
645
646
# File 'lib/stripe/resources/terminal/configuration.rb', line 643

def initialize(end_hour: nil, start_hour: nil)
  @end_hour = end_hour
  @start_hour = start_hour
end

Instance Attribute Details

#end_hourObject

Integer between 0 to 23 that represents the end hour of the reboot time window. The value must be different than the start_hour.



639
640
641
# File 'lib/stripe/resources/terminal/configuration.rb', line 639

def end_hour
  @end_hour
end

#start_hourObject

Integer between 0 to 23 that represents the start hour of the reboot time window.



641
642
643
# File 'lib/stripe/resources/terminal/configuration.rb', line 641

def start_hour
  @start_hour
end