Class: Stripe::Terminal::Configuration::UpdateParams::Wifi

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/terminal/configuration.rb

Defined Under Namespace

Classes: EnterpriseEapPeap, EnterpriseEapTls, PersonalPsk

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(enterprise_eap_peap: nil, enterprise_eap_tls: nil, personal_psk: nil, type: nil) ⇒ Wifi

Returns a new instance of Wifi.



1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
# File 'lib/stripe/resources/terminal/configuration.rb', line 1138

def initialize(
  enterprise_eap_peap: nil,
  enterprise_eap_tls: nil,
  personal_psk: nil,
  type: nil
)
  @enterprise_eap_peap = enterprise_eap_peap
  @enterprise_eap_tls = enterprise_eap_tls
  @personal_psk = personal_psk
  @type = type
end

Instance Attribute Details

#enterprise_eap_peapObject

Credentials for a WPA-Enterprise WiFi network using the EAP-PEAP authentication method.



1130
1131
1132
# File 'lib/stripe/resources/terminal/configuration.rb', line 1130

def enterprise_eap_peap
  @enterprise_eap_peap
end

#enterprise_eap_tlsObject

Credentials for a WPA-Enterprise WiFi network using the EAP-TLS authentication method.



1132
1133
1134
# File 'lib/stripe/resources/terminal/configuration.rb', line 1132

def enterprise_eap_tls
  @enterprise_eap_tls
end

#personal_pskObject

Credentials for a WPA-Personal WiFi network.



1134
1135
1136
# File 'lib/stripe/resources/terminal/configuration.rb', line 1134

def personal_psk
  @personal_psk
end

#typeObject

Security type of the WiFi network. Fill out the hash with the corresponding name to provide the set of credentials for this security type.



1136
1137
1138
# File 'lib/stripe/resources/terminal/configuration.rb', line 1136

def type
  @type
end