Class: Stripe::Terminal::ConfigurationCreateParams::Cellular
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::ConfigurationCreateParams::Cellular
- Defined in:
- lib/stripe/params/terminal/configuration_create_params.rb
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Determines whether to allow the reader to connect to a cellular network.
Instance Method Summary collapse
-
#initialize(enabled: nil) ⇒ Cellular
constructor
A new instance of Cellular.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil) ⇒ Cellular
Returns a new instance of Cellular.
29 30 31 |
# File 'lib/stripe/params/terminal/configuration_create_params.rb', line 29 def initialize(enabled: nil) @enabled = enabled end |
Instance Attribute Details
#enabled ⇒ Object
Determines whether to allow the reader to connect to a cellular network. Defaults to false.
27 28 29 |
# File 'lib/stripe/params/terminal/configuration_create_params.rb', line 27 def enabled @enabled end |