Class: Stripe::Terminal::ConfigurationService::CreateParams::BbposWiseposE
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::ConfigurationService::CreateParams::BbposWiseposE
- Defined in:
- lib/stripe/services/terminal/configuration_service.rb
Instance Attribute Summary collapse
-
#splashscreen ⇒ Object
A File ID representing an image to display on the reader.
Instance Method Summary collapse
-
#initialize(splashscreen: nil) ⇒ BbposWiseposE
constructor
A new instance of BbposWiseposE.
Methods inherited from RequestParams
Constructor Details
#initialize(splashscreen: nil) ⇒ BbposWiseposE
Returns a new instance of BbposWiseposE.
529 530 531 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 529 def initialize(splashscreen: nil) @splashscreen = splashscreen end |
Instance Attribute Details
#splashscreen ⇒ Object
A File ID representing an image to display on the reader
527 528 529 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 527 def splashscreen @splashscreen end |