Class: Stripe::Terminal::ConfigurationService::CreateParams::Offline
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::ConfigurationService::CreateParams::Offline
- Defined in:
- lib/stripe/services/terminal/configuration_service.rb
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Determines whether to allow transactions to be collected while reader is offline.
Instance Method Summary collapse
-
#initialize(enabled: nil) ⇒ Offline
constructor
A new instance of Offline.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil) ⇒ Offline
Returns a new instance of Offline.
539 540 541 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 539 def initialize(enabled: nil) @enabled = enabled end |
Instance Attribute Details
#enabled ⇒ Object
Determines whether to allow transactions to be collected while reader is offline. Defaults to false.
537 538 539 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 537 def enabled @enabled end |