Class: Stripe::Terminal::ConfigurationService::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::ConfigurationService::ListParams
- Defined in:
- lib/stripe/services/terminal/configuration_service.rb
Instance Attribute Summary collapse
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#is_account_default ⇒ Object
if present, only return the account default or non-default configurations.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#starting_after ⇒ Object
A cursor for use in pagination.
Instance Method Summary collapse
-
#initialize(ending_before: nil, expand: nil, is_account_default: nil, limit: nil, starting_after: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(ending_before: nil, expand: nil, is_account_default: nil, limit: nil, starting_after: nil) ⇒ ListParams
Returns a new instance of ListParams.
617 618 619 620 621 622 623 624 625 626 627 628 629 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 617 def initialize( ending_before: nil, expand: nil, is_account_default: nil, limit: nil, starting_after: nil ) @ending_before = ending_before @expand = @is_account_default = is_account_default @limit = limit @starting_after = starting_after end |
Instance Attribute Details
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
607 608 609 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 607 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
609 610 611 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 609 def @expand end |
#is_account_default ⇒ Object
if present, only return the account default or non-default configurations.
611 612 613 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 611 def is_account_default @is_account_default end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
613 614 615 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 613 def limit @limit end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
615 616 617 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 615 def starting_after @starting_after end |