Class: Stripe::Terminal::ConfigurationService::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/terminal/configuration_service.rb

Defined Under Namespace

Classes: BbposWiseposE, Offline, ReaderSecurity, RebootWindow, StripeS700, Tipping, VerifoneP400, Wifi

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bbpos_wisepos_e: nil, expand: nil, name: nil, offline: nil, reader_security: nil, reboot_window: nil, stripe_s700: nil, tipping: nil, verifone_p400: nil, wifi: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
# File 'lib/stripe/services/terminal/configuration_service.rb', line 580

def initialize(
  bbpos_wisepos_e: nil,
  expand: nil,
  name: nil,
  offline: nil,
  reader_security: nil,
  reboot_window: nil,
  stripe_s700: nil,
  tipping: nil,
  verifone_p400: nil,
  wifi: nil
)
  @bbpos_wisepos_e = bbpos_wisepos_e
  @expand = expand
  @name = name
  @offline = offline
  @reader_security = reader_security
  @reboot_window = reboot_window
  @stripe_s700 = stripe_s700
  @tipping = tipping
  @verifone_p400 = verifone_p400
  @wifi = wifi
end

Instance Attribute Details

#bbpos_wisepos_eObject

An object containing device type specific settings for BBPOS WisePOS E readers



560
561
562
# File 'lib/stripe/services/terminal/configuration_service.rb', line 560

def bbpos_wisepos_e
  @bbpos_wisepos_e
end

#expandObject

Specifies which fields in the response should be expanded.



562
563
564
# File 'lib/stripe/services/terminal/configuration_service.rb', line 562

def expand
  @expand
end

#nameObject

Name of the configuration



564
565
566
# File 'lib/stripe/services/terminal/configuration_service.rb', line 564

def name
  @name
end

#offlineObject

Configurations for collecting transactions offline.



566
567
568
# File 'lib/stripe/services/terminal/configuration_service.rb', line 566

def offline
  @offline
end

#reader_securityObject

Configurations for reader security settings.



568
569
570
# File 'lib/stripe/services/terminal/configuration_service.rb', line 568

def reader_security
  @reader_security
end

#reboot_windowObject

Reboot time settings for readers that support customized reboot time configuration.



570
571
572
# File 'lib/stripe/services/terminal/configuration_service.rb', line 570

def reboot_window
  @reboot_window
end

#stripe_s700Object

An object containing device type specific settings for Stripe S700 readers



572
573
574
# File 'lib/stripe/services/terminal/configuration_service.rb', line 572

def stripe_s700
  @stripe_s700
end

#tippingObject

Tipping configurations for readers supporting on-reader tips



574
575
576
# File 'lib/stripe/services/terminal/configuration_service.rb', line 574

def tipping
  @tipping
end

#verifone_p400Object

An object containing device type specific settings for Verifone P400 readers



576
577
578
# File 'lib/stripe/services/terminal/configuration_service.rb', line 576

def verifone_p400
  @verifone_p400
end

#wifiObject

Configurations for connecting to a WiFi network.



578
579
580
# File 'lib/stripe/services/terminal/configuration_service.rb', line 578

def wifi
  @wifi
end