Class: Stripe::Terminal::ConfigurationUpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/terminal/configuration_update_params.rb

Defined Under Namespace

Classes: BbposWisepad3, BbposWiseposE, Cellular, Offline, RebootWindow, StripeS700, StripeS710, Tipping, VerifoneP400, Wifi

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(bbpos_wisepad3: nil, bbpos_wisepos_e: nil, cellular: nil, expand: nil, name: nil, offline: nil, reboot_window: nil, stripe_s700: nil, stripe_s710: nil, tipping: nil, verifone_p400: nil, wifi: nil) ⇒ ConfigurationUpdateParams

Returns a new instance of ConfigurationUpdateParams.



590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
# File 'lib/stripe/params/terminal/configuration_update_params.rb', line 590

def initialize(
  bbpos_wisepad3: nil,
  bbpos_wisepos_e: nil,
  cellular: nil,
  expand: nil,
  name: nil,
  offline: nil,
  reboot_window: nil,
  stripe_s700: nil,
  stripe_s710: nil,
  tipping: nil,
  verifone_p400: nil,
  wifi: nil
)
  @bbpos_wisepad3 = bbpos_wisepad3
  @bbpos_wisepos_e = bbpos_wisepos_e
  @cellular = cellular
  @expand = expand
  @name = name
  @offline = offline
  @reboot_window = reboot_window
  @stripe_s700 = stripe_s700
  @stripe_s710 = stripe_s710
  @tipping = tipping
  @verifone_p400 = verifone_p400
  @wifi = wifi
end

Instance Attribute Details

#bbpos_wisepad3Object

An object containing device type specific settings for BBPOS WisePad 3 readers.



566
567
568
# File 'lib/stripe/params/terminal/configuration_update_params.rb', line 566

def bbpos_wisepad3
  @bbpos_wisepad3
end

#bbpos_wisepos_eObject

An object containing device type specific settings for BBPOS WisePOS E readers.



568
569
570
# File 'lib/stripe/params/terminal/configuration_update_params.rb', line 568

def bbpos_wisepos_e
  @bbpos_wisepos_e
end

#cellularObject

Configuration for cellular connectivity.



570
571
572
# File 'lib/stripe/params/terminal/configuration_update_params.rb', line 570

def cellular
  @cellular
end

#expandObject

Specifies which fields in the response should be expanded.



572
573
574
# File 'lib/stripe/params/terminal/configuration_update_params.rb', line 572

def expand
  @expand
end

#nameObject

Name of the configuration



574
575
576
# File 'lib/stripe/params/terminal/configuration_update_params.rb', line 574

def name
  @name
end

#offlineObject

Configurations for collecting transactions offline.



576
577
578
# File 'lib/stripe/params/terminal/configuration_update_params.rb', line 576

def offline
  @offline
end

#reboot_windowObject

Reboot time settings for readers. that support customized reboot time configuration.



578
579
580
# File 'lib/stripe/params/terminal/configuration_update_params.rb', line 578

def reboot_window
  @reboot_window
end

#stripe_s700Object

An object containing device type specific settings for Stripe S700 readers.



580
581
582
# File 'lib/stripe/params/terminal/configuration_update_params.rb', line 580

def stripe_s700
  @stripe_s700
end

#stripe_s710Object

An object containing device type specific settings for Stripe S710 readers.



582
583
584
# File 'lib/stripe/params/terminal/configuration_update_params.rb', line 582

def stripe_s710
  @stripe_s710
end

#tippingObject

Tipping configurations for readers that support on-reader tips.



584
585
586
# File 'lib/stripe/params/terminal/configuration_update_params.rb', line 584

def tipping
  @tipping
end

#verifone_p400Object

An object containing device type specific settings for Verifone P400 readers.



586
587
588
# File 'lib/stripe/params/terminal/configuration_update_params.rb', line 586

def verifone_p400
  @verifone_p400
end

#wifiObject

Configurations for connecting to a WiFi network.



588
589
590
# File 'lib/stripe/params/terminal/configuration_update_params.rb', line 588

def wifi
  @wifi
end