Class: Stripe::Terminal::ConfigurationUpdateParams::RebootWindow

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/terminal/configuration_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(end_hour: nil, start_hour: nil) ⇒ RebootWindow

Returns a new instance of RebootWindow.



49
50
51
52
# File 'lib/stripe/params/terminal/configuration_update_params.rb', line 49

def initialize(end_hour: nil, start_hour: nil)
  @end_hour = end_hour
  @start_hour = start_hour
end

Instance Attribute Details

#end_hourObject

Integer between 0 to 23 that represents the end hour of the reboot time window. The value must be different than the start_hour.



45
46
47
# File 'lib/stripe/params/terminal/configuration_update_params.rb', line 45

def end_hour
  @end_hour
end

#start_hourObject

Integer between 0 to 23 that represents the start hour of the reboot time window.



47
48
49
# File 'lib/stripe/params/terminal/configuration_update_params.rb', line 47

def start_hour
  @start_hour
end