Class: Stripe::Terminal::ConfigurationUpdateParams::VerifoneV660p
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::ConfigurationUpdateParams::VerifoneV660p
- Defined in:
- lib/stripe/params/terminal/configuration_update_params.rb
Instance Attribute Summary collapse
-
#splashscreen ⇒ Object
A File ID representing an image you want to display on the reader.
Instance Method Summary collapse
-
#initialize(splashscreen: nil) ⇒ VerifoneV660p
constructor
A new instance of VerifoneV660p.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(splashscreen: nil) ⇒ VerifoneV660p
Returns a new instance of VerifoneV660p.
527 528 529 |
# File 'lib/stripe/params/terminal/configuration_update_params.rb', line 527 def initialize(splashscreen: nil) @splashscreen = splashscreen end |
Instance Attribute Details
#splashscreen ⇒ Object
A File ID representing an image you want to display on the reader.
525 526 527 |
# File 'lib/stripe/params/terminal/configuration_update_params.rb', line 525 def splashscreen @splashscreen end |