Class: Stripe::Terminal::Location
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Terminal::Location
- Extended by:
- APIOperations::Create, APIOperations::List
- Includes:
- APIOperations::Delete, APIOperations::Save
- Defined in:
- lib/stripe/resources/terminal/location.rb
Overview
A Location represents a grouping of readers.
Related guide: [Fleet management](stripe.com/docs/terminal/fleet/locations)
Defined Under Namespace
Classes: Address, CreateParams, DeleteParams, ListParams, UpdateParams
Constant Summary collapse
- OBJECT_NAME =
"terminal.location"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#address ⇒ Object
readonly
Attribute for field address.
-
#configuration_overrides ⇒ Object
readonly
The ID of a configuration that will be used to customize all readers in this location.
-
#deleted ⇒ Object
readonly
Always true for a deleted object.
-
#display_name ⇒ Object
readonly
The display name of the location.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#object ⇒ Object
readonly
String representing the object’s type.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.create(params = {}, opts = {}) ⇒ Object
Creates a new Location object.
-
.delete(location, params = {}, opts = {}) ⇒ Object
Deletes a Location object.
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
-
.list(params = {}, opts = {}) ⇒ Object
Returns a list of Location objects.
- .object_name ⇒ Object
-
.update(location, params = {}, opts = {}) ⇒ Object
Updates a Location object by setting the values of the parameters passed.
Instance Method Summary collapse
-
#delete(params = {}, opts = {}) ⇒ Object
Deletes a Location object.
Methods included from APIOperations::Create
Methods included from APIOperations::List
Methods included from APIOperations::Save
Methods included from APIOperations::Delete
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#address ⇒ Object (readonly)
Attribute for field address
177 178 179 |
# File 'lib/stripe/resources/terminal/location.rb', line 177 def address @address end |
#configuration_overrides ⇒ Object (readonly)
The ID of a configuration that will be used to customize all readers in this location.
179 180 181 |
# File 'lib/stripe/resources/terminal/location.rb', line 179 def configuration_overrides @configuration_overrides end |
#deleted ⇒ Object (readonly)
Always true for a deleted object
191 192 193 |
# File 'lib/stripe/resources/terminal/location.rb', line 191 def deleted @deleted end |
#display_name ⇒ Object (readonly)
The display name of the location.
181 182 183 |
# File 'lib/stripe/resources/terminal/location.rb', line 181 def display_name @display_name end |
#id ⇒ Object (readonly)
Unique identifier for the object.
183 184 185 |
# File 'lib/stripe/resources/terminal/location.rb', line 183 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
185 186 187 |
# File 'lib/stripe/resources/terminal/location.rb', line 185 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
187 188 189 |
# File 'lib/stripe/resources/terminal/location.rb', line 187 def @metadata end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
189 190 191 |
# File 'lib/stripe/resources/terminal/location.rb', line 189 def object @object end |
Class Method Details
.create(params = {}, opts = {}) ⇒ Object
Creates a new Location object. For further details, including which address fields are required in each country, see the [Manage locations](docs.stripe.com/docs/terminal/fleet/locations) guide.
195 196 197 198 199 200 201 202 |
# File 'lib/stripe/resources/terminal/location.rb', line 195 def self.create(params = {}, opts = {}) request_stripe_object( method: :post, path: "/v1/terminal/locations", params: params, opts: opts ) end |
.delete(location, params = {}, opts = {}) ⇒ Object
Deletes a Location object.
205 206 207 208 209 210 211 212 |
# File 'lib/stripe/resources/terminal/location.rb', line 205 def self.delete(location, params = {}, opts = {}) request_stripe_object( method: :delete, path: format("/v1/terminal/locations/%<location>s", { location: CGI.escape(location) }), params: params, opts: opts ) end |
.field_remappings ⇒ Object
248 249 250 |
# File 'lib/stripe/resources/terminal/location.rb', line 248 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
244 245 246 |
# File 'lib/stripe/resources/terminal/location.rb', line 244 def self.inner_class_types @inner_class_types = { address: Address } end |
.list(params = {}, opts = {}) ⇒ Object
Returns a list of Location objects.
225 226 227 228 229 230 231 232 |
# File 'lib/stripe/resources/terminal/location.rb', line 225 def self.list(params = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/terminal/locations", params: params, opts: opts ) end |
.object_name ⇒ Object
16 17 18 |
# File 'lib/stripe/resources/terminal/location.rb', line 16 def self.object_name "terminal.location" end |
.update(location, params = {}, opts = {}) ⇒ Object
Updates a Location object by setting the values of the parameters passed. Any parameters not provided will be left unchanged.
235 236 237 238 239 240 241 242 |
# File 'lib/stripe/resources/terminal/location.rb', line 235 def self.update(location, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/terminal/locations/%<location>s", { location: CGI.escape(location) }), params: params, opts: opts ) end |
Instance Method Details
#delete(params = {}, opts = {}) ⇒ Object
Deletes a Location object.
215 216 217 218 219 220 221 222 |
# File 'lib/stripe/resources/terminal/location.rb', line 215 def delete(params = {}, opts = {}) request_stripe_object( method: :delete, path: format("/v1/terminal/locations/%<location>s", { location: CGI.escape(self["id"]) }), params: params, opts: opts ) end |