Class: Stripe::Terminal::Location::RetrieveParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::Location::RetrieveParams
- Defined in:
- lib/stripe/resources/terminal/location.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ RetrieveParams
constructor
A new instance of RetrieveParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ RetrieveParams
Returns a new instance of RetrieveParams.
47 48 49 |
# File 'lib/stripe/resources/terminal/location.rb', line 47 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
45 46 47 |
# File 'lib/stripe/resources/terminal/location.rb', line 45 def @expand end |