Class: Stripe::Terminal::Location::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/terminal/location.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, configuration_overrides: nil, display_name: nil, expand: nil, metadata: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/stripe/resources/terminal/location.rb', line 79

def initialize(
  address: nil,
  configuration_overrides: nil,
  display_name: nil,
  expand: nil,
  metadata: nil
)
  @address = address
  @configuration_overrides = configuration_overrides
  @display_name = display_name
  @expand = expand
  @metadata = 
end

Instance Attribute Details

#addressObject

The full address of the location. You can’t change the location’s ‘country`. If you need to modify the `country` field, create a new `Location` object and re-register any existing readers to that location.



69
70
71
# File 'lib/stripe/resources/terminal/location.rb', line 69

def address
  @address
end

#configuration_overridesObject

The ID of a configuration that will be used to customize all readers in this location.



71
72
73
# File 'lib/stripe/resources/terminal/location.rb', line 71

def configuration_overrides
  @configuration_overrides
end

#display_nameObject

A name for the location.



73
74
75
# File 'lib/stripe/resources/terminal/location.rb', line 73

def display_name
  @display_name
end

#expandObject

Specifies which fields in the response should be expanded.



75
76
77
# File 'lib/stripe/resources/terminal/location.rb', line 75

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



77
78
79
# File 'lib/stripe/resources/terminal/location.rb', line 77

def 
  @metadata
end