Class: Stripe::Terminal::LocationService::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/terminal/location_service.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, configuration_overrides: nil, display_name: nil, expand: nil, metadata: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/stripe/services/terminal/location_service.rb', line 60

def initialize(
  address: nil,
  configuration_overrides: nil,
  display_name: nil,
  expand: nil,
  metadata: nil
)
  @address = address
  @configuration_overrides = configuration_overrides
  @display_name = display_name
  @expand = expand
  @metadata = 
end

Instance Attribute Details

#addressObject

The full address of the location. You can’t change the location’s ‘country`. If you need to modify the `country` field, create a new `Location` object and re-register any existing readers to that location.



50
51
52
# File 'lib/stripe/services/terminal/location_service.rb', line 50

def address
  @address
end

#configuration_overridesObject

The ID of a configuration that will be used to customize all readers in this location.



52
53
54
# File 'lib/stripe/services/terminal/location_service.rb', line 52

def configuration_overrides
  @configuration_overrides
end

#display_nameObject

A name for the location.



54
55
56
# File 'lib/stripe/services/terminal/location_service.rb', line 54

def display_name
  @display_name
end

#expandObject

Specifies which fields in the response should be expanded.



56
57
58
# File 'lib/stripe/services/terminal/location_service.rb', line 56

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



58
59
60
# File 'lib/stripe/services/terminal/location_service.rb', line 58

def 
  @metadata
end