Class: Stripe::Terminal::OnboardingLink::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/terminal/onboarding_link.rb

Defined Under Namespace

Classes: LinkOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, link_options: nil, link_type: nil, on_behalf_of: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



55
56
57
58
59
60
# File 'lib/stripe/resources/terminal/onboarding_link.rb', line 55

def initialize(expand: nil, link_options: nil, link_type: nil, on_behalf_of: nil)
  @expand = expand
  @link_options = link_options
  @link_type = link_type
  @on_behalf_of = on_behalf_of
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



47
48
49
# File 'lib/stripe/resources/terminal/onboarding_link.rb', line 47

def expand
  @expand
end

Specific fields needed to generate the desired link type.



49
50
51
# File 'lib/stripe/resources/terminal/onboarding_link.rb', line 49

def link_options
  @link_options
end

The type of link being generated.



51
52
53
# File 'lib/stripe/resources/terminal/onboarding_link.rb', line 51

def link_type
  @link_type
end

#on_behalf_ofObject

Stripe account ID to generate the link for.



53
54
55
# File 'lib/stripe/resources/terminal/onboarding_link.rb', line 53

def on_behalf_of
  @on_behalf_of
end