Class: Stripe::Terminal::OnboardingLink::CreateParams::LinkOptions::AppleTermsAndConditions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::OnboardingLink::CreateParams::LinkOptions::AppleTermsAndConditions
- Defined in:
- lib/stripe/resources/terminal/onboarding_link.rb
Instance Attribute Summary collapse
-
#allow_relinking ⇒ Object
Whether the link should also support users relinking their Apple account.
-
#merchant_display_name ⇒ Object
The business name of the merchant accepting Apple’s Terms and Conditions.
Instance Method Summary collapse
-
#initialize(allow_relinking: nil, merchant_display_name: nil) ⇒ AppleTermsAndConditions
constructor
A new instance of AppleTermsAndConditions.
Methods inherited from RequestParams
Constructor Details
#initialize(allow_relinking: nil, merchant_display_name: nil) ⇒ AppleTermsAndConditions
Returns a new instance of AppleTermsAndConditions.
50 51 52 53 |
# File 'lib/stripe/resources/terminal/onboarding_link.rb', line 50 def initialize(allow_relinking: nil, merchant_display_name: nil) @allow_relinking = allow_relinking @merchant_display_name = merchant_display_name end |
Instance Attribute Details
#allow_relinking ⇒ Object
Whether the link should also support users relinking their Apple account.
46 47 48 |
# File 'lib/stripe/resources/terminal/onboarding_link.rb', line 46 def allow_relinking @allow_relinking end |
#merchant_display_name ⇒ Object
The business name of the merchant accepting Apple’s Terms and Conditions.
48 49 50 |
# File 'lib/stripe/resources/terminal/onboarding_link.rb', line 48 def merchant_display_name @merchant_display_name end |