Class: Stripe::Terminal::OnboardingLinkService::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/terminal/onboarding_link_service.rb

Defined Under Namespace

Classes: LinkOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, link_options: nil, link_type: nil, on_behalf_of: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



36
37
38
39
40
41
# File 'lib/stripe/services/terminal/onboarding_link_service.rb', line 36

def initialize(expand: nil, link_options: nil, link_type: nil, on_behalf_of: nil)
  @expand = expand
  @link_options = link_options
  @link_type = link_type
  @on_behalf_of = on_behalf_of
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



28
29
30
# File 'lib/stripe/services/terminal/onboarding_link_service.rb', line 28

def expand
  @expand
end

Specific fields needed to generate the desired link type.



30
31
32
# File 'lib/stripe/services/terminal/onboarding_link_service.rb', line 30

def link_options
  @link_options
end

The type of link being generated.



32
33
34
# File 'lib/stripe/services/terminal/onboarding_link_service.rb', line 32

def link_type
  @link_type
end

#on_behalf_ofObject

Stripe account ID to generate the link for.



34
35
36
# File 'lib/stripe/services/terminal/onboarding_link_service.rb', line 34

def on_behalf_of
  @on_behalf_of
end