Class: Stripe::Terminal::OnboardingLinkService::CreateParams::LinkOptions::AppleTermsAndConditions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::OnboardingLinkService::CreateParams::LinkOptions::AppleTermsAndConditions
- Defined in:
- lib/stripe/services/terminal/onboarding_link_service.rb
Instance Attribute Summary collapse
-
#allow_relinking ⇒ Object
Whether the link should also support users relinking their Apple account.
-
#merchant_display_name ⇒ Object
The business name of the merchant accepting Apple’s Terms and Conditions.
Instance Method Summary collapse
-
#initialize(allow_relinking: nil, merchant_display_name: nil) ⇒ AppleTermsAndConditions
constructor
A new instance of AppleTermsAndConditions.
Methods inherited from RequestParams
Constructor Details
#initialize(allow_relinking: nil, merchant_display_name: nil) ⇒ AppleTermsAndConditions
Returns a new instance of AppleTermsAndConditions.
15 16 17 18 |
# File 'lib/stripe/services/terminal/onboarding_link_service.rb', line 15 def initialize(allow_relinking: nil, merchant_display_name: nil) @allow_relinking = allow_relinking @merchant_display_name = merchant_display_name end |
Instance Attribute Details
#allow_relinking ⇒ Object
Whether the link should also support users relinking their Apple account.
11 12 13 |
# File 'lib/stripe/services/terminal/onboarding_link_service.rb', line 11 def allow_relinking @allow_relinking end |
#merchant_display_name ⇒ Object
The business name of the merchant accepting Apple’s Terms and Conditions.
13 14 15 |
# File 'lib/stripe/services/terminal/onboarding_link_service.rb', line 13 def merchant_display_name @merchant_display_name end |