Class: Stripe::Terminal::Reader::Action

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/terminal/reader.rb

Defined Under Namespace

Classes: ActivateGiftCard, ApiError, CashoutGiftCard, CheckGiftCardBalance, CollectInputs, CollectPaymentMethod, ConfirmPaymentIntent, DeactivateGiftCard, PrintContent, ProcessPaymentIntent, ProcessSetupIntent, RefundPayment, ReloadGiftCard, SetReaderDisplay

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#activate_gift_cardObject (readonly)

Represents a reader action to activate a gift card



648
649
650
# File 'lib/stripe/resources/terminal/reader.rb', line 648

def activate_gift_card
  @activate_gift_card
end

#api_errorObject (readonly)

The reader action failed due to an API error. Only present when status is failed and the underlying failure was an API error. Avoid parsing the message field for programmatic logic; use type or code instead. The message field is for display to humans only and may be updated at anytime. Requires reader version 2.42 or later. Readers on older versions always return null.



650
651
652
# File 'lib/stripe/resources/terminal/reader.rb', line 650

def api_error
  @api_error
end

#cashout_gift_cardObject (readonly)

Represents a reader action to cash out a gift card



652
653
654
# File 'lib/stripe/resources/terminal/reader.rb', line 652

def cashout_gift_card
  @cashout_gift_card
end

#check_gift_card_balanceObject (readonly)

Represents a reader action to check a gift card balance



654
655
656
# File 'lib/stripe/resources/terminal/reader.rb', line 654

def check_gift_card_balance
  @check_gift_card_balance
end

#collect_inputsObject (readonly)

Represents a reader action to collect customer inputs



656
657
658
# File 'lib/stripe/resources/terminal/reader.rb', line 656

def collect_inputs
  @collect_inputs
end

#collect_payment_methodObject (readonly)

Represents a reader action to collect a payment method



658
659
660
# File 'lib/stripe/resources/terminal/reader.rb', line 658

def collect_payment_method
  @collect_payment_method
end

#confirm_payment_intentObject (readonly)

Represents a reader action to confirm a payment



660
661
662
# File 'lib/stripe/resources/terminal/reader.rb', line 660

def confirm_payment_intent
  @confirm_payment_intent
end

#deactivate_gift_cardObject (readonly)

Represents a reader action to deactivate a gift card



662
663
664
# File 'lib/stripe/resources/terminal/reader.rb', line 662

def deactivate_gift_card
  @deactivate_gift_card
end

#failure_codeObject (readonly)

Failure code, only set if status is failed.



664
665
666
# File 'lib/stripe/resources/terminal/reader.rb', line 664

def failure_code
  @failure_code
end

#failure_messageObject (readonly)

Detailed failure message, only set if status is failed.



666
667
668
# File 'lib/stripe/resources/terminal/reader.rb', line 666

def failure_message
  @failure_message
end

Represents a reader action to print content



668
669
670
# File 'lib/stripe/resources/terminal/reader.rb', line 668

def print_content
  @print_content
end

#process_payment_intentObject (readonly)

Represents a reader action to process a payment intent



670
671
672
# File 'lib/stripe/resources/terminal/reader.rb', line 670

def process_payment_intent
  @process_payment_intent
end

#process_setup_intentObject (readonly)

Represents a reader action to process a setup intent



672
673
674
# File 'lib/stripe/resources/terminal/reader.rb', line 672

def process_setup_intent
  @process_setup_intent
end

#refund_paymentObject (readonly)

Represents a reader action to refund a payment



674
675
676
# File 'lib/stripe/resources/terminal/reader.rb', line 674

def refund_payment
  @refund_payment
end

#reload_gift_cardObject (readonly)

Represents a reader action to reload a gift card



676
677
678
# File 'lib/stripe/resources/terminal/reader.rb', line 676

def reload_gift_card
  @reload_gift_card
end

#set_reader_displayObject (readonly)

Represents a reader action to set the reader display



678
679
680
# File 'lib/stripe/resources/terminal/reader.rb', line 678

def set_reader_display
  @set_reader_display
end

#statusObject (readonly)

Status of the action performed by the reader.



680
681
682
# File 'lib/stripe/resources/terminal/reader.rb', line 680

def status
  @status
end

#typeObject (readonly)

Type of action performed by the reader.



682
683
684
# File 'lib/stripe/resources/terminal/reader.rb', line 682

def type
  @type
end

Class Method Details

.field_remappingsObject



703
704
705
# File 'lib/stripe/resources/terminal/reader.rb', line 703

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
# File 'lib/stripe/resources/terminal/reader.rb', line 684

def self.inner_class_types
  @inner_class_types = {
    activate_gift_card: ActivateGiftCard,
    api_error: ApiError,
    cashout_gift_card: CashoutGiftCard,
    check_gift_card_balance: CheckGiftCardBalance,
    collect_inputs: CollectInputs,
    collect_payment_method: CollectPaymentMethod,
    confirm_payment_intent: ConfirmPaymentIntent,
    deactivate_gift_card: DeactivateGiftCard,
    print_content: PrintContent,
    process_payment_intent: ProcessPaymentIntent,
    process_setup_intent: ProcessSetupIntent,
    refund_payment: RefundPayment,
    reload_gift_card: ReloadGiftCard,
    set_reader_display: SetReaderDisplay,
  }
end