Class: Stripe::Terminal::Reader::Action::CollectPaymentMethod

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/terminal/reader.rb

Defined Under Namespace

Classes: CollectConfig

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#accountObject (readonly)

Account the payment intent belongs to.



367
368
369
# File 'lib/stripe/resources/terminal/reader.rb', line 367

def 
  @account
end

#collect_configObject (readonly)

Represents a per-transaction override of a reader configuration



369
370
371
# File 'lib/stripe/resources/terminal/reader.rb', line 369

def collect_config
  @collect_config
end

#payment_intentObject (readonly)

Most recent PaymentIntent processed by the reader.



371
372
373
# File 'lib/stripe/resources/terminal/reader.rb', line 371

def payment_intent
  @payment_intent
end

#payment_methodObject (readonly)

PaymentMethod objects represent your customer's payment instruments. You can use them with PaymentIntents to collect payments or save them to Customer objects to store instrument details for future payments.

Related guides: Payment Methods and More Payment Scenarios.



377
378
379
# File 'lib/stripe/resources/terminal/reader.rb', line 377

def payment_method
  @payment_method
end

Class Method Details

.field_remappingsObject



383
384
385
# File 'lib/stripe/resources/terminal/reader.rb', line 383

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



379
380
381
# File 'lib/stripe/resources/terminal/reader.rb', line 379

def self.inner_class_types
  @inner_class_types = { collect_config: CollectConfig }
end