Class: Stripe::Terminal::Reader::Action::ProcessPaymentIntent::ProcessConfig
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Terminal::Reader::Action::ProcessPaymentIntent::ProcessConfig
- Defined in:
- lib/stripe/resources/terminal/reader.rb
Defined Under Namespace
Classes: Tipping
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#enable_customer_cancellation ⇒ Object
readonly
Enable customer initiated cancellation when processing this payment.
-
#skip_tipping ⇒ Object
readonly
Override showing a tipping selection screen on this transaction.
-
#tipping ⇒ Object
readonly
Represents a per-transaction tipping configuration.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#enable_customer_cancellation ⇒ Object (readonly)
Enable customer initiated cancellation when processing this payment.
152 153 154 |
# File 'lib/stripe/resources/terminal/reader.rb', line 152 def enable_customer_cancellation @enable_customer_cancellation end |
#skip_tipping ⇒ Object (readonly)
Override showing a tipping selection screen on this transaction.
154 155 156 |
# File 'lib/stripe/resources/terminal/reader.rb', line 154 def skip_tipping @skip_tipping end |
#tipping ⇒ Object (readonly)
Represents a per-transaction tipping configuration
156 157 158 |
# File 'lib/stripe/resources/terminal/reader.rb', line 156 def tipping @tipping end |