Class: Stripe::Terminal::Reader::Action::ProcessPaymentIntent::ProcessConfig::Tipping
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Terminal::Reader::Action::ProcessPaymentIntent::ProcessConfig::Tipping
- Defined in:
- lib/stripe/resources/terminal/reader.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount_eligible ⇒ Object
readonly
Amount used to calculate tip suggestions on tipping selection screen for this transaction.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount_eligible ⇒ Object (readonly)
Amount used to calculate tip suggestions on tipping selection screen for this transaction. Must be a positive integer in the smallest currency unit (e.g., 100 cents to represent $1.00 or 100 to represent ¥100, a zero-decimal currency).
155 156 157 |
# File 'lib/stripe/resources/terminal/reader.rb', line 155 def amount_eligible @amount_eligible end |