Class: Stripe::Terminal::Reader::CollectInputsParams::Input

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/terminal/reader.rb

Defined Under Namespace

Classes: CustomText, Selection, Toggle

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(custom_text: nil, required: nil, selection: nil, toggles: nil, type: nil) ⇒ Input

Returns a new instance of Input.



659
660
661
662
663
664
665
# File 'lib/stripe/resources/terminal/reader.rb', line 659

def initialize(custom_text: nil, required: nil, selection: nil, toggles: nil, type: nil)
  @custom_text = custom_text
  @required = required
  @selection = selection
  @toggles = toggles
  @type = type
end

Instance Attribute Details

#custom_textObject

Customize the text which will be displayed while collecting this input



649
650
651
# File 'lib/stripe/resources/terminal/reader.rb', line 649

def custom_text
  @custom_text
end

#requiredObject

Indicate that this input is required, disabling the skip button



651
652
653
# File 'lib/stripe/resources/terminal/reader.rb', line 651

def required
  @required
end

#selectionObject

Options for the ‘selection` input



653
654
655
# File 'lib/stripe/resources/terminal/reader.rb', line 653

def selection
  @selection
end

#togglesObject

List of toggles to be displayed and customization for the toggles



655
656
657
# File 'lib/stripe/resources/terminal/reader.rb', line 655

def toggles
  @toggles
end

#typeObject

The type of input to collect



657
658
659
# File 'lib/stripe/resources/terminal/reader.rb', line 657

def type
  @type
end