Class: Stripe::Terminal::Reader::CollectInputsParams::Input::Toggle

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/terminal/reader.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(default_value: nil, description: nil, title: nil) ⇒ Toggle

Returns a new instance of Toggle.



401
402
403
404
405
# File 'lib/stripe/resources/terminal/reader.rb', line 401

def initialize(default_value: nil, description: nil, title: nil)
  @default_value = default_value
  @description = description
  @title = title
end

Instance Attribute Details

#default_valueObject

The default value of the toggle



395
396
397
# File 'lib/stripe/resources/terminal/reader.rb', line 395

def default_value
  @default_value
end

#descriptionObject

The description which will be displayed for the toggle



397
398
399
# File 'lib/stripe/resources/terminal/reader.rb', line 397

def description
  @description
end

#titleObject

The title which will be displayed for the toggle



399
400
401
# File 'lib/stripe/resources/terminal/reader.rb', line 399

def title
  @title
end