Class: Stripe::Terminal::Reader::CollectPaymentMethodParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::Reader::CollectPaymentMethodParams
- Defined in:
- lib/stripe/resources/terminal/reader.rb
Defined Under Namespace
Classes: CollectConfig
Instance Attribute Summary collapse
-
#collect_config ⇒ Object
Configuration overrides.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#payment_intent ⇒ Object
PaymentIntent ID.
Instance Method Summary collapse
-
#initialize(collect_config: nil, expand: nil, payment_intent: nil) ⇒ CollectPaymentMethodParams
constructor
A new instance of CollectPaymentMethodParams.
Methods inherited from RequestParams
Constructor Details
#initialize(collect_config: nil, expand: nil, payment_intent: nil) ⇒ CollectPaymentMethodParams
Returns a new instance of CollectPaymentMethodParams.
486 487 488 489 490 |
# File 'lib/stripe/resources/terminal/reader.rb', line 486 def initialize(collect_config: nil, expand: nil, payment_intent: nil) @collect_config = collect_config @expand = @payment_intent = payment_intent end |
Instance Attribute Details
#collect_config ⇒ Object
Configuration overrides
480 481 482 |
# File 'lib/stripe/resources/terminal/reader.rb', line 480 def collect_config @collect_config end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
482 483 484 |
# File 'lib/stripe/resources/terminal/reader.rb', line 482 def @expand end |
#payment_intent ⇒ Object
PaymentIntent ID
484 485 486 |
# File 'lib/stripe/resources/terminal/reader.rb', line 484 def payment_intent @payment_intent end |