Class: Stripe::Terminal::Reader::CollectPaymentMethodParams::CollectConfig

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/terminal/reader.rb

Defined Under Namespace

Classes: Tipping

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(allow_redisplay: nil, enable_customer_cancellation: nil, skip_tipping: nil, tipping: nil) ⇒ CollectConfig

Returns a new instance of CollectConfig.



700
701
702
703
704
705
706
707
708
709
710
# File 'lib/stripe/resources/terminal/reader.rb', line 700

def initialize(
  allow_redisplay: nil,
  enable_customer_cancellation: nil,
  skip_tipping: nil,
  tipping: nil
)
  @allow_redisplay = allow_redisplay
  @enable_customer_cancellation = enable_customer_cancellation
  @skip_tipping = skip_tipping
  @tipping = tipping
end

Instance Attribute Details

#allow_redisplayObject

This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow.



692
693
694
# File 'lib/stripe/resources/terminal/reader.rb', line 692

def allow_redisplay
  @allow_redisplay
end

#enable_customer_cancellationObject

Enables cancel button on transaction screens.



694
695
696
# File 'lib/stripe/resources/terminal/reader.rb', line 694

def enable_customer_cancellation
  @enable_customer_cancellation
end

#skip_tippingObject

Override showing a tipping selection screen on this transaction.



696
697
698
# File 'lib/stripe/resources/terminal/reader.rb', line 696

def skip_tipping
  @skip_tipping
end

#tippingObject

Tipping configuration for this transaction.



698
699
700
# File 'lib/stripe/resources/terminal/reader.rb', line 698

def tipping
  @tipping
end