Class: Stripe::Terminal::Reader::ConfirmPaymentIntentParams::ConfirmConfig
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::Reader::ConfirmPaymentIntentParams::ConfirmConfig
- Defined in:
- lib/stripe/resources/terminal/reader.rb
Instance Attribute Summary collapse
-
#return_url ⇒ Object
The URL to redirect your customer back to after they authenticate or cancel their payment on the payment method’s app or site.
Instance Method Summary collapse
-
#initialize(return_url: nil) ⇒ ConfirmConfig
constructor
A new instance of ConfirmConfig.
Methods inherited from RequestParams
Constructor Details
#initialize(return_url: nil) ⇒ ConfirmConfig
Returns a new instance of ConfirmConfig.
490 491 492 |
# File 'lib/stripe/resources/terminal/reader.rb', line 490 def initialize(return_url: nil) @return_url = return_url end |
Instance Attribute Details
#return_url ⇒ Object
The URL to redirect your customer back to after they authenticate or cancel their payment on the payment method’s app or site. If you’d prefer to redirect to a mobile application, you can alternatively supply an application URI scheme.
488 489 490 |
# File 'lib/stripe/resources/terminal/reader.rb', line 488 def return_url @return_url end |