Class: Stripe::Terminal::Reader::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/terminal/reader.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(device_type: nil, ending_before: nil, expand: nil, limit: nil, location: nil, serial_number: nil, starting_after: nil, status: nil) ⇒ ListParams

Returns a new instance of ListParams.



534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
# File 'lib/stripe/resources/terminal/reader.rb', line 534

def initialize(
  device_type: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  location: nil,
  serial_number: nil,
  starting_after: nil,
  status: nil
)
  @device_type = device_type
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @location = location
  @serial_number = serial_number
  @starting_after = starting_after
  @status = status
end

Instance Attribute Details

#device_typeObject

Filters readers by device type



518
519
520
# File 'lib/stripe/resources/terminal/reader.rb', line 518

def device_type
  @device_type
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



520
521
522
# File 'lib/stripe/resources/terminal/reader.rb', line 520

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



522
523
524
# File 'lib/stripe/resources/terminal/reader.rb', line 522

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



524
525
526
# File 'lib/stripe/resources/terminal/reader.rb', line 524

def limit
  @limit
end

#locationObject

A location ID to filter the response list to only readers at the specific location



526
527
528
# File 'lib/stripe/resources/terminal/reader.rb', line 526

def location
  @location
end

#serial_numberObject

Filters readers by serial number



528
529
530
# File 'lib/stripe/resources/terminal/reader.rb', line 528

def serial_number
  @serial_number
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



530
531
532
# File 'lib/stripe/resources/terminal/reader.rb', line 530

def starting_after
  @starting_after
end

#statusObject

A status filter to filter readers to only offline or online readers



532
533
534
# File 'lib/stripe/resources/terminal/reader.rb', line 532

def status
  @status
end