Class: Stripe::Terminal::Reader::PresentPaymentMethodParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::Reader::PresentPaymentMethodParams
- Defined in:
- lib/stripe/resources/terminal/reader.rb
Defined Under Namespace
Classes: Card, CardPresent, InteracPresent
Instance Attribute Summary collapse
-
#amount_tip ⇒ Object
Simulated on-reader tip amount.
-
#card ⇒ Object
Simulated data for the card payment method.
-
#card_present ⇒ Object
Simulated data for the card_present payment method.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#interac_present ⇒ Object
Simulated data for the interac_present payment method.
-
#type ⇒ Object
Simulated payment type.
Instance Method Summary collapse
-
#initialize(amount_tip: nil, card: nil, card_present: nil, expand: nil, interac_present: nil, type: nil) ⇒ PresentPaymentMethodParams
constructor
A new instance of PresentPaymentMethodParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount_tip: nil, card: nil, card_present: nil, expand: nil, interac_present: nil, type: nil) ⇒ PresentPaymentMethodParams
Returns a new instance of PresentPaymentMethodParams.
966 967 968 969 970 971 972 973 974 975 976 977 978 979 980 |
# File 'lib/stripe/resources/terminal/reader.rb', line 966 def initialize( amount_tip: nil, card: nil, card_present: nil, expand: nil, interac_present: nil, type: nil ) @amount_tip = amount_tip @card = card @card_present = card_present @expand = @interac_present = interac_present @type = type end |
Instance Attribute Details
#amount_tip ⇒ Object
Simulated on-reader tip amount.
954 955 956 |
# File 'lib/stripe/resources/terminal/reader.rb', line 954 def amount_tip @amount_tip end |
#card ⇒ Object
Simulated data for the card payment method.
956 957 958 |
# File 'lib/stripe/resources/terminal/reader.rb', line 956 def card @card end |
#card_present ⇒ Object
Simulated data for the card_present payment method.
958 959 960 |
# File 'lib/stripe/resources/terminal/reader.rb', line 958 def card_present @card_present end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
960 961 962 |
# File 'lib/stripe/resources/terminal/reader.rb', line 960 def @expand end |
#interac_present ⇒ Object
Simulated data for the interac_present payment method.
962 963 964 |
# File 'lib/stripe/resources/terminal/reader.rb', line 962 def interac_present @interac_present end |
#type ⇒ Object
Simulated payment type.
964 965 966 |
# File 'lib/stripe/resources/terminal/reader.rb', line 964 def type @type end |