Class: Stripe::Terminal::Reader::PresentPaymentMethodParams::Card
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::Reader::PresentPaymentMethodParams::Card
- Defined in:
- lib/stripe/resources/terminal/reader.rb
Instance Attribute Summary collapse
-
#cvc ⇒ Object
Card security code.
-
#exp_month ⇒ Object
Two-digit number representing the card’s expiration month.
-
#exp_year ⇒ Object
Two- or four-digit number representing the card’s expiration year.
-
#number ⇒ Object
The card number, as a string without any separators.
Instance Method Summary collapse
-
#initialize(cvc: nil, exp_month: nil, exp_year: nil, number: nil) ⇒ Card
constructor
A new instance of Card.
Methods inherited from RequestParams
Constructor Details
#initialize(cvc: nil, exp_month: nil, exp_year: nil, number: nil) ⇒ Card
Returns a new instance of Card.
928 929 930 931 932 933 |
# File 'lib/stripe/resources/terminal/reader.rb', line 928 def initialize(cvc: nil, exp_month: nil, exp_year: nil, number: nil) @cvc = cvc @exp_month = exp_month @exp_year = exp_year @number = number end |
Instance Attribute Details
#cvc ⇒ Object
Card security code.
920 921 922 |
# File 'lib/stripe/resources/terminal/reader.rb', line 920 def cvc @cvc end |
#exp_month ⇒ Object
Two-digit number representing the card’s expiration month.
922 923 924 |
# File 'lib/stripe/resources/terminal/reader.rb', line 922 def exp_month @exp_month end |
#exp_year ⇒ Object
Two- or four-digit number representing the card’s expiration year.
924 925 926 |
# File 'lib/stripe/resources/terminal/reader.rb', line 924 def exp_year @exp_year end |
#number ⇒ Object
The card number, as a string without any separators.
926 927 928 |
# File 'lib/stripe/resources/terminal/reader.rb', line 926 def number @number end |