Class: Stripe::Terminal::Reader::ProcessPaymentIntentParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::Reader::ProcessPaymentIntentParams
- Defined in:
- lib/stripe/resources/terminal/reader.rb
Defined Under Namespace
Classes: ProcessConfig
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#payment_intent ⇒ Object
PaymentIntent ID.
-
#process_config ⇒ Object
Configuration overrides.
Instance Method Summary collapse
-
#initialize(expand: nil, payment_intent: nil, process_config: nil) ⇒ ProcessPaymentIntentParams
constructor
A new instance of ProcessPaymentIntentParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, payment_intent: nil, process_config: nil) ⇒ ProcessPaymentIntentParams
Returns a new instance of ProcessPaymentIntentParams.
791 792 793 794 795 |
# File 'lib/stripe/resources/terminal/reader.rb', line 791 def initialize(expand: nil, payment_intent: nil, process_config: nil) @expand = @payment_intent = payment_intent @process_config = process_config end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
785 786 787 |
# File 'lib/stripe/resources/terminal/reader.rb', line 785 def @expand end |
#payment_intent ⇒ Object
PaymentIntent ID
787 788 789 |
# File 'lib/stripe/resources/terminal/reader.rb', line 787 def payment_intent @payment_intent end |
#process_config ⇒ Object
Configuration overrides
789 790 791 |
# File 'lib/stripe/resources/terminal/reader.rb', line 789 def process_config @process_config end |