Class: Stripe::Terminal::Reader::ProcessSetupIntentParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/terminal/reader.rb

Defined Under Namespace

Classes: ProcessConfig

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(allow_redisplay: nil, expand: nil, process_config: nil, setup_intent: nil) ⇒ ProcessSetupIntentParams

Returns a new instance of ProcessSetupIntentParams.



467
468
469
470
471
472
# File 'lib/stripe/resources/terminal/reader.rb', line 467

def initialize(allow_redisplay: nil, expand: nil, process_config: nil, setup_intent: nil)
  @allow_redisplay = allow_redisplay
  @expand = expand
  @process_config = process_config
  @setup_intent = setup_intent
end

Instance Attribute Details

#allow_redisplayObject

This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow.



459
460
461
# File 'lib/stripe/resources/terminal/reader.rb', line 459

def allow_redisplay
  @allow_redisplay
end

#expandObject

Specifies which fields in the response should be expanded.



461
462
463
# File 'lib/stripe/resources/terminal/reader.rb', line 461

def expand
  @expand
end

#process_configObject

Configuration overrides



463
464
465
# File 'lib/stripe/resources/terminal/reader.rb', line 463

def process_config
  @process_config
end

#setup_intentObject

SetupIntent ID



465
466
467
# File 'lib/stripe/resources/terminal/reader.rb', line 465

def setup_intent
  @setup_intent
end