Class: Stripe::Terminal::Reader::SetReaderDisplayParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::Reader::SetReaderDisplayParams
- Defined in:
- lib/stripe/resources/terminal/reader.rb
Defined Under Namespace
Classes: Cart
Instance Attribute Summary collapse
-
#cart ⇒ Object
Cart.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#type ⇒ Object
Type.
Instance Method Summary collapse
-
#initialize(cart: nil, expand: nil, type: nil) ⇒ SetReaderDisplayParams
constructor
A new instance of SetReaderDisplayParams.
Methods inherited from RequestParams
Constructor Details
#initialize(cart: nil, expand: nil, type: nil) ⇒ SetReaderDisplayParams
Returns a new instance of SetReaderDisplayParams.
910 911 912 913 914 |
# File 'lib/stripe/resources/terminal/reader.rb', line 910 def initialize(cart: nil, expand: nil, type: nil) @cart = cart @expand = @type = type end |
Instance Attribute Details
#cart ⇒ Object
Cart
904 905 906 |
# File 'lib/stripe/resources/terminal/reader.rb', line 904 def cart @cart end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
906 907 908 |
# File 'lib/stripe/resources/terminal/reader.rb', line 906 def @expand end |
#type ⇒ Object
Type
908 909 910 |
# File 'lib/stripe/resources/terminal/reader.rb', line 908 def type @type end |