Class: Stripe::Terminal::Reader::TimeoutInputCollectionParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::Reader::TimeoutInputCollectionParams
- Defined in:
- lib/stripe/resources/terminal/reader.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ TimeoutInputCollectionParams
constructor
A new instance of TimeoutInputCollectionParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ TimeoutInputCollectionParams
Returns a new instance of TimeoutInputCollectionParams.
999 1000 1001 |
# File 'lib/stripe/resources/terminal/reader.rb', line 999 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
997 998 999 |
# File 'lib/stripe/resources/terminal/reader.rb', line 997 def @expand end |