Class: Stripe::Terminal::Reader::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/terminal/reader.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, label: nil, metadata: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



509
510
511
512
513
# File 'lib/stripe/resources/terminal/reader.rb', line 509

def initialize(expand: nil, label: nil, metadata: nil)
  @expand = expand
  @label = label
  @metadata = 
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



503
504
505
# File 'lib/stripe/resources/terminal/reader.rb', line 503

def expand
  @expand
end

#labelObject

The new label of the reader.



505
506
507
# File 'lib/stripe/resources/terminal/reader.rb', line 505

def label
  @label
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



507
508
509
# File 'lib/stripe/resources/terminal/reader.rb', line 507

def 
  @metadata
end