Class: Stripe::Terminal::ReaderActivateGiftCardParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/terminal/reader_activate_gift_card_params.rb

Defined Under Namespace

Classes: Balance

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(balance: nil, brand: nil, expand: nil, on_behalf_of: nil) ⇒ ReaderActivateGiftCardParams

Returns a new instance of ReaderActivateGiftCardParams.



27
28
29
30
31
32
# File 'lib/stripe/params/terminal/reader_activate_gift_card_params.rb', line 27

def initialize(balance: nil, brand: nil, expand: nil, on_behalf_of: nil)
  @balance = balance
  @brand = brand
  @expand = expand
  @on_behalf_of = on_behalf_of
end

Instance Attribute Details

#balanceObject

The initial balance to set on the gift card.



19
20
21
# File 'lib/stripe/params/terminal/reader_activate_gift_card_params.rb', line 19

def balance
  @balance
end

#brandObject

The brand of the gift card.



21
22
23
# File 'lib/stripe/params/terminal/reader_activate_gift_card_params.rb', line 21

def brand
  @brand
end

#expandObject

Specifies which fields in the response should be expanded.



23
24
25
# File 'lib/stripe/params/terminal/reader_activate_gift_card_params.rb', line 23

def expand
  @expand
end

#on_behalf_ofObject

The Stripe account ID to process the gift card operation on behalf of.



25
26
27
# File 'lib/stripe/params/terminal/reader_activate_gift_card_params.rb', line 25

def on_behalf_of
  @on_behalf_of
end