Class: Stripe::Terminal::ReaderCashoutGiftCardParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/terminal/reader_cashout_gift_card_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(brand: nil, expand: nil, on_behalf_of: nil) ⇒ ReaderCashoutGiftCardParams

Returns a new instance of ReaderCashoutGiftCardParams.



14
15
16
17
18
# File 'lib/stripe/params/terminal/reader_cashout_gift_card_params.rb', line 14

def initialize(brand: nil, expand: nil, on_behalf_of: nil)
  @brand = brand
  @expand = expand
  @on_behalf_of = on_behalf_of
end

Instance Attribute Details

#brandObject

The brand of the gift card.



8
9
10
# File 'lib/stripe/params/terminal/reader_cashout_gift_card_params.rb', line 8

def brand
  @brand
end

#expandObject

Specifies which fields in the response should be expanded.



10
11
12
# File 'lib/stripe/params/terminal/reader_cashout_gift_card_params.rb', line 10

def expand
  @expand
end

#on_behalf_ofObject

The Stripe account ID to process the gift card operation on behalf of.



12
13
14
# File 'lib/stripe/params/terminal/reader_cashout_gift_card_params.rb', line 12

def on_behalf_of
  @on_behalf_of
end