Class: Stripe::Terminal::ReaderCheckGiftCardBalanceParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::ReaderCheckGiftCardBalanceParams
- Defined in:
- lib/stripe/params/terminal/reader_check_gift_card_balance_params.rb
Instance Attribute Summary collapse
-
#brand ⇒ Object
The brand of the gift card.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#on_behalf_of ⇒ Object
The Stripe account ID to process the gift card operation on behalf of.
Instance Method Summary collapse
-
#initialize(brand: nil, expand: nil, on_behalf_of: nil) ⇒ ReaderCheckGiftCardBalanceParams
constructor
A new instance of ReaderCheckGiftCardBalanceParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(brand: nil, expand: nil, on_behalf_of: nil) ⇒ ReaderCheckGiftCardBalanceParams
Returns a new instance of ReaderCheckGiftCardBalanceParams.
14 15 16 17 18 |
# File 'lib/stripe/params/terminal/reader_check_gift_card_balance_params.rb', line 14 def initialize(brand: nil, expand: nil, on_behalf_of: nil) @brand = brand @expand = @on_behalf_of = on_behalf_of end |
Instance Attribute Details
#brand ⇒ Object
The brand of the gift card.
8 9 10 |
# File 'lib/stripe/params/terminal/reader_check_gift_card_balance_params.rb', line 8 def brand @brand end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
10 11 12 |
# File 'lib/stripe/params/terminal/reader_check_gift_card_balance_params.rb', line 10 def @expand end |
#on_behalf_of ⇒ Object
The Stripe account ID to process the gift card operation on behalf of.
12 13 14 |
# File 'lib/stripe/params/terminal/reader_check_gift_card_balance_params.rb', line 12 def on_behalf_of @on_behalf_of end |