Class: Stripe::Terminal::ReaderCollectedData::RetrieveParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::ReaderCollectedData::RetrieveParams
- Defined in:
- lib/stripe/resources/terminal/reader_collected_data.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ RetrieveParams
constructor
A new instance of RetrieveParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ RetrieveParams
Returns a new instance of RetrieveParams.
22 23 24 |
# File 'lib/stripe/resources/terminal/reader_collected_data.rb', line 22 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
20 21 22 |
# File 'lib/stripe/resources/terminal/reader_collected_data.rb', line 20 def @expand end |