Class: Stripe::Terminal::ReaderService::CollectInputsParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::ReaderService::CollectInputsParams
- Defined in:
- lib/stripe/services/terminal/reader_service.rb
Defined Under Namespace
Classes: Input
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#inputs ⇒ Object
List of inputs to be collected using the Reader.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
Instance Method Summary collapse
-
#initialize(expand: nil, inputs: nil, metadata: nil) ⇒ CollectInputsParams
constructor
A new instance of CollectInputsParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, inputs: nil, metadata: nil) ⇒ CollectInputsParams
Returns a new instance of CollectInputsParams.
192 193 194 195 196 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 192 def initialize(expand: nil, inputs: nil, metadata: nil) @expand = @inputs = inputs @metadata = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
186 187 188 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 186 def @expand end |
#inputs ⇒ Object
List of inputs to be collected using the Reader
188 189 190 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 188 def inputs @inputs end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
190 191 192 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 190 def @metadata end |