Class: Stripe::Terminal::ReaderService::CollectInputsParams::Input

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/terminal/reader_service.rb

Defined Under Namespace

Classes: CustomText, Selection, Toggle

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(custom_text: nil, required: nil, selection: nil, toggles: nil, type: nil) ⇒ Input

Returns a new instance of Input.



176
177
178
179
180
181
182
# File 'lib/stripe/services/terminal/reader_service.rb', line 176

def initialize(custom_text: nil, required: nil, selection: nil, toggles: nil, type: nil)
  @custom_text = custom_text
  @required = required
  @selection = selection
  @toggles = toggles
  @type = type
end

Instance Attribute Details

#custom_textObject

Customize the text which will be displayed while collecting this input



166
167
168
# File 'lib/stripe/services/terminal/reader_service.rb', line 166

def custom_text
  @custom_text
end

#requiredObject

Indicate that this input is required, disabling the skip button



168
169
170
# File 'lib/stripe/services/terminal/reader_service.rb', line 168

def required
  @required
end

#selectionObject

Options for the ‘selection` input



170
171
172
# File 'lib/stripe/services/terminal/reader_service.rb', line 170

def selection
  @selection
end

#togglesObject

List of toggles to be displayed and customization for the toggles



172
173
174
# File 'lib/stripe/services/terminal/reader_service.rb', line 172

def toggles
  @toggles
end

#typeObject

The type of input to collect



174
175
176
# File 'lib/stripe/services/terminal/reader_service.rb', line 174

def type
  @type
end