Class: Stripe::Terminal::ReaderService::CollectInputsParams::Input::Selection::Choice

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/terminal/reader_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(id: nil, style: nil, text: nil) ⇒ Choice

Returns a new instance of Choice.



137
138
139
140
141
# File 'lib/stripe/services/terminal/reader_service.rb', line 137

def initialize(id: nil, style: nil, text: nil)
  @id = id
  @style = style
  @text = text
end

Instance Attribute Details

#idObject

The unique identifier for this choice



131
132
133
# File 'lib/stripe/services/terminal/reader_service.rb', line 131

def id
  @id
end

#styleObject

The style of the button which will be shown for this choice



133
134
135
# File 'lib/stripe/services/terminal/reader_service.rb', line 133

def style
  @style
end

#textObject

The text which will be shown on the button for this choice



135
136
137
# File 'lib/stripe/services/terminal/reader_service.rb', line 135

def text
  @text
end