Class: Stripe::Terminal::ReaderService::CollectInputsParams::Input::Toggle
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::ReaderService::CollectInputsParams::Input::Toggle
- Defined in:
- lib/stripe/services/terminal/reader_service.rb
Instance Attribute Summary collapse
-
#default_value ⇒ Object
The default value of the toggle.
-
#description ⇒ Object
The description which will be displayed for the toggle.
-
#title ⇒ Object
The title which will be displayed for the toggle.
Instance Method Summary collapse
-
#initialize(default_value: nil, description: nil, title: nil) ⇒ Toggle
constructor
A new instance of Toggle.
Methods inherited from RequestParams
Constructor Details
#initialize(default_value: nil, description: nil, title: nil) ⇒ Toggle
Returns a new instance of Toggle.
160 161 162 163 164 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 160 def initialize(default_value: nil, description: nil, title: nil) @default_value = default_value @description = description @title = title end |
Instance Attribute Details
#default_value ⇒ Object
The default value of the toggle
154 155 156 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 154 def default_value @default_value end |
#description ⇒ Object
The description which will be displayed for the toggle
156 157 158 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 156 def description @description end |
#title ⇒ Object
The title which will be displayed for the toggle
158 159 160 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 158 def title @title end |