Class: Stripe::Terminal::ReaderService::CollectPaymentMethodParams::CollectConfig

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/terminal/reader_service.rb

Defined Under Namespace

Classes: Tipping

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(allow_redisplay: nil, enable_customer_cancellation: nil, skip_tipping: nil, tipping: nil) ⇒ CollectConfig

Returns a new instance of CollectConfig.



215
216
217
218
219
220
221
222
223
224
225
# File 'lib/stripe/services/terminal/reader_service.rb', line 215

def initialize(
  allow_redisplay: nil,
  enable_customer_cancellation: nil,
  skip_tipping: nil,
  tipping: nil
)
  @allow_redisplay = allow_redisplay
  @enable_customer_cancellation = enable_customer_cancellation
  @skip_tipping = skip_tipping
  @tipping = tipping
end

Instance Attribute Details

#allow_redisplayObject

This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow.



207
208
209
# File 'lib/stripe/services/terminal/reader_service.rb', line 207

def allow_redisplay
  @allow_redisplay
end

#enable_customer_cancellationObject

Enables cancel button on transaction screens.



209
210
211
# File 'lib/stripe/services/terminal/reader_service.rb', line 209

def enable_customer_cancellation
  @enable_customer_cancellation
end

#skip_tippingObject

Override showing a tipping selection screen on this transaction.



211
212
213
# File 'lib/stripe/services/terminal/reader_service.rb', line 211

def skip_tipping
  @skip_tipping
end

#tippingObject

Tipping configuration for this transaction.



213
214
215
# File 'lib/stripe/services/terminal/reader_service.rb', line 213

def tipping
  @tipping
end