Class: Stripe::Terminal::ReaderService::ConfirmPaymentIntentParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::ReaderService::ConfirmPaymentIntentParams
- Defined in:
- lib/stripe/services/terminal/reader_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#payment_intent ⇒ Object
PaymentIntent ID.
Instance Method Summary collapse
-
#initialize(expand: nil, payment_intent: nil) ⇒ ConfirmPaymentIntentParams
constructor
A new instance of ConfirmPaymentIntentParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, payment_intent: nil) ⇒ ConfirmPaymentIntentParams
Returns a new instance of ConfirmPaymentIntentParams.
250 251 252 253 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 250 def initialize(expand: nil, payment_intent: nil) @expand = @payment_intent = payment_intent end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
246 247 248 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 246 def @expand end |
#payment_intent ⇒ Object
PaymentIntent ID
248 249 250 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 248 def payment_intent @payment_intent end |