Class: Stripe::Terminal::ReaderService::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/terminal/reader_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, label: nil, location: nil, metadata: nil, registration_code: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/stripe/services/terminal/reader_service.rb', line 85

def initialize(
  expand: nil,
  label: nil,
  location: nil,
  metadata: nil,
  registration_code: nil
)
  @expand = expand
  @label = label
  @location = location
  @metadata = 
  @registration_code = registration_code
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



75
76
77
# File 'lib/stripe/services/terminal/reader_service.rb', line 75

def expand
  @expand
end

#labelObject

Custom label given to the reader for easier identification. If no label is specified, the registration code will be used.



77
78
79
# File 'lib/stripe/services/terminal/reader_service.rb', line 77

def label
  @label
end

#locationObject

The location to assign the reader to.



79
80
81
# File 'lib/stripe/services/terminal/reader_service.rb', line 79

def location
  @location
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



81
82
83
# File 'lib/stripe/services/terminal/reader_service.rb', line 81

def 
  @metadata
end

#registration_codeObject

A code generated by the reader used for registering to an account.



83
84
85
# File 'lib/stripe/services/terminal/reader_service.rb', line 83

def registration_code
  @registration_code
end