Class: Stripe::Terminal::ReaderService::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::ReaderService::ListParams
- Defined in:
- lib/stripe/services/terminal/reader_service.rb
Instance Attribute Summary collapse
-
#device_type ⇒ Object
Filters readers by device type.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#location ⇒ Object
A location ID to filter the response list to only readers at the specific location.
-
#serial_number ⇒ Object
Filters readers by serial number.
-
#starting_after ⇒ Object
A cursor for use in pagination.
-
#status ⇒ Object
A status filter to filter readers to only offline or online readers.
Instance Method Summary collapse
-
#initialize(device_type: nil, ending_before: nil, expand: nil, limit: nil, location: nil, serial_number: nil, starting_after: nil, status: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(device_type: nil, ending_before: nil, expand: nil, limit: nil, location: nil, serial_number: nil, starting_after: nil, status: nil) ⇒ ListParams
Returns a new instance of ListParams.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 51 def initialize( device_type: nil, ending_before: nil, expand: nil, limit: nil, location: nil, serial_number: nil, starting_after: nil, status: nil ) @device_type = device_type @ending_before = ending_before @expand = @limit = limit @location = location @serial_number = serial_number @starting_after = starting_after @status = status end |
Instance Attribute Details
#device_type ⇒ Object
Filters readers by device type
35 36 37 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 35 def device_type @device_type end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
37 38 39 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 37 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
39 40 41 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 39 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
41 42 43 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 41 def limit @limit end |
#location ⇒ Object
A location ID to filter the response list to only readers at the specific location
43 44 45 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 43 def location @location end |
#serial_number ⇒ Object
Filters readers by serial number
45 46 47 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 45 def serial_number @serial_number end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
47 48 49 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 47 def starting_after @starting_after end |
#status ⇒ Object
A status filter to filter readers to only offline or online readers
49 50 51 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 49 def status @status end |