Class: Stripe::Terminal::ReaderService::SetReaderDisplayParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::ReaderService::SetReaderDisplayParams
- Defined in:
- lib/stripe/services/terminal/reader_service.rb
Defined Under Namespace
Classes: Cart
Instance Attribute Summary collapse
-
#cart ⇒ Object
Cart.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#type ⇒ Object
Type.
Instance Method Summary collapse
-
#initialize(cart: nil, expand: nil, type: nil) ⇒ SetReaderDisplayParams
constructor
A new instance of SetReaderDisplayParams.
Methods inherited from RequestParams
Constructor Details
#initialize(cart: nil, expand: nil, type: nil) ⇒ SetReaderDisplayParams
Returns a new instance of SetReaderDisplayParams.
359 360 361 362 363 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 359 def initialize(cart: nil, expand: nil, type: nil) @cart = cart @expand = @type = type end |
Instance Attribute Details
#cart ⇒ Object
Cart
353 354 355 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 353 def cart @cart end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
355 356 357 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 355 def @expand end |
#type ⇒ Object
Type
357 358 359 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 357 def type @type end |