Class: Stripe::Terminal::ReaderService::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/terminal/reader_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, label: nil, metadata: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



26
27
28
29
30
# File 'lib/stripe/services/terminal/reader_service.rb', line 26

def initialize(expand: nil, label: nil, metadata: nil)
  @expand = expand
  @label = label
  @metadata = 
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



20
21
22
# File 'lib/stripe/services/terminal/reader_service.rb', line 20

def expand
  @expand
end

#labelObject

The new label of the reader.



22
23
24
# File 'lib/stripe/services/terminal/reader_service.rb', line 22

def label
  @label
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



24
25
26
# File 'lib/stripe/services/terminal/reader_service.rb', line 24

def 
  @metadata
end