Class: Stripe::TestHelpers::Capital::FinancingOfferRefillParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/test_helpers/capital/financing_offer_refill_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(advance_amount: nil, expand: nil, fee_amount: nil, financing_type: nil, status: nil, withhold_rate: nil) ⇒ FinancingOfferRefillParams

Returns a new instance of FinancingOfferRefillParams.



21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
# File 'lib/stripe/params/test_helpers/capital/financing_offer_refill_params.rb', line 21

def initialize(
  advance_amount: nil,
  expand: nil,
  fee_amount: nil,
  financing_type: nil,
  status: nil,
  withhold_rate: nil
)
  @advance_amount = advance_amount
  @expand = expand
  @fee_amount = fee_amount
  @financing_type = financing_type
  @status = status
  @withhold_rate = withhold_rate
end

Instance Attribute Details

#advance_amountObject

Amount of financing offered, in minor units. For example, 1,000 USD is represented as 100000.



9
10
11
# File 'lib/stripe/params/test_helpers/capital/financing_offer_refill_params.rb', line 9

def advance_amount
  @advance_amount
end

#expandObject

Specifies which fields in the response should be expanded.



11
12
13
# File 'lib/stripe/params/test_helpers/capital/financing_offer_refill_params.rb', line 11

def expand
  @expand
end

#fee_amountObject

Fixed fee amount, in minor units. For example, 100 USD is represented as 10000.



13
14
15
# File 'lib/stripe/params/test_helpers/capital/financing_offer_refill_params.rb', line 13

def fee_amount
  @fee_amount
end

#financing_typeObject

The type of financing offer



15
16
17
# File 'lib/stripe/params/test_helpers/capital/financing_offer_refill_params.rb', line 15

def financing_type
  @financing_type
end

#statusObject

The status of the financing offer



17
18
19
# File 'lib/stripe/params/test_helpers/capital/financing_offer_refill_params.rb', line 17

def status
  @status
end

#withhold_rateObject

Per-transaction rate at which Stripe withholds funds to repay the financing.



19
20
21
# File 'lib/stripe/params/test_helpers/capital/financing_offer_refill_params.rb', line 19

def withhold_rate
  @withhold_rate
end