Class: Stripe::TestHelpers::ConfirmationTokenCreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/test_helpers/confirmation_token_create_params.rb

Defined Under Namespace

Classes: PaymentMethodData, PaymentMethodOptions, Shipping

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(expand: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, return_url: nil, setup_future_usage: nil, shipping: nil) ⇒ ConfirmationTokenCreateParams



683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 683

def initialize(
  expand: nil,
  payment_method: nil,
  payment_method_data: nil,
  payment_method_options: nil,
  return_url: nil,
  setup_future_usage: nil,
  shipping: nil
)
  @expand = expand
  @payment_method = payment_method
  @payment_method_data = payment_method_data
  @payment_method_options = payment_method_options
  @return_url = return_url
  @setup_future_usage = setup_future_usage
  @shipping = shipping
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



667
668
669
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 667

def expand
  @expand
end

#payment_methodObject

ID of an existing PaymentMethod.



669
670
671
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 669

def payment_method
  @payment_method
end

#payment_method_dataObject

If provided, this hash will be used to create a PaymentMethod.



671
672
673
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 671

def payment_method_data
  @payment_method_data
end

#payment_method_optionsObject

Payment-method-specific configuration for this ConfirmationToken.



673
674
675
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 673

def payment_method_options
  @payment_method_options
end

#return_urlObject

Return URL used to confirm the Intent.



675
676
677
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 675

def return_url
  @return_url
end

#setup_future_usageObject

Indicates that you intend to make future payments with this ConfirmationToken’s payment method.

The presence of this property will [attach the payment method](docs.stripe.com/payments/save-during-payment) to the PaymentIntent’s Customer, if present, after the PaymentIntent is confirmed and any required actions from the user are complete.



679
680
681
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 679

def setup_future_usage
  @setup_future_usage
end

#shippingObject

Shipping information for this ConfirmationToken.



681
682
683
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 681

def shipping
  @shipping
end