Class: Stripe::TestHelpers::ConfirmationTokenCreateParams::PaymentMethodData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/test_helpers/confirmation_token_create_params.rb

Defined Under Namespace

Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, BillingDetails, Bizum, Blik, Boleto, Cashapp, Crypto, CustomerBalance, Eps, Fpx, Giropay, Grabpay, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Payto, Pix, Promptpay, RadarOptions, RevolutPay, SamsungPay, Satispay, Scalapay, SepaDebit, Sofort, Sunbit, Swish, Twint, Upi, UsBankAccount, WechatPay, Zip

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, allow_redisplay: nil, alma: nil, amazon_pay: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, billie: nil, billing_details: nil, bizum: nil, blik: nil, boleto: nil, cashapp: nil, crypto: nil, customer_balance: nil, eps: nil, fpx: nil, giropay: nil, grabpay: nil, ideal: nil, interac_present: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, mb_way: nil, metadata: nil, mobilepay: nil, multibanco: nil, naver_pay: nil, nz_bank_account: nil, oxxo: nil, p24: nil, pay_by_bank: nil, payco: nil, paynow: nil, paypal: nil, payto: nil, pix: nil, promptpay: nil, radar_options: nil, revolut_pay: nil, samsung_pay: nil, satispay: nil, scalapay: nil, sepa_debit: nil, sofort: nil, sunbit: nil, swish: nil, twint: nil, type: nil, upi: nil, us_bank_account: nil, wechat_pay: nil, zip: nil) ⇒ PaymentMethodData

Returns a new instance of PaymentMethodData.



473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 473

def initialize(
  acss_debit: nil,
  affirm: nil,
  afterpay_clearpay: nil,
  alipay: nil,
  allow_redisplay: nil,
  alma: nil,
  amazon_pay: nil,
  au_becs_debit: nil,
  bacs_debit: nil,
  bancontact: nil,
  billie: nil,
  billing_details: nil,
  bizum: nil,
  blik: nil,
  boleto: nil,
  cashapp: nil,
  crypto: nil,
  customer_balance: nil,
  eps: nil,
  fpx: nil,
  giropay: nil,
  grabpay: nil,
  ideal: nil,
  interac_present: nil,
  kakao_pay: nil,
  klarna: nil,
  konbini: nil,
  kr_card: nil,
  link: nil,
  mb_way: nil,
  metadata: nil,
  mobilepay: nil,
  multibanco: nil,
  naver_pay: nil,
  nz_bank_account: nil,
  oxxo: nil,
  p24: nil,
  pay_by_bank: nil,
  payco: nil,
  paynow: nil,
  paypal: nil,
  payto: nil,
  pix: nil,
  promptpay: nil,
  radar_options: nil,
  revolut_pay: nil,
  samsung_pay: nil,
  satispay: nil,
  scalapay: nil,
  sepa_debit: nil,
  sofort: nil,
  sunbit: nil,
  swish: nil,
  twint: nil,
  type: nil,
  upi: nil,
  us_bank_account: nil,
  wechat_pay: nil,
  zip: nil
)
  @acss_debit = acss_debit
  @affirm = affirm
  @afterpay_clearpay = afterpay_clearpay
  @alipay = alipay
  @allow_redisplay = allow_redisplay
  @alma = alma
  @amazon_pay = amazon_pay
  @au_becs_debit = au_becs_debit
  @bacs_debit = bacs_debit
  @bancontact = bancontact
  @billie = billie
  @billing_details = billing_details
  @bizum = bizum
  @blik = blik
  @boleto = boleto
  @cashapp = cashapp
  @crypto = crypto
  @customer_balance = customer_balance
  @eps = eps
  @fpx = fpx
  @giropay = giropay
  @grabpay = grabpay
  @ideal = ideal
  @interac_present = interac_present
  @kakao_pay = kakao_pay
  @klarna = klarna
  @konbini = konbini
  @kr_card = kr_card
  @link = link
  @mb_way = mb_way
  @metadata = 
  @mobilepay = mobilepay
  @multibanco = multibanco
  @naver_pay = naver_pay
  @nz_bank_account = 
  @oxxo = oxxo
  @p24 = p24
  @pay_by_bank = pay_by_bank
  @payco = payco
  @paynow = paynow
  @paypal = paypal
  @payto = payto
  @pix = pix
  @promptpay = promptpay
  @radar_options = radar_options
  @revolut_pay = revolut_pay
  @samsung_pay = samsung_pay
  @satispay = satispay
  @scalapay = scalapay
  @sepa_debit = sepa_debit
  @sofort = sofort
  @sunbit = sunbit
  @swish = swish
  @twint = twint
  @type = type
  @upi = upi
  @us_bank_account = 
  @wechat_pay = wechat_pay
  @zip = zip
end

Instance Attribute Details

#acss_debitObject

If this is an ‘acss_debit` PaymentMethod, this hash contains details about the ACSS Debit payment method.



355
356
357
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 355

def acss_debit
  @acss_debit
end

#affirmObject

If this is an ‘affirm` PaymentMethod, this hash contains details about the Affirm payment method.



357
358
359
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 357

def affirm
  @affirm
end

#afterpay_clearpayObject

If this is an ‘AfterpayClearpay` PaymentMethod, this hash contains details about the AfterpayClearpay payment method.



359
360
361
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 359

def afterpay_clearpay
  @afterpay_clearpay
end

#alipayObject

If this is an ‘Alipay` PaymentMethod, this hash contains details about the Alipay payment method.



361
362
363
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 361

def alipay
  @alipay
end

#allow_redisplayObject

This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. The field defaults to ‘unspecified`.



363
364
365
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 363

def allow_redisplay
  @allow_redisplay
end

#almaObject

If this is a Alma PaymentMethod, this hash contains details about the Alma payment method.



365
366
367
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 365

def alma
  @alma
end

#amazon_payObject

If this is a AmazonPay PaymentMethod, this hash contains details about the AmazonPay payment method.



367
368
369
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 367

def amazon_pay
  @amazon_pay
end

#au_becs_debitObject

If this is an ‘au_becs_debit` PaymentMethod, this hash contains details about the bank account.



369
370
371
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 369

def au_becs_debit
  @au_becs_debit
end

#bacs_debitObject

If this is a ‘bacs_debit` PaymentMethod, this hash contains details about the Bacs Direct Debit bank account.



371
372
373
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 371

def bacs_debit
  @bacs_debit
end

#bancontactObject

If this is a ‘bancontact` PaymentMethod, this hash contains details about the Bancontact payment method.



373
374
375
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 373

def bancontact
  @bancontact
end

#billieObject

If this is a ‘billie` PaymentMethod, this hash contains details about the Billie payment method.



375
376
377
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 375

def billie
  @billie
end

#billing_detailsObject

Billing information associated with the PaymentMethod that may be used or required by particular types of payment methods.



377
378
379
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 377

def billing_details
  @billing_details
end

#bizumObject

If this is a ‘bizum` PaymentMethod, this hash contains details about the Bizum payment method.



379
380
381
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 379

def bizum
  @bizum
end

#blikObject

If this is a ‘blik` PaymentMethod, this hash contains details about the BLIK payment method.



381
382
383
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 381

def blik
  @blik
end

#boletoObject

If this is a ‘boleto` PaymentMethod, this hash contains details about the Boleto payment method.



383
384
385
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 383

def boleto
  @boleto
end

#cashappObject

If this is a ‘cashapp` PaymentMethod, this hash contains details about the Cash App Pay payment method.



385
386
387
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 385

def cashapp
  @cashapp
end

#cryptoObject

If this is a Crypto PaymentMethod, this hash contains details about the Crypto payment method.



387
388
389
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 387

def crypto
  @crypto
end

#customer_balanceObject

If this is a ‘customer_balance` PaymentMethod, this hash contains details about the CustomerBalance payment method.



389
390
391
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 389

def customer_balance
  @customer_balance
end

#epsObject

If this is an ‘eps` PaymentMethod, this hash contains details about the EPS payment method.



391
392
393
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 391

def eps
  @eps
end

#fpxObject

If this is an ‘fpx` PaymentMethod, this hash contains details about the FPX payment method.



393
394
395
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 393

def fpx
  @fpx
end

#giropayObject

If this is a ‘giropay` PaymentMethod, this hash contains details about the Giropay payment method.



395
396
397
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 395

def giropay
  @giropay
end

#grabpayObject

If this is a ‘grabpay` PaymentMethod, this hash contains details about the GrabPay payment method.



397
398
399
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 397

def grabpay
  @grabpay
end

#idealObject

If this is an ‘ideal` PaymentMethod, this hash contains details about the iDEAL payment method.



399
400
401
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 399

def ideal
  @ideal
end

#interac_presentObject

If this is an ‘interac_present` PaymentMethod, this hash contains details about the Interac Present payment method.



401
402
403
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 401

def interac_present
  @interac_present
end

#kakao_payObject

If this is a ‘kakao_pay` PaymentMethod, this hash contains details about the Kakao Pay payment method.



403
404
405
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 403

def kakao_pay
  @kakao_pay
end

#klarnaObject

If this is a ‘klarna` PaymentMethod, this hash contains details about the Klarna payment method.



405
406
407
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 405

def klarna
  @klarna
end

#konbiniObject

If this is a ‘konbini` PaymentMethod, this hash contains details about the Konbini payment method.



407
408
409
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 407

def konbini
  @konbini
end

#kr_cardObject

If this is a ‘kr_card` PaymentMethod, this hash contains details about the Korean Card payment method.



409
410
411
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 409

def kr_card
  @kr_card
end

If this is an ‘Link` PaymentMethod, this hash contains details about the Link payment method (Link is also known as Onelink in the UK).



411
412
413
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 411

def link
  @link
end

#mb_wayObject

If this is a MB WAY PaymentMethod, this hash contains details about the MB WAY payment method.



413
414
415
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 413

def mb_way
  @mb_way
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



415
416
417
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 415

def 
  @metadata
end

#mobilepayObject

If this is a ‘mobilepay` PaymentMethod, this hash contains details about the MobilePay payment method.



417
418
419
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 417

def mobilepay
  @mobilepay
end

#multibancoObject

If this is a ‘multibanco` PaymentMethod, this hash contains details about the Multibanco payment method.



419
420
421
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 419

def multibanco
  @multibanco
end

If this is a ‘naver_pay` PaymentMethod, this hash contains details about the Naver Pay payment method.



421
422
423
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 421

def naver_pay
  @naver_pay
end

#nz_bank_accountObject

If this is an nz_bank_account PaymentMethod, this hash contains details about the nz_bank_account payment method.



423
424
425
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 423

def 
  @nz_bank_account
end

#oxxoObject

If this is an ‘oxxo` PaymentMethod, this hash contains details about the OXXO payment method.



425
426
427
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 425

def oxxo
  @oxxo
end

#p24Object

If this is a ‘p24` PaymentMethod, this hash contains details about the P24 payment method.



427
428
429
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 427

def p24
  @p24
end

#pay_by_bankObject

If this is a ‘pay_by_bank` PaymentMethod, this hash contains details about the PayByBank payment method.



429
430
431
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 429

def pay_by_bank
  @pay_by_bank
end

#paycoObject

If this is a ‘payco` PaymentMethod, this hash contains details about the PAYCO payment method.



431
432
433
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 431

def payco
  @payco
end

#paynowObject

If this is a ‘paynow` PaymentMethod, this hash contains details about the PayNow payment method.



433
434
435
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 433

def paynow
  @paynow
end

#paypalObject

If this is a ‘paypal` PaymentMethod, this hash contains details about the PayPal payment method.



435
436
437
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 435

def paypal
  @paypal
end

#paytoObject

If this is a ‘payto` PaymentMethod, this hash contains details about the PayTo payment method.



437
438
439
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 437

def payto
  @payto
end

#pixObject

If this is a ‘pix` PaymentMethod, this hash contains details about the Pix payment method.



439
440
441
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 439

def pix
  @pix
end

#promptpayObject

If this is a ‘promptpay` PaymentMethod, this hash contains details about the PromptPay payment method.



441
442
443
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 441

def promptpay
  @promptpay
end

#radar_optionsObject

Options to configure Radar. See [Radar Session](docs.stripe.com/radar/radar-session) for more information.



443
444
445
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 443

def radar_options
  @radar_options
end

#revolut_payObject

If this is a ‘revolut_pay` PaymentMethod, this hash contains details about the Revolut Pay payment method.



445
446
447
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 445

def revolut_pay
  @revolut_pay
end

#samsung_payObject

If this is a ‘samsung_pay` PaymentMethod, this hash contains details about the SamsungPay payment method.



447
448
449
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 447

def samsung_pay
  @samsung_pay
end

#satispayObject

If this is a ‘satispay` PaymentMethod, this hash contains details about the Satispay payment method.



449
450
451
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 449

def satispay
  @satispay
end

#scalapayObject

If this is a Scalapay PaymentMethod, this hash contains details about the Scalapay payment method.



451
452
453
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 451

def scalapay
  @scalapay
end

#sepa_debitObject

If this is a ‘sepa_debit` PaymentMethod, this hash contains details about the SEPA debit bank account.



453
454
455
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 453

def sepa_debit
  @sepa_debit
end

#sofortObject

If this is a ‘sofort` PaymentMethod, this hash contains details about the SOFORT payment method.



455
456
457
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 455

def sofort
  @sofort
end

#sunbitObject

If this is a Sunbit PaymentMethod, this hash contains details about the Sunbit payment method.



457
458
459
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 457

def sunbit
  @sunbit
end

#swishObject

If this is a ‘swish` PaymentMethod, this hash contains details about the Swish payment method.



459
460
461
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 459

def swish
  @swish
end

#twintObject

If this is a TWINT PaymentMethod, this hash contains details about the TWINT payment method.



461
462
463
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 461

def twint
  @twint
end

#typeObject

The type of the PaymentMethod. An additional hash is included on the PaymentMethod with a name matching this value. It contains additional information specific to the PaymentMethod type.



463
464
465
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 463

def type
  @type
end

#upiObject

If this is a ‘upi` PaymentMethod, this hash contains details about the UPI payment method.



465
466
467
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 465

def upi
  @upi
end

#us_bank_accountObject

If this is an ‘us_bank_account` PaymentMethod, this hash contains details about the US bank account payment method.



467
468
469
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 467

def 
  @us_bank_account
end

#wechat_payObject

If this is an ‘wechat_pay` PaymentMethod, this hash contains details about the wechat_pay payment method.



469
470
471
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 469

def wechat_pay
  @wechat_pay
end

#zipObject

If this is a ‘zip` PaymentMethod, this hash contains details about the Zip payment method.



471
472
473
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 471

def zip
  @zip
end