Class: Stripe::TestHelpers::ConfirmationTokenCreateParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::TestHelpers::ConfirmationTokenCreateParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/params/test_helpers/confirmation_token_create_params.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 231 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
219 220 221 |
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 219 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
221 222 223 |
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 221 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
223 224 225 |
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 223 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
225 226 227 |
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 225 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
227 228 229 |
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 227 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
229 230 231 |
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 229 def suffix @suffix end |