Class: Stripe::TestHelpers::ConfirmationTokenCreateParams::PaymentMethodData::StripeBalance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::TestHelpers::ConfirmationTokenCreateParams::PaymentMethodData::StripeBalance
- Defined in:
- lib/stripe/params/test_helpers/confirmation_token_create_params.rb
Instance Attribute Summary collapse
-
#account ⇒ Object
The connected account ID whose Stripe balance to use as the source of payment.
Instance Method Summary collapse
-
#initialize(account: nil) ⇒ StripeBalance
constructor
A new instance of StripeBalance.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(account: nil) ⇒ StripeBalance
Returns a new instance of StripeBalance.
334 335 336 |
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 334 def initialize(account: nil) @account = account end |
Instance Attribute Details
#account ⇒ Object
The connected account ID whose Stripe balance to use as the source of payment
332 333 334 |
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 332 def account @account end |