Class: Stripe::TestHelpers::ConfirmationTokenCreateParams::PaymentMethodData::Upi::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/test_helpers/confirmation_token_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



307
308
309
310
311
312
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 307

def initialize(amount: nil, amount_type: nil, description: nil, end_date: nil)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



299
300
301
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 299

def amount
  @amount
end

#amount_typeObject

One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.



301
302
303
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 301

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



303
304
305
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 303

def description
  @description
end

#end_dateObject

End date of the mandate or subscription.



305
306
307
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 305

def end_date
  @end_date
end