Class: Stripe::TestHelpers::ConfirmationTokenCreateParams::PaymentMethodData::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::TestHelpers::ConfirmationTokenCreateParams::PaymentMethodData::UsBankAccount
- Defined in:
- lib/stripe/params/test_helpers/confirmation_token_create_params.rb
Instance Attribute Summary collapse
-
#account_holder_type ⇒ Object
Account holder type: individual or company.
-
#account_number ⇒ Object
Account number of the bank account.
-
#account_type ⇒ Object
Account type: checkings or savings.
-
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
-
#routing_number ⇒ Object
Routing number of the bank account.
Instance Method Summary collapse
-
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 392 def initialize( account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil ) @account_holder_type = account_holder_type @account_number = account_number @account_type = account_type @financial_connections_account = financial_connections_account @routing_number = routing_number end |
Instance Attribute Details
#account_holder_type ⇒ Object
Account holder type: individual or company.
382 383 384 |
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 382 def account_holder_type @account_holder_type end |
#account_number ⇒ Object
Account number of the bank account.
384 385 386 |
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 384 def account_number @account_number end |
#account_type ⇒ Object
Account type: checkings or savings. Defaults to checking if omitted.
386 387 388 |
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 386 def account_type @account_type end |
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
388 389 390 |
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 388 def financial_connections_account @financial_connections_account end |
#routing_number ⇒ Object
Routing number of the bank account.
390 391 392 |
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 390 def routing_number @routing_number end |