Class: Stripe::TestHelpers::ConfirmationTokenService::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/test_helpers/confirmation_token_service.rb

Defined Under Namespace

Classes: PaymentMethodData, PaymentMethodOptions, Shipping

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, return_url: nil, setup_future_usage: nil, shipping: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
# File 'lib/stripe/services/test_helpers/confirmation_token_service.rb', line 721

def initialize(
  expand: nil,
  payment_method: nil,
  payment_method_data: nil,
  payment_method_options: nil,
  return_url: nil,
  setup_future_usage: nil,
  shipping: nil
)
  @expand = expand
  @payment_method = payment_method
  @payment_method_data = payment_method_data
  @payment_method_options = payment_method_options
  @return_url = return_url
  @setup_future_usage = setup_future_usage
  @shipping = shipping
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



705
706
707
# File 'lib/stripe/services/test_helpers/confirmation_token_service.rb', line 705

def expand
  @expand
end

#payment_methodObject

ID of an existing PaymentMethod.



707
708
709
# File 'lib/stripe/services/test_helpers/confirmation_token_service.rb', line 707

def payment_method
  @payment_method
end

#payment_method_dataObject

If provided, this hash will be used to create a PaymentMethod.



709
710
711
# File 'lib/stripe/services/test_helpers/confirmation_token_service.rb', line 709

def payment_method_data
  @payment_method_data
end

#payment_method_optionsObject

Payment-method-specific configuration for this ConfirmationToken.



711
712
713
# File 'lib/stripe/services/test_helpers/confirmation_token_service.rb', line 711

def payment_method_options
  @payment_method_options
end

#return_urlObject

Return URL used to confirm the Intent.



713
714
715
# File 'lib/stripe/services/test_helpers/confirmation_token_service.rb', line 713

def return_url
  @return_url
end

#setup_future_usageObject

Indicates that you intend to make future payments with this ConfirmationToken’s payment method.

The presence of this property will [attach the payment method](stripe.com/docs/payments/save-during-payment) to the PaymentIntent’s Customer, if present, after the PaymentIntent is confirmed and any required actions from the user are complete.



717
718
719
# File 'lib/stripe/services/test_helpers/confirmation_token_service.rb', line 717

def setup_future_usage
  @setup_future_usage
end

#shippingObject

Shipping information for this ConfirmationToken.



719
720
721
# File 'lib/stripe/services/test_helpers/confirmation_token_service.rb', line 719

def shipping
  @shipping
end