Class: Stripe::TestHelpers::ConfirmationTokenService::CreateParams::PaymentMethodData::BacsDebit
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::TestHelpers::ConfirmationTokenService::CreateParams::PaymentMethodData::BacsDebit
- Defined in:
- lib/stripe/services/test_helpers/confirmation_token_service.rb
Instance Attribute Summary collapse
-
#account_number ⇒ Object
Account number of the bank account that the funds will be debited from.
-
#sort_code ⇒ Object
Sort code of the bank account.
Instance Method Summary collapse
-
#initialize(account_number: nil, sort_code: nil) ⇒ BacsDebit
constructor
A new instance of BacsDebit.
Methods inherited from RequestParams
Constructor Details
#initialize(account_number: nil, sort_code: nil) ⇒ BacsDebit
Returns a new instance of BacsDebit.
57 58 59 60 |
# File 'lib/stripe/services/test_helpers/confirmation_token_service.rb', line 57 def initialize(account_number: nil, sort_code: nil) @account_number = account_number @sort_code = sort_code end |
Instance Attribute Details
#account_number ⇒ Object
Account number of the bank account that the funds will be debited from.
53 54 55 |
# File 'lib/stripe/services/test_helpers/confirmation_token_service.rb', line 53 def account_number @account_number end |
#sort_code ⇒ Object
Sort code of the bank account. (e.g., ‘10-20-30`)
55 56 57 |
# File 'lib/stripe/services/test_helpers/confirmation_token_service.rb', line 55 def sort_code @sort_code end |