Class: Stripe::TestHelpers::ConfirmationTokenService::CreateParams::PaymentMethodData::StripeBalance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::TestHelpers::ConfirmationTokenService::CreateParams::PaymentMethodData::StripeBalance
- Defined in:
- lib/stripe/services/test_helpers/confirmation_token_service.rb
Instance Attribute Summary collapse
-
#account ⇒ Object
The connected account ID whose Stripe balance to use as the source of payment.
-
#source_type ⇒ Object
The [source_type](docs.stripe.com/api/balance/balance_object#balance_object-available-source_types) of the balance.
Instance Method Summary collapse
-
#initialize(account: nil, source_type: nil) ⇒ StripeBalance
constructor
A new instance of StripeBalance.
Methods inherited from RequestParams
Constructor Details
#initialize(account: nil, source_type: nil) ⇒ StripeBalance
Returns a new instance of StripeBalance.
336 337 338 339 |
# File 'lib/stripe/services/test_helpers/confirmation_token_service.rb', line 336 def initialize(account: nil, source_type: nil) @account = account @source_type = source_type end |
Instance Attribute Details
#account ⇒ Object
The connected account ID whose Stripe balance to use as the source of payment
332 333 334 |
# File 'lib/stripe/services/test_helpers/confirmation_token_service.rb', line 332 def account @account end |
#source_type ⇒ Object
The [source_type](docs.stripe.com/api/balance/balance_object#balance_object-available-source_types) of the balance
334 335 336 |
# File 'lib/stripe/services/test_helpers/confirmation_token_service.rb', line 334 def source_type @source_type end |