Class: Stripe::TestHelpers::ConfirmationTokenService::CreateParams::PaymentMethodData::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::TestHelpers::ConfirmationTokenService::CreateParams::PaymentMethodData::UsBankAccount
- Defined in:
- lib/stripe/services/test_helpers/confirmation_token_service.rb
Instance Attribute Summary collapse
-
#account_holder_type ⇒ Object
Account holder type: individual or company.
-
#account_number ⇒ Object
Account number of the bank account.
-
#account_type ⇒ Object
Account type: checkings or savings.
-
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
-
#routing_number ⇒ Object
Routing number of the bank account.
Instance Method Summary collapse
-
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
356 357 358 359 360 361 362 363 364 365 366 367 368 |
# File 'lib/stripe/services/test_helpers/confirmation_token_service.rb', line 356 def initialize( account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil ) @account_holder_type = account_holder_type @account_number = account_number @account_type = account_type @financial_connections_account = financial_connections_account @routing_number = routing_number end |
Instance Attribute Details
#account_holder_type ⇒ Object
Account holder type: individual or company.
346 347 348 |
# File 'lib/stripe/services/test_helpers/confirmation_token_service.rb', line 346 def account_holder_type @account_holder_type end |
#account_number ⇒ Object
Account number of the bank account.
348 349 350 |
# File 'lib/stripe/services/test_helpers/confirmation_token_service.rb', line 348 def account_number @account_number end |
#account_type ⇒ Object
Account type: checkings or savings. Defaults to checking if omitted.
350 351 352 |
# File 'lib/stripe/services/test_helpers/confirmation_token_service.rb', line 350 def account_type @account_type end |
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
352 353 354 |
# File 'lib/stripe/services/test_helpers/confirmation_token_service.rb', line 352 def financial_connections_account @financial_connections_account end |
#routing_number ⇒ Object
Routing number of the bank account.
354 355 356 |
# File 'lib/stripe/services/test_helpers/confirmation_token_service.rb', line 354 def routing_number @routing_number end |