Class: Stripe::TestHelpers::ConfirmationTokenService::CreateParams::PaymentMethodOptions::Card::Installments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::TestHelpers::ConfirmationTokenService::CreateParams::PaymentMethodOptions::Card::Installments
- Defined in:
- lib/stripe/services/test_helpers/confirmation_token_service.rb
Defined Under Namespace
Classes: Plan
Instance Attribute Summary collapse
-
#plan ⇒ Object
The selected installment plan to use for this payment attempt.
Instance Method Summary collapse
-
#initialize(plan: nil) ⇒ Installments
constructor
A new instance of Installments.
Methods inherited from RequestParams
Constructor Details
#initialize(plan: nil) ⇒ Installments
Returns a new instance of Installments.
544 545 546 |
# File 'lib/stripe/services/test_helpers/confirmation_token_service.rb', line 544 def initialize(plan: nil) @plan = plan end |
Instance Attribute Details
#plan ⇒ Object
The selected installment plan to use for this payment attempt. This parameter can only be provided during confirmation.
542 543 544 |
# File 'lib/stripe/services/test_helpers/confirmation_token_service.rb', line 542 def plan @plan end |