Class: Stripe::TestHelpers::Issuing::AuthorizationCaptureParams::PurchaseDetails::Fleet::ReportedBreakdown::Tax

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/test_helpers/issuing/authorization_capture_params.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(local_amount_decimal: nil, national_amount_decimal: nil) ⇒ Tax

Returns a new instance of Tax.



70
71
72
73
# File 'lib/stripe/params/test_helpers/issuing/authorization_capture_params.rb', line 70

def initialize(local_amount_decimal: nil, national_amount_decimal: nil)
  @local_amount_decimal = local_amount_decimal
  @national_amount_decimal = national_amount_decimal
end

Instance Attribute Details

#local_amount_decimalObject

Amount of state or provincial Sales Tax included in the transaction amount. Null if not reported by merchant or not subject to tax.



66
67
68
# File 'lib/stripe/params/test_helpers/issuing/authorization_capture_params.rb', line 66

def local_amount_decimal
  @local_amount_decimal
end

#national_amount_decimalObject

Amount of national Sales Tax or VAT included in the transaction amount. Null if not reported by merchant or not subject to tax.



68
69
70
# File 'lib/stripe/params/test_helpers/issuing/authorization_capture_params.rb', line 68

def national_amount_decimal
  @national_amount_decimal
end

Class Method Details

.field_encodingsObject



75
76
77
78
79
80
# File 'lib/stripe/params/test_helpers/issuing/authorization_capture_params.rb', line 75

def self.field_encodings
  @field_encodings = {
    local_amount_decimal: :decimal_string,
    national_amount_decimal: :decimal_string,
  }
end