Class: Stripe::TestHelpers::Issuing::AuthorizationCreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/test_helpers/issuing/authorization_create_params.rb

Defined Under Namespace

Classes: AmountDetails, Fleet, Fuel, MerchantData, NetworkData, RiskAssessment, VerificationData

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(amount: nil, amount_details: nil, authorization_method: nil, card: nil, currency: nil, expand: nil, fleet: nil, fraud_disputability_likelihood: nil, fuel: nil, is_amount_controllable: nil, merchant_amount: nil, merchant_currency: nil, merchant_data: nil, network_data: nil, risk_assessment: nil, verification_data: nil, wallet: nil) ⇒ AuthorizationCreateParams

Returns a new instance of AuthorizationCreateParams.



389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
# File 'lib/stripe/params/test_helpers/issuing/authorization_create_params.rb', line 389

def initialize(
  amount: nil,
  amount_details: nil,
  authorization_method: nil,
  card: nil,
  currency: nil,
  expand: nil,
  fleet: nil,
  fraud_disputability_likelihood: nil,
  fuel: nil,
  is_amount_controllable: nil,
  merchant_amount: nil,
  merchant_currency: nil,
  merchant_data: nil,
  network_data: nil,
  risk_assessment: nil,
  verification_data: nil,
  wallet: nil
)
  @amount = amount
  @amount_details = amount_details
  @authorization_method = authorization_method
  @card = card
  @currency = currency
  @expand = expand
  @fleet = fleet
  @fraud_disputability_likelihood = fraud_disputability_likelihood
  @fuel = fuel
  @is_amount_controllable = is_amount_controllable
  @merchant_amount = merchant_amount
  @merchant_currency = merchant_currency
  @merchant_data = merchant_data
  @network_data = network_data
  @risk_assessment = risk_assessment
  @verification_data = verification_data
  @wallet = wallet
end

Instance Attribute Details

#amountObject

The total amount to attempt to authorize. This amount is in the provided currency, or defaults to the card’s currency, and in the [smallest currency unit](docs.stripe.com/currencies#zero-decimal).



355
356
357
# File 'lib/stripe/params/test_helpers/issuing/authorization_create_params.rb', line 355

def amount
  @amount
end

#amount_detailsObject

Detailed breakdown of amount components. These amounts are denominated in currency and in the [smallest currency unit](docs.stripe.com/currencies#zero-decimal).



357
358
359
# File 'lib/stripe/params/test_helpers/issuing/authorization_create_params.rb', line 357

def amount_details
  @amount_details
end

#authorization_methodObject

How the card details were provided. Defaults to online.



359
360
361
# File 'lib/stripe/params/test_helpers/issuing/authorization_create_params.rb', line 359

def authorization_method
  @authorization_method
end

#cardObject

Card associated with this authorization.



361
362
363
# File 'lib/stripe/params/test_helpers/issuing/authorization_create_params.rb', line 361

def card
  @card
end

#currencyObject

The currency of the authorization. If not provided, defaults to the currency of the card. Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



363
364
365
# File 'lib/stripe/params/test_helpers/issuing/authorization_create_params.rb', line 363

def currency
  @currency
end

#expandObject

Specifies which fields in the response should be expanded.



365
366
367
# File 'lib/stripe/params/test_helpers/issuing/authorization_create_params.rb', line 365

def expand
  @expand
end

#fleetObject

Fleet-specific information for authorizations using Fleet cards.



367
368
369
# File 'lib/stripe/params/test_helpers/issuing/authorization_create_params.rb', line 367

def fleet
  @fleet
end

#fraud_disputability_likelihoodObject

Probability that this transaction can be disputed in the event of fraud. Assessed by comparing the characteristics of the authorization to card network rules.



369
370
371
# File 'lib/stripe/params/test_helpers/issuing/authorization_create_params.rb', line 369

def fraud_disputability_likelihood
  @fraud_disputability_likelihood
end

#fuelObject

Information about fuel that was purchased with this transaction.



371
372
373
# File 'lib/stripe/params/test_helpers/issuing/authorization_create_params.rb', line 371

def fuel
  @fuel
end

#is_amount_controllableObject

If set true, you may provide [amount](docs.stripe.com/api/issuing/authorizations/approve#approve_issuing_authorization-amount) to control how much to hold for the authorization.



373
374
375
# File 'lib/stripe/params/test_helpers/issuing/authorization_create_params.rb', line 373

def is_amount_controllable
  @is_amount_controllable
end

#merchant_amountObject

The total amount to attempt to authorize. This amount is in the provided merchant currency, and in the [smallest currency unit](docs.stripe.com/currencies#zero-decimal).



375
376
377
# File 'lib/stripe/params/test_helpers/issuing/authorization_create_params.rb', line 375

def merchant_amount
  @merchant_amount
end

#merchant_currencyObject

The currency of the authorization. If not provided, defaults to the currency of the card. Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



377
378
379
# File 'lib/stripe/params/test_helpers/issuing/authorization_create_params.rb', line 377

def merchant_currency
  @merchant_currency
end

#merchant_dataObject

Details about the seller (grocery store, e-commerce website, etc.) where the card authorization happened.



379
380
381
# File 'lib/stripe/params/test_helpers/issuing/authorization_create_params.rb', line 379

def merchant_data
  @merchant_data
end

#network_dataObject

Details about the authorization, such as identifiers, set by the card network.



381
382
383
# File 'lib/stripe/params/test_helpers/issuing/authorization_create_params.rb', line 381

def network_data
  @network_data
end

#risk_assessmentObject

Stripe’s assessment of the fraud risk for this authorization.



383
384
385
# File 'lib/stripe/params/test_helpers/issuing/authorization_create_params.rb', line 383

def risk_assessment
  @risk_assessment
end

#verification_dataObject

Verifications that Stripe performed on information that the cardholder provided to the merchant.



385
386
387
# File 'lib/stripe/params/test_helpers/issuing/authorization_create_params.rb', line 385

def verification_data
  @verification_data
end

#walletObject

The digital wallet used for this transaction. One of apple_pay, google_pay, or samsung_pay. Will populate as null when no digital wallet was utilized.



387
388
389
# File 'lib/stripe/params/test_helpers/issuing/authorization_create_params.rb', line 387

def wallet
  @wallet
end

Class Method Details

.field_encodingsObject



427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
# File 'lib/stripe/params/test_helpers/issuing/authorization_create_params.rb', line 427

def self.field_encodings
  @field_encodings = {
    fleet: {
      kind: :object,
      fields: {
        reported_breakdown: {
          kind: :object,
          fields: {
            fuel: { kind: :object, fields: { gross_amount_decimal: :decimal_string } },
            non_fuel: { kind: :object, fields: { gross_amount_decimal: :decimal_string } },
            tax: {
              kind: :object,
              fields: {
                local_amount_decimal: :decimal_string,
                national_amount_decimal: :decimal_string,
              },
            },
          },
        },
      },
    },
    fuel: {
      kind: :object,
      fields: { quantity_decimal: :decimal_string, unit_cost_decimal: :decimal_string },
    },
  }
end