Class: Stripe::TestHelpers::Issuing::AuthorizationCreateParams::Fleet::ReportedBreakdown::Tax

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/test_helpers/issuing/authorization_create_params.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(local_amount_decimal: nil, national_amount_decimal: nil) ⇒ Tax

Returns a new instance of Tax.



81
82
83
84
# File 'lib/stripe/params/test_helpers/issuing/authorization_create_params.rb', line 81

def initialize(local_amount_decimal: nil, national_amount_decimal: nil)
  @local_amount_decimal = local_amount_decimal
  @national_amount_decimal = national_amount_decimal
end

Instance Attribute Details

#local_amount_decimalObject

Amount of state or provincial Sales Tax included in the transaction amount. Null if not reported by merchant or not subject to tax.



77
78
79
# File 'lib/stripe/params/test_helpers/issuing/authorization_create_params.rb', line 77

def local_amount_decimal
  @local_amount_decimal
end

#national_amount_decimalObject

Amount of national Sales Tax or VAT included in the transaction amount. Null if not reported by merchant or not subject to tax.



79
80
81
# File 'lib/stripe/params/test_helpers/issuing/authorization_create_params.rb', line 79

def national_amount_decimal
  @national_amount_decimal
end

Class Method Details

.field_encodingsObject



86
87
88
89
90
91
# File 'lib/stripe/params/test_helpers/issuing/authorization_create_params.rb', line 86

def self.field_encodings
  @field_encodings = {
    local_amount_decimal: :decimal_string,
    national_amount_decimal: :decimal_string,
  }
end