Class: Stripe::TestHelpers::Issuing::AuthorizationCreateParams::MerchantData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/test_helpers/issuing/authorization_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(category: nil, city: nil, country: nil, name: nil, network_id: nil, payment_facilitator_id: nil, postal_code: nil, state: nil, sub_merchant_id: nil, terminal_id: nil, url: nil) ⇒ MerchantData

Returns a new instance of MerchantData.



258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
# File 'lib/stripe/params/test_helpers/issuing/authorization_create_params.rb', line 258

def initialize(
  category: nil,
  city: nil,
  country: nil,
  name: nil,
  network_id: nil,
  payment_facilitator_id: nil,
  postal_code: nil,
  state: nil,
  sub_merchant_id: nil,
  terminal_id: nil,
  url: nil
)
  @category = category
  @city = city
  @country = country
  @name = name
  @network_id = network_id
  @payment_facilitator_id = payment_facilitator_id
  @postal_code = postal_code
  @state = state
  @sub_merchant_id = sub_merchant_id
  @terminal_id = terminal_id
  @url = url
end

Instance Attribute Details

#categoryObject

A categorization of the seller's type of business. See our merchant categories guide for a list of possible values.



236
237
238
# File 'lib/stripe/params/test_helpers/issuing/authorization_create_params.rb', line 236

def category
  @category
end

#cityObject

City where the seller is located



238
239
240
# File 'lib/stripe/params/test_helpers/issuing/authorization_create_params.rb', line 238

def city
  @city
end

#countryObject

Country where the seller is located



240
241
242
# File 'lib/stripe/params/test_helpers/issuing/authorization_create_params.rb', line 240

def country
  @country
end

#nameObject

Name of the seller



242
243
244
# File 'lib/stripe/params/test_helpers/issuing/authorization_create_params.rb', line 242

def name
  @name
end

#network_idObject

Identifier assigned to the seller by the card network. Different card networks may assign different network_id fields to the same merchant.



244
245
246
# File 'lib/stripe/params/test_helpers/issuing/authorization_create_params.rb', line 244

def network_id
  @network_id
end

#payment_facilitator_idObject

The identifier of the payment facilitator (PayFac) that processed this authorization, as assigned by the card network.



246
247
248
# File 'lib/stripe/params/test_helpers/issuing/authorization_create_params.rb', line 246

def payment_facilitator_id
  @payment_facilitator_id
end

#postal_codeObject

Postal code where the seller is located



248
249
250
# File 'lib/stripe/params/test_helpers/issuing/authorization_create_params.rb', line 248

def postal_code
  @postal_code
end

#stateObject

State where the seller is located



250
251
252
# File 'lib/stripe/params/test_helpers/issuing/authorization_create_params.rb', line 250

def state
  @state
end

#sub_merchant_idObject

The identifier of the sub-merchant involved in this authorization, as assigned by the payment facilitator.



252
253
254
# File 'lib/stripe/params/test_helpers/issuing/authorization_create_params.rb', line 252

def sub_merchant_id
  @sub_merchant_id
end

#terminal_idObject

An ID assigned by the seller to the location of the sale.



254
255
256
# File 'lib/stripe/params/test_helpers/issuing/authorization_create_params.rb', line 254

def terminal_id
  @terminal_id
end

#urlObject

URL provided by the merchant on a 3DS request



256
257
258
# File 'lib/stripe/params/test_helpers/issuing/authorization_create_params.rb', line 256

def url
  @url
end