Class: Stripe::TestHelpers::Issuing::AuthorizationCreateParams::RiskAssessment::CardTestingRisk
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::TestHelpers::Issuing::AuthorizationCreateParams::RiskAssessment::CardTestingRisk
- Defined in:
- lib/stripe/params/test_helpers/issuing/authorization_create_params.rb
Instance Attribute Summary collapse
-
#invalid_account_number_decline_rate_past_hour ⇒ Object
The % of declines due to a card number not existing in the past hour, taking place at the same merchant.
-
#invalid_credentials_decline_rate_past_hour ⇒ Object
The % of declines due to incorrect verification data (like CVV or expiry) in the past hour, taking place at the same merchant.
-
#level ⇒ Object
The likelihood that this authorization is associated with card testing activity.
Instance Method Summary collapse
-
#initialize(invalid_account_number_decline_rate_past_hour: nil, invalid_credentials_decline_rate_past_hour: nil, level: nil) ⇒ CardTestingRisk
constructor
A new instance of CardTestingRisk.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(invalid_account_number_decline_rate_past_hour: nil, invalid_credentials_decline_rate_past_hour: nil, level: nil) ⇒ CardTestingRisk
256 257 258 259 260 261 262 263 264 |
# File 'lib/stripe/params/test_helpers/issuing/authorization_create_params.rb', line 256 def initialize( invalid_account_number_decline_rate_past_hour: nil, invalid_credentials_decline_rate_past_hour: nil, level: nil ) @invalid_account_number_decline_rate_past_hour = invalid_account_number_decline_rate_past_hour @invalid_credentials_decline_rate_past_hour = invalid_credentials_decline_rate_past_hour @level = level end |
Instance Attribute Details
#invalid_account_number_decline_rate_past_hour ⇒ Object
The % of declines due to a card number not existing in the past hour, taking place at the same merchant. Higher rates correspond to a greater probability of card testing activity, meaning bad actors may be attempting different card number combinations to guess a correct one. Takes on values between 0 and 100.
250 251 252 |
# File 'lib/stripe/params/test_helpers/issuing/authorization_create_params.rb', line 250 def invalid_account_number_decline_rate_past_hour @invalid_account_number_decline_rate_past_hour end |
#invalid_credentials_decline_rate_past_hour ⇒ Object
The % of declines due to incorrect verification data (like CVV or expiry) in the past hour, taking place at the same merchant. Higher rates correspond to a greater probability of bad actors attempting to utilize valid card credentials at merchants with verification requirements. Takes on values between 0 and 100.
252 253 254 |
# File 'lib/stripe/params/test_helpers/issuing/authorization_create_params.rb', line 252 def invalid_credentials_decline_rate_past_hour @invalid_credentials_decline_rate_past_hour end |
#level ⇒ Object
The likelihood that this authorization is associated with card testing activity. This is assessed by evaluating decline activity over the last hour.
254 255 256 |
# File 'lib/stripe/params/test_helpers/issuing/authorization_create_params.rb', line 254 def level @level end |