Class: Stripe::TestHelpers::Issuing::AuthorizationCreateParams::RiskAssessment::MerchantDisputeRisk
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::TestHelpers::Issuing::AuthorizationCreateParams::RiskAssessment::MerchantDisputeRisk
- Defined in:
- lib/stripe/params/test_helpers/issuing/authorization_create_params.rb
Instance Attribute Summary collapse
-
#dispute_rate ⇒ Object
The dispute rate observed across all Stripe Issuing authorizations for this merchant.
-
#level ⇒ Object
The likelihood that authorizations from this merchant will result in a dispute based on their history on Stripe Issuing.
Instance Method Summary collapse
-
#initialize(dispute_rate: nil, level: nil) ⇒ MerchantDisputeRisk
constructor
A new instance of MerchantDisputeRisk.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(dispute_rate: nil, level: nil) ⇒ MerchantDisputeRisk
Returns a new instance of MerchantDisputeRisk.
285 286 287 288 |
# File 'lib/stripe/params/test_helpers/issuing/authorization_create_params.rb', line 285 def initialize(dispute_rate: nil, level: nil) @dispute_rate = dispute_rate @level = level end |
Instance Attribute Details
#dispute_rate ⇒ Object
The dispute rate observed across all Stripe Issuing authorizations for this merchant. For example, a value of 50 means 50% of authorizations from this merchant on Stripe Issuing have resulted in a dispute. Higher values mean a higher likelihood the authorization is disputed. Takes on values between 0 and 100.
281 282 283 |
# File 'lib/stripe/params/test_helpers/issuing/authorization_create_params.rb', line 281 def dispute_rate @dispute_rate end |
#level ⇒ Object
The likelihood that authorizations from this merchant will result in a dispute based on their history on Stripe Issuing.
283 284 285 |
# File 'lib/stripe/params/test_helpers/issuing/authorization_create_params.rb', line 283 def level @level end |