Class: Stripe::TestHelpers::Issuing::AuthorizationCreateParams::VerificationData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/test_helpers/issuing/authorization_create_params.rb

Defined Under Namespace

Classes: AuthenticationExemption, ThreeDSecure

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(address_line1_check: nil, address_postal_code_check: nil, authentication_exemption: nil, cvc_check: nil, expiry_check: nil, three_d_secure: nil) ⇒ VerificationData

Returns a new instance of VerificationData.



385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
# File 'lib/stripe/params/test_helpers/issuing/authorization_create_params.rb', line 385

def initialize(
  address_line1_check: nil,
  address_postal_code_check: nil,
  authentication_exemption: nil,
  cvc_check: nil,
  expiry_check: nil,
  three_d_secure: nil
)
  @address_line1_check = address_line1_check
  @address_postal_code_check = address_postal_code_check
  @authentication_exemption = authentication_exemption
  @cvc_check = cvc_check
  @expiry_check = expiry_check
  @three_d_secure = three_d_secure
end

Instance Attribute Details

#address_line1_checkObject

Whether the cardholder provided an address first line and if it matched the cardholder’s billing.address.line1.



373
374
375
# File 'lib/stripe/params/test_helpers/issuing/authorization_create_params.rb', line 373

def address_line1_check
  @address_line1_check
end

#address_postal_code_checkObject

Whether the cardholder provided a postal code and if it matched the cardholder’s billing.address.postal_code.



375
376
377
# File 'lib/stripe/params/test_helpers/issuing/authorization_create_params.rb', line 375

def address_postal_code_check
  @address_postal_code_check
end

#authentication_exemptionObject

The exemption applied to this authorization.



377
378
379
# File 'lib/stripe/params/test_helpers/issuing/authorization_create_params.rb', line 377

def authentication_exemption
  @authentication_exemption
end

#cvc_checkObject

Whether the cardholder provided a CVC and if it matched Stripe’s record.



379
380
381
# File 'lib/stripe/params/test_helpers/issuing/authorization_create_params.rb', line 379

def cvc_check
  @cvc_check
end

#expiry_checkObject

Whether the cardholder provided an expiry date and if it matched Stripe’s record.



381
382
383
# File 'lib/stripe/params/test_helpers/issuing/authorization_create_params.rb', line 381

def expiry_check
  @expiry_check
end

#three_d_secureObject

3D Secure details.



383
384
385
# File 'lib/stripe/params/test_helpers/issuing/authorization_create_params.rb', line 383

def three_d_secure
  @three_d_secure
end