Class: Stripe::TestHelpers::Issuing::AuthorizationFinalizeAmountParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::TestHelpers::Issuing::AuthorizationFinalizeAmountParams
- Defined in:
- lib/stripe/params/test_helpers/issuing/authorization_finalize_amount_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#final_amount ⇒ Object
The final authorization amount that will be captured by the merchant.
-
#fleet ⇒ Object
Fleet-specific information for authorizations using Fleet cards.
-
#fuel ⇒ Object
Information about fuel that was purchased with this transaction.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(expand: nil, final_amount: nil, fleet: nil, fuel: nil) ⇒ AuthorizationFinalizeAmountParams
constructor
A new instance of AuthorizationFinalizeAmountParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(expand: nil, final_amount: nil, fleet: nil, fuel: nil) ⇒ AuthorizationFinalizeAmountParams
Returns a new instance of AuthorizationFinalizeAmountParams.
191 192 193 194 195 196 |
# File 'lib/stripe/params/test_helpers/issuing/authorization_finalize_amount_params.rb', line 191 def initialize(expand: nil, final_amount: nil, fleet: nil, fuel: nil) @expand = @final_amount = final_amount @fleet = fleet @fuel = fuel end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
183 184 185 |
# File 'lib/stripe/params/test_helpers/issuing/authorization_finalize_amount_params.rb', line 183 def @expand end |
#final_amount ⇒ Object
The final authorization amount that will be captured by the merchant. This amount is in the authorization currency and in the [smallest currency unit](docs.stripe.com/currencies#zero-decimal).
185 186 187 |
# File 'lib/stripe/params/test_helpers/issuing/authorization_finalize_amount_params.rb', line 185 def final_amount @final_amount end |
#fleet ⇒ Object
Fleet-specific information for authorizations using Fleet cards.
187 188 189 |
# File 'lib/stripe/params/test_helpers/issuing/authorization_finalize_amount_params.rb', line 187 def fleet @fleet end |
#fuel ⇒ Object
Information about fuel that was purchased with this transaction.
189 190 191 |
# File 'lib/stripe/params/test_helpers/issuing/authorization_finalize_amount_params.rb', line 189 def fuel @fuel end |
Class Method Details
.field_encodings ⇒ Object
198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/stripe/params/test_helpers/issuing/authorization_finalize_amount_params.rb', line 198 def self.field_encodings @field_encodings = { fleet: { kind: :object, fields: { reported_breakdown: { kind: :object, fields: { fuel: { kind: :object, fields: { gross_amount_decimal: :decimal_string } }, non_fuel: { kind: :object, fields: { gross_amount_decimal: :decimal_string } }, tax: { kind: :object, fields: { local_amount_decimal: :decimal_string, national_amount_decimal: :decimal_string, }, }, }, }, }, }, fuel: { kind: :object, fields: { quantity_decimal: :decimal_string, unit_cost_decimal: :decimal_string }, }, } end |