Class: Stripe::TestHelpers::Issuing::AuthorizationService::CaptureParams::PurchaseDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/test_helpers/issuing/authorization_service.rb

Defined Under Namespace

Classes: Fleet, Flight, Fuel, Lodging, Receipt

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(fleet: nil, flight: nil, fuel: nil, lodging: nil, receipt: nil, reference: nil) ⇒ PurchaseDetails

Returns a new instance of PurchaseDetails.



605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 605

def initialize(
  fleet: nil,
  flight: nil,
  fuel: nil,
  lodging: nil,
  receipt: nil,
  reference: nil
)
  @fleet = fleet
  @flight = flight
  @fuel = fuel
  @lodging = lodging
  @receipt = receipt
  @reference = reference
end

Instance Attribute Details

#fleetObject

Fleet-specific information for transactions using Fleet cards.



588
589
590
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 588

def fleet
  @fleet
end

#flightObject

Information about the flight that was purchased with this transaction.



591
592
593
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 591

def flight
  @flight
end

#fuelObject

Information about fuel that was purchased with this transaction.



594
595
596
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 594

def fuel
  @fuel
end

#lodgingObject

Information about lodging that was purchased with this transaction.



597
598
599
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 597

def lodging
  @lodging
end

#receiptObject

The line items in the purchase.



600
601
602
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 600

def receipt
  @receipt
end

#referenceObject

A merchant-specific order number.



603
604
605
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 603

def reference
  @reference
end