Class: Stripe::TestHelpers::Issuing::AuthorizationService::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/test_helpers/issuing/authorization_service.rb

Defined Under Namespace

Classes: AmountDetails, Fleet, Fuel, MerchantData, NetworkData, VerificationData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, amount_details: nil, authorization_method: nil, card: nil, currency: nil, expand: nil, fleet: nil, fuel: nil, is_amount_controllable: nil, merchant_amount: nil, merchant_currency: nil, merchant_data: nil, network_data: nil, verification_data: nil, wallet: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 317

def initialize(
  amount: nil,
  amount_details: nil,
  authorization_method: nil,
  card: nil,
  currency: nil,
  expand: nil,
  fleet: nil,
  fuel: nil,
  is_amount_controllable: nil,
  merchant_amount: nil,
  merchant_currency: nil,
  merchant_data: nil,
  network_data: nil,
  verification_data: nil,
  wallet: nil
)
  @amount = amount
  @amount_details = amount_details
  @authorization_method = authorization_method
  @card = card
  @currency = currency
  @expand = expand
  @fleet = fleet
  @fuel = fuel
  @is_amount_controllable = is_amount_controllable
  @merchant_amount = merchant_amount
  @merchant_currency = merchant_currency
  @merchant_data = merchant_data
  @network_data = network_data
  @verification_data = verification_data
  @wallet = wallet
end

Instance Attribute Details

#amountObject

The total amount to attempt to authorize. This amount is in the provided currency, or defaults to the card’s currency, and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).



273
274
275
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 273

def amount
  @amount
end

#amount_detailsObject

Detailed breakdown of amount components. These amounts are denominated in ‘currency` and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).



276
277
278
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 276

def amount_details
  @amount_details
end

#authorization_methodObject

How the card details were provided. Defaults to online.



279
280
281
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 279

def authorization_method
  @authorization_method
end

#cardObject

Card associated with this authorization.



282
283
284
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 282

def card
  @card
end

#currencyObject

The currency of the authorization. If not provided, defaults to the currency of the card. Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



285
286
287
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 285

def currency
  @currency
end

#expandObject

Specifies which fields in the response should be expanded.



288
289
290
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 288

def expand
  @expand
end

#fleetObject

Fleet-specific information for authorizations using Fleet cards.



291
292
293
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 291

def fleet
  @fleet
end

#fuelObject

Information about fuel that was purchased with this transaction.



294
295
296
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 294

def fuel
  @fuel
end

#is_amount_controllableObject

If set ‘true`, you may provide [amount](stripe.com/docs/api/issuing/authorizations/approve#approve_issuing_authorization-amount) to control how much to hold for the authorization.



297
298
299
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 297

def is_amount_controllable
  @is_amount_controllable
end

#merchant_amountObject

The total amount to attempt to authorize. This amount is in the provided merchant currency, and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).



300
301
302
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 300

def merchant_amount
  @merchant_amount
end

#merchant_currencyObject

The currency of the authorization. If not provided, defaults to the currency of the card. Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



303
304
305
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 303

def merchant_currency
  @merchant_currency
end

#merchant_dataObject

Details about the seller (grocery store, e-commerce website, etc.) where the card authorization happened.



306
307
308
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 306

def merchant_data
  @merchant_data
end

#network_dataObject

Details about the authorization, such as identifiers, set by the card network.



309
310
311
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 309

def network_data
  @network_data
end

#verification_dataObject

Verifications that Stripe performed on information that the cardholder provided to the merchant.



312
313
314
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 312

def verification_data
  @verification_data
end

#walletObject

The digital wallet used for this transaction. One of ‘apple_pay`, `google_pay`, or `samsung_pay`. Will populate as `null` when no digital wallet was utilized.



315
316
317
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 315

def wallet
  @wallet
end