Class: Stripe::TestHelpers::Issuing::AuthorizationService::CreateParams::Fleet::ReportedBreakdown::Tax
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::TestHelpers::Issuing::AuthorizationService::CreateParams::Fleet::ReportedBreakdown::Tax
- Defined in:
- lib/stripe/services/test_helpers/issuing/authorization_service.rb
Instance Attribute Summary collapse
-
#local_amount_decimal ⇒ Object
Amount of state or provincial Sales Tax included in the transaction amount.
-
#national_amount_decimal ⇒ Object
Amount of national Sales Tax or VAT included in the transaction amount.
Instance Method Summary collapse
-
#initialize(local_amount_decimal: nil, national_amount_decimal: nil) ⇒ Tax
constructor
A new instance of Tax.
Methods inherited from RequestParams
Constructor Details
#initialize(local_amount_decimal: nil, national_amount_decimal: nil) ⇒ Tax
Returns a new instance of Tax.
74 75 76 77 |
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 74 def initialize(local_amount_decimal: nil, national_amount_decimal: nil) @local_amount_decimal = local_amount_decimal @national_amount_decimal = national_amount_decimal end |
Instance Attribute Details
#local_amount_decimal ⇒ Object
Amount of state or provincial Sales Tax included in the transaction amount. Null if not reported by merchant or not subject to tax.
70 71 72 |
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 70 def local_amount_decimal @local_amount_decimal end |
#national_amount_decimal ⇒ Object
Amount of national Sales Tax or VAT included in the transaction amount. Null if not reported by merchant or not subject to tax.
72 73 74 |
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 72 def national_amount_decimal @national_amount_decimal end |