Class: Stripe::TestHelpers::Issuing::AuthorizationService::CreateParams::MerchantData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/test_helpers/issuing/authorization_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(category: nil, city: nil, country: nil, name: nil, network_id: nil, postal_code: nil, state: nil, terminal_id: nil, url: nil) ⇒ MerchantData

Returns a new instance of MerchantData.



184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 184

def initialize(
  category: nil,
  city: nil,
  country: nil,
  name: nil,
  network_id: nil,
  postal_code: nil,
  state: nil,
  terminal_id: nil,
  url: nil
)
  @category = category
  @city = city
  @country = country
  @name = name
  @network_id = network_id
  @postal_code = postal_code
  @state = state
  @terminal_id = terminal_id
  @url = url
end

Instance Attribute Details

#categoryObject

A categorization of the seller’s type of business. See our [merchant categories guide](stripe.com/docs/issuing/merchant-categories) for a list of possible values.



158
159
160
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 158

def category
  @category
end

#cityObject

City where the seller is located



161
162
163
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 161

def city
  @city
end

#countryObject

Country where the seller is located



164
165
166
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 164

def country
  @country
end

#nameObject

Name of the seller



167
168
169
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 167

def name
  @name
end

#network_idObject

Identifier assigned to the seller by the card network. Different card networks may assign different network_id fields to the same merchant.



170
171
172
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 170

def network_id
  @network_id
end

#postal_codeObject

Postal code where the seller is located



173
174
175
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 173

def postal_code
  @postal_code
end

#stateObject

State where the seller is located



176
177
178
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 176

def state
  @state
end

#terminal_idObject

An ID assigned by the seller to the location of the sale.



179
180
181
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 179

def terminal_id
  @terminal_id
end

#urlObject

URL provided by the merchant on a 3DS request



182
183
184
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 182

def url
  @url
end