Class: Stripe::TestHelpers::Issuing::AuthorizationService::CreateParams::VerificationData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::TestHelpers::Issuing::AuthorizationService::CreateParams::VerificationData
- Defined in:
- lib/stripe/services/test_helpers/issuing/authorization_service.rb
Defined Under Namespace
Classes: AuthenticationExemption, ThreeDSecure
Instance Attribute Summary collapse
-
#address_line1_check ⇒ Object
Whether the cardholder provided an address first line and if it matched the cardholder’s ‘billing.address.line1`.
-
#address_postal_code_check ⇒ Object
Whether the cardholder provided a postal code and if it matched the cardholder’s ‘billing.address.postal_code`.
-
#authentication_exemption ⇒ Object
The exemption applied to this authorization.
-
#cvc_check ⇒ Object
Whether the cardholder provided a CVC and if it matched Stripe’s record.
-
#expiry_check ⇒ Object
Whether the cardholder provided an expiry date and if it matched Stripe’s record.
-
#three_d_secure ⇒ Object
3D Secure details.
Instance Method Summary collapse
-
#initialize(address_line1_check: nil, address_postal_code_check: nil, authentication_exemption: nil, cvc_check: nil, expiry_check: nil, three_d_secure: nil) ⇒ VerificationData
constructor
A new instance of VerificationData.
Methods inherited from RequestParams
Constructor Details
#initialize(address_line1_check: nil, address_postal_code_check: nil, authentication_exemption: nil, cvc_check: nil, expiry_check: nil, three_d_secure: nil) ⇒ VerificationData
Returns a new instance of VerificationData.
256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 |
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 256 def initialize( address_line1_check: nil, address_postal_code_check: nil, authentication_exemption: nil, cvc_check: nil, expiry_check: nil, three_d_secure: nil ) @address_line1_check = address_line1_check @address_postal_code_check = address_postal_code_check @authentication_exemption = authentication_exemption @cvc_check = cvc_check @expiry_check = expiry_check @three_d_secure = three_d_secure end |
Instance Attribute Details
#address_line1_check ⇒ Object
Whether the cardholder provided an address first line and if it matched the cardholder’s ‘billing.address.line1`.
239 240 241 |
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 239 def address_line1_check @address_line1_check end |
#address_postal_code_check ⇒ Object
Whether the cardholder provided a postal code and if it matched the cardholder’s ‘billing.address.postal_code`.
242 243 244 |
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 242 def address_postal_code_check @address_postal_code_check end |
#authentication_exemption ⇒ Object
The exemption applied to this authorization.
245 246 247 |
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 245 def authentication_exemption @authentication_exemption end |
#cvc_check ⇒ Object
Whether the cardholder provided a CVC and if it matched Stripe’s record.
248 249 250 |
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 248 def cvc_check @cvc_check end |
#expiry_check ⇒ Object
Whether the cardholder provided an expiry date and if it matched Stripe’s record.
251 252 253 |
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 251 def expiry_check @expiry_check end |
#three_d_secure ⇒ Object
3D Secure details.
254 255 256 |
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 254 def three_d_secure @three_d_secure end |