Class: Stripe::TestHelpers::Issuing::AuthorizationService::ExpireParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::TestHelpers::Issuing::AuthorizationService::ExpireParams
- Defined in:
- lib/stripe/services/test_helpers/issuing/authorization_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ ExpireParams
constructor
A new instance of ExpireParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ ExpireParams
Returns a new instance of ExpireParams.
650 651 652 |
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 650 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
648 649 650 |
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 648 def @expand end |