Class: Stripe::TestHelpers::Issuing::AuthorizationService::FinalizeAmountParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/test_helpers/issuing/authorization_service.rb

Defined Under Namespace

Classes: Fleet, Fuel

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, final_amount: nil, fleet: nil, fuel: nil) ⇒ FinalizeAmountParams

Returns a new instance of FinalizeAmountParams.



706
707
708
709
710
711
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 706

def initialize(expand: nil, final_amount: nil, fleet: nil, fuel: nil)
  @expand = expand
  @final_amount = final_amount
  @fleet = fleet
  @fuel = fuel
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



698
699
700
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 698

def expand
  @expand
end

#final_amountObject

The final authorization amount that will be captured by the merchant. This amount is in the authorization currency and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).



700
701
702
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 700

def final_amount
  @final_amount
end

#fleetObject

Fleet-specific information for authorizations using Fleet cards.



702
703
704
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 702

def fleet
  @fleet
end

#fuelObject

Information about fuel that was purchased with this transaction.



704
705
706
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 704

def fuel
  @fuel
end