Class: Stripe::TestHelpers::Issuing::AuthorizationService::FinalizeAmountParams::Fleet

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/test_helpers/issuing/authorization_service.rb

Defined Under Namespace

Classes: CardholderPromptData, ReportedBreakdown

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(cardholder_prompt_data: nil, purchase_type: nil, reported_breakdown: nil, service_type: nil) ⇒ Fleet

Returns a new instance of Fleet.



658
659
660
661
662
663
664
665
666
667
668
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 658

def initialize(
  cardholder_prompt_data: nil,
  purchase_type: nil,
  reported_breakdown: nil,
  service_type: nil
)
  @cardholder_prompt_data = cardholder_prompt_data
  @purchase_type = purchase_type
  @reported_breakdown = reported_breakdown
  @service_type = service_type
end

Instance Attribute Details

#cardholder_prompt_dataObject

Answers to prompts presented to the cardholder at the point of sale. Prompted fields vary depending on the configuration of your physical fleet cards. Typical points of sale support only numeric entry.



650
651
652
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 650

def cardholder_prompt_data
  @cardholder_prompt_data
end

#purchase_typeObject

The type of purchase. One of ‘fuel_purchase`, `non_fuel_purchase`, or `fuel_and_non_fuel_purchase`.



652
653
654
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 652

def purchase_type
  @purchase_type
end

#reported_breakdownObject

More information about the total amount. This information is not guaranteed to be accurate as some merchants may provide unreliable data.



654
655
656
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 654

def reported_breakdown
  @reported_breakdown
end

#service_typeObject

The type of fuel service. One of ‘non_fuel_transaction`, `full_service`, or `self_service`.



656
657
658
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 656

def service_type
  @service_type
end