Class: Stripe::TestHelpers::Issuing::AuthorizationService::RespondParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::TestHelpers::Issuing::AuthorizationService::RespondParams
- Defined in:
- lib/stripe/services/test_helpers/issuing/authorization_service.rb
Instance Attribute Summary collapse
-
#confirmed ⇒ Object
Whether to simulate the user confirming that the transaction was legitimate (true) or telling Stripe that it was fraudulent (false).
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(confirmed: nil, expand: nil) ⇒ RespondParams
constructor
A new instance of RespondParams.
Methods inherited from RequestParams
Constructor Details
#initialize(confirmed: nil, expand: nil) ⇒ RespondParams
Returns a new instance of RespondParams.
720 721 722 723 |
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 720 def initialize(confirmed: nil, expand: nil) @confirmed = confirmed @expand = end |
Instance Attribute Details
#confirmed ⇒ Object
Whether to simulate the user confirming that the transaction was legitimate (true) or telling Stripe that it was fraudulent (false).
716 717 718 |
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 716 def confirmed @confirmed end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
718 719 720 |
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 718 def @expand end |