Class: Stripe::TestHelpers::Issuing::DisputeProvisionalCreditParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/test_helpers/issuing/dispute_provisional_credit_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(expand: nil, grant_deadline: nil, revocable_after: nil) ⇒ DisputeProvisionalCreditParams

Returns a new instance of DisputeProvisionalCreditParams.



15
16
17
18
19
# File 'lib/stripe/params/test_helpers/issuing/dispute_provisional_credit_params.rb', line 15

def initialize(expand: nil, grant_deadline: nil, revocable_after: nil)
  @expand = expand
  @grant_deadline = grant_deadline
  @revocable_after = revocable_after
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



9
10
11
# File 'lib/stripe/params/test_helpers/issuing/dispute_provisional_credit_params.rb', line 9

def expand
  @expand
end

#grant_deadlineObject

Override the deadline by which the platform must grant a provisional credit to the consumer.



11
12
13
# File 'lib/stripe/params/test_helpers/issuing/dispute_provisional_credit_params.rb', line 11

def grant_deadline
  @grant_deadline
end

#revocable_afterObject

Override the earliest time after which the platform may revoke the provisional credit.



13
14
15
# File 'lib/stripe/params/test_helpers/issuing/dispute_provisional_credit_params.rb', line 13

def revocable_after
  @revocable_after
end