Class: Stripe::TestHelpers::Issuing::TransactionCreateForceCaptureParams::PurchaseDetails::Fleet

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/test_helpers/issuing/transaction_create_force_capture_params.rb

Defined Under Namespace

Classes: CardholderPromptData, ReportedBreakdown

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(cardholder_prompt_data: nil, purchase_type: nil, reported_breakdown: nil, service_type: nil) ⇒ Fleet

Returns a new instance of Fleet.



161
162
163
164
165
166
167
168
169
170
171
# File 'lib/stripe/params/test_helpers/issuing/transaction_create_force_capture_params.rb', line 161

def initialize(
  cardholder_prompt_data: nil,
  purchase_type: nil,
  reported_breakdown: nil,
  service_type: nil
)
  @cardholder_prompt_data = cardholder_prompt_data
  @purchase_type = purchase_type
  @reported_breakdown = reported_breakdown
  @service_type = service_type
end

Instance Attribute Details

#cardholder_prompt_dataObject

Answers to prompts presented to the cardholder at the point of sale. Prompted fields vary depending on the configuration of your physical fleet cards. Typical points of sale support only numeric entry.



153
154
155
# File 'lib/stripe/params/test_helpers/issuing/transaction_create_force_capture_params.rb', line 153

def cardholder_prompt_data
  @cardholder_prompt_data
end

#purchase_typeObject

The type of purchase. One of fuel_purchase, non_fuel_purchase, or fuel_and_non_fuel_purchase.



155
156
157
# File 'lib/stripe/params/test_helpers/issuing/transaction_create_force_capture_params.rb', line 155

def purchase_type
  @purchase_type
end

#reported_breakdownObject

More information about the total amount. This information is not guaranteed to be accurate as some merchants may provide unreliable data.



157
158
159
# File 'lib/stripe/params/test_helpers/issuing/transaction_create_force_capture_params.rb', line 157

def reported_breakdown
  @reported_breakdown
end

#service_typeObject

The type of fuel service. One of non_fuel_transaction, full_service, or self_service.



159
160
161
# File 'lib/stripe/params/test_helpers/issuing/transaction_create_force_capture_params.rb', line 159

def service_type
  @service_type
end

Class Method Details

.field_encodingsObject



173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/stripe/params/test_helpers/issuing/transaction_create_force_capture_params.rb', line 173

def self.field_encodings
  @field_encodings = {
    reported_breakdown: {
      kind: :object,
      fields: {
        fuel: { kind: :object, fields: { gross_amount_decimal: :decimal_string } },
        non_fuel: { kind: :object, fields: { gross_amount_decimal: :decimal_string } },
        tax: {
          kind: :object,
          fields: {
            local_amount_decimal: :decimal_string,
            national_amount_decimal: :decimal_string,
          },
        },
      },
    },
  }
end