Class: Stripe::TestHelpers::Issuing::TransactionCreateUnlinkedRefundParams::PurchaseDetails::Fuel
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::TestHelpers::Issuing::TransactionCreateUnlinkedRefundParams::PurchaseDetails::Fuel
- Defined in:
- lib/stripe/params/test_helpers/issuing/transaction_create_unlinked_refund_params.rb
Instance Attribute Summary collapse
-
#industry_product_code ⇒ Object
[Conexxus Payment System Product Code](www.conexxus.org/conexxus-payment-system-product-codes) identifying the primary fuel product purchased.
-
#quantity_decimal ⇒ Object
The quantity of ‘unit`s of fuel that was dispensed, represented as a decimal string with at most 12 decimal places.
-
#type ⇒ Object
The type of fuel that was purchased.
-
#unit ⇒ Object
The units for ‘quantity_decimal`.
-
#unit_cost_decimal ⇒ Object
The cost in cents per each unit of fuel, represented as a decimal string with at most 12 decimal places.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(industry_product_code: nil, quantity_decimal: nil, type: nil, unit: nil, unit_cost_decimal: nil) ⇒ Fuel
constructor
A new instance of Fuel.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(industry_product_code: nil, quantity_decimal: nil, type: nil, unit: nil, unit_cost_decimal: nil) ⇒ Fuel
Returns a new instance of Fuel.
270 271 272 273 274 275 276 277 278 279 280 281 282 |
# File 'lib/stripe/params/test_helpers/issuing/transaction_create_unlinked_refund_params.rb', line 270 def initialize( industry_product_code: nil, quantity_decimal: nil, type: nil, unit: nil, unit_cost_decimal: nil ) @industry_product_code = industry_product_code @quantity_decimal = quantity_decimal @type = type @unit = unit @unit_cost_decimal = unit_cost_decimal end |
Instance Attribute Details
#industry_product_code ⇒ Object
[Conexxus Payment System Product Code](www.conexxus.org/conexxus-payment-system-product-codes) identifying the primary fuel product purchased.
260 261 262 |
# File 'lib/stripe/params/test_helpers/issuing/transaction_create_unlinked_refund_params.rb', line 260 def industry_product_code @industry_product_code end |
#quantity_decimal ⇒ Object
The quantity of ‘unit`s of fuel that was dispensed, represented as a decimal string with at most 12 decimal places.
262 263 264 |
# File 'lib/stripe/params/test_helpers/issuing/transaction_create_unlinked_refund_params.rb', line 262 def quantity_decimal @quantity_decimal end |
#type ⇒ Object
The type of fuel that was purchased. One of ‘diesel`, `unleaded_plus`, `unleaded_regular`, `unleaded_super`, or `other`.
264 265 266 |
# File 'lib/stripe/params/test_helpers/issuing/transaction_create_unlinked_refund_params.rb', line 264 def type @type end |
#unit ⇒ Object
The units for ‘quantity_decimal`. One of `charging_minute`, `imperial_gallon`, `kilogram`, `kilowatt_hour`, `liter`, `pound`, `us_gallon`, or `other`.
266 267 268 |
# File 'lib/stripe/params/test_helpers/issuing/transaction_create_unlinked_refund_params.rb', line 266 def unit @unit end |
#unit_cost_decimal ⇒ Object
The cost in cents per each unit of fuel, represented as a decimal string with at most 12 decimal places.
268 269 270 |
# File 'lib/stripe/params/test_helpers/issuing/transaction_create_unlinked_refund_params.rb', line 268 def unit_cost_decimal @unit_cost_decimal end |
Class Method Details
.field_encodings ⇒ Object
284 285 286 287 288 289 |
# File 'lib/stripe/params/test_helpers/issuing/transaction_create_unlinked_refund_params.rb', line 284 def self.field_encodings @field_encodings = { quantity_decimal: :decimal_string, unit_cost_decimal: :decimal_string, } end |