Class: Stripe::TestHelpers::Issuing::TransactionService::CreateForceCaptureParams::MerchantData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/test_helpers/issuing/transaction_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(category: nil, city: nil, country: nil, name: nil, network_id: nil, postal_code: nil, state: nil, terminal_id: nil, url: nil) ⇒ MerchantData

Returns a new instance of MerchantData.



50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/stripe/services/test_helpers/issuing/transaction_service.rb', line 50

def initialize(
  category: nil,
  city: nil,
  country: nil,
  name: nil,
  network_id: nil,
  postal_code: nil,
  state: nil,
  terminal_id: nil,
  url: nil
)
  @category = category
  @city = city
  @country = country
  @name = name
  @network_id = network_id
  @postal_code = postal_code
  @state = state
  @terminal_id = terminal_id
  @url = url
end

Instance Attribute Details

#categoryObject

A categorization of the seller’s type of business. See our [merchant categories guide](stripe.com/docs/issuing/merchant-categories) for a list of possible values.



24
25
26
# File 'lib/stripe/services/test_helpers/issuing/transaction_service.rb', line 24

def category
  @category
end

#cityObject

City where the seller is located



27
28
29
# File 'lib/stripe/services/test_helpers/issuing/transaction_service.rb', line 27

def city
  @city
end

#countryObject

Country where the seller is located



30
31
32
# File 'lib/stripe/services/test_helpers/issuing/transaction_service.rb', line 30

def country
  @country
end

#nameObject

Name of the seller



33
34
35
# File 'lib/stripe/services/test_helpers/issuing/transaction_service.rb', line 33

def name
  @name
end

#network_idObject

Identifier assigned to the seller by the card network. Different card networks may assign different network_id fields to the same merchant.



36
37
38
# File 'lib/stripe/services/test_helpers/issuing/transaction_service.rb', line 36

def network_id
  @network_id
end

#postal_codeObject

Postal code where the seller is located



39
40
41
# File 'lib/stripe/services/test_helpers/issuing/transaction_service.rb', line 39

def postal_code
  @postal_code
end

#stateObject

State where the seller is located



42
43
44
# File 'lib/stripe/services/test_helpers/issuing/transaction_service.rb', line 42

def state
  @state
end

#terminal_idObject

An ID assigned by the seller to the location of the sale.



45
46
47
# File 'lib/stripe/services/test_helpers/issuing/transaction_service.rb', line 45

def terminal_id
  @terminal_id
end

#urlObject

URL provided by the merchant on a 3DS request



48
49
50
# File 'lib/stripe/services/test_helpers/issuing/transaction_service.rb', line 48

def url
  @url
end