Class: Stripe::TestHelpers::Issuing::TransactionService::CreateForceCaptureParams::PurchaseDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/test_helpers/issuing/transaction_service.rb

Defined Under Namespace

Classes: Fleet, Flight, Fuel, Lodging, Receipt

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(fleet: nil, flight: nil, fuel: nil, lodging: nil, receipt: nil, reference: nil) ⇒ PurchaseDetails

Returns a new instance of PurchaseDetails.



325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
# File 'lib/stripe/services/test_helpers/issuing/transaction_service.rb', line 325

def initialize(
  fleet: nil,
  flight: nil,
  fuel: nil,
  lodging: nil,
  receipt: nil,
  reference: nil
)
  @fleet = fleet
  @flight = flight
  @fuel = fuel
  @lodging = lodging
  @receipt = receipt
  @reference = reference
end

Instance Attribute Details

#fleetObject

Fleet-specific information for transactions using Fleet cards.



308
309
310
# File 'lib/stripe/services/test_helpers/issuing/transaction_service.rb', line 308

def fleet
  @fleet
end

#flightObject

Information about the flight that was purchased with this transaction.



311
312
313
# File 'lib/stripe/services/test_helpers/issuing/transaction_service.rb', line 311

def flight
  @flight
end

#fuelObject

Information about fuel that was purchased with this transaction.



314
315
316
# File 'lib/stripe/services/test_helpers/issuing/transaction_service.rb', line 314

def fuel
  @fuel
end

#lodgingObject

Information about lodging that was purchased with this transaction.



317
318
319
# File 'lib/stripe/services/test_helpers/issuing/transaction_service.rb', line 317

def lodging
  @lodging
end

#receiptObject

The line items in the purchase.



320
321
322
# File 'lib/stripe/services/test_helpers/issuing/transaction_service.rb', line 320

def receipt
  @receipt
end

#referenceObject

A merchant-specific order number.



323
324
325
# File 'lib/stripe/services/test_helpers/issuing/transaction_service.rb', line 323

def reference
  @reference
end