Class: Stripe::TestHelpers::Issuing::TransactionService::CreateForceCaptureParams::PurchaseDetails::Fuel
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::TestHelpers::Issuing::TransactionService::CreateForceCaptureParams::PurchaseDetails::Fuel
- Defined in:
- lib/stripe/services/test_helpers/issuing/transaction_service.rb
Instance Attribute Summary collapse
-
#industry_product_code ⇒ Object
[Conexxus Payment System Product Code](www.conexxus.org/conexxus-payment-system-product-codes) identifying the primary fuel product purchased.
-
#quantity_decimal ⇒ Object
The quantity of ‘unit`s of fuel that was dispensed, represented as a decimal string with at most 12 decimal places.
-
#type ⇒ Object
The type of fuel that was purchased.
-
#unit ⇒ Object
The units for ‘quantity_decimal`.
-
#unit_cost_decimal ⇒ Object
The cost in cents per each unit of fuel, represented as a decimal string with at most 12 decimal places.
Instance Method Summary collapse
-
#initialize(industry_product_code: nil, quantity_decimal: nil, type: nil, unit: nil, unit_cost_decimal: nil) ⇒ Fuel
constructor
A new instance of Fuel.
Methods inherited from RequestParams
Constructor Details
#initialize(industry_product_code: nil, quantity_decimal: nil, type: nil, unit: nil, unit_cost_decimal: nil) ⇒ Fuel
Returns a new instance of Fuel.
259 260 261 262 263 264 265 266 267 268 269 270 271 |
# File 'lib/stripe/services/test_helpers/issuing/transaction_service.rb', line 259 def initialize( industry_product_code: nil, quantity_decimal: nil, type: nil, unit: nil, unit_cost_decimal: nil ) @industry_product_code = industry_product_code @quantity_decimal = quantity_decimal @type = type @unit = unit @unit_cost_decimal = unit_cost_decimal end |
Instance Attribute Details
#industry_product_code ⇒ Object
[Conexxus Payment System Product Code](www.conexxus.org/conexxus-payment-system-product-codes) identifying the primary fuel product purchased.
245 246 247 |
# File 'lib/stripe/services/test_helpers/issuing/transaction_service.rb', line 245 def industry_product_code @industry_product_code end |
#quantity_decimal ⇒ Object
The quantity of ‘unit`s of fuel that was dispensed, represented as a decimal string with at most 12 decimal places.
248 249 250 |
# File 'lib/stripe/services/test_helpers/issuing/transaction_service.rb', line 248 def quantity_decimal @quantity_decimal end |
#type ⇒ Object
The type of fuel that was purchased. One of ‘diesel`, `unleaded_plus`, `unleaded_regular`, `unleaded_super`, or `other`.
251 252 253 |
# File 'lib/stripe/services/test_helpers/issuing/transaction_service.rb', line 251 def type @type end |
#unit ⇒ Object
The units for ‘quantity_decimal`. One of `charging_minute`, `imperial_gallon`, `kilogram`, `kilowatt_hour`, `liter`, `pound`, `us_gallon`, or `other`.
254 255 256 |
# File 'lib/stripe/services/test_helpers/issuing/transaction_service.rb', line 254 def unit @unit end |
#unit_cost_decimal ⇒ Object
The cost in cents per each unit of fuel, represented as a decimal string with at most 12 decimal places.
257 258 259 |
# File 'lib/stripe/services/test_helpers/issuing/transaction_service.rb', line 257 def unit_cost_decimal @unit_cost_decimal end |