Class: Stripe::TestHelpers::Issuing::TransactionService::CreateUnlinkedRefundParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::TestHelpers::Issuing::TransactionService::CreateUnlinkedRefundParams
- Defined in:
- lib/stripe/services/test_helpers/issuing/transaction_service.rb
Defined Under Namespace
Classes: MerchantData, PurchaseDetails
Instance Attribute Summary collapse
-
#amount ⇒ Object
The total amount to attempt to refund.
-
#card ⇒ Object
Card associated with this unlinked refund transaction.
-
#currency ⇒ Object
The currency of the unlinked refund.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#merchant_data ⇒ Object
Details about the seller (grocery store, e-commerce website, etc.) where the card authorization happened.
-
#purchase_details ⇒ Object
Additional purchase information that is optionally provided by the merchant.
Instance Method Summary collapse
-
#initialize(amount: nil, card: nil, currency: nil, expand: nil, merchant_data: nil, purchase_details: nil) ⇒ CreateUnlinkedRefundParams
constructor
A new instance of CreateUnlinkedRefundParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, card: nil, currency: nil, expand: nil, merchant_data: nil, purchase_details: nil) ⇒ CreateUnlinkedRefundParams
Returns a new instance of CreateUnlinkedRefundParams.
714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 |
# File 'lib/stripe/services/test_helpers/issuing/transaction_service.rb', line 714 def initialize( amount: nil, card: nil, currency: nil, expand: nil, merchant_data: nil, purchase_details: nil ) @amount = amount @card = card @currency = currency @expand = @merchant_data = merchant_data @purchase_details = purchase_details end |
Instance Attribute Details
#amount ⇒ Object
The total amount to attempt to refund. This amount is in the provided currency, or defaults to the cards currency, and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).
697 698 699 |
# File 'lib/stripe/services/test_helpers/issuing/transaction_service.rb', line 697 def amount @amount end |
#card ⇒ Object
Card associated with this unlinked refund transaction.
700 701 702 |
# File 'lib/stripe/services/test_helpers/issuing/transaction_service.rb', line 700 def card @card end |
#currency ⇒ Object
The currency of the unlinked refund. If not provided, defaults to the currency of the card. Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
703 704 705 |
# File 'lib/stripe/services/test_helpers/issuing/transaction_service.rb', line 703 def currency @currency end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
706 707 708 |
# File 'lib/stripe/services/test_helpers/issuing/transaction_service.rb', line 706 def @expand end |
#merchant_data ⇒ Object
Details about the seller (grocery store, e-commerce website, etc.) where the card authorization happened.
709 710 711 |
# File 'lib/stripe/services/test_helpers/issuing/transaction_service.rb', line 709 def merchant_data @merchant_data end |
#purchase_details ⇒ Object
Additional purchase information that is optionally provided by the merchant.
712 713 714 |
# File 'lib/stripe/services/test_helpers/issuing/transaction_service.rb', line 712 def purchase_details @purchase_details end |