Class: Stripe::TestHelpers::Issuing::TransactionService::CreateUnlinkedRefundParams::MerchantData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::TestHelpers::Issuing::TransactionService::CreateUnlinkedRefundParams::MerchantData
- Defined in:
- lib/stripe/services/test_helpers/issuing/transaction_service.rb
Instance Attribute Summary collapse
-
#category ⇒ Object
A categorization of the seller’s type of business.
-
#city ⇒ Object
City where the seller is located.
-
#country ⇒ Object
Country where the seller is located.
-
#name ⇒ Object
Name of the seller.
-
#network_id ⇒ Object
Identifier assigned to the seller by the card network.
-
#postal_code ⇒ Object
Postal code where the seller is located.
-
#state ⇒ Object
State where the seller is located.
-
#terminal_id ⇒ Object
An ID assigned by the seller to the location of the sale.
-
#url ⇒ Object
URL provided by the merchant on a 3DS request.
Instance Method Summary collapse
-
#initialize(category: nil, city: nil, country: nil, name: nil, network_id: nil, postal_code: nil, state: nil, terminal_id: nil, url: nil) ⇒ MerchantData
constructor
A new instance of MerchantData.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, city: nil, country: nil, name: nil, network_id: nil, postal_code: nil, state: nil, terminal_id: nil, url: nil) ⇒ MerchantData
Returns a new instance of MerchantData.
405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 |
# File 'lib/stripe/services/test_helpers/issuing/transaction_service.rb', line 405 def initialize( category: nil, city: nil, country: nil, name: nil, network_id: nil, postal_code: nil, state: nil, terminal_id: nil, url: nil ) @category = category @city = city @country = country @name = name @network_id = network_id @postal_code = postal_code @state = state @terminal_id = terminal_id @url = url end |
Instance Attribute Details
#category ⇒ Object
A categorization of the seller’s type of business. See our [merchant categories guide](stripe.com/docs/issuing/merchant-categories) for a list of possible values.
379 380 381 |
# File 'lib/stripe/services/test_helpers/issuing/transaction_service.rb', line 379 def category @category end |
#city ⇒ Object
City where the seller is located
382 383 384 |
# File 'lib/stripe/services/test_helpers/issuing/transaction_service.rb', line 382 def city @city end |
#country ⇒ Object
Country where the seller is located
385 386 387 |
# File 'lib/stripe/services/test_helpers/issuing/transaction_service.rb', line 385 def country @country end |
#name ⇒ Object
Name of the seller
388 389 390 |
# File 'lib/stripe/services/test_helpers/issuing/transaction_service.rb', line 388 def name @name end |
#network_id ⇒ Object
Identifier assigned to the seller by the card network. Different card networks may assign different network_id fields to the same merchant.
391 392 393 |
# File 'lib/stripe/services/test_helpers/issuing/transaction_service.rb', line 391 def network_id @network_id end |
#postal_code ⇒ Object
Postal code where the seller is located
394 395 396 |
# File 'lib/stripe/services/test_helpers/issuing/transaction_service.rb', line 394 def postal_code @postal_code end |
#state ⇒ Object
State where the seller is located
397 398 399 |
# File 'lib/stripe/services/test_helpers/issuing/transaction_service.rb', line 397 def state @state end |
#terminal_id ⇒ Object
An ID assigned by the seller to the location of the sale.
400 401 402 |
# File 'lib/stripe/services/test_helpers/issuing/transaction_service.rb', line 400 def terminal_id @terminal_id end |
#url ⇒ Object
URL provided by the merchant on a 3DS request
403 404 405 |
# File 'lib/stripe/services/test_helpers/issuing/transaction_service.rb', line 403 def url @url end |