Class: Stripe::TestHelpers::Issuing::TransactionService::CreateUnlinkedRefundParams::PurchaseDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/test_helpers/issuing/transaction_service.rb

Defined Under Namespace

Classes: Fleet, Flight, Fuel, Lodging, Receipt

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(fleet: nil, flight: nil, fuel: nil, lodging: nil, receipt: nil, reference: nil) ⇒ PurchaseDetails

Returns a new instance of PurchaseDetails.



680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
# File 'lib/stripe/services/test_helpers/issuing/transaction_service.rb', line 680

def initialize(
  fleet: nil,
  flight: nil,
  fuel: nil,
  lodging: nil,
  receipt: nil,
  reference: nil
)
  @fleet = fleet
  @flight = flight
  @fuel = fuel
  @lodging = lodging
  @receipt = receipt
  @reference = reference
end

Instance Attribute Details

#fleetObject

Fleet-specific information for transactions using Fleet cards.



663
664
665
# File 'lib/stripe/services/test_helpers/issuing/transaction_service.rb', line 663

def fleet
  @fleet
end

#flightObject

Information about the flight that was purchased with this transaction.



666
667
668
# File 'lib/stripe/services/test_helpers/issuing/transaction_service.rb', line 666

def flight
  @flight
end

#fuelObject

Information about fuel that was purchased with this transaction.



669
670
671
# File 'lib/stripe/services/test_helpers/issuing/transaction_service.rb', line 669

def fuel
  @fuel
end

#lodgingObject

Information about lodging that was purchased with this transaction.



672
673
674
# File 'lib/stripe/services/test_helpers/issuing/transaction_service.rb', line 672

def lodging
  @lodging
end

#receiptObject

The line items in the purchase.



675
676
677
# File 'lib/stripe/services/test_helpers/issuing/transaction_service.rb', line 675

def receipt
  @receipt
end

#referenceObject

A merchant-specific order number.



678
679
680
# File 'lib/stripe/services/test_helpers/issuing/transaction_service.rb', line 678

def reference
  @reference
end