Class: Stripe::TestHelpers::PaymentIntentSimulateCryptoDepositParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::TestHelpers::PaymentIntentSimulateCryptoDepositParams
- Defined in:
- lib/stripe/params/test_helpers/payment_intent_simulate_crypto_deposit_params.rb
Instance Attribute Summary collapse
-
#buyer_wallet ⇒ Object
The buyer’s wallet address from which the crypto deposit is originating.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#network ⇒ Object
The blockchain network of the simulated crypto deposit.
-
#token_currency ⇒ Object
The token currency of the simulated crypto deposit.
-
#transaction_hash ⇒ Object
A testmode transaction hash that determines the outcome of the simulated deposit.
Instance Method Summary collapse
-
#initialize(buyer_wallet: nil, expand: nil, network: nil, token_currency: nil, transaction_hash: nil) ⇒ PaymentIntentSimulateCryptoDepositParams
constructor
A new instance of PaymentIntentSimulateCryptoDepositParams.
Methods inherited from RequestParams
Constructor Details
#initialize(buyer_wallet: nil, expand: nil, network: nil, token_currency: nil, transaction_hash: nil) ⇒ PaymentIntentSimulateCryptoDepositParams
Returns a new instance of PaymentIntentSimulateCryptoDepositParams.
18 19 20 21 22 23 24 25 26 27 28 29 30 |
# File 'lib/stripe/params/test_helpers/payment_intent_simulate_crypto_deposit_params.rb', line 18 def initialize( buyer_wallet: nil, expand: nil, network: nil, token_currency: nil, transaction_hash: nil ) @buyer_wallet = buyer_wallet @expand = @network = network @token_currency = token_currency @transaction_hash = transaction_hash end |
Instance Attribute Details
#buyer_wallet ⇒ Object
The buyer’s wallet address from which the crypto deposit is originating.
8 9 10 |
# File 'lib/stripe/params/test_helpers/payment_intent_simulate_crypto_deposit_params.rb', line 8 def buyer_wallet @buyer_wallet end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
10 11 12 |
# File 'lib/stripe/params/test_helpers/payment_intent_simulate_crypto_deposit_params.rb', line 10 def @expand end |
#network ⇒ Object
The blockchain network of the simulated crypto deposit.
12 13 14 |
# File 'lib/stripe/params/test_helpers/payment_intent_simulate_crypto_deposit_params.rb', line 12 def network @network end |
#token_currency ⇒ Object
The token currency of the simulated crypto deposit.
14 15 16 |
# File 'lib/stripe/params/test_helpers/payment_intent_simulate_crypto_deposit_params.rb', line 14 def token_currency @token_currency end |
#transaction_hash ⇒ Object
A testmode transaction hash that determines the outcome of the simulated deposit.
16 17 18 |
# File 'lib/stripe/params/test_helpers/payment_intent_simulate_crypto_deposit_params.rb', line 16 def transaction_hash @transaction_hash end |