Class: Stripe::TestHelpers::SharedPayment::GrantedTokenCreateParams::UsageLimits

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/test_helpers/shared_payment/granted_token_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(currency: nil, expires_at: nil, max_amount: nil) ⇒ UsageLimits

Returns a new instance of UsageLimits.



16
17
18
19
20
# File 'lib/stripe/params/test_helpers/shared_payment/granted_token_create_params.rb', line 16

def initialize(currency: nil, expires_at: nil, max_amount: nil)
  @currency = currency
  @expires_at = expires_at
  @max_amount = max_amount
end

Instance Attribute Details

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



10
11
12
# File 'lib/stripe/params/test_helpers/shared_payment/granted_token_create_params.rb', line 10

def currency
  @currency
end

#expires_atObject

Time at which this SharedPaymentToken expires and can no longer be used to confirm a PaymentIntent.



12
13
14
# File 'lib/stripe/params/test_helpers/shared_payment/granted_token_create_params.rb', line 12

def expires_at
  @expires_at
end

#max_amountObject

Max amount that can be captured using this SharedPaymentToken



14
15
16
# File 'lib/stripe/params/test_helpers/shared_payment/granted_token_create_params.rb', line 14

def max_amount
  @max_amount
end