Class: Stripe::TestHelpers::TestClockAdvanceParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::TestHelpers::TestClockAdvanceParams
- Defined in:
- lib/stripe/params/test_helpers/test_clock_advance_params.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#frozen_time ⇒ Object
The time to advance the test clock.
Instance Method Summary collapse
-
#initialize(expand: nil, frozen_time: nil) ⇒ TestClockAdvanceParams
constructor
A new instance of TestClockAdvanceParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(expand: nil, frozen_time: nil) ⇒ TestClockAdvanceParams
Returns a new instance of TestClockAdvanceParams.
12 13 14 15 |
# File 'lib/stripe/params/test_helpers/test_clock_advance_params.rb', line 12 def initialize(expand: nil, frozen_time: nil) @expand = @frozen_time = frozen_time end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
8 9 10 |
# File 'lib/stripe/params/test_helpers/test_clock_advance_params.rb', line 8 def @expand end |
#frozen_time ⇒ Object
The time to advance the test clock. Must be after the test clockâs current frozen time. Cannot be more than two intervals in the future from the shortest subscription in this test clock. If there are no subscriptions in this test clock, it cannot be more than two years in the future.
10 11 12 |
# File 'lib/stripe/params/test_helpers/test_clock_advance_params.rb', line 10 def frozen_time @frozen_time end |