Class: Stripe::TestHelpers::Treasury::InboundTransferService::FailParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::TestHelpers::Treasury::InboundTransferService::FailParams
- Defined in:
- lib/stripe/services/test_helpers/treasury/inbound_transfer_service.rb
Defined Under Namespace
Classes: FailureDetails
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#failure_details ⇒ Object
Details about a failed InboundTransfer.
Instance Method Summary collapse
-
#initialize(expand: nil, failure_details: nil) ⇒ FailParams
constructor
A new instance of FailParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, failure_details: nil) ⇒ FailParams
Returns a new instance of FailParams.
22 23 24 25 |
# File 'lib/stripe/services/test_helpers/treasury/inbound_transfer_service.rb', line 22 def initialize(expand: nil, failure_details: nil) @expand = @failure_details = failure_details end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
18 19 20 |
# File 'lib/stripe/services/test_helpers/treasury/inbound_transfer_service.rb', line 18 def @expand end |
#failure_details ⇒ Object
Details about a failed InboundTransfer.
20 21 22 |
# File 'lib/stripe/services/test_helpers/treasury/inbound_transfer_service.rb', line 20 def failure_details @failure_details end |