Class: Stripe::TestHelpers::Treasury::OutboundTransferService::FailParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::TestHelpers::Treasury::OutboundTransferService::FailParams
- Defined in:
- lib/stripe/services/test_helpers/treasury/outbound_transfer_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ FailParams
constructor
A new instance of FailParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ FailParams
Returns a new instance of FailParams.
66 67 68 |
# File 'lib/stripe/services/test_helpers/treasury/outbound_transfer_service.rb', line 66 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
64 65 66 |
# File 'lib/stripe/services/test_helpers/treasury/outbound_transfer_service.rb', line 64 def @expand end |