Class: Stripe::TestHelpers::Treasury::ReceivedDebitService::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/test_helpers/treasury/received_debit_service.rb

Defined Under Namespace

Classes: InitiatingPaymentMethodDetails, NetworkDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, currency: nil, description: nil, expand: nil, financial_account: nil, initiating_payment_method_details: nil, network: nil, network_details: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/stripe/services/test_helpers/treasury/received_debit_service.rb', line 82

def initialize(
  amount: nil,
  currency: nil,
  description: nil,
  expand: nil,
  financial_account: nil,
  initiating_payment_method_details: nil,
  network: nil,
  network_details: nil
)
  @amount = amount
  @currency = currency
  @description = description
  @expand = expand
  @financial_account = 
  @initiating_payment_method_details = initiating_payment_method_details
  @network = network
  @network_details = network_details
end

Instance Attribute Details

#amountObject

Amount (in cents) to be transferred.



59
60
61
# File 'lib/stripe/services/test_helpers/treasury/received_debit_service.rb', line 59

def amount
  @amount
end

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



62
63
64
# File 'lib/stripe/services/test_helpers/treasury/received_debit_service.rb', line 62

def currency
  @currency
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



65
66
67
# File 'lib/stripe/services/test_helpers/treasury/received_debit_service.rb', line 65

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



68
69
70
# File 'lib/stripe/services/test_helpers/treasury/received_debit_service.rb', line 68

def expand
  @expand
end

#financial_accountObject

The FinancialAccount to pull funds from.



71
72
73
# File 'lib/stripe/services/test_helpers/treasury/received_debit_service.rb', line 71

def 
  @financial_account
end

#initiating_payment_method_detailsObject

Initiating payment method details for the object.



74
75
76
# File 'lib/stripe/services/test_helpers/treasury/received_debit_service.rb', line 74

def initiating_payment_method_details
  @initiating_payment_method_details
end

#networkObject

Specifies the network rails to be used. If not set, will default to the PaymentMethod’s preferred network. See the [docs](stripe.com/docs/treasury/money-movement/timelines) to learn more about money movement timelines for each network type.



77
78
79
# File 'lib/stripe/services/test_helpers/treasury/received_debit_service.rb', line 77

def network
  @network
end

#network_detailsObject

Details about the network used for the ReceivedDebit.



80
81
82
# File 'lib/stripe/services/test_helpers/treasury/received_debit_service.rb', line 80

def network_details
  @network_details
end