Class: Stripe::ThreeDSecure::Authentication::AcquirerDetails

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/three_d_secure/authentication.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#acquirer_bin ⇒ Object (readonly)

The Acquirer BIN (specific to the directory_server).



20
21
22
# File 'lib/stripe/resources/three_d_secure/authentication.rb', line 20

def acquirer_bin
  @acquirer_bin
end

#acquirer_country ⇒ Object (readonly)

The two-letter country code of the acquirer (ISO 3166-1 alpha-2).



22
23
24
# File 'lib/stripe/resources/three_d_secure/authentication.rb', line 22

def acquirer_country
  @acquirer_country
end

#acquirer_merchant_id ⇒ Object (readonly)

The Merchant ID (or Card Acceptor ID) that your acquirer assigned you (specific to the directory_server).



24
25
26
# File 'lib/stripe/resources/three_d_secure/authentication.rb', line 24

def acquirer_merchant_id
  @acquirer_merchant_id
end

#mcc ⇒ Object (readonly)

The merchant category code as defined by each payment system or directory server.



26
27
28
# File 'lib/stripe/resources/three_d_secure/authentication.rb', line 26

def mcc
  @mcc
end

#merchant_name ⇒ Object (readonly)

The merchant name assigned by the acquirer or payment system. Same name used in the authorization message as defined in ISO 8583.



28
29
30
# File 'lib/stripe/resources/three_d_secure/authentication.rb', line 28

def merchant_name
  @merchant_name
end

#requestor_id ⇒ Object (readonly)

Requestor ID if you’re enrolled in the card network’s 3DS program. Otherwise, you can omit this field because Stripe assigns a Requestor ID with the card networks.



30
31
32
# File 'lib/stripe/resources/three_d_secure/authentication.rb', line 30

def requestor_id
  @requestor_id
end

Class Method Details

.field_remappings ⇒ Object



36
37
38
# File 'lib/stripe/resources/three_d_secure/authentication.rb', line 36

def self.field_remappings
  @field_remappings = {}
end

.inner_class_types ⇒ Object



32
33
34
# File 'lib/stripe/resources/three_d_secure/authentication.rb', line 32

def self.inner_class_types
  @inner_class_types = {}
end