Class: Stripe::ThreeDSecure::Authentication::Channel::Browser
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::ThreeDSecure::Authentication::Channel::Browser
- Defined in:
- lib/stripe/resources/three_d_secure/authentication.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#accept_header ⇒ Object
readonly
The HTTP accept headers from the cardholder's browser.
-
#color_depth ⇒ Object
readonly
The color depth of the cardholder’s screen.
-
#ip_address ⇒ Object
readonly
The IP address of the browser.
-
#java_enabled ⇒ Object
readonly
The cardholder browser’s ability to execute Java.
-
#javascript_enabled ⇒ Object
readonly
The cardholder browser’s ability to execute JavaScript.
-
#language ⇒ Object
readonly
An IETF BCP 47 language tag representing the browser language.
-
#screen_height ⇒ Object
readonly
The total height of the cardholder’s screen in pixels.
-
#screen_width ⇒ Object
readonly
The total width of the cardholder’s screen in pixels.
-
#timezone_offset ⇒ Object
readonly
The time difference between UTC time and the local time of the cardholder’s browser, in minutes.
-
#user_agent ⇒ Object
readonly
The browser user agent.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#accept_header ⇒ Object (readonly)
The HTTP accept headers from the cardholder's browser.
44 45 46 |
# File 'lib/stripe/resources/three_d_secure/authentication.rb', line 44 def accept_header @accept_header end |
#color_depth ⇒ Object (readonly)
The color depth of the cardholder’s screen.
46 47 48 |
# File 'lib/stripe/resources/three_d_secure/authentication.rb', line 46 def color_depth @color_depth end |
#ip_address ⇒ Object (readonly)
The IP address of the browser.
48 49 50 |
# File 'lib/stripe/resources/three_d_secure/authentication.rb', line 48 def ip_address @ip_address end |
#java_enabled ⇒ Object (readonly)
The cardholder browser’s ability to execute Java.
50 51 52 |
# File 'lib/stripe/resources/three_d_secure/authentication.rb', line 50 def java_enabled @java_enabled end |
#javascript_enabled ⇒ Object (readonly)
The cardholder browser’s ability to execute JavaScript.
52 53 54 |
# File 'lib/stripe/resources/three_d_secure/authentication.rb', line 52 def javascript_enabled @javascript_enabled end |
#language ⇒ Object (readonly)
An IETF BCP 47 language tag representing the browser language.
54 55 56 |
# File 'lib/stripe/resources/three_d_secure/authentication.rb', line 54 def language @language end |
#screen_height ⇒ Object (readonly)
The total height of the cardholder’s screen in pixels.
56 57 58 |
# File 'lib/stripe/resources/three_d_secure/authentication.rb', line 56 def screen_height @screen_height end |
#screen_width ⇒ Object (readonly)
The total width of the cardholder’s screen in pixels.
58 59 60 |
# File 'lib/stripe/resources/three_d_secure/authentication.rb', line 58 def screen_width @screen_width end |
#timezone_offset ⇒ Object (readonly)
The time difference between UTC time and the local time of the cardholder’s browser, in minutes.
60 61 62 |
# File 'lib/stripe/resources/three_d_secure/authentication.rb', line 60 def timezone_offset @timezone_offset end |
#user_agent ⇒ Object (readonly)
The browser user agent.
62 63 64 |
# File 'lib/stripe/resources/three_d_secure/authentication.rb', line 62 def user_agent @user_agent end |
Class Method Details
.field_remappings ⇒ Object
68 69 70 |
# File 'lib/stripe/resources/three_d_secure/authentication.rb', line 68 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
64 65 66 |
# File 'lib/stripe/resources/three_d_secure/authentication.rb', line 64 def self.inner_class_types @inner_class_types = {} end |