Class: Stripe::ThreeDSecure::Authentication::FutureUsage::Recurring
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::ThreeDSecure::Authentication::FutureUsage::Recurring
- Defined in:
- lib/stripe/resources/three_d_secure/authentication.rb
Defined Under Namespace
Classes: Expiry
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
A non-negative integer representing the amount in the smallest currency unit.
-
#expiry ⇒ Object
readonly
Information about recurring payment expiry.
-
#interval ⇒ Object
readonly
The unit of time for
interval_count. -
#interval_count ⇒ Object
readonly
The minimum number of time intervals between authorizations.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
A non-negative integer representing the amount in the smallest currency unit.
216 217 218 |
# File 'lib/stripe/resources/three_d_secure/authentication.rb', line 216 def amount @amount end |
#expiry ⇒ Object (readonly)
Information about recurring payment expiry
218 219 220 |
# File 'lib/stripe/resources/three_d_secure/authentication.rb', line 218 def expiry @expiry end |
#interval ⇒ Object (readonly)
The unit of time for interval_count.
220 221 222 |
# File 'lib/stripe/resources/three_d_secure/authentication.rb', line 220 def interval @interval end |
#interval_count ⇒ Object (readonly)
The minimum number of time intervals between authorizations.
222 223 224 |
# File 'lib/stripe/resources/three_d_secure/authentication.rb', line 222 def interval_count @interval_count end |
Class Method Details
.field_remappings ⇒ Object
228 229 230 |
# File 'lib/stripe/resources/three_d_secure/authentication.rb', line 228 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
224 225 226 |
# File 'lib/stripe/resources/three_d_secure/authentication.rb', line 224 def self.inner_class_types @inner_class_types = { expiry: Expiry } end |