Class: Stripe::ThreeDSecure::Authentication::OutcomeDetails::NetworkDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::ThreeDSecure::Authentication::OutcomeDetails::NetworkDetails
- Defined in:
- lib/stripe/resources/three_d_secure/authentication.rb
Defined Under Namespace
Classes: CartesBancaires
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#cartes_bancaires ⇒ Object
readonly
Contains details for Cartes Bancaires specific fields in the authentication outcomes.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#cartes_bancaires ⇒ Object (readonly)
Contains details for Cartes Bancaires specific fields in the authentication outcomes.
267 268 269 |
# File 'lib/stripe/resources/three_d_secure/authentication.rb', line 267 def cartes_bancaires @cartes_bancaires end |
Class Method Details
.field_remappings ⇒ Object
273 274 275 |
# File 'lib/stripe/resources/three_d_secure/authentication.rb', line 273 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
269 270 271 |
# File 'lib/stripe/resources/three_d_secure/authentication.rb', line 269 def self.inner_class_types @inner_class_types = { cartes_bancaires: CartesBancaires } end |