Class: Stripe::ThreeDSecure::Authentication::OutcomeDetails::NetworkDetails::CartesBancaires

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/three_d_secure/authentication.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#avalgo ⇒ Object (readonly)

The cryptogram calculation algorithm used by the card Issuer's ACS to calculate the Authentication cryptogram. Also known as cavvAlgorithm. ARes/RReq messageExtension: CB-AVALGO



252
253
254
# File 'lib/stripe/resources/three_d_secure/authentication.rb', line 252

def avalgo
  @avalgo
end

#cb_exemption ⇒ Object (readonly)

The exemption indicator returned from Cartes Bancaires in the ARes. This is a 3 byte bitmap (lowest significant byte first and most significant bit first) that has been Base64 encoded. String (4 characters). ARes message extension: CB-EXEMPTION



254
255
256
# File 'lib/stripe/resources/three_d_secure/authentication.rb', line 254

def cb_exemption
  @cb_exemption
end

#cb_score ⇒ Object (readonly)

The risk score returned from Cartes Bancaires in the ARes. Numeric value 0-99. ARes/RReq message extension: CB-SCORE



256
257
258
# File 'lib/stripe/resources/three_d_secure/authentication.rb', line 256

def cb_score
  @cb_score
end

Class Method Details

.field_remappings ⇒ Object



262
263
264
# File 'lib/stripe/resources/three_d_secure/authentication.rb', line 262

def self.field_remappings
  @field_remappings = {}
end

.inner_class_types ⇒ Object



258
259
260
# File 'lib/stripe/resources/three_d_secure/authentication.rb', line 258

def self.inner_class_types
  @inner_class_types = {}
end