Class: Stripe::ThreeDSecure::AuthenticationCreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/three_d_secure/authentication_create_params.rb

Defined Under Namespace

Classes: AcquirerDetails, Channel, FlowPreference, FutureUsage, PaymentMethodData, ShippingAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h

Constructor Details

#initialize(acquirer_details: nil, amount: nil, channel: nil, currency: nil, directory_server: nil, expand: nil, flow_preference: nil, future_usage: nil, message_category: nil, metadata: nil, payment_method: nil, payment_method_data: nil, reason: nil, shipping_address: nil, submit: nil) ⇒ AuthenticationCreateParams

Returns a new instance of AuthenticationCreateParams.



398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 398

def initialize(
  acquirer_details: nil,
  amount: nil,
  channel: nil,
  currency: nil,
  directory_server: nil,
  expand: nil,
  flow_preference: nil,
  future_usage: nil,
  message_category: nil,
  metadata: nil,
  payment_method: nil,
  payment_method_data: nil,
  reason: nil,
  shipping_address: nil,
  submit: nil
)
  @acquirer_details = acquirer_details
  @amount = amount
  @channel = channel
  @currency = currency
  @directory_server = directory_server
  @expand = expand
  @flow_preference = flow_preference
  @future_usage = future_usage
  @message_category = message_category
  @metadata = 
  @payment_method = payment_method
  @payment_method_data = payment_method_data
  @reason = reason
  @shipping_address = shipping_address
  @submit = submit
end

Instance Attribute Details

#acquirer_details ⇒ Object

Contains additional details about the acquirer for this 3DS Authentication.

Refer to the Pass acquirer details and directory server section of the standalone 3DS guide for more information.



362
363
364
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 362

def acquirer_details
  @acquirer_details
end

#amount ⇒ Object

A non-negative integer representing the amount in the smallest currency unit. You can't include this parameter if message_category is non_payment_authentication



364
365
366
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 364

def amount
  @amount
end

#channel ⇒ Object

Contains additional details on the channel used for this 3DS Authentication.



366
367
368
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 366

def channel
  @channel
end

#currency ⇒ Object

Three-letter ISO currency code, in lowercase. Must be a supported currency.



368
369
370
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 368

def currency
  @currency
end

#directory_server ⇒ Object

The 3DS directory server with which this 3DS Authentication was processed.



370
371
372
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 370

def directory_server
  @directory_server
end

#expand ⇒ Object

Specifies which fields in the response should be expanded.



372
373
374
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 372

def expand
  @expand
end

#flow_preference ⇒ Object

Contains additional details on your flow preference for this 3DS Authentication.

Refer to the Specify a flow preference section of the standalone 3DS guide for more information.



376
377
378
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 376

def flow_preference
  @flow_preference
end

#future_usage ⇒ Object

Contains information about future usage of this 3DS Authentication



378
379
380
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 378

def future_usage
  @future_usage
end

#message_category ⇒ Object

Indicates whether this 3DS Authentication is being performed for a payment or non-payment use case.



380
381
382
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 380

def message_category
  @message_category
end

#metadata ⇒ Object

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.



382
383
384
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 382

def 
  @metadata
end

#payment_method ⇒ Object

ID of the payment method (a PaymentMethod object) to attach to this 3DS Authentication.



384
385
386
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 384

def payment_method
  @payment_method
end

#payment_method_data ⇒ Object

Hash used to generate the PaymentMethod to be used for this Authentication. This is mutually exclusive with the payment_method parameter.



386
387
388
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 386

def payment_method_data
  @payment_method_data
end

#reason ⇒ Object

The reason for invoking standalone 3DS. This is tailored specifically for cases when you want Stripe to help determine the standalone 3DS flow to fit your use case instead of needing to select a specific 3DS flow.

This parameter is exclusive with flow_preference. You can either use reason for controlling 3DS according to your business requirements, or use flow_preference for having fine-grained control over your 3DS flow preference.



390
391
392
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 390

def reason
  @reason
end

#shipping_address ⇒ Object

The shipping address requested by the cardholder. You should try to include as complete address information as possible.



392
393
394
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 392

def shipping_address
  @shipping_address
end

#submit ⇒ Object

Set to always to skip the fingerprinting step and submit this Authentication immediately or if_fingerprinting_not_supported to submit this Authentication only if fingerprinting is not available. This parameter defaults to never.

Refer to the Submit at creation section of the standalone 3DS guide for more information.



396
397
398
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 396

def submit
  @submit
end