Class: Stripe::ThreeDSecure::AuthenticationCreateParams::AcquirerDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/three_d_secure/authentication_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h

Constructor Details

#initialize(acquirer_bin: nil, acquirer_country: nil, acquirer_merchant_id: nil, mcc: nil, merchant_name: nil, requestor_id: nil) ⇒ AcquirerDetails



21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 21

def initialize(
  acquirer_bin: nil,
  acquirer_country: nil,
  acquirer_merchant_id: nil,
  mcc: nil,
  merchant_name: nil,
  requestor_id: nil
)
  @acquirer_bin = acquirer_bin
  @acquirer_country = acquirer_country
  @acquirer_merchant_id = acquirer_merchant_id
  @mcc = mcc
  @merchant_name = merchant_name
  @requestor_id = requestor_id
end

Instance Attribute Details

#acquirer_bin ⇒ Object

The Acquirer BIN (specific to the directory_server).



9
10
11
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 9

def acquirer_bin
  @acquirer_bin
end

#acquirer_country ⇒ Object

The two-letter country code of the acquirer (ISO 3166-1 alpha-2).



11
12
13
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 11

def acquirer_country
  @acquirer_country
end

#acquirer_merchant_id ⇒ Object

The Merchant ID (or Card Acceptor ID) that your acquirer assigned you (specific to the directory_server).



13
14
15
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 13

def acquirer_merchant_id
  @acquirer_merchant_id
end

#mcc ⇒ Object

The merchant category code as defined by each payment system or directory server.



15
16
17
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 15

def mcc
  @mcc
end

#merchant_name ⇒ Object

The merchant name assigned by the acquirer or payment system. Same name used in the authorization message as defined in ISO 8583.



17
18
19
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 17

def merchant_name
  @merchant_name
end

#requestor_id ⇒ Object

Requestor ID if you’re enrolled in the card network’s 3DS program. Otherwise, you can omit this field because Stripe assigns a Requestor ID with the card networks.



19
20
21
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 19

def requestor_id
  @requestor_id
end