Class: Stripe::ThreeDSecure::AuthenticationCreateParams::Channel::Browser

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/three_d_secure/authentication_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h

Constructor Details

#initialize(accept_header: nil, color_depth: nil, device_id: nil, ip_address: nil, java_enabled: nil, javascript_enabled: nil, language: nil, screen_height: nil, screen_width: nil, timezone_offset: nil, user_agent: nil) ⇒ Browser

Returns a new instance of Browser.



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 75

def initialize(
  accept_header: nil,
  color_depth: nil,
  device_id: nil,
  ip_address: nil,
  java_enabled: nil,
  javascript_enabled: nil,
  language: nil,
  screen_height: nil,
  screen_width: nil,
  timezone_offset: nil,
  user_agent: nil
)
  @accept_header = accept_header
  @color_depth = color_depth
  @device_id = device_id
  @ip_address = ip_address
  @java_enabled = java_enabled
  @javascript_enabled = javascript_enabled
  @language = language
  @screen_height = screen_height
  @screen_width = screen_width
  @timezone_offset = timezone_offset
  @user_agent = user_agent
end

Instance Attribute Details

#accept_header ⇒ Object

The HTTP accept headers from the cardholder's browser. Collected server-side.



41
42
43
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 41

def accept_header
  @accept_header
end

#color_depth ⇒ Object

The color depth of the cardholder’s screen.

Returned from the screen.colorDepth property.



45
46
47
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 45

def color_depth
  @color_depth
end

#device_id ⇒ Object

Unique and immutable identifier linked to a device that is consistent across 3DS transactions for the specific user device. For example: hardware device ID or a platform-calculated device fingerprint.



47
48
49
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 47

def device_id
  @device_id
end

#ip_address ⇒ Object

The IP address of the browser. Included in the HTTP request to your server before you create the 3DS Authentication.

Collected server-side.



51
52
53
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 51

def ip_address
  @ip_address
end

#java_enabled ⇒ Object

The cardholder browser’s ability to execute Java. Returned from the navigator.javaEnabled property.



53
54
55
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 53

def java_enabled
  @java_enabled
end

#javascript_enabled ⇒ Object

The cardholder browser’s ability to execute JavaScript.



55
56
57
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 55

def javascript_enabled
  @javascript_enabled
end

#language ⇒ Object

An IETF BCP 47 language tag representing the browser language. Typically returned from the navigator.language property, but might also be returned from navigator.languages or navigator.browserLanguage.

In some cases, this value might be an array. To cast it to a string or null value, you can use the getBrowserLanguage() example function.



59
60
61
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 59

def language
  @language
end

#screen_height ⇒ Object

The total height of the cardholder’s screen in pixels.

Returned from the screen.height property.



63
64
65
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 63

def screen_height
  @screen_height
end

#screen_width ⇒ Object

The total width of the cardholder’s screen in pixels.

Returned from the screen.width property.



67
68
69
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 67

def screen_width
  @screen_width
end

#timezone_offset ⇒ Object

The time difference between UTC time and the local time of the cardholder’s browser, in minutes.

Returned by new Date().getTimezoneOffset()



71
72
73
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 71

def timezone_offset
  @timezone_offset
end

#user_agent ⇒ Object

The browser user agent. You can retrieve this value on the client side using the navigator.userAgent property, or in the HTTP request to your server before you create the 3DS Authentication.



73
74
75
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 73

def user_agent
  @user_agent
end