Class: Stripe::ThreeDSecure::AuthenticationCreateParams::FlowPreference::Challenge
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ThreeDSecure::AuthenticationCreateParams::FlowPreference::Challenge
- Defined in:
- lib/stripe/params/three_d_secure/authentication_create_params.rb
Instance Attribute Summary collapse
-
#type ⇒ Object
Type of challenge flow you requested for this 3DS Authentication.
Instance Method Summary collapse
-
#initialize(type: nil) ⇒ Challenge
constructor
A new instance of Challenge.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(type: nil) ⇒ Challenge
Returns a new instance of Challenge.
132 133 134 |
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 132 def initialize(type: nil) @type = type end |
Instance Attribute Details
#type ⇒ Object
Type of challenge flow you requested for this 3DS Authentication.
130 131 132 |
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 130 def type @type end |