Class: Stripe::ThreeDSecure::AuthenticationCreateParams::FlowPreference::DataShare
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ThreeDSecure::AuthenticationCreateParams::FlowPreference::DataShare
- Defined in:
- lib/stripe/params/three_d_secure/authentication_create_params.rb
Instance Attribute Summary collapse
-
#type ⇒ Object
Type of data share only flow you requested for this 3DS Authentication.
Instance Method Summary collapse
-
#initialize(type: nil) ⇒ DataShare
constructor
A new instance of DataShare.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(type: nil) ⇒ DataShare
Returns a new instance of DataShare.
141 142 143 |
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 141 def initialize(type: nil) @type = type end |
Instance Attribute Details
#type ⇒ Object
Type of data share only flow you requested for this 3DS Authentication.
139 140 141 |
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 139 def type @type end |