Class: Stripe::ThreeDSecure::AuthenticationCreateParams::FlowPreference::Frictionless
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ThreeDSecure::AuthenticationCreateParams::FlowPreference::Frictionless
- Defined in:
- lib/stripe/params/three_d_secure/authentication_create_params.rb
Instance Attribute Summary collapse
-
#type ⇒ Object
Type of frictionless flow you requested for this 3DS Authentication.
Instance Method Summary collapse
-
#initialize(type: nil) ⇒ Frictionless
constructor
A new instance of Frictionless.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(type: nil) ⇒ Frictionless
Returns a new instance of Frictionless.
150 151 152 |
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 150 def initialize(type: nil) @type = type end |
Instance Attribute Details
#type ⇒ Object
Type of frictionless flow you requested for this 3DS Authentication.
148 149 150 |
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 148 def type @type end |