Class: Stripe::ThreeDSecure::AuthenticationCreateParams::FutureUsage
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ThreeDSecure::AuthenticationCreateParams::FutureUsage
- Defined in:
- lib/stripe/params/three_d_secure/authentication_create_params.rb
Defined Under Namespace
Classes: Installment, Recurring
Instance Attribute Summary collapse
-
#installment ⇒ Object
Parameters related to an installment payment.
-
#recurring ⇒ Object
Parameters related to a recurring payment.
-
#type ⇒ Object
The type of future usage declared for this 3DS Authentication.
Instance Method Summary collapse
-
#initialize(installment: nil, recurring: nil, type: nil) ⇒ FutureUsage
constructor
A new instance of FutureUsage.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(installment: nil, recurring: nil, type: nil) ⇒ FutureUsage
Returns a new instance of FutureUsage.
239 240 241 242 243 |
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 239 def initialize(installment: nil, recurring: nil, type: nil) @installment = installment @recurring = recurring @type = type end |
Instance Attribute Details
#installment ⇒ Object
Parameters related to an installment payment.
233 234 235 |
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 233 def installment @installment end |
#recurring ⇒ Object
Parameters related to a recurring payment.
235 236 237 |
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 235 def recurring @recurring end |
#type ⇒ Object
The type of future usage declared for this 3DS Authentication
237 238 239 |
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 237 def type @type end |