Class: Stripe::ThreeDSecure::AuthenticationCreateParams::FutureUsage::Installment
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ThreeDSecure::AuthenticationCreateParams::FutureUsage::Installment
- Defined in:
- lib/stripe/params/three_d_secure/authentication_create_params.rb
Defined Under Namespace
Classes: Expiry
Instance Attribute Summary collapse
-
#amount ⇒ Object
A non-negative integer representing the future authorizations' amount in the smallest currency unit.
-
#expiry ⇒ Object
Information about the expiry of the future usage of this authentication.
-
#interval ⇒ Object
The unit of time for
interval_count. -
#interval_count ⇒ Object
The minimum number of time intervals between authorizations.
-
#number ⇒ Object
The maximum number of installments.
Instance Method Summary collapse
-
#initialize(amount: nil, expiry: nil, interval: nil, interval_count: nil, number: nil) ⇒ Installment
constructor
A new instance of Installment.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, expiry: nil, interval: nil, interval_count: nil, number: nil) ⇒ Installment
195 196 197 198 199 200 201 |
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 195 def initialize(amount: nil, expiry: nil, interval: nil, interval_count: nil, number: nil) @amount = amount @expiry = expiry @interval = interval @interval_count = interval_count @number = number end |
Instance Attribute Details
#amount ⇒ Object
A non-negative integer representing the future authorizations' amount in the smallest currency unit.
185 186 187 |
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 185 def amount @amount end |
#expiry ⇒ Object
Information about the expiry of the future usage of this authentication.
187 188 189 |
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 187 def expiry @expiry end |
#interval ⇒ Object
The unit of time for interval_count.
189 190 191 |
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 189 def interval @interval end |
#interval_count ⇒ Object
The minimum number of time intervals between authorizations. Must be greater than 0, and defaults to 1.
191 192 193 |
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 191 def interval_count @interval_count end |
#number ⇒ Object
The maximum number of installments. Must be greater than 1.
193 194 195 |
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 193 def number @number end |