Class: Stripe::ThreeDSecure::AuthenticationCreateParams::FutureUsage::Installment::Expiry

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/three_d_secure/authentication_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h

Constructor Details

#initialize(date: nil, type: nil) ⇒ Expiry



179
180
181
182
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 179

def initialize(date: nil, type: nil)
  @date = date
  @type = type
end

Instance Attribute Details

#date ⇒ Object

The date before which the last authorization related to this authentication will occur.



175
176
177
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 175

def date
  @date
end

#type ⇒ Object

The type of expiry for the future use of this authentication.



177
178
179
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 177

def type
  @type
end