Class: Stripe::ThreeDSecure::AuthenticationCreateParams::FutureUsage::Recurring
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ThreeDSecure::AuthenticationCreateParams::FutureUsage::Recurring
- Defined in:
- lib/stripe/params/three_d_secure/authentication_create_params.rb
Defined Under Namespace
Classes: Expiry
Instance Attribute Summary collapse
-
#amount ⇒ Object
A non-negative integer representing the future authorizations' amount in the smallest currency unit.
-
#expiry ⇒ Object
Information about the expiry of the future usage of this authentication.
-
#interval ⇒ Object
The unit of time for
interval_count. -
#interval_count ⇒ Object
The minimum number of time intervals between authorizations.
Instance Method Summary collapse
-
#initialize(amount: nil, expiry: nil, interval: nil, interval_count: nil) ⇒ Recurring
constructor
A new instance of Recurring.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, expiry: nil, interval: nil, interval_count: nil) ⇒ Recurring
225 226 227 228 229 230 |
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 225 def initialize(amount: nil, expiry: nil, interval: nil, interval_count: nil) @amount = amount @expiry = expiry @interval = interval @interval_count = interval_count end |
Instance Attribute Details
#amount ⇒ Object
A non-negative integer representing the future authorizations' amount in the smallest currency unit.
217 218 219 |
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 217 def amount @amount end |
#expiry ⇒ Object
Information about the expiry of the future usage of this authentication.
219 220 221 |
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 219 def expiry @expiry end |
#interval ⇒ Object
The unit of time for interval_count.
221 222 223 |
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 221 def interval @interval end |
#interval_count ⇒ Object
The minimum number of time intervals between authorizations. Must be greater than 0, and defaults to 1.
223 224 225 |
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 223 def interval_count @interval_count end |