Class: Stripe::ThreeDSecure::AuthenticationCreateParams::FutureUsage::Recurring::Expiry

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/three_d_secure/authentication_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h

Constructor Details

#initialize(date: nil, type: nil) ⇒ Expiry

Returns a new instance of Expiry.



211
212
213
214
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 211

def initialize(date: nil, type: nil)
  @date = date
  @type = type
end

Instance Attribute Details

#date ⇒ Object

The date before which the last authorization related to this authentication will occur.



207
208
209
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 207

def date
  @date
end

#type ⇒ Object

The type of expiry for the future use of this authentication.



209
210
211
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 209

def type
  @type
end