Class: Stripe::ThreeDSecure::AuthenticationCreateParams::PaymentMethodData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ThreeDSecure::AuthenticationCreateParams::PaymentMethodData
- Defined in:
- lib/stripe/params/three_d_secure/authentication_create_params.rb
Defined Under Namespace
Classes: BillingDetails, Card
Instance Attribute Summary collapse
-
#billing_details ⇒ Object
Billing information associated with the PaymentMethod that may be used or required by particular types of payment methods.
-
#card ⇒ Object
Attribute for param field card.
-
#type ⇒ Object
The type of the PaymentMethod.
Instance Method Summary collapse
-
#initialize(billing_details: nil, card: nil, type: nil) ⇒ PaymentMethodData
constructor
A new instance of PaymentMethodData.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(billing_details: nil, card: nil, type: nil) ⇒ PaymentMethodData
Returns a new instance of PaymentMethodData.
322 323 324 325 326 |
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 322 def initialize(billing_details: nil, card: nil, type: nil) @billing_details = billing_details @card = card @type = type end |
Instance Attribute Details
#billing_details ⇒ Object
Billing information associated with the PaymentMethod that may be used or required by particular types of payment methods.
316 317 318 |
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 316 def billing_details @billing_details end |
#card ⇒ Object
Attribute for param field card
318 319 320 |
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 318 def card @card end |
#type ⇒ Object
The type of the PaymentMethod. An additional hash is included on the PaymentMethod with a name matching this value. It contains additional information specific to the PaymentMethod type.
320 321 322 |
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 320 def type @type end |