Class: Stripe::ThreeDSecure::AuthenticationSubmitParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/three_d_secure/authentication_submit_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h

Constructor Details

#initialize(expand: nil, fingerprinting_result: nil, metadata: nil) ⇒ AuthenticationSubmitParams

Returns a new instance of AuthenticationSubmitParams.



16
17
18
19
20
# File 'lib/stripe/params/three_d_secure/authentication_submit_params.rb', line 16

def initialize(expand: nil, fingerprinting_result: nil, metadata: nil)
  @expand = expand
  @fingerprinting_result = fingerprinting_result
  @metadata = 
end

Instance Attribute Details

#expand ⇒ Object

Specifies which fields in the response should be expanded.



8
9
10
# File 'lib/stripe/params/three_d_secure/authentication_submit_params.rb', line 8

def expand
  @expand
end

#fingerprinting_result ⇒ Object

The fingerprinting result of the issuer fingerprinting step.

Refer to the Issuer fingerprinting section of the Standalone 3DS guide for more information.



12
13
14
# File 'lib/stripe/params/three_d_secure/authentication_submit_params.rb', line 12

def fingerprinting_result
  @fingerprinting_result
end

#metadata ⇒ Object

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.



14
15
16
# File 'lib/stripe/params/three_d_secure/authentication_submit_params.rb', line 14

def 
  @metadata
end