Class: Stripe::Token::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/token.rb

Defined Under Namespace

Classes: Account, BankAccount, Card, CvcUpdate, Person, Pii

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account: nil, bank_account: nil, card: nil, customer: nil, cvc_update: nil, expand: nil, person: nil, pii: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



1204
1205
1206
1207
1208
1209
1210
1211
1212
1213
1214
1215
1216
1217
1218
1219
1220
1221
1222
# File 'lib/stripe/resources/token.rb', line 1204

def initialize(
  account: nil,
  bank_account: nil,
  card: nil,
  customer: nil,
  cvc_update: nil,
  expand: nil,
  person: nil,
  pii: nil
)
  @account = 
  @bank_account = 
  @card = card
  @customer = customer
  @cvc_update = cvc_update
  @expand = expand
  @person = person
  @pii = pii
end

Instance Attribute Details

#accountObject

Information for the account this token represents.



1188
1189
1190
# File 'lib/stripe/resources/token.rb', line 1188

def 
  @account
end

#bank_accountObject

The bank account this token will represent.



1190
1191
1192
# File 'lib/stripe/resources/token.rb', line 1190

def 
  @bank_account
end

#cardObject

The card this token will represent. If you also pass in a customer, the card must be the ID of a card belonging to the customer. Otherwise, if you do not pass in a customer, this is a dictionary containing a user’s credit card details, with the options described below.



1192
1193
1194
# File 'lib/stripe/resources/token.rb', line 1192

def card
  @card
end

#customerObject

Create a token for the customer, which is owned by the application’s account. You can only use this with an [OAuth access token](stripe.com/docs/connect/standard-accounts) or [Stripe-Account header](stripe.com/docs/connect/authentication). Learn more about [cloning saved payment methods](stripe.com/docs/connect/cloning-saved-payment-methods).



1194
1195
1196
# File 'lib/stripe/resources/token.rb', line 1194

def customer
  @customer
end

#cvc_updateObject

The updated CVC value this token represents.



1196
1197
1198
# File 'lib/stripe/resources/token.rb', line 1196

def cvc_update
  @cvc_update
end

#expandObject

Specifies which fields in the response should be expanded.



1198
1199
1200
# File 'lib/stripe/resources/token.rb', line 1198

def expand
  @expand
end

#personObject

Information for the person this token represents.



1200
1201
1202
# File 'lib/stripe/resources/token.rb', line 1200

def person
  @person
end

#piiObject

The PII this token represents.



1202
1203
1204
# File 'lib/stripe/resources/token.rb', line 1202

def pii
  @pii
end