Class: Stripe::Token::CreateParams::Account
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Token::CreateParams::Account
- Defined in:
- lib/stripe/resources/token.rb
Defined Under Namespace
Classes: Company, Individual
Instance Attribute Summary collapse
-
#business_type ⇒ Object
The business type.
-
#company ⇒ Object
Information about the company or business.
-
#individual ⇒ Object
Information about the person represented by the account.
-
#tos_shown_and_accepted ⇒ Object
Whether the user described by the data in the token has been shown [the Stripe Connected Account Agreement](/connect/account-tokens#stripe-connected-account-agreement).
Instance Method Summary collapse
-
#initialize(business_type: nil, company: nil, individual: nil, tos_shown_and_accepted: nil) ⇒ Account
constructor
A new instance of Account.
Methods inherited from RequestParams
Constructor Details
#initialize(business_type: nil, company: nil, individual: nil, tos_shown_and_accepted: nil) ⇒ Account
Returns a new instance of Account.
614 615 616 617 618 619 620 621 622 623 624 |
# File 'lib/stripe/resources/token.rb', line 614 def initialize( business_type: nil, company: nil, individual: nil, tos_shown_and_accepted: nil ) @business_type = business_type @company = company @individual = individual @tos_shown_and_accepted = tos_shown_and_accepted end |
Instance Attribute Details
#business_type ⇒ Object
The business type.
606 607 608 |
# File 'lib/stripe/resources/token.rb', line 606 def business_type @business_type end |
#company ⇒ Object
Information about the company or business.
608 609 610 |
# File 'lib/stripe/resources/token.rb', line 608 def company @company end |
#individual ⇒ Object
Information about the person represented by the account.
610 611 612 |
# File 'lib/stripe/resources/token.rb', line 610 def individual @individual end |
#tos_shown_and_accepted ⇒ Object
Whether the user described by the data in the token has been shown [the Stripe Connected Account Agreement](/connect/account-tokens#stripe-connected-account-agreement). When creating an account token to create a new Connect account, this value must be ‘true`.
612 613 614 |
# File 'lib/stripe/resources/token.rb', line 612 def tos_shown_and_accepted @tos_shown_and_accepted end |