Class: Stripe::Token::CreateParams::Account::Company

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/token.rb

Defined Under Namespace

Classes: Address, AddressKana, AddressKanji, DirectorshipDeclaration, OwnershipDeclaration, RegistrationDate, Verification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, address_kana: nil, address_kanji: nil, directors_provided: nil, directorship_declaration: nil, executives_provided: nil, export_license_id: nil, export_purpose_code: nil, name: nil, name_kana: nil, name_kanji: nil, owners_provided: nil, ownership_declaration: nil, ownership_declaration_shown_and_signed: nil, ownership_exemption_reason: nil, phone: nil, registration_date: nil, registration_number: nil, structure: nil, tax_id: nil, tax_id_registrar: nil, vat_id: nil, verification: nil) ⇒ Company

Returns a new instance of Company.



248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
# File 'lib/stripe/resources/token.rb', line 248

def initialize(
  address: nil,
  address_kana: nil,
  address_kanji: nil,
  directors_provided: nil,
  directorship_declaration: nil,
  executives_provided: nil,
  export_license_id: nil,
  export_purpose_code: nil,
  name: nil,
  name_kana: nil,
  name_kanji: nil,
  owners_provided: nil,
  ownership_declaration: nil,
  ownership_declaration_shown_and_signed: nil,
  ownership_exemption_reason: nil,
  phone: nil,
  registration_date: nil,
  registration_number: nil,
  structure: nil,
  tax_id: nil,
  tax_id_registrar: nil,
  vat_id: nil,
  verification: nil
)
  @address = address
  @address_kana = address_kana
  @address_kanji = address_kanji
  @directors_provided = directors_provided
  @directorship_declaration = directorship_declaration
  @executives_provided = executives_provided
  @export_license_id = export_license_id
  @export_purpose_code = export_purpose_code
  @name = name
  @name_kana = name_kana
  @name_kanji = name_kanji
  @owners_provided = owners_provided
  @ownership_declaration = ownership_declaration
  @ownership_declaration_shown_and_signed = ownership_declaration_shown_and_signed
  @ownership_exemption_reason = ownership_exemption_reason
  @phone = phone
  @registration_date = registration_date
  @registration_number = registration_number
  @structure = structure
  @tax_id = tax_id
  @tax_id_registrar = tax_id_registrar
  @vat_id = vat_id
  @verification = verification
end

Instance Attribute Details

#addressObject

The company’s primary address.



202
203
204
# File 'lib/stripe/resources/token.rb', line 202

def address
  @address
end

#address_kanaObject

The Kana variation of the company’s primary address (Japan only).



204
205
206
# File 'lib/stripe/resources/token.rb', line 204

def address_kana
  @address_kana
end

#address_kanjiObject

The Kanji variation of the company’s primary address (Japan only).



206
207
208
# File 'lib/stripe/resources/token.rb', line 206

def address_kanji
  @address_kanji
end

#directors_providedObject

Whether the company’s directors have been provided. Set this Boolean to ‘true` after creating all the company’s directors with [the Persons API](/api/persons) for accounts with a ‘relationship.director` requirement. This value is not automatically set to `true` after creating directors, so it needs to be updated to indicate all directors have been provided.



208
209
210
# File 'lib/stripe/resources/token.rb', line 208

def directors_provided
  @directors_provided
end

#directorship_declarationObject

This hash is used to attest that the directors information provided to Stripe is both current and correct.



210
211
212
# File 'lib/stripe/resources/token.rb', line 210

def directorship_declaration
  @directorship_declaration
end

#executives_providedObject

Whether the company’s executives have been provided. Set this Boolean to ‘true` after creating all the company’s executives with [the Persons API](/api/persons) for accounts with a ‘relationship.executive` requirement.



212
213
214
# File 'lib/stripe/resources/token.rb', line 212

def executives_provided
  @executives_provided
end

#export_license_idObject

The export license ID number of the company, also referred as Import Export Code (India only).



214
215
216
# File 'lib/stripe/resources/token.rb', line 214

def export_license_id
  @export_license_id
end

#export_purpose_codeObject

The purpose code to use for export transactions (India only).



216
217
218
# File 'lib/stripe/resources/token.rb', line 216

def export_purpose_code
  @export_purpose_code
end

#nameObject

The company’s legal name.



218
219
220
# File 'lib/stripe/resources/token.rb', line 218

def name
  @name
end

#name_kanaObject

The Kana variation of the company’s legal name (Japan only).



220
221
222
# File 'lib/stripe/resources/token.rb', line 220

def name_kana
  @name_kana
end

#name_kanjiObject

The Kanji variation of the company’s legal name (Japan only).



222
223
224
# File 'lib/stripe/resources/token.rb', line 222

def name_kanji
  @name_kanji
end

#owners_providedObject

Whether the company’s owners have been provided. Set this Boolean to ‘true` after creating all the company’s owners with [the Persons API](/api/persons) for accounts with a ‘relationship.owner` requirement.



224
225
226
# File 'lib/stripe/resources/token.rb', line 224

def owners_provided
  @owners_provided
end

#ownership_declarationObject

This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.



226
227
228
# File 'lib/stripe/resources/token.rb', line 226

def ownership_declaration
  @ownership_declaration
end

#ownership_declaration_shown_and_signedObject

Whether the user described by the data in the token has been shown the Ownership Declaration and indicated that it is correct.



228
229
230
# File 'lib/stripe/resources/token.rb', line 228

def ownership_declaration_shown_and_signed
  @ownership_declaration_shown_and_signed
end

#ownership_exemption_reasonObject

This value is used to determine if a business is exempt from providing ultimate beneficial owners. See [this support article](support.stripe.com/questions/exemption-from-providing-ownership-details) and [changelog](docs.stripe.com/changelog/acacia/2025-01-27/ownership-exemption-reason-accounts-api) for more details.



230
231
232
# File 'lib/stripe/resources/token.rb', line 230

def ownership_exemption_reason
  @ownership_exemption_reason
end

#phoneObject

The company’s phone number (used for verification).



232
233
234
# File 'lib/stripe/resources/token.rb', line 232

def phone
  @phone
end

#registration_dateObject

When the business was incorporated or registered.



234
235
236
# File 'lib/stripe/resources/token.rb', line 234

def registration_date
  @registration_date
end

#registration_numberObject

The identification number given to a company when it is registered or incorporated, if distinct from the identification number used for filing taxes. (Examples are the CIN for companies and LLP IN for partnerships in India, and the Company Registration Number in Hong Kong).



236
237
238
# File 'lib/stripe/resources/token.rb', line 236

def registration_number
  @registration_number
end

#structureObject

The category identifying the legal structure of the company or legal entity. See [Business structure](/connect/identity-verification#business-structure) for more details. Pass an empty string to unset this value.



238
239
240
# File 'lib/stripe/resources/token.rb', line 238

def structure
  @structure
end

#tax_idObject

The business ID number of the company, as appropriate for the company’s country. (Examples are an Employer ID Number in the U.S., a Business Number in Canada, or a Company Number in the UK.)



240
241
242
# File 'lib/stripe/resources/token.rb', line 240

def tax_id
  @tax_id
end

#tax_id_registrarObject

The jurisdiction in which the ‘tax_id` is registered (Germany-based companies only).



242
243
244
# File 'lib/stripe/resources/token.rb', line 242

def tax_id_registrar
  @tax_id_registrar
end

#vat_idObject

The VAT number of the company.



244
245
246
# File 'lib/stripe/resources/token.rb', line 244

def vat_id
  @vat_id
end

#verificationObject

Information on the verification state of the company.



246
247
248
# File 'lib/stripe/resources/token.rb', line 246

def verification
  @verification
end