Class: Stripe::Token::CreateParams::Account::Company::DirectorshipDeclaration
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Token::CreateParams::Account::Company::DirectorshipDeclaration
- Defined in:
- lib/stripe/resources/token.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the directorship declaration attestation was made.
-
#ip ⇒ Object
The IP address from which the directorship declaration attestation was made.
-
#user_agent ⇒ Object
The user agent of the browser from which the directorship declaration attestation was made.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ DirectorshipDeclaration
constructor
A new instance of DirectorshipDeclaration.
Methods inherited from RequestParams
Constructor Details
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ DirectorshipDeclaration
Returns a new instance of DirectorshipDeclaration.
145 146 147 148 149 |
# File 'lib/stripe/resources/token.rb', line 145 def initialize(date: nil, ip: nil, user_agent: nil) @date = date @ip = ip @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the directorship declaration attestation was made.
139 140 141 |
# File 'lib/stripe/resources/token.rb', line 139 def date @date end |
#ip ⇒ Object
The IP address from which the directorship declaration attestation was made.
141 142 143 |
# File 'lib/stripe/resources/token.rb', line 141 def ip @ip end |
#user_agent ⇒ Object
The user agent of the browser from which the directorship declaration attestation was made.
143 144 145 |
# File 'lib/stripe/resources/token.rb', line 143 def user_agent @user_agent end |