Class: Stripe::Token::CreateParams::Account::Company::OwnershipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/token.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ OwnershipDeclaration

Returns a new instance of OwnershipDeclaration.



160
161
162
163
164
# File 'lib/stripe/resources/token.rb', line 160

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the beneficial owner attestation was made.



154
155
156
# File 'lib/stripe/resources/token.rb', line 154

def date
  @date
end

#ipObject

The IP address from which the beneficial owner attestation was made.



156
157
158
# File 'lib/stripe/resources/token.rb', line 156

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the beneficial owner attestation was made.



158
159
160
# File 'lib/stripe/resources/token.rb', line 158

def user_agent
  @user_agent
end