Class: Stripe::Token::CreateParams::Account::Individual
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Token::CreateParams::Account::Individual
- Defined in:
- lib/stripe/resources/token.rb
Defined Under Namespace
Classes: Address, AddressKana, AddressKanji, Dob, RegisteredAddress, Relationship, Verification
Instance Attribute Summary collapse
-
#address ⇒ Object
The individual’s primary address.
-
#address_kana ⇒ Object
The Kana variation of the individual’s primary address (Japan only).
-
#address_kanji ⇒ Object
The Kanji variation of the individual’s primary address (Japan only).
-
#dob ⇒ Object
The individual’s date of birth.
-
#email ⇒ Object
The individual’s email address.
-
#first_name ⇒ Object
The individual’s first name.
-
#first_name_kana ⇒ Object
The Kana variation of the individual’s first name (Japan only).
-
#first_name_kanji ⇒ Object
The Kanji variation of the individual’s first name (Japan only).
-
#full_name_aliases ⇒ Object
A list of alternate names or aliases that the individual is known by.
-
#gender ⇒ Object
The individual’s gender.
-
#id_number ⇒ Object
The government-issued ID number of the individual, as appropriate for the representative’s country.
-
#id_number_secondary ⇒ Object
The government-issued secondary ID number of the individual, as appropriate for the representative’s country, will be used for enhanced verification checks.
-
#last_name ⇒ Object
The individual’s last name.
-
#last_name_kana ⇒ Object
The Kana variation of the individual’s last name (Japan only).
-
#last_name_kanji ⇒ Object
The Kanji variation of the individual’s last name (Japan only).
-
#maiden_name ⇒ Object
The individual’s maiden name.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#phone ⇒ Object
The individual’s phone number.
-
#political_exposure ⇒ Object
Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
-
#registered_address ⇒ Object
The individual’s registered address.
-
#relationship ⇒ Object
Describes the person’s relationship to the account.
-
#ssn_last_4 ⇒ Object
The last four digits of the individual’s Social Security Number (U.S. only).
-
#verification ⇒ Object
The individual’s verification document information.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, address_kana: nil, address_kanji: nil, dob: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil) ⇒ Individual
Returns a new instance of Individual.
555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 |
# File 'lib/stripe/resources/token.rb', line 555 def initialize( address: nil, address_kana: nil, address_kanji: nil, dob: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil ) @address = address @address_kana = address_kana @address_kanji = address_kanji @dob = dob @email = email @first_name = first_name @first_name_kana = first_name_kana @first_name_kanji = first_name_kanji @full_name_aliases = full_name_aliases @gender = gender @id_number = id_number @id_number_secondary = id_number_secondary @last_name = last_name @last_name_kana = last_name_kana @last_name_kanji = last_name_kanji @maiden_name = maiden_name @metadata = @phone = phone @political_exposure = political_exposure @registered_address = registered_address @relationship = relationship @ssn_last_4 = ssn_last_4 @verification = verification end |
Instance Attribute Details
#address ⇒ Object
The individual’s primary address.
509 510 511 |
# File 'lib/stripe/resources/token.rb', line 509 def address @address end |
#address_kana ⇒ Object
The Kana variation of the individual’s primary address (Japan only).
511 512 513 |
# File 'lib/stripe/resources/token.rb', line 511 def address_kana @address_kana end |
#address_kanji ⇒ Object
The Kanji variation of the individual’s primary address (Japan only).
513 514 515 |
# File 'lib/stripe/resources/token.rb', line 513 def address_kanji @address_kanji end |
#dob ⇒ Object
The individual’s date of birth.
515 516 517 |
# File 'lib/stripe/resources/token.rb', line 515 def dob @dob end |
#email ⇒ Object
The individual’s email address.
517 518 519 |
# File 'lib/stripe/resources/token.rb', line 517 def email @email end |
#first_name ⇒ Object
The individual’s first name.
519 520 521 |
# File 'lib/stripe/resources/token.rb', line 519 def first_name @first_name end |
#first_name_kana ⇒ Object
The Kana variation of the individual’s first name (Japan only).
521 522 523 |
# File 'lib/stripe/resources/token.rb', line 521 def first_name_kana @first_name_kana end |
#first_name_kanji ⇒ Object
The Kanji variation of the individual’s first name (Japan only).
523 524 525 |
# File 'lib/stripe/resources/token.rb', line 523 def first_name_kanji @first_name_kanji end |
#full_name_aliases ⇒ Object
A list of alternate names or aliases that the individual is known by.
525 526 527 |
# File 'lib/stripe/resources/token.rb', line 525 def full_name_aliases @full_name_aliases end |
#gender ⇒ Object
The individual’s gender
527 528 529 |
# File 'lib/stripe/resources/token.rb', line 527 def gender @gender end |
#id_number ⇒ Object
The government-issued ID number of the individual, as appropriate for the representative’s country. (Examples are a Social Security Number in the U.S., or a Social Insurance Number in Canada). Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).
529 530 531 |
# File 'lib/stripe/resources/token.rb', line 529 def id_number @id_number end |
#id_number_secondary ⇒ Object
The government-issued secondary ID number of the individual, as appropriate for the representative’s country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).
531 532 533 |
# File 'lib/stripe/resources/token.rb', line 531 def id_number_secondary @id_number_secondary end |
#last_name ⇒ Object
The individual’s last name.
533 534 535 |
# File 'lib/stripe/resources/token.rb', line 533 def last_name @last_name end |
#last_name_kana ⇒ Object
The Kana variation of the individual’s last name (Japan only).
535 536 537 |
# File 'lib/stripe/resources/token.rb', line 535 def last_name_kana @last_name_kana end |
#last_name_kanji ⇒ Object
The Kanji variation of the individual’s last name (Japan only).
537 538 539 |
# File 'lib/stripe/resources/token.rb', line 537 def last_name_kanji @last_name_kanji end |
#maiden_name ⇒ Object
The individual’s maiden name.
539 540 541 |
# File 'lib/stripe/resources/token.rb', line 539 def maiden_name @maiden_name end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
541 542 543 |
# File 'lib/stripe/resources/token.rb', line 541 def @metadata end |
#phone ⇒ Object
The individual’s phone number.
543 544 545 |
# File 'lib/stripe/resources/token.rb', line 543 def phone @phone end |
#political_exposure ⇒ Object
Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
545 546 547 |
# File 'lib/stripe/resources/token.rb', line 545 def political_exposure @political_exposure end |
#registered_address ⇒ Object
The individual’s registered address.
547 548 549 |
# File 'lib/stripe/resources/token.rb', line 547 def registered_address @registered_address end |
#relationship ⇒ Object
Describes the person’s relationship to the account.
549 550 551 |
# File 'lib/stripe/resources/token.rb', line 549 def relationship @relationship end |
#ssn_last_4 ⇒ Object
The last four digits of the individual’s Social Security Number (U.S. only).
551 552 553 |
# File 'lib/stripe/resources/token.rb', line 551 def ssn_last_4 @ssn_last_4 end |
#verification ⇒ Object
The individual’s verification document information.
553 554 555 |
# File 'lib/stripe/resources/token.rb', line 553 def verification @verification end |