Class: Stripe::Token::CreateParams::Account::Individual::Relationship
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Token::CreateParams::Account::Individual::Relationship
- Defined in:
- lib/stripe/resources/token.rb
Instance Attribute Summary collapse
-
#director ⇒ Object
Whether the person is a director of the account’s legal entity.
-
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
-
#owner ⇒ Object
Whether the person is an owner of the account’s legal entity.
-
#percent_ownership ⇒ Object
The percent owned by the person of the account’s legal entity.
-
#title ⇒ Object
The person’s title (e.g., CEO, Support Engineer).
Instance Method Summary collapse
-
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
constructor
A new instance of Relationship.
Methods inherited from RequestParams
Constructor Details
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
Returns a new instance of Relationship.
493 494 495 496 497 498 499 500 501 502 503 504 505 |
# File 'lib/stripe/resources/token.rb', line 493 def initialize( director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil ) @director = director @executive = executive @owner = owner @percent_ownership = percent_ownership @title = title end |
Instance Attribute Details
#director ⇒ Object
Whether the person is a director of the account’s legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.
479 480 481 |
# File 'lib/stripe/resources/token.rb', line 479 def director @director end |
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
482 483 484 |
# File 'lib/stripe/resources/token.rb', line 482 def executive @executive end |
#owner ⇒ Object
Whether the person is an owner of the account’s legal entity.
485 486 487 |
# File 'lib/stripe/resources/token.rb', line 485 def owner @owner end |
#percent_ownership ⇒ Object
The percent owned by the person of the account’s legal entity.
488 489 490 |
# File 'lib/stripe/resources/token.rb', line 488 def percent_ownership @percent_ownership end |
#title ⇒ Object
The person’s title (e.g., CEO, Support Engineer).
491 492 493 |
# File 'lib/stripe/resources/token.rb', line 491 def title @title end |