Class: Stripe::Token::CreateParams::Person
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Token::CreateParams::Person
- Defined in:
- lib/stripe/resources/token.rb
Defined Under Namespace
Classes: AdditionalTosAcceptances, Address, AddressKana, AddressKanji, Dob, Documents, RegisteredAddress, Relationship, UsCfpbData, Verification
Instance Attribute Summary collapse
-
#additional_tos_acceptances ⇒ Object
Details on the legal guardian’s or authorizer’s acceptance of the required Stripe agreements.
-
#address ⇒ Object
The person’s address.
-
#address_kana ⇒ Object
The Kana variation of the person’s address (Japan only).
-
#address_kanji ⇒ Object
The Kanji variation of the person’s address (Japan only).
-
#dob ⇒ Object
The person’s date of birth.
-
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
-
#email ⇒ Object
The person’s email address.
-
#first_name ⇒ Object
The person’s first name.
-
#first_name_kana ⇒ Object
The Kana variation of the person’s first name (Japan only).
-
#first_name_kanji ⇒ Object
The Kanji variation of the person’s first name (Japan only).
-
#full_name_aliases ⇒ Object
A list of alternate names or aliases that the person is known by.
-
#gender ⇒ Object
The person’s gender (International regulations require either “male” or “female”).
-
#id_number ⇒ Object
The person’s ID number, as appropriate for their country.
-
#id_number_secondary ⇒ Object
The person’s secondary ID number, as appropriate for their country, will be used for enhanced verification checks.
-
#last_name ⇒ Object
The person’s last name.
-
#last_name_kana ⇒ Object
The Kana variation of the person’s last name (Japan only).
-
#last_name_kanji ⇒ Object
The Kanji variation of the person’s last name (Japan only).
-
#maiden_name ⇒ Object
The person’s maiden name.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#nationality ⇒ Object
The country where the person is a national.
-
#phone ⇒ Object
The person’s phone number.
-
#political_exposure ⇒ Object
Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
-
#registered_address ⇒ Object
The person’s registered address.
-
#relationship ⇒ Object
The relationship that this person has with the account’s legal entity.
-
#ssn_last_4 ⇒ Object
The last four digits of the person’s Social Security number (U.S. only).
-
#us_cfpb_data ⇒ Object
Demographic data related to the person.
-
#verification ⇒ Object
The person’s verification status.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(additional_tos_acceptances: nil, address: nil, address_kana: nil, address_kanji: nil, dob: nil, documents: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, nationality: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, us_cfpb_data: nil, verification: nil) ⇒ Person
Returns a new instance of Person.
1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 1151 1152 1153 1154 1155 1156 1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 |
# File 'lib/stripe/resources/token.rb', line 1120 def initialize( additional_tos_acceptances: nil, address: nil, address_kana: nil, address_kanji: nil, dob: nil, documents: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, nationality: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, us_cfpb_data: nil, verification: nil ) @additional_tos_acceptances = additional_tos_acceptances @address = address @address_kana = address_kana @address_kanji = address_kanji @dob = dob @documents = documents @email = email @first_name = first_name @first_name_kana = first_name_kana @first_name_kanji = first_name_kanji @full_name_aliases = full_name_aliases @gender = gender @id_number = id_number @id_number_secondary = id_number_secondary @last_name = last_name @last_name_kana = last_name_kana @last_name_kanji = last_name_kanji @maiden_name = maiden_name @metadata = @nationality = nationality @phone = phone @political_exposure = political_exposure @registered_address = registered_address @relationship = relationship @ssn_last_4 = ssn_last_4 @us_cfpb_data = us_cfpb_data @verification = verification end |
Instance Attribute Details
#additional_tos_acceptances ⇒ Object
Details on the legal guardian’s or authorizer’s acceptance of the required Stripe agreements.
1066 1067 1068 |
# File 'lib/stripe/resources/token.rb', line 1066 def additional_tos_acceptances @additional_tos_acceptances end |
#address ⇒ Object
The person’s address.
1068 1069 1070 |
# File 'lib/stripe/resources/token.rb', line 1068 def address @address end |
#address_kana ⇒ Object
The Kana variation of the person’s address (Japan only).
1070 1071 1072 |
# File 'lib/stripe/resources/token.rb', line 1070 def address_kana @address_kana end |
#address_kanji ⇒ Object
The Kanji variation of the person’s address (Japan only).
1072 1073 1074 |
# File 'lib/stripe/resources/token.rb', line 1072 def address_kanji @address_kanji end |
#dob ⇒ Object
The person’s date of birth.
1074 1075 1076 |
# File 'lib/stripe/resources/token.rb', line 1074 def dob @dob end |
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
1076 1077 1078 |
# File 'lib/stripe/resources/token.rb', line 1076 def documents @documents end |
#email ⇒ Object
The person’s email address.
1078 1079 1080 |
# File 'lib/stripe/resources/token.rb', line 1078 def email @email end |
#first_name ⇒ Object
The person’s first name.
1080 1081 1082 |
# File 'lib/stripe/resources/token.rb', line 1080 def first_name @first_name end |
#first_name_kana ⇒ Object
The Kana variation of the person’s first name (Japan only).
1082 1083 1084 |
# File 'lib/stripe/resources/token.rb', line 1082 def first_name_kana @first_name_kana end |
#first_name_kanji ⇒ Object
The Kanji variation of the person’s first name (Japan only).
1084 1085 1086 |
# File 'lib/stripe/resources/token.rb', line 1084 def first_name_kanji @first_name_kanji end |
#full_name_aliases ⇒ Object
A list of alternate names or aliases that the person is known by.
1086 1087 1088 |
# File 'lib/stripe/resources/token.rb', line 1086 def full_name_aliases @full_name_aliases end |
#gender ⇒ Object
The person’s gender (International regulations require either “male” or “female”).
1088 1089 1090 |
# File 'lib/stripe/resources/token.rb', line 1088 def gender @gender end |
#id_number ⇒ Object
The person’s ID number, as appropriate for their country. For example, a social security number in the U.S., social insurance number in Canada, etc. Instead of the number itself, you can also provide a [PII token provided by Stripe.js](docs.stripe.com/js/tokens/create_token?type=pii).
1090 1091 1092 |
# File 'lib/stripe/resources/token.rb', line 1090 def id_number @id_number end |
#id_number_secondary ⇒ Object
The person’s secondary ID number, as appropriate for their country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a [PII token provided by Stripe.js](docs.stripe.com/js/tokens/create_token?type=pii).
1092 1093 1094 |
# File 'lib/stripe/resources/token.rb', line 1092 def id_number_secondary @id_number_secondary end |
#last_name ⇒ Object
The person’s last name.
1094 1095 1096 |
# File 'lib/stripe/resources/token.rb', line 1094 def last_name @last_name end |
#last_name_kana ⇒ Object
The Kana variation of the person’s last name (Japan only).
1096 1097 1098 |
# File 'lib/stripe/resources/token.rb', line 1096 def last_name_kana @last_name_kana end |
#last_name_kanji ⇒ Object
The Kanji variation of the person’s last name (Japan only).
1098 1099 1100 |
# File 'lib/stripe/resources/token.rb', line 1098 def last_name_kanji @last_name_kanji end |
#maiden_name ⇒ Object
The person’s maiden name.
1100 1101 1102 |
# File 'lib/stripe/resources/token.rb', line 1100 def maiden_name @maiden_name end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
1102 1103 1104 |
# File 'lib/stripe/resources/token.rb', line 1102 def @metadata end |
#nationality ⇒ Object
The country where the person is a national. Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)), or “XX” if unavailable.
1104 1105 1106 |
# File 'lib/stripe/resources/token.rb', line 1104 def nationality @nationality end |
#phone ⇒ Object
The person’s phone number.
1106 1107 1108 |
# File 'lib/stripe/resources/token.rb', line 1106 def phone @phone end |
#political_exposure ⇒ Object
Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
1108 1109 1110 |
# File 'lib/stripe/resources/token.rb', line 1108 def political_exposure @political_exposure end |
#registered_address ⇒ Object
The person’s registered address.
1110 1111 1112 |
# File 'lib/stripe/resources/token.rb', line 1110 def registered_address @registered_address end |
#relationship ⇒ Object
The relationship that this person has with the account’s legal entity.
1112 1113 1114 |
# File 'lib/stripe/resources/token.rb', line 1112 def relationship @relationship end |
#ssn_last_4 ⇒ Object
The last four digits of the person’s Social Security number (U.S. only).
1114 1115 1116 |
# File 'lib/stripe/resources/token.rb', line 1114 def ssn_last_4 @ssn_last_4 end |
#us_cfpb_data ⇒ Object
Demographic data related to the person.
1116 1117 1118 |
# File 'lib/stripe/resources/token.rb', line 1116 def us_cfpb_data @us_cfpb_data end |
#verification ⇒ Object
The person’s verification status.
1118 1119 1120 |
# File 'lib/stripe/resources/token.rb', line 1118 def verification @verification end |