Class: Stripe::Token::CreateParams::Person::AdditionalTosAcceptances::Account

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/token.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ Account

Returns a new instance of Account.



733
734
735
736
737
# File 'lib/stripe/resources/token.rb', line 733

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



727
728
729
# File 'lib/stripe/resources/token.rb', line 727

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



729
730
731
# File 'lib/stripe/resources/token.rb', line 729

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



731
732
733
# File 'lib/stripe/resources/token.rb', line 731

def user_agent
  @user_agent
end