Class: Stripe::Token::CreateParams::Person::Documents

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/token.rb

Defined Under Namespace

Classes: CompanyAuthorization, Passport, Visa

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(company_authorization: nil, passport: nil, visa: nil) ⇒ Documents

Returns a new instance of Documents.



916
917
918
919
920
# File 'lib/stripe/resources/token.rb', line 916

def initialize(company_authorization: nil, passport: nil, visa: nil)
  @company_authorization = company_authorization
  @passport = passport
  @visa = visa
end

Instance Attribute Details

#company_authorizationObject

One or more documents that demonstrate proof that this person is authorized to represent the company.



910
911
912
# File 'lib/stripe/resources/token.rb', line 910

def company_authorization
  @company_authorization
end

#passportObject

One or more documents showing the person’s passport page with photo and personal data.



912
913
914
# File 'lib/stripe/resources/token.rb', line 912

def passport
  @passport
end

#visaObject

One or more documents showing the person’s visa required for living in the country where they are residing.



914
915
916
# File 'lib/stripe/resources/token.rb', line 914

def visa
  @visa
end