Class: Stripe::Token::CreateParams::Person::Verification::Document

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/token.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(back: nil, front: nil) ⇒ Document

Returns a new instance of Document.



1050
1051
1052
1053
# File 'lib/stripe/resources/token.rb', line 1050

def initialize(back: nil, front: nil)
  @back = back
  @front = front
end

Instance Attribute Details

#backObject

The back of an ID returned by a [file upload](stripe.com/docs/api#create_file) with a ‘purpose` value of `identity_document`. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.



1046
1047
1048
# File 'lib/stripe/resources/token.rb', line 1046

def back
  @back
end

#frontObject

The front of an ID returned by a [file upload](stripe.com/docs/api#create_file) with a ‘purpose` value of `identity_document`. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.



1048
1049
1050
# File 'lib/stripe/resources/token.rb', line 1048

def front
  @front
end