Class: Stripe::TokenCreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/token_create_params.rb

Defined Under Namespace

Classes: Account, BankAccount, Card, CvcUpdate, Person, Pii

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(account: nil, bank_account: nil, card: nil, customer: nil, cvc_update: nil, expand: nil, person: nil, pii: nil) ⇒ TokenCreateParams

Returns a new instance of TokenCreateParams.



1402
1403
1404
1405
1406
1407
1408
1409
1410
1411
1412
1413
1414
1415
1416
1417
1418
1419
1420
# File 'lib/stripe/params/token_create_params.rb', line 1402

def initialize(
  account: nil,
  bank_account: nil,
  card: nil,
  customer: nil,
  cvc_update: nil,
  expand: nil,
  person: nil,
  pii: nil
)
  @account = 
  @bank_account = 
  @card = card
  @customer = customer
  @cvc_update = cvc_update
  @expand = expand
  @person = person
  @pii = pii
end

Instance Attribute Details

#accountObject

Information for the account this token represents.



1386
1387
1388
# File 'lib/stripe/params/token_create_params.rb', line 1386

def 
  @account
end

#bank_accountObject

The bank account this token will represent.



1388
1389
1390
# File 'lib/stripe/params/token_create_params.rb', line 1388

def 
  @bank_account
end

#cardObject

The card this token will represent. If you also pass in a customer, the card must be the ID of a card belonging to the customer. Otherwise, if you do not pass in a customer, this is a dictionary containing a user's credit card details, with the options described below.



1390
1391
1392
# File 'lib/stripe/params/token_create_params.rb', line 1390

def card
  @card
end

#customerObject

Create a token for the customer, which is owned by the application's account. You can only use this with an OAuth access token or Stripe-Account header. Learn more about cloning saved payment methods.



1392
1393
1394
# File 'lib/stripe/params/token_create_params.rb', line 1392

def customer
  @customer
end

#cvc_updateObject

The updated CVC value this token represents.



1394
1395
1396
# File 'lib/stripe/params/token_create_params.rb', line 1394

def cvc_update
  @cvc_update
end

#expandObject

Specifies which fields in the response should be expanded.



1396
1397
1398
# File 'lib/stripe/params/token_create_params.rb', line 1396

def expand
  @expand
end

#personObject

Information for the person this token represents.



1398
1399
1400
# File 'lib/stripe/params/token_create_params.rb', line 1398

def person
  @person
end

#piiObject

The PII this token represents.



1400
1401
1402
# File 'lib/stripe/params/token_create_params.rb', line 1400

def pii
  @pii
end