Class: Stripe::TokenCreateParams::Account::Company::DirectorshipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/token_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ DirectorshipDeclaration

Returns a new instance of DirectorshipDeclaration.



148
149
150
151
152
# File 'lib/stripe/params/token_create_params.rb', line 148

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the directorship declaration attestation was made.



142
143
144
# File 'lib/stripe/params/token_create_params.rb', line 142

def date
  @date
end

#ipObject

The IP address from which the directorship declaration attestation was made.



144
145
146
# File 'lib/stripe/params/token_create_params.rb', line 144

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the directorship declaration attestation was made.



146
147
148
# File 'lib/stripe/params/token_create_params.rb', line 146

def user_agent
  @user_agent
end