Class: Stripe::TokenCreateParams::Account::Company::OwnershipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/token_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ OwnershipDeclaration

Returns a new instance of OwnershipDeclaration.



163
164
165
166
167
# File 'lib/stripe/params/token_create_params.rb', line 163

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the beneficial owner attestation was made.



157
158
159
# File 'lib/stripe/params/token_create_params.rb', line 157

def date
  @date
end

#ipObject

The IP address from which the beneficial owner attestation was made.



159
160
161
# File 'lib/stripe/params/token_create_params.rb', line 159

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the beneficial owner attestation was made.



161
162
163
# File 'lib/stripe/params/token_create_params.rb', line 161

def user_agent
  @user_agent
end