Class: Stripe::TokenCreateParams::Account::Individual::Relationship
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::TokenCreateParams::Account::Individual::Relationship
- Defined in:
- lib/stripe/params/token_create_params.rb
Instance Attribute Summary collapse
-
#director ⇒ Object
Whether the person is a director of the account's legal entity.
-
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
-
#owner ⇒ Object
Whether the person is an owner of the account’s legal entity.
-
#percent_ownership ⇒ Object
The percent owned by the person of the account's legal entity.
-
#title ⇒ Object
The person's title (e.g., CEO, Support Engineer).
Instance Method Summary collapse
-
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
constructor
A new instance of Relationship.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
Returns a new instance of Relationship.
522 523 524 525 526 527 528 529 530 531 532 533 534 |
# File 'lib/stripe/params/token_create_params.rb', line 522 def initialize( director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil ) @director = director @executive = executive @owner = owner @percent_ownership = percent_ownership @title = title end |
Instance Attribute Details
#director ⇒ Object
Whether the person is a director of the account's legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.
512 513 514 |
# File 'lib/stripe/params/token_create_params.rb', line 512 def director @director end |
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
514 515 516 |
# File 'lib/stripe/params/token_create_params.rb', line 514 def executive @executive end |
#owner ⇒ Object
Whether the person is an owner of the account’s legal entity.
516 517 518 |
# File 'lib/stripe/params/token_create_params.rb', line 516 def owner @owner end |
#percent_ownership ⇒ Object
The percent owned by the person of the account's legal entity.
518 519 520 |
# File 'lib/stripe/params/token_create_params.rb', line 518 def percent_ownership @percent_ownership end |
#title ⇒ Object
The person's title (e.g., CEO, Support Engineer).
520 521 522 |
# File 'lib/stripe/params/token_create_params.rb', line 520 def title @title end |