Class: Stripe::TokenCreateParams::Card

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/token_create_params.rb

Defined Under Namespace

Classes: Networks

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(address_city: nil, address_country: nil, address_line1: nil, address_line2: nil, address_state: nil, address_zip: nil, currency: nil, cvc: nil, exp_month: nil, exp_year: nil, name: nil, networks: nil, number: nil) ⇒ Card

Returns a new instance of Card.



827
828
829
830
831
832
833
834
835
836
837
838
839
840
841
842
843
844
845
846
847
848
849
850
851
852
853
854
855
# File 'lib/stripe/params/token_create_params.rb', line 827

def initialize(
  address_city: nil,
  address_country: nil,
  address_line1: nil,
  address_line2: nil,
  address_state: nil,
  address_zip: nil,
  currency: nil,
  cvc: nil,
  exp_month: nil,
  exp_year: nil,
  name: nil,
  networks: nil,
  number: nil
)
  @address_city = address_city
  @address_country = address_country
  @address_line1 = address_line1
  @address_line2 = address_line2
  @address_state = address_state
  @address_zip = address_zip
  @currency = currency
  @cvc = cvc
  @exp_month = exp_month
  @exp_year = exp_year
  @name = name
  @networks = networks
  @number = number
end

Instance Attribute Details

#address_cityObject

City / District / Suburb / Town / Village.



801
802
803
# File 'lib/stripe/params/token_create_params.rb', line 801

def address_city
  @address_city
end

#address_countryObject

Billing address country, if provided.



803
804
805
# File 'lib/stripe/params/token_create_params.rb', line 803

def address_country
  @address_country
end

#address_line1Object

Address line 1 (Street address / PO Box / Company name).



805
806
807
# File 'lib/stripe/params/token_create_params.rb', line 805

def address_line1
  @address_line1
end

#address_line2Object

Address line 2 (Apartment / Suite / Unit / Building).



807
808
809
# File 'lib/stripe/params/token_create_params.rb', line 807

def address_line2
  @address_line2
end

#address_stateObject

State / County / Province / Region.



809
810
811
# File 'lib/stripe/params/token_create_params.rb', line 809

def address_state
  @address_state
end

#address_zipObject

ZIP or postal code.



811
812
813
# File 'lib/stripe/params/token_create_params.rb', line 811

def address_zip
  @address_zip
end

#currencyObject

Required in order to add the card to an account; in all other cases, this parameter is not used. When added to an account, the card (which must be a debit card) can be used as a transfer destination for funds in this currency.



813
814
815
# File 'lib/stripe/params/token_create_params.rb', line 813

def currency
  @currency
end

#cvcObject

Card security code. Highly recommended to always include this value.



815
816
817
# File 'lib/stripe/params/token_create_params.rb', line 815

def cvc
  @cvc
end

#exp_monthObject

Two-digit number representing the card's expiration month.



817
818
819
# File 'lib/stripe/params/token_create_params.rb', line 817

def exp_month
  @exp_month
end

#exp_yearObject

Two- or four-digit number representing the card's expiration year.



819
820
821
# File 'lib/stripe/params/token_create_params.rb', line 819

def exp_year
  @exp_year
end

#nameObject

Cardholder's full name.



821
822
823
# File 'lib/stripe/params/token_create_params.rb', line 821

def name
  @name
end

#networksObject

Contains information about card networks used to process the payment.



823
824
825
# File 'lib/stripe/params/token_create_params.rb', line 823

def networks
  @networks
end

#numberObject

The card number, as a string without any separators.



825
826
827
# File 'lib/stripe/params/token_create_params.rb', line 825

def number
  @number
end