Class: Stripe::TokenCreateParams::Person

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/token_create_params.rb

Defined Under Namespace

Classes: AdditionalTosAcceptances, Address, AddressKana, AddressKanji, BirthAddress, Dob, Documents, RegisteredAddress, Relationship, SelfReportedIncome, SelfReportedMonthlyHousingPayment, UsCfpbData, Verification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(additional_tos_acceptances: nil, address: nil, address_kana: nil, address_kanji: nil, birth_address: nil, dob: nil, documents: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, nationality: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, self_reported_income: nil, self_reported_monthly_housing_payment: nil, ssn_last_4: nil, us_cfpb_data: nil, verification: nil) ⇒ Person

Returns a new instance of Person.



1312
1313
1314
1315
1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
1342
1343
1344
1345
1346
1347
1348
1349
1350
1351
1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
1362
1363
1364
1365
1366
1367
1368
1369
1370
1371
1372
1373
1374
# File 'lib/stripe/params/token_create_params.rb', line 1312

def initialize(
  additional_tos_acceptances: nil,
  address: nil,
  address_kana: nil,
  address_kanji: nil,
  birth_address: nil,
  dob: nil,
  documents: nil,
  email: nil,
  first_name: nil,
  first_name_kana: nil,
  first_name_kanji: nil,
  full_name_aliases: nil,
  gender: nil,
  id_number: nil,
  id_number_secondary: nil,
  last_name: nil,
  last_name_kana: nil,
  last_name_kanji: nil,
  maiden_name: nil,
  metadata: nil,
  nationality: nil,
  phone: nil,
  political_exposure: nil,
  registered_address: nil,
  relationship: nil,
  self_reported_income: nil,
  self_reported_monthly_housing_payment: nil,
  ssn_last_4: nil,
  us_cfpb_data: nil,
  verification: nil
)
  @additional_tos_acceptances = additional_tos_acceptances
  @address = address
  @address_kana = address_kana
  @address_kanji = address_kanji
  @birth_address = birth_address
  @dob = dob
  @documents = documents
  @email = email
  @first_name = first_name
  @first_name_kana = first_name_kana
  @first_name_kanji = first_name_kanji
  @full_name_aliases = full_name_aliases
  @gender = gender
  @id_number = id_number
  @id_number_secondary = id_number_secondary
  @last_name = last_name
  @last_name_kana = last_name_kana
  @last_name_kanji = last_name_kanji
  @maiden_name = maiden_name
  @metadata = 
  @nationality = nationality
  @phone = phone
  @political_exposure = political_exposure
  @registered_address = registered_address
  @relationship = relationship
  @self_reported_income = self_reported_income
  @self_reported_monthly_housing_payment = self_reported_monthly_housing_payment
  @ssn_last_4 = ssn_last_4
  @us_cfpb_data = us_cfpb_data
  @verification = verification
end

Instance Attribute Details

#additional_tos_acceptancesObject

Details on the legal guardian's or authorizer's acceptance of the required Stripe agreements.



1246
1247
1248
# File 'lib/stripe/params/token_create_params.rb', line 1246

def additional_tos_acceptances
  @additional_tos_acceptances
end

#addressObject

The person's address.



1248
1249
1250
# File 'lib/stripe/params/token_create_params.rb', line 1248

def address
  @address
end

#address_kanaObject

The Kana variation of the person's address (Japan only).



1250
1251
1252
# File 'lib/stripe/params/token_create_params.rb', line 1250

def address_kana
  @address_kana
end

#address_kanjiObject

The Kanji variation of the person's address (Japan only).



1252
1253
1254
# File 'lib/stripe/params/token_create_params.rb', line 1252

def address_kanji
  @address_kanji
end

#birth_addressObject

The person's place of birth.



1254
1255
1256
# File 'lib/stripe/params/token_create_params.rb', line 1254

def birth_address
  @birth_address
end

#dobObject

The person's date of birth.



1256
1257
1258
# File 'lib/stripe/params/token_create_params.rb', line 1256

def dob
  @dob
end

#documentsObject

Documents that may be submitted to satisfy various informational requests.



1258
1259
1260
# File 'lib/stripe/params/token_create_params.rb', line 1258

def documents
  @documents
end

#emailObject

The person's email address.



1260
1261
1262
# File 'lib/stripe/params/token_create_params.rb', line 1260

def email
  @email
end

#first_nameObject

The person's first name.



1262
1263
1264
# File 'lib/stripe/params/token_create_params.rb', line 1262

def first_name
  @first_name
end

#first_name_kanaObject

The Kana variation of the person's first name (Japan only).



1264
1265
1266
# File 'lib/stripe/params/token_create_params.rb', line 1264

def first_name_kana
  @first_name_kana
end

#first_name_kanjiObject

The Kanji variation of the person's first name (Japan only).



1266
1267
1268
# File 'lib/stripe/params/token_create_params.rb', line 1266

def first_name_kanji
  @first_name_kanji
end

#full_name_aliasesObject

A list of alternate names or aliases that the person is known by.



1268
1269
1270
# File 'lib/stripe/params/token_create_params.rb', line 1268

def full_name_aliases
  @full_name_aliases
end

#genderObject

The person's gender (International regulations require either "male" or "female").



1270
1271
1272
# File 'lib/stripe/params/token_create_params.rb', line 1270

def gender
  @gender
end

#id_numberObject

The person's ID number, as appropriate for their country. For example, a social security number in the U.S., social insurance number in Canada, etc. Instead of the number itself, you can also provide a PII token provided by Stripe.js.

Changing this value for the account's representative requires that the account re-accept the terms of service.



1274
1275
1276
# File 'lib/stripe/params/token_create_params.rb', line 1274

def id_number
  @id_number
end

#id_number_secondaryObject

The person's secondary ID number, as appropriate for their country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a PII token provided by Stripe.js.

Changing this value for the account's representative requires that the account re-accept the terms of service.



1278
1279
1280
# File 'lib/stripe/params/token_create_params.rb', line 1278

def id_number_secondary
  @id_number_secondary
end

#last_nameObject

The person's last name.



1280
1281
1282
# File 'lib/stripe/params/token_create_params.rb', line 1280

def last_name
  @last_name
end

#last_name_kanaObject

The Kana variation of the person's last name (Japan only).



1282
1283
1284
# File 'lib/stripe/params/token_create_params.rb', line 1282

def last_name_kana
  @last_name_kana
end

#last_name_kanjiObject

The Kanji variation of the person's last name (Japan only).



1284
1285
1286
# File 'lib/stripe/params/token_create_params.rb', line 1284

def last_name_kanji
  @last_name_kanji
end

#maiden_nameObject

The person's maiden name.



1286
1287
1288
# File 'lib/stripe/params/token_create_params.rb', line 1286

def maiden_name
  @maiden_name
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.



1288
1289
1290
# File 'lib/stripe/params/token_create_params.rb', line 1288

def 
  @metadata
end

#nationalityObject

The country where the person is a national. Two-letter country code (ISO 3166-1 alpha-2), or "XX" if unavailable.



1290
1291
1292
# File 'lib/stripe/params/token_create_params.rb', line 1290

def nationality
  @nationality
end

#phoneObject

The person's phone number.



1292
1293
1294
# File 'lib/stripe/params/token_create_params.rb', line 1292

def phone
  @phone
end

#political_exposureObject

Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.



1294
1295
1296
# File 'lib/stripe/params/token_create_params.rb', line 1294

def political_exposure
  @political_exposure
end

#registered_addressObject

The person's registered address.



1296
1297
1298
# File 'lib/stripe/params/token_create_params.rb', line 1296

def registered_address
  @registered_address
end

#relationshipObject

The relationship that this person has with the account's legal entity.



1298
1299
1300
# File 'lib/stripe/params/token_create_params.rb', line 1298

def relationship
  @relationship
end

#self_reported_incomeObject

The credit applicant's self-reported yearly income in minor units.



1300
1301
1302
# File 'lib/stripe/params/token_create_params.rb', line 1300

def self_reported_income
  @self_reported_income
end

#self_reported_monthly_housing_paymentObject

The credit applicant's self-reported monthly housing payment in minor units.



1302
1303
1304
# File 'lib/stripe/params/token_create_params.rb', line 1302

def self_reported_monthly_housing_payment
  @self_reported_monthly_housing_payment
end

#ssn_last_4Object

The last four digits of the person's Social Security number (U.S. only).

Changing this value for the account's representative requires that the account re-accept the terms of service.



1306
1307
1308
# File 'lib/stripe/params/token_create_params.rb', line 1306

def ssn_last_4
  @ssn_last_4
end

#us_cfpb_dataObject

Demographic data related to the person.



1308
1309
1310
# File 'lib/stripe/params/token_create_params.rb', line 1308

def us_cfpb_data
  @us_cfpb_data
end

#verificationObject

The person's verification status.



1310
1311
1312
# File 'lib/stripe/params/token_create_params.rb', line 1310

def verification
  @verification
end