Class: Stripe::TokenCreateParams::Person::AdditionalTosAcceptances::Account

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/token_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ Account

Returns a new instance of Account.



877
878
879
880
881
# File 'lib/stripe/params/token_create_params.rb', line 877

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



871
872
873
# File 'lib/stripe/params/token_create_params.rb', line 871

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



873
874
875
# File 'lib/stripe/params/token_create_params.rb', line 873

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



875
876
877
# File 'lib/stripe/params/token_create_params.rb', line 875

def user_agent
  @user_agent
end