Class: Stripe::TokenCreateParams::Person::Documents

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/token_create_params.rb

Defined Under Namespace

Classes: CompanyAuthorization, Passport, Visa

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(company_authorization: nil, passport: nil, visa: nil) ⇒ Documents

Returns a new instance of Documents.



1072
1073
1074
1075
1076
# File 'lib/stripe/params/token_create_params.rb', line 1072

def initialize(company_authorization: nil, passport: nil, visa: nil)
  @company_authorization = company_authorization
  @passport = passport
  @visa = visa
end

Instance Attribute Details

#company_authorizationObject

One or more documents that demonstrate proof that this person is authorized to represent the company.



1066
1067
1068
# File 'lib/stripe/params/token_create_params.rb', line 1066

def company_authorization
  @company_authorization
end

#passportObject

One or more documents showing the person's passport page with photo and personal data.



1068
1069
1070
# File 'lib/stripe/params/token_create_params.rb', line 1068

def passport
  @passport
end

#visaObject

One or more documents showing the person's visa required for living in the country where they are residing.



1070
1071
1072
# File 'lib/stripe/params/token_create_params.rb', line 1070

def visa
  @visa
end