Class: Stripe::TokenCreateParams::Person::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/token_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(authorizer: nil, director: nil, executive: nil, legal_guardian: nil, owner: nil, percent_ownership: nil, representative: nil, title: nil) ⇒ Relationship

Returns a new instance of Relationship.



1128
1129
1130
1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
# File 'lib/stripe/params/token_create_params.rb', line 1128

def initialize(
  authorizer: nil,
  director: nil,
  executive: nil,
  legal_guardian: nil,
  owner: nil,
  percent_ownership: nil,
  representative: nil,
  title: nil
)
  @authorizer = authorizer
  @director = director
  @executive = executive
  @legal_guardian = legal_guardian
  @owner = owner
  @percent_ownership = percent_ownership
  @representative = representative
  @title = title
end

Instance Attribute Details

#authorizerObject

Whether the person is the authorizer of the account's representative.



1112
1113
1114
# File 'lib/stripe/params/token_create_params.rb', line 1112

def authorizer
  @authorizer
end

#directorObject

Whether the person is a director of the account's legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



1114
1115
1116
# File 'lib/stripe/params/token_create_params.rb', line 1114

def director
  @director
end

#executiveObject

Whether the person has significant responsibility to control, manage, or direct the organization.



1116
1117
1118
# File 'lib/stripe/params/token_create_params.rb', line 1116

def executive
  @executive
end

Whether the person is the legal guardian of the account's representative.



1118
1119
1120
# File 'lib/stripe/params/token_create_params.rb', line 1118

def legal_guardian
  @legal_guardian
end

#ownerObject

Whether the person is an owner of the account’s legal entity.



1120
1121
1122
# File 'lib/stripe/params/token_create_params.rb', line 1120

def owner
  @owner
end

#percent_ownershipObject

The percent owned by the person of the account's legal entity.



1122
1123
1124
# File 'lib/stripe/params/token_create_params.rb', line 1122

def percent_ownership
  @percent_ownership
end

#representativeObject

Whether the person is authorized as the primary representative of the account. This is the person nominated by the business to provide information about themselves, and general information about the account. There can only be one representative at any given time. At the time the account is created, this person should be set to the person responsible for opening the account.



1124
1125
1126
# File 'lib/stripe/params/token_create_params.rb', line 1124

def representative
  @representative
end

#titleObject

The person's title (e.g., CEO, Support Engineer).



1126
1127
1128
# File 'lib/stripe/params/token_create_params.rb', line 1126

def title
  @title
end