Class: Stripe::TokenCreateParams::Person::Verification::AdditionalDocument

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/token_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(back: nil, front: nil) ⇒ AdditionalDocument

Returns a new instance of AdditionalDocument.



1080
1081
1082
1083
# File 'lib/stripe/params/token_create_params.rb', line 1080

def initialize(back: nil, front: nil)
  @back = back
  @front = front
end

Instance Attribute Details

#backObject

The back of an ID returned by a [file upload](api.stripe.com#create_file) with a ‘purpose` value of `identity_document`. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.



1076
1077
1078
# File 'lib/stripe/params/token_create_params.rb', line 1076

def back
  @back
end

#frontObject

The front of an ID returned by a [file upload](api.stripe.com#create_file) with a ‘purpose` value of `identity_document`. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.



1078
1079
1080
# File 'lib/stripe/params/token_create_params.rb', line 1078

def front
  @front
end