Class: Stripe::TokenService::CreateParams::Account

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/token_service.rb

Defined Under Namespace

Classes: Company, Individual

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(business_type: nil, company: nil, individual: nil, tos_shown_and_accepted: nil) ⇒ Account

Returns a new instance of Account.



596
597
598
599
600
601
602
603
604
605
606
# File 'lib/stripe/services/token_service.rb', line 596

def initialize(
  business_type: nil,
  company: nil,
  individual: nil,
  tos_shown_and_accepted: nil
)
  @business_type = business_type
  @company = company
  @individual = individual
  @tos_shown_and_accepted = tos_shown_and_accepted
end

Instance Attribute Details

#business_typeObject

The business type.



588
589
590
# File 'lib/stripe/services/token_service.rb', line 588

def business_type
  @business_type
end

#companyObject

Information about the company or business.



590
591
592
# File 'lib/stripe/services/token_service.rb', line 590

def company
  @company
end

#individualObject

Information about the person represented by the account.



592
593
594
# File 'lib/stripe/services/token_service.rb', line 592

def individual
  @individual
end

#tos_shown_and_acceptedObject

Whether the user described by the data in the token has been shown [the Stripe Connected Account Agreement](/connect/account-tokens#stripe-connected-account-agreement). When creating an account token to create a new Connect account, this value must be ‘true`.



594
595
596
# File 'lib/stripe/services/token_service.rb', line 594

def tos_shown_and_accepted
  @tos_shown_and_accepted
end