Class: Stripe::TokenService::CreateParams::Account::Company::OwnershipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/token_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ OwnershipDeclaration

Returns a new instance of OwnershipDeclaration.



146
147
148
149
150
# File 'lib/stripe/services/token_service.rb', line 146

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the beneficial owner attestation was made.



138
139
140
# File 'lib/stripe/services/token_service.rb', line 138

def date
  @date
end

#ipObject

The IP address from which the beneficial owner attestation was made.



141
142
143
# File 'lib/stripe/services/token_service.rb', line 141

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the beneficial owner attestation was made.



144
145
146
# File 'lib/stripe/services/token_service.rb', line 144

def user_agent
  @user_agent
end