Class: Stripe::TokenService::CreateParams::Account::Individual

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/token_service.rb

Defined Under Namespace

Classes: Address, AddressKana, AddressKanji, Dob, RegisteredAddress, Relationship, Verification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, address_kana: nil, address_kanji: nil, dob: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil) ⇒ Individual

Returns a new instance of Individual.



537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
# File 'lib/stripe/services/token_service.rb', line 537

def initialize(
  address: nil,
  address_kana: nil,
  address_kanji: nil,
  dob: nil,
  email: nil,
  first_name: nil,
  first_name_kana: nil,
  first_name_kanji: nil,
  full_name_aliases: nil,
  gender: nil,
  id_number: nil,
  id_number_secondary: nil,
  last_name: nil,
  last_name_kana: nil,
  last_name_kanji: nil,
  maiden_name: nil,
  metadata: nil,
  phone: nil,
  political_exposure: nil,
  registered_address: nil,
  relationship: nil,
  ssn_last_4: nil,
  verification: nil
)
  @address = address
  @address_kana = address_kana
  @address_kanji = address_kanji
  @dob = dob
  @email = email
  @first_name = first_name
  @first_name_kana = first_name_kana
  @first_name_kanji = first_name_kanji
  @full_name_aliases = full_name_aliases
  @gender = gender
  @id_number = id_number
  @id_number_secondary = id_number_secondary
  @last_name = last_name
  @last_name_kana = last_name_kana
  @last_name_kanji = last_name_kanji
  @maiden_name = maiden_name
  @metadata = 
  @phone = phone
  @political_exposure = political_exposure
  @registered_address = registered_address
  @relationship = relationship
  @ssn_last_4 = ssn_last_4
  @verification = verification
end

Instance Attribute Details

#addressObject

The individual’s primary address.



491
492
493
# File 'lib/stripe/services/token_service.rb', line 491

def address
  @address
end

#address_kanaObject

The Kana variation of the individual’s primary address (Japan only).



493
494
495
# File 'lib/stripe/services/token_service.rb', line 493

def address_kana
  @address_kana
end

#address_kanjiObject

The Kanji variation of the individual’s primary address (Japan only).



495
496
497
# File 'lib/stripe/services/token_service.rb', line 495

def address_kanji
  @address_kanji
end

#dobObject

The individual’s date of birth.



497
498
499
# File 'lib/stripe/services/token_service.rb', line 497

def dob
  @dob
end

#emailObject

The individual’s email address.



499
500
501
# File 'lib/stripe/services/token_service.rb', line 499

def email
  @email
end

#first_nameObject

The individual’s first name.



501
502
503
# File 'lib/stripe/services/token_service.rb', line 501

def first_name
  @first_name
end

#first_name_kanaObject

The Kana variation of the individual’s first name (Japan only).



503
504
505
# File 'lib/stripe/services/token_service.rb', line 503

def first_name_kana
  @first_name_kana
end

#first_name_kanjiObject

The Kanji variation of the individual’s first name (Japan only).



505
506
507
# File 'lib/stripe/services/token_service.rb', line 505

def first_name_kanji
  @first_name_kanji
end

#full_name_aliasesObject

A list of alternate names or aliases that the individual is known by.



507
508
509
# File 'lib/stripe/services/token_service.rb', line 507

def full_name_aliases
  @full_name_aliases
end

#genderObject

The individual’s gender



509
510
511
# File 'lib/stripe/services/token_service.rb', line 509

def gender
  @gender
end

#id_numberObject

The government-issued ID number of the individual, as appropriate for the representative’s country. (Examples are a Social Security Number in the U.S., or a Social Insurance Number in Canada). Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).



511
512
513
# File 'lib/stripe/services/token_service.rb', line 511

def id_number
  @id_number
end

#id_number_secondaryObject

The government-issued secondary ID number of the individual, as appropriate for the representative’s country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).



513
514
515
# File 'lib/stripe/services/token_service.rb', line 513

def id_number_secondary
  @id_number_secondary
end

#last_nameObject

The individual’s last name.



515
516
517
# File 'lib/stripe/services/token_service.rb', line 515

def last_name
  @last_name
end

#last_name_kanaObject

The Kana variation of the individual’s last name (Japan only).



517
518
519
# File 'lib/stripe/services/token_service.rb', line 517

def last_name_kana
  @last_name_kana
end

#last_name_kanjiObject

The Kanji variation of the individual’s last name (Japan only).



519
520
521
# File 'lib/stripe/services/token_service.rb', line 519

def last_name_kanji
  @last_name_kanji
end

#maiden_nameObject

The individual’s maiden name.



521
522
523
# File 'lib/stripe/services/token_service.rb', line 521

def maiden_name
  @maiden_name
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



523
524
525
# File 'lib/stripe/services/token_service.rb', line 523

def 
  @metadata
end

#phoneObject

The individual’s phone number.



525
526
527
# File 'lib/stripe/services/token_service.rb', line 525

def phone
  @phone
end

#political_exposureObject

Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.



527
528
529
# File 'lib/stripe/services/token_service.rb', line 527

def political_exposure
  @political_exposure
end

#registered_addressObject

The individual’s registered address.



529
530
531
# File 'lib/stripe/services/token_service.rb', line 529

def registered_address
  @registered_address
end

#relationshipObject

Describes the person’s relationship to the account.



531
532
533
# File 'lib/stripe/services/token_service.rb', line 531

def relationship
  @relationship
end

#ssn_last_4Object

The last four digits of the individual’s Social Security Number (U.S. only).



533
534
535
# File 'lib/stripe/services/token_service.rb', line 533

def ssn_last_4
  @ssn_last_4
end

#verificationObject

The individual’s verification document information.



535
536
537
# File 'lib/stripe/services/token_service.rb', line 535

def verification
  @verification
end