Class: Stripe::TokenService::CreateParams::Account::Individual::Relationship
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::TokenService::CreateParams::Account::Individual::Relationship
- Defined in:
- lib/stripe/services/token_service.rb
Instance Attribute Summary collapse
-
#director ⇒ Object
Whether the person is a director of the account’s legal entity.
-
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
-
#owner ⇒ Object
Whether the person is an owner of the account’s legal entity.
-
#percent_ownership ⇒ Object
The percent owned by the person of the account’s legal entity.
-
#title ⇒ Object
The person’s title (e.g., CEO, Support Engineer).
Instance Method Summary collapse
-
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
constructor
A new instance of Relationship.
Methods inherited from RequestParams
Constructor Details
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
Returns a new instance of Relationship.
441 442 443 444 445 446 447 448 449 450 451 452 453 |
# File 'lib/stripe/services/token_service.rb', line 441 def initialize( director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil ) @director = director @executive = executive @owner = owner @percent_ownership = percent_ownership @title = title end |
Instance Attribute Details
#director ⇒ Object
Whether the person is a director of the account’s legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.
431 432 433 |
# File 'lib/stripe/services/token_service.rb', line 431 def director @director end |
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
433 434 435 |
# File 'lib/stripe/services/token_service.rb', line 433 def executive @executive end |
#owner ⇒ Object
Whether the person is an owner of the account’s legal entity.
435 436 437 |
# File 'lib/stripe/services/token_service.rb', line 435 def owner @owner end |
#percent_ownership ⇒ Object
The percent owned by the person of the account’s legal entity.
437 438 439 |
# File 'lib/stripe/services/token_service.rb', line 437 def percent_ownership @percent_ownership end |
#title ⇒ Object
The person’s title (e.g., CEO, Support Engineer).
439 440 441 |
# File 'lib/stripe/services/token_service.rb', line 439 def title @title end |