Class: Stripe::TokenService::CreateParams::Card

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/token_service.rb

Defined Under Namespace

Classes: Networks

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address_city: nil, address_country: nil, address_line1: nil, address_line2: nil, address_state: nil, address_zip: nil, currency: nil, cvc: nil, exp_month: nil, exp_year: nil, name: nil, networks: nil, number: nil) ⇒ Card

Returns a new instance of Card.



684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
# File 'lib/stripe/services/token_service.rb', line 684

def initialize(
  address_city: nil,
  address_country: nil,
  address_line1: nil,
  address_line2: nil,
  address_state: nil,
  address_zip: nil,
  currency: nil,
  cvc: nil,
  exp_month: nil,
  exp_year: nil,
  name: nil,
  networks: nil,
  number: nil
)
  @address_city = address_city
  @address_country = address_country
  @address_line1 = address_line1
  @address_line2 = address_line2
  @address_state = address_state
  @address_zip = address_zip
  @currency = currency
  @cvc = cvc
  @exp_month = exp_month
  @exp_year = exp_year
  @name = name
  @networks = networks
  @number = number
end

Instance Attribute Details

#address_cityObject

City / District / Suburb / Town / Village.



658
659
660
# File 'lib/stripe/services/token_service.rb', line 658

def address_city
  @address_city
end

#address_countryObject

Billing address country, if provided.



660
661
662
# File 'lib/stripe/services/token_service.rb', line 660

def address_country
  @address_country
end

#address_line1Object

Address line 1 (Street address / PO Box / Company name).



662
663
664
# File 'lib/stripe/services/token_service.rb', line 662

def address_line1
  @address_line1
end

#address_line2Object

Address line 2 (Apartment / Suite / Unit / Building).



664
665
666
# File 'lib/stripe/services/token_service.rb', line 664

def address_line2
  @address_line2
end

#address_stateObject

State / County / Province / Region.



666
667
668
# File 'lib/stripe/services/token_service.rb', line 666

def address_state
  @address_state
end

#address_zipObject

ZIP or postal code.



668
669
670
# File 'lib/stripe/services/token_service.rb', line 668

def address_zip
  @address_zip
end

#currencyObject

Required in order to add the card to an account; in all other cases, this parameter is not used. When added to an account, the card (which must be a debit card) can be used as a transfer destination for funds in this currency.



670
671
672
# File 'lib/stripe/services/token_service.rb', line 670

def currency
  @currency
end

#cvcObject

Card security code. Highly recommended to always include this value.



672
673
674
# File 'lib/stripe/services/token_service.rb', line 672

def cvc
  @cvc
end

#exp_monthObject

Two-digit number representing the card’s expiration month.



674
675
676
# File 'lib/stripe/services/token_service.rb', line 674

def exp_month
  @exp_month
end

#exp_yearObject

Two- or four-digit number representing the card’s expiration year.



676
677
678
# File 'lib/stripe/services/token_service.rb', line 676

def exp_year
  @exp_year
end

#nameObject

Cardholder’s full name.



678
679
680
# File 'lib/stripe/services/token_service.rb', line 678

def name
  @name
end

#networksObject

Contains information about card networks used to process the payment.



680
681
682
# File 'lib/stripe/services/token_service.rb', line 680

def networks
  @networks
end

#numberObject

The card number, as a string without any separators.



682
683
684
# File 'lib/stripe/services/token_service.rb', line 682

def number
  @number
end