Class: Stripe::TokenService::CreateParams::Person

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/token_service.rb

Defined Under Namespace

Classes: AdditionalTosAcceptances, Address, AddressKana, AddressKanji, Dob, Documents, RegisteredAddress, Relationship, Verification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(additional_tos_acceptances: nil, address: nil, address_kana: nil, address_kanji: nil, dob: nil, documents: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, nationality: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil) ⇒ Person

Returns a new instance of Person.



1197
1198
1199
1200
1201
1202
1203
1204
1205
1206
1207
1208
1209
1210
1211
1212
1213
1214
1215
1216
1217
1218
1219
1220
1221
1222
1223
1224
1225
1226
1227
1228
1229
1230
1231
1232
1233
1234
1235
1236
1237
1238
1239
1240
1241
1242
1243
1244
1245
1246
1247
1248
1249
1250
1251
# File 'lib/stripe/services/token_service.rb', line 1197

def initialize(
  additional_tos_acceptances: nil,
  address: nil,
  address_kana: nil,
  address_kanji: nil,
  dob: nil,
  documents: nil,
  email: nil,
  first_name: nil,
  first_name_kana: nil,
  first_name_kanji: nil,
  full_name_aliases: nil,
  gender: nil,
  id_number: nil,
  id_number_secondary: nil,
  last_name: nil,
  last_name_kana: nil,
  last_name_kanji: nil,
  maiden_name: nil,
  metadata: nil,
  nationality: nil,
  phone: nil,
  political_exposure: nil,
  registered_address: nil,
  relationship: nil,
  ssn_last_4: nil,
  verification: nil
)
  @additional_tos_acceptances = additional_tos_acceptances
  @address = address
  @address_kana = address_kana
  @address_kanji = address_kanji
  @dob = dob
  @documents = documents
  @email = email
  @first_name = first_name
  @first_name_kana = first_name_kana
  @first_name_kanji = first_name_kanji
  @full_name_aliases = full_name_aliases
  @gender = gender
  @id_number = id_number
  @id_number_secondary = id_number_secondary
  @last_name = last_name
  @last_name_kana = last_name_kana
  @last_name_kanji = last_name_kanji
  @maiden_name = maiden_name
  @metadata = 
  @nationality = nationality
  @phone = phone
  @political_exposure = political_exposure
  @registered_address = registered_address
  @relationship = relationship
  @ssn_last_4 = ssn_last_4
  @verification = verification
end

Instance Attribute Details

#additional_tos_acceptancesObject

Details on the legal guardian’s or authorizer’s acceptance of the required Stripe agreements.



1120
1121
1122
# File 'lib/stripe/services/token_service.rb', line 1120

def additional_tos_acceptances
  @additional_tos_acceptances
end

#addressObject

The person’s address.



1123
1124
1125
# File 'lib/stripe/services/token_service.rb', line 1123

def address
  @address
end

#address_kanaObject

The Kana variation of the person’s address (Japan only).



1126
1127
1128
# File 'lib/stripe/services/token_service.rb', line 1126

def address_kana
  @address_kana
end

#address_kanjiObject

The Kanji variation of the person’s address (Japan only).



1129
1130
1131
# File 'lib/stripe/services/token_service.rb', line 1129

def address_kanji
  @address_kanji
end

#dobObject

The person’s date of birth.



1132
1133
1134
# File 'lib/stripe/services/token_service.rb', line 1132

def dob
  @dob
end

#documentsObject

Documents that may be submitted to satisfy various informational requests.



1135
1136
1137
# File 'lib/stripe/services/token_service.rb', line 1135

def documents
  @documents
end

#emailObject

The person’s email address.



1138
1139
1140
# File 'lib/stripe/services/token_service.rb', line 1138

def email
  @email
end

#first_nameObject

The person’s first name.



1141
1142
1143
# File 'lib/stripe/services/token_service.rb', line 1141

def first_name
  @first_name
end

#first_name_kanaObject

The Kana variation of the person’s first name (Japan only).



1144
1145
1146
# File 'lib/stripe/services/token_service.rb', line 1144

def first_name_kana
  @first_name_kana
end

#first_name_kanjiObject

The Kanji variation of the person’s first name (Japan only).



1147
1148
1149
# File 'lib/stripe/services/token_service.rb', line 1147

def first_name_kanji
  @first_name_kanji
end

#full_name_aliasesObject

A list of alternate names or aliases that the person is known by.



1150
1151
1152
# File 'lib/stripe/services/token_service.rb', line 1150

def full_name_aliases
  @full_name_aliases
end

#genderObject

The person’s gender (International regulations require either “male” or “female”).



1153
1154
1155
# File 'lib/stripe/services/token_service.rb', line 1153

def gender
  @gender
end

#id_numberObject

The person’s ID number, as appropriate for their country. For example, a social security number in the U.S., social insurance number in Canada, etc. Instead of the number itself, you can also provide a [PII token provided by Stripe.js](docs.stripe.com/js/tokens/create_token?type=pii).



1156
1157
1158
# File 'lib/stripe/services/token_service.rb', line 1156

def id_number
  @id_number
end

#id_number_secondaryObject

The person’s secondary ID number, as appropriate for their country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a [PII token provided by Stripe.js](docs.stripe.com/js/tokens/create_token?type=pii).



1159
1160
1161
# File 'lib/stripe/services/token_service.rb', line 1159

def id_number_secondary
  @id_number_secondary
end

#last_nameObject

The person’s last name.



1162
1163
1164
# File 'lib/stripe/services/token_service.rb', line 1162

def last_name
  @last_name
end

#last_name_kanaObject

The Kana variation of the person’s last name (Japan only).



1165
1166
1167
# File 'lib/stripe/services/token_service.rb', line 1165

def last_name_kana
  @last_name_kana
end

#last_name_kanjiObject

The Kanji variation of the person’s last name (Japan only).



1168
1169
1170
# File 'lib/stripe/services/token_service.rb', line 1168

def last_name_kanji
  @last_name_kanji
end

#maiden_nameObject

The person’s maiden name.



1171
1172
1173
# File 'lib/stripe/services/token_service.rb', line 1171

def maiden_name
  @maiden_name
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1174
1175
1176
# File 'lib/stripe/services/token_service.rb', line 1174

def 
  @metadata
end

#nationalityObject

The country where the person is a national. Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)), or “XX” if unavailable.



1177
1178
1179
# File 'lib/stripe/services/token_service.rb', line 1177

def nationality
  @nationality
end

#phoneObject

The person’s phone number.



1180
1181
1182
# File 'lib/stripe/services/token_service.rb', line 1180

def phone
  @phone
end

#political_exposureObject

Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.



1183
1184
1185
# File 'lib/stripe/services/token_service.rb', line 1183

def political_exposure
  @political_exposure
end

#registered_addressObject

The person’s registered address.



1186
1187
1188
# File 'lib/stripe/services/token_service.rb', line 1186

def registered_address
  @registered_address
end

#relationshipObject

The relationship that this person has with the account’s legal entity.



1189
1190
1191
# File 'lib/stripe/services/token_service.rb', line 1189

def relationship
  @relationship
end

#ssn_last_4Object

The last four digits of the person’s Social Security number (U.S. only).



1192
1193
1194
# File 'lib/stripe/services/token_service.rb', line 1192

def ssn_last_4
  @ssn_last_4
end

#verificationObject

The person’s verification status.



1195
1196
1197
# File 'lib/stripe/services/token_service.rb', line 1195

def verification
  @verification
end