Class: Stripe::TokenService::CreateParams::Person::AdditionalTosAcceptances::Account
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::TokenService::CreateParams::Person::AdditionalTosAcceptances::Account
- Defined in:
- lib/stripe/services/token_service.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the account representative accepted the service agreement.
-
#ip ⇒ Object
The IP address from which the account representative accepted the service agreement.
-
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted the service agreement.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ Account
constructor
A new instance of Account.
Methods inherited from RequestParams
Constructor Details
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ Account
Returns a new instance of Account.
734 735 736 737 738 |
# File 'lib/stripe/services/token_service.rb', line 734 def initialize(date: nil, ip: nil, user_agent: nil) @date = date @ip = ip @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the account representative accepted the service agreement.
728 729 730 |
# File 'lib/stripe/services/token_service.rb', line 728 def date @date end |
#ip ⇒ Object
The IP address from which the account representative accepted the service agreement.
730 731 732 |
# File 'lib/stripe/services/token_service.rb', line 730 def ip @ip end |
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted the service agreement.
732 733 734 |
# File 'lib/stripe/services/token_service.rb', line 732 def user_agent @user_agent end |