Class: Stripe::TokenService::CreateParams::Person::Documents

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/token_service.rb

Defined Under Namespace

Classes: CompanyAuthorization, Passport, Visa

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(company_authorization: nil, passport: nil, visa: nil) ⇒ Documents

Returns a new instance of Documents.



898
899
900
901
902
# File 'lib/stripe/services/token_service.rb', line 898

def initialize(company_authorization: nil, passport: nil, visa: nil)
  @company_authorization = company_authorization
  @passport = passport
  @visa = visa
end

Instance Attribute Details

#company_authorizationObject

One or more documents that demonstrate proof that this person is authorized to represent the company.



892
893
894
# File 'lib/stripe/services/token_service.rb', line 892

def company_authorization
  @company_authorization
end

#passportObject

One or more documents showing the person’s passport page with photo and personal data.



894
895
896
# File 'lib/stripe/services/token_service.rb', line 894

def passport
  @passport
end

#visaObject

One or more documents showing the person’s visa required for living in the country where they are residing.



896
897
898
# File 'lib/stripe/services/token_service.rb', line 896

def visa
  @visa
end