Class: Stripe::Transfer::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/transfer.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(created: nil, destination: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, transfer_group: nil) ⇒ ListParams

Returns a new instance of ListParams.



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/stripe/resources/transfer.rb', line 70

def initialize(
  created: nil,
  destination: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  starting_after: nil,
  transfer_group: nil
)
  @created = created
  @destination = destination
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
  @transfer_group = transfer_group
end

Instance Attribute Details

#createdObject

Only return transfers that were created during the given date interval.



50
51
52
# File 'lib/stripe/resources/transfer.rb', line 50

def created
  @created
end

#destinationObject

Only return transfers for the destination specified by this account ID.



53
54
55
# File 'lib/stripe/resources/transfer.rb', line 53

def destination
  @destination
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



56
57
58
# File 'lib/stripe/resources/transfer.rb', line 56

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



59
60
61
# File 'lib/stripe/resources/transfer.rb', line 59

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



62
63
64
# File 'lib/stripe/resources/transfer.rb', line 62

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



65
66
67
# File 'lib/stripe/resources/transfer.rb', line 65

def starting_after
  @starting_after
end

#transfer_groupObject

Only return transfers with the specified transfer group.



68
69
70
# File 'lib/stripe/resources/transfer.rb', line 68

def transfer_group
  @transfer_group
end