Class: Stripe::Transfer::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/transfer.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, expand: nil, metadata: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



135
136
137
138
139
# File 'lib/stripe/resources/transfer.rb', line 135

def initialize(description: nil, expand: nil, metadata: nil)
  @description = description
  @expand = expand
  @metadata = 
end

Instance Attribute Details

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



129
130
131
# File 'lib/stripe/resources/transfer.rb', line 129

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



131
132
133
# File 'lib/stripe/resources/transfer.rb', line 131

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



133
134
135
# File 'lib/stripe/resources/transfer.rb', line 133

def 
  @metadata
end