Class: Stripe::TransferReversalService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::TransferReversalService::CreateParams
- Defined in:
- lib/stripe/services/transfer_reversal_service.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
A positive integer in cents (or local equivalent) representing how much of this transfer to reverse.
-
#description ⇒ Object
An arbitrary string which you can attach to a reversal object.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#refund_application_fee ⇒ Object
Boolean indicating whether the application fee should be refunded when reversing this transfer.
Instance Method Summary collapse
-
#initialize(amount: nil, description: nil, expand: nil, metadata: nil, refund_application_fee: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, description: nil, expand: nil, metadata: nil, refund_application_fee: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
36 37 38 39 40 41 42 43 44 45 46 47 48 |
# File 'lib/stripe/services/transfer_reversal_service.rb', line 36 def initialize( amount: nil, description: nil, expand: nil, metadata: nil, refund_application_fee: nil ) @amount = amount @description = description @expand = @metadata = @refund_application_fee = refund_application_fee end |
Instance Attribute Details
#amount ⇒ Object
A positive integer in cents (or local equivalent) representing how much of this transfer to reverse. Can only reverse up to the unreversed amount remaining of the transfer. Partial transfer reversals are only allowed for transfers to Stripe Accounts. Defaults to the entire transfer amount.
26 27 28 |
# File 'lib/stripe/services/transfer_reversal_service.rb', line 26 def amount @amount end |
#description ⇒ Object
An arbitrary string which you can attach to a reversal object. This will be unset if you POST an empty value.
28 29 30 |
# File 'lib/stripe/services/transfer_reversal_service.rb', line 28 def description @description end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
30 31 32 |
# File 'lib/stripe/services/transfer_reversal_service.rb', line 30 def @expand end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
32 33 34 |
# File 'lib/stripe/services/transfer_reversal_service.rb', line 32 def @metadata end |
#refund_application_fee ⇒ Object
Boolean indicating whether the application fee should be refunded when reversing this transfer. If a full transfer reversal is given, the full application fee will be refunded. Otherwise, the application fee will be refunded with an amount proportional to the amount of the transfer reversed.
34 35 36 |
# File 'lib/stripe/services/transfer_reversal_service.rb', line 34 def refund_application_fee @refund_application_fee end |