Class: Stripe::TransferService::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/transfer_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, expand: nil, metadata: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



144
145
146
147
148
# File 'lib/stripe/services/transfer_service.rb', line 144

def initialize(description: nil, expand: nil, metadata: nil)
  @description = description
  @expand = expand
  @metadata = 
end

Instance Attribute Details

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



136
137
138
# File 'lib/stripe/services/transfer_service.rb', line 136

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



139
140
141
# File 'lib/stripe/services/transfer_service.rb', line 139

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



142
143
144
# File 'lib/stripe/services/transfer_service.rb', line 142

def 
  @metadata
end