Class: Stripe::TransitBalance

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/transit_balance.rb

Overview

Funds that are in transit and destined for another balance or another connected account.

Defined Under Namespace

Classes: Balance

Constant Summary collapse

OBJECT_NAME =
"transit_balance"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#balanceObject (readonly)

Attribute for field balance



27
28
29
# File 'lib/stripe/resources/transit_balance.rb', line 27

def balance
  @balance
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



29
30
31
# File 'lib/stripe/resources/transit_balance.rb', line 29

def created
  @created
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



31
32
33
# File 'lib/stripe/resources/transit_balance.rb', line 31

def currency
  @currency
end

#livemodeObject (readonly)

If the object exists in live mode, the value is ‘true`. If the object exists in test mode, the value is `false`.



33
34
35
# File 'lib/stripe/resources/transit_balance.rb', line 33

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



35
36
37
# File 'lib/stripe/resources/transit_balance.rb', line 35

def object
  @object
end

Class Method Details

.field_remappingsObject



41
42
43
# File 'lib/stripe/resources/transit_balance.rb', line 41

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



37
38
39
# File 'lib/stripe/resources/transit_balance.rb', line 37

def self.inner_class_types
  @inner_class_types = { balance: Balance }
end

.object_nameObject



8
9
10
# File 'lib/stripe/resources/transit_balance.rb', line 8

def self.object_name
  "transit_balance"
end