Class: Stripe::Treasury::CreditReversal::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/treasury/credit_reversal.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, metadata: nil, received_credit: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



64
65
66
67
68
# File 'lib/stripe/resources/treasury/credit_reversal.rb', line 64

def initialize(expand: nil, metadata: nil, received_credit: nil)
  @expand = expand
  @metadata = 
  @received_credit = received_credit
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



58
59
60
# File 'lib/stripe/resources/treasury/credit_reversal.rb', line 58

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



60
61
62
# File 'lib/stripe/resources/treasury/credit_reversal.rb', line 60

def 
  @metadata
end

#received_creditObject

The ReceivedCredit to reverse.



62
63
64
# File 'lib/stripe/resources/treasury/credit_reversal.rb', line 62

def received_credit
  @received_credit
end