Class: Stripe::Treasury::CreditReversalService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Treasury::CreditReversalService::CreateParams
- Defined in:
- lib/stripe/services/treasury/credit_reversal_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#received_credit ⇒ Object
The ReceivedCredit to reverse.
Instance Method Summary collapse
-
#initialize(expand: nil, metadata: nil, received_credit: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, metadata: nil, received_credit: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
58 59 60 61 62 |
# File 'lib/stripe/services/treasury/credit_reversal_service.rb', line 58 def initialize(expand: nil, metadata: nil, received_credit: nil) @expand = @metadata = @received_credit = received_credit end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
50 51 52 |
# File 'lib/stripe/services/treasury/credit_reversal_service.rb', line 50 def @expand end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
53 54 55 |
# File 'lib/stripe/services/treasury/credit_reversal_service.rb', line 53 def @metadata end |
#received_credit ⇒ Object
The ReceivedCredit to reverse.
56 57 58 |
# File 'lib/stripe/services/treasury/credit_reversal_service.rb', line 56 def received_credit @received_credit end |