Class: Stripe::Treasury::DebitReversal::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/treasury/debit_reversal.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, metadata: nil, received_debit: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



89
90
91
92
93
# File 'lib/stripe/resources/treasury/debit_reversal.rb', line 89

def initialize(expand: nil, metadata: nil, received_debit: nil)
  @expand = expand
  @metadata = 
  @received_debit = received_debit
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



83
84
85
# File 'lib/stripe/resources/treasury/debit_reversal.rb', line 83

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



85
86
87
# File 'lib/stripe/resources/treasury/debit_reversal.rb', line 85

def 
  @metadata
end

#received_debitObject

The ReceivedDebit to reverse.



87
88
89
# File 'lib/stripe/resources/treasury/debit_reversal.rb', line 87

def received_debit
  @received_debit
end