Class: Stripe::Treasury::DebitReversal::RetrieveParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Treasury::DebitReversal::RetrieveParams
- Defined in:
- lib/stripe/resources/treasury/debit_reversal.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ RetrieveParams
constructor
A new instance of RetrieveParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ RetrieveParams
Returns a new instance of RetrieveParams.
84 85 86 |
# File 'lib/stripe/resources/treasury/debit_reversal.rb', line 84 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
82 83 84 |
# File 'lib/stripe/resources/treasury/debit_reversal.rb', line 82 def @expand end |