Class: Stripe::Treasury::FinancialAccount
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Treasury::FinancialAccount
- Extended by:
- APIOperations::Create, APIOperations::List
- Includes:
- APIOperations::Save
- Defined in:
- lib/stripe/resources/treasury/financial_account.rb
Overview
Stripe Treasury provides users with a container for money called a FinancialAccount that is separate from their Payments balance. FinancialAccounts serve as the source and destination of Treasury’s money movement APIs.
Defined Under Namespace
Classes: Balance, FinancialAddress, PlatformRestrictions, StatusDetails
Constant Summary collapse
- OBJECT_NAME =
"treasury.financial_account"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#active_features ⇒ Object
readonly
The array of paths to active Features in the Features hash.
-
#balance ⇒ Object
readonly
Balance information for the FinancialAccount.
-
#country ⇒ Object
readonly
Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#display_name ⇒ Object
readonly
The display name for the FinancialAccount.
-
#features ⇒ Object
readonly
Encodes whether a FinancialAccount has access to a particular Feature, with a ‘status` enum and associated `status_details`.
-
#financial_addresses ⇒ Object
readonly
The set of credentials that resolve to a FinancialAccount.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#is_default ⇒ Object
readonly
Attribute for field is_default.
-
#livemode ⇒ Object
readonly
If the object exists in live mode, the value is ‘true`.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#nickname ⇒ Object
readonly
The nickname for the FinancialAccount.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#pending_features ⇒ Object
readonly
The array of paths to pending Features in the Features hash.
-
#platform_restrictions ⇒ Object
readonly
The set of functionalities that the platform can restrict on the FinancialAccount.
-
#restricted_features ⇒ Object
readonly
The array of paths to restricted Features in the Features hash.
-
#status ⇒ Object
readonly
Status of this FinancialAccount.
-
#status_details ⇒ Object
readonly
Attribute for field status_details.
-
#supported_currencies ⇒ Object
readonly
The currencies the FinancialAccount can hold a balance in.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.close(financial_account, params = {}, opts = {}) ⇒ Object
Closes a FinancialAccount.
-
.create(params = {}, opts = {}) ⇒ Object
Creates a new FinancialAccount.
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
-
.list(params = {}, opts = {}) ⇒ Object
Returns a list of FinancialAccounts.
- .object_name ⇒ Object
-
.retrieve_features(financial_account, params = {}, opts = {}) ⇒ Object
Retrieves Features information associated with the FinancialAccount.
-
.update(financial_account, params = {}, opts = {}) ⇒ Object
Updates the details of a FinancialAccount.
-
.update_features(financial_account, params = {}, opts = {}) ⇒ Object
Updates the Features associated with a FinancialAccount.
Instance Method Summary collapse
-
#close(params = {}, opts = {}) ⇒ Object
Closes a FinancialAccount.
-
#retrieve_features(params = {}, opts = {}) ⇒ Object
Retrieves Features information associated with the FinancialAccount.
-
#update_features(params = {}, opts = {}) ⇒ Object
Updates the Features associated with a FinancialAccount.
Methods included from APIOperations::Create
Methods included from APIOperations::List
Methods included from APIOperations::Save
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#active_features ⇒ Object (readonly)
The array of paths to active Features in the Features hash.
112 113 114 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 112 def active_features @active_features end |
#balance ⇒ Object (readonly)
Balance information for the FinancialAccount
114 115 116 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 114 def balance @balance end |
#country ⇒ Object (readonly)
Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
116 117 118 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 116 def country @country end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
118 119 120 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 118 def created @created end |
#display_name ⇒ Object (readonly)
The display name for the FinancialAccount. Use this field to customize the names of the FinancialAccounts for your connected accounts. Unlike the ‘nickname` field, `display_name` is not internal metadata and will be exposed to connected accounts.
120 121 122 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 120 def display_name @display_name end |
#features ⇒ Object (readonly)
Encodes whether a FinancialAccount has access to a particular Feature, with a ‘status` enum and associated `status_details`. Stripe or the platform can control Features via the requested field.
123 124 125 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 123 def features @features end |
#financial_addresses ⇒ Object (readonly)
The set of credentials that resolve to a FinancialAccount.
125 126 127 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 125 def financial_addresses @financial_addresses end |
#id ⇒ Object (readonly)
Unique identifier for the object.
127 128 129 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 127 def id @id end |
#is_default ⇒ Object (readonly)
Attribute for field is_default
129 130 131 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 129 def is_default @is_default end |
#livemode ⇒ Object (readonly)
If the object exists in live mode, the value is ‘true`. If the object exists in test mode, the value is `false`.
131 132 133 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 131 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
133 134 135 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 133 def @metadata end |
#nickname ⇒ Object (readonly)
The nickname for the FinancialAccount.
135 136 137 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 135 def nickname @nickname end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
137 138 139 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 137 def object @object end |
#pending_features ⇒ Object (readonly)
The array of paths to pending Features in the Features hash.
139 140 141 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 139 def pending_features @pending_features end |
#platform_restrictions ⇒ Object (readonly)
The set of functionalities that the platform can restrict on the FinancialAccount.
141 142 143 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 141 def platform_restrictions @platform_restrictions end |
#restricted_features ⇒ Object (readonly)
The array of paths to restricted Features in the Features hash.
143 144 145 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 143 def restricted_features @restricted_features end |
#status ⇒ Object (readonly)
Status of this FinancialAccount.
145 146 147 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 145 def status @status end |
#status_details ⇒ Object (readonly)
Attribute for field status_details
147 148 149 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 147 def status_details @status_details end |
#supported_currencies ⇒ Object (readonly)
The currencies the FinancialAccount can hold a balance in. Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
149 150 151 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 149 def supported_currencies @supported_currencies end |
Class Method Details
.close(financial_account, params = {}, opts = {}) ⇒ Object
Closes a FinancialAccount. A FinancialAccount can only be closed if it has a zero balance, has no pending InboundTransfers, and has canceled all attached Issuing cards.
162 163 164 165 166 167 168 169 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 162 def self.close(financial_account, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/treasury/financial_accounts/%<financial_account>s/close", { financial_account: CGI.escape(financial_account) }), params: params, opts: opts ) end |
.create(params = {}, opts = {}) ⇒ Object
Creates a new FinancialAccount. Each connected account can have up to three FinancialAccounts by default.
172 173 174 175 176 177 178 179 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 172 def self.create(params = {}, opts = {}) request_stripe_object( method: :post, path: "/v1/treasury/financial_accounts", params: params, opts: opts ) end |
.field_remappings ⇒ Object
250 251 252 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 250 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
241 242 243 244 245 246 247 248 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 241 def self.inner_class_types @inner_class_types = { balance: Balance, financial_addresses: FinancialAddress, platform_restrictions: PlatformRestrictions, status_details: StatusDetails, } end |
.list(params = {}, opts = {}) ⇒ Object
Returns a list of FinancialAccounts.
182 183 184 185 186 187 188 189 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 182 def self.list(params = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/treasury/financial_accounts", params: params, opts: opts ) end |
.object_name ⇒ Object
14 15 16 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 14 def self.object_name "treasury.financial_account" end |
.retrieve_features(financial_account, params = {}, opts = {}) ⇒ Object
Retrieves Features information associated with the FinancialAccount.
202 203 204 205 206 207 208 209 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 202 def self.retrieve_features(financial_account, params = {}, opts = {}) request_stripe_object( method: :get, path: format("/v1/treasury/financial_accounts/%<financial_account>s/features", { financial_account: CGI.escape(financial_account) }), params: params, opts: opts ) end |
.update(financial_account, params = {}, opts = {}) ⇒ Object
Updates the details of a FinancialAccount.
212 213 214 215 216 217 218 219 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 212 def self.update(financial_account, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/treasury/financial_accounts/%<financial_account>s", { financial_account: CGI.escape(financial_account) }), params: params, opts: opts ) end |
.update_features(financial_account, params = {}, opts = {}) ⇒ Object
Updates the Features associated with a FinancialAccount.
232 233 234 235 236 237 238 239 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 232 def self.update_features(financial_account, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/treasury/financial_accounts/%<financial_account>s/features", { financial_account: CGI.escape(financial_account) }), params: params, opts: opts ) end |
Instance Method Details
#close(params = {}, opts = {}) ⇒ Object
Closes a FinancialAccount. A FinancialAccount can only be closed if it has a zero balance, has no pending InboundTransfers, and has canceled all attached Issuing cards.
152 153 154 155 156 157 158 159 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 152 def close(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/treasury/financial_accounts/%<financial_account>s/close", { financial_account: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#retrieve_features(params = {}, opts = {}) ⇒ Object
Retrieves Features information associated with the FinancialAccount.
192 193 194 195 196 197 198 199 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 192 def retrieve_features(params = {}, opts = {}) request_stripe_object( method: :get, path: format("/v1/treasury/financial_accounts/%<financial_account>s/features", { financial_account: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#update_features(params = {}, opts = {}) ⇒ Object
Updates the Features associated with a FinancialAccount.
222 223 224 225 226 227 228 229 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 222 def update_features(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/treasury/financial_accounts/%<financial_account>s/features", { financial_account: CGI.escape(self["id"]) }), params: params, opts: opts ) end |