Class: Stripe::Treasury::FinancialAccount::Balance
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Treasury::FinancialAccount::Balance
- Defined in:
- lib/stripe/resources/treasury/financial_account.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#cash ⇒ Object
readonly
Funds the user can spend right now.
-
#inbound_pending ⇒ Object
readonly
Funds not spendable yet, but will become available at a later time.
-
#outbound_pending ⇒ Object
readonly
Funds in the account, but not spendable because they are being held for pending outbound flows.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#cash ⇒ Object (readonly)
Funds the user can spend right now.
20 21 22 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 20 def cash @cash end |
#inbound_pending ⇒ Object (readonly)
Funds not spendable yet, but will become available at a later time.
23 24 25 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 23 def inbound_pending @inbound_pending end |
#outbound_pending ⇒ Object (readonly)
Funds in the account, but not spendable because they are being held for pending outbound flows.
26 27 28 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 26 def outbound_pending @outbound_pending end |