Class: Stripe::Treasury::FinancialAccount::FinancialAddress::Aba
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Treasury::FinancialAccount::FinancialAddress::Aba
- Defined in:
- lib/stripe/resources/treasury/financial_account.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
readonly
The name of the person or business that owns the bank account.
-
#account_number ⇒ Object
readonly
The account number.
-
#account_number_last4 ⇒ Object
readonly
The last four characters of the account number.
-
#bank_name ⇒ Object
readonly
Name of the bank.
-
#routing_number ⇒ Object
readonly
Routing number for the account.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_holder_name ⇒ Object (readonly)
The name of the person or business that owns the bank account.
30 31 32 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 30 def account_holder_name @account_holder_name end |
#account_number ⇒ Object (readonly)
The account number.
32 33 34 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 32 def account_number @account_number end |
#account_number_last4 ⇒ Object (readonly)
The last four characters of the account number.
34 35 36 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 34 def account_number_last4 @account_number_last4 end |
#bank_name ⇒ Object (readonly)
Name of the bank.
36 37 38 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 36 def bank_name @bank_name end |
#routing_number ⇒ Object (readonly)
Routing number for the account.
38 39 40 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 38 def routing_number @routing_number end |