Class: Stripe::Treasury::FinancialAccount::UpdateFeaturesParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/treasury/financial_account.rb

Defined Under Namespace

Classes: CardIssuing, DepositInsurance, FinancialAddresses, InboundTransfers, IntraStripeFlows, OutboundPayments, OutboundTransfers

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(card_issuing: nil, deposit_insurance: nil, expand: nil, financial_addresses: nil, inbound_transfers: nil, intra_stripe_flows: nil, outbound_payments: nil, outbound_transfers: nil) ⇒ UpdateFeaturesParams

Returns a new instance of UpdateFeaturesParams.



727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
# File 'lib/stripe/resources/treasury/financial_account.rb', line 727

def initialize(
  card_issuing: nil,
  deposit_insurance: nil,
  expand: nil,
  financial_addresses: nil,
  inbound_transfers: nil,
  intra_stripe_flows: nil,
  outbound_payments: nil,
  outbound_transfers: nil
)
  @card_issuing = card_issuing
  @deposit_insurance = deposit_insurance
  @expand = expand
  @financial_addresses = financial_addresses
  @inbound_transfers = inbound_transfers
  @intra_stripe_flows = intra_stripe_flows
  @outbound_payments = outbound_payments
  @outbound_transfers = outbound_transfers
end

Instance Attribute Details

#card_issuingObject

Encodes the FinancialAccount’s ability to be used with the Issuing product, including attaching cards to and drawing funds from the FinancialAccount.



711
712
713
# File 'lib/stripe/resources/treasury/financial_account.rb', line 711

def card_issuing
  @card_issuing
end

#deposit_insuranceObject

Represents whether this FinancialAccount is eligible for deposit insurance. Various factors determine the insurance amount.



713
714
715
# File 'lib/stripe/resources/treasury/financial_account.rb', line 713

def deposit_insurance
  @deposit_insurance
end

#expandObject

Specifies which fields in the response should be expanded.



715
716
717
# File 'lib/stripe/resources/treasury/financial_account.rb', line 715

def expand
  @expand
end

#financial_addressesObject

Contains Features that add FinancialAddresses to the FinancialAccount.



717
718
719
# File 'lib/stripe/resources/treasury/financial_account.rb', line 717

def financial_addresses
  @financial_addresses
end

#inbound_transfersObject

Contains settings related to adding funds to a FinancialAccount from another Account with the same owner.



719
720
721
# File 'lib/stripe/resources/treasury/financial_account.rb', line 719

def inbound_transfers
  @inbound_transfers
end

#intra_stripe_flowsObject

Represents the ability for the FinancialAccount to send money to, or receive money from other FinancialAccounts (for example, via OutboundPayment).



721
722
723
# File 'lib/stripe/resources/treasury/financial_account.rb', line 721

def intra_stripe_flows
  @intra_stripe_flows
end

#outbound_paymentsObject

Includes Features related to initiating money movement out of the FinancialAccount to someone else’s bucket of money.



723
724
725
# File 'lib/stripe/resources/treasury/financial_account.rb', line 723

def outbound_payments
  @outbound_payments
end

#outbound_transfersObject

Contains a Feature and settings related to moving money out of the FinancialAccount into another Account with the same owner.



725
726
727
# File 'lib/stripe/resources/treasury/financial_account.rb', line 725

def outbound_transfers
  @outbound_transfers
end