Class: Stripe::Treasury::FinancialAccount::UpdateParams::Features
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Treasury::FinancialAccount::UpdateParams::Features
- Defined in:
- lib/stripe/resources/treasury/financial_account.rb
Defined Under Namespace
Classes: CardIssuing, DepositInsurance, FinancialAddresses, InboundTransfers, IntraStripeFlows, OutboundPayments, OutboundTransfers
Instance Attribute Summary collapse
-
#card_issuing ⇒ Object
Encodes the FinancialAccount’s ability to be used with the Issuing product, including attaching cards to and drawing funds from the FinancialAccount.
-
#deposit_insurance ⇒ Object
Represents whether this FinancialAccount is eligible for deposit insurance.
-
#financial_addresses ⇒ Object
Contains Features that add FinancialAddresses to the FinancialAccount.
-
#inbound_transfers ⇒ Object
Contains settings related to adding funds to a FinancialAccount from another Account with the same owner.
-
#intra_stripe_flows ⇒ Object
Represents the ability for the FinancialAccount to send money to, or receive money from other FinancialAccounts (for example, via OutboundPayment).
-
#outbound_payments ⇒ Object
Includes Features related to initiating money movement out of the FinancialAccount to someone else’s bucket of money.
-
#outbound_transfers ⇒ Object
Contains a Feature and settings related to moving money out of the FinancialAccount into another Account with the same owner.
Instance Method Summary collapse
-
#initialize(card_issuing: nil, deposit_insurance: nil, financial_addresses: nil, inbound_transfers: nil, intra_stripe_flows: nil, outbound_payments: nil, outbound_transfers: nil) ⇒ Features
constructor
A new instance of Features.
Methods inherited from RequestParams
Constructor Details
#initialize(card_issuing: nil, deposit_insurance: nil, financial_addresses: nil, inbound_transfers: nil, intra_stripe_flows: nil, outbound_payments: nil, outbound_transfers: nil) ⇒ Features
Returns a new instance of Features.
457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 457 def initialize( card_issuing: nil, deposit_insurance: nil, financial_addresses: nil, inbound_transfers: nil, intra_stripe_flows: nil, outbound_payments: nil, outbound_transfers: nil ) @card_issuing = card_issuing @deposit_insurance = deposit_insurance @financial_addresses = financial_addresses @inbound_transfers = inbound_transfers @intra_stripe_flows = intra_stripe_flows @outbound_payments = outbound_payments @outbound_transfers = outbound_transfers end |
Instance Attribute Details
#card_issuing ⇒ Object
Encodes the FinancialAccount’s ability to be used with the Issuing product, including attaching cards to and drawing funds from the FinancialAccount.
443 444 445 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 443 def card_issuing @card_issuing end |
#deposit_insurance ⇒ Object
Represents whether this FinancialAccount is eligible for deposit insurance. Various factors determine the insurance amount.
445 446 447 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 445 def deposit_insurance @deposit_insurance end |
#financial_addresses ⇒ Object
Contains Features that add FinancialAddresses to the FinancialAccount.
447 448 449 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 447 def financial_addresses @financial_addresses end |
#inbound_transfers ⇒ Object
Contains settings related to adding funds to a FinancialAccount from another Account with the same owner.
449 450 451 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 449 def inbound_transfers @inbound_transfers end |
#intra_stripe_flows ⇒ Object
Represents the ability for the FinancialAccount to send money to, or receive money from other FinancialAccounts (for example, via OutboundPayment).
451 452 453 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 451 def intra_stripe_flows @intra_stripe_flows end |
#outbound_payments ⇒ Object
Includes Features related to initiating money movement out of the FinancialAccount to someone else’s bucket of money.
453 454 455 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 453 def outbound_payments @outbound_payments end |
#outbound_transfers ⇒ Object
Contains a Feature and settings related to moving money out of the FinancialAccount into another Account with the same owner.
455 456 457 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 455 def outbound_transfers @outbound_transfers end |