Class: Stripe::Treasury::FinancialAccountCreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/treasury/financial_account_create_params.rb

Defined Under Namespace

Classes: Features, PlatformRestrictions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(display_name: nil, expand: nil, features: nil, metadata: nil, nickname: nil, platform_restrictions: nil, supported_currencies: nil) ⇒ FinancialAccountCreateParams

Returns a new instance of FinancialAccountCreateParams.



189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/stripe/params/treasury/financial_account_create_params.rb', line 189

def initialize(
  display_name: nil,
  expand: nil,
  features: nil,
  metadata: nil,
  nickname: nil,
  platform_restrictions: nil,
  supported_currencies: nil
)
  @display_name = display_name
  @expand = expand
  @features = features
  @metadata = 
  @nickname = nickname
  @platform_restrictions = platform_restrictions
  @supported_currencies = supported_currencies
end

Instance Attribute Details

#display_nameObject

The display name for the FinancialAccount. Use this field to customize the names of the FinancialAccounts for your connected accounts. Unlike the ‘nickname` field, `display_name` is not internal metadata and will be exposed to connected accounts.



175
176
177
# File 'lib/stripe/params/treasury/financial_account_create_params.rb', line 175

def display_name
  @display_name
end

#expandObject

Specifies which fields in the response should be expanded.



177
178
179
# File 'lib/stripe/params/treasury/financial_account_create_params.rb', line 177

def expand
  @expand
end

#featuresObject

Encodes whether a FinancialAccount has access to a particular feature. Stripe or the platform can control features via the requested field.



179
180
181
# File 'lib/stripe/params/treasury/financial_account_create_params.rb', line 179

def features
  @features
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



181
182
183
# File 'lib/stripe/params/treasury/financial_account_create_params.rb', line 181

def 
  @metadata
end

#nicknameObject

The nickname for the FinancialAccount.



183
184
185
# File 'lib/stripe/params/treasury/financial_account_create_params.rb', line 183

def nickname
  @nickname
end

#platform_restrictionsObject

The set of functionalities that the platform can restrict on the FinancialAccount.



185
186
187
# File 'lib/stripe/params/treasury/financial_account_create_params.rb', line 185

def platform_restrictions
  @platform_restrictions
end

#supported_currenciesObject

The currencies the FinancialAccount can hold a balance in.



187
188
189
# File 'lib/stripe/params/treasury/financial_account_create_params.rb', line 187

def supported_currencies
  @supported_currencies
end