Class: Stripe::Treasury::FinancialAccountFeaturesService::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Treasury::FinancialAccountFeaturesService::UpdateParams
- Defined in:
- lib/stripe/services/treasury/financial_account_features_service.rb
Defined Under Namespace
Classes: CardIssuing, DepositInsurance, FinancialAddresses, InboundTransfers, IntraStripeFlows, OutboundPayments, OutboundTransfers
Instance Attribute Summary collapse
-
#card_issuing ⇒ Object
Encodes the FinancialAccount’s ability to be used with the Issuing product, including attaching cards to and drawing funds from the FinancialAccount.
-
#deposit_insurance ⇒ Object
Represents whether this FinancialAccount is eligible for deposit insurance.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#financial_addresses ⇒ Object
Contains Features that add FinancialAddresses to the FinancialAccount.
-
#inbound_transfers ⇒ Object
Contains settings related to adding funds to a FinancialAccount from another Account with the same owner.
-
#intra_stripe_flows ⇒ Object
Represents the ability for the FinancialAccount to send money to, or receive money from other FinancialAccounts (for example, via OutboundPayment).
-
#outbound_payments ⇒ Object
Includes Features related to initiating money movement out of the FinancialAccount to someone else’s bucket of money.
-
#outbound_transfers ⇒ Object
Contains a Feature and settings related to moving money out of the FinancialAccount into another Account with the same owner.
Instance Method Summary collapse
-
#initialize(card_issuing: nil, deposit_insurance: nil, expand: nil, financial_addresses: nil, inbound_transfers: nil, intra_stripe_flows: nil, outbound_payments: nil, outbound_transfers: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(card_issuing: nil, deposit_insurance: nil, expand: nil, financial_addresses: nil, inbound_transfers: nil, intra_stripe_flows: nil, outbound_payments: nil, outbound_transfers: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/stripe/services/treasury/financial_account_features_service.rb', line 156 def initialize( card_issuing: nil, deposit_insurance: nil, expand: nil, financial_addresses: nil, inbound_transfers: nil, intra_stripe_flows: nil, outbound_payments: nil, outbound_transfers: nil ) @card_issuing = card_issuing @deposit_insurance = deposit_insurance @expand = @financial_addresses = financial_addresses @inbound_transfers = inbound_transfers @intra_stripe_flows = intra_stripe_flows @outbound_payments = outbound_payments @outbound_transfers = outbound_transfers end |
Instance Attribute Details
#card_issuing ⇒ Object
Encodes the FinancialAccount’s ability to be used with the Issuing product, including attaching cards to and drawing funds from the FinancialAccount.
133 134 135 |
# File 'lib/stripe/services/treasury/financial_account_features_service.rb', line 133 def card_issuing @card_issuing end |
#deposit_insurance ⇒ Object
Represents whether this FinancialAccount is eligible for deposit insurance. Various factors determine the insurance amount.
136 137 138 |
# File 'lib/stripe/services/treasury/financial_account_features_service.rb', line 136 def deposit_insurance @deposit_insurance end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
139 140 141 |
# File 'lib/stripe/services/treasury/financial_account_features_service.rb', line 139 def @expand end |
#financial_addresses ⇒ Object
Contains Features that add FinancialAddresses to the FinancialAccount.
142 143 144 |
# File 'lib/stripe/services/treasury/financial_account_features_service.rb', line 142 def financial_addresses @financial_addresses end |
#inbound_transfers ⇒ Object
Contains settings related to adding funds to a FinancialAccount from another Account with the same owner.
145 146 147 |
# File 'lib/stripe/services/treasury/financial_account_features_service.rb', line 145 def inbound_transfers @inbound_transfers end |
#intra_stripe_flows ⇒ Object
Represents the ability for the FinancialAccount to send money to, or receive money from other FinancialAccounts (for example, via OutboundPayment).
148 149 150 |
# File 'lib/stripe/services/treasury/financial_account_features_service.rb', line 148 def intra_stripe_flows @intra_stripe_flows end |
#outbound_payments ⇒ Object
Includes Features related to initiating money movement out of the FinancialAccount to someone else’s bucket of money.
151 152 153 |
# File 'lib/stripe/services/treasury/financial_account_features_service.rb', line 151 def outbound_payments @outbound_payments end |
#outbound_transfers ⇒ Object
Contains a Feature and settings related to moving money out of the FinancialAccount into another Account with the same owner.
154 155 156 |
# File 'lib/stripe/services/treasury/financial_account_features_service.rb', line 154 def outbound_transfers @outbound_transfers end |