Class: Stripe::Treasury::FinancialAccountService::CloseParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/treasury/financial_account_service.rb

Defined Under Namespace

Classes: ForwardingSettings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, forwarding_settings: nil) ⇒ CloseParams

Returns a new instance of CloseParams.



496
497
498
499
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 496

def initialize(expand: nil, forwarding_settings: nil)
  @expand = expand
  @forwarding_settings = forwarding_settings
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



492
493
494
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 492

def expand
  @expand
end

#forwarding_settingsObject

A different bank account where funds can be deposited/debited in order to get the closing FA’s balance to $0



494
495
496
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 494

def forwarding_settings
  @forwarding_settings
end