Class: Stripe::Treasury::FinancialAccountService::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/treasury/financial_account_service.rb

Defined Under Namespace

Classes: Features, PlatformRestrictions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, features: nil, metadata: nil, nickname: nil, platform_restrictions: nil, supported_currencies: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 240

def initialize(
  expand: nil,
  features: nil,
  metadata: nil,
  nickname: nil,
  platform_restrictions: nil,
  supported_currencies: nil
)
  @expand = expand
  @features = features
  @metadata = 
  @nickname = nickname
  @platform_restrictions = platform_restrictions
  @supported_currencies = supported_currencies
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



228
229
230
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 228

def expand
  @expand
end

#featuresObject

Encodes whether a FinancialAccount has access to a particular feature. Stripe or the platform can control features via the requested field.



230
231
232
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 230

def features
  @features
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



232
233
234
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 232

def 
  @metadata
end

#nicknameObject

The nickname for the FinancialAccount.



234
235
236
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 234

def nickname
  @nickname
end

#platform_restrictionsObject

The set of functionalities that the platform can restrict on the FinancialAccount.



236
237
238
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 236

def platform_restrictions
  @platform_restrictions
end

#supported_currenciesObject

The currencies the FinancialAccount can hold a balance in.



238
239
240
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 238

def supported_currencies
  @supported_currencies
end