Class: Stripe::Treasury::FinancialAccountService::ListParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/treasury/financial_account_service.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, status: nil) ⇒ ListParams

Returns a new instance of ListParams.



45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 45

def initialize(
  created: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  starting_after: nil,
  status: nil
)
  @created = created
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
  @status = status
end

Instance Attribute Details

#createdObject

Only return FinancialAccounts that were created during the given date interval.



33
34
35
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 33

def created
  @created
end

#ending_beforeObject

An object ID cursor for use in pagination.



35
36
37
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 35

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



37
38
39
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 37

def expand
  @expand
end

#limitObject

A limit ranging from 1 to 100 (defaults to 10).



39
40
41
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 39

def limit
  @limit
end

#starting_afterObject

An object ID cursor for use in pagination.



41
42
43
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 41

def starting_after
  @starting_after
end

#statusObject

Only return FinancialAccounts that have the given status: ‘open` or `closed`



43
44
45
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 43

def status
  @status
end