Class: Stripe::Treasury::FinancialAccountService::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/treasury/financial_account_service.rb

Defined Under Namespace

Classes: Features, ForwardingSettings, PlatformRestrictions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, features: nil, forwarding_settings: nil, metadata: nil, nickname: nil, platform_restrictions: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 459

def initialize(
  expand: nil,
  features: nil,
  forwarding_settings: nil,
  metadata: nil,
  nickname: nil,
  platform_restrictions: nil
)
  @expand = expand
  @features = features
  @forwarding_settings = forwarding_settings
  @metadata = 
  @nickname = nickname
  @platform_restrictions = platform_restrictions
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



447
448
449
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 447

def expand
  @expand
end

#featuresObject

Encodes whether a FinancialAccount has access to a particular feature, with a status enum and associated ‘status_details`. Stripe or the platform may control features via the requested field.



449
450
451
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 449

def features
  @features
end

#forwarding_settingsObject

A different bank account where funds can be deposited/debited in order to get the closing FA’s balance to $0



451
452
453
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 451

def forwarding_settings
  @forwarding_settings
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



453
454
455
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 453

def 
  @metadata
end

#nicknameObject

The nickname for the FinancialAccount.



455
456
457
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 455

def nickname
  @nickname
end

#platform_restrictionsObject

The set of functionalities that the platform can restrict on the FinancialAccount.



457
458
459
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 457

def platform_restrictions
  @platform_restrictions
end