Class: Stripe::Treasury::FinancialAccountService::UpdateParams::Features
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Treasury::FinancialAccountService::UpdateParams::Features
- Defined in:
- lib/stripe/services/treasury/financial_account_service.rb
Defined Under Namespace
Classes: CardIssuing, DepositInsurance, FinancialAddresses, InboundTransfers, IntraStripeFlows, OutboundPayments, OutboundTransfers
Instance Attribute Summary collapse
-
#card_issuing ⇒ Object
Encodes the FinancialAccount’s ability to be used with the Issuing product, including attaching cards to and drawing funds from the FinancialAccount.
-
#deposit_insurance ⇒ Object
Represents whether this FinancialAccount is eligible for deposit insurance.
-
#financial_addresses ⇒ Object
Contains Features that add FinancialAddresses to the FinancialAccount.
-
#inbound_transfers ⇒ Object
Contains settings related to adding funds to a FinancialAccount from another Account with the same owner.
-
#intra_stripe_flows ⇒ Object
Represents the ability for the FinancialAccount to send money to, or receive money from other FinancialAccounts (for example, via OutboundPayment).
-
#outbound_payments ⇒ Object
Includes Features related to initiating money movement out of the FinancialAccount to someone else’s bucket of money.
-
#outbound_transfers ⇒ Object
Contains a Feature and settings related to moving money out of the FinancialAccount into another Account with the same owner.
Instance Method Summary collapse
-
#initialize(card_issuing: nil, deposit_insurance: nil, financial_addresses: nil, inbound_transfers: nil, intra_stripe_flows: nil, outbound_payments: nil, outbound_transfers: nil) ⇒ Features
constructor
A new instance of Features.
Methods inherited from RequestParams
Constructor Details
#initialize(card_issuing: nil, deposit_insurance: nil, financial_addresses: nil, inbound_transfers: nil, intra_stripe_flows: nil, outbound_payments: nil, outbound_transfers: nil) ⇒ Features
Returns a new instance of Features.
407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 |
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 407 def initialize( card_issuing: nil, deposit_insurance: nil, financial_addresses: nil, inbound_transfers: nil, intra_stripe_flows: nil, outbound_payments: nil, outbound_transfers: nil ) @card_issuing = card_issuing @deposit_insurance = deposit_insurance @financial_addresses = financial_addresses @inbound_transfers = inbound_transfers @intra_stripe_flows = intra_stripe_flows @outbound_payments = outbound_payments @outbound_transfers = outbound_transfers end |
Instance Attribute Details
#card_issuing ⇒ Object
Encodes the FinancialAccount’s ability to be used with the Issuing product, including attaching cards to and drawing funds from the FinancialAccount.
393 394 395 |
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 393 def card_issuing @card_issuing end |
#deposit_insurance ⇒ Object
Represents whether this FinancialAccount is eligible for deposit insurance. Various factors determine the insurance amount.
395 396 397 |
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 395 def deposit_insurance @deposit_insurance end |
#financial_addresses ⇒ Object
Contains Features that add FinancialAddresses to the FinancialAccount.
397 398 399 |
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 397 def financial_addresses @financial_addresses end |
#inbound_transfers ⇒ Object
Contains settings related to adding funds to a FinancialAccount from another Account with the same owner.
399 400 401 |
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 399 def inbound_transfers @inbound_transfers end |
#intra_stripe_flows ⇒ Object
Represents the ability for the FinancialAccount to send money to, or receive money from other FinancialAccounts (for example, via OutboundPayment).
401 402 403 |
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 401 def intra_stripe_flows @intra_stripe_flows end |
#outbound_payments ⇒ Object
Includes Features related to initiating money movement out of the FinancialAccount to someone else’s bucket of money.
403 404 405 |
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 403 def outbound_payments @outbound_payments end |
#outbound_transfers ⇒ Object
Contains a Feature and settings related to moving money out of the FinancialAccount into another Account with the same owner.
405 406 407 |
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 405 def outbound_transfers @outbound_transfers end |