Class: Stripe::Treasury::FinancialAccountUpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Treasury::FinancialAccountUpdateParams
- Defined in:
- lib/stripe/params/treasury/financial_account_update_params.rb
Defined Under Namespace
Classes: Features, ForwardingSettings, PlatformRestrictions
Instance Attribute Summary collapse
-
#display_name ⇒ Object
The display name for the FinancialAccount.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#features ⇒ Object
Encodes whether a FinancialAccount has access to a particular feature, with a status enum and associated ‘status_details`.
-
#forwarding_settings ⇒ Object
A different bank account where funds can be deposited/debited in order to get the closing FA’s balance to $0.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#nickname ⇒ Object
The nickname for the FinancialAccount.
-
#platform_restrictions ⇒ Object
The set of functionalities that the platform can restrict on the FinancialAccount.
Instance Method Summary collapse
-
#initialize(display_name: nil, expand: nil, features: nil, forwarding_settings: nil, metadata: nil, nickname: nil, platform_restrictions: nil) ⇒ FinancialAccountUpdateParams
constructor
A new instance of FinancialAccountUpdateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(display_name: nil, expand: nil, features: nil, forwarding_settings: nil, metadata: nil, nickname: nil, platform_restrictions: nil) ⇒ FinancialAccountUpdateParams
Returns a new instance of FinancialAccountUpdateParams.
204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 |
# File 'lib/stripe/params/treasury/financial_account_update_params.rb', line 204 def initialize( display_name: nil, expand: nil, features: nil, forwarding_settings: nil, metadata: nil, nickname: nil, platform_restrictions: nil ) @display_name = display_name @expand = @features = features @forwarding_settings = forwarding_settings @metadata = @nickname = nickname @platform_restrictions = platform_restrictions end |
Instance Attribute Details
#display_name ⇒ Object
The display name for the FinancialAccount. Use this field to customize the names of the FinancialAccounts for your connected accounts. Unlike the ‘nickname` field, `display_name` is not internal metadata and will be exposed to connected accounts.
190 191 192 |
# File 'lib/stripe/params/treasury/financial_account_update_params.rb', line 190 def display_name @display_name end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
192 193 194 |
# File 'lib/stripe/params/treasury/financial_account_update_params.rb', line 192 def @expand end |
#features ⇒ Object
Encodes whether a FinancialAccount has access to a particular feature, with a status enum and associated ‘status_details`. Stripe or the platform may control features via the requested field.
194 195 196 |
# File 'lib/stripe/params/treasury/financial_account_update_params.rb', line 194 def features @features end |
#forwarding_settings ⇒ Object
A different bank account where funds can be deposited/debited in order to get the closing FA’s balance to $0
196 197 198 |
# File 'lib/stripe/params/treasury/financial_account_update_params.rb', line 196 def forwarding_settings @forwarding_settings end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
198 199 200 |
# File 'lib/stripe/params/treasury/financial_account_update_params.rb', line 198 def @metadata end |
#nickname ⇒ Object
The nickname for the FinancialAccount.
200 201 202 |
# File 'lib/stripe/params/treasury/financial_account_update_params.rb', line 200 def nickname @nickname end |
#platform_restrictions ⇒ Object
The set of functionalities that the platform can restrict on the FinancialAccount.
202 203 204 |
# File 'lib/stripe/params/treasury/financial_account_update_params.rb', line 202 def platform_restrictions @platform_restrictions end |