Class: Stripe::Treasury::InboundTransfer::CancelParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Treasury::InboundTransfer::CancelParams
- Defined in:
- lib/stripe/resources/treasury/inbound_transfer.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ CancelParams
constructor
A new instance of CancelParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ CancelParams
Returns a new instance of CancelParams.
217 218 219 |
# File 'lib/stripe/resources/treasury/inbound_transfer.rb', line 217 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
215 216 217 |
# File 'lib/stripe/resources/treasury/inbound_transfer.rb', line 215 def @expand end |