Class: Stripe::Treasury::InboundTransfer::OriginPaymentMethodDetails::UsBankAccount

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/treasury/inbound_transfer.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_holder_typeObject (readonly)

Account holder type: individual or company.



54
55
56
# File 'lib/stripe/resources/treasury/inbound_transfer.rb', line 54

def 
  @account_holder_type
end

#account_typeObject (readonly)

Account type: checkings or savings. Defaults to checking if omitted.



56
57
58
# File 'lib/stripe/resources/treasury/inbound_transfer.rb', line 56

def 
  @account_type
end

#bank_nameObject (readonly)

Name of the bank associated with the bank account.



58
59
60
# File 'lib/stripe/resources/treasury/inbound_transfer.rb', line 58

def bank_name
  @bank_name
end

#fingerprintObject (readonly)

Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.



60
61
62
# File 'lib/stripe/resources/treasury/inbound_transfer.rb', line 60

def fingerprint
  @fingerprint
end

#last4Object (readonly)

Last four digits of the bank account number.



62
63
64
# File 'lib/stripe/resources/treasury/inbound_transfer.rb', line 62

def last4
  @last4
end

#mandateObject (readonly)

ID of the mandate used to make this payment.



64
65
66
# File 'lib/stripe/resources/treasury/inbound_transfer.rb', line 64

def mandate
  @mandate
end

#networkObject (readonly)

The network rails used. See the [docs](stripe.com/docs/treasury/money-movement/timelines) to learn more about money movement timelines for each network type.



66
67
68
# File 'lib/stripe/resources/treasury/inbound_transfer.rb', line 66

def network
  @network
end

#routing_numberObject (readonly)

Routing number of the bank account.



68
69
70
# File 'lib/stripe/resources/treasury/inbound_transfer.rb', line 68

def routing_number
  @routing_number
end