Class: Stripe::Treasury::InboundTransferService::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/treasury/inbound_transfer_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, currency: nil, description: nil, expand: nil, financial_account: nil, metadata: nil, origin_payment_method: nil, statement_descriptor: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/stripe/services/treasury/inbound_transfer_service.rb', line 56

def initialize(
  amount: nil,
  currency: nil,
  description: nil,
  expand: nil,
  financial_account: nil,
  metadata: nil,
  origin_payment_method: nil,
  statement_descriptor: nil
)
  @amount = amount
  @currency = currency
  @description = description
  @expand = expand
  @financial_account = 
  @metadata = 
  @origin_payment_method = origin_payment_method
  @statement_descriptor = statement_descriptor
end

Instance Attribute Details

#amountObject

Amount (in cents) to be transferred.



40
41
42
# File 'lib/stripe/services/treasury/inbound_transfer_service.rb', line 40

def amount
  @amount
end

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



42
43
44
# File 'lib/stripe/services/treasury/inbound_transfer_service.rb', line 42

def currency
  @currency
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



44
45
46
# File 'lib/stripe/services/treasury/inbound_transfer_service.rb', line 44

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



46
47
48
# File 'lib/stripe/services/treasury/inbound_transfer_service.rb', line 46

def expand
  @expand
end

#financial_accountObject

The FinancialAccount to send funds to.



48
49
50
# File 'lib/stripe/services/treasury/inbound_transfer_service.rb', line 48

def 
  @financial_account
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



50
51
52
# File 'lib/stripe/services/treasury/inbound_transfer_service.rb', line 50

def 
  @metadata
end

#origin_payment_methodObject

The origin payment method to be debited for the InboundTransfer.



52
53
54
# File 'lib/stripe/services/treasury/inbound_transfer_service.rb', line 52

def origin_payment_method
  @origin_payment_method
end

#statement_descriptorObject

The complete description that appears on your customers’ statements. Maximum 10 characters.



54
55
56
# File 'lib/stripe/services/treasury/inbound_transfer_service.rb', line 54

def statement_descriptor
  @statement_descriptor
end