Class: Stripe::Treasury::OutboundPayment::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/treasury/outbound_payment.rb

Defined Under Namespace

Classes: DestinationPaymentMethodData, DestinationPaymentMethodOptions, EndUserDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, currency: nil, customer: nil, description: nil, destination_payment_method: nil, destination_payment_method_data: nil, destination_payment_method_options: nil, end_user_details: nil, expand: nil, financial_account: nil, metadata: nil, statement_descriptor: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 429

def initialize(
  amount: nil,
  currency: nil,
  customer: nil,
  description: nil,
  destination_payment_method: nil,
  destination_payment_method_data: nil,
  destination_payment_method_options: nil,
  end_user_details: nil,
  expand: nil,
  financial_account: nil,
  metadata: nil,
  statement_descriptor: nil
)
  @amount = amount
  @currency = currency
  @customer = customer
  @description = description
  @destination_payment_method = destination_payment_method
  @destination_payment_method_data = destination_payment_method_data
  @destination_payment_method_options = destination_payment_method_options
  @end_user_details = end_user_details
  @expand = expand
  @financial_account = 
  @metadata = 
  @statement_descriptor = statement_descriptor
end

Instance Attribute Details

#amountObject

Amount (in cents) to be transferred.



405
406
407
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 405

def amount
  @amount
end

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



407
408
409
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 407

def currency
  @currency
end

#customerObject

ID of the customer to whom the OutboundPayment is sent. Must match the Customer attached to the ‘destination_payment_method` passed in.



409
410
411
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 409

def customer
  @customer
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



411
412
413
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 411

def description
  @description
end

#destination_payment_methodObject

The PaymentMethod to use as the payment instrument for the OutboundPayment. Exclusive with ‘destination_payment_method_data`.



413
414
415
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 413

def destination_payment_method
  @destination_payment_method
end

#destination_payment_method_dataObject

Hash used to generate the PaymentMethod to be used for this OutboundPayment. Exclusive with ‘destination_payment_method`.



415
416
417
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 415

def destination_payment_method_data
  @destination_payment_method_data
end

#destination_payment_method_optionsObject

Payment method-specific configuration for this OutboundPayment.



417
418
419
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 417

def destination_payment_method_options
  @destination_payment_method_options
end

#end_user_detailsObject

End user details.



419
420
421
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 419

def end_user_details
  @end_user_details
end

#expandObject

Specifies which fields in the response should be expanded.



421
422
423
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 421

def expand
  @expand
end

#financial_accountObject

The FinancialAccount to pull funds from.



423
424
425
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 423

def 
  @financial_account
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



425
426
427
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 425

def 
  @metadata
end

#statement_descriptorObject

The description that appears on the receiving end for this OutboundPayment (for example, bank statement for external bank transfer). Maximum 10 characters for ‘ach` payments, 140 characters for `us_domestic_wire` payments, or 500 characters for `stripe` network transfers. The default value is “payment”.



427
428
429
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 427

def statement_descriptor
  @statement_descriptor
end