Class: Stripe::Treasury::OutboundPayment::CreateParams::DestinationPaymentMethodData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/treasury/outbound_payment.rb

Defined Under Namespace

Classes: BillingDetails, UsBankAccount

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_details: nil, financial_account: nil, metadata: nil, type: nil, us_bank_account: nil) ⇒ DestinationPaymentMethodData

Returns a new instance of DestinationPaymentMethodData.



272
273
274
275
276
277
278
279
280
281
282
283
284
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 272

def initialize(
  billing_details: nil,
  financial_account: nil,
  metadata: nil,
  type: nil,
  us_bank_account: nil
)
  @billing_details = billing_details
  @financial_account = 
  @metadata = 
  @type = type
  @us_bank_account = 
end

Instance Attribute Details

#billing_detailsObject

Billing information associated with the PaymentMethod that may be used or required by particular types of payment methods.



262
263
264
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 262

def billing_details
  @billing_details
end

#financial_accountObject

Required if type is set to ‘financial_account`. The FinancialAccount ID to send funds to.



264
265
266
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 264

def 
  @financial_account
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



266
267
268
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 266

def 
  @metadata
end

#typeObject

The type of the PaymentMethod. An additional hash is included on the PaymentMethod with a name matching this value. It contains additional information specific to the PaymentMethod type.



268
269
270
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 268

def type
  @type
end

#us_bank_accountObject

Required hash if type is set to ‘us_bank_account`.



270
271
272
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 270

def 
  @us_bank_account
end