Class: Stripe::Treasury::OutboundPayment::CreateParams::DestinationPaymentMethodData::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Treasury::OutboundPayment::CreateParams::DestinationPaymentMethodData::UsBankAccount
- Defined in:
- lib/stripe/resources/treasury/outbound_payment.rb
Instance Attribute Summary collapse
-
#account_holder_type ⇒ Object
Account holder type: individual or company.
-
#account_number ⇒ Object
Account number of the bank account.
-
#account_type ⇒ Object
Account type: checkings or savings.
-
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
-
#routing_number ⇒ Object
Routing number of the bank account.
Instance Method Summary collapse
-
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
244 245 246 247 248 249 250 251 252 253 254 255 256 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 244 def initialize( account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil ) @account_holder_type = account_holder_type @account_number = account_number @account_type = account_type @financial_connections_account = financial_connections_account @routing_number = routing_number end |
Instance Attribute Details
#account_holder_type ⇒ Object
Account holder type: individual or company.
234 235 236 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 234 def account_holder_type @account_holder_type end |
#account_number ⇒ Object
Account number of the bank account.
236 237 238 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 236 def account_number @account_number end |
#account_type ⇒ Object
Account type: checkings or savings. Defaults to checking if omitted.
238 239 240 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 238 def account_type @account_type end |
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
240 241 242 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 240 def financial_connections_account @financial_connections_account end |
#routing_number ⇒ Object
Routing number of the bank account.
242 243 244 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 242 def routing_number @routing_number end |