Class: Stripe::Treasury::OutboundPayment::EndUserDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Treasury::OutboundPayment::EndUserDetails
- Defined in:
- lib/stripe/resources/treasury/outbound_payment.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#ip_address ⇒ Object
readonly
IP address of the user initiating the OutboundPayment.
-
#present ⇒ Object
readonly
‘true` if the OutboundPayment creation request is being made on behalf of an end user by a platform.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#ip_address ⇒ Object (readonly)
IP address of the user initiating the OutboundPayment. Set if ‘present` is set to `true`. IP address collection is required for risk and compliance reasons. This will be used to help determine if the OutboundPayment is authorized or should be blocked.
99 100 101 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 99 def ip_address @ip_address end |
#present ⇒ Object (readonly)
‘true` if the OutboundPayment creation request is being made on behalf of an end user by a platform. Otherwise, `false`.
102 103 104 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 102 def present @present end |