Class: Stripe::Treasury::OutboundPayment::FailParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Treasury::OutboundPayment::FailParams
- Defined in:
- lib/stripe/resources/treasury/outbound_payment.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ FailParams
constructor
A new instance of FailParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ FailParams
Returns a new instance of FailParams.
507 508 509 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 507 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
505 506 507 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 505 def @expand end |