Class: Stripe::Treasury::OutboundPayment::ReturnOutboundPaymentParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Treasury::OutboundPayment::ReturnOutboundPaymentParams
- Defined in:
- lib/stripe/resources/treasury/outbound_payment.rb
Defined Under Namespace
Classes: ReturnedDetails
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#returned_details ⇒ Object
Optional hash to set the return code.
Instance Method Summary collapse
-
#initialize(expand: nil, returned_details: nil) ⇒ ReturnOutboundPaymentParams
constructor
A new instance of ReturnOutboundPaymentParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, returned_details: nil) ⇒ ReturnOutboundPaymentParams
Returns a new instance of ReturnOutboundPaymentParams.
548 549 550 551 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 548 def initialize(expand: nil, returned_details: nil) @expand = @returned_details = returned_details end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
544 545 546 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 544 def @expand end |
#returned_details ⇒ Object
Optional hash to set the return code.
546 547 548 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 546 def returned_details @returned_details end |