Class: Stripe::Treasury::OutboundPaymentService::CancelParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Treasury::OutboundPaymentService::CancelParams
- Defined in:
- lib/stripe/services/treasury/outbound_payment_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ CancelParams
constructor
A new instance of CancelParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ CancelParams
Returns a new instance of CancelParams.
260 261 262 |
# File 'lib/stripe/services/treasury/outbound_payment_service.rb', line 260 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
258 259 260 |
# File 'lib/stripe/services/treasury/outbound_payment_service.rb', line 258 def @expand end |