Class: Stripe::Treasury::OutboundPaymentService::CreateParams::DestinationPaymentMethodData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Treasury::OutboundPaymentService::CreateParams::DestinationPaymentMethodData
- Defined in:
- lib/stripe/services/treasury/outbound_payment_service.rb
Defined Under Namespace
Classes: BillingDetails, UsBankAccount
Instance Attribute Summary collapse
-
#billing_details ⇒ Object
Billing information associated with the PaymentMethod that may be used or required by particular types of payment methods.
-
#financial_account ⇒ Object
Required if type is set to ‘financial_account`.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#type ⇒ Object
The type of the PaymentMethod.
-
#us_bank_account ⇒ Object
Required hash if type is set to ‘us_bank_account`.
Instance Method Summary collapse
-
#initialize(billing_details: nil, financial_account: nil, metadata: nil, type: nil, us_bank_account: nil) ⇒ DestinationPaymentMethodData
constructor
A new instance of DestinationPaymentMethodData.
Methods inherited from RequestParams
Constructor Details
#initialize(billing_details: nil, financial_account: nil, metadata: nil, type: nil, us_bank_account: nil) ⇒ DestinationPaymentMethodData
Returns a new instance of DestinationPaymentMethodData.
150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/stripe/services/treasury/outbound_payment_service.rb', line 150 def initialize( billing_details: nil, financial_account: nil, metadata: nil, type: nil, us_bank_account: nil ) @billing_details = billing_details @financial_account = financial_account @metadata = @type = type @us_bank_account = us_bank_account end |
Instance Attribute Details
#billing_details ⇒ Object
Billing information associated with the PaymentMethod that may be used or required by particular types of payment methods.
140 141 142 |
# File 'lib/stripe/services/treasury/outbound_payment_service.rb', line 140 def billing_details @billing_details end |
#financial_account ⇒ Object
Required if type is set to ‘financial_account`. The FinancialAccount ID to send funds to.
142 143 144 |
# File 'lib/stripe/services/treasury/outbound_payment_service.rb', line 142 def financial_account @financial_account end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
144 145 146 |
# File 'lib/stripe/services/treasury/outbound_payment_service.rb', line 144 def @metadata end |
#type ⇒ Object
The type of the PaymentMethod. An additional hash is included on the PaymentMethod with a name matching this value. It contains additional information specific to the PaymentMethod type.
146 147 148 |
# File 'lib/stripe/services/treasury/outbound_payment_service.rb', line 146 def type @type end |
#us_bank_account ⇒ Object
Required hash if type is set to ‘us_bank_account`.
148 149 150 |
# File 'lib/stripe/services/treasury/outbound_payment_service.rb', line 148 def us_bank_account @us_bank_account end |