Class: Stripe::Treasury::OutboundTransfer::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/treasury/outbound_transfer.rb

Defined Under Namespace

Classes: DestinationPaymentMethodData, DestinationPaymentMethodOptions, NetworkDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, currency: nil, description: nil, destination_payment_method: nil, destination_payment_method_data: nil, destination_payment_method_options: nil, expand: nil, financial_account: nil, metadata: nil, network_details: nil, statement_descriptor: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
# File 'lib/stripe/resources/treasury/outbound_transfer.rb', line 333

def initialize(
  amount: nil,
  currency: nil,
  description: nil,
  destination_payment_method: nil,
  destination_payment_method_data: nil,
  destination_payment_method_options: nil,
  expand: nil,
  financial_account: nil,
  metadata: nil,
  network_details: nil,
  statement_descriptor: nil
)
  @amount = amount
  @currency = currency
  @description = description
  @destination_payment_method = destination_payment_method
  @destination_payment_method_data = destination_payment_method_data
  @destination_payment_method_options = destination_payment_method_options
  @expand = expand
  @financial_account = 
  @metadata = 
  @network_details = network_details
  @statement_descriptor = statement_descriptor
end

Instance Attribute Details

#amountObject

Amount (in cents) to be transferred.



311
312
313
# File 'lib/stripe/resources/treasury/outbound_transfer.rb', line 311

def amount
  @amount
end

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



313
314
315
# File 'lib/stripe/resources/treasury/outbound_transfer.rb', line 313

def currency
  @currency
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



315
316
317
# File 'lib/stripe/resources/treasury/outbound_transfer.rb', line 315

def description
  @description
end

#destination_payment_methodObject

The PaymentMethod to use as the payment instrument for the OutboundTransfer.



317
318
319
# File 'lib/stripe/resources/treasury/outbound_transfer.rb', line 317

def destination_payment_method
  @destination_payment_method
end

#destination_payment_method_dataObject

Hash used to generate the PaymentMethod to be used for this OutboundTransfer. Exclusive with ‘destination_payment_method`.



319
320
321
# File 'lib/stripe/resources/treasury/outbound_transfer.rb', line 319

def destination_payment_method_data
  @destination_payment_method_data
end

#destination_payment_method_optionsObject

Hash describing payment method configuration details.



321
322
323
# File 'lib/stripe/resources/treasury/outbound_transfer.rb', line 321

def destination_payment_method_options
  @destination_payment_method_options
end

#expandObject

Specifies which fields in the response should be expanded.



323
324
325
# File 'lib/stripe/resources/treasury/outbound_transfer.rb', line 323

def expand
  @expand
end

#financial_accountObject

The FinancialAccount to pull funds from.



325
326
327
# File 'lib/stripe/resources/treasury/outbound_transfer.rb', line 325

def 
  @financial_account
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



327
328
329
# File 'lib/stripe/resources/treasury/outbound_transfer.rb', line 327

def 
  @metadata
end

#network_detailsObject

Details about the network used for the OutboundTransfer.



329
330
331
# File 'lib/stripe/resources/treasury/outbound_transfer.rb', line 329

def network_details
  @network_details
end

#statement_descriptorObject

Statement descriptor to be shown on the receiving end of an OutboundTransfer. Maximum 10 characters for ‘ach` transfers or 140 characters for `us_domestic_wire` transfers. The default value is “transfer”.



331
332
333
# File 'lib/stripe/resources/treasury/outbound_transfer.rb', line 331

def statement_descriptor
  @statement_descriptor
end