Class: Stripe::Treasury::OutboundTransfer::ListParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/treasury/outbound_transfer.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(ending_before: nil, expand: nil, financial_account: nil, limit: nil, starting_after: nil, status: nil) ⇒ ListParams

Returns a new instance of ListParams.



244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
# File 'lib/stripe/resources/treasury/outbound_transfer.rb', line 244

def initialize(
  ending_before: nil,
  expand: nil,
  financial_account: nil,
  limit: nil,
  starting_after: nil,
  status: nil
)
  @ending_before = ending_before
  @expand = expand
  @financial_account = 
  @limit = limit
  @starting_after = starting_after
  @status = status
end

Instance Attribute Details

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



232
233
234
# File 'lib/stripe/resources/treasury/outbound_transfer.rb', line 232

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



234
235
236
# File 'lib/stripe/resources/treasury/outbound_transfer.rb', line 234

def expand
  @expand
end

#financial_accountObject

Returns objects associated with this FinancialAccount.



236
237
238
# File 'lib/stripe/resources/treasury/outbound_transfer.rb', line 236

def 
  @financial_account
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



238
239
240
# File 'lib/stripe/resources/treasury/outbound_transfer.rb', line 238

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



240
241
242
# File 'lib/stripe/resources/treasury/outbound_transfer.rb', line 240

def starting_after
  @starting_after
end

#statusObject

Only return OutboundTransfers that have the given status: ‘processing`, `canceled`, `failed`, `posted`, or `returned`.



242
243
244
# File 'lib/stripe/resources/treasury/outbound_transfer.rb', line 242

def status
  @status
end