Class: Stripe::Treasury::OutboundTransferCreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/treasury/outbound_transfer_create_params.rb

Defined Under Namespace

Classes: DestinationPaymentMethodData, DestinationPaymentMethodOptions, NetworkDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, currency: nil, description: nil, destination_payment_method: nil, destination_payment_method_data: nil, destination_payment_method_options: nil, expand: nil, financial_account: nil, metadata: nil, network_details: nil, statement_descriptor: nil) ⇒ OutboundTransferCreateParams

Returns a new instance of OutboundTransferCreateParams.



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/stripe/params/treasury/outbound_transfer_create_params.rb', line 78

def initialize(
  amount: nil,
  currency: nil,
  description: nil,
  destination_payment_method: nil,
  destination_payment_method_data: nil,
  destination_payment_method_options: nil,
  expand: nil,
  financial_account: nil,
  metadata: nil,
  network_details: nil,
  statement_descriptor: nil
)
  @amount = amount
  @currency = currency
  @description = description
  @destination_payment_method = destination_payment_method
  @destination_payment_method_data = destination_payment_method_data
  @destination_payment_method_options = destination_payment_method_options
  @expand = expand
  @financial_account = 
  @metadata = 
  @network_details = network_details
  @statement_descriptor = statement_descriptor
end

Instance Attribute Details

#amountObject

Amount (in cents) to be transferred.



56
57
58
# File 'lib/stripe/params/treasury/outbound_transfer_create_params.rb', line 56

def amount
  @amount
end

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



58
59
60
# File 'lib/stripe/params/treasury/outbound_transfer_create_params.rb', line 58

def currency
  @currency
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



60
61
62
# File 'lib/stripe/params/treasury/outbound_transfer_create_params.rb', line 60

def description
  @description
end

#destination_payment_methodObject

The PaymentMethod to use as the payment instrument for the OutboundTransfer.



62
63
64
# File 'lib/stripe/params/treasury/outbound_transfer_create_params.rb', line 62

def destination_payment_method
  @destination_payment_method
end

#destination_payment_method_dataObject

Hash used to generate the PaymentMethod to be used for this OutboundTransfer. Exclusive with ‘destination_payment_method`.



64
65
66
# File 'lib/stripe/params/treasury/outbound_transfer_create_params.rb', line 64

def destination_payment_method_data
  @destination_payment_method_data
end

#destination_payment_method_optionsObject

Hash describing payment method configuration details.



66
67
68
# File 'lib/stripe/params/treasury/outbound_transfer_create_params.rb', line 66

def destination_payment_method_options
  @destination_payment_method_options
end

#expandObject

Specifies which fields in the response should be expanded.



68
69
70
# File 'lib/stripe/params/treasury/outbound_transfer_create_params.rb', line 68

def expand
  @expand
end

#financial_accountObject

The FinancialAccount to pull funds from.



70
71
72
# File 'lib/stripe/params/treasury/outbound_transfer_create_params.rb', line 70

def 
  @financial_account
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



72
73
74
# File 'lib/stripe/params/treasury/outbound_transfer_create_params.rb', line 72

def 
  @metadata
end

#network_detailsObject

Details about the network used for the OutboundTransfer.



74
75
76
# File 'lib/stripe/params/treasury/outbound_transfer_create_params.rb', line 74

def network_details
  @network_details
end

#statement_descriptorObject

Statement descriptor to be shown on the receiving end of an OutboundTransfer. Maximum 10 characters for ‘ach` transfers or 140 characters for `us_domestic_wire` transfers. The default value is “transfer”. Can only include -#.$&*, spaces, and alphanumeric characters.



76
77
78
# File 'lib/stripe/params/treasury/outbound_transfer_create_params.rb', line 76

def statement_descriptor
  @statement_descriptor
end