Class: Stripe::Treasury::ReceivedCredit::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/treasury/received_credit.rb

Defined Under Namespace

Classes: InitiatingPaymentMethodDetails, NetworkDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, currency: nil, description: nil, expand: nil, financial_account: nil, initiating_payment_method_details: nil, network: nil, network_details: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
# File 'lib/stripe/resources/treasury/received_credit.rb', line 318

def initialize(
  amount: nil,
  currency: nil,
  description: nil,
  expand: nil,
  financial_account: nil,
  initiating_payment_method_details: nil,
  network: nil,
  network_details: nil
)
  @amount = amount
  @currency = currency
  @description = description
  @expand = expand
  @financial_account = 
  @initiating_payment_method_details = initiating_payment_method_details
  @network = network
  @network_details = network_details
end

Instance Attribute Details

#amountObject

Amount (in cents) to be transferred.



302
303
304
# File 'lib/stripe/resources/treasury/received_credit.rb', line 302

def amount
  @amount
end

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



304
305
306
# File 'lib/stripe/resources/treasury/received_credit.rb', line 304

def currency
  @currency
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



306
307
308
# File 'lib/stripe/resources/treasury/received_credit.rb', line 306

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



308
309
310
# File 'lib/stripe/resources/treasury/received_credit.rb', line 308

def expand
  @expand
end

#financial_accountObject

The FinancialAccount to send funds to.



310
311
312
# File 'lib/stripe/resources/treasury/received_credit.rb', line 310

def 
  @financial_account
end

#initiating_payment_method_detailsObject

Initiating payment method details for the object.



312
313
314
# File 'lib/stripe/resources/treasury/received_credit.rb', line 312

def initiating_payment_method_details
  @initiating_payment_method_details
end

#networkObject

Specifies the network rails to be used. If not set, will default to the PaymentMethod’s preferred network. See the [docs](stripe.com/docs/treasury/money-movement/timelines) to learn more about money movement timelines for each network type.



314
315
316
# File 'lib/stripe/resources/treasury/received_credit.rb', line 314

def network
  @network
end

#network_detailsObject

Details about the network used for the ReceivedCredit.



316
317
318
# File 'lib/stripe/resources/treasury/received_credit.rb', line 316

def network_details
  @network_details
end