Class: Stripe::Treasury::ReceivedCredit::InitiatingPaymentMethodDetails::UsBankAccount
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Treasury::ReceivedCredit::InitiatingPaymentMethodDetails::UsBankAccount
- Defined in:
- lib/stripe/resources/treasury/received_credit.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bank_name ⇒ Object
readonly
Bank name.
-
#last4 ⇒ Object
readonly
The last four digits of the bank account number.
-
#routing_number ⇒ Object
readonly
The routing number for the bank account.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bank_name ⇒ Object (readonly)
Bank name.
48 49 50 |
# File 'lib/stripe/resources/treasury/received_credit.rb', line 48 def bank_name @bank_name end |
#last4 ⇒ Object (readonly)
The last four digits of the bank account number.
50 51 52 |
# File 'lib/stripe/resources/treasury/received_credit.rb', line 50 def last4 @last4 end |
#routing_number ⇒ Object (readonly)
The routing number for the bank account.
52 53 54 |
# File 'lib/stripe/resources/treasury/received_credit.rb', line 52 def routing_number @routing_number end |