Class: Stripe::Treasury::ReceivedCredit::LinkedFlows::SourceFlowDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Treasury::ReceivedCredit::LinkedFlows::SourceFlowDetails
- Defined in:
- lib/stripe/resources/treasury/received_credit.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#credit_reversal ⇒ Object
readonly
You can reverse some [ReceivedCredits](stripe.com/docs/api#received_credits) depending on their network and source flow.
-
#outbound_payment ⇒ Object
readonly
Use [OutboundPayments](docs.stripe.com/docs/treasury/moving-money/financial-accounts/out-of/outbound-payments) to send funds to another party’s external bank account or [FinancialAccount](stripe.com/docs/api#financial_accounts).
-
#payout ⇒ Object
readonly
A ‘Payout` object is created when you receive funds from Stripe, or when you initiate a payout to either a bank account or debit card of a [connected Stripe account](/docs/connect/bank-debit-card-payouts).
-
#type ⇒ Object
readonly
The type of the source flow that originated the ReceivedCredit.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#credit_reversal ⇒ Object (readonly)
You can reverse some [ReceivedCredits](stripe.com/docs/api#received_credits) depending on their network and source flow. Reversing a ReceivedCredit leads to the creation of a new object known as a CreditReversal.
86 87 88 |
# File 'lib/stripe/resources/treasury/received_credit.rb', line 86 def credit_reversal @credit_reversal end |
#outbound_payment ⇒ Object (readonly)
Use [OutboundPayments](docs.stripe.com/docs/treasury/moving-money/financial-accounts/out-of/outbound-payments) to send funds to another party’s external bank account or [FinancialAccount](stripe.com/docs/api#financial_accounts). To send money to an account belonging to the same user, use an [OutboundTransfer](stripe.com/docs/api#outbound_transfers).
Simulate OutboundPayment state changes with the ‘/v1/test_helpers/treasury/outbound_payments` endpoints. These methods can only be called on test mode objects.
Related guide: [Moving money with Treasury using OutboundPayment objects](docs.stripe.com/docs/treasury/moving-money/financial-accounts/out-of/outbound-payments)
93 94 95 |
# File 'lib/stripe/resources/treasury/received_credit.rb', line 93 def outbound_payment @outbound_payment end |
#payout ⇒ Object (readonly)
A ‘Payout` object is created when you receive funds from Stripe, or when you initiate a payout to either a bank account or debit card of a [connected Stripe account](/docs/connect/bank-debit-card-payouts). You can retrieve individual payouts, and list all payouts. Payouts are made on [varying schedules](/docs/connect/manage-payout-schedule), depending on your country and industry.
Related guide: [Receiving payouts](stripe.com/docs/payouts)
103 104 105 |
# File 'lib/stripe/resources/treasury/received_credit.rb', line 103 def payout @payout end |
#type ⇒ Object (readonly)
The type of the source flow that originated the ReceivedCredit.
106 107 108 |
# File 'lib/stripe/resources/treasury/received_credit.rb', line 106 def type @type end |