Class: Stripe::Treasury::ReceivedCreditCreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/treasury/received_credit_create_params.rb

Defined Under Namespace

Classes: InitiatingPaymentMethodDetails, NetworkDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, currency: nil, description: nil, expand: nil, financial_account: nil, initiating_payment_method_details: nil, network: nil, network_details: nil) ⇒ ReceivedCreditCreateParams

Returns a new instance of ReceivedCreditCreateParams.



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/stripe/params/treasury/received_credit_create_params.rb', line 69

def initialize(
  amount: nil,
  currency: nil,
  description: nil,
  expand: nil,
  financial_account: nil,
  initiating_payment_method_details: nil,
  network: nil,
  network_details: nil
)
  @amount = amount
  @currency = currency
  @description = description
  @expand = expand
  @financial_account = 
  @initiating_payment_method_details = initiating_payment_method_details
  @network = network
  @network_details = network_details
end

Instance Attribute Details

#amountObject

Amount (in cents) to be transferred.



53
54
55
# File 'lib/stripe/params/treasury/received_credit_create_params.rb', line 53

def amount
  @amount
end

#currencyObject

Three-letter ISO currency code, in lowercase. Must be a supported currency.



55
56
57
# File 'lib/stripe/params/treasury/received_credit_create_params.rb', line 55

def currency
  @currency
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



57
58
59
# File 'lib/stripe/params/treasury/received_credit_create_params.rb', line 57

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



59
60
61
# File 'lib/stripe/params/treasury/received_credit_create_params.rb', line 59

def expand
  @expand
end

#financial_accountObject

The FinancialAccount to send funds to.



61
62
63
# File 'lib/stripe/params/treasury/received_credit_create_params.rb', line 61

def 
  @financial_account
end

#initiating_payment_method_detailsObject

Initiating payment method details for the object.



63
64
65
# File 'lib/stripe/params/treasury/received_credit_create_params.rb', line 63

def initiating_payment_method_details
  @initiating_payment_method_details
end

#networkObject

Specifies the network rails to be used. If not set, will default to the PaymentMethod's preferred network. See the docs to learn more about money movement timelines for each network type.



65
66
67
# File 'lib/stripe/params/treasury/received_credit_create_params.rb', line 65

def network
  @network
end

#network_detailsObject

Details about the network used for the ReceivedCredit.



67
68
69
# File 'lib/stripe/params/treasury/received_credit_create_params.rb', line 67

def network_details
  @network_details
end