Class: Stripe::Treasury::ReceivedDebit
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Treasury::ReceivedDebit
- Extended by:
- APIOperations::List
- Defined in:
- lib/stripe/resources/treasury/received_debit.rb
Overview
ReceivedDebits represent funds pulled from a [FinancialAccount](stripe.com/docs/api#financial_accounts). These are not initiated from the FinancialAccount.
Defined Under Namespace
Classes: CreateParams, InitiatingPaymentMethodDetails, LinkedFlows, ListParams, NetworkDetails, ReversalDetails, TestHelpers
Constant Summary collapse
- OBJECT_NAME =
"treasury.received_debit"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
Amount (in cents) transferred.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#currency ⇒ Object
readonly
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#description ⇒ Object
readonly
An arbitrary string attached to the object.
-
#failure_code ⇒ Object
readonly
Reason for the failure.
-
#financial_account ⇒ Object
readonly
The FinancialAccount that funds were pulled from.
-
#hosted_regulatory_receipt_url ⇒ Object
readonly
A [hosted transaction receipt](stripe.com/docs/treasury/moving-money/regulatory-receipts) URL that is provided when money movement is considered regulated under Stripe’s money transmission licenses.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#initiating_payment_method_details ⇒ Object
readonly
Attribute for field initiating_payment_method_details.
-
#linked_flows ⇒ Object
readonly
Attribute for field linked_flows.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#network ⇒ Object
readonly
The network used for the ReceivedDebit.
-
#network_details ⇒ Object
readonly
Details specific to the money movement rails.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#reversal_details ⇒ Object
readonly
Details describing when a ReceivedDebit might be reversed.
-
#status ⇒ Object
readonly
Status of the ReceivedDebit.
-
#transaction ⇒ Object
readonly
The Transaction associated with this object.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
-
.list(params = {}, opts = {}) ⇒ Object
Returns a list of ReceivedDebits.
- .object_name ⇒ Object
Instance Method Summary collapse
Methods included from APIOperations::List
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
Amount (in cents) transferred.
292 293 294 |
# File 'lib/stripe/resources/treasury/received_debit.rb', line 292 def amount @amount end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
294 295 296 |
# File 'lib/stripe/resources/treasury/received_debit.rb', line 294 def created @created end |
#currency ⇒ Object (readonly)
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
296 297 298 |
# File 'lib/stripe/resources/treasury/received_debit.rb', line 296 def currency @currency end |
#description ⇒ Object (readonly)
An arbitrary string attached to the object. Often useful for displaying to users.
298 299 300 |
# File 'lib/stripe/resources/treasury/received_debit.rb', line 298 def description @description end |
#failure_code ⇒ Object (readonly)
Reason for the failure. A ReceivedDebit might fail because the FinancialAccount doesn’t have sufficient funds, is closed, or is frozen.
300 301 302 |
# File 'lib/stripe/resources/treasury/received_debit.rb', line 300 def failure_code @failure_code end |
#financial_account ⇒ Object (readonly)
The FinancialAccount that funds were pulled from.
302 303 304 |
# File 'lib/stripe/resources/treasury/received_debit.rb', line 302 def financial_account @financial_account end |
#hosted_regulatory_receipt_url ⇒ Object (readonly)
A [hosted transaction receipt](stripe.com/docs/treasury/moving-money/regulatory-receipts) URL that is provided when money movement is considered regulated under Stripe’s money transmission licenses.
304 305 306 |
# File 'lib/stripe/resources/treasury/received_debit.rb', line 304 def hosted_regulatory_receipt_url @hosted_regulatory_receipt_url end |
#id ⇒ Object (readonly)
Unique identifier for the object.
306 307 308 |
# File 'lib/stripe/resources/treasury/received_debit.rb', line 306 def id @id end |
#initiating_payment_method_details ⇒ Object (readonly)
Attribute for field initiating_payment_method_details
308 309 310 |
# File 'lib/stripe/resources/treasury/received_debit.rb', line 308 def initiating_payment_method_details @initiating_payment_method_details end |
#linked_flows ⇒ Object (readonly)
Attribute for field linked_flows
310 311 312 |
# File 'lib/stripe/resources/treasury/received_debit.rb', line 310 def linked_flows @linked_flows end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
312 313 314 |
# File 'lib/stripe/resources/treasury/received_debit.rb', line 312 def livemode @livemode end |
#network ⇒ Object (readonly)
The network used for the ReceivedDebit.
314 315 316 |
# File 'lib/stripe/resources/treasury/received_debit.rb', line 314 def network @network end |
#network_details ⇒ Object (readonly)
Details specific to the money movement rails.
316 317 318 |
# File 'lib/stripe/resources/treasury/received_debit.rb', line 316 def network_details @network_details end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
318 319 320 |
# File 'lib/stripe/resources/treasury/received_debit.rb', line 318 def object @object end |
#reversal_details ⇒ Object (readonly)
Details describing when a ReceivedDebit might be reversed.
320 321 322 |
# File 'lib/stripe/resources/treasury/received_debit.rb', line 320 def reversal_details @reversal_details end |
#status ⇒ Object (readonly)
Status of the ReceivedDebit. ReceivedDebits are created with a status of either ‘succeeded` (approved) or `failed` (declined). The failure reason can be found under the `failure_code`.
322 323 324 |
# File 'lib/stripe/resources/treasury/received_debit.rb', line 322 def status @status end |
#transaction ⇒ Object (readonly)
The Transaction associated with this object.
324 325 326 |
# File 'lib/stripe/resources/treasury/received_debit.rb', line 324 def transaction @transaction end |
Class Method Details
.field_remappings ⇒ Object
366 367 368 |
# File 'lib/stripe/resources/treasury/received_debit.rb', line 366 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
357 358 359 360 361 362 363 364 |
# File 'lib/stripe/resources/treasury/received_debit.rb', line 357 def self.inner_class_types @inner_class_types = { initiating_payment_method_details: InitiatingPaymentMethodDetails, linked_flows: LinkedFlows, network_details: NetworkDetails, reversal_details: ReversalDetails, } end |
.list(params = {}, opts = {}) ⇒ Object
Returns a list of ReceivedDebits.
327 328 329 330 331 332 333 334 |
# File 'lib/stripe/resources/treasury/received_debit.rb', line 327 def self.list(params = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/treasury/received_debits", params: params, opts: opts ) end |
.object_name ⇒ Object
11 12 13 |
# File 'lib/stripe/resources/treasury/received_debit.rb', line 11 def self.object_name "treasury.received_debit" end |
Instance Method Details
#test_helpers ⇒ Object
336 337 338 |
# File 'lib/stripe/resources/treasury/received_debit.rb', line 336 def test_helpers TestHelpers.new(self) end |