Class: Stripe::Treasury::ReceivedDebit::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/treasury/received_debit.rb

Defined Under Namespace

Classes: InitiatingPaymentMethodDetails, NetworkDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, currency: nil, description: nil, expand: nil, financial_account: nil, initiating_payment_method_details: nil, network: nil, network_details: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
# File 'lib/stripe/resources/treasury/received_debit.rb', line 271

def initialize(
  amount: nil,
  currency: nil,
  description: nil,
  expand: nil,
  financial_account: nil,
  initiating_payment_method_details: nil,
  network: nil,
  network_details: nil
)
  @amount = amount
  @currency = currency
  @description = description
  @expand = expand
  @financial_account = 
  @initiating_payment_method_details = initiating_payment_method_details
  @network = network
  @network_details = network_details
end

Instance Attribute Details

#amountObject

Amount (in cents) to be transferred.



255
256
257
# File 'lib/stripe/resources/treasury/received_debit.rb', line 255

def amount
  @amount
end

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



257
258
259
# File 'lib/stripe/resources/treasury/received_debit.rb', line 257

def currency
  @currency
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



259
260
261
# File 'lib/stripe/resources/treasury/received_debit.rb', line 259

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



261
262
263
# File 'lib/stripe/resources/treasury/received_debit.rb', line 261

def expand
  @expand
end

#financial_accountObject

The FinancialAccount to pull funds from.



263
264
265
# File 'lib/stripe/resources/treasury/received_debit.rb', line 263

def 
  @financial_account
end

#initiating_payment_method_detailsObject

Initiating payment method details for the object.



265
266
267
# File 'lib/stripe/resources/treasury/received_debit.rb', line 265

def initiating_payment_method_details
  @initiating_payment_method_details
end

#networkObject

Specifies the network rails to be used. If not set, will default to the PaymentMethod’s preferred network. See the [docs](stripe.com/docs/treasury/money-movement/timelines) to learn more about money movement timelines for each network type.



267
268
269
# File 'lib/stripe/resources/treasury/received_debit.rb', line 267

def network
  @network
end

#network_detailsObject

Details about the network used for the ReceivedDebit.



269
270
271
# File 'lib/stripe/resources/treasury/received_debit.rb', line 269

def network_details
  @network_details
end