Class: Stripe::Treasury::ReceivedDebit::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Treasury::ReceivedDebit::ListParams
- Defined in:
- lib/stripe/resources/treasury/received_debit.rb
Instance Attribute Summary collapse
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#financial_account ⇒ Object
The FinancialAccount that funds were pulled from.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#starting_after ⇒ Object
A cursor for use in pagination.
-
#status ⇒ Object
Only return ReceivedDebits that have the given status: ‘succeeded` or `failed`.
Instance Method Summary collapse
-
#initialize(ending_before: nil, expand: nil, financial_account: nil, limit: nil, starting_after: nil, status: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(ending_before: nil, expand: nil, financial_account: nil, limit: nil, starting_after: nil, status: nil) ⇒ ListParams
Returns a new instance of ListParams.
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/stripe/resources/treasury/received_debit.rb', line 191 def initialize( ending_before: nil, expand: nil, financial_account: nil, limit: nil, starting_after: nil, status: nil ) @ending_before = ending_before @expand = @financial_account = financial_account @limit = limit @starting_after = starting_after @status = status end |
Instance Attribute Details
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
179 180 181 |
# File 'lib/stripe/resources/treasury/received_debit.rb', line 179 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
181 182 183 |
# File 'lib/stripe/resources/treasury/received_debit.rb', line 181 def @expand end |
#financial_account ⇒ Object
The FinancialAccount that funds were pulled from.
183 184 185 |
# File 'lib/stripe/resources/treasury/received_debit.rb', line 183 def financial_account @financial_account end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
185 186 187 |
# File 'lib/stripe/resources/treasury/received_debit.rb', line 185 def limit @limit end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
187 188 189 |
# File 'lib/stripe/resources/treasury/received_debit.rb', line 187 def starting_after @starting_after end |
#status ⇒ Object
Only return ReceivedDebits that have the given status: ‘succeeded` or `failed`.
189 190 191 |
# File 'lib/stripe/resources/treasury/received_debit.rb', line 189 def status @status end |