Class: Stripe::Treasury::Transaction::RetrieveParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Treasury::Transaction::RetrieveParams
- Defined in:
- lib/stripe/resources/treasury/transaction.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ RetrieveParams
constructor
A new instance of RetrieveParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ RetrieveParams
Returns a new instance of RetrieveParams.
181 182 183 |
# File 'lib/stripe/resources/treasury/transaction.rb', line 181 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
179 180 181 |
# File 'lib/stripe/resources/treasury/transaction.rb', line 179 def @expand end |