Class: Stripe::Treasury::TransactionEntry
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Treasury::TransactionEntry
- Extended by:
- APIOperations::List
- Defined in:
- lib/stripe/resources/treasury/transaction_entry.rb
Overview
TransactionEntries represent individual units of money movements within a single [Transaction](stripe.com/docs/api#transactions).
Defined Under Namespace
Classes: BalanceImpact, FlowDetails, ListParams
Constant Summary collapse
- OBJECT_NAME =
"treasury.transaction_entry"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#balance_impact ⇒ Object
readonly
Change to a FinancialAccount’s balance.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#currency ⇒ Object
readonly
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#effective_at ⇒ Object
readonly
When the TransactionEntry will impact the FinancialAccount’s balance.
-
#financial_account ⇒ Object
readonly
The FinancialAccount associated with this object.
-
#flow ⇒ Object
readonly
Token of the flow associated with the TransactionEntry.
-
#flow_details ⇒ Object
readonly
Details of the flow associated with the TransactionEntry.
-
#flow_type ⇒ Object
readonly
Type of the flow associated with the TransactionEntry.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#transaction ⇒ Object
readonly
The Transaction associated with this object.
-
#type ⇒ Object
readonly
The specific money movement that generated the TransactionEntry.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
-
.list(params = {}, opts = {}) ⇒ Object
Retrieves a list of TransactionEntry objects.
- .object_name ⇒ Object
- .resource_url ⇒ Object
Methods included from APIOperations::List
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#balance_impact ⇒ Object (readonly)
Change to a FinancialAccount’s balance
153 154 155 |
# File 'lib/stripe/resources/treasury/transaction_entry.rb', line 153 def balance_impact @balance_impact end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
155 156 157 |
# File 'lib/stripe/resources/treasury/transaction_entry.rb', line 155 def created @created end |
#currency ⇒ Object (readonly)
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
157 158 159 |
# File 'lib/stripe/resources/treasury/transaction_entry.rb', line 157 def currency @currency end |
#effective_at ⇒ Object (readonly)
When the TransactionEntry will impact the FinancialAccount’s balance.
159 160 161 |
# File 'lib/stripe/resources/treasury/transaction_entry.rb', line 159 def effective_at @effective_at end |
#financial_account ⇒ Object (readonly)
The FinancialAccount associated with this object.
161 162 163 |
# File 'lib/stripe/resources/treasury/transaction_entry.rb', line 161 def financial_account @financial_account end |
#flow ⇒ Object (readonly)
Token of the flow associated with the TransactionEntry.
163 164 165 |
# File 'lib/stripe/resources/treasury/transaction_entry.rb', line 163 def flow @flow end |
#flow_details ⇒ Object (readonly)
Details of the flow associated with the TransactionEntry.
165 166 167 |
# File 'lib/stripe/resources/treasury/transaction_entry.rb', line 165 def flow_details @flow_details end |
#flow_type ⇒ Object (readonly)
Type of the flow associated with the TransactionEntry.
167 168 169 |
# File 'lib/stripe/resources/treasury/transaction_entry.rb', line 167 def flow_type @flow_type end |
#id ⇒ Object (readonly)
Unique identifier for the object.
169 170 171 |
# File 'lib/stripe/resources/treasury/transaction_entry.rb', line 169 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
171 172 173 |
# File 'lib/stripe/resources/treasury/transaction_entry.rb', line 171 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
173 174 175 |
# File 'lib/stripe/resources/treasury/transaction_entry.rb', line 173 def object @object end |
#transaction ⇒ Object (readonly)
The Transaction associated with this object.
175 176 177 |
# File 'lib/stripe/resources/treasury/transaction_entry.rb', line 175 def transaction @transaction end |
#type ⇒ Object (readonly)
The specific money movement that generated the TransactionEntry.
177 178 179 |
# File 'lib/stripe/resources/treasury/transaction_entry.rb', line 177 def type @type end |
Class Method Details
.field_remappings ⇒ Object
197 198 199 |
# File 'lib/stripe/resources/treasury/transaction_entry.rb', line 197 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
193 194 195 |
# File 'lib/stripe/resources/treasury/transaction_entry.rb', line 193 def self.inner_class_types @inner_class_types = { balance_impact: BalanceImpact, flow_details: FlowDetails } end |
.list(params = {}, opts = {}) ⇒ Object
Retrieves a list of TransactionEntry objects.
180 181 182 183 184 185 186 187 |
# File 'lib/stripe/resources/treasury/transaction_entry.rb', line 180 def self.list(params = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/treasury/transaction_entries", params: params, opts: opts ) end |
.object_name ⇒ Object
11 12 13 |
# File 'lib/stripe/resources/treasury/transaction_entry.rb', line 11 def self.object_name "treasury.transaction_entry" end |
.resource_url ⇒ Object
189 190 191 |
# File 'lib/stripe/resources/treasury/transaction_entry.rb', line 189 def self.resource_url "/v1/treasury/transaction_entries" end |