Class: Stripe::Treasury::TransactionEntry::ListParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/treasury/transaction_entry.rb

Defined Under Namespace

Classes: Created, EffectiveAt

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(created: nil, effective_at: nil, ending_before: nil, expand: nil, financial_account: nil, limit: nil, order_by: nil, starting_after: nil, transaction: nil) ⇒ ListParams

Returns a new instance of ListParams.



130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
# File 'lib/stripe/resources/treasury/transaction_entry.rb', line 130

def initialize(
  created: nil,
  effective_at: nil,
  ending_before: nil,
  expand: nil,
  financial_account: nil,
  limit: nil,
  order_by: nil,
  starting_after: nil,
  transaction: nil
)
  @created = created
  @effective_at = effective_at
  @ending_before = ending_before
  @expand = expand
  @financial_account = 
  @limit = limit
  @order_by = order_by
  @starting_after = starting_after
  @transaction = transaction
end

Instance Attribute Details

#createdObject

Only return TransactionEntries that were created during the given date interval.



112
113
114
# File 'lib/stripe/resources/treasury/transaction_entry.rb', line 112

def created
  @created
end

#effective_atObject

Attribute for param field effective_at



114
115
116
# File 'lib/stripe/resources/treasury/transaction_entry.rb', line 114

def effective_at
  @effective_at
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



116
117
118
# File 'lib/stripe/resources/treasury/transaction_entry.rb', line 116

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



118
119
120
# File 'lib/stripe/resources/treasury/transaction_entry.rb', line 118

def expand
  @expand
end

#financial_accountObject

Returns objects associated with this FinancialAccount.



120
121
122
# File 'lib/stripe/resources/treasury/transaction_entry.rb', line 120

def 
  @financial_account
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



122
123
124
# File 'lib/stripe/resources/treasury/transaction_entry.rb', line 122

def limit
  @limit
end

#order_byObject

The results are in reverse chronological order by ‘created` or `effective_at`. The default is `created`.



124
125
126
# File 'lib/stripe/resources/treasury/transaction_entry.rb', line 124

def order_by
  @order_by
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



126
127
128
# File 'lib/stripe/resources/treasury/transaction_entry.rb', line 126

def starting_after
  @starting_after
end

#transactionObject

Only return TransactionEntries associated with this Transaction.



128
129
130
# File 'lib/stripe/resources/treasury/transaction_entry.rb', line 128

def transaction
  @transaction
end