Class: Stripe::Treasury::TransactionEntryService::ListParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/treasury/transaction_entry_service.rb

Defined Under Namespace

Classes: Created, EffectiveAt

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(created: nil, effective_at: nil, ending_before: nil, expand: nil, financial_account: nil, limit: nil, order_by: nil, starting_after: nil, transaction: nil) ⇒ ListParams

Returns a new instance of ListParams.



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/stripe/services/treasury/transaction_entry_service.rb', line 62

def initialize(
  created: nil,
  effective_at: nil,
  ending_before: nil,
  expand: nil,
  financial_account: nil,
  limit: nil,
  order_by: nil,
  starting_after: nil,
  transaction: nil
)
  @created = created
  @effective_at = effective_at
  @ending_before = ending_before
  @expand = expand
  @financial_account = 
  @limit = limit
  @order_by = order_by
  @starting_after = starting_after
  @transaction = transaction
end

Instance Attribute Details

#createdObject

Only return TransactionEntries that were created during the given date interval.



44
45
46
# File 'lib/stripe/services/treasury/transaction_entry_service.rb', line 44

def created
  @created
end

#effective_atObject

Attribute for param field effective_at



46
47
48
# File 'lib/stripe/services/treasury/transaction_entry_service.rb', line 46

def effective_at
  @effective_at
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



48
49
50
# File 'lib/stripe/services/treasury/transaction_entry_service.rb', line 48

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



50
51
52
# File 'lib/stripe/services/treasury/transaction_entry_service.rb', line 50

def expand
  @expand
end

#financial_accountObject

Returns objects associated with this FinancialAccount.



52
53
54
# File 'lib/stripe/services/treasury/transaction_entry_service.rb', line 52

def 
  @financial_account
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



54
55
56
# File 'lib/stripe/services/treasury/transaction_entry_service.rb', line 54

def limit
  @limit
end

#order_byObject

The results are in reverse chronological order by ‘created` or `effective_at`. The default is `created`.



56
57
58
# File 'lib/stripe/services/treasury/transaction_entry_service.rb', line 56

def order_by
  @order_by
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



58
59
60
# File 'lib/stripe/services/treasury/transaction_entry_service.rb', line 58

def starting_after
  @starting_after
end

#transactionObject

Only return TransactionEntries associated with this Transaction.



60
61
62
# File 'lib/stripe/services/treasury/transaction_entry_service.rb', line 60

def transaction
  @transaction
end