Class: Stripe::Treasury::TransactionService::ListParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/treasury/transaction_service.rb

Defined Under Namespace

Classes: Created, StatusTransitions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(created: nil, ending_before: nil, expand: nil, financial_account: nil, limit: nil, order_by: nil, starting_after: nil, status: nil, status_transitions: nil) ⇒ ListParams

Returns a new instance of ListParams.



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/stripe/services/treasury/transaction_service.rb', line 84

def initialize(
  created: nil,
  ending_before: nil,
  expand: nil,
  financial_account: nil,
  limit: nil,
  order_by: nil,
  starting_after: nil,
  status: nil,
  status_transitions: nil
)
  @created = created
  @ending_before = ending_before
  @expand = expand
  @financial_account = 
  @limit = limit
  @order_by = order_by
  @starting_after = starting_after
  @status = status
  @status_transitions = status_transitions
end

Instance Attribute Details

#createdObject

Only return Transactions that were created during the given date interval.



58
59
60
# File 'lib/stripe/services/treasury/transaction_service.rb', line 58

def created
  @created
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



61
62
63
# File 'lib/stripe/services/treasury/transaction_service.rb', line 61

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



64
65
66
# File 'lib/stripe/services/treasury/transaction_service.rb', line 64

def expand
  @expand
end

#financial_accountObject

Returns objects associated with this FinancialAccount.



67
68
69
# File 'lib/stripe/services/treasury/transaction_service.rb', line 67

def 
  @financial_account
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



70
71
72
# File 'lib/stripe/services/treasury/transaction_service.rb', line 70

def limit
  @limit
end

#order_byObject

The results are in reverse chronological order by ‘created` or `posted_at`. The default is `created`.



73
74
75
# File 'lib/stripe/services/treasury/transaction_service.rb', line 73

def order_by
  @order_by
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



76
77
78
# File 'lib/stripe/services/treasury/transaction_service.rb', line 76

def starting_after
  @starting_after
end

#statusObject

Only return Transactions that have the given status: ‘open`, `posted`, or `void`.



79
80
81
# File 'lib/stripe/services/treasury/transaction_service.rb', line 79

def status
  @status
end

#status_transitionsObject

A filter for the ‘status_transitions.posted_at` timestamp. When using this filter, `status=posted` and `order_by=posted_at` must also be specified.



82
83
84
# File 'lib/stripe/services/treasury/transaction_service.rb', line 82

def status_transitions
  @status_transitions
end