Class: Stripe::UsageRecord
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::UsageRecord
- Defined in:
- lib/stripe/resources/usage_record.rb
Overview
Usage records allow you to report customer usage and metrics to Stripe for metered billing of subscription prices.
Related guide: [Metered billing](stripe.com/docs/billing/subscriptions/metered-billing)
This is our legacy usage-based billing API. See the [updated usage-based billing docs](docs.stripe.com/billing/subscriptions/usage-based).
Constant Summary collapse
- OBJECT_NAME =
"usage_record"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#quantity ⇒ Object
readonly
The usage quantity for the specified date.
-
#subscription_item ⇒ Object
readonly
The ID of the subscription item this usage record contains data for.
-
#timestamp ⇒ Object
readonly
The timestamp when this usage occurred.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#id ⇒ Object (readonly)
Unique identifier for the object.
18 19 20 |
# File 'lib/stripe/resources/usage_record.rb', line 18 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
21 22 23 |
# File 'lib/stripe/resources/usage_record.rb', line 21 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
24 25 26 |
# File 'lib/stripe/resources/usage_record.rb', line 24 def object @object end |
#quantity ⇒ Object (readonly)
The usage quantity for the specified date.
27 28 29 |
# File 'lib/stripe/resources/usage_record.rb', line 27 def quantity @quantity end |
#subscription_item ⇒ Object (readonly)
The ID of the subscription item this usage record contains data for.
30 31 32 |
# File 'lib/stripe/resources/usage_record.rb', line 30 def subscription_item @subscription_item end |
#timestamp ⇒ Object (readonly)
The timestamp when this usage occurred.
33 34 35 |
# File 'lib/stripe/resources/usage_record.rb', line 33 def @timestamp end |
Class Method Details
.object_name ⇒ Object
13 14 15 |
# File 'lib/stripe/resources/usage_record.rb', line 13 def self.object_name "usage_record" end |