Class: Stripe::UsageRecordSummary
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::UsageRecordSummary
- Defined in:
- lib/stripe/resources/usage_record_summary.rb
Overview
A usage record summary represents an aggregated view of how much usage was accrued for a subscription item within a subscription billing period.
Defined Under Namespace
Classes: Period
Constant Summary collapse
- OBJECT_NAME =
"usage_record_summary"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#invoice ⇒ Object
readonly
The invoice in which this usage period has been billed for.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#period ⇒ Object
readonly
Attribute for field period.
-
#subscription_item ⇒ Object
readonly
The ID of the subscription item this summary is describing.
-
#total_usage ⇒ Object
readonly
The total usage within this usage period.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#id ⇒ Object (readonly)
Unique identifier for the object.
16 17 18 |
# File 'lib/stripe/resources/usage_record_summary.rb', line 16 def id @id end |
#invoice ⇒ Object (readonly)
The invoice in which this usage period has been billed for.
18 19 20 |
# File 'lib/stripe/resources/usage_record_summary.rb', line 18 def invoice @invoice end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
20 21 22 |
# File 'lib/stripe/resources/usage_record_summary.rb', line 20 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
22 23 24 |
# File 'lib/stripe/resources/usage_record_summary.rb', line 22 def object @object end |
#period ⇒ Object (readonly)
Attribute for field period
24 25 26 |
# File 'lib/stripe/resources/usage_record_summary.rb', line 24 def period @period end |
#subscription_item ⇒ Object (readonly)
The ID of the subscription item this summary is describing.
26 27 28 |
# File 'lib/stripe/resources/usage_record_summary.rb', line 26 def subscription_item @subscription_item end |
#total_usage ⇒ Object (readonly)
The total usage within this usage period.
28 29 30 |
# File 'lib/stripe/resources/usage_record_summary.rb', line 28 def total_usage @total_usage end |
Class Method Details
.object_name ⇒ Object
8 9 10 |
# File 'lib/stripe/resources/usage_record_summary.rb', line 8 def self.object_name "usage_record_summary" end |