Class: Stripe::UsageRecordSummary::Period
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::UsageRecordSummary::Period
- Defined in:
- lib/stripe/resources/usage_record_summary.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#end ⇒ Object
readonly
The end date of this usage period.
-
#start ⇒ Object
readonly
The start date of this usage period.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#end ⇒ Object (readonly)
The end date of this usage period. All usage up to and including this point in time is included.
14 15 16 |
# File 'lib/stripe/resources/usage_record_summary.rb', line 14 def end @end end |
#start ⇒ Object (readonly)
The start date of this usage period. All usage after this point in time is included.
16 17 18 |
# File 'lib/stripe/resources/usage_record_summary.rb', line 16 def start @start end |