Class: Stripe::V2::Billing::BillSettingCreateParams::Calculation::Tax

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/billing/bill_setting_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(type: nil) ⇒ Tax

Returns a new instance of Tax.



13
14
15
# File 'lib/stripe/params/v2/billing/bill_setting_create_params.rb', line 13

def initialize(type: nil)
  @type = type
end

Instance Attribute Details

#typeObject

Determines if tax will be calculated automatically based on a PTC or manually based on rules defined by the merchant. Defaults to “manual”.



11
12
13
# File 'lib/stripe/params/v2/billing/bill_setting_create_params.rb', line 11

def type
  @type
end