Class: Stripe::V2::Billing::BillSettingCreateParams::Invoice
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::BillSettingCreateParams::Invoice
- Defined in:
- lib/stripe/params/v2/billing/bill_setting_create_params.rb
Defined Under Namespace
Classes: TimeUntilDue
Instance Attribute Summary collapse
-
#time_until_due ⇒ Object
The amount of time until the invoice will be overdue for payment.
Instance Method Summary collapse
-
#initialize(time_until_due: nil) ⇒ Invoice
constructor
A new instance of Invoice.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(time_until_due: nil) ⇒ Invoice
Returns a new instance of Invoice.
41 42 43 |
# File 'lib/stripe/params/v2/billing/bill_setting_create_params.rb', line 41 def initialize(time_until_due: nil) @time_until_due = time_until_due end |
Instance Attribute Details
#time_until_due ⇒ Object
The amount of time until the invoice will be overdue for payment.
39 40 41 |
# File 'lib/stripe/params/v2/billing/bill_setting_create_params.rb', line 39 def time_until_due @time_until_due end |