Class: Stripe::V2::Billing::BillSettingService::CreateParams::Calculation::Tax

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/billing/bill_setting_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(type: nil) ⇒ Tax

Returns a new instance of Tax.



34
35
36
# File 'lib/stripe/services/v2/billing/bill_setting_service.rb', line 34

def initialize(type: nil)
  @type = type
end

Instance Attribute Details

#typeObject

Determines if tax will be calculated automatically based on a PTC or manually based on rules defined by the merchant. Defaults to “manual”.



32
33
34
# File 'lib/stripe/services/v2/billing/bill_setting_service.rb', line 32

def type
  @type
end