Class: Stripe::V2::Billing::BillSettingService::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::BillSettingService::ListParams
- Defined in:
- lib/stripe/services/v2/billing/bill_setting_service.rb
Instance Attribute Summary collapse
-
#limit ⇒ Object
Optionally set the maximum number of results per page.
-
#lookup_keys ⇒ Object
Only return the settings with these lookup_keys, if any exist.
Instance Method Summary collapse
-
#initialize(limit: nil, lookup_keys: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(limit: nil, lookup_keys: nil) ⇒ ListParams
Returns a new instance of ListParams.
22 23 24 25 |
# File 'lib/stripe/services/v2/billing/bill_setting_service.rb', line 22 def initialize(limit: nil, lookup_keys: nil) @limit = limit @lookup_keys = lookup_keys end |
Instance Attribute Details
#limit ⇒ Object
Optionally set the maximum number of results per page. Defaults to 20.
17 18 19 |
# File 'lib/stripe/services/v2/billing/bill_setting_service.rb', line 17 def limit @limit end |
#lookup_keys ⇒ Object
Only return the settings with these lookup_keys, if any exist. You can specify up to 10 lookup_keys.
20 21 22 |
# File 'lib/stripe/services/v2/billing/bill_setting_service.rb', line 20 def lookup_keys @lookup_keys end |