Class: Stripe::V2::Billing::BillSettingService::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/billing/bill_setting_service.rb

Defined Under Namespace

Classes: Calculation, Invoice

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(calculation: nil, display_name: nil, invoice: nil, invoice_rendering_template: nil, live_version: nil, lookup_key: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/stripe/services/v2/billing/bill_setting_service.rb', line 151

def initialize(
  calculation: nil,
  display_name: nil,
  invoice: nil,
  invoice_rendering_template: nil,
  live_version: nil,
  lookup_key: nil
)
  @calculation = calculation
  @display_name = display_name
  @invoice = invoice
  @invoice_rendering_template = invoice_rendering_template
  @live_version = live_version
  @lookup_key = lookup_key
end

Instance Attribute Details

#calculationObject

Settings related to calculating a bill.



135
136
137
# File 'lib/stripe/services/v2/billing/bill_setting_service.rb', line 135

def calculation
  @calculation
end

#display_nameObject

An optional customer-facing display name for the BillSetting object. To remove the display name, set it to an empty string in the request. Maximum length of 250 characters.



139
140
141
# File 'lib/stripe/services/v2/billing/bill_setting_service.rb', line 139

def display_name
  @display_name
end

#invoiceObject

Settings related to invoice behavior.



141
142
143
# File 'lib/stripe/services/v2/billing/bill_setting_service.rb', line 141

def invoice
  @invoice
end

#invoice_rendering_templateObject

The ID of the invoice rendering template to be used when generating invoices.



143
144
145
# File 'lib/stripe/services/v2/billing/bill_setting_service.rb', line 143

def invoice_rendering_template
  @invoice_rendering_template
end

#live_versionObject

Optionally change the live version of the BillSetting. Providing ‘live_version = “latest”` will set the BillSetting’ ‘live_version` to its latest version.



146
147
148
# File 'lib/stripe/services/v2/billing/bill_setting_service.rb', line 146

def live_version
  @live_version
end

#lookup_keyObject

A lookup key used to retrieve settings dynamically from a static string. This may be up to 200 characters.



149
150
151
# File 'lib/stripe/services/v2/billing/bill_setting_service.rb', line 149

def lookup_key
  @lookup_key
end