Class: Stripe::V2::Billing::BillSettingService::UpdateParams::Invoice
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::BillSettingService::UpdateParams::Invoice
- Defined in:
- lib/stripe/services/v2/billing/bill_setting_service.rb
Defined Under Namespace
Classes: TimeUntilDue
Instance Attribute Summary collapse
-
#time_until_due ⇒ Object
The amount of time until the invoice will be overdue for payment.
Instance Method Summary collapse
-
#initialize(time_until_due: nil) ⇒ Invoice
constructor
A new instance of Invoice.
Methods inherited from RequestParams
Constructor Details
#initialize(time_until_due: nil) ⇒ Invoice
Returns a new instance of Invoice.
130 131 132 |
# File 'lib/stripe/services/v2/billing/bill_setting_service.rb', line 130 def initialize(time_until_due: nil) @time_until_due = time_until_due end |
Instance Attribute Details
#time_until_due ⇒ Object
The amount of time until the invoice will be overdue for payment.
128 129 130 |
# File 'lib/stripe/services/v2/billing/bill_setting_service.rb', line 128 def time_until_due @time_until_due end |