Class: Stripe::V2::Billing::Cadence::BillingCycle::Week

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/billing/cadence.rb

Defined Under Namespace

Classes: Time

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#day_of_weekObject (readonly)

The day of the week to bill the type=week billing cycle on. Numbered from 1-7 for Monday to Sunday respectively, based on the ISO-8601 week day numbering.



111
112
113
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 111

def day_of_week
  @day_of_week
end

#timeObject (readonly)

The time at which the billing cycle ends.



113
114
115
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 113

def time
  @time
end

Class Method Details

.field_remappingsObject



119
120
121
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 119

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



115
116
117
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 115

def self.inner_class_types
  @inner_class_types = { time: Time }
end