Class: Stripe::V2::Billing::Cadence::BillingCycle::Year

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/billing/cadence.rb

Defined Under Namespace

Classes: Time

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#day_of_monthObject (readonly)

The day to anchor the billing on for a type=“month” billing cycle from 1-31. If this number is greater than the number of days in the month being billed, this will anchor to the last day of the month.



148
149
150
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 148

def day_of_month
  @day_of_month
end

#month_of_yearObject (readonly)

The month to bill on from 1-12. If not provided, this will default to the month the cadence was created.



150
151
152
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 150

def month_of_year
  @month_of_year
end

#timeObject (readonly)

The time at which the billing cycle ends.



152
153
154
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 152

def time
  @time
end

Class Method Details

.field_remappingsObject



158
159
160
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 158

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



154
155
156
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 154

def self.inner_class_types
  @inner_class_types = { time: Time }
end