Class: Stripe::V2::Billing::Cadence::Payer
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::Cadence::Payer
- Defined in:
- lib/stripe/resources/v2/billing/cadence.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#billing_profile ⇒ Object
readonly
The ID of the Billing Profile object which determines how a bill will be paid.
-
#customer ⇒ Object
readonly
The ID of the Customer object.
-
#type ⇒ Object
readonly
A string identifying the type of the payer.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#billing_profile ⇒ Object (readonly)
The ID of the Billing Profile object which determines how a bill will be paid.
129 130 131 |
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 129 def billing_profile @billing_profile end |
#customer ⇒ Object (readonly)
The ID of the Customer object.
131 132 133 |
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 131 def customer @customer end |
#type ⇒ Object (readonly)
A string identifying the type of the payer. Currently the only supported value is ‘customer`.
133 134 135 |
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 133 def type @type end |