Class: Stripe::V2::Billing::Cadence::SettingsData::Bill
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::Cadence::SettingsData::Bill
- Defined in:
- lib/stripe/resources/v2/billing/cadence.rb
Defined Under Namespace
Classes: Calculation, Invoice
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#calculation ⇒ Object
readonly
Settings related to calculating a bill.
-
#invoice ⇒ Object
readonly
Settings related to invoice behavior.
-
#invoice_rendering_template ⇒ Object
readonly
The ID of the invoice rendering template to be used when generating invoices.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#calculation ⇒ Object (readonly)
Settings related to calculating a bill.
300 301 302 |
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 300 def calculation @calculation end |
#invoice ⇒ Object (readonly)
Settings related to invoice behavior.
302 303 304 |
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 302 def invoice @invoice end |
#invoice_rendering_template ⇒ Object (readonly)
The ID of the invoice rendering template to be used when generating invoices.
304 305 306 |
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 304 def invoice_rendering_template @invoice_rendering_template end |
Class Method Details
.field_remappings ⇒ Object
310 311 312 |
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 310 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
306 307 308 |
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 306 def self.inner_class_types @inner_class_types = { calculation: Calculation, invoice: Invoice } end |