Class: Stripe::V2::Billing::Cadence::SettingsData::Collection::EmailDelivery::PaymentDue
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::Cadence::SettingsData::Collection::EmailDelivery::PaymentDue
- Defined in:
- lib/stripe/resources/v2/billing/cadence.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#enabled ⇒ Object
readonly
If true an email for the invoice would be generated and sent out.
-
#include_payment_link ⇒ Object
readonly
If true the payment link to hosted invoice page would be included in email and PDF of the invoice.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#enabled ⇒ Object (readonly)
If true an email for the invoice would be generated and sent out.
372 373 374 |
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 372 def enabled @enabled end |
#include_payment_link ⇒ Object (readonly)
If true the payment link to hosted invoice page would be included in email and PDF of the invoice.
374 375 376 |
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 374 def include_payment_link @include_payment_link end |
Class Method Details
.field_remappings ⇒ Object
380 381 382 |
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 380 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
376 377 378 |
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 376 def self.inner_class_types @inner_class_types = {} end |