Class: Stripe::V2::Billing::Cadence::SettingsData::Collection::PaymentMethodOptions

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/billing/cadence.rb

Defined Under Namespace

Classes: AcssDebit, Bancontact, Card, CustomerBalance, UsBankAccount

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#acss_debitObject (readonly)

This sub-hash contains details about the Canadian pre-authorized debit payment method options.



567
568
569
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 567

def acss_debit
  @acss_debit
end

#bancontactObject (readonly)

This sub-hash contains details about the Bancontact payment method.



569
570
571
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 569

def bancontact
  @bancontact
end

#cardObject (readonly)

This sub-hash contains details about the Card payment method options.



571
572
573
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 571

def card
  @card
end

#customer_balanceObject (readonly)

This sub-hash contains details about the Bank transfer payment method options.



573
574
575
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 573

def customer_balance
  @customer_balance
end

#konbiniObject (readonly)

This sub-hash contains details about the Konbini payment method options.



575
576
577
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 575

def konbini
  @konbini
end

#sepa_debitObject (readonly)

This sub-hash contains details about the SEPA Direct Debit payment method options.



577
578
579
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 577

def sepa_debit
  @sepa_debit
end

#us_bank_accountObject (readonly)

This sub-hash contains details about the ACH direct debit payment method options.



579
580
581
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 579

def 
  @us_bank_account
end

Class Method Details

.field_encodingsObject



595
596
597
598
599
600
601
602
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 595

def self.field_encodings
  @field_encodings = {
    card: {
      kind: :object,
      fields: { mandate_options: { kind: :object, fields: { amount: :int64_string } } },
    },
  }
end

.field_remappingsObject



591
592
593
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 591

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



581
582
583
584
585
586
587
588
589
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 581

def self.inner_class_types
  @inner_class_types = {
    acss_debit: AcssDebit,
    bancontact: Bancontact,
    card: Card,
    customer_balance: CustomerBalance,
    us_bank_account: UsBankAccount,
  }
end