Class: Stripe::V2::Billing::Cadence::SettingsData::Collection::PaymentMethodOptions::Card::MandateOptions
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::Cadence::SettingsData::Collection::PaymentMethodOptions::Card::MandateOptions
- Defined in:
- lib/stripe/resources/v2/billing/cadence.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
Amount to be charged for future payments.
-
#amount_type ⇒ Object
readonly
The AmountType for the mandate.
-
#description ⇒ Object
readonly
A description of the mandate that is meant to be displayed to the customer.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
Amount to be charged for future payments.
387 388 389 |
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 387 def amount @amount end |
#amount_type ⇒ Object (readonly)
The AmountType for the mandate. One of ‘fixed` or `maximum`.
389 390 391 |
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 389 def amount_type @amount_type end |
#description ⇒ Object (readonly)
A description of the mandate that is meant to be displayed to the customer.
391 392 393 |
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 391 def description @description end |
Class Method Details
.field_encodings ⇒ Object
401 402 403 |
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 401 def self.field_encodings @field_encodings = { amount: :int64_string } end |
.field_remappings ⇒ Object
397 398 399 |
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 397 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
393 394 395 |
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 393 def self.inner_class_types @inner_class_types = {} end |