Class: Stripe::V2::Billing::CadenceCreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/v2/billing/cadence_create_params.rb

Defined Under Namespace

Classes: BillingCycle, Payer, Settings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(billing_cycle: nil, lookup_key: nil, metadata: nil, payer: nil, settings: nil) ⇒ CadenceCreateParams

Returns a new instance of CadenceCreateParams.



237
238
239
240
241
242
243
244
245
246
247
248
249
# File 'lib/stripe/params/v2/billing/cadence_create_params.rb', line 237

def initialize(
  billing_cycle: nil,
  lookup_key: nil,
  metadata: nil,
  payer: nil,
  settings: nil
)
  @billing_cycle = billing_cycle
  @lookup_key = lookup_key
  @metadata = 
  @payer = payer
  @settings = settings
end

Instance Attribute Details

#billing_cycleObject

The billing cycle is the object that defines future billing cycle dates.



227
228
229
# File 'lib/stripe/params/v2/billing/cadence_create_params.rb', line 227

def billing_cycle
  @billing_cycle
end

#lookup_keyObject

A lookup key used to retrieve cadences dynamically from a static string. Maximum length of 200 characters.



229
230
231
# File 'lib/stripe/params/v2/billing/cadence_create_params.rb', line 229

def lookup_key
  @lookup_key
end

#metadataObject

Set of [key-value pairs](/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



231
232
233
# File 'lib/stripe/params/v2/billing/cadence_create_params.rb', line 231

def 
  @metadata
end

#payerObject

The payer determines the entity financially responsible for the bill.



233
234
235
# File 'lib/stripe/params/v2/billing/cadence_create_params.rb', line 233

def payer
  @payer
end

#settingsObject

The settings associated with the cadence.



235
236
237
# File 'lib/stripe/params/v2/billing/cadence_create_params.rb', line 235

def settings
  @settings
end