Class: Stripe::V2::Billing::CadenceCreateParams::BillingCycle::Week

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/billing/cadence_create_params.rb

Defined Under Namespace

Classes: Time

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(day_of_week: nil, time: nil) ⇒ Week

Returns a new instance of Week.



108
109
110
111
# File 'lib/stripe/params/v2/billing/cadence_create_params.rb', line 108

def initialize(day_of_week: nil, time: nil)
  @day_of_week = day_of_week
  @time = time
end

Instance Attribute Details

#day_of_weekObject

The day of the week to bill the type=week billing cycle on. Numbered from 1-7 for Monday to Sunday respectively, based on the ISO-8601 week day numbering. If not provided, this will default to the day the cadence was created.



102
103
104
# File 'lib/stripe/params/v2/billing/cadence_create_params.rb', line 102

def day_of_week
  @day_of_week
end

#timeObject

The time at which the billing cycle ends. This field is optional, and if not provided, it will default to the time at which the cadence was created in UTC timezone.



106
107
108
# File 'lib/stripe/params/v2/billing/cadence_create_params.rb', line 106

def time
  @time
end