Class: Stripe::V2::Billing::CadenceCreateParams::Settings::Bill

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/billing/cadence_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(id: nil, version: nil) ⇒ Bill

Returns a new instance of Bill.



194
195
196
197
# File 'lib/stripe/params/v2/billing/cadence_create_params.rb', line 194

def initialize(id: nil, version: nil)
  @id = id
  @version = version
end

Instance Attribute Details

#idObject

The ID of the referenced settings object.



189
190
191
# File 'lib/stripe/params/v2/billing/cadence_create_params.rb', line 189

def id
  @id
end

#versionObject

An optional field to specify the version of the Settings to use. If not provided, this will always default to the live version any time the settings are used.



192
193
194
# File 'lib/stripe/params/v2/billing/cadence_create_params.rb', line 192

def version
  @version
end