Class: Stripe::V2::Billing::CadenceCreateParams::Settings::Collection

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/billing/cadence_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(id: nil, version: nil) ⇒ Collection

Returns a new instance of Collection.



207
208
209
210
# File 'lib/stripe/params/v2/billing/cadence_create_params.rb', line 207

def initialize(id: nil, version: nil)
  @id = id
  @version = version
end

Instance Attribute Details

#idObject

The ID of the referenced settings object.



202
203
204
# File 'lib/stripe/params/v2/billing/cadence_create_params.rb', line 202

def id
  @id
end

#versionObject

An optional field to specify the version of the Settings to use. If not provided, this will always default to the live version any time the settings are used.



205
206
207
# File 'lib/stripe/params/v2/billing/cadence_create_params.rb', line 205

def version
  @version
end