Class: Stripe::V2::Billing::CadenceService::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/billing/cadence_service.rb

Defined Under Namespace

Classes: BillingCycle, Payer, Settings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_cycle: nil, include: nil, metadata: nil, payer: nil, settings: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



277
278
279
280
281
282
283
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 277

def initialize(billing_cycle: nil, include: nil, metadata: nil, payer: nil, settings: nil)
  @billing_cycle = billing_cycle
  @include = include
  @metadata = 
  @payer = payer
  @settings = settings
end

Instance Attribute Details

#billing_cycleObject

The billing cycle is the object that defines future billing cycle dates.



267
268
269
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 267

def billing_cycle
  @billing_cycle
end

#includeObject

Additional resource to include in the response.



269
270
271
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 269

def include
  @include
end

#metadataObject

Set of [key-value pairs](/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



271
272
273
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 271

def 
  @metadata
end

#payerObject

The payer determines the entity financially responsible for the bill.



273
274
275
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 273

def payer
  @payer
end

#settingsObject

The settings associated with the cadence.



275
276
277
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 275

def settings
  @settings
end