Class: Stripe::V2::Billing::CadenceService::CreateParams::BillingCycle::Month
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::CadenceService::CreateParams::BillingCycle::Month
- Defined in:
- lib/stripe/services/v2/billing/cadence_service.rb
Defined Under Namespace
Classes: Time
Instance Attribute Summary collapse
-
#day_of_month ⇒ Object
The day to anchor the billing on for a type=“month” billing cycle from 1-31.
-
#time ⇒ Object
The time at which the billing cycle ends.
Instance Method Summary collapse
-
#initialize(day_of_month: nil, time: nil) ⇒ Month
constructor
A new instance of Month.
Methods inherited from RequestParams
Constructor Details
#initialize(day_of_month: nil, time: nil) ⇒ Month
Returns a new instance of Month.
99 100 101 102 |
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 99 def initialize(day_of_month: nil, time: nil) @day_of_month = day_of_month @time = time end |
Instance Attribute Details
#day_of_month ⇒ Object
The day to anchor the billing on for a type=“month” billing cycle from 1-31. If this number is greater than the number of days in the month being billed, this will anchor to the last day of the month. If not provided, this will default to the day the cadence was created.
93 94 95 |
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 93 def day_of_month @day_of_month end |
#time ⇒ Object
The time at which the billing cycle ends. This field is optional, and if not provided, it will default to the time at which the cadence was created in UTC timezone.
97 98 99 |
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 97 def time @time end |