Class: Stripe::V2::Billing::CadenceService::CreateParams::Payer

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/billing/cadence_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_profile: nil, customer: nil, type: nil) ⇒ Payer

Returns a new instance of Payer.



219
220
221
222
223
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 219

def initialize(billing_profile: nil, customer: nil, type: nil)
  @billing_profile = billing_profile
  @customer = customer
  @type = type
end

Instance Attribute Details

#billing_profileObject

The ID of the Billing Profile object which determines how a bill will be paid. If provided, the created cadence will be associated with the provided Billing Profile. If not provided, a new Billing Profile will be created and associated with the cadence.



213
214
215
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 213

def billing_profile
  @billing_profile
end

#customerObject

The ID of the Customer object.



215
216
217
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 215

def customer
  @customer
end

#typeObject

A string identifying the type of the payer. Currently the only supported value is ‘customer`.



217
218
219
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 217

def type
  @type
end