Class: Stripe::V2::Billing::CadenceService::CreateParams::Settings

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/billing/cadence_service.rb

Defined Under Namespace

Classes: Bill, Collection

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bill: nil, collection: nil) ⇒ Settings

Returns a new instance of Settings.



261
262
263
264
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 261

def initialize(bill: nil, collection: nil)
  @bill = bill
  @collection = collection
end

Instance Attribute Details

#billObject

Settings that configure bill generation, which includes calculating totals, tax, and presenting invoices. If no setting is provided here, the settings from the customer referenced on the payer will be used. If no customer settings are present, the merchant default settings will be used.



255
256
257
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 255

def bill
  @bill
end

#collectionObject

Settings that configure and manage the behavior of collecting payments. If no setting is provided here, the settings from the customer referenced from the payer will be used if they exist. If no customer settings are present, the merchant default settings will be used.



259
260
261
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 259

def collection
  @collection
end