Class: Stripe::V2::Billing::CadenceService::CreateParams::Settings::Collection

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/billing/cadence_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(id: nil, version: nil) ⇒ Collection

Returns a new instance of Collection.



253
254
255
256
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 253

def initialize(id: nil, version: nil)
  @id = id
  @version = version
end

Instance Attribute Details

#idObject

The ID of the referenced settings object.



248
249
250
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 248

def id
  @id
end

#versionObject

An optional field to specify the version of the Settings to use. If not provided, this will always default to the live version any time the settings are used.



251
252
253
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 251

def version
  @version
end