Class: Stripe::V2::Billing::CadenceService::ListParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/billing/cadence_service.rb

Defined Under Namespace

Classes: Payer

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(include: nil, limit: nil, payer: nil, test_clock: nil) ⇒ ListParams

Returns a new instance of ListParams.



31
32
33
34
35
36
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 31

def initialize(include: nil, limit: nil, payer: nil, test_clock: nil)
  @include = include
  @limit = limit
  @payer = payer
  @test_clock = test_clock
end

Instance Attribute Details

#includeObject

Additional resource to include in the response.



21
22
23
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 21

def include
  @include
end

#limitObject

Optionally set the maximum number of results per page. Defaults to 20.



23
24
25
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 23

def limit
  @limit
end

#payerObject

If provided, only cadences that specifically reference the payer will be returned. Mutually exclusive with ‘test_clock`.



25
26
27
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 25

def payer
  @payer
end

#test_clockObject

If provided, only cadences that specifically reference the provided test clock ID (via the customer’s test clock) will be returned. Mutually exclusive with ‘payer`.



29
30
31
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 29

def test_clock
  @test_clock
end