Class: Stripe::V2::Billing::CadenceService::UpdateParams::Settings

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/billing/cadence_service.rb

Defined Under Namespace

Classes: Bill, Collection

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bill: nil, collection: nil) ⇒ Settings

Returns a new instance of Settings.



340
341
342
343
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 340

def initialize(bill: nil, collection: nil)
  @bill = bill
  @collection = collection
end

Instance Attribute Details

#billObject

Settings that configure bills generation, which includes calculating totals, tax, and presenting invoices. If null is provided, the current bill settings will be removed from the billing cadence.



336
337
338
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 336

def bill
  @bill
end

#collectionObject

Settings that configure and manage the behavior of collecting payments. If null is provided, the current collection settings will be removed from the billing cadence.



338
339
340
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 338

def collection
  @collection
end