Class: Stripe::V2::Billing::CadenceService::UpdateParams::Settings::Collection

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/billing/cadence_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(id: nil, version: nil) ⇒ Collection

Returns a new instance of Collection.



330
331
332
333
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 330

def initialize(id: nil, version: nil)
  @id = id
  @version = version
end

Instance Attribute Details

#idObject

The ID of the referenced settings object.



323
324
325
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 323

def id
  @id
end

#versionObject

An optional field to specify the version of Settings to use. If not provided, this will always default to the ‘live_version` specified on the setting, any time the settings are used. Using a specific version here will prevent the settings from updating, and is discouraged for cadences. To clear a pinned version, set the version to null.



328
329
330
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 328

def version
  @version
end