Class: Stripe::V2::Billing::CadenceUpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::CadenceUpdateParams
- Defined in:
- lib/stripe/params/v2/billing/cadence_update_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#lookup_key ⇒ Object
A lookup key used to retrieve cadences dynamically from a static string.
-
#metadata ⇒ Object
Set of [key-value pairs](/docs/api/metadata) that you can attach to an object.
-
#payer ⇒ Object
The payer determines the entity financially responsible for the bill.
-
#settings ⇒ Object
The settings associated with the cadence.
Instance Method Summary collapse
-
#initialize(lookup_key: nil, metadata: nil, payer: nil, settings: nil) ⇒ CadenceUpdateParams
constructor
A new instance of CadenceUpdateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(lookup_key: nil, metadata: nil, payer: nil, settings: nil) ⇒ CadenceUpdateParams
Returns a new instance of CadenceUpdateParams.
66 67 68 69 70 71 |
# File 'lib/stripe/params/v2/billing/cadence_update_params.rb', line 66 def initialize(lookup_key: nil, metadata: nil, payer: nil, settings: nil) @lookup_key = lookup_key @metadata = @payer = payer @settings = settings end |
Instance Attribute Details
#lookup_key ⇒ Object
A lookup key used to retrieve cadences dynamically from a static string. Maximum length of 200 characters.
58 59 60 |
# File 'lib/stripe/params/v2/billing/cadence_update_params.rb', line 58 def lookup_key @lookup_key end |
#metadata ⇒ Object
Set of [key-value pairs](/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
60 61 62 |
# File 'lib/stripe/params/v2/billing/cadence_update_params.rb', line 60 def @metadata end |
#payer ⇒ Object
The payer determines the entity financially responsible for the bill.
62 63 64 |
# File 'lib/stripe/params/v2/billing/cadence_update_params.rb', line 62 def payer @payer end |
#settings ⇒ Object
The settings associated with the cadence.
64 65 66 |
# File 'lib/stripe/params/v2/billing/cadence_update_params.rb', line 64 def settings @settings end |