Class: Stripe::V2::Billing::CadenceUpdateParams::Payer
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::CadenceUpdateParams::Payer
- Defined in:
- lib/stripe/params/v2/billing/cadence_update_params.rb
Instance Attribute Summary collapse
-
#billing_profile ⇒ Object
The ID of the Billing Profile object which determines how a bill will be paid.
Instance Method Summary collapse
-
#initialize(billing_profile: nil) ⇒ Payer
constructor
A new instance of Payer.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(billing_profile: nil) ⇒ Payer
Returns a new instance of Payer.
12 13 14 |
# File 'lib/stripe/params/v2/billing/cadence_update_params.rb', line 12 def initialize(billing_profile: nil) @billing_profile = billing_profile end |
Instance Attribute Details
#billing_profile ⇒ Object
The ID of the Billing Profile object which determines how a bill will be paid.
10 11 12 |
# File 'lib/stripe/params/v2/billing/cadence_update_params.rb', line 10 def billing_profile @billing_profile end |