Class: Stripe::V2::Billing::CadenceUpdateParams::Settings

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/billing/cadence_update_params.rb

Defined Under Namespace

Classes: Bill, Collection

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(bill: nil, collection: nil) ⇒ Settings

Returns a new instance of Settings.



52
53
54
55
# File 'lib/stripe/params/v2/billing/cadence_update_params.rb', line 52

def initialize(bill: nil, collection: nil)
  @bill = bill
  @collection = collection
end

Instance Attribute Details

#billObject

Settings that configure bills generation, which includes calculating totals, tax, and presenting invoices. If null is provided, the current bill settings will be removed from the billing cadence.



48
49
50
# File 'lib/stripe/params/v2/billing/cadence_update_params.rb', line 48

def bill
  @bill
end

#collectionObject

Settings that configure and manage the behavior of collecting payments. If null is provided, the current collection settings will be removed from the billing cadence.



50
51
52
# File 'lib/stripe/params/v2/billing/cadence_update_params.rb', line 50

def collection
  @collection
end