Class: Stripe::V2::Billing::CollectionSetting

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/billing/collection_setting.rb

Overview

Settings that configure and manage the behavior of collecting payments.

Defined Under Namespace

Classes: EmailDelivery, PaymentMethodOptions

Constant Summary collapse

OBJECT_NAME =
"v2.billing.collection_setting"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#collection_methodObject (readonly)

Either automatic, or send_invoice. When charging automatically, Stripe attempts to pay this bill at the end of the period using the payment method attached to the billing profile. When sending an invoice, Stripe emails your billing profile an invoice with payment instructions. Defaults to automatic.



273
274
275
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 273

def collection_method
  @collection_method
end

#createdObject (readonly)

Timestamp of when the object was created.



275
276
277
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 275

def created
  @created
end

#display_nameObject (readonly)

An optional field for adding a display name for the CollectionSetting object.



277
278
279
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 277

def display_name
  @display_name
end

#email_deliveryObject (readonly)

Email delivery settings.



279
280
281
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 279

def email_delivery
  @email_delivery
end

#idObject (readonly)

The ID of the CollectionSetting.



281
282
283
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 281

def id
  @id
end

#latest_versionObject (readonly)

The latest version of the current settings object. This is updated every time an attribute of the settings is updated.



284
285
286
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 284

def latest_version
  @latest_version
end

#live_versionObject (readonly)

The current live version of the settings object. This can be different from latest_version if settings are updated without setting live_version=‘latest’.



287
288
289
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 287

def live_version
  @live_version
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



289
290
291
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 289

def livemode
  @livemode
end

#lookup_keyObject (readonly)

A lookup key used to retrieve settings dynamically from a static string. This may be up to 200 characters.



292
293
294
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 292

def lookup_key
  @lookup_key
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



294
295
296
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 294

def object
  @object
end

#payment_method_configurationObject (readonly)

The ID of the PaymentMethodConfiguration object, which controls which payment methods are displayed to your customers.



296
297
298
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 296

def payment_method_configuration
  @payment_method_configuration
end

#payment_method_optionsObject (readonly)

Payment Method specific configuration stored on the object.



298
299
300
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 298

def payment_method_options
  @payment_method_options
end

Class Method Details

.field_encodingsObject



311
312
313
314
315
316
317
318
319
320
321
322
323
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 311

def self.field_encodings
  @field_encodings = {
    payment_method_options: {
      kind: :object,
      fields: {
        card: {
          kind: :object,
          fields: { mandate_options: { kind: :object, fields: { amount: :int64_string } } },
        },
      },
    },
  }
end

.field_remappingsObject



307
308
309
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 307

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



300
301
302
303
304
305
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 300

def self.inner_class_types
  @inner_class_types = {
    email_delivery: EmailDelivery,
    payment_method_options: PaymentMethodOptions,
  }
end

.object_nameObject



10
11
12
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 10

def self.object_name
  "v2.billing.collection_setting"
end