Class: Stripe::V2::Billing::CollectionSetting::PaymentMethodOptions::Card

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/billing/collection_setting.rb

Defined Under Namespace

Classes: MandateOptions

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#mandate_optionsObject (readonly)

Configuration options for setting up an eMandate for cards issued in India.



104
105
106
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 104

def mandate_options
  @mandate_options
end

#networkObject (readonly)

Selected network to process the payment on. Depends on the available networks of the card.



106
107
108
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 106

def network
  @network
end

#request_three_d_secureObject (readonly)

An advanced option 3D Secure. We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and other requirements. However, if you wish to request 3D Secure based on logic from your own fraud engine, provide this option. Read our guide on manually requesting 3D Secure for more information on how this configuration interacts with Radar and our SCA Engine.



111
112
113
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 111

def request_three_d_secure
  @request_three_d_secure
end

Class Method Details

.field_encodingsObject



121
122
123
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 121

def self.field_encodings
  @field_encodings = { mandate_options: { kind: :object, fields: { amount: :int64_string } } }
end

.field_remappingsObject



117
118
119
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 117

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



113
114
115
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 113

def self.inner_class_types
  @inner_class_types = { mandate_options: MandateOptions }
end