Class: Stripe::V2::Billing::CollectionSetting::PaymentMethodOptions::UsBankAccount::FinancialConnections

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/billing/collection_setting.rb

Defined Under Namespace

Classes: Filters

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#filtersObject (readonly)

Provide filters for the linked accounts that the customer can select for the payment method.



89
90
91
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 89

def filters
  @filters
end

#permissionsObject (readonly)

The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included.



91
92
93
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 91

def permissions
  @permissions
end

#prefetchObject (readonly)

List of data features that you would like to retrieve upon account creation.



93
94
95
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 93

def prefetch
  @prefetch
end