Class: Stripe::V2::Billing::CollectionSettingCreateParams::EmailDelivery::PaymentDue

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/billing/collection_setting_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(enabled: nil, include_payment_link: nil) ⇒ PaymentDue

Returns a new instance of PaymentDue.



15
16
17
18
# File 'lib/stripe/params/v2/billing/collection_setting_create_params.rb', line 15

def initialize(enabled: nil, include_payment_link: nil)
  @enabled = enabled
  @include_payment_link = include_payment_link
end

Instance Attribute Details

#enabledObject

If true an email for the invoice would be generated and sent out.



11
12
13
# File 'lib/stripe/params/v2/billing/collection_setting_create_params.rb', line 11

def enabled
  @enabled
end

If true the payment link to hosted invoice page would be included in email and PDF of the invoice.



13
14
15
# File 'lib/stripe/params/v2/billing/collection_setting_create_params.rb', line 13

def include_payment_link
  @include_payment_link
end