Class: Stripe::V2::Billing::CollectionSettingCreateParams::PaymentMethodOptions::CustomerBalance::BankTransfer
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::CollectionSettingCreateParams::PaymentMethodOptions::CustomerBalance::BankTransfer
- Defined in:
- lib/stripe/params/v2/billing/collection_setting_create_params.rb
Defined Under Namespace
Classes: EuBankTransfer
Instance Attribute Summary collapse
-
#eu_bank_transfer ⇒ Object
Configuration for ‘eu_bank_transfer` funding type.
-
#type ⇒ Object
The bank transfer type that can be used for funding.
Instance Method Summary collapse
-
#initialize(eu_bank_transfer: nil, type: nil) ⇒ BankTransfer
constructor
A new instance of BankTransfer.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(eu_bank_transfer: nil, type: nil) ⇒ BankTransfer
Returns a new instance of BankTransfer.
113 114 115 116 |
# File 'lib/stripe/params/v2/billing/collection_setting_create_params.rb', line 113 def initialize(eu_bank_transfer: nil, type: nil) @eu_bank_transfer = eu_bank_transfer @type = type end |
Instance Attribute Details
#eu_bank_transfer ⇒ Object
Configuration for ‘eu_bank_transfer` funding type. Required if `type` is `eu_bank_transfer`.
109 110 111 |
# File 'lib/stripe/params/v2/billing/collection_setting_create_params.rb', line 109 def eu_bank_transfer @eu_bank_transfer end |
#type ⇒ Object
The bank transfer type that can be used for funding.
111 112 113 |
# File 'lib/stripe/params/v2/billing/collection_setting_create_params.rb', line 111 def type @type end |