Class: Stripe::V2::Billing::CollectionSettingCreateParams::PaymentMethodOptions::CustomerBalance::BankTransfer::EuBankTransfer
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::CollectionSettingCreateParams::PaymentMethodOptions::CustomerBalance::BankTransfer::EuBankTransfer
- Defined in:
- lib/stripe/params/v2/billing/collection_setting_create_params.rb
Instance Attribute Summary collapse
-
#country ⇒ Object
The desired country code of the bank account information.
Instance Method Summary collapse
-
#initialize(country: nil) ⇒ EuBankTransfer
constructor
A new instance of EuBankTransfer.
Methods inherited from RequestParams
Constructor Details
#initialize(country: nil) ⇒ EuBankTransfer
Returns a new instance of EuBankTransfer.
96 97 98 |
# File 'lib/stripe/params/v2/billing/collection_setting_create_params.rb', line 96 def initialize(country: nil) @country = country end |
Instance Attribute Details
#country ⇒ Object
The desired country code of the bank account information.
94 95 96 |
# File 'lib/stripe/params/v2/billing/collection_setting_create_params.rb', line 94 def country @country end |