Class: Stripe::V2::Billing::CollectionSettingListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::CollectionSettingListParams
- Defined in:
- lib/stripe/params/v2/billing/collection_setting_list_params.rb
Instance Attribute Summary collapse
-
#limit ⇒ Object
Optionally set the maximum number of results per page.
-
#lookup_keys ⇒ Object
Only return the settings with these lookup_keys, if any exist.
Instance Method Summary collapse
-
#initialize(limit: nil, lookup_keys: nil) ⇒ CollectionSettingListParams
constructor
A new instance of CollectionSettingListParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(limit: nil, lookup_keys: nil) ⇒ CollectionSettingListParams
Returns a new instance of CollectionSettingListParams.
14 15 16 17 |
# File 'lib/stripe/params/v2/billing/collection_setting_list_params.rb', line 14 def initialize(limit: nil, lookup_keys: nil) @limit = limit @lookup_keys = lookup_keys end |
Instance Attribute Details
#limit ⇒ Object
Optionally set the maximum number of results per page. Defaults to 20.
9 10 11 |
# File 'lib/stripe/params/v2/billing/collection_setting_list_params.rb', line 9 def limit @limit end |
#lookup_keys ⇒ Object
Only return the settings with these lookup_keys, if any exist. You can specify up to 10 lookup_keys.
12 13 14 |
# File 'lib/stripe/params/v2/billing/collection_setting_list_params.rb', line 12 def lookup_keys @lookup_keys end |