Class: Stripe::V2::Billing::CollectionSettingService::CreateParams::PaymentMethodOptions::CustomerBalance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/billing/collection_setting_service.rb

Defined Under Namespace

Classes: BankTransfer

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bank_transfer: nil, funding_type: nil) ⇒ CustomerBalance

Returns a new instance of CustomerBalance.



136
137
138
139
# File 'lib/stripe/services/v2/billing/collection_setting_service.rb', line 136

def initialize(bank_transfer: nil, funding_type: nil)
  @bank_transfer = bank_transfer
  @funding_type = funding_type
end

Instance Attribute Details

#bank_transferObject

Configuration for the bank transfer funding type, if the ‘funding_type` is set to `bank_transfer`.



132
133
134
# File 'lib/stripe/services/v2/billing/collection_setting_service.rb', line 132

def bank_transfer
  @bank_transfer
end

#funding_typeObject

The funding method type to be used when there are not enough funds in the customer balance. Currently the only supported value is ‘bank_transfer`.



134
135
136
# File 'lib/stripe/services/v2/billing/collection_setting_service.rb', line 134

def funding_type
  @funding_type
end