Class: Stripe::V2::Billing::CollectionSettingService::CreateParams::PaymentMethodOptions::CustomerBalance::BankTransfer::EuBankTransfer
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::CollectionSettingService::CreateParams::PaymentMethodOptions::CustomerBalance::BankTransfer::EuBankTransfer
- Defined in:
- lib/stripe/services/v2/billing/collection_setting_service.rb
Instance Attribute Summary collapse
-
#country ⇒ Object
The desired country code of the bank account information.
Instance Method Summary collapse
-
#initialize(country: nil) ⇒ EuBankTransfer
constructor
A new instance of EuBankTransfer.
Methods inherited from RequestParams
Constructor Details
#initialize(country: nil) ⇒ EuBankTransfer
Returns a new instance of EuBankTransfer.
117 118 119 |
# File 'lib/stripe/services/v2/billing/collection_setting_service.rb', line 117 def initialize(country: nil) @country = country end |
Instance Attribute Details
#country ⇒ Object
The desired country code of the bank account information.
115 116 117 |
# File 'lib/stripe/services/v2/billing/collection_setting_service.rb', line 115 def country @country end |