Class: Stripe::V2::Billing::CollectionSettingService::UpdateParams::PaymentMethodOptions::Card
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::CollectionSettingService::UpdateParams::PaymentMethodOptions::Card
- Defined in:
- lib/stripe/services/v2/billing/collection_setting_service.rb
Defined Under Namespace
Classes: MandateOptions
Instance Attribute Summary collapse
-
#mandate_options ⇒ Object
Configuration options for setting up an eMandate for cards issued in India.
-
#network ⇒ Object
Selected network to process the payment on.
-
#request_three_d_secure ⇒ Object
An advanced option 3D Secure.
Instance Method Summary collapse
-
#initialize(mandate_options: nil, network: nil, request_three_d_secure: nil) ⇒ Card
constructor
A new instance of Card.
Methods inherited from RequestParams
Constructor Details
#initialize(mandate_options: nil, network: nil, request_three_d_secure: nil) ⇒ Card
Returns a new instance of Card.
324 325 326 327 328 |
# File 'lib/stripe/services/v2/billing/collection_setting_service.rb', line 324 def initialize(mandate_options: nil, network: nil, request_three_d_secure: nil) @mandate_options = @network = network @request_three_d_secure = request_three_d_secure end |
Instance Attribute Details
#mandate_options ⇒ Object
Configuration options for setting up an eMandate for cards issued in India.
315 316 317 |
# File 'lib/stripe/services/v2/billing/collection_setting_service.rb', line 315 def @mandate_options end |
#network ⇒ Object
Selected network to process the payment on. Depends on the available networks of the card.
317 318 319 |
# File 'lib/stripe/services/v2/billing/collection_setting_service.rb', line 317 def network @network end |
#request_three_d_secure ⇒ Object
An advanced option 3D Secure. We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and [other requirements](docs.corp.stripe.com/strong-customer-authentication). However, if you wish to request 3D Secure based on logic from your own fraud engine, provide this option. Read our guide on [manually requesting 3D Secure](docs.corp.stripe.com/payments/3d-secure/authentication-flow#manual-three-ds) for more information on how this configuration interacts with Radar and our SCA Engine.
322 323 324 |
# File 'lib/stripe/services/v2/billing/collection_setting_service.rb', line 322 def request_three_d_secure @request_three_d_secure end |