Class: Stripe::V2::Billing::CollectionSettingService::UpdateParams::PaymentMethodOptions::Card::MandateOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::CollectionSettingService::UpdateParams::PaymentMethodOptions::Card::MandateOptions
- Defined in:
- lib/stripe/services/v2/billing/collection_setting_service.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount to be charged for future payments.
-
#amount_type ⇒ Object
The AmountType for the mandate.
-
#description ⇒ Object
A description of the mandate that is meant to be displayed to the customer.
Instance Method Summary collapse
-
#initialize(amount: nil, amount_type: nil, description: nil) ⇒ MandateOptions
constructor
A new instance of MandateOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, amount_type: nil, description: nil) ⇒ MandateOptions
Returns a new instance of MandateOptions.
308 309 310 311 312 |
# File 'lib/stripe/services/v2/billing/collection_setting_service.rb', line 308 def initialize(amount: nil, amount_type: nil, description: nil) @amount = amount @amount_type = amount_type @description = description end |
Instance Attribute Details
#amount ⇒ Object
Amount to be charged for future payments.
302 303 304 |
# File 'lib/stripe/services/v2/billing/collection_setting_service.rb', line 302 def amount @amount end |
#amount_type ⇒ Object
The AmountType for the mandate. One of ‘fixed` or `maximum`.
304 305 306 |
# File 'lib/stripe/services/v2/billing/collection_setting_service.rb', line 304 def amount_type @amount_type end |
#description ⇒ Object
A description of the mandate that is meant to be displayed to the customer.
306 307 308 |
# File 'lib/stripe/services/v2/billing/collection_setting_service.rb', line 306 def description @description end |