Class: Stripe::V2::Billing::CollectionSettingUpdateParams::PaymentMethodOptions::Bancontact
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::CollectionSettingUpdateParams::PaymentMethodOptions::Bancontact
- Defined in:
- lib/stripe/params/v2/billing/collection_setting_update_params.rb
Instance Attribute Summary collapse
-
#preferred_language ⇒ Object
Preferred language of the Bancontact authorization page that the customer is redirected to.
Instance Method Summary collapse
-
#initialize(preferred_language: nil) ⇒ Bancontact
constructor
A new instance of Bancontact.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(preferred_language: nil) ⇒ Bancontact
Returns a new instance of Bancontact.
53 54 55 |
# File 'lib/stripe/params/v2/billing/collection_setting_update_params.rb', line 53 def initialize(preferred_language: nil) @preferred_language = preferred_language end |
Instance Attribute Details
#preferred_language ⇒ Object
Preferred language of the Bancontact authorization page that the customer is redirected to.
51 52 53 |
# File 'lib/stripe/params/v2/billing/collection_setting_update_params.rb', line 51 def preferred_language @preferred_language end |