Class: Stripe::V2::Billing::CollectionSettingUpdateParams::PaymentMethodOptions::Card

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/billing/collection_setting_update_params.rb

Defined Under Namespace

Classes: MandateOptions

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(mandate_options: nil, network: nil, request_three_d_secure: nil) ⇒ Card

Returns a new instance of Card.



87
88
89
90
91
# File 'lib/stripe/params/v2/billing/collection_setting_update_params.rb', line 87

def initialize(mandate_options: nil, network: nil, request_three_d_secure: nil)
  @mandate_options = mandate_options
  @network = network
  @request_three_d_secure = request_three_d_secure
end

Instance Attribute Details

#mandate_optionsObject

Configuration options for setting up an eMandate for cards issued in India.



78
79
80
# File 'lib/stripe/params/v2/billing/collection_setting_update_params.rb', line 78

def mandate_options
  @mandate_options
end

#networkObject

Selected network to process the payment on. Depends on the available networks of the card.



80
81
82
# File 'lib/stripe/params/v2/billing/collection_setting_update_params.rb', line 80

def network
  @network
end

#request_three_d_secureObject

An advanced option 3D Secure. We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and other requirements. However, if you wish to request 3D Secure based on logic from your own fraud engine, provide this option. Read our guide on manually requesting 3D Secure for more information on how this configuration interacts with Radar and our SCA Engine.



85
86
87
# File 'lib/stripe/params/v2/billing/collection_setting_update_params.rb', line 85

def request_three_d_secure
  @request_three_d_secure
end

Class Method Details

.field_encodingsObject



93
94
95
# File 'lib/stripe/params/v2/billing/collection_setting_update_params.rb', line 93

def self.field_encodings
  @field_encodings = { mandate_options: { kind: :object, fields: { amount: :int64_string } } }
end