Class: Stripe::V2::Billing::CollectionSettingUpdateParams::PaymentMethodOptions::Card::MandateOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::CollectionSettingUpdateParams::PaymentMethodOptions::Card::MandateOptions
- Defined in:
- lib/stripe/params/v2/billing/collection_setting_update_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount to be charged for future payments.
-
#amount_type ⇒ Object
The AmountType for the mandate.
-
#description ⇒ Object
A description of the mandate that is meant to be displayed to the customer.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(amount: nil, amount_type: nil, description: nil) ⇒ MandateOptions
constructor
A new instance of MandateOptions.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(amount: nil, amount_type: nil, description: nil) ⇒ MandateOptions
Returns a new instance of MandateOptions.
67 68 69 70 71 |
# File 'lib/stripe/params/v2/billing/collection_setting_update_params.rb', line 67 def initialize(amount: nil, amount_type: nil, description: nil) @amount = amount @amount_type = amount_type @description = description end |
Instance Attribute Details
#amount ⇒ Object
Amount to be charged for future payments.
61 62 63 |
# File 'lib/stripe/params/v2/billing/collection_setting_update_params.rb', line 61 def amount @amount end |
#amount_type ⇒ Object
The AmountType for the mandate. One of ‘fixed` or `maximum`.
63 64 65 |
# File 'lib/stripe/params/v2/billing/collection_setting_update_params.rb', line 63 def amount_type @amount_type end |
#description ⇒ Object
A description of the mandate that is meant to be displayed to the customer.
65 66 67 |
# File 'lib/stripe/params/v2/billing/collection_setting_update_params.rb', line 65 def description @description end |
Class Method Details
.field_encodings ⇒ Object
73 74 75 |
# File 'lib/stripe/params/v2/billing/collection_setting_update_params.rb', line 73 def self.field_encodings @field_encodings = { amount: :int64_string } end |