Class: Stripe::V2::Billing::CollectionSettingUpdateParams::PaymentMethodOptions::CustomerBalance::BankTransfer::EuBankTransfer
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::CollectionSettingUpdateParams::PaymentMethodOptions::CustomerBalance::BankTransfer::EuBankTransfer
- Defined in:
- lib/stripe/params/v2/billing/collection_setting_update_params.rb
Instance Attribute Summary collapse
-
#country ⇒ Object
The desired country code of the bank account information.
Instance Method Summary collapse
-
#initialize(country: nil) ⇒ EuBankTransfer
constructor
A new instance of EuBankTransfer.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(country: nil) ⇒ EuBankTransfer
Returns a new instance of EuBankTransfer.
104 105 106 |
# File 'lib/stripe/params/v2/billing/collection_setting_update_params.rb', line 104 def initialize(country: nil) @country = country end |
Instance Attribute Details
#country ⇒ Object
The desired country code of the bank account information.
102 103 104 |
# File 'lib/stripe/params/v2/billing/collection_setting_update_params.rb', line 102 def country @country end |