Class: Stripe::V2::Billing::CollectionSettingUpdateParams::PaymentMethodOptions::UsBankAccount::FinancialConnections
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::CollectionSettingUpdateParams::PaymentMethodOptions::UsBankAccount::FinancialConnections
- Defined in:
- lib/stripe/params/v2/billing/collection_setting_update_params.rb
Defined Under Namespace
Classes: Filters
Instance Attribute Summary collapse
-
#filters ⇒ Object
Provide filters for the linked accounts that the customer can select for the payment method.
-
#permissions ⇒ Object
The list of permissions to request.
-
#prefetch ⇒ Object
List of data features that you would like to retrieve upon account creation.
Instance Method Summary collapse
-
#initialize(filters: nil, permissions: nil, prefetch: nil) ⇒ FinancialConnections
constructor
A new instance of FinancialConnections.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(filters: nil, permissions: nil, prefetch: nil) ⇒ FinancialConnections
Returns a new instance of FinancialConnections.
146 147 148 149 150 |
# File 'lib/stripe/params/v2/billing/collection_setting_update_params.rb', line 146 def initialize(filters: nil, permissions: nil, prefetch: nil) @filters = filters @permissions = @prefetch = prefetch end |
Instance Attribute Details
#filters ⇒ Object
Provide filters for the linked accounts that the customer can select for the payment method.
140 141 142 |
# File 'lib/stripe/params/v2/billing/collection_setting_update_params.rb', line 140 def filters @filters end |
#permissions ⇒ Object
The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included.
142 143 144 |
# File 'lib/stripe/params/v2/billing/collection_setting_update_params.rb', line 142 def @permissions end |
#prefetch ⇒ Object
List of data features that you would like to retrieve upon account creation.
144 145 146 |
# File 'lib/stripe/params/v2/billing/collection_setting_update_params.rb', line 144 def prefetch @prefetch end |