Class: Stripe::V2::Billing::CollectionSettingVersion

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/billing/collection_setting_version.rb

Overview

A Collection Setting Version is a specific configuration of a CollectionSetting at a point in time. Collection Setting Versions enable you to track changes to payment collection settings over time and manage which version is active for new billing operations.

Defined Under Namespace

Classes: EmailDelivery, PaymentMethodOptions

Constant Summary collapse

OBJECT_NAME =
"v2.billing.collection_setting_version"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#collection_methodObject (readonly)

Either automatic, or send_invoice. When charging automatically, Stripe attempts to pay this bill at the end of the period using the payment method attached to the billing profile. When sending an invoice, Stripe emails your billing profile an invoice with payment instructions. Defaults to automatic.



273
274
275
# File 'lib/stripe/resources/v2/billing/collection_setting_version.rb', line 273

def collection_method
  @collection_method
end

#createdObject (readonly)

Timestamp of when the object was created.



275
276
277
# File 'lib/stripe/resources/v2/billing/collection_setting_version.rb', line 275

def created
  @created
end

#email_deliveryObject (readonly)

Email delivery settings.



277
278
279
# File 'lib/stripe/resources/v2/billing/collection_setting_version.rb', line 277

def email_delivery
  @email_delivery
end

#idObject (readonly)

The ID of the CollectionSettingVersion object.



279
280
281
# File 'lib/stripe/resources/v2/billing/collection_setting_version.rb', line 279

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



281
282
283
# File 'lib/stripe/resources/v2/billing/collection_setting_version.rb', line 281

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



283
284
285
# File 'lib/stripe/resources/v2/billing/collection_setting_version.rb', line 283

def object
  @object
end

#payment_method_configurationObject (readonly)

The ID of the PaymentMethodConfiguration object, which controls which payment methods are displayed to your customers.



285
286
287
# File 'lib/stripe/resources/v2/billing/collection_setting_version.rb', line 285

def payment_method_configuration
  @payment_method_configuration
end

#payment_method_optionsObject (readonly)

Payment Method specific configuration stored on the object.



287
288
289
# File 'lib/stripe/resources/v2/billing/collection_setting_version.rb', line 287

def payment_method_options
  @payment_method_options
end

Class Method Details

.field_encodingsObject



300
301
302
303
304
305
306
307
308
309
310
311
312
# File 'lib/stripe/resources/v2/billing/collection_setting_version.rb', line 300

def self.field_encodings
  @field_encodings = {
    payment_method_options: {
      kind: :object,
      fields: {
        card: {
          kind: :object,
          fields: { mandate_options: { kind: :object, fields: { amount: :int64_string } } },
        },
      },
    },
  }
end

.field_remappingsObject



296
297
298
# File 'lib/stripe/resources/v2/billing/collection_setting_version.rb', line 296

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



289
290
291
292
293
294
# File 'lib/stripe/resources/v2/billing/collection_setting_version.rb', line 289

def self.inner_class_types
  @inner_class_types = {
    email_delivery: EmailDelivery,
    payment_method_options: PaymentMethodOptions,
  }
end

.object_nameObject



10
11
12
# File 'lib/stripe/resources/v2/billing/collection_setting_version.rb', line 10

def self.object_name
  "v2.billing.collection_setting_version"
end