Class: Stripe::V2::Billing::Contract::BillingSettings
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::Contract::BillingSettings
- Defined in:
- lib/stripe/resources/v2/billing/contract.rb
Defined Under Namespace
Classes: BillSettingsDetails, BillingProfileDetails, CollectionSettingsDetails
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bill_settings_details ⇒ Object
readonly
The bill settings details configures invoice and tax settings for the contract.
-
#billing_profile_details ⇒ Object
readonly
The billing profile details configures who is charged for the contract.
-
#collection_settings_details ⇒ Object
readonly
The collection settings details configures how payments are collected on the contract.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bill_settings_details ⇒ Object (readonly)
The bill settings details configures invoice and tax settings for the contract.
124 125 126 |
# File 'lib/stripe/resources/v2/billing/contract.rb', line 124 def bill_settings_details @bill_settings_details end |
#billing_profile_details ⇒ Object (readonly)
The billing profile details configures who is charged for the contract.
126 127 128 |
# File 'lib/stripe/resources/v2/billing/contract.rb', line 126 def billing_profile_details @billing_profile_details end |
#collection_settings_details ⇒ Object (readonly)
The collection settings details configures how payments are collected on the contract.
128 129 130 |
# File 'lib/stripe/resources/v2/billing/contract.rb', line 128 def collection_settings_details @collection_settings_details end |
Class Method Details
.field_remappings ⇒ Object
138 139 140 |
# File 'lib/stripe/resources/v2/billing/contract.rb', line 138 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
130 131 132 133 134 135 136 |
# File 'lib/stripe/resources/v2/billing/contract.rb', line 130 def self.inner_class_types @inner_class_types = { bill_settings_details: BillSettingsDetails, billing_profile_details: BillingProfileDetails, collection_settings_details: CollectionSettingsDetails, } end |