Class: Stripe::V2::Billing::Contract::ContractLineDetail
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::Contract::ContractLineDetail
- Defined in:
- lib/stripe/resources/v2/billing/contract.rb
Defined Under Namespace
Classes: ContractLineValueDetails, EndsAt, Override, Pricing, StartsAt
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#contract_line ⇒ Object
readonly
The ID of the contract line.
-
#contract_line_value_details ⇒ Object
readonly
The computed value details for the contract line.
-
#created ⇒ Object
readonly
Timestamp of when the object was created.
-
#ends_at ⇒ Object
readonly
Timestamp to indicate when the contract line ends.
-
#metadata ⇒ Object
readonly
Set of key-value pairs that you can attach to an object.
-
#overrides ⇒ Object
readonly
List of overrides applied to the contract line.
-
#pricing ⇒ Object
readonly
The pricing configuration for the contract line.
-
#starts_at ⇒ Object
readonly
Timestamp to indicate when the contract line starts.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#contract_line ⇒ Object (readonly)
The ID of the contract line.
458 459 460 |
# File 'lib/stripe/resources/v2/billing/contract.rb', line 458 def contract_line @contract_line end |
#contract_line_value_details ⇒ Object (readonly)
The computed value details for the contract line.
460 461 462 |
# File 'lib/stripe/resources/v2/billing/contract.rb', line 460 def contract_line_value_details @contract_line_value_details end |
#created ⇒ Object (readonly)
Timestamp of when the object was created.
462 463 464 |
# File 'lib/stripe/resources/v2/billing/contract.rb', line 462 def created @created end |
#ends_at ⇒ Object (readonly)
Timestamp to indicate when the contract line ends.
464 465 466 |
# File 'lib/stripe/resources/v2/billing/contract.rb', line 464 def ends_at @ends_at end |
#metadata ⇒ Object (readonly)
Set of key-value pairs that you can attach to an object.
466 467 468 |
# File 'lib/stripe/resources/v2/billing/contract.rb', line 466 def @metadata end |
#overrides ⇒ Object (readonly)
List of overrides applied to the contract line.
468 469 470 |
# File 'lib/stripe/resources/v2/billing/contract.rb', line 468 def overrides @overrides end |
#pricing ⇒ Object (readonly)
The pricing configuration for the contract line.
470 471 472 |
# File 'lib/stripe/resources/v2/billing/contract.rb', line 470 def pricing @pricing end |
#starts_at ⇒ Object (readonly)
Timestamp to indicate when the contract line starts.
472 473 474 |
# File 'lib/stripe/resources/v2/billing/contract.rb', line 472 def starts_at @starts_at end |
Class Method Details
.field_remappings ⇒ Object
484 485 486 |
# File 'lib/stripe/resources/v2/billing/contract.rb', line 484 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
474 475 476 477 478 479 480 481 482 |
# File 'lib/stripe/resources/v2/billing/contract.rb', line 474 def self.inner_class_types @inner_class_types = { contract_line_value_details: ContractLineValueDetails, ends_at: EndsAt, overrides: Override, pricing: Pricing, starts_at: StartsAt, } end |