Class: Stripe::V2::Billing::Contract::ContractLineDetail::Override::ServiceAction::Replace
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::Contract::ContractLineDetail::Override::ServiceAction::Replace
- Defined in:
- lib/stripe/resources/v2/billing/contract.rb
Defined Under Namespace
Classes: CreditGrant
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#credit_grant ⇒ Object
readonly
Details for the credit grant.
-
#id ⇒ Object
readonly
The ID of the service action to replace.
-
#lookup_key ⇒ Object
readonly
The lookup key for the service action to replace.
-
#service_interval ⇒ Object
readonly
The interval for assessing service.
-
#service_interval_count ⇒ Object
readonly
The length of the interval for assessing service.
-
#type ⇒ Object
readonly
The type of the service action.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#credit_grant ⇒ Object (readonly)
Details for the credit grant. Required if ‘type` is `credit_grant`.
365 366 367 |
# File 'lib/stripe/resources/v2/billing/contract.rb', line 365 def credit_grant @credit_grant end |
#id ⇒ Object (readonly)
The ID of the service action to replace.
367 368 369 |
# File 'lib/stripe/resources/v2/billing/contract.rb', line 367 def id @id end |
#lookup_key ⇒ Object (readonly)
The lookup key for the service action to replace.
369 370 371 |
# File 'lib/stripe/resources/v2/billing/contract.rb', line 369 def lookup_key @lookup_key end |
#service_interval ⇒ Object (readonly)
The interval for assessing service.
371 372 373 |
# File 'lib/stripe/resources/v2/billing/contract.rb', line 371 def service_interval @service_interval end |
#service_interval_count ⇒ Object (readonly)
The length of the interval for assessing service.
373 374 375 |
# File 'lib/stripe/resources/v2/billing/contract.rb', line 373 def service_interval_count @service_interval_count end |
#type ⇒ Object (readonly)
The type of the service action.
375 376 377 |
# File 'lib/stripe/resources/v2/billing/contract.rb', line 375 def type @type end |
Class Method Details
.field_remappings ⇒ Object
381 382 383 |
# File 'lib/stripe/resources/v2/billing/contract.rb', line 381 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
377 378 379 |
# File 'lib/stripe/resources/v2/billing/contract.rb', line 377 def self.inner_class_types @inner_class_types = { credit_grant: CreditGrant } end |