Class: Stripe::V2::Billing::Contract::ContractLineDetail::Override::ServiceAction::Replace::CreditGrant
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::Contract::ContractLineDetail::Override::ServiceAction::Replace::CreditGrant
- Defined in:
- lib/stripe/resources/v2/billing/contract.rb
Defined Under Namespace
Classes: Amount, ApplicabilityConfig, ExpiryConfig
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The amount of the credit grant.
-
#applicability_config ⇒ Object
readonly
Defines the scope where the credit grant is applicable.
-
#category ⇒ Object
readonly
The category of the credit grant.
-
#expiry_config ⇒ Object
readonly
The expiry configuration for the credit grant.
-
#name ⇒ Object
readonly
A descriptive name.
-
#priority ⇒ Object
readonly
The desired priority for applying this credit grant.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The amount of the credit grant.
340 341 342 |
# File 'lib/stripe/resources/v2/billing/contract.rb', line 340 def amount @amount end |
#applicability_config ⇒ Object (readonly)
Defines the scope where the credit grant is applicable.
342 343 344 |
# File 'lib/stripe/resources/v2/billing/contract.rb', line 342 def applicability_config @applicability_config end |
#category ⇒ Object (readonly)
The category of the credit grant.
344 345 346 |
# File 'lib/stripe/resources/v2/billing/contract.rb', line 344 def category @category end |
#expiry_config ⇒ Object (readonly)
The expiry configuration for the credit grant.
346 347 348 |
# File 'lib/stripe/resources/v2/billing/contract.rb', line 346 def expiry_config @expiry_config end |
#name ⇒ Object (readonly)
A descriptive name.
348 349 350 |
# File 'lib/stripe/resources/v2/billing/contract.rb', line 348 def name @name end |
#priority ⇒ Object (readonly)
The desired priority for applying this credit grant. The highest priority is 0 and the lowest is 100.
350 351 352 |
# File 'lib/stripe/resources/v2/billing/contract.rb', line 350 def priority @priority end |
Class Method Details
.field_remappings ⇒ Object
360 361 362 |
# File 'lib/stripe/resources/v2/billing/contract.rb', line 360 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
352 353 354 355 356 357 358 |
# File 'lib/stripe/resources/v2/billing/contract.rb', line 352 def self.inner_class_types @inner_class_types = { amount: Amount, applicability_config: ApplicabilityConfig, expiry_config: ExpiryConfig, } end |