Class: Stripe::V2::Billing::Contract::OneTimeFee
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::Contract::OneTimeFee
- Defined in:
- lib/stripe/resources/v2/billing/contract.rb
Defined Under Namespace
Classes: BillSchedule, ProductDetails
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bill_schedule ⇒ Object
readonly
The resolved bill schedule for the fee.
-
#billable_item_type ⇒ Object
readonly
The type of billable item that this fee references.
-
#product_details ⇒ Object
readonly
Details for a product billable target.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bill_schedule ⇒ Object (readonly)
The resolved bill schedule for the fee.
568 569 570 |
# File 'lib/stripe/resources/v2/billing/contract.rb', line 568 def bill_schedule @bill_schedule end |
#billable_item_type ⇒ Object (readonly)
The type of billable item that this fee references.
570 571 572 |
# File 'lib/stripe/resources/v2/billing/contract.rb', line 570 def billable_item_type @billable_item_type end |
#product_details ⇒ Object (readonly)
Details for a product billable target. Set when ‘billable_item_type` is `product`.
572 573 574 |
# File 'lib/stripe/resources/v2/billing/contract.rb', line 572 def product_details @product_details end |
Class Method Details
.field_encodings ⇒ Object
582 583 584 585 586 587 588 589 |
# File 'lib/stripe/resources/v2/billing/contract.rb', line 582 def self.field_encodings @field_encodings = { bill_schedule: { kind: :array, element: { kind: :object, fields: { value: :int64_string } }, }, } end |
.field_remappings ⇒ Object
578 579 580 |
# File 'lib/stripe/resources/v2/billing/contract.rb', line 578 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
574 575 576 |
# File 'lib/stripe/resources/v2/billing/contract.rb', line 574 def self.inner_class_types @inner_class_types = { bill_schedule: BillSchedule, product_details: ProductDetails } end |