Class: Stripe::V2::Billing::Contract::OneTimeFee::BillSchedule
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::Contract::OneTimeFee::BillSchedule
- Defined in:
- lib/stripe/resources/v2/billing/contract.rb
Defined Under Namespace
Classes: BillAt
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bill_at ⇒ Object
readonly
When this entry will be billed.
-
#value ⇒ Object
readonly
The amount to bill for this entry, in the smallest currency unit.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bill_at ⇒ Object (readonly)
When this entry will be billed.
538 539 540 |
# File 'lib/stripe/resources/v2/billing/contract.rb', line 538 def bill_at @bill_at end |
#value ⇒ Object (readonly)
The amount to bill for this entry, in the smallest currency unit.
540 541 542 |
# File 'lib/stripe/resources/v2/billing/contract.rb', line 540 def value @value end |
Class Method Details
.field_encodings ⇒ Object
550 551 552 |
# File 'lib/stripe/resources/v2/billing/contract.rb', line 550 def self.field_encodings @field_encodings = { value: :int64_string } end |
.field_remappings ⇒ Object
546 547 548 |
# File 'lib/stripe/resources/v2/billing/contract.rb', line 546 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
542 543 544 |
# File 'lib/stripe/resources/v2/billing/contract.rb', line 542 def self.inner_class_types @inner_class_types = { bill_at: BillAt } end |