Class: Stripe::V2::Billing::Contract::PricingLine
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::Contract::PricingLine
- Defined in:
- lib/stripe/resources/v2/billing/contract.rb
Defined Under Namespace
Classes: EndsAt, Pricing, StartsAt
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#ends_at ⇒ Object
readonly
Resolved timestamp when the pricing line ends.
-
#lookup_key ⇒ Object
readonly
The user-provided lookup key for the pricing line.
-
#metadata ⇒ Object
readonly
Set of key-value pairs that you can attach to an object.
-
#pricing ⇒ Object
readonly
The pricing configuration for the pricing line.
-
#pricing_line ⇒ Object
readonly
The ID of the pricing line.
-
#starts_at ⇒ Object
readonly
Resolved timestamp when the pricing line starts.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#ends_at ⇒ Object (readonly)
Resolved timestamp when the pricing line ends.
646 647 648 |
# File 'lib/stripe/resources/v2/billing/contract.rb', line 646 def ends_at @ends_at end |
#lookup_key ⇒ Object (readonly)
The user-provided lookup key for the pricing line.
648 649 650 |
# File 'lib/stripe/resources/v2/billing/contract.rb', line 648 def lookup_key @lookup_key end |
#metadata ⇒ Object (readonly)
Set of key-value pairs that you can attach to an object.
650 651 652 |
# File 'lib/stripe/resources/v2/billing/contract.rb', line 650 def @metadata end |
#pricing ⇒ Object (readonly)
The pricing configuration for the pricing line.
652 653 654 |
# File 'lib/stripe/resources/v2/billing/contract.rb', line 652 def pricing @pricing end |
#pricing_line ⇒ Object (readonly)
The ID of the pricing line.
654 655 656 |
# File 'lib/stripe/resources/v2/billing/contract.rb', line 654 def pricing_line @pricing_line end |
#starts_at ⇒ Object (readonly)
Resolved timestamp when the pricing line starts.
656 657 658 |
# File 'lib/stripe/resources/v2/billing/contract.rb', line 656 def starts_at @starts_at end |
Class Method Details
.field_remappings ⇒ Object
662 663 664 |
# File 'lib/stripe/resources/v2/billing/contract.rb', line 662 def self.field_remappings @field_remappings = {} end |