Class: Stripe::V2::Billing::ContractCreateParams::BillingSettings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::ContractCreateParams::BillingSettings
- Defined in:
- lib/stripe/params/v2/billing/contract_create_params.rb
Defined Under Namespace
Classes: BillSettingsDetails, BillingProfileDetails, CollectionSettingsDetails
Instance Attribute Summary collapse
-
#bill_settings_details ⇒ Object
The bill settings details configures invoice and tax settings for the contract.
-
#billing_profile_details ⇒ Object
The billing profile details configures who is charged for the contract.
-
#collection_settings_details ⇒ Object
The collection settings details configures how payments are collected on the contract.
Instance Method Summary collapse
-
#initialize(bill_settings_details: nil, billing_profile_details: nil, collection_settings_details: nil) ⇒ BillingSettings
constructor
A new instance of BillingSettings.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(bill_settings_details: nil, billing_profile_details: nil, collection_settings_details: nil) ⇒ BillingSettings
Returns a new instance of BillingSettings.
128 129 130 131 132 133 134 135 136 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 128 def initialize( bill_settings_details: nil, billing_profile_details: nil, collection_settings_details: nil ) @bill_settings_details = bill_settings_details @billing_profile_details = billing_profile_details @collection_settings_details = collection_settings_details end |
Instance Attribute Details
#bill_settings_details ⇒ Object
The bill settings details configures invoice and tax settings for the contract.
122 123 124 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 122 def bill_settings_details @bill_settings_details end |
#billing_profile_details ⇒ Object
The billing profile details configures who is charged for the contract.
124 125 126 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 124 def billing_profile_details @billing_profile_details end |
#collection_settings_details ⇒ Object
The collection settings details configures how payments are collected on the contract.
126 127 128 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 126 def collection_settings_details @collection_settings_details end |