Class: Stripe::V2::Billing::ContractCreateParams::BillingSettings::BillSettingsDetails::Invoice
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::ContractCreateParams::BillingSettings::BillSettingsDetails::Invoice
- Defined in:
- lib/stripe/params/v2/billing/contract_create_params.rb
Defined Under Namespace
Classes: TimeUntilDue
Instance Attribute Summary collapse
-
#time_until_due ⇒ Object
How long the customer has to pay the invoice before it's past due.
Instance Method Summary collapse
-
#initialize(time_until_due: nil) ⇒ Invoice
constructor
A new instance of Invoice.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(time_until_due: nil) ⇒ Invoice
Returns a new instance of Invoice.
83 84 85 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 83 def initialize(time_until_due: nil) @time_until_due = time_until_due end |
Instance Attribute Details
#time_until_due ⇒ Object
How long the customer has to pay the invoice before it's past due.
81 82 83 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 81 def time_until_due @time_until_due end |