Class: Stripe::V2::Billing::ContractCreateParams::ContractLine::Override::ServiceAction::Add::CreditGrant
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::ContractCreateParams::ContractLine::Override::ServiceAction::Add::CreditGrant
- Defined in:
- lib/stripe/params/v2/billing/contract_create_params.rb
Defined Under Namespace
Classes: Amount, ApplicabilityConfig, ExpiryConfig
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount of the credit grant.
-
#applicability_config ⇒ Object
Defines the scope where the credit grant is applicable.
-
#category ⇒ Object
The category of the credit grant.
-
#expiry_config ⇒ Object
The expiry configuration for the credit grant.
-
#name ⇒ Object
A descriptive name.
-
#priority ⇒ Object
The desired priority for applying this credit grant.
Instance Method Summary collapse
-
#initialize(amount: nil, applicability_config: nil, category: nil, expiry_config: nil, name: nil, priority: nil) ⇒ CreditGrant
constructor
A new instance of CreditGrant.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, applicability_config: nil, category: nil, expiry_config: nil, name: nil, priority: nil) ⇒ CreditGrant
Returns a new instance of CreditGrant.
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 182 def initialize( amount: nil, applicability_config: nil, category: nil, expiry_config: nil, name: nil, priority: nil ) @amount = amount @applicability_config = applicability_config @category = category @expiry_config = expiry_config @name = name @priority = priority end |
Instance Attribute Details
#amount ⇒ Object
The amount of the credit grant.
170 171 172 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 170 def amount @amount end |
#applicability_config ⇒ Object
Defines the scope where the credit grant is applicable.
172 173 174 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 172 def applicability_config @applicability_config end |
#category ⇒ Object
The category of the credit grant.
174 175 176 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 174 def category @category end |
#expiry_config ⇒ Object
The expiry configuration for the credit grant.
176 177 178 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 176 def expiry_config @expiry_config end |
#name ⇒ Object
A descriptive name.
178 179 180 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 178 def name @name end |
#priority ⇒ Object
The desired priority for applying this credit grant. The highest priority is 0 and the lowest is 100.
180 181 182 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 180 def priority @priority end |