Class: Stripe::V2::Billing::ContractCreateParams::ContractLine::Override::ServiceAction::Replace
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::ContractCreateParams::ContractLine::Override::ServiceAction::Replace
- Defined in:
- lib/stripe/params/v2/billing/contract_create_params.rb
Defined Under Namespace
Classes: CreditGrant
Instance Attribute Summary collapse
-
#credit_grant ⇒ Object
Details for the credit grant.
-
#id ⇒ Object
The ID of the service action to replace.
-
#lookup_key ⇒ Object
The lookup key for the service action to replace.
-
#service_interval ⇒ Object
The interval for assessing service.
-
#service_interval_count ⇒ Object
The length of the interval for assessing service.
-
#type ⇒ Object
The type of the service action.
Instance Method Summary collapse
-
#initialize(credit_grant: nil, id: nil, lookup_key: nil, service_interval: nil, service_interval_count: nil, type: nil) ⇒ Replace
constructor
A new instance of Replace.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(credit_grant: nil, id: nil, lookup_key: nil, service_interval: nil, service_interval_count: nil, type: nil) ⇒ Replace
Returns a new instance of Replace.
304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 304 def initialize( credit_grant: nil, id: nil, lookup_key: nil, service_interval: nil, service_interval_count: nil, type: nil ) @credit_grant = credit_grant @id = id @lookup_key = lookup_key @service_interval = service_interval @service_interval_count = service_interval_count @type = type end |
Instance Attribute Details
#credit_grant ⇒ Object
Details for the credit grant. Required if ‘type` is `credit_grant`.
292 293 294 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 292 def credit_grant @credit_grant end |
#id ⇒ Object
The ID of the service action to replace.
294 295 296 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 294 def id @id end |
#lookup_key ⇒ Object
The lookup key for the service action to replace.
296 297 298 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 296 def lookup_key @lookup_key end |
#service_interval ⇒ Object
The interval for assessing service.
298 299 300 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 298 def service_interval @service_interval end |
#service_interval_count ⇒ Object
The length of the interval for assessing service.
300 301 302 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 300 def service_interval_count @service_interval_count end |
#type ⇒ Object
The type of the service action.
302 303 304 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 302 def type @type end |