Class: Stripe::V2::Billing::ContractCreateParams::ContractLine::Override::ServiceAction::Replace::CreditGrant
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::ContractCreateParams::ContractLine::Override::ServiceAction::Replace::CreditGrant
- Defined in:
- lib/stripe/params/v2/billing/contract_create_params.rb
Defined Under Namespace
Classes: Amount, ApplicabilityConfig, ExpiryConfig
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount of the credit grant.
-
#applicability_config ⇒ Object
Defines the scope where the credit grant is applicable.
-
#category ⇒ Object
The category of the credit grant.
-
#expiry_config ⇒ Object
The expiry configuration for the credit grant.
-
#name ⇒ Object
A descriptive name.
-
#priority ⇒ Object
The desired priority for applying this credit grant.
Instance Method Summary collapse
-
#initialize(amount: nil, applicability_config: nil, category: nil, expiry_config: nil, name: nil, priority: nil) ⇒ CreditGrant
constructor
A new instance of CreditGrant.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, applicability_config: nil, category: nil, expiry_config: nil, name: nil, priority: nil) ⇒ CreditGrant
Returns a new instance of CreditGrant.
275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 275 def initialize( amount: nil, applicability_config: nil, category: nil, expiry_config: nil, name: nil, priority: nil ) @amount = amount @applicability_config = applicability_config @category = category @expiry_config = expiry_config @name = name @priority = priority end |
Instance Attribute Details
#amount ⇒ Object
The amount of the credit grant.
263 264 265 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 263 def amount @amount end |
#applicability_config ⇒ Object
Defines the scope where the credit grant is applicable.
265 266 267 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 265 def applicability_config @applicability_config end |
#category ⇒ Object
The category of the credit grant.
267 268 269 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 267 def category @category end |
#expiry_config ⇒ Object
The expiry configuration for the credit grant.
269 270 271 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 269 def expiry_config @expiry_config end |
#name ⇒ Object
A descriptive name.
271 272 273 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 271 def name @name end |
#priority ⇒ Object
The desired priority for applying this credit grant. The highest priority is 0 and the lowest is 100.
273 274 275 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 273 def priority @priority end |