Class: Stripe::V2::Billing::ContractCreateParams::OneTimeFee

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/billing/contract_create_params.rb

Defined Under Namespace

Classes: BillSchedule, ProductDetails

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(bill_schedule: nil, billable_item_type: nil, product_details: nil) ⇒ OneTimeFee

Returns a new instance of OneTimeFee.



487
488
489
490
491
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 487

def initialize(bill_schedule: nil, billable_item_type: nil, product_details: nil)
  @bill_schedule = bill_schedule
  @billable_item_type = billable_item_type
  @product_details = product_details
end

Instance Attribute Details

#bill_scheduleObject

The bill schedule for the fee. Each entry produces an individual invoice item billed at ‘bill_at`.



481
482
483
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 481

def bill_schedule
  @bill_schedule
end

#billable_item_typeObject

The type of billable item that this fee references.



483
484
485
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 483

def billable_item_type
  @billable_item_type
end

#product_detailsObject

Details for a product billable target. Required when ‘billable_item_type` is `product`.



485
486
487
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 485

def product_details
  @product_details
end

Class Method Details

.field_encodingsObject



493
494
495
496
497
498
499
500
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 493

def self.field_encodings
  @field_encodings = {
    bill_schedule: {
      kind: :array,
      element: { kind: :object, fields: { value: :int64_string } },
    },
  }
end