Class: Stripe::V2::Billing::ContractCreateParams::OneTimeFee::BillSchedule
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::ContractCreateParams::OneTimeFee::BillSchedule
- Defined in:
- lib/stripe/params/v2/billing/contract_create_params.rb
Defined Under Namespace
Classes: BillAt
Instance Attribute Summary collapse
-
#bill_at ⇒ Object
When this entry should be billed.
-
#value ⇒ Object
The amount to bill for this entry, in the smallest currency unit.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(bill_at: nil, value: nil) ⇒ BillSchedule
constructor
A new instance of BillSchedule.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(bill_at: nil, value: nil) ⇒ BillSchedule
Returns a new instance of BillSchedule.
462 463 464 465 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 462 def initialize(bill_at: nil, value: nil) @bill_at = bill_at @value = value end |
Instance Attribute Details
#bill_at ⇒ Object
When this entry should be billed.
458 459 460 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 458 def bill_at @bill_at end |
#value ⇒ Object
The amount to bill for this entry, in the smallest currency unit.
460 461 462 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 460 def value @value end |
Class Method Details
.field_encodings ⇒ Object
467 468 469 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 467 def self.field_encodings @field_encodings = { value: :int64_string } end |