Class: Stripe::V2::Billing::ContractCreateParams::PricingLine::Pricing::PriceDetails::PricingOverride
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::ContractCreateParams::PricingLine::Pricing::PriceDetails::PricingOverride
- Defined in:
- lib/stripe/params/v2/billing/contract_create_params.rb
Defined Under Namespace
Classes: EndsAt, OverwritePrice, StartsAt
Instance Attribute Summary collapse
-
#ends_at ⇒ Object
When the override ends.
-
#lookup_key ⇒ Object
A user-provided lookup key to reference this override.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#overwrite_price ⇒ Object
Parameters for the overwrite_price override.
-
#priority ⇒ Object
The priority of this override relative to others.
-
#starts_at ⇒ Object
When the override starts.
-
#type ⇒ Object
The type of override.
Instance Method Summary collapse
-
#initialize(ends_at: nil, lookup_key: nil, metadata: nil, overwrite_price: nil, priority: nil, starts_at: nil, type: nil) ⇒ PricingOverride
constructor
A new instance of PricingOverride.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(ends_at: nil, lookup_key: nil, metadata: nil, overwrite_price: nil, priority: nil, starts_at: nil, type: nil) ⇒ PricingOverride
Returns a new instance of PricingOverride.
202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 202 def initialize( ends_at: nil, lookup_key: nil, metadata: nil, overwrite_price: nil, priority: nil, starts_at: nil, type: nil ) @ends_at = ends_at @lookup_key = lookup_key @metadata = @overwrite_price = overwrite_price @priority = priority @starts_at = starts_at @type = type end |
Instance Attribute Details
#ends_at ⇒ Object
When the override ends. Defaults to the pricing line's end if not specified.
188 189 190 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 188 def ends_at @ends_at end |
#lookup_key ⇒ Object
A user-provided lookup key to reference this override.
190 191 192 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 190 def lookup_key @lookup_key end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
192 193 194 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 192 def @metadata end |
#overwrite_price ⇒ Object
Parameters for the overwrite_price override. Required if type is overwrite_price.
194 195 196 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 194 def overwrite_price @overwrite_price end |
#priority ⇒ Object
The priority of this override relative to others. 0 is highest, 100 is lowest. Defaults to 50.
196 197 198 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 196 def priority @priority end |
#starts_at ⇒ Object
When the override starts. Defaults to the pricing line's start if not specified.
198 199 200 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 198 def starts_at @starts_at end |
#type ⇒ Object
The type of override.
200 201 202 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 200 def type @type end |