Class: Stripe::V2::Billing::ContractLicensePricingQuantityChange
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Billing::ContractLicensePricingQuantityChange
- Defined in:
- lib/stripe/resources/v2/billing/contract_license_pricing_quantity_change.rb
Overview
A license pricing quantity change object returned by ListContractLicenseQuantityChanges.
Constant Summary collapse
- OBJECT_NAME =
"v2.billing.contract_license_pricing_quantity_change"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#created ⇒ Object
readonly
The timestamp when this quantity change object was created.
-
#effective_at ⇒ Object
readonly
The timestamp when this quantity change takes effect.
-
#id ⇒ Object
readonly
The ID of the quantity change object.
-
#license_pricing_id ⇒ Object
readonly
The ID of the license pricing.
-
#license_pricing_type ⇒ Object
readonly
The type of the license pricing.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#pricing_line ⇒ Object
readonly
The ID of the pricing line associated with this quantity change.
-
#quantity ⇒ Object
readonly
The quantity at the effective time.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#created ⇒ Object (readonly)
The timestamp when this quantity change object was created.
15 16 17 |
# File 'lib/stripe/resources/v2/billing/contract_license_pricing_quantity_change.rb', line 15 def created @created end |
#effective_at ⇒ Object (readonly)
The timestamp when this quantity change takes effect.
17 18 19 |
# File 'lib/stripe/resources/v2/billing/contract_license_pricing_quantity_change.rb', line 17 def effective_at @effective_at end |
#id ⇒ Object (readonly)
The ID of the quantity change object.
19 20 21 |
# File 'lib/stripe/resources/v2/billing/contract_license_pricing_quantity_change.rb', line 19 def id @id end |
#license_pricing_id ⇒ Object (readonly)
The ID of the license pricing.
21 22 23 |
# File 'lib/stripe/resources/v2/billing/contract_license_pricing_quantity_change.rb', line 21 def license_pricing_id @license_pricing_id end |
#license_pricing_type ⇒ Object (readonly)
The type of the license pricing.
23 24 25 |
# File 'lib/stripe/resources/v2/billing/contract_license_pricing_quantity_change.rb', line 23 def license_pricing_type @license_pricing_type end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
25 26 27 |
# File 'lib/stripe/resources/v2/billing/contract_license_pricing_quantity_change.rb', line 25 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
27 28 29 |
# File 'lib/stripe/resources/v2/billing/contract_license_pricing_quantity_change.rb', line 27 def object @object end |
#pricing_line ⇒ Object (readonly)
The ID of the pricing line associated with this quantity change.
29 30 31 |
# File 'lib/stripe/resources/v2/billing/contract_license_pricing_quantity_change.rb', line 29 def pricing_line @pricing_line end |
#quantity ⇒ Object (readonly)
The quantity at the effective time.
31 32 33 |
# File 'lib/stripe/resources/v2/billing/contract_license_pricing_quantity_change.rb', line 31 def quantity @quantity end |
Class Method Details
.field_remappings ⇒ Object
37 38 39 |
# File 'lib/stripe/resources/v2/billing/contract_license_pricing_quantity_change.rb', line 37 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
33 34 35 |
# File 'lib/stripe/resources/v2/billing/contract_license_pricing_quantity_change.rb', line 33 def self.inner_class_types @inner_class_types = {} end |
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/v2/billing/contract_license_pricing_quantity_change.rb', line 10 def self.object_name "v2.billing.contract_license_pricing_quantity_change" end |