Class: Stripe::V2::Billing::ContractPricingLineQuantityChange

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/billing/contract_pricing_line_quantity_change.rb

Overview

A quantity change object for a pricing line, returned by ListContractPricingLineQuantityChanges.

Defined Under Namespace

Classes: Pricing

Constant Summary collapse

OBJECT_NAME =
"v2.billing.contract_pricing_line_quantity_change"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#createdObject (readonly)

The timestamp when this quantity change object was created.



29
30
31
# File 'lib/stripe/resources/v2/billing/contract_pricing_line_quantity_change.rb', line 29

def created
  @created
end

#effective_atObject (readonly)

The timestamp when this quantity change takes effect.



31
32
33
# File 'lib/stripe/resources/v2/billing/contract_pricing_line_quantity_change.rb', line 31

def effective_at
  @effective_at
end

#idObject (readonly)

The id of the quantity change object.



33
34
35
# File 'lib/stripe/resources/v2/billing/contract_pricing_line_quantity_change.rb', line 33

def id
  @id
end

#livemodeObject (readonly)

Has the value true if the object exists in live mode or the value false if the object exists in test mode.



35
36
37
# File 'lib/stripe/resources/v2/billing/contract_pricing_line_quantity_change.rb', line 35

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object's type. Objects of the same type share the same value of the object field.



37
38
39
# File 'lib/stripe/resources/v2/billing/contract_pricing_line_quantity_change.rb', line 37

def object
  @object
end

#pricingObject (readonly)

The pricing configuration for the associated pricing line.



39
40
41
# File 'lib/stripe/resources/v2/billing/contract_pricing_line_quantity_change.rb', line 39

def pricing
  @pricing
end

#pricing_lineObject (readonly)

The id of the pricing line associated with this quantity change.



41
42
43
# File 'lib/stripe/resources/v2/billing/contract_pricing_line_quantity_change.rb', line 41

def pricing_line
  @pricing_line
end

#quantityObject (readonly)

The quantity at the effective time.



43
44
45
# File 'lib/stripe/resources/v2/billing/contract_pricing_line_quantity_change.rb', line 43

def quantity
  @quantity
end

Class Method Details

.field_encodingsObject



53
54
55
# File 'lib/stripe/resources/v2/billing/contract_pricing_line_quantity_change.rb', line 53

def self.field_encodings
  @field_encodings = { quantity: :decimal_string }
end

.field_remappingsObject



49
50
51
# File 'lib/stripe/resources/v2/billing/contract_pricing_line_quantity_change.rb', line 49

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



45
46
47
# File 'lib/stripe/resources/v2/billing/contract_pricing_line_quantity_change.rb', line 45

def self.inner_class_types
  @inner_class_types = { pricing: Pricing }
end

.object_nameObject



10
11
12
# File 'lib/stripe/resources/v2/billing/contract_pricing_line_quantity_change.rb', line 10

def self.object_name
  "v2.billing.contract_pricing_line_quantity_change"
end