Class: Stripe::V2::Billing::ContractUpdateParams::LicenseQuantityAction
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::ContractUpdateParams::LicenseQuantityAction
- Defined in:
- lib/stripe/params/v2/billing/contract_update_params.rb
Defined Under Namespace
Classes: EffectiveAt, Set
Instance Attribute Summary collapse
-
#effective_at ⇒ Object
The effective at for the license quantity action.
-
#license_pricing_id ⇒ Object
The ID of the license pricing.
-
#license_pricing_lookup_key ⇒ Object
The lookup key for the license pricing.
-
#license_pricing_type ⇒ Object
The type of the license pricing.
-
#pricing_line ⇒ Object
The pricing line ID for the license quantity action.
-
#pricing_line_lookup_key ⇒ Object
The pricing line lookup key for the license quantity action.
-
#set ⇒ Object
The set quantity for the license quantity action.
-
#type ⇒ Object
The type of the license quantity action.
Instance Method Summary collapse
-
#initialize(effective_at: nil, license_pricing_id: nil, license_pricing_lookup_key: nil, license_pricing_type: nil, pricing_line: nil, pricing_line_lookup_key: nil, set: nil, type: nil) ⇒ LicenseQuantityAction
constructor
A new instance of LicenseQuantityAction.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(effective_at: nil, license_pricing_id: nil, license_pricing_lookup_key: nil, license_pricing_type: nil, pricing_line: nil, pricing_line_lookup_key: nil, set: nil, type: nil) ⇒ LicenseQuantityAction
Returns a new instance of LicenseQuantityAction.
46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/stripe/params/v2/billing/contract_update_params.rb', line 46 def initialize( effective_at: nil, license_pricing_id: nil, license_pricing_lookup_key: nil, license_pricing_type: nil, pricing_line: nil, pricing_line_lookup_key: nil, set: nil, type: nil ) @effective_at = effective_at @license_pricing_id = license_pricing_id @license_pricing_lookup_key = license_pricing_lookup_key @license_pricing_type = license_pricing_type @pricing_line = pricing_line @pricing_line_lookup_key = pricing_line_lookup_key @set = set @type = type end |
Instance Attribute Details
#effective_at ⇒ Object
The effective at for the license quantity action.
30 31 32 |
# File 'lib/stripe/params/v2/billing/contract_update_params.rb', line 30 def effective_at @effective_at end |
#license_pricing_id ⇒ Object
The ID of the license pricing.
32 33 34 |
# File 'lib/stripe/params/v2/billing/contract_update_params.rb', line 32 def license_pricing_id @license_pricing_id end |
#license_pricing_lookup_key ⇒ Object
The lookup key for the license pricing.
34 35 36 |
# File 'lib/stripe/params/v2/billing/contract_update_params.rb', line 34 def license_pricing_lookup_key @license_pricing_lookup_key end |
#license_pricing_type ⇒ Object
The type of the license pricing.
36 37 38 |
# File 'lib/stripe/params/v2/billing/contract_update_params.rb', line 36 def license_pricing_type @license_pricing_type end |
#pricing_line ⇒ Object
The pricing line ID for the license quantity action.
38 39 40 |
# File 'lib/stripe/params/v2/billing/contract_update_params.rb', line 38 def pricing_line @pricing_line end |
#pricing_line_lookup_key ⇒ Object
The pricing line lookup key for the license quantity action.
40 41 42 |
# File 'lib/stripe/params/v2/billing/contract_update_params.rb', line 40 def pricing_line_lookup_key @pricing_line_lookup_key end |
#set ⇒ Object
The set quantity for the license quantity action.
42 43 44 |
# File 'lib/stripe/params/v2/billing/contract_update_params.rb', line 42 def set @set end |
#type ⇒ Object
The type of the license quantity action.
44 45 46 |
# File 'lib/stripe/params/v2/billing/contract_update_params.rb', line 44 def type @type end |