Class: Stripe::V2::Billing::ContractUpdateParams::PricingLineAction::Add::Pricing::PriceDetails::PricingOverride
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::ContractUpdateParams::PricingLineAction::Add::Pricing::PriceDetails::PricingOverride
- Defined in:
- lib/stripe/params/v2/billing/contract_update_params.rb
Defined Under Namespace
Classes: EndsAt, OverwritePrice, StartsAt
Instance Attribute Summary collapse
-
#ends_at ⇒ Object
When the override ends.
-
#lookup_key ⇒ Object
A user-provided lookup key to reference this override.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#overwrite_price ⇒ Object
Parameters for the overwrite_price override.
-
#priority ⇒ Object
The priority of this override relative to others.
-
#starts_at ⇒ Object
When the override starts.
-
#type ⇒ Object
The type of override.
Instance Method Summary collapse
-
#initialize(ends_at: nil, lookup_key: nil, metadata: nil, overwrite_price: nil, priority: nil, starts_at: nil, type: nil) ⇒ PricingOverride
constructor
A new instance of PricingOverride.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(ends_at: nil, lookup_key: nil, metadata: nil, overwrite_price: nil, priority: nil, starts_at: nil, type: nil) ⇒ PricingOverride
Returns a new instance of PricingOverride.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/stripe/params/v2/billing/contract_update_params.rb', line 72 def initialize( ends_at: nil, lookup_key: nil, metadata: nil, overwrite_price: nil, priority: nil, starts_at: nil, type: nil ) @ends_at = ends_at @lookup_key = lookup_key @metadata = @overwrite_price = overwrite_price @priority = priority @starts_at = starts_at @type = type end |
Instance Attribute Details
#ends_at ⇒ Object
When the override ends. Defaults to the pricing line's end if not specified.
58 59 60 |
# File 'lib/stripe/params/v2/billing/contract_update_params.rb', line 58 def ends_at @ends_at end |
#lookup_key ⇒ Object
A user-provided lookup key to reference this override.
60 61 62 |
# File 'lib/stripe/params/v2/billing/contract_update_params.rb', line 60 def lookup_key @lookup_key end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
62 63 64 |
# File 'lib/stripe/params/v2/billing/contract_update_params.rb', line 62 def @metadata end |
#overwrite_price ⇒ Object
Parameters for the overwrite_price override. Required if type is overwrite_price.
64 65 66 |
# File 'lib/stripe/params/v2/billing/contract_update_params.rb', line 64 def overwrite_price @overwrite_price end |
#priority ⇒ Object
The priority of this override relative to others. 0 is highest, 100 is lowest. Defaults to 50.
66 67 68 |
# File 'lib/stripe/params/v2/billing/contract_update_params.rb', line 66 def priority @priority end |
#starts_at ⇒ Object
When the override starts. Defaults to the pricing line's start if not specified.
68 69 70 |
# File 'lib/stripe/params/v2/billing/contract_update_params.rb', line 68 def starts_at @starts_at end |
#type ⇒ Object
The type of override.
70 71 72 |
# File 'lib/stripe/params/v2/billing/contract_update_params.rb', line 70 def type @type end |