Class: Stripe::V2::Billing::ContractUpdateParams::PricingLineAction::Update::Pricing::PriceDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::ContractUpdateParams::PricingLineAction::Update::Pricing::PriceDetails
- Defined in:
- lib/stripe/params/v2/billing/contract_update_params.rb
Defined Under Namespace
Classes: PricingOverrideAction, QuantityChange
Instance Attribute Summary collapse
-
#pricing_override_actions ⇒ Object
Pricing override actions to apply to the overrides embedded on this pricing line.
-
#quantity_changes ⇒ Object
Quantity changes for the pricing line.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(pricing_override_actions: nil, quantity_changes: nil) ⇒ PriceDetails
constructor
A new instance of PriceDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(pricing_override_actions: nil, quantity_changes: nil) ⇒ PriceDetails
Returns a new instance of PriceDetails.
422 423 424 425 |
# File 'lib/stripe/params/v2/billing/contract_update_params.rb', line 422 def initialize(pricing_override_actions: nil, quantity_changes: nil) @pricing_override_actions = pricing_override_actions @quantity_changes = quantity_changes end |
Instance Attribute Details
#pricing_override_actions ⇒ Object
Pricing override actions to apply to the overrides embedded on this pricing line.
418 419 420 |
# File 'lib/stripe/params/v2/billing/contract_update_params.rb', line 418 def pricing_override_actions @pricing_override_actions end |
#quantity_changes ⇒ Object
Quantity changes for the pricing line. Setting this clears all future quantity changes.
420 421 422 |
# File 'lib/stripe/params/v2/billing/contract_update_params.rb', line 420 def quantity_changes @quantity_changes end |
Class Method Details
.field_encodings ⇒ Object
427 428 429 430 431 432 433 434 |
# File 'lib/stripe/params/v2/billing/contract_update_params.rb', line 427 def self.field_encodings @field_encodings = { quantity_changes: { kind: :array, element: { kind: :object, fields: { set: :decimal_string } }, }, } end |