Class: Stripe::V2::Billing::ContractUpdateParams::PricingOverrideAction::Add::OverwritePrice::Tier
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::ContractUpdateParams::PricingOverrideAction::Add::OverwritePrice::Tier
- Defined in:
- lib/stripe/params/v2/billing/contract_update_params.rb
Instance Attribute Summary collapse
-
#flat_amount ⇒ Object
Price for the entire tier, represented as a decimal string in minor currency units.
-
#unit_amount ⇒ Object
Per-unit price for units included in this tier, represented as a decimal string in minor currency units.
-
#up_to_decimal ⇒ Object
Up to and including this quantity will be contained in the tier.
-
#up_to_inf ⇒ Object
No upper bound to this tier.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(flat_amount: nil, unit_amount: nil, up_to_decimal: nil, up_to_inf: nil) ⇒ Tier
constructor
A new instance of Tier.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(flat_amount: nil, unit_amount: nil, up_to_decimal: nil, up_to_inf: nil) ⇒ Tier
Returns a new instance of Tier.
290 291 292 293 294 295 296 297 298 299 300 |
# File 'lib/stripe/params/v2/billing/contract_update_params.rb', line 290 def initialize( flat_amount: nil, unit_amount: nil, up_to_decimal: nil, up_to_inf: nil ) @flat_amount = flat_amount @unit_amount = unit_amount @up_to_decimal = up_to_decimal @up_to_inf = up_to_inf end |
Instance Attribute Details
#flat_amount ⇒ Object
Price for the entire tier, represented as a decimal string in minor currency units.
282 283 284 |
# File 'lib/stripe/params/v2/billing/contract_update_params.rb', line 282 def flat_amount @flat_amount end |
#unit_amount ⇒ Object
Per-unit price for units included in this tier, represented as a decimal string in minor currency units.
284 285 286 |
# File 'lib/stripe/params/v2/billing/contract_update_params.rb', line 284 def unit_amount @unit_amount end |
#up_to_decimal ⇒ Object
Up to and including this quantity will be contained in the tier.
286 287 288 |
# File 'lib/stripe/params/v2/billing/contract_update_params.rb', line 286 def up_to_decimal @up_to_decimal end |
#up_to_inf ⇒ Object
No upper bound to this tier.
288 289 290 |
# File 'lib/stripe/params/v2/billing/contract_update_params.rb', line 288 def up_to_inf @up_to_inf end |
Class Method Details
.field_encodings ⇒ Object
302 303 304 |
# File 'lib/stripe/params/v2/billing/contract_update_params.rb', line 302 def self.field_encodings @field_encodings = { up_to_decimal: :decimal_string } end |