Class: Stripe::V2::Billing::CustomPricingUnit

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/billing/custom_pricing_unit.rb

Overview

The Custom Pricing Unit object.

Constant Summary collapse

OBJECT_NAME =
"v2.billing.custom_pricing_unit"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#activeObject (readonly)

Whether the custom pricing unit is active.



15
16
17
# File 'lib/stripe/resources/v2/billing/custom_pricing_unit.rb', line 15

def active
  @active
end

#createdObject (readonly)

Timestamp of when the object was created.



17
18
19
# File 'lib/stripe/resources/v2/billing/custom_pricing_unit.rb', line 17

def created
  @created
end

#display_nameObject (readonly)

Description that customers will see in the invoice line item. Maximum length of 10 characters.



20
21
22
# File 'lib/stripe/resources/v2/billing/custom_pricing_unit.rb', line 20

def display_name
  @display_name
end

#idObject (readonly)

Unique identifier for the object.



22
23
24
# File 'lib/stripe/resources/v2/billing/custom_pricing_unit.rb', line 22

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



31
32
33
# File 'lib/stripe/resources/v2/billing/custom_pricing_unit.rb', line 31

def livemode
  @livemode
end

#lookup_keyObject (readonly)

An internal key you can use to search for a particular Custom Pricing Unit. Maximum length of 200 characters.



25
26
27
# File 'lib/stripe/resources/v2/billing/custom_pricing_unit.rb', line 25

def lookup_key
  @lookup_key
end

#metadataObject (readonly)

Set of [key-value pairs](/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



27
28
29
# File 'lib/stripe/resources/v2/billing/custom_pricing_unit.rb', line 27

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



29
30
31
# File 'lib/stripe/resources/v2/billing/custom_pricing_unit.rb', line 29

def object
  @object
end

Class Method Details

.field_remappingsObject



37
38
39
# File 'lib/stripe/resources/v2/billing/custom_pricing_unit.rb', line 37

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



33
34
35
# File 'lib/stripe/resources/v2/billing/custom_pricing_unit.rb', line 33

def self.inner_class_types
  @inner_class_types = {}
end

.object_nameObject



10
11
12
# File 'lib/stripe/resources/v2/billing/custom_pricing_unit.rb', line 10

def self.object_name
  "v2.billing.custom_pricing_unit"
end