Class: Stripe::V2::Billing::CustomPricingUnitService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::CustomPricingUnitService::CreateParams
- Defined in:
- lib/stripe/services/v2/billing/custom_pricing_unit_service.rb
Instance Attribute Summary collapse
-
#display_name ⇒ Object
Description that customers will see in the invoice line item.
-
#lookup_key ⇒ Object
An internal key you can use to search for a particular custom pricing unit item.
-
#metadata ⇒ Object
Set of [key-value pairs](/docs/api/metadata) that you can attach to an object.
Instance Method Summary collapse
-
#initialize(display_name: nil, lookup_key: nil, metadata: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(display_name: nil, lookup_key: nil, metadata: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
35 36 37 38 39 |
# File 'lib/stripe/services/v2/billing/custom_pricing_unit_service.rb', line 35 def initialize(display_name: nil, lookup_key: nil, metadata: nil) @display_name = display_name @lookup_key = lookup_key @metadata = end |
Instance Attribute Details
#display_name ⇒ Object
Description that customers will see in the invoice line item. Maximum length of 10 characters.
27 28 29 |
# File 'lib/stripe/services/v2/billing/custom_pricing_unit_service.rb', line 27 def display_name @display_name end |
#lookup_key ⇒ Object
An internal key you can use to search for a particular custom pricing unit item. Must be unique among items. Maximum length of 200 characters.
31 32 33 |
# File 'lib/stripe/services/v2/billing/custom_pricing_unit_service.rb', line 31 def lookup_key @lookup_key end |
#metadata ⇒ Object
Set of [key-value pairs](/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
33 34 35 |
# File 'lib/stripe/services/v2/billing/custom_pricing_unit_service.rb', line 33 def @metadata end |