Class: Stripe::V2::Billing::CustomPricingUnitService::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::CustomPricingUnitService::UpdateParams
- Defined in:
- lib/stripe/services/v2/billing/custom_pricing_unit_service.rb
Instance Attribute Summary collapse
-
#active ⇒ Object
Whether the Custom Pricing Unit is active.
-
#display_name ⇒ Object
Description that customers will see in the invoice line item.
-
#lookup_key ⇒ Object
An internal key you can use to search for a particular CustomPricingUnit item.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
Instance Method Summary collapse
-
#initialize(active: nil, display_name: nil, lookup_key: nil, metadata: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(active: nil, display_name: nil, lookup_key: nil, metadata: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
54 55 56 57 58 59 |
# File 'lib/stripe/services/v2/billing/custom_pricing_unit_service.rb', line 54 def initialize(active: nil, display_name: nil, lookup_key: nil, metadata: nil) @active = active @display_name = display_name @lookup_key = lookup_key @metadata = end |
Instance Attribute Details
#active ⇒ Object
Whether the Custom Pricing Unit is active.
46 47 48 |
# File 'lib/stripe/services/v2/billing/custom_pricing_unit_service.rb', line 46 def active @active end |
#display_name ⇒ Object
Description that customers will see in the invoice line item.
48 49 50 |
# File 'lib/stripe/services/v2/billing/custom_pricing_unit_service.rb', line 48 def display_name @display_name end |
#lookup_key ⇒ Object
An internal key you can use to search for a particular CustomPricingUnit item.
50 51 52 |
# File 'lib/stripe/services/v2/billing/custom_pricing_unit_service.rb', line 50 def lookup_key @lookup_key end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
52 53 54 |
# File 'lib/stripe/services/v2/billing/custom_pricing_unit_service.rb', line 52 def @metadata end |