Class: Stripe::V2::Billing::CustomPricingUnitUpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::CustomPricingUnitUpdateParams
- Defined in:
- lib/stripe/params/v2/billing/custom_pricing_unit_update_params.rb
Instance Attribute Summary collapse
-
#active ⇒ Object
Whether the Custom Pricing Unit is active.
-
#display_name ⇒ Object
Description that customers will see in the invoice line item.
-
#lookup_key ⇒ Object
An internal key you can use to search for a particular CustomPricingUnit item.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
Instance Method Summary collapse
-
#initialize(active: nil, display_name: nil, lookup_key: nil, metadata: nil) ⇒ CustomPricingUnitUpdateParams
constructor
A new instance of CustomPricingUnitUpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(active: nil, display_name: nil, lookup_key: nil, metadata: nil) ⇒ CustomPricingUnitUpdateParams
Returns a new instance of CustomPricingUnitUpdateParams.
17 18 19 20 21 22 |
# File 'lib/stripe/params/v2/billing/custom_pricing_unit_update_params.rb', line 17 def initialize(active: nil, display_name: nil, lookup_key: nil, metadata: nil) @active = active @display_name = display_name @lookup_key = lookup_key @metadata = end |
Instance Attribute Details
#active ⇒ Object
Whether the Custom Pricing Unit is active.
9 10 11 |
# File 'lib/stripe/params/v2/billing/custom_pricing_unit_update_params.rb', line 9 def active @active end |
#display_name ⇒ Object
Description that customers will see in the invoice line item.
11 12 13 |
# File 'lib/stripe/params/v2/billing/custom_pricing_unit_update_params.rb', line 11 def display_name @display_name end |
#lookup_key ⇒ Object
An internal key you can use to search for a particular CustomPricingUnit item.
13 14 15 |
# File 'lib/stripe/params/v2/billing/custom_pricing_unit_update_params.rb', line 13 def lookup_key @lookup_key end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
15 16 17 |
# File 'lib/stripe/params/v2/billing/custom_pricing_unit_update_params.rb', line 15 def @metadata end |