Class: Stripe::V2::Billing::Intent::CadenceData::BillingCycle::Year
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::Intent::CadenceData::BillingCycle::Year
- Defined in:
- lib/stripe/resources/v2/billing/intent.rb
Defined Under Namespace
Classes: Time
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#day_of_month ⇒ Object
readonly
The day to anchor the billing on for a type=“month” billing cycle from 1-31.
-
#month_of_year ⇒ Object
readonly
The month to bill on from 1-12.
-
#time ⇒ Object
readonly
The time at which the billing cycle ends.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#day_of_month ⇒ Object (readonly)
The day to anchor the billing on for a type=“month” billing cycle from 1-31. If this number is greater than the number of days in the month being billed, this anchors to the last day of the month.
174 175 176 |
# File 'lib/stripe/resources/v2/billing/intent.rb', line 174 def day_of_month @day_of_month end |
#month_of_year ⇒ Object (readonly)
The month to bill on from 1-12. If not provided, this defaults to the month the cadence was created.
176 177 178 |
# File 'lib/stripe/resources/v2/billing/intent.rb', line 176 def month_of_year @month_of_year end |
#time ⇒ Object (readonly)
The time at which the billing cycle ends.
178 179 180 |
# File 'lib/stripe/resources/v2/billing/intent.rb', line 178 def time @time end |
Class Method Details
.field_remappings ⇒ Object
184 185 186 |
# File 'lib/stripe/resources/v2/billing/intent.rb', line 184 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
180 181 182 |
# File 'lib/stripe/resources/v2/billing/intent.rb', line 180 def self.inner_class_types @inner_class_types = { time: Time } end |