Class: Stripe::V2::Billing::Intent::CadenceData::Payer::BillingProfileData
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::Intent::CadenceData::Payer::BillingProfileData
- Defined in:
- lib/stripe/resources/v2/billing/intent.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#customer ⇒ Object
readonly
The customer to associate with the profile.
-
#default_payment_method ⇒ Object
readonly
The default payment method to use when billing this profile.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#customer ⇒ Object (readonly)
The customer to associate with the profile.
213 214 215 |
# File 'lib/stripe/resources/v2/billing/intent.rb', line 213 def customer @customer end |
#default_payment_method ⇒ Object (readonly)
The default payment method to use when billing this profile. If none is provided, the customer ‘default_payment_method` is used.
216 217 218 |
# File 'lib/stripe/resources/v2/billing/intent.rb', line 216 def default_payment_method @default_payment_method end |
Class Method Details
.field_remappings ⇒ Object
222 223 224 |
# File 'lib/stripe/resources/v2/billing/intent.rb', line 222 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
218 219 220 |
# File 'lib/stripe/resources/v2/billing/intent.rb', line 218 def self.inner_class_types @inner_class_types = {} end |