Class: Stripe::V2::Billing::Intent::CadenceData::Settings
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::Intent::CadenceData::Settings
- Defined in:
- lib/stripe/resources/v2/billing/intent.rb
Defined Under Namespace
Classes: Bill, Collection
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bill ⇒ Object
readonly
Settings that configure bills generation, which includes calculating totals, tax, and presenting invoices.
-
#collection ⇒ Object
readonly
Settings that configure and manage the behavior of collecting payments.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bill ⇒ Object (readonly)
Settings that configure bills generation, which includes calculating totals, tax, and presenting invoices.
271 272 273 |
# File 'lib/stripe/resources/v2/billing/intent.rb', line 271 def bill @bill end |
#collection ⇒ Object (readonly)
Settings that configure and manage the behavior of collecting payments.
273 274 275 |
# File 'lib/stripe/resources/v2/billing/intent.rb', line 273 def collection @collection end |
Class Method Details
.field_remappings ⇒ Object
279 280 281 |
# File 'lib/stripe/resources/v2/billing/intent.rb', line 279 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
275 276 277 |
# File 'lib/stripe/resources/v2/billing/intent.rb', line 275 def self.inner_class_types @inner_class_types = { bill: Bill, collection: Collection } end |