Class: Stripe::V2::Billing::Intent::CadenceData::Settings::Collection
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::Intent::CadenceData::Settings::Collection
- Defined in:
- lib/stripe/resources/v2/billing/intent.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#id ⇒ Object
readonly
The ID of the referenced settings object.
-
#version ⇒ Object
readonly
Returns the Settings Version when the cadence is pinned to a specific version.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#id ⇒ Object (readonly)
The ID of the referenced settings object.
258 259 260 |
# File 'lib/stripe/resources/v2/billing/intent.rb', line 258 def id @id end |
#version ⇒ Object (readonly)
Returns the Settings Version when the cadence is pinned to a specific version.
260 261 262 |
# File 'lib/stripe/resources/v2/billing/intent.rb', line 260 def version @version end |
Class Method Details
.field_remappings ⇒ Object
266 267 268 |
# File 'lib/stripe/resources/v2/billing/intent.rb', line 266 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
262 263 264 |
# File 'lib/stripe/resources/v2/billing/intent.rb', line 262 def self.inner_class_types @inner_class_types = {} end |