Class: Stripe::V2::Billing::IntentAction

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/billing/intent_action.rb

Overview

A Billing Intent Action represents a specific operation within a Billing Intent, such as subscribing to a Pricing Plan, modifying a subscription’s quantity, or deactivating service. Each action has a specific type and associated details that define what change will be made when the Intent is committed.

Defined Under Namespace

Classes: Apply, Deactivate, Modify, Remove, Subscribe

Constant Summary collapse

OBJECT_NAME =
"v2.billing.intent_action"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#applyObject (readonly)

Details for an apply action.



669
670
671
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 669

def apply
  @apply
end

#createdObject (readonly)

Time at which the object was created.



659
660
661
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 659

def created
  @created
end

#deactivateObject (readonly)

Details for a deactivate action.



671
672
673
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 671

def deactivate
  @deactivate
end

#idObject (readonly)

Unique identifier for the object.



661
662
663
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 661

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



667
668
669
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 667

def livemode
  @livemode
end

#modifyObject (readonly)

Details for a modify action.



673
674
675
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 673

def modify
  @modify
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



663
664
665
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 663

def object
  @object
end

#removeObject (readonly)

Details for a remove action.



675
676
677
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 675

def remove
  @remove
end

#subscribeObject (readonly)

Details for a subscribe action.



677
678
679
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 677

def subscribe
  @subscribe
end

#typeObject (readonly)

Type of the Billing Intent Action.



665
666
667
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 665

def type
  @type
end

Class Method Details

.field_encodingsObject



693
694
695
696
697
698
699
700
701
702
703
704
705
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 693

def self.field_encodings
  @field_encodings = {
    apply: {
      kind: :object,
      fields: {
        invoice_discount_rule: {
          kind: :object,
          fields: { percent_off: { kind: :object, fields: { percent_off: :decimal_string } } },
        },
      },
    },
  }
end

.field_remappingsObject



689
690
691
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 689

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



679
680
681
682
683
684
685
686
687
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 679

def self.inner_class_types
  @inner_class_types = {
    apply: Apply,
    deactivate: Deactivate,
    modify: Modify,
    remove: Remove,
    subscribe: Subscribe,
  }
end

.object_nameObject



12
13
14
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 12

def self.object_name
  "v2.billing.intent_action"
end