Class: Stripe::V2::Billing::IntentAction::Apply::InvoiceDiscountRule

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/billing/intent_action.rb

Defined Under Namespace

Classes: PercentOff

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#applies_toObject (readonly)

The entity that the discount rule applies to, for example, the Billing Cadence.



83
84
85
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 83

def applies_to
  @applies_to
end

#invoice_discount_ruleObject (readonly)

The ID of the created discount rule. This is only present once the Billing Intent is committed and the discount rule is created.



85
86
87
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 85

def invoice_discount_rule
  @invoice_discount_rule
end

#percent_offObject (readonly)

Configuration for percentage off discount.



87
88
89
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 87

def percent_off
  @percent_off
end

#typeObject (readonly)

Type of the discount rule.



89
90
91
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 89

def type
  @type
end

Class Method Details

.field_encodingsObject



99
100
101
102
103
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 99

def self.field_encodings
  @field_encodings = {
    percent_off: { kind: :object, fields: { percent_off: :decimal_string } },
  }
end

.field_remappingsObject



95
96
97
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 95

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



91
92
93
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 91

def self.inner_class_types
  @inner_class_types = { percent_off: PercentOff }
end