Class: Stripe::V2::Billing::IntentAction::Apply::InvoiceDiscountRule::PercentOff
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::IntentAction::Apply::InvoiceDiscountRule::PercentOff
- Defined in:
- lib/stripe/resources/v2/billing/intent_action.rb
Defined Under Namespace
Classes: MaximumApplications
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#maximum_applications ⇒ Object
readonly
The maximum number of times this discount can be applied for this Billing Cadence.
-
#percent_off ⇒ Object
readonly
Percent that will be taken off of the amount.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#maximum_applications ⇒ Object (readonly)
The maximum number of times this discount can be applied for this Billing Cadence.
21 22 23 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 21 def maximum_applications @maximum_applications end |
#percent_off ⇒ Object (readonly)
Percent that will be taken off of the amount. For example, percent_off of 50.0 will make $100 amount $50 instead.
23 24 25 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 23 def percent_off @percent_off end |