Class: Stripe::V2::Billing::IntentAction::Apply::SpendModifierRule::MaxBillingPeriodSpend
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::IntentAction::Apply::SpendModifierRule::MaxBillingPeriodSpend
- Defined in:
- lib/stripe/resources/v2/billing/intent_action.rb
Defined Under Namespace
Classes: Amount, CustomPricingUnitOverageRate
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The maximum amount allowed for the billing period.
-
#custom_pricing_unit_overage_rate ⇒ Object
readonly
The configration for the overage rate for the custom pricing unit.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The maximum amount allowed for the billing period.
114 115 116 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 114 def amount @amount end |
#custom_pricing_unit_overage_rate ⇒ Object (readonly)
The configration for the overage rate for the custom pricing unit.
116 117 118 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 116 def custom_pricing_unit_overage_rate @custom_pricing_unit_overage_rate end |
Class Method Details
.field_remappings ⇒ Object
125 126 127 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 125 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
118 119 120 121 122 123 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 118 def self.inner_class_types @inner_class_types = { amount: Amount, custom_pricing_unit_overage_rate: CustomPricingUnitOverageRate, } end |