Class: Stripe::V2::Billing::IntentAction::Deactivate
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::IntentAction::Deactivate
- Defined in:
- lib/stripe/resources/v2/billing/intent_action.rb
Defined Under Namespace
Classes: CancellationDetails, EffectiveAt, PricingPlanSubscriptionDetails
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#cancellation_details ⇒ Object
readonly
Details about why the cancellation was requested by the user.
-
#collect_at ⇒ Object
readonly
Allows users to override the collect at behavior.
-
#effective_at ⇒ Object
readonly
When the deactivate action takes effect.
-
#pricing_plan_subscription_details ⇒ Object
readonly
Details for deactivating a Pricing Plan Subscription.
-
#type ⇒ Object
readonly
Type of the action details.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#cancellation_details ⇒ Object (readonly)
Details about why the cancellation was requested by the user.
300 301 302 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 300 def cancellation_details @cancellation_details end |
#collect_at ⇒ Object (readonly)
Allows users to override the collect at behavior.
302 303 304 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 302 def collect_at @collect_at end |
#effective_at ⇒ Object (readonly)
When the deactivate action takes effect. If not specified, the default behavior is on_reserve.
304 305 306 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 304 def effective_at @effective_at end |
#pricing_plan_subscription_details ⇒ Object (readonly)
Details for deactivating a Pricing Plan Subscription.
306 307 308 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 306 def pricing_plan_subscription_details @pricing_plan_subscription_details end |
#type ⇒ Object (readonly)
Type of the action details.
308 309 310 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 308 def type @type end |
Class Method Details
.field_remappings ⇒ Object
318 319 320 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 318 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
310 311 312 313 314 315 316 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 310 def self.inner_class_types @inner_class_types = { cancellation_details: CancellationDetails, effective_at: EffectiveAt, pricing_plan_subscription_details: PricingPlanSubscriptionDetails, } end |