Class: Stripe::V2::Billing::IntentAction::Deactivate::PricingPlanSubscriptionDetails::Overrides
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::IntentAction::Deactivate::PricingPlanSubscriptionDetails::Overrides
- Defined in:
- lib/stripe/resources/v2/billing/intent_action.rb
Defined Under Namespace
Classes: PartialPeriodBehavior
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#partial_period_behaviors ⇒ Object
readonly
Configurations for behaviors when the action takes effect during the service period.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#partial_period_behaviors ⇒ Object (readonly)
Configurations for behaviors when the action takes effect during the service period.
276 277 278 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 276 def partial_period_behaviors @partial_period_behaviors end |
Class Method Details
.field_remappings ⇒ Object
282 283 284 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 282 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
278 279 280 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 278 def self.inner_class_types @inner_class_types = { partial_period_behaviors: PartialPeriodBehavior } end |