Class: Stripe::V2::Billing::IntentAction::Modify::EffectiveAt
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::IntentAction::Modify::EffectiveAt
- Defined in:
- lib/stripe/resources/v2/billing/intent_action.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#timestamp ⇒ Object
readonly
The timestamp at which the modify action will take effect.
-
#type ⇒ Object
readonly
When the modify action will take effect.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#timestamp ⇒ Object (readonly)
The timestamp at which the modify action will take effect. Only present if type is timestamp.
75 76 77 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 75 def @timestamp end |
#type ⇒ Object (readonly)
When the modify action will take effect.
77 78 79 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 77 def type @type end |