Class: Stripe::V2::Billing::IntentAction::Modify::PricingPlanSubscriptionDetails::Overrides::PartialPeriodBehavior::LicenseFee

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/billing/intent_action.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#credit_proration_behaviorObject (readonly)

The proration behavior for the partial servicing period. Defines how we prorate the license fee when the user modifies the subscription. If not specified, defaults to prorated.



361
362
363
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 361

def credit_proration_behavior
  @credit_proration_behavior
end

#debit_proration_behaviorObject (readonly)

The proration behavior for the partial servicing period. Defines how we prorate the license fee when the user modifies the subscription. If not specified, defaults to prorated.



363
364
365
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 363

def debit_proration_behavior
  @debit_proration_behavior
end

Class Method Details

.field_remappingsObject



369
370
371
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 369

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



365
366
367
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 365

def self.inner_class_types
  @inner_class_types = {}
end