Class: Stripe::V2::Billing::IntentAction::Remove
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::IntentAction::Remove
- Defined in:
- lib/stripe/resources/v2/billing/intent_action.rb
Defined Under Namespace
Classes: EffectiveAt
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#effective_at ⇒ Object
readonly
When the remove action will take effect.
-
#invoice_discount_rule ⇒ Object
readonly
The ID of the discount rule to remove for future invoices.
-
#spend_modifier_rule ⇒ Object
readonly
The ID of the spend modifier rule removed.
-
#type ⇒ Object
readonly
Type of the remove action.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#effective_at ⇒ Object (readonly)
When the remove action will take effect. Defaults to on_reserve if not specified.
409 410 411 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 409 def effective_at @effective_at end |
#invoice_discount_rule ⇒ Object (readonly)
The ID of the discount rule to remove for future invoices.
413 414 415 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 413 def invoice_discount_rule @invoice_discount_rule end |
#spend_modifier_rule ⇒ Object (readonly)
The ID of the spend modifier rule removed.
415 416 417 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 415 def spend_modifier_rule @spend_modifier_rule end |
#type ⇒ Object (readonly)
Type of the remove action.
411 412 413 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 411 def type @type end |
Class Method Details
.field_remappings ⇒ Object
421 422 423 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 421 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
417 418 419 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 417 def self.inner_class_types @inner_class_types = { effective_at: EffectiveAt } end |