Class: Stripe::V2::Billing::IntentAction::Subscribe::PricingPlanSubscriptionDetails::Overrides::PartialPeriodBehavior

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/billing/intent_action.rb

Defined Under Namespace

Classes: LicenseFee, RecurringCreditGrant

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#license_feeObject (readonly)

Overrides the behavior for license fee components when the action takes effect during the service period.



551
552
553
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 551

def license_fee
  @license_fee
end

#recurring_credit_grantObject (readonly)

Overrides the behavior for recurring credit grant components when the action takes effect during the service period.



553
554
555
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 553

def recurring_credit_grant
  @recurring_credit_grant
end

#typeObject (readonly)

The type of behavior to override.



555
556
557
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 555

def type
  @type
end

Class Method Details

.field_remappingsObject



564
565
566
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 564

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



557
558
559
560
561
562
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 557

def self.inner_class_types
  @inner_class_types = {
    license_fee: LicenseFee,
    recurring_credit_grant: RecurringCreditGrant,
  }
end