Class: Stripe::V2::Billing::IntentAction::Subscribe::V1SubscriptionDetails::Item

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/billing/intent_action.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#metadataObject (readonly)

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



152
153
154
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 152

def 
  @metadata
end

#priceObject (readonly)

The ID of the price object.



154
155
156
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 154

def price
  @price
end

#quantityObject (readonly)

Quantity for this item. If not provided, will default to 1.



156
157
158
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 156

def quantity
  @quantity
end