Class: Stripe::V2::Billing::IntentCreateParams::Action::Apply::InvoiceDiscountRule::PercentOff
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::IntentCreateParams::Action::Apply::InvoiceDiscountRule::PercentOff
- Defined in:
- lib/stripe/params/v2/billing/intent_create_params.rb
Defined Under Namespace
Classes: MaximumApplications
Instance Attribute Summary collapse
-
#maximum_applications ⇒ Object
The maximum number of times this discount can be applied for this cadence.
-
#percent_off ⇒ Object
Percent that will be taken off of the amount.
Instance Method Summary collapse
-
#initialize(maximum_applications: nil, percent_off: nil) ⇒ PercentOff
constructor
A new instance of PercentOff.
Methods inherited from RequestParams
Constructor Details
#initialize(maximum_applications: nil, percent_off: nil) ⇒ PercentOff
Returns a new instance of PercentOff.
34 35 36 37 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 34 def initialize(maximum_applications: nil, percent_off: nil) @maximum_applications = maximum_applications @percent_off = percent_off end |
Instance Attribute Details
#maximum_applications ⇒ Object
The maximum number of times this discount can be applied for this cadence.
30 31 32 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 30 def maximum_applications @maximum_applications end |
#percent_off ⇒ Object
Percent that will be taken off of the amount. For example, percent_off of 50.0 will make $100 amount $50 instead.
32 33 34 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 32 def percent_off @percent_off end |