Class: Stripe::V2::Billing::IntentCreateParams::Action::Deactivate::CancellationDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/billing/intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(comment: nil, feedback: nil) ⇒ CancellationDetails

Returns a new instance of CancellationDetails.



179
180
181
182
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 179

def initialize(comment: nil, feedback: nil)
  @comment = comment
  @feedback = feedback
end

Instance Attribute Details

#commentObject

Additional comments about why the user canceled the subscription, if the subscription was canceled explicitly by the user.



175
176
177
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 175

def comment
  @comment
end

#feedbackObject

The customer submitted reason for why they canceled, if the subscription was canceled explicitly by the user.



177
178
179
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 177

def feedback
  @feedback
end