Class: Stripe::V2::Billing::IntentCreateParams::Action::Deactivate::EffectiveAt
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::IntentCreateParams::Action::Deactivate::EffectiveAt
- Defined in:
- lib/stripe/params/v2/billing/intent_create_params.rb
Instance Attribute Summary collapse
-
#timestamp ⇒ Object
The timestamp at which the deactivate action takes effect.
-
#type ⇒ Object
When the deactivate action takes effect.
Instance Method Summary collapse
-
#initialize(timestamp: nil, type: nil) ⇒ EffectiveAt
constructor
A new instance of EffectiveAt.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(timestamp: nil, type: nil) ⇒ EffectiveAt
Returns a new instance of EffectiveAt.
191 192 193 194 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 191 def initialize(timestamp: nil, type: nil) @timestamp = @type = type end |
Instance Attribute Details
#timestamp ⇒ Object
The timestamp at which the deactivate action takes effect. Only present if type is timestamp.
187 188 189 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 187 def @timestamp end |
#type ⇒ Object
When the deactivate action takes effect.
189 190 191 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 189 def type @type end |