Class: Stripe::V2::Billing::IntentCreateParams::Action::Deactivate::PricingPlanSubscriptionDetails::Overrides::PartialPeriodBehavior
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::IntentCreateParams::Action::Deactivate::PricingPlanSubscriptionDetails::Overrides::PartialPeriodBehavior
- Defined in:
- lib/stripe/params/v2/billing/intent_create_params.rb
Defined Under Namespace
Classes: LicenseFee
Instance Attribute Summary collapse
-
#license_fee ⇒ Object
Overrides the behavior for license fee components when the action takes effect during the service period.
-
#type ⇒ Object
The type of behavior to override.
Instance Method Summary collapse
-
#initialize(license_fee: nil, type: nil) ⇒ PartialPeriodBehavior
constructor
A new instance of PartialPeriodBehavior.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(license_fee: nil, type: nil) ⇒ PartialPeriodBehavior
Returns a new instance of PartialPeriodBehavior.
213 214 215 216 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 213 def initialize(license_fee: nil, type: nil) @license_fee = license_fee @type = type end |
Instance Attribute Details
#license_fee ⇒ Object
Overrides the behavior for license fee components when the action takes effect during the service period.
209 210 211 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 209 def license_fee @license_fee end |
#type ⇒ Object
The type of behavior to override.
211 212 213 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 211 def type @type end |