Class: Stripe::V2::Billing::IntentCreateParams::Action::Modify::BillingDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::IntentCreateParams::Action::Modify::BillingDetails
- Defined in:
- lib/stripe/params/v2/billing/intent_create_params.rb
Instance Attribute Summary collapse
-
#proration_behavior ⇒ Object
This controls the proration adjustment for the partial servicing period.
Instance Method Summary collapse
-
#initialize(proration_behavior: nil) ⇒ BillingDetails
constructor
A new instance of BillingDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(proration_behavior: nil) ⇒ BillingDetails
Returns a new instance of BillingDetails.
111 112 113 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 111 def initialize(proration_behavior: nil) @proration_behavior = proration_behavior end |
Instance Attribute Details
#proration_behavior ⇒ Object
This controls the proration adjustment for the partial servicing period.
109 110 111 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 109 def proration_behavior @proration_behavior end |