Class: Stripe::V2::Billing::IntentCreateParams::Action::Modify::EffectiveAt
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::IntentCreateParams::Action::Modify::EffectiveAt
- Defined in:
- lib/stripe/params/v2/billing/intent_create_params.rb
Instance Attribute Summary collapse
-
#timestamp ⇒ Object
The timestamp at which the modify action will take effect.
-
#type ⇒ Object
When the modify action will take effect.
Instance Method Summary collapse
-
#initialize(timestamp: nil, type: nil) ⇒ EffectiveAt
constructor
A new instance of EffectiveAt.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(timestamp: nil, type: nil) ⇒ EffectiveAt
Returns a new instance of EffectiveAt.
265 266 267 268 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 265 def initialize(timestamp: nil, type: nil) @timestamp = @type = type end |
Instance Attribute Details
#timestamp ⇒ Object
The timestamp at which the modify action will take effect. Only present if type is timestamp.
261 262 263 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 261 def @timestamp end |
#type ⇒ Object
When the modify action will take effect.
263 264 265 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 263 def type @type end |