Class: Stripe::V2::Billing::IntentCreateParams::Action::Modify::PricingPlanSubscriptionDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::IntentCreateParams::Action::Modify::PricingPlanSubscriptionDetails
- Defined in:
- lib/stripe/params/v2/billing/intent_create_params.rb
Defined Under Namespace
Classes: ComponentConfiguration, Overrides
Instance Attribute Summary collapse
-
#component_configurations ⇒ Object
New configurations for the components of the pricing plan.
-
#new_pricing_plan ⇒ Object
The ID of the new Pricing Plan, if changing plans.
-
#new_pricing_plan_version ⇒ Object
The ID of the new Pricing Plan Version to use.
-
#overrides ⇒ Object
Configurations for overriding behaviors related to the subscription.
-
#pricing_plan_subscription ⇒ Object
The ID of the Pricing Plan Subscription to modify.
Instance Method Summary collapse
-
#initialize(component_configurations: nil, new_pricing_plan: nil, new_pricing_plan_version: nil, overrides: nil, pricing_plan_subscription: nil) ⇒ PricingPlanSubscriptionDetails
constructor
A new instance of PricingPlanSubscriptionDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(component_configurations: nil, new_pricing_plan: nil, new_pricing_plan_version: nil, overrides: nil, pricing_plan_subscription: nil) ⇒ PricingPlanSubscriptionDetails
Returns a new instance of PricingPlanSubscriptionDetails.
343 344 345 346 347 348 349 350 351 352 353 354 355 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 343 def initialize( component_configurations: nil, new_pricing_plan: nil, new_pricing_plan_version: nil, overrides: nil, pricing_plan_subscription: nil ) @component_configurations = component_configurations @new_pricing_plan = new_pricing_plan @new_pricing_plan_version = new_pricing_plan_version @overrides = overrides @pricing_plan_subscription = pricing_plan_subscription end |
Instance Attribute Details
#component_configurations ⇒ Object
New configurations for the components of the pricing plan.
333 334 335 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 333 def component_configurations @component_configurations end |
#new_pricing_plan ⇒ Object
The ID of the new Pricing Plan, if changing plans.
335 336 337 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 335 def new_pricing_plan @new_pricing_plan end |
#new_pricing_plan_version ⇒ Object
The ID of the new Pricing Plan Version to use.
337 338 339 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 337 def new_pricing_plan_version @new_pricing_plan_version end |
#overrides ⇒ Object
Configurations for overriding behaviors related to the subscription.
339 340 341 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 339 def overrides @overrides end |
#pricing_plan_subscription ⇒ Object
The ID of the Pricing Plan Subscription to modify.
341 342 343 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 341 def pricing_plan_subscription @pricing_plan_subscription end |