Class: Stripe::V2::Billing::IntentCreateParams::Action::Modify::PricingPlanSubscriptionDetails::Overrides::PartialPeriodBehavior::LicenseFee

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/billing/intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(credit_proration_behavior: nil, debit_proration_behavior: nil) ⇒ LicenseFee

Returns a new instance of LicenseFee.



298
299
300
301
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 298

def initialize(credit_proration_behavior: nil, debit_proration_behavior: nil)
  @credit_proration_behavior = credit_proration_behavior
  @debit_proration_behavior = debit_proration_behavior
end

Instance Attribute Details

#credit_proration_behaviorObject

The proration behavior for the partial servicing period. Defines how we prorate the license fee when the user modifies the subscription. If not specified, defaults to prorated.



294
295
296
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 294

def credit_proration_behavior
  @credit_proration_behavior
end

#debit_proration_behaviorObject

The proration behavior for the partial servicing period. Defines how we prorate the license fee when the user modifies the subscription. If not specified, defaults to prorated.



296
297
298
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 296

def debit_proration_behavior
  @debit_proration_behavior
end