Class: Stripe::V2::Billing::IntentCreateParams::Action::Remove
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::IntentCreateParams::Action::Remove
- Defined in:
- lib/stripe/params/v2/billing/intent_create_params.rb
Defined Under Namespace
Classes: EffectiveAt
Instance Attribute Summary collapse
-
#effective_at ⇒ Object
When the remove action will take effect.
-
#invoice_discount_rule ⇒ Object
The ID of the discount rule to remove for future invoices.
-
#spend_modifier_rule ⇒ Object
The ID of the spend modifier rule to remove.
-
#type ⇒ Object
Type of the remove action.
Instance Method Summary collapse
-
#initialize(effective_at: nil, invoice_discount_rule: nil, spend_modifier_rule: nil, type: nil) ⇒ Remove
constructor
A new instance of Remove.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(effective_at: nil, invoice_discount_rule: nil, spend_modifier_rule: nil, type: nil) ⇒ Remove
Returns a new instance of Remove.
397 398 399 400 401 402 403 404 405 406 407 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 397 def initialize( effective_at: nil, invoice_discount_rule: nil, spend_modifier_rule: nil, type: nil ) @effective_at = effective_at @invoice_discount_rule = invoice_discount_rule @spend_modifier_rule = spend_modifier_rule @type = type end |
Instance Attribute Details
#effective_at ⇒ Object
When the remove action will take effect. If not specified, defaults to on_reserve.
389 390 391 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 389 def effective_at @effective_at end |
#invoice_discount_rule ⇒ Object
The ID of the discount rule to remove for future invoices.
391 392 393 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 391 def invoice_discount_rule @invoice_discount_rule end |
#spend_modifier_rule ⇒ Object
The ID of the spend modifier rule to remove.
393 394 395 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 393 def spend_modifier_rule @spend_modifier_rule end |
#type ⇒ Object
Type of the remove action.
395 396 397 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 395 def type @type end |