Class: Stripe::V2::Billing::IntentCreateParams::Action::Subscribe::EffectiveAt
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::IntentCreateParams::Action::Subscribe::EffectiveAt
- Defined in:
- lib/stripe/params/v2/billing/intent_create_params.rb
Instance Attribute Summary collapse
-
#timestamp ⇒ Object
The timestamp at which the subscribe action takes effect.
-
#type ⇒ Object
When the subscribe action takes effect.
Instance Method Summary collapse
-
#initialize(timestamp: nil, type: nil) ⇒ EffectiveAt
constructor
A new instance of EffectiveAt.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(timestamp: nil, type: nil) ⇒ EffectiveAt
Returns a new instance of EffectiveAt.
417 418 419 420 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 417 def initialize(timestamp: nil, type: nil) @timestamp = @type = type end |
Instance Attribute Details
#timestamp ⇒ Object
The timestamp at which the subscribe action takes effect. Only present if type is timestamp.
413 414 415 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 413 def @timestamp end |
#type ⇒ Object
When the subscribe action takes effect.
415 416 417 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 415 def type @type end |