Class: Stripe::V2::Billing::IntentCreateParams::Action::Subscribe::PricingPlanSubscriptionDetails::Overrides::PartialPeriodBehavior

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/billing/intent_create_params.rb

Defined Under Namespace

Classes: LicenseFee, RecurringCreditGrant

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(type: nil, license_fee: nil, recurring_credit_grant: nil) ⇒ PartialPeriodBehavior

Returns a new instance of PartialPeriodBehavior.



462
463
464
465
466
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 462

def initialize(type: nil, license_fee: nil, recurring_credit_grant: nil)
  @type = type
  @license_fee = license_fee
  @recurring_credit_grant = recurring_credit_grant
end

Instance Attribute Details

#license_feeObject

Overrides the behavior for license fee components when the action takes effect during the service period.



458
459
460
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 458

def license_fee
  @license_fee
end

#recurring_credit_grantObject

Overrides the behavior for recurring credit grant components when the action takes effect during the service period.



460
461
462
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 460

def recurring_credit_grant
  @recurring_credit_grant
end

#typeObject

The type of behavior to override.



456
457
458
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 456

def type
  @type
end