Class: Stripe::V2::Billing::IntentCreateParams::CadenceData::BillingCycle::Month
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::IntentCreateParams::CadenceData::BillingCycle::Month
- Defined in:
- lib/stripe/params/v2/billing/intent_create_params.rb
Defined Under Namespace
Classes: Time
Instance Attribute Summary collapse
-
#day_of_month ⇒ Object
The day to anchor the billing on for a type=“month” billing cycle from 1-31.
-
#month_of_year ⇒ Object
The month to anchor the billing on for a type=“month” billing cycle from 1-12.
-
#time ⇒ Object
The time at which the billing cycle ends.
Instance Method Summary collapse
-
#initialize(day_of_month: nil, month_of_year: nil, time: nil) ⇒ Month
constructor
A new instance of Month.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(day_of_month: nil, month_of_year: nil, time: nil) ⇒ Month
Returns a new instance of Month.
667 668 669 670 671 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 667 def initialize(day_of_month: nil, month_of_year: nil, time: nil) @day_of_month = day_of_month @month_of_year = month_of_year @time = time end |
Instance Attribute Details
#day_of_month ⇒ Object
The day to anchor the billing on for a type=“month” billing cycle from 1-31. If this number is greater than the number of days in the month being billed, this anchors to the last day of the month. If not provided, this defaults to the day the cadence was created.
656 657 658 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 656 def day_of_month @day_of_month end |
#month_of_year ⇒ Object
The month to anchor the billing on for a type=“month” billing cycle from 1-12. If not provided, this defaults to the month the cadence was created. This setting can only be used for monthly billing cycles with ‘interval_count` of 2, 3, 4 or 6. All occurrences are calculated from the month provided.
661 662 663 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 661 def month_of_year @month_of_year end |
#time ⇒ Object
The time at which the billing cycle ends. This field is optional, and if not provided, it defaults to the time at which the cadence was created in UTC timezone.
665 666 667 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 665 def time @time end |