Class: Stripe::V2::Billing::IntentCreateParams::CadenceData::BillingCycle::Year
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::IntentCreateParams::CadenceData::BillingCycle::Year
- Defined in:
- lib/stripe/params/v2/billing/intent_create_params.rb
Defined Under Namespace
Classes: Time
Instance Attribute Summary collapse
-
#day_of_month ⇒ Object
The day to anchor the billing on for a type=“month” billing cycle from 1-31.
-
#month_of_year ⇒ Object
The month to bill on from 1-12.
-
#time ⇒ Object
The time at which the billing cycle ends.
Instance Method Summary collapse
-
#initialize(day_of_month: nil, month_of_year: nil, time: nil) ⇒ Year
constructor
A new instance of Year.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(day_of_month: nil, month_of_year: nil, time: nil) ⇒ Year
Returns a new instance of Year.
741 742 743 744 745 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 741 def initialize(day_of_month: nil, month_of_year: nil, time: nil) @day_of_month = day_of_month @month_of_year = month_of_year @time = time end |
Instance Attribute Details
#day_of_month ⇒ Object
The day to anchor the billing on for a type=“month” billing cycle from 1-31. If this number is greater than the number of days in the month being billed, this anchors to the last day of the month. If not provided, this defaults to the day the cadence was created.
732 733 734 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 732 def day_of_month @day_of_month end |
#month_of_year ⇒ Object
The month to bill on from 1-12. If not provided, this defaults to the month the cadence was created.
735 736 737 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 735 def month_of_year @month_of_year end |
#time ⇒ Object
The time at which the billing cycle ends. This field is optional, and if not provided, it defaults to the time at which the cadence was created in UTC timezone.
739 740 741 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 739 def time @time end |