Class: Stripe::V2::Billing::IntentCreateParams::CadenceData::Payer
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::IntentCreateParams::CadenceData::Payer
- Defined in:
- lib/stripe/params/v2/billing/intent_create_params.rb
Defined Under Namespace
Classes: BillingProfileData
Instance Attribute Summary collapse
-
#billing_profile ⇒ Object
The ID of the Billing Profile object which determines how a bill is paid.
-
#billing_profile_data ⇒ Object
Data for creating a new profile.
Instance Method Summary collapse
-
#initialize(billing_profile: nil, billing_profile_data: nil) ⇒ Payer
constructor
A new instance of Payer.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(billing_profile: nil, billing_profile_data: nil) ⇒ Payer
Returns a new instance of Payer.
798 799 800 801 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 798 def initialize(billing_profile: nil, billing_profile_data: nil) @billing_profile = billing_profile @billing_profile_data = billing_profile_data end |
Instance Attribute Details
#billing_profile ⇒ Object
The ID of the Billing Profile object which determines how a bill is paid.
794 795 796 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 794 def billing_profile @billing_profile end |
#billing_profile_data ⇒ Object
Data for creating a new profile.
796 797 798 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 796 def billing_profile_data @billing_profile_data end |