Class: Stripe::V2::Billing::IntentCreateParams::CadenceData::Settings::Bill

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/billing/intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(id: nil, version: nil) ⇒ Bill

Returns a new instance of Bill.



812
813
814
815
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 812

def initialize(id: nil, version: nil)
  @id = id
  @version = version
end

Instance Attribute Details

#idObject

The ID of the referenced settings object.



807
808
809
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 807

def id
  @id
end

#versionObject

An optional field to specify the version of the Settings to use. If not provided, this defaults to the live version any time the settings are used.



810
811
812
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 810

def version
  @version
end