Class: Stripe::V2::Billing::IntentCreateParams::CadenceData::Settings::Collection

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/billing/intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(id: nil, version: nil) ⇒ Collection

Returns a new instance of Collection.



822
823
824
825
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 822

def initialize(id: nil, version: nil)
  @id = id
  @version = version
end

Instance Attribute Details

#idObject

The ID of the referenced settings object.



817
818
819
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 817

def id
  @id
end

#versionObject

An optional field to specify the version of the Settings to use. If not provided, this will always default to the live version any time the settings are used.



820
821
822
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 820

def version
  @version
end