Class: Stripe::V2::Billing::IntentService::CreateParams::Action::Deactivate::EffectiveAt
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::IntentService::CreateParams::Action::Deactivate::EffectiveAt
- Defined in:
- lib/stripe/services/v2/billing/intent_service.rb
Instance Attribute Summary collapse
-
#timestamp ⇒ Object
The timestamp at which the deactivate action will take effect.
-
#type ⇒ Object
When the deactivate action will take effect.
Instance Method Summary collapse
-
#initialize(timestamp: nil, type: nil) ⇒ EffectiveAt
constructor
A new instance of EffectiveAt.
Methods inherited from RequestParams
Constructor Details
#initialize(timestamp: nil, type: nil) ⇒ EffectiveAt
Returns a new instance of EffectiveAt.
87 88 89 90 |
# File 'lib/stripe/services/v2/billing/intent_service.rb', line 87 def initialize(timestamp: nil, type: nil) @timestamp = @type = type end |
Instance Attribute Details
#timestamp ⇒ Object
The timestamp at which the deactivate action will take effect. Only present if type is timestamp.
83 84 85 |
# File 'lib/stripe/services/v2/billing/intent_service.rb', line 83 def @timestamp end |
#type ⇒ Object
When the deactivate action will take effect.
85 86 87 |
# File 'lib/stripe/services/v2/billing/intent_service.rb', line 85 def type @type end |