Class: Stripe::V2::Billing::IntentService::CreateParams::Action::Modify::EffectiveAt
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::IntentService::CreateParams::Action::Modify::EffectiveAt
- Defined in:
- lib/stripe/services/v2/billing/intent_service.rb
Instance Attribute Summary collapse
-
#timestamp ⇒ Object
The timestamp at which the modify action will take effect.
-
#type ⇒ Object
When the modify action will take effect.
Instance Method Summary collapse
-
#initialize(timestamp: nil, type: nil) ⇒ EffectiveAt
constructor
A new instance of EffectiveAt.
Methods inherited from RequestParams
Constructor Details
#initialize(timestamp: nil, type: nil) ⇒ EffectiveAt
Returns a new instance of EffectiveAt.
139 140 141 142 |
# File 'lib/stripe/services/v2/billing/intent_service.rb', line 139 def initialize(timestamp: nil, type: nil) @timestamp = @type = type end |
Instance Attribute Details
#timestamp ⇒ Object
The timestamp at which the modify action will take effect. Only present if type is timestamp.
135 136 137 |
# File 'lib/stripe/services/v2/billing/intent_service.rb', line 135 def @timestamp end |
#type ⇒ Object
When the modify action will take effect.
137 138 139 |
# File 'lib/stripe/services/v2/billing/intent_service.rb', line 137 def type @type end |