Class: Stripe::V2::Billing::IntentService::CreateParams::Action::Modify::PricingPlanSubscriptionDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/billing/intent_service.rb

Defined Under Namespace

Classes: ComponentConfiguration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(component_configurations: nil, new_pricing_plan: nil, new_pricing_plan_version: nil, pricing_plan_subscription: nil) ⇒ PricingPlanSubscriptionDetails

Returns a new instance of PricingPlanSubscriptionDetails.



169
170
171
172
173
174
175
176
177
178
179
# File 'lib/stripe/services/v2/billing/intent_service.rb', line 169

def initialize(
  component_configurations: nil,
  new_pricing_plan: nil,
  new_pricing_plan_version: nil,
  pricing_plan_subscription: nil
)
  @component_configurations = component_configurations
  @new_pricing_plan = new_pricing_plan
  @new_pricing_plan_version = new_pricing_plan_version
  @pricing_plan_subscription = pricing_plan_subscription
end

Instance Attribute Details

#component_configurationsObject

New configurations for the components of the pricing plan.



161
162
163
# File 'lib/stripe/services/v2/billing/intent_service.rb', line 161

def component_configurations
  @component_configurations
end

#new_pricing_planObject

The ID of the new Pricing Plan, if changing plans.



163
164
165
# File 'lib/stripe/services/v2/billing/intent_service.rb', line 163

def new_pricing_plan
  @new_pricing_plan
end

#new_pricing_plan_versionObject

The ID of the new Pricing Plan Version to use.



165
166
167
# File 'lib/stripe/services/v2/billing/intent_service.rb', line 165

def new_pricing_plan_version
  @new_pricing_plan_version
end

#pricing_plan_subscriptionObject

The ID of the Pricing Plan Subscription to modify.



167
168
169
# File 'lib/stripe/services/v2/billing/intent_service.rb', line 167

def pricing_plan_subscription
  @pricing_plan_subscription
end