Class: Stripe::V2::Billing::IntentService::CreateParams::Action::Subscribe::V1SubscriptionDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/billing/intent_service.rb

Defined Under Namespace

Classes: Item

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, items: nil, metadata: nil) ⇒ V1SubscriptionDetails

Returns a new instance of V1SubscriptionDetails.



297
298
299
300
301
# File 'lib/stripe/services/v2/billing/intent_service.rb', line 297

def initialize(description: nil, items: nil, metadata: nil)
  @description = description
  @items = items
  @metadata = 
end

Instance Attribute Details

#descriptionObject

The subscription’s description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.



291
292
293
# File 'lib/stripe/services/v2/billing/intent_service.rb', line 291

def description
  @description
end

#itemsObject

A list of up to 20 subscription items, each with an attached price.



293
294
295
# File 'lib/stripe/services/v2/billing/intent_service.rb', line 293

def items
  @items
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



295
296
297
# File 'lib/stripe/services/v2/billing/intent_service.rb', line 295

def 
  @metadata
end