Class: Stripe::V2::Billing::IntentService::CreateParams::Action::Subscribe::V1SubscriptionDetails::Item

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/billing/intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(metadata: nil, price: nil, quantity: nil) ⇒ Item

Returns a new instance of Item.



283
284
285
286
287
# File 'lib/stripe/services/v2/billing/intent_service.rb', line 283

def initialize(metadata: nil, price: nil, quantity: nil)
  @metadata = 
  @price = price
  @quantity = quantity
end

Instance Attribute Details

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



277
278
279
# File 'lib/stripe/services/v2/billing/intent_service.rb', line 277

def 
  @metadata
end

#priceObject

The ID of the price object.



279
280
281
# File 'lib/stripe/services/v2/billing/intent_service.rb', line 279

def price
  @price
end

#quantityObject

Quantity for this item. If not provided, will default to 1.



281
282
283
# File 'lib/stripe/services/v2/billing/intent_service.rb', line 281

def quantity
  @quantity
end