Class: Stripe::V2::Billing::LicenseFee::Tier

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/v2/billing/license_fee.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#flat_amountObject (readonly)

Price for the entire tier, represented as a decimal string in minor currency units with at most 12 decimal places.



34
35
36
# File 'lib/stripe/resources/v2/billing/license_fee.rb', line 34

def flat_amount
  @flat_amount
end

#unit_amountObject (readonly)

Per-unit price for units included in this tier, represented as a decimal string in minor currency units with at most 12 decimal places.



37
38
39
# File 'lib/stripe/resources/v2/billing/license_fee.rb', line 37

def unit_amount
  @unit_amount
end

#up_to_decimalObject (readonly)

Up to and including this quantity will be contained in the tier. Only one of ‘up_to_decimal` and `up_to_inf` may be set.



40
41
42
# File 'lib/stripe/resources/v2/billing/license_fee.rb', line 40

def up_to_decimal
  @up_to_decimal
end

#up_to_infObject (readonly)

No upper bound to this tier. Only one of ‘up_to_decimal` and `up_to_inf` may be set.



42
43
44
# File 'lib/stripe/resources/v2/billing/license_fee.rb', line 42

def up_to_inf
  @up_to_inf
end

Class Method Details

.field_encodingsObject



52
53
54
# File 'lib/stripe/resources/v2/billing/license_fee.rb', line 52

def self.field_encodings
  @field_encodings = { up_to_decimal: :decimal_string }
end

.field_remappingsObject



48
49
50
# File 'lib/stripe/resources/v2/billing/license_fee.rb', line 48

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



44
45
46
# File 'lib/stripe/resources/v2/billing/license_fee.rb', line 44

def self.inner_class_types
  @inner_class_types = {}
end