Class: Stripe::V2::Billing::LicenseFeeCreateParams::Tier
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::LicenseFeeCreateParams::Tier
- Defined in:
- lib/stripe/params/v2/billing/license_fee_create_params.rb
Instance Attribute Summary collapse
-
#flat_amount ⇒ Object
Price for the entire tier, represented as a decimal string in minor currency units with at most 12 decimal places.
-
#unit_amount ⇒ Object
Per-unit price for units included in this tier, represented as a decimal string in minor currency units with at most 12 decimal places.
-
#up_to_decimal ⇒ Object
Up to and including this quantity is contained in the tier.
-
#up_to_inf ⇒ Object
No upper bound to this tier.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(flat_amount: nil, unit_amount: nil, up_to_decimal: nil, up_to_inf: nil) ⇒ Tier
constructor
A new instance of Tier.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(flat_amount: nil, unit_amount: nil, up_to_decimal: nil, up_to_inf: nil) ⇒ Tier
Returns a new instance of Tier.
20 21 22 23 24 25 |
# File 'lib/stripe/params/v2/billing/license_fee_create_params.rb', line 20 def initialize(flat_amount: nil, unit_amount: nil, up_to_decimal: nil, up_to_inf: nil) @flat_amount = flat_amount @unit_amount = unit_amount @up_to_decimal = up_to_decimal @up_to_inf = up_to_inf end |
Instance Attribute Details
#flat_amount ⇒ Object
Price for the entire tier, represented as a decimal string in minor currency units with at most 12 decimal places.
10 11 12 |
# File 'lib/stripe/params/v2/billing/license_fee_create_params.rb', line 10 def flat_amount @flat_amount end |
#unit_amount ⇒ Object
Per-unit price for units included in this tier, represented as a decimal string in minor currency units with at most 12 decimal places.
13 14 15 |
# File 'lib/stripe/params/v2/billing/license_fee_create_params.rb', line 13 def unit_amount @unit_amount end |
#up_to_decimal ⇒ Object
Up to and including this quantity is contained in the tier. Only one of ‘up_to_decimal` and `up_to_inf` may be set.
16 17 18 |
# File 'lib/stripe/params/v2/billing/license_fee_create_params.rb', line 16 def up_to_decimal @up_to_decimal end |
#up_to_inf ⇒ Object
No upper bound to this tier. Only one of ‘up_to_decimal` and `up_to_inf` may be set.
18 19 20 |
# File 'lib/stripe/params/v2/billing/license_fee_create_params.rb', line 18 def up_to_inf @up_to_inf end |
Class Method Details
.field_encodings ⇒ Object
27 28 29 |
# File 'lib/stripe/params/v2/billing/license_fee_create_params.rb', line 27 def self.field_encodings @field_encodings = { up_to_decimal: :decimal_string } end |