Class: Stripe::V2::Billing::LicenseFeeListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::LicenseFeeListParams
- Defined in:
- lib/stripe/params/v2/billing/license_fee_list_params.rb
Instance Attribute Summary collapse
-
#licensed_item ⇒ Object
Filter by licensed item.
-
#limit ⇒ Object
Optionally set the maximum number of results per page.
-
#lookup_keys ⇒ Object
Filter by lookup keys.
Instance Method Summary collapse
-
#initialize(licensed_item: nil, limit: nil, lookup_keys: nil) ⇒ LicenseFeeListParams
constructor
A new instance of LicenseFeeListParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(licensed_item: nil, limit: nil, lookup_keys: nil) ⇒ LicenseFeeListParams
Returns a new instance of LicenseFeeListParams.
16 17 18 19 20 |
# File 'lib/stripe/params/v2/billing/license_fee_list_params.rb', line 16 def initialize(licensed_item: nil, limit: nil, lookup_keys: nil) @licensed_item = licensed_item @limit = limit @lookup_keys = lookup_keys end |
Instance Attribute Details
#licensed_item ⇒ Object
Filter by licensed item.
9 10 11 |
# File 'lib/stripe/params/v2/billing/license_fee_list_params.rb', line 9 def licensed_item @licensed_item end |
#limit ⇒ Object
Optionally set the maximum number of results per page. Defaults to 20.
11 12 13 |
# File 'lib/stripe/params/v2/billing/license_fee_list_params.rb', line 11 def limit @limit end |
#lookup_keys ⇒ Object
Filter by lookup keys. You can specify up to 10 lookup keys.
14 15 16 |
# File 'lib/stripe/params/v2/billing/license_fee_list_params.rb', line 14 def lookup_keys @lookup_keys end |