Class: Stripe::V2::Billing::LicenseFeeService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::LicenseFeeService::CreateParams
- Defined in:
- lib/stripe/services/v2/billing/license_fee_service.rb
Defined Under Namespace
Classes: Tier, TransformQuantity
Instance Attribute Summary collapse
-
#currency ⇒ Object
Three-letter ISO currency code, in lowercase.
-
#display_name ⇒ Object
A customer-facing name for the License Fee.
-
#licensed_item ⇒ Object
The Licensed Item that this License Fee binds to.
-
#lookup_key ⇒ Object
An internal key you can use to search for a particular license fee.
-
#metadata ⇒ Object
Set of [key-value pairs](/docs/api/metadata) that you can attach to an object.
-
#service_interval ⇒ Object
The interval for assessing service.
-
#service_interval_count ⇒ Object
The length of the interval for assessing service.
-
#tax_behavior ⇒ Object
The Stripe Tax tax behavior - whether the license fee is inclusive or exclusive of tax.
-
#tiering_mode ⇒ Object
Defines whether the tiered price should be graduated or volume-based.
-
#tiers ⇒ Object
Each element represents a pricing tier.
-
#transform_quantity ⇒ Object
Apply a transformation to the reported usage or set quantity before computing the amount billed.
-
#unit_amount ⇒ Object
The per-unit amount to be charged, represented as a decimal string in minor currency units with at most 12 decimal places.
Instance Method Summary collapse
-
#initialize(currency: nil, display_name: nil, licensed_item: nil, lookup_key: nil, metadata: nil, service_interval: nil, service_interval_count: nil, tax_behavior: nil, tiering_mode: nil, tiers: nil, transform_quantity: nil, unit_amount: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(currency: nil, display_name: nil, licensed_item: nil, lookup_key: nil, metadata: nil, service_interval: nil, service_interval_count: nil, tax_behavior: nil, tiering_mode: nil, tiers: nil, transform_quantity: nil, unit_amount: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/stripe/services/v2/billing/license_fee_service.rb', line 97 def initialize( currency: nil, display_name: nil, licensed_item: nil, lookup_key: nil, metadata: nil, service_interval: nil, service_interval_count: nil, tax_behavior: nil, tiering_mode: nil, tiers: nil, transform_quantity: nil, unit_amount: nil ) @currency = currency @display_name = display_name @licensed_item = licensed_item @lookup_key = lookup_key @metadata = @service_interval = service_interval @service_interval_count = service_interval_count @tax_behavior = tax_behavior @tiering_mode = tiering_mode @tiers = tiers @transform_quantity = transform_quantity @unit_amount = unit_amount end |
Instance Attribute Details
#currency ⇒ Object
Three-letter ISO currency code, in lowercase. Must be a supported currency.
64 65 66 |
# File 'lib/stripe/services/v2/billing/license_fee_service.rb', line 64 def currency @currency end |
#display_name ⇒ Object
A customer-facing name for the License Fee. This name is used in Stripe-hosted products like the Customer Portal and Checkout. It does not show up on Invoices. Maximum length of 250 characters.
68 69 70 |
# File 'lib/stripe/services/v2/billing/license_fee_service.rb', line 68 def display_name @display_name end |
#licensed_item ⇒ Object
The Licensed Item that this License Fee binds to.
70 71 72 |
# File 'lib/stripe/services/v2/billing/license_fee_service.rb', line 70 def licensed_item @licensed_item end |
#lookup_key ⇒ Object
An internal key you can use to search for a particular license fee. Maximum length of 200 characters.
72 73 74 |
# File 'lib/stripe/services/v2/billing/license_fee_service.rb', line 72 def lookup_key @lookup_key end |
#metadata ⇒ Object
Set of [key-value pairs](/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
74 75 76 |
# File 'lib/stripe/services/v2/billing/license_fee_service.rb', line 74 def @metadata end |
#service_interval ⇒ Object
The interval for assessing service. For example, a monthly license fee with a rate of $1 for the first 10 “workloads” and $2 thereafter means “$1 per workload up to 10 workloads during a month of service.” This is similar to but distinct from billing interval; the service interval deals with the rate at which the customer accumulates fees, while the billing interval in Cadence deals with the rate the customer is billed.
79 80 81 |
# File 'lib/stripe/services/v2/billing/license_fee_service.rb', line 79 def service_interval @service_interval end |
#service_interval_count ⇒ Object
The length of the interval for assessing service. For example, set this to 3 and ‘service_interval` to `“month”` in order to specify quarterly service.
82 83 84 |
# File 'lib/stripe/services/v2/billing/license_fee_service.rb', line 82 def service_interval_count @service_interval_count end |
#tax_behavior ⇒ Object
The Stripe Tax tax behavior - whether the license fee is inclusive or exclusive of tax.
84 85 86 |
# File 'lib/stripe/services/v2/billing/license_fee_service.rb', line 84 def tax_behavior @tax_behavior end |
#tiering_mode ⇒ Object
Defines whether the tiered price should be graduated or volume-based. In volume-based tiering, the maximum quantity within a period determines the per-unit price. In graduated tiering, the pricing changes as the quantity grows into new tiers. Can only be set if ‘tiers` is set.
88 89 90 |
# File 'lib/stripe/services/v2/billing/license_fee_service.rb', line 88 def tiering_mode @tiering_mode end |
#tiers ⇒ Object
Each element represents a pricing tier. Cannot be set if ‘unit_amount` is provided.
90 91 92 |
# File 'lib/stripe/services/v2/billing/license_fee_service.rb', line 90 def tiers @tiers end |
#transform_quantity ⇒ Object
Apply a transformation to the reported usage or set quantity before computing the amount billed.
92 93 94 |
# File 'lib/stripe/services/v2/billing/license_fee_service.rb', line 92 def transform_quantity @transform_quantity end |
#unit_amount ⇒ Object
The per-unit amount to be charged, represented as a decimal string in minor currency units with at most 12 decimal places. Cannot be set if ‘tiers` is provided.
95 96 97 |
# File 'lib/stripe/services/v2/billing/license_fee_service.rb', line 95 def unit_amount @unit_amount end |