Class: Stripe::V2::Billing::LicenseFeeService::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::LicenseFeeService::ListParams
- Defined in:
- lib/stripe/services/v2/billing/license_fee_service.rb
Instance Attribute Summary collapse
-
#licensed_item ⇒ Object
Filter by licensed item.
-
#limit ⇒ Object
Optionally set the maximum number of results per page.
-
#lookup_keys ⇒ Object
Filter by lookup keys.
Instance Method Summary collapse
-
#initialize(licensed_item: nil, limit: nil, lookup_keys: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(licensed_item: nil, limit: nil, lookup_keys: nil) ⇒ ListParams
Returns a new instance of ListParams.
24 25 26 27 28 |
# File 'lib/stripe/services/v2/billing/license_fee_service.rb', line 24 def initialize(licensed_item: nil, limit: nil, lookup_keys: nil) @licensed_item = licensed_item @limit = limit @lookup_keys = lookup_keys end |
Instance Attribute Details
#licensed_item ⇒ Object
Filter by licensed item.
17 18 19 |
# File 'lib/stripe/services/v2/billing/license_fee_service.rb', line 17 def licensed_item @licensed_item end |
#limit ⇒ Object
Optionally set the maximum number of results per page. Defaults to 20.
19 20 21 |
# File 'lib/stripe/services/v2/billing/license_fee_service.rb', line 19 def limit @limit end |
#lookup_keys ⇒ Object
Filter by lookup keys. You can specify up to 10 lookup keys.
22 23 24 |
# File 'lib/stripe/services/v2/billing/license_fee_service.rb', line 22 def lookup_keys @lookup_keys end |