Class: Stripe::V2::Billing::LicenseFeeService::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/billing/license_fee_service.rb

Defined Under Namespace

Classes: Tier, TransformQuantity

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(display_name: nil, live_version: nil, lookup_key: nil, metadata: nil, tiering_mode: nil, tiers: nil, transform_quantity: nil, unit_amount: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/stripe/services/v2/billing/license_fee_service.rb', line 183

def initialize(
  display_name: nil,
  live_version: nil,
  lookup_key: nil,
  metadata: nil,
  tiering_mode: nil,
  tiers: nil,
  transform_quantity: nil,
  unit_amount: nil
)
  @display_name = display_name
  @live_version = live_version
  @lookup_key = lookup_key
  @metadata = 
  @tiering_mode = tiering_mode
  @tiers = tiers
  @transform_quantity = transform_quantity
  @unit_amount = unit_amount
end

Instance Attribute Details

#display_nameObject

A customer-facing name for the License Fee. This name is used in Stripe-hosted products like the Customer Portal and Checkout. It does not show up on Invoices. Maximum length of 250 characters.



163
164
165
# File 'lib/stripe/services/v2/billing/license_fee_service.rb', line 163

def display_name
  @display_name
end

#live_versionObject

Changes the version that new license fee will use. Providing ‘live_version = “latest”` will set the license fee’s ‘live_version` to its latest version.



166
167
168
# File 'lib/stripe/services/v2/billing/license_fee_service.rb', line 166

def live_version
  @live_version
end

#lookup_keyObject

An internal key you can use to search for a particular license fee. Maximum length of 200 characters.



168
169
170
# File 'lib/stripe/services/v2/billing/license_fee_service.rb', line 168

def lookup_key
  @lookup_key
end

#metadataObject

Set of [key-value pairs](/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



170
171
172
# File 'lib/stripe/services/v2/billing/license_fee_service.rb', line 170

def 
  @metadata
end

#tiering_modeObject

Defines whether the tiered price should be graduated or volume-based. In volume-based tiering, the maximum quantity within a period determines the per-unit price. In graduated tiering, the pricing changes as the quantity grows into new tiers. Can only be set if ‘tiers` is set.



174
175
176
# File 'lib/stripe/services/v2/billing/license_fee_service.rb', line 174

def tiering_mode
  @tiering_mode
end

#tiersObject

Each element represents a pricing tier. Cannot be set if ‘unit_amount` is provided.



176
177
178
# File 'lib/stripe/services/v2/billing/license_fee_service.rb', line 176

def tiers
  @tiers
end

#transform_quantityObject

Apply a transformation to the reported usage or set quantity before computing the amount billed.



178
179
180
# File 'lib/stripe/services/v2/billing/license_fee_service.rb', line 178

def transform_quantity
  @transform_quantity
end

#unit_amountObject

The per-unit amount to be charged, represented as a decimal string in minor currency units with at most 12 decimal places. Cannot be set if ‘tiers` is provided.



181
182
183
# File 'lib/stripe/services/v2/billing/license_fee_service.rb', line 181

def unit_amount
  @unit_amount
end