Class: Stripe::V2::Billing::LicenseFeeVersion::Tier
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::LicenseFeeVersion::Tier
- Defined in:
- lib/stripe/resources/v2/billing/license_fee_version.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#flat_amount ⇒ Object
readonly
Price for the entire tier, represented as a decimal string in minor currency units with at most 12 decimal places.
-
#unit_amount ⇒ Object
readonly
Per-unit price for units included in this tier, represented as a decimal string in minor currency units with at most 12 decimal places.
-
#up_to_decimal ⇒ Object
readonly
Up to and including this quantity is contained in the tier.
-
#up_to_inf ⇒ Object
readonly
No upper bound to this tier.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#flat_amount ⇒ Object (readonly)
Price for the entire tier, represented as a decimal string in minor currency units with at most 12 decimal places.
18 19 20 |
# File 'lib/stripe/resources/v2/billing/license_fee_version.rb', line 18 def flat_amount @flat_amount end |
#unit_amount ⇒ Object (readonly)
Per-unit price for units included in this tier, represented as a decimal string in minor currency units with at most 12 decimal places.
21 22 23 |
# File 'lib/stripe/resources/v2/billing/license_fee_version.rb', line 21 def unit_amount @unit_amount end |
#up_to_decimal ⇒ Object (readonly)
Up to and including this quantity is contained in the tier. Only one of ‘up_to_decimal` and `up_to_inf` may be set.
24 25 26 |
# File 'lib/stripe/resources/v2/billing/license_fee_version.rb', line 24 def up_to_decimal @up_to_decimal end |
#up_to_inf ⇒ Object (readonly)
No upper bound to this tier. Only one of ‘up_to_decimal` and `up_to_inf` may be set.
26 27 28 |
# File 'lib/stripe/resources/v2/billing/license_fee_version.rb', line 26 def up_to_inf @up_to_inf end |
Class Method Details
.field_encodings ⇒ Object
36 37 38 |
# File 'lib/stripe/resources/v2/billing/license_fee_version.rb', line 36 def self.field_encodings @field_encodings = { up_to_decimal: :decimal_string } end |
.field_remappings ⇒ Object
32 33 34 |
# File 'lib/stripe/resources/v2/billing/license_fee_version.rb', line 32 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
28 29 30 |
# File 'lib/stripe/resources/v2/billing/license_fee_version.rb', line 28 def self.inner_class_types @inner_class_types = {} end |