Class: Stripe::V2::Billing::LicensedItem

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/billing/licensed_item.rb

Overview

A Licensed Item represents a billable item whose pricing is based on license fees. You can use license fees to specify the pricing and create subscriptions to these items.

Defined Under Namespace

Classes: TaxDetails

Constant Summary collapse

OBJECT_NAME =
"v2.billing.licensed_item"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#createdObject (readonly)

Timestamp of when the object was created.



28
29
30
# File 'lib/stripe/resources/v2/billing/licensed_item.rb', line 28

def created
  @created
end

#display_nameObject (readonly)

Description that customers see in the invoice line item. Maximum length of 250 characters.



31
32
33
# File 'lib/stripe/resources/v2/billing/licensed_item.rb', line 31

def display_name
  @display_name
end

#idObject (readonly)

Unique identifier for the object.



33
34
35
# File 'lib/stripe/resources/v2/billing/licensed_item.rb', line 33

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



35
36
37
# File 'lib/stripe/resources/v2/billing/licensed_item.rb', line 35

def livemode
  @livemode
end

#lookup_keyObject (readonly)

An internal key you can use to search for a particular licensed item. Maximum length of 200 characters.



38
39
40
# File 'lib/stripe/resources/v2/billing/licensed_item.rb', line 38

def lookup_key
  @lookup_key
end

#metadataObject (readonly)

Set of [key-value pairs](/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



40
41
42
# File 'lib/stripe/resources/v2/billing/licensed_item.rb', line 40

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



42
43
44
# File 'lib/stripe/resources/v2/billing/licensed_item.rb', line 42

def object
  @object
end

#tax_detailsObject (readonly)

Stripe Tax details.



44
45
46
# File 'lib/stripe/resources/v2/billing/licensed_item.rb', line 44

def tax_details
  @tax_details
end

#unit_labelObject (readonly)

The unit to use when displaying prices for this billable item in places like Checkout. For example, set this field to “seat” for Checkout to display “(price) per seat”, or “environment” to display “(price) per environment”. Maximum length of 100 characters.



48
49
50
# File 'lib/stripe/resources/v2/billing/licensed_item.rb', line 48

def unit_label
  @unit_label
end

Class Method Details

.field_remappingsObject



54
55
56
# File 'lib/stripe/resources/v2/billing/licensed_item.rb', line 54

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



50
51
52
# File 'lib/stripe/resources/v2/billing/licensed_item.rb', line 50

def self.inner_class_types
  @inner_class_types = { tax_details: TaxDetails }
end

.object_nameObject



11
12
13
# File 'lib/stripe/resources/v2/billing/licensed_item.rb', line 11

def self.object_name
  "v2.billing.licensed_item"
end