Class: Stripe::V2::Billing::LicensedItemService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::V2::Billing::LicensedItemService
- Defined in:
- lib/stripe/services/v2/billing/licensed_item_service.rb
Instance Method Summary collapse
-
#create(params = {}, opts = {}) ⇒ Object
Create a Licensed Item object.
-
#list(params = {}, opts = {}) ⇒ Object
List all Licensed Item objects in reverse chronological order of creation.
-
#retrieve(id, params = {}, opts = {}) ⇒ Object
Retrieve a Licensed Item object.
-
#update(id, params = {}, opts = {}) ⇒ Object
Update a Licensed Item object.
Methods inherited from StripeService
#initialize, #request, #request_stream
Constructor Details
This class inherits a constructor from Stripe::StripeService
Instance Method Details
#create(params = {}, opts = {}) ⇒ Object
Create a Licensed Item object.
9 10 11 12 13 14 15 16 17 |
# File 'lib/stripe/services/v2/billing/licensed_item_service.rb', line 9 def create(params = {}, opts = {}) request( method: :post, path: "/v2/billing/licensed_items", params: params, opts: opts, base_address: :api ) end |
#list(params = {}, opts = {}) ⇒ Object
List all Licensed Item objects in reverse chronological order of creation.
20 21 22 23 24 25 26 27 28 |
# File 'lib/stripe/services/v2/billing/licensed_item_service.rb', line 20 def list(params = {}, opts = {}) request( method: :get, path: "/v2/billing/licensed_items", params: params, opts: opts, base_address: :api ) end |
#retrieve(id, params = {}, opts = {}) ⇒ Object
Retrieve a Licensed Item object.
31 32 33 34 35 36 37 38 39 |
# File 'lib/stripe/services/v2/billing/licensed_item_service.rb', line 31 def retrieve(id, params = {}, opts = {}) request( method: :get, path: format("/v2/billing/licensed_items/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |
#update(id, params = {}, opts = {}) ⇒ Object
Update a Licensed Item object. At least one of the fields is required.
42 43 44 45 46 47 48 49 50 |
# File 'lib/stripe/services/v2/billing/licensed_item_service.rb', line 42 def update(id, params = {}, opts = {}) request( method: :post, path: format("/v2/billing/licensed_items/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |