Class: Stripe::V2::Billing::LicensedItemService::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::LicensedItemService::UpdateParams
- Defined in:
- lib/stripe/services/v2/billing/licensed_item_service.rb
Defined Under Namespace
Classes: TaxDetails
Instance Attribute Summary collapse
-
#display_name ⇒ Object
Description that customers will see in the invoice line item.
-
#lookup_key ⇒ Object
An internal key you can use to search for a particular billable item.
-
#metadata ⇒ Object
Set of [key-value pairs](/docs/api/metadata) that you can attach to an object.
-
#tax_details ⇒ Object
Stripe Tax details.
-
#unit_label ⇒ Object
The unit to use when displaying prices for this billable item in places like Checkout.
Instance Method Summary collapse
-
#initialize(display_name: nil, lookup_key: nil, metadata: nil, tax_details: nil, unit_label: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(display_name: nil, lookup_key: nil, metadata: nil, tax_details: nil, unit_label: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/stripe/services/v2/billing/licensed_item_service.rb', line 88 def initialize( display_name: nil, lookup_key: nil, metadata: nil, tax_details: nil, unit_label: nil ) @display_name = display_name @lookup_key = lookup_key @metadata = @tax_details = tax_details @unit_label = unit_label end |
Instance Attribute Details
#display_name ⇒ Object
Description that customers will see in the invoice line item. Maximum length of 250 characters.
74 75 76 |
# File 'lib/stripe/services/v2/billing/licensed_item_service.rb', line 74 def display_name @display_name end |
#lookup_key ⇒ Object
An internal key you can use to search for a particular billable item. Maximum length of 200 characters. To remove the lookup_key from the object, set it to null in the request.
78 79 80 |
# File 'lib/stripe/services/v2/billing/licensed_item_service.rb', line 78 def lookup_key @lookup_key end |
#metadata ⇒ Object
Set of [key-value pairs](/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
80 81 82 |
# File 'lib/stripe/services/v2/billing/licensed_item_service.rb', line 80 def @metadata end |
#tax_details ⇒ Object
Stripe Tax details.
82 83 84 |
# File 'lib/stripe/services/v2/billing/licensed_item_service.rb', line 82 def tax_details @tax_details end |
#unit_label ⇒ Object
The unit to use when displaying prices for this billable item in places like Checkout. For example, set this field to “seat” for Checkout to display “(price) per seat”, or “environment” to display “(price) per environment”. Maximum length of 100 characters.
86 87 88 |
# File 'lib/stripe/services/v2/billing/licensed_item_service.rb', line 86 def unit_label @unit_label end |