Class: Stripe::V2::Billing::LicensedItemUpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::LicensedItemUpdateParams
- Defined in:
- lib/stripe/params/v2/billing/licensed_item_update_params.rb
Defined Under Namespace
Classes: TaxDetails
Instance Attribute Summary collapse
-
#display_name ⇒ Object
Description that customers see in the invoice line item.
-
#lookup_key ⇒ Object
An internal key you can use to search for a particular licensed item.
-
#metadata ⇒ Object
Set of [key-value pairs](/docs/api/metadata) that you can attach to an object.
-
#tax_details ⇒ Object
Stripe Tax details.
-
#unit_label ⇒ Object
The unit to use when displaying prices for this billable item in places like Checkout.
Instance Method Summary collapse
-
#initialize(display_name: nil, lookup_key: nil, metadata: nil, tax_details: nil, unit_label: nil) ⇒ LicensedItemUpdateParams
constructor
A new instance of LicensedItemUpdateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(display_name: nil, lookup_key: nil, metadata: nil, tax_details: nil, unit_label: nil) ⇒ LicensedItemUpdateParams
Returns a new instance of LicensedItemUpdateParams.
32 33 34 35 36 37 38 39 40 41 42 43 44 |
# File 'lib/stripe/params/v2/billing/licensed_item_update_params.rb', line 32 def initialize( display_name: nil, lookup_key: nil, metadata: nil, tax_details: nil, unit_label: nil ) @display_name = display_name @lookup_key = lookup_key @metadata = @tax_details = tax_details @unit_label = unit_label end |
Instance Attribute Details
#display_name ⇒ Object
Description that customers see in the invoice line item. Maximum length of 250 characters.
18 19 20 |
# File 'lib/stripe/params/v2/billing/licensed_item_update_params.rb', line 18 def display_name @display_name end |
#lookup_key ⇒ Object
An internal key you can use to search for a particular licensed item. Maximum length of 200 characters. To remove the lookup_key from the object, set it to null in the request.
22 23 24 |
# File 'lib/stripe/params/v2/billing/licensed_item_update_params.rb', line 22 def lookup_key @lookup_key end |
#metadata ⇒ Object
Set of [key-value pairs](/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
24 25 26 |
# File 'lib/stripe/params/v2/billing/licensed_item_update_params.rb', line 24 def @metadata end |
#tax_details ⇒ Object
Stripe Tax details.
26 27 28 |
# File 'lib/stripe/params/v2/billing/licensed_item_update_params.rb', line 26 def tax_details @tax_details end |
#unit_label ⇒ Object
The unit to use when displaying prices for this billable item in places like Checkout. For example, set this field to “seat” for Checkout to display “(price) per seat”, or “environment” to display “(price) per environment”. Maximum length of 100 characters.
30 31 32 |
# File 'lib/stripe/params/v2/billing/licensed_item_update_params.rb', line 30 def unit_label @unit_label end |