Class: Stripe::V2::Billing::MeterEventAdjustmentService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::MeterEventAdjustmentService::CreateParams
- Defined in:
- lib/stripe/services/v2/billing/meter_event_adjustment_service.rb
Defined Under Namespace
Classes: Cancel
Instance Attribute Summary collapse
-
#cancel ⇒ Object
Specifies which event to cancel.
-
#event_name ⇒ Object
The name of the meter event.
-
#type ⇒ Object
Specifies whether to cancel a single event or a range of events for a time period.
Instance Method Summary collapse
-
#initialize(cancel: nil, event_name: nil, type: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(cancel: nil, event_name: nil, type: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
26 27 28 29 30 |
# File 'lib/stripe/services/v2/billing/meter_event_adjustment_service.rb', line 26 def initialize(cancel: nil, event_name: nil, type: nil) @cancel = cancel @event_name = event_name @type = type end |
Instance Attribute Details
#cancel ⇒ Object
Specifies which event to cancel.
18 19 20 |
# File 'lib/stripe/services/v2/billing/meter_event_adjustment_service.rb', line 18 def cancel @cancel end |
#event_name ⇒ Object
The name of the meter event. Corresponds with the ‘event_name` field on a meter.
21 22 23 |
# File 'lib/stripe/services/v2/billing/meter_event_adjustment_service.rb', line 21 def event_name @event_name end |
#type ⇒ Object
Specifies whether to cancel a single event or a range of events for a time period. Time period cancellation is not supported yet.
24 25 26 |
# File 'lib/stripe/services/v2/billing/meter_event_adjustment_service.rb', line 24 def type @type end |