Class: Stripe::V2::Billing::MeteredItemService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::MeteredItemService::CreateParams
- Defined in:
- lib/stripe/services/v2/billing/metered_item_service.rb
Defined Under Namespace
Classes: MeterSegmentCondition, TaxDetails
Instance Attribute Summary collapse
-
#display_name ⇒ Object
Description that customers will see in the invoice line item.
-
#invoice_presentation_dimensions ⇒ Object
Optional array of Meter dimensions to group event dimension keys for invoice line items.
-
#lookup_key ⇒ Object
An internal key you can use to search for a particular billable item.
-
#metadata ⇒ Object
Set of [key-value pairs](/docs/api/metadata) that you can attach to an object.
-
#meter ⇒ Object
ID of the Meter that measures usage for this Metered Item.
-
#meter_segment_conditions ⇒ Object
Optional array of Meter segments to filter event dimension keys for billing.
-
#tax_details ⇒ Object
Stripe Tax details.
-
#unit_label ⇒ Object
The unit to use when displaying prices for this billable item in places like Checkout.
Instance Method Summary collapse
-
#initialize(display_name: nil, invoice_presentation_dimensions: nil, lookup_key: nil, metadata: nil, meter: nil, meter_segment_conditions: nil, tax_details: nil, unit_label: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(display_name: nil, invoice_presentation_dimensions: nil, lookup_key: nil, metadata: nil, meter: nil, meter_segment_conditions: nil, tax_details: nil, unit_label: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/stripe/services/v2/billing/metered_item_service.rb', line 65 def initialize( display_name: nil, invoice_presentation_dimensions: nil, lookup_key: nil, metadata: nil, meter: nil, meter_segment_conditions: nil, tax_details: nil, unit_label: nil ) @display_name = display_name @invoice_presentation_dimensions = invoice_presentation_dimensions @lookup_key = lookup_key @metadata = @meter = meter @meter_segment_conditions = meter_segment_conditions @tax_details = tax_details @unit_label = unit_label end |
Instance Attribute Details
#display_name ⇒ Object
Description that customers will see in the invoice line item. Maximum length of 250 characters.
44 45 46 |
# File 'lib/stripe/services/v2/billing/metered_item_service.rb', line 44 def display_name @display_name end |
#invoice_presentation_dimensions ⇒ Object
Optional array of Meter dimensions to group event dimension keys for invoice line items.
46 47 48 |
# File 'lib/stripe/services/v2/billing/metered_item_service.rb', line 46 def invoice_presentation_dimensions @invoice_presentation_dimensions end |
#lookup_key ⇒ Object
An internal key you can use to search for a particular billable item. Must be unique among billable items. Maximum length of 200 characters.
50 51 52 |
# File 'lib/stripe/services/v2/billing/metered_item_service.rb', line 50 def lookup_key @lookup_key end |
#metadata ⇒ Object
Set of [key-value pairs](/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
52 53 54 |
# File 'lib/stripe/services/v2/billing/metered_item_service.rb', line 52 def @metadata end |
#meter ⇒ Object
ID of the Meter that measures usage for this Metered Item.
54 55 56 |
# File 'lib/stripe/services/v2/billing/metered_item_service.rb', line 54 def meter @meter end |
#meter_segment_conditions ⇒ Object
Optional array of Meter segments to filter event dimension keys for billing.
56 57 58 |
# File 'lib/stripe/services/v2/billing/metered_item_service.rb', line 56 def meter_segment_conditions @meter_segment_conditions end |
#tax_details ⇒ Object
Stripe Tax details.
58 59 60 |
# File 'lib/stripe/services/v2/billing/metered_item_service.rb', line 58 def tax_details @tax_details end |
#unit_label ⇒ Object
The unit to use when displaying prices for this billable item in places like Checkout. For example, set this field to “CPU-hour” for Checkout to display “(price) per CPU-hour”, or “1 million events” to display “(price) per 1 million events”. Maximum length of 100 characters.
63 64 65 |
# File 'lib/stripe/services/v2/billing/metered_item_service.rb', line 63 def unit_label @unit_label end |