Class: Stripe::V2::Billing::MeteredItemService::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::MeteredItemService::ListParams
- Defined in:
- lib/stripe/services/v2/billing/metered_item_service.rb
Instance Attribute Summary collapse
-
#limit ⇒ Object
Optionally set the maximum number of results per page.
-
#lookup_keys ⇒ Object
Filter by lookup keys.
Instance Method Summary collapse
-
#initialize(limit: nil, lookup_keys: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(limit: nil, lookup_keys: nil) ⇒ ListParams
Returns a new instance of ListParams.
15 16 17 18 |
# File 'lib/stripe/services/v2/billing/metered_item_service.rb', line 15 def initialize(limit: nil, lookup_keys: nil) @limit = limit @lookup_keys = lookup_keys end |
Instance Attribute Details
#limit ⇒ Object
Optionally set the maximum number of results per page. Defaults to 20.
10 11 12 |
# File 'lib/stripe/services/v2/billing/metered_item_service.rb', line 10 def limit @limit end |
#lookup_keys ⇒ Object
Filter by lookup keys. You can specify up to 10 lookup keys.
13 14 15 |
# File 'lib/stripe/services/v2/billing/metered_item_service.rb', line 13 def lookup_keys @lookup_keys end |