Class: Stripe::V2::Billing::MeteredItemService::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/billing/metered_item_service.rb

Defined Under Namespace

Classes: TaxDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(display_name: nil, lookup_key: nil, metadata: nil, tax_details: nil, unit_label: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'lib/stripe/services/v2/billing/metered_item_service.rb', line 115

def initialize(
  display_name: nil,
  lookup_key: nil,
  metadata: nil,
  tax_details: nil,
  unit_label: nil
)
  @display_name = display_name
  @lookup_key = lookup_key
  @metadata = 
  @tax_details = tax_details
  @unit_label = unit_label
end

Instance Attribute Details

#display_nameObject

Description that customers will see in the invoice line item. Maximum length of 250 characters.



99
100
101
# File 'lib/stripe/services/v2/billing/metered_item_service.rb', line 99

def display_name
  @display_name
end

#lookup_keyObject

An internal key you can use to search for a particular billable item. Maximum length of 200 characters. To remove the lookup_key from the object, set it to null in the request.



103
104
105
# File 'lib/stripe/services/v2/billing/metered_item_service.rb', line 103

def lookup_key
  @lookup_key
end

#metadataObject

Set of [key-value pairs](/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



105
106
107
# File 'lib/stripe/services/v2/billing/metered_item_service.rb', line 105

def 
  @metadata
end

#tax_detailsObject

Stripe Tax details.



107
108
109
# File 'lib/stripe/services/v2/billing/metered_item_service.rb', line 107

def tax_details
  @tax_details
end

#unit_labelObject

The unit to use when displaying prices for this billable item in places like Checkout. For example, set this field to “CPU-hour” for Checkout to display “(price) per CPU-hour”, or “1 million events” to display “(price) per 1 million events”. Maximum length of 100 characters. To remove the unit_label from the object, set it to null in the request.



113
114
115
# File 'lib/stripe/services/v2/billing/metered_item_service.rb', line 113

def unit_label
  @unit_label
end