Class: Stripe::V2::Billing::OneTimeItem
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Billing::OneTimeItem
- Defined in:
- lib/stripe/resources/v2/billing/one_time_item.rb
Overview
A one-time item represents a product that can be charged as a one-time line item, used for overage charges when custom pricing unit credits are exhausted.
Defined Under Namespace
Classes: TaxDetails
Constant Summary collapse
- OBJECT_NAME =
"v2.billing.one_time_item"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#created ⇒ Object
readonly
Timestamp of when the object was created.
-
#display_name ⇒ Object
readonly
Description that customers will see in the invoice line item.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#lookup_key ⇒ Object
readonly
An internal key you can use to search for a particular one-time item.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](/docs/api/metadata) that you can attach to an object.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#tax_details ⇒ Object
readonly
Stripe Tax details.
-
#unit_label ⇒ Object
readonly
The unit to use when displaying prices for this one-time item.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#created ⇒ Object (readonly)
Timestamp of when the object was created.
28 29 30 |
# File 'lib/stripe/resources/v2/billing/one_time_item.rb', line 28 def created @created end |
#display_name ⇒ Object (readonly)
Description that customers will see in the invoice line item. Maximum length of 250 characters.
31 32 33 |
# File 'lib/stripe/resources/v2/billing/one_time_item.rb', line 31 def display_name @display_name end |
#id ⇒ Object (readonly)
Unique identifier for the object.
33 34 35 |
# File 'lib/stripe/resources/v2/billing/one_time_item.rb', line 33 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
48 49 50 |
# File 'lib/stripe/resources/v2/billing/one_time_item.rb', line 48 def livemode @livemode end |
#lookup_key ⇒ Object (readonly)
An internal key you can use to search for a particular one-time item. Maximum length of 200 characters.
36 37 38 |
# File 'lib/stripe/resources/v2/billing/one_time_item.rb', line 36 def lookup_key @lookup_key end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
38 39 40 |
# File 'lib/stripe/resources/v2/billing/one_time_item.rb', line 38 def @metadata end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
40 41 42 |
# File 'lib/stripe/resources/v2/billing/one_time_item.rb', line 40 def object @object end |
#tax_details ⇒ Object (readonly)
Stripe Tax details.
42 43 44 |
# File 'lib/stripe/resources/v2/billing/one_time_item.rb', line 42 def tax_details @tax_details end |
#unit_label ⇒ Object (readonly)
The unit to use when displaying prices for this one-time item. For example, set this field to “credit” for the display to show “(price) per credit”. Maximum length of 100 characters.
46 47 48 |
# File 'lib/stripe/resources/v2/billing/one_time_item.rb', line 46 def unit_label @unit_label end |
Class Method Details
.field_remappings ⇒ Object
54 55 56 |
# File 'lib/stripe/resources/v2/billing/one_time_item.rb', line 54 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
50 51 52 |
# File 'lib/stripe/resources/v2/billing/one_time_item.rb', line 50 def self.inner_class_types @inner_class_types = { tax_details: TaxDetails } end |
.object_name ⇒ Object
11 12 13 |
# File 'lib/stripe/resources/v2/billing/one_time_item.rb', line 11 def self.object_name "v2.billing.one_time_item" end |