Class: Stripe::V2::Billing::OneTimeItemUpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/billing/one_time_item_update_params.rb

Defined Under Namespace

Classes: TaxDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(display_name: nil, lookup_key: nil, metadata: nil, tax_details: nil, unit_label: nil) ⇒ OneTimeItemUpdateParams

Returns a new instance of OneTimeItemUpdateParams.



32
33
34
35
36
37
38
39
40
41
42
43
44
# File 'lib/stripe/params/v2/billing/one_time_item_update_params.rb', line 32

def initialize(
  display_name: nil,
  lookup_key: nil,
  metadata: nil,
  tax_details: nil,
  unit_label: nil
)
  @display_name = display_name
  @lookup_key = lookup_key
  @metadata = 
  @tax_details = tax_details
  @unit_label = unit_label
end

Instance Attribute Details

#display_nameObject

Description that customers will see in the invoice line item. Maximum length of 250 characters.



18
19
20
# File 'lib/stripe/params/v2/billing/one_time_item_update_params.rb', line 18

def display_name
  @display_name
end

#lookup_keyObject

An internal key you can use to search for a particular one-time item. Maximum length of 200 characters. To remove the lookup_key from the object, set it to null in the request.



22
23
24
# File 'lib/stripe/params/v2/billing/one_time_item_update_params.rb', line 22

def lookup_key
  @lookup_key
end

#metadataObject

Set of [key-value pairs](/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



24
25
26
# File 'lib/stripe/params/v2/billing/one_time_item_update_params.rb', line 24

def 
  @metadata
end

#tax_detailsObject

Stripe Tax details.



26
27
28
# File 'lib/stripe/params/v2/billing/one_time_item_update_params.rb', line 26

def tax_details
  @tax_details
end

#unit_labelObject

The unit to use when displaying prices for this one-time item. For example, set this field to “credit” for the display to show “(price) per credit”. Maximum length of 100 characters.



30
31
32
# File 'lib/stripe/params/v2/billing/one_time_item_update_params.rb', line 30

def unit_label
  @unit_label
end