Class: Stripe::V2::Billing::PricingPlanComponent
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Billing::PricingPlanComponent
- Defined in:
- lib/stripe/resources/v2/billing/pricing_plan_component.rb
Overview
A Pricing Plan Component represents an individual billing element within a Pricing Plan. Components can be Rate Cards for usage-based charges, License Fees for recurring fixed charges, or Service Actions for recurring credit grants. Each component is associated with a specific version of the Pricing Plan and defines one aspect of how customers are billed.
Defined Under Namespace
Classes: LicenseFee, RateCard, ServiceAction
Constant Summary collapse
- OBJECT_NAME =
"v2.billing.pricing_plan_component"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#license_fee ⇒ Object
readonly
Details if this component is a License Fee.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#lookup_key ⇒ Object
readonly
An internal key you can use to search for a particular PricingPlanComponent.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](/docs/api/metadata) that you can attach to an object.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#pricing_plan ⇒ Object
readonly
The ID of the Pricing Plan this component belongs to.
-
#pricing_plan_version ⇒ Object
readonly
The ID of the Pricing Plan Version this component belongs to.
-
#rate_card ⇒ Object
readonly
Details if this component is a Rate Card.
-
#service_action ⇒ Object
readonly
Details if this component is a Service Action.
-
#type ⇒ Object
readonly
The type of the PricingPlanComponent.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#created ⇒ Object (readonly)
Time at which the object was created.
59 60 61 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_component.rb', line 59 def created @created end |
#id ⇒ Object (readonly)
Unique identifier for the object.
61 62 63 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_component.rb', line 61 def id @id end |
#license_fee ⇒ Object (readonly)
Details if this component is a License Fee.
63 64 65 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_component.rb', line 63 def license_fee @license_fee end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
65 66 67 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_component.rb', line 65 def livemode @livemode end |
#lookup_key ⇒ Object (readonly)
An internal key you can use to search for a particular PricingPlanComponent.
67 68 69 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_component.rb', line 67 def lookup_key @lookup_key end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
69 70 71 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_component.rb', line 69 def @metadata end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
71 72 73 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_component.rb', line 71 def object @object end |
#pricing_plan ⇒ Object (readonly)
The ID of the Pricing Plan this component belongs to.
73 74 75 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_component.rb', line 73 def pricing_plan @pricing_plan end |
#pricing_plan_version ⇒ Object (readonly)
The ID of the Pricing Plan Version this component belongs to.
75 76 77 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_component.rb', line 75 def pricing_plan_version @pricing_plan_version end |
#rate_card ⇒ Object (readonly)
Details if this component is a Rate Card.
77 78 79 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_component.rb', line 77 def rate_card @rate_card end |
#service_action ⇒ Object (readonly)
Details if this component is a Service Action.
79 80 81 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_component.rb', line 79 def service_action @service_action end |
#type ⇒ Object (readonly)
The type of the PricingPlanComponent.
81 82 83 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_component.rb', line 81 def type @type end |
Class Method Details
.field_remappings ⇒ Object
91 92 93 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_component.rb', line 91 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
83 84 85 86 87 88 89 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_component.rb', line 83 def self.inner_class_types @inner_class_types = { license_fee: LicenseFee, rate_card: RateCard, service_action: ServiceAction, } end |
.object_name ⇒ Object
12 13 14 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_component.rb', line 12 def self.object_name "v2.billing.pricing_plan_component" end |