Class: Stripe::V2::Billing::PricingPlanCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::PricingPlanCreateParams
- Defined in:
- lib/stripe/params/v2/billing/pricing_plan_create_params.rb
Instance Attribute Summary collapse
-
#currency ⇒ Object
The currency of the PricingPlan.
-
#description ⇒ Object
Description of pricing plan subscription.
-
#display_name ⇒ Object
Display name of the PricingPlan.
-
#lookup_key ⇒ Object
An internal key you can use to search for a particular PricingPlan.
-
#metadata ⇒ Object
Set of [key-value pairs](/docs/api/metadata) that you can attach to an object.
-
#tax_behavior ⇒ Object
The Stripe Tax tax behavior - whether the PricingPlan is inclusive or exclusive of tax.
Instance Method Summary collapse
-
#initialize(currency: nil, description: nil, display_name: nil, lookup_key: nil, metadata: nil, tax_behavior: nil) ⇒ PricingPlanCreateParams
constructor
A new instance of PricingPlanCreateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(currency: nil, description: nil, display_name: nil, lookup_key: nil, metadata: nil, tax_behavior: nil) ⇒ PricingPlanCreateParams
Returns a new instance of PricingPlanCreateParams.
21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 |
# File 'lib/stripe/params/v2/billing/pricing_plan_create_params.rb', line 21 def initialize( currency: nil, description: nil, display_name: nil, lookup_key: nil, metadata: nil, tax_behavior: nil ) @currency = currency @description = description @display_name = display_name @lookup_key = lookup_key @metadata = @tax_behavior = tax_behavior end |
Instance Attribute Details
#currency ⇒ Object
The currency of the PricingPlan.
9 10 11 |
# File 'lib/stripe/params/v2/billing/pricing_plan_create_params.rb', line 9 def currency @currency end |
#description ⇒ Object
Description of pricing plan subscription.
11 12 13 |
# File 'lib/stripe/params/v2/billing/pricing_plan_create_params.rb', line 11 def description @description end |
#display_name ⇒ Object
Display name of the PricingPlan. Maximum 250 characters.
13 14 15 |
# File 'lib/stripe/params/v2/billing/pricing_plan_create_params.rb', line 13 def display_name @display_name end |
#lookup_key ⇒ Object
An internal key you can use to search for a particular PricingPlan. Maximum length of 200 characters.
15 16 17 |
# File 'lib/stripe/params/v2/billing/pricing_plan_create_params.rb', line 15 def lookup_key @lookup_key end |
#metadata ⇒ Object
Set of [key-value pairs](/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
17 18 19 |
# File 'lib/stripe/params/v2/billing/pricing_plan_create_params.rb', line 17 def @metadata end |
#tax_behavior ⇒ Object
The Stripe Tax tax behavior - whether the PricingPlan is inclusive or exclusive of tax.
19 20 21 |
# File 'lib/stripe/params/v2/billing/pricing_plan_create_params.rb', line 19 def tax_behavior @tax_behavior end |