Class: Stripe::V2::Billing::PricingPlanListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::PricingPlanListParams
- Defined in:
- lib/stripe/params/v2/billing/pricing_plan_list_params.rb
Instance Attribute Summary collapse
-
#active ⇒ Object
Filter for active/inactive PricingPlans.
-
#limit ⇒ Object
Optionally set the maximum number of results per page.
-
#lookup_keys ⇒ Object
Filter by lookup keys.
Instance Method Summary collapse
-
#initialize(active: nil, limit: nil, lookup_keys: nil) ⇒ PricingPlanListParams
constructor
A new instance of PricingPlanListParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(active: nil, limit: nil, lookup_keys: nil) ⇒ PricingPlanListParams
Returns a new instance of PricingPlanListParams.
16 17 18 19 20 |
# File 'lib/stripe/params/v2/billing/pricing_plan_list_params.rb', line 16 def initialize(active: nil, limit: nil, lookup_keys: nil) @active = active @limit = limit @lookup_keys = lookup_keys end |
Instance Attribute Details
#active ⇒ Object
Filter for active/inactive PricingPlans. Mutually exclusive with ‘lookup_keys`.
9 10 11 |
# File 'lib/stripe/params/v2/billing/pricing_plan_list_params.rb', line 9 def active @active end |
#limit ⇒ Object
Optionally set the maximum number of results per page. Defaults to 20.
11 12 13 |
# File 'lib/stripe/params/v2/billing/pricing_plan_list_params.rb', line 11 def limit @limit end |
#lookup_keys ⇒ Object
Filter by lookup keys. Mutually exclusive with ‘active`. You can specify up to 10 lookup keys.
14 15 16 |
# File 'lib/stripe/params/v2/billing/pricing_plan_list_params.rb', line 14 def lookup_keys @lookup_keys end |