Class: Stripe::V2::Billing::PricingPlanService::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/billing/pricing_plan_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(currency: nil, description: nil, display_name: nil, lookup_key: nil, metadata: nil, tax_behavior: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
# File 'lib/stripe/services/v2/billing/pricing_plan_service.rb', line 46

def initialize(
  currency: nil,
  description: nil,
  display_name: nil,
  lookup_key: nil,
  metadata: nil,
  tax_behavior: nil
)
  @currency = currency
  @description = description
  @display_name = display_name
  @lookup_key = lookup_key
  @metadata = 
  @tax_behavior = tax_behavior
end

Instance Attribute Details

#currencyObject

The currency of the PricingPlan.



34
35
36
# File 'lib/stripe/services/v2/billing/pricing_plan_service.rb', line 34

def currency
  @currency
end

#descriptionObject

Description of pricing plan subscription.



36
37
38
# File 'lib/stripe/services/v2/billing/pricing_plan_service.rb', line 36

def description
  @description
end

#display_nameObject

Display name of the PricingPlan. Maximum 250 characters.



38
39
40
# File 'lib/stripe/services/v2/billing/pricing_plan_service.rb', line 38

def display_name
  @display_name
end

#lookup_keyObject

An internal key you can use to search for a particular PricingPlan. Maximum length of 200 characters.



40
41
42
# File 'lib/stripe/services/v2/billing/pricing_plan_service.rb', line 40

def lookup_key
  @lookup_key
end

#metadataObject

Set of [key-value pairs](/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



42
43
44
# File 'lib/stripe/services/v2/billing/pricing_plan_service.rb', line 42

def 
  @metadata
end

#tax_behaviorObject

The Stripe Tax tax behavior - whether the PricingPlan is inclusive or exclusive of tax.



44
45
46
# File 'lib/stripe/services/v2/billing/pricing_plan_service.rb', line 44

def tax_behavior
  @tax_behavior
end