Class: Stripe::V2::Billing::PricingPlanSubscription::CollectionStatusTransitions
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::PricingPlanSubscription::CollectionStatusTransitions
- Defined in:
- lib/stripe/resources/v2/billing/pricing_plan_subscription.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#awaiting_customer_action_at ⇒ Object
readonly
When the collection status transitioned to awaiting customer action.
-
#current_at ⇒ Object
readonly
When the collection status transitioned to current.
-
#past_due_at ⇒ Object
readonly
When the collection status transitioned to past due.
-
#paused_at ⇒ Object
readonly
When the collection status transitioned to paused.
-
#unpaid_at ⇒ Object
readonly
When the collection status transitioned to unpaid.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#awaiting_customer_action_at ⇒ Object (readonly)
When the collection status transitioned to awaiting customer action.
35 36 37 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 35 def awaiting_customer_action_at @awaiting_customer_action_at end |
#current_at ⇒ Object (readonly)
When the collection status transitioned to current.
37 38 39 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 37 def current_at @current_at end |
#past_due_at ⇒ Object (readonly)
When the collection status transitioned to past due.
39 40 41 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 39 def past_due_at @past_due_at end |
#paused_at ⇒ Object (readonly)
When the collection status transitioned to paused.
41 42 43 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 41 def paused_at @paused_at end |
#unpaid_at ⇒ Object (readonly)
When the collection status transitioned to unpaid.
43 44 45 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 43 def unpaid_at @unpaid_at end |
Class Method Details
.field_remappings ⇒ Object
49 50 51 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 49 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
45 46 47 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 45 def self.inner_class_types @inner_class_types = {} end |