Class: Stripe::V2::Billing::PricingPlanSubscription::DiscountDetail
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::PricingPlanSubscription::DiscountDetail
- Defined in:
- lib/stripe/resources/v2/billing/pricing_plan_subscription.rb
Defined Under Namespace
Classes: Source
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#discount ⇒ Object
readonly
The ID of the Discount.
-
#end ⇒ Object
readonly
The time at which the Discount ends, if applicable.
-
#promotion_code ⇒ Object
readonly
The ID of the PromotionCode, if applicable.
-
#source ⇒ Object
readonly
The source of the Discount.
-
#start ⇒ Object
readonly
The time at which the Discount starts.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#discount ⇒ Object (readonly)
The ID of the Discount.
70 71 72 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 70 def discount @discount end |
#end ⇒ Object (readonly)
The time at which the Discount ends, if applicable.
72 73 74 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 72 def end @end end |
#promotion_code ⇒ Object (readonly)
The ID of the PromotionCode, if applicable.
74 75 76 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 74 def promotion_code @promotion_code end |
#source ⇒ Object (readonly)
The source of the Discount.
76 77 78 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 76 def source @source end |
#start ⇒ Object (readonly)
The time at which the Discount starts.
78 79 80 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 78 def start @start end |
Class Method Details
.field_remappings ⇒ Object
84 85 86 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 84 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
80 81 82 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 80 def self.inner_class_types @inner_class_types = { source: Source } end |