Class: Stripe::V2::Billing::PricingPlanSubscription::PricingPlanComponentDetail
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::PricingPlanSubscription::PricingPlanComponentDetail
- Defined in:
- lib/stripe/resources/v2/billing/pricing_plan_subscription.rb
Defined Under Namespace
Classes: LicenseFeeDetails, RateCardDetails, RecurringCreditGrantDetails
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#license_fee_details ⇒ Object
readonly
License fee details, present when type is license_fee_details.
-
#pricing_plan_component ⇒ Object
readonly
The ID of the Pricing Plan Component.
-
#rate_card_details ⇒ Object
readonly
Rate card details, present when type is rate_card_details.
-
#recurring_credit_grant_details ⇒ Object
readonly
Recurring credit grant details, present when type is recurring_credit_grant_details.
-
#type ⇒ Object
readonly
The type of component details included.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#license_fee_details ⇒ Object (readonly)
License fee details, present when type is license_fee_details.
529 530 531 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 529 def license_fee_details @license_fee_details end |
#pricing_plan_component ⇒ Object (readonly)
The ID of the Pricing Plan Component.
531 532 533 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 531 def pricing_plan_component @pricing_plan_component end |
#rate_card_details ⇒ Object (readonly)
Rate card details, present when type is rate_card_details.
533 534 535 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 533 def rate_card_details @rate_card_details end |
#recurring_credit_grant_details ⇒ Object (readonly)
Recurring credit grant details, present when type is recurring_credit_grant_details.
535 536 537 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 535 def recurring_credit_grant_details @recurring_credit_grant_details end |
#type ⇒ Object (readonly)
The type of component details included.
537 538 539 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 537 def type @type end |
Class Method Details
.field_encodings ⇒ Object
551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 551 def self.field_encodings @field_encodings = { license_fee_details: { kind: :object, fields: { tiers: { kind: :array, element: { kind: :object, fields: { up_to_decimal: :decimal_string } }, }, transform_quantity: { kind: :object, fields: { divide_by: :int64_string } }, }, }, recurring_credit_grant_details: { kind: :object, fields: { credit_grant_details: { kind: :object, fields: { amount: { kind: :object, fields: { custom_pricing_unit: { kind: :object, fields: { value: :decimal_string } }, }, }, }, }, credit_grant_per_tenant_details: { kind: :object, fields: { amount: { kind: :object, fields: { custom_pricing_unit: { kind: :object, fields: { value: :decimal_string } }, }, }, }, }, }, }, } end |
.field_remappings ⇒ Object
547 548 549 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 547 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
539 540 541 542 543 544 545 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 539 def self.inner_class_types @inner_class_types = { license_fee_details: LicenseFeeDetails, rate_card_details: RateCardDetails, recurring_credit_grant_details: RecurringCreditGrantDetails, } end |