Class: Stripe::V2::Billing::PricingPlanSubscription::PricingPlanComponentDetail::LicenseFeeDetails

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/billing/pricing_plan_subscription.rb

Defined Under Namespace

Classes: ServiceCycle, Tier, TransformQuantity

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#currencyObject (readonly)

Three-letter ISO currency code, in lowercase.



151
152
153
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 151

def currency
  @currency
end

#display_nameObject (readonly)

A customer-facing name for the license fee.



153
154
155
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 153

def display_name
  @display_name
end

#license_feeObject (readonly)

The ID of the License Fee.



155
156
157
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 155

def license_fee
  @license_fee
end

#license_fee_versionObject (readonly)

The ID of the License Fee Version.



157
158
159
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 157

def license_fee_version
  @license_fee_version
end

#quantityObject (readonly)

Quantity of the license fee on the subscription.



159
160
161
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 159

def quantity
  @quantity
end

#service_cycleObject (readonly)

The service cycle configuration.



161
162
163
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 161

def service_cycle
  @service_cycle
end

#tiering_modeObject (readonly)

Defines whether the tiering price is graduated or volume-based.



163
164
165
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 163

def tiering_mode
  @tiering_mode
end

#tiersObject (readonly)

Each element represents a pricing tier.



165
166
167
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 165

def tiers
  @tiers
end

#transform_quantityObject (readonly)

Apply a transformation to the reported usage or set quantity before computing the amount billed.



167
168
169
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 167

def transform_quantity
  @transform_quantity
end

#unit_amountObject (readonly)

The per-unit amount to be charged, represented as a decimal string in minor currency units with at most 12 decimal places.



169
170
171
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 169

def unit_amount
  @unit_amount
end

#unit_labelObject (readonly)

The unit label from the licensed item, used for display purposes (for example, “seat”, “environment”).



171
172
173
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 171

def unit_label
  @unit_label
end

Class Method Details

.field_encodingsObject



185
186
187
188
189
190
191
192
193
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 185

def self.field_encodings
  @field_encodings = {
    tiers: {
      kind: :array,
      element: { kind: :object, fields: { up_to_decimal: :decimal_string } },
    },
    transform_quantity: { kind: :object, fields: { divide_by: :int64_string } },
  }
end

.field_remappingsObject



181
182
183
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 181

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



173
174
175
176
177
178
179
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 173

def self.inner_class_types
  @inner_class_types = {
    service_cycle: ServiceCycle,
    tiers: Tier,
    transform_quantity: TransformQuantity,
  }
end