Class: Stripe::V2::Billing::PricingPlanSubscription::PricingPlanComponentDetail::RateCardDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::PricingPlanSubscription::PricingPlanComponentDetail::RateCardDetails
- Defined in:
- lib/stripe/resources/v2/billing/pricing_plan_subscription.rb
Defined Under Namespace
Classes: ServiceCycle
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#currency ⇒ Object
readonly
Three-letter ISO currency code, in lowercase.
-
#display_name ⇒ Object
readonly
A customer-facing name for the rate card.
-
#rate_card ⇒ Object
readonly
The ID of the Rate Card.
-
#rate_card_version ⇒ Object
readonly
The ID of the Rate Card Version.
-
#service_cycle ⇒ Object
readonly
The service cycle configuration.
-
#tax_behavior ⇒ Object
readonly
Whether the rates are inclusive or exclusive of tax.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#currency ⇒ Object (readonly)
Three-letter ISO currency code, in lowercase.
213 214 215 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 213 def currency @currency end |
#display_name ⇒ Object (readonly)
A customer-facing name for the rate card.
215 216 217 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 215 def display_name @display_name end |
#rate_card ⇒ Object (readonly)
The ID of the Rate Card.
217 218 219 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 217 def rate_card @rate_card end |
#rate_card_version ⇒ Object (readonly)
The ID of the Rate Card Version.
219 220 221 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 219 def rate_card_version @rate_card_version end |
#service_cycle ⇒ Object (readonly)
The service cycle configuration.
221 222 223 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 221 def service_cycle @service_cycle end |
#tax_behavior ⇒ Object (readonly)
Whether the rates are inclusive or exclusive of tax.
223 224 225 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 223 def tax_behavior @tax_behavior end |
Class Method Details
.field_remappings ⇒ Object
229 230 231 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 229 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
225 226 227 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 225 def self.inner_class_types @inner_class_types = { service_cycle: ServiceCycle } end |