Class: Stripe::V2::Billing::PricingPlanSubscription::PricingPlanComponentDetail::RecurringCreditGrantDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::PricingPlanSubscription::PricingPlanComponentDetail::RecurringCreditGrantDetails
- Defined in:
- lib/stripe/resources/v2/billing/pricing_plan_subscription.rb
Defined Under Namespace
Classes: CreditGrantDetails, CreditGrantPerTenantDetails, ServiceCycle
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#credit_grant_details ⇒ Object
readonly
Credit grant details, present when type is CREDIT_GRANT.
-
#credit_grant_per_tenant_details ⇒ Object
readonly
Credit grant per tenant details, present when type is CREDIT_GRANT_PER_TENANT.
-
#recurring_credit_grant ⇒ Object
readonly
The ID of the Recurring Credit Grant.
-
#service_cycle ⇒ Object
readonly
The service cycle configuration.
-
#type ⇒ Object
readonly
The type of the recurring credit grant.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#credit_grant_details ⇒ Object (readonly)
Credit grant details, present when type is CREDIT_GRANT.
479 480 481 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 479 def credit_grant_details @credit_grant_details end |
#credit_grant_per_tenant_details ⇒ Object (readonly)
Credit grant per tenant details, present when type is CREDIT_GRANT_PER_TENANT.
481 482 483 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 481 def credit_grant_per_tenant_details @credit_grant_per_tenant_details end |
#recurring_credit_grant ⇒ Object (readonly)
The ID of the Recurring Credit Grant.
483 484 485 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 483 def recurring_credit_grant @recurring_credit_grant end |
#service_cycle ⇒ Object (readonly)
The service cycle configuration.
485 486 487 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 485 def service_cycle @service_cycle end |
#type ⇒ Object (readonly)
The type of the recurring credit grant.
487 488 489 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 487 def type @type end |
Class Method Details
.field_encodings ⇒ Object
501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 501 def self.field_encodings @field_encodings = { credit_grant_details: { kind: :object, fields: { amount: { kind: :object, fields: { custom_pricing_unit: { kind: :object, fields: { value: :decimal_string } }, }, }, }, }, credit_grant_per_tenant_details: { kind: :object, fields: { amount: { kind: :object, fields: { custom_pricing_unit: { kind: :object, fields: { value: :decimal_string } }, }, }, }, }, } end |
.field_remappings ⇒ Object
497 498 499 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 497 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
489 490 491 492 493 494 495 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 489 def self.inner_class_types @inner_class_types = { credit_grant_details: CreditGrantDetails, credit_grant_per_tenant_details: CreditGrantPerTenantDetails, service_cycle: ServiceCycle, } end |