Class: Stripe::V2::Billing::PricingPlanSubscription::PricingPlanComponentDetail::RecurringCreditGrantDetails::CreditGrantDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::PricingPlanSubscription::PricingPlanComponentDetail::RecurringCreditGrantDetails::CreditGrantDetails
- Defined in:
- lib/stripe/resources/v2/billing/pricing_plan_subscription.rb
Defined Under Namespace
Classes: Amount, ApplicabilityConfig, ExpiryConfig
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The amount of the credit grant.
-
#applicability_config ⇒ Object
readonly
Defines the scope where the credit grant is applicable.
-
#expiry_config ⇒ Object
readonly
The expiry configuration for the credit grant.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The amount of the credit grant.
319 320 321 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 319 def amount @amount end |
#applicability_config ⇒ Object (readonly)
Defines the scope where the credit grant is applicable.
321 322 323 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 321 def applicability_config @applicability_config end |
#expiry_config ⇒ Object (readonly)
The expiry configuration for the credit grant.
323 324 325 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 323 def expiry_config @expiry_config end |
Class Method Details
.field_encodings ⇒ Object
337 338 339 340 341 342 343 344 345 346 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 337 def self.field_encodings @field_encodings = { amount: { kind: :object, fields: { custom_pricing_unit: { kind: :object, fields: { value: :decimal_string } }, }, }, } end |
.field_remappings ⇒ Object
333 334 335 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 333 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
325 326 327 328 329 330 331 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 325 def self.inner_class_types @inner_class_types = { amount: Amount, applicability_config: ApplicabilityConfig, expiry_config: ExpiryConfig, } end |