Class: Stripe::V2::Billing::PricingPlanSubscription::PricingPlanComponentDetail::RecurringCreditGrantDetails::CreditGrantDetails::Amount::CustomPricingUnit
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::PricingPlanSubscription::PricingPlanComponentDetail::RecurringCreditGrantDetails::CreditGrantDetails::Amount::CustomPricingUnit
- Defined in:
- lib/stripe/resources/v2/billing/pricing_plan_subscription.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#custom_pricing_unit_details ⇒ Object
readonly
The Custom Pricing Unit object.
-
#id ⇒ Object
readonly
The id of the custom pricing unit.
-
#value ⇒ Object
readonly
The value of the credit grant, decimal value represented as a string.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#custom_pricing_unit_details ⇒ Object (readonly)
The Custom Pricing Unit object.
239 240 241 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 239 def custom_pricing_unit_details @custom_pricing_unit_details end |
#id ⇒ Object (readonly)
The id of the custom pricing unit.
241 242 243 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 241 def id @id end |
#value ⇒ Object (readonly)
The value of the credit grant, decimal value represented as a string.
243 244 245 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 243 def value @value end |
Class Method Details
.field_encodings ⇒ Object
253 254 255 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 253 def self.field_encodings @field_encodings = { value: :decimal_string } end |
.field_remappings ⇒ Object
249 250 251 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 249 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
245 246 247 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 245 def self.inner_class_types @inner_class_types = {} end |