Class: Stripe::V2::Billing::PricingPlanSubscription::PricingPlanComponentDetail::RecurringCreditGrantDetails::CreditGrantPerTenantDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::PricingPlanSubscription::PricingPlanComponentDetail::RecurringCreditGrantDetails::CreditGrantPerTenantDetails
- Defined in:
- lib/stripe/resources/v2/billing/pricing_plan_subscription.rb
Defined Under Namespace
Classes: Amount, ApplicabilityConfig, ExpiryConfig
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The amount of the credit grant.
-
#applicability_config ⇒ Object
readonly
Defines the scope where the credit grant is applicable.
-
#expiry_config ⇒ Object
readonly
The expiry configuration for the credit grant.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The amount of the credit grant.
433 434 435 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 433 def amount @amount end |
#applicability_config ⇒ Object (readonly)
Defines the scope where the credit grant is applicable.
435 436 437 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 435 def applicability_config @applicability_config end |
#expiry_config ⇒ Object (readonly)
The expiry configuration for the credit grant.
437 438 439 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 437 def expiry_config @expiry_config end |
Class Method Details
.field_encodings ⇒ Object
451 452 453 454 455 456 457 458 459 460 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 451 def self.field_encodings @field_encodings = { amount: { kind: :object, fields: { custom_pricing_unit: { kind: :object, fields: { value: :decimal_string } }, }, }, } end |
.field_remappings ⇒ Object
447 448 449 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 447 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
439 440 441 442 443 444 445 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 439 def self.inner_class_types @inner_class_types = { amount: Amount, applicability_config: ApplicabilityConfig, expiry_config: ExpiryConfig, } end |