Class: Stripe::V2::Billing::PricingPlanSubscription::PricingPlanComponentDetail::RecurringCreditGrantDetails::CreditGrantPerTenantDetails::Amount
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::PricingPlanSubscription::PricingPlanComponentDetail::RecurringCreditGrantDetails::CreditGrantPerTenantDetails::Amount
- Defined in:
- lib/stripe/resources/v2/billing/pricing_plan_subscription.rb
Defined Under Namespace
Classes: CustomPricingUnit
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#custom_pricing_unit ⇒ Object
readonly
The custom pricing unit amount of the credit grant.
-
#monetary ⇒ Object
readonly
The monetary amount of the credit grant.
-
#type ⇒ Object
readonly
The type of the credit grant amount.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#custom_pricing_unit ⇒ Object (readonly)
The custom pricing unit amount of the credit grant. Required if ‘type` is `custom_pricing_unit`.
372 373 374 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 372 def custom_pricing_unit @custom_pricing_unit end |
#monetary ⇒ Object (readonly)
The monetary amount of the credit grant. Required if ‘type` is `monetary`.
374 375 376 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 374 def monetary @monetary end |
#type ⇒ Object (readonly)
The type of the credit grant amount. We currently support ‘monetary` and `custom_pricing_unit` billing credits.
376 377 378 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 376 def type @type end |
Class Method Details
.field_encodings ⇒ Object
386 387 388 389 390 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 386 def self.field_encodings @field_encodings = { custom_pricing_unit: { kind: :object, fields: { value: :decimal_string } }, } end |
.field_remappings ⇒ Object
382 383 384 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 382 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
378 379 380 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 378 def self.inner_class_types @inner_class_types = { custom_pricing_unit: CustomPricingUnit } end |