Class: Stripe::V2::Billing::PricingPlanSubscription::PricingPlanComponentDetail::RecurringCreditGrantDetails::CreditGrantPerTenantDetails::Amount::CustomPricingUnit
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::PricingPlanSubscription::PricingPlanComponentDetail::RecurringCreditGrantDetails::CreditGrantPerTenantDetails::Amount::CustomPricingUnit
- Defined in:
- lib/stripe/resources/v2/billing/pricing_plan_subscription.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#custom_pricing_unit_details ⇒ Object
readonly
The Custom Pricing Unit object.
-
#id ⇒ Object
readonly
The id of the custom pricing unit.
-
#value ⇒ Object
readonly
The value of the credit grant, decimal value represented as a string.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#custom_pricing_unit_details ⇒ Object (readonly)
The Custom Pricing Unit object.
353 354 355 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 353 def custom_pricing_unit_details @custom_pricing_unit_details end |
#id ⇒ Object (readonly)
The id of the custom pricing unit.
355 356 357 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 355 def id @id end |
#value ⇒ Object (readonly)
The value of the credit grant, decimal value represented as a string.
357 358 359 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 357 def value @value end |
Class Method Details
.field_encodings ⇒ Object
367 368 369 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 367 def self.field_encodings @field_encodings = { value: :decimal_string } end |
.field_remappings ⇒ Object
363 364 365 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 363 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
359 360 361 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 359 def self.inner_class_types @inner_class_types = {} end |