Class: Stripe::V2::Billing::PricingPlans::ComponentService::ListParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/billing/pricing_plans/component_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(limit: nil, lookup_keys: nil, pricing_plan_version: nil) ⇒ ListParams

Returns a new instance of ListParams.



19
20
21
22
23
# File 'lib/stripe/services/v2/billing/pricing_plans/component_service.rb', line 19

def initialize(limit: nil, lookup_keys: nil, pricing_plan_version: nil)
  @limit = limit
  @lookup_keys = lookup_keys
  @pricing_plan_version = pricing_plan_version
end

Instance Attribute Details

#limitObject

Optionally set the maximum number of results per page. Defaults to 20.



11
12
13
# File 'lib/stripe/services/v2/billing/pricing_plans/component_service.rb', line 11

def limit
  @limit
end

#lookup_keysObject

Filter by lookup keys. Mutually exclusive with ‘pricing_plan_version`. You can specify up to 10 lookup keys.



14
15
16
# File 'lib/stripe/services/v2/billing/pricing_plans/component_service.rb', line 14

def lookup_keys
  @lookup_keys
end

#pricing_plan_versionObject

The ID of the Pricing Plan Version to list components for. Will use the latest version if not provided. Mutually exclusive with ‘lookup_keys`.



17
18
19
# File 'lib/stripe/services/v2/billing/pricing_plans/component_service.rb', line 17

def pricing_plan_version
  @pricing_plan_version
end