Class: Stripe::V2::Billing::PricingPlans::ComponentService::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/billing/pricing_plans/component_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(lookup_key: nil, metadata: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



98
99
100
101
# File 'lib/stripe/services/v2/billing/pricing_plans/component_service.rb', line 98

def initialize(lookup_key: nil, metadata: nil)
  @lookup_key = lookup_key
  @metadata = 
end

Instance Attribute Details

#lookup_keyObject

An identifier that can be used to find this component. Maximum length of 200 characters.



94
95
96
# File 'lib/stripe/services/v2/billing/pricing_plans/component_service.rb', line 94

def lookup_key
  @lookup_key
end

#metadataObject

Set of key-value pairs that you can attach to an object.



96
97
98
# File 'lib/stripe/services/v2/billing/pricing_plans/component_service.rb', line 96

def 
  @metadata
end