Class: Stripe::V2::Billing::ProfileCreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/v2/billing/profile_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(customer: nil, default_payment_method: nil, display_name: nil, lookup_key: nil, metadata: nil) ⇒ ProfileCreateParams

Returns a new instance of ProfileCreateParams.



21
22
23
24
25
26
27
28
29
30
31
32
33
# File 'lib/stripe/params/v2/billing/profile_create_params.rb', line 21

def initialize(
  customer: nil,
  default_payment_method: nil,
  display_name: nil,
  lookup_key: nil,
  metadata: nil
)
  @customer = customer
  @default_payment_method = default_payment_method
  @display_name = display_name
  @lookup_key = lookup_key
  @metadata = 
end

Instance Attribute Details

#customerObject

The ID of the customer object.



9
10
11
# File 'lib/stripe/params/v2/billing/profile_create_params.rb', line 9

def customer
  @customer
end

#default_payment_methodObject

The ID of the payment method object.



11
12
13
# File 'lib/stripe/params/v2/billing/profile_create_params.rb', line 11

def default_payment_method
  @default_payment_method
end

#display_nameObject

A customer-facing name for the billing profile. Maximum length of 250 characters.



14
15
16
# File 'lib/stripe/params/v2/billing/profile_create_params.rb', line 14

def display_name
  @display_name
end

#lookup_keyObject

An internal key you can use to search for a particular billing profile. It must be unique among billing profiles for a given customer. Maximum length of 200 characters.



17
18
19
# File 'lib/stripe/params/v2/billing/profile_create_params.rb', line 17

def lookup_key
  @lookup_key
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



19
20
21
# File 'lib/stripe/params/v2/billing/profile_create_params.rb', line 19

def 
  @metadata
end