Class: Stripe::V2::Billing::ProfileListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/v2/billing/profile_list_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(customer: nil, default_payment_method: nil, limit: nil, lookup_keys: nil, status: nil) ⇒ ProfileListParams

Returns a new instance of ProfileListParams.



24
25
26
27
28
29
30
31
32
33
34
35
36
# File 'lib/stripe/params/v2/billing/profile_list_params.rb', line 24

def initialize(
  customer: nil,
  default_payment_method: nil,
  limit: nil,
  lookup_keys: nil,
  status: nil
)
  @customer = customer
  @default_payment_method = default_payment_method
  @limit = limit
  @lookup_keys = lookup_keys
  @status = status
end

Instance Attribute Details

#customerObject

Filter billing profiles by a customer. Mutually exclusive with ‘lookup_keys` and `default_payment_method`.



10
11
12
# File 'lib/stripe/params/v2/billing/profile_list_params.rb', line 10

def customer
  @customer
end

#default_payment_methodObject

Filter billing profiles by a default payment method. Mutually exclusive with ‘customer` and `lookup_keys`.



13
14
15
# File 'lib/stripe/params/v2/billing/profile_list_params.rb', line 13

def default_payment_method
  @default_payment_method
end

#limitObject

Optionally set the maximum number of results per page. Defaults to 10.



15
16
17
# File 'lib/stripe/params/v2/billing/profile_list_params.rb', line 15

def limit
  @limit
end

#lookup_keysObject

Filter billing profiles by lookup keys. Mutually exclusive with ‘customer` and `default_payment_method`. You can specify up to 10 lookup_keys.



19
20
21
# File 'lib/stripe/params/v2/billing/profile_list_params.rb', line 19

def lookup_keys
  @lookup_keys
end

#statusObject

Filter billing profiles by status. Can be combined with all other filters. If not provided, all billing profiles will be returned.



22
23
24
# File 'lib/stripe/params/v2/billing/profile_list_params.rb', line 22

def status
  @status
end