Class: Stripe::V2::Billing::ProfileService::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/billing/profile_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(customer: nil, default_payment_method: nil, display_name: nil, lookup_key: nil, metadata: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/stripe/services/v2/billing/profile_service.rb', line 54

def initialize(
  customer: nil,
  default_payment_method: nil,
  display_name: nil,
  lookup_key: nil,
  metadata: nil
)
  @customer = customer
  @default_payment_method = default_payment_method
  @display_name = display_name
  @lookup_key = lookup_key
  @metadata = 
end

Instance Attribute Details

#customerObject

The ID of the customer object.



42
43
44
# File 'lib/stripe/services/v2/billing/profile_service.rb', line 42

def customer
  @customer
end

#default_payment_methodObject

The ID of the payment method object.



44
45
46
# File 'lib/stripe/services/v2/billing/profile_service.rb', line 44

def default_payment_method
  @default_payment_method
end

#display_nameObject

A customer-facing name for the billing profile. Maximum length of 250 characters.



47
48
49
# File 'lib/stripe/services/v2/billing/profile_service.rb', line 47

def display_name
  @display_name
end

#lookup_keyObject

An internal key you can use to search for a particular billing profile. It must be unique among billing profiles for a given customer. Maximum length of 200 characters.



50
51
52
# File 'lib/stripe/services/v2/billing/profile_service.rb', line 50

def lookup_key
  @lookup_key
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



52
53
54
# File 'lib/stripe/services/v2/billing/profile_service.rb', line 52

def 
  @metadata
end