Class: Stripe::V2::Billing::ProfileService::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/billing/profile_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(default_payment_method: nil, display_name: nil, lookup_key: nil, metadata: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



85
86
87
88
89
90
91
92
93
94
95
# File 'lib/stripe/services/v2/billing/profile_service.rb', line 85

def initialize(
  default_payment_method: nil,
  display_name: nil,
  lookup_key: nil,
  metadata: nil
)
  @default_payment_method = default_payment_method
  @display_name = display_name
  @lookup_key = lookup_key
  @metadata = 
end

Instance Attribute Details

#default_payment_methodObject

The ID of the payment method object.



73
74
75
# File 'lib/stripe/services/v2/billing/profile_service.rb', line 73

def default_payment_method
  @default_payment_method
end

#display_nameObject

A customer-facing name for the billing profile. Maximum length of 250 characters. To remove the display_name from the object, set it to null in the request.



77
78
79
# File 'lib/stripe/services/v2/billing/profile_service.rb', line 77

def display_name
  @display_name
end

#lookup_keyObject

An internal key you can use to search for a particular billing profile. It must be unique among billing profiles for a given customer. Maximum length of 200 characters. To remove the lookup_key from the object, set it to null in the request.



81
82
83
# File 'lib/stripe/services/v2/billing/profile_service.rb', line 81

def lookup_key
  @lookup_key
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



83
84
85
# File 'lib/stripe/services/v2/billing/profile_service.rb', line 83

def 
  @metadata
end