Class: Stripe::V2::Billing::RateCard

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/billing/rate_card.rb

Overview

A Rate Card represents a versioned set of usage-based prices (rates). Each rate is associated with one Metered Item and defines how much to charge for usage of that item. After you’ve set up a RateCard, you can subscribe customers to it by creating a Rate Card Subscription.

Defined Under Namespace

Classes: ServiceCycle

Constant Summary collapse

OBJECT_NAME =
"v2.billing.rate_card"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#activeObject (readonly)

Whether this RateCard is active. Inactive RateCards cannot be used in new activations or have new rates added.



32
33
34
# File 'lib/stripe/resources/v2/billing/rate_card.rb', line 32

def active
  @active
end

#createdObject (readonly)

Timestamp of when the object was created.



34
35
36
# File 'lib/stripe/resources/v2/billing/rate_card.rb', line 34

def created
  @created
end

#currencyObject (readonly)

Three-letter ISO currency code, in lowercase. Must be a supported currency.



36
37
38
# File 'lib/stripe/resources/v2/billing/rate_card.rb', line 36

def currency
  @currency
end

#display_nameObject (readonly)

A customer-facing name for the Rate Card. This name is used in Stripe-hosted products like the Customer Portal and Checkout. It does not show up on Invoices. Maximum length of 250 characters.



40
41
42
# File 'lib/stripe/resources/v2/billing/rate_card.rb', line 40

def display_name
  @display_name
end

#idObject (readonly)

Unique identifier for the object.



42
43
44
# File 'lib/stripe/resources/v2/billing/rate_card.rb', line 42

def id
  @id
end

#latest_versionObject (readonly)

The ID of this rate card’s most recently created version.



44
45
46
# File 'lib/stripe/resources/v2/billing/rate_card.rb', line 44

def latest_version
  @latest_version
end

#live_versionObject (readonly)

The ID of the Rate Card Version used by all subscriptions when no specific version is specified.



46
47
48
# File 'lib/stripe/resources/v2/billing/rate_card.rb', line 46

def live_version
  @live_version
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



48
49
50
# File 'lib/stripe/resources/v2/billing/rate_card.rb', line 48

def livemode
  @livemode
end

#lookup_keyObject (readonly)

An internal key you can use to search for a particular RateCard. Maximum length of 200 characters.



50
51
52
# File 'lib/stripe/resources/v2/billing/rate_card.rb', line 50

def lookup_key
  @lookup_key
end

#metadataObject (readonly)

Set of [key-value pairs](/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



52
53
54
# File 'lib/stripe/resources/v2/billing/rate_card.rb', line 52

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



54
55
56
# File 'lib/stripe/resources/v2/billing/rate_card.rb', line 54

def object
  @object
end

#service_cycleObject (readonly)

The service cycle configuration for this Rate Card. For example, a monthly Rate Card with a rate of 1 USD for the first 10 “workloads” and 2 USD thereafter means “1 USD per workload up to 10 workloads during a month of service.” This is similar to but distinct from billing interval; the service interval deals with the rate at which the customer accumulates fees, while the billing interval in Cadence deals with the rate the customer is billed.



59
60
61
# File 'lib/stripe/resources/v2/billing/rate_card.rb', line 59

def service_cycle
  @service_cycle
end

#service_intervalObject (readonly)

The interval for assessing service. For example, a monthly Rate Card with a rate of 1 USD for the first 10 “workloads” and 2 USD thereafter means “1 USD per workload up to 10 workloads during a month of service.” This is similar to but distinct from billing interval; the service interval deals with the rate at which the customer accumulates fees, while the billing interval in Cadence deals with the rate the customer is billed.



64
65
66
# File 'lib/stripe/resources/v2/billing/rate_card.rb', line 64

def service_interval
  @service_interval
end

#service_interval_countObject (readonly)

The length of the interval for assessing service. For example, set this to 3 and ‘service_interval` to `“month”` to specify quarterly service.



67
68
69
# File 'lib/stripe/resources/v2/billing/rate_card.rb', line 67

def service_interval_count
  @service_interval_count
end

#tax_behaviorObject (readonly)

The tax behavior for Stripe Tax — whether the rate card price includes or excludes tax.



69
70
71
# File 'lib/stripe/resources/v2/billing/rate_card.rb', line 69

def tax_behavior
  @tax_behavior
end

Class Method Details

.field_remappingsObject



75
76
77
# File 'lib/stripe/resources/v2/billing/rate_card.rb', line 75

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



71
72
73
# File 'lib/stripe/resources/v2/billing/rate_card.rb', line 71

def self.inner_class_types
  @inner_class_types = { service_cycle: ServiceCycle }
end

.object_nameObject



12
13
14
# File 'lib/stripe/resources/v2/billing/rate_card.rb', line 12

def self.object_name
  "v2.billing.rate_card"
end