Class: Stripe::V2::Billing::RateCardModifyRatesParams::RatesToCreate::MeteredItemData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::RateCardModifyRatesParams::RatesToCreate::MeteredItemData
- Defined in:
- lib/stripe/params/v2/billing/rate_card_modify_rates_params.rb
Defined Under Namespace
Classes: MeterSegmentCondition
Instance Attribute Summary collapse
-
#display_name ⇒ Object
Description that customers see in the invoice line item.
-
#lookup_key ⇒ Object
An internal key you can use to search for a particular metered item.
-
#meter ⇒ Object
ID of the Meter that measures usage for this Metered Item.
-
#meter_segment_conditions ⇒ Object
Optional array of Meter segments to filter event dimension keys for billing.
-
#unit_label ⇒ Object
The unit to use when displaying prices for this billable item in places like Checkout.
Instance Method Summary collapse
-
#initialize(display_name: nil, lookup_key: nil, meter: nil, meter_segment_conditions: nil, unit_label: nil) ⇒ MeteredItemData
constructor
A new instance of MeteredItemData.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(display_name: nil, lookup_key: nil, meter: nil, meter_segment_conditions: nil, unit_label: nil) ⇒ MeteredItemData
Returns a new instance of MeteredItemData.
38 39 40 41 42 43 44 45 46 47 48 49 50 |
# File 'lib/stripe/params/v2/billing/rate_card_modify_rates_params.rb', line 38 def initialize( display_name: nil, lookup_key: nil, meter: nil, meter_segment_conditions: nil, unit_label: nil ) @display_name = display_name @lookup_key = lookup_key @meter = meter @meter_segment_conditions = meter_segment_conditions @unit_label = unit_label end |
Instance Attribute Details
#display_name ⇒ Object
Description that customers see in the invoice line item. Maximum length of 250 characters.
23 24 25 |
# File 'lib/stripe/params/v2/billing/rate_card_modify_rates_params.rb', line 23 def display_name @display_name end |
#lookup_key ⇒ Object
An internal key you can use to search for a particular metered item. Must be unique among metered items. Maximum length of 200 characters.
27 28 29 |
# File 'lib/stripe/params/v2/billing/rate_card_modify_rates_params.rb', line 27 def lookup_key @lookup_key end |
#meter ⇒ Object
ID of the Meter that measures usage for this Metered Item.
29 30 31 |
# File 'lib/stripe/params/v2/billing/rate_card_modify_rates_params.rb', line 29 def meter @meter end |
#meter_segment_conditions ⇒ Object
Optional array of Meter segments to filter event dimension keys for billing.
31 32 33 |
# File 'lib/stripe/params/v2/billing/rate_card_modify_rates_params.rb', line 31 def meter_segment_conditions @meter_segment_conditions end |
#unit_label ⇒ Object
The unit to use when displaying prices for this billable item in places like Checkout. For example, set this field to “CPU-hour” for Checkout to display “(price) per CPU-hour”, or “1 million events” to display “(price) per 1 million events”. Maximum length of 100 characters.
36 37 38 |
# File 'lib/stripe/params/v2/billing/rate_card_modify_rates_params.rb', line 36 def unit_label @unit_label end |