Class: Stripe::V2::Billing::RateCardRate::CustomPricingUnitAmount
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::RateCardRate::CustomPricingUnitAmount
- Defined in:
- lib/stripe/resources/v2/billing/rate_card_rate.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#id ⇒ Object
readonly
The id of the custom pricing unit.
-
#value ⇒ Object
readonly
The unit value for the custom pricing unit, as a string.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#id ⇒ Object (readonly)
The id of the custom pricing unit.
15 16 17 |
# File 'lib/stripe/resources/v2/billing/rate_card_rate.rb', line 15 def id @id end |
#value ⇒ Object (readonly)
The unit value for the custom pricing unit, as a string.
17 18 19 |
# File 'lib/stripe/resources/v2/billing/rate_card_rate.rb', line 17 def value @value end |