Class: Stripe::V2::Billing::RateCardService::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/billing/rate_card_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(currency: nil, display_name: nil, lookup_key: nil, metadata: nil, service_interval: nil, service_interval_count: nil, tax_behavior: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/stripe/services/v2/billing/rate_card_service.rb', line 54

def initialize(
  currency: nil,
  display_name: nil,
  lookup_key: nil,
  metadata: nil,
  service_interval: nil,
  service_interval_count: nil,
  tax_behavior: nil
)
  @currency = currency
  @display_name = display_name
  @lookup_key = lookup_key
  @metadata = 
  @service_interval = service_interval
  @service_interval_count = service_interval_count
  @tax_behavior = tax_behavior
end

Instance Attribute Details

#currencyObject

The currency of this RateCard.



34
35
36
# File 'lib/stripe/services/v2/billing/rate_card_service.rb', line 34

def currency
  @currency
end

#display_nameObject

A customer-facing name for the RateCard. This name is used in Stripe-hosted products like the Customer Portal and Checkout. It does not show up on Invoices. Maximum length of 250 characters.



38
39
40
# File 'lib/stripe/services/v2/billing/rate_card_service.rb', line 38

def display_name
  @display_name
end

#lookup_keyObject

An internal key you can use to search for a particular RateCard. Maximum length of 200 characters.



40
41
42
# File 'lib/stripe/services/v2/billing/rate_card_service.rb', line 40

def lookup_key
  @lookup_key
end

#metadataObject

Set of [key-value pairs](/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



42
43
44
# File 'lib/stripe/services/v2/billing/rate_card_service.rb', line 42

def 
  @metadata
end

#service_intervalObject

The interval for assessing service. For example, a monthly RateCard with a rate of $1 for the first 10 “workloads” and $2 thereafter means “$1 per workload up to 10 workloads during a month of service.” This is similar to but distinct from billing interval; the service interval deals with the rate at which the customer accumulates fees, while the billing interval in Cadence deals with the rate the customer is billed.



47
48
49
# File 'lib/stripe/services/v2/billing/rate_card_service.rb', line 47

def service_interval
  @service_interval
end

#service_interval_countObject

The length of the interval for assessing service. For example, set this to 3 and ‘service_interval` to `“month”` in order to specify quarterly service.



50
51
52
# File 'lib/stripe/services/v2/billing/rate_card_service.rb', line 50

def service_interval_count
  @service_interval_count
end

#tax_behaviorObject

The Stripe Tax tax behavior - whether the rates are inclusive or exclusive of tax.



52
53
54
# File 'lib/stripe/services/v2/billing/rate_card_service.rb', line 52

def tax_behavior
  @tax_behavior
end