Class: Stripe::V2::Billing::RateCardService::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::RateCardService::UpdateParams
- Defined in:
- lib/stripe/services/v2/billing/rate_card_service.rb
Instance Attribute Summary collapse
-
#active ⇒ Object
Sets whether the RateCard is active.
-
#display_name ⇒ Object
A customer-facing name for the RateCard.
-
#live_version ⇒ Object
Changes the version that new RateCard activations will use.
-
#lookup_key ⇒ Object
An internal key you can use to search for a particular RateCard.
-
#metadata ⇒ Object
Set of [key-value pairs](/docs/api/metadata) that you can attach to an object.
Instance Method Summary collapse
-
#initialize(active: nil, display_name: nil, live_version: nil, lookup_key: nil, metadata: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(active: nil, display_name: nil, live_version: nil, lookup_key: nil, metadata: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/stripe/services/v2/billing/rate_card_service.rb', line 90 def initialize( active: nil, display_name: nil, live_version: nil, lookup_key: nil, metadata: nil ) @active = active @display_name = display_name @live_version = live_version @lookup_key = lookup_key @metadata = end |
Instance Attribute Details
#active ⇒ Object
Sets whether the RateCard is active. Inactive RateCards cannot be used in new activations or have new rates added.
77 78 79 |
# File 'lib/stripe/services/v2/billing/rate_card_service.rb', line 77 def active @active end |
#display_name ⇒ Object
A customer-facing name for the RateCard. This name is used in Stripe-hosted products like the Customer Portal and Checkout. It does not show up on Invoices. Maximum length of 250 characters.
81 82 83 |
# File 'lib/stripe/services/v2/billing/rate_card_service.rb', line 81 def display_name @display_name end |
#live_version ⇒ Object
Changes the version that new RateCard activations will use. Providing ‘live_version = “latest”` will set the RateCard’s ‘live_version` to its latest version.
84 85 86 |
# File 'lib/stripe/services/v2/billing/rate_card_service.rb', line 84 def live_version @live_version end |
#lookup_key ⇒ Object
An internal key you can use to search for a particular RateCard. Maximum length of 200 characters.
86 87 88 |
# File 'lib/stripe/services/v2/billing/rate_card_service.rb', line 86 def lookup_key @lookup_key end |
#metadata ⇒ Object
Set of [key-value pairs](/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
88 89 90 |
# File 'lib/stripe/services/v2/billing/rate_card_service.rb', line 88 def @metadata end |