Class: Stripe::V2::Billing::RateCardSubscriptionListParams::Payer
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::RateCardSubscriptionListParams::Payer
- Defined in:
- lib/stripe/params/v2/billing/rate_card_subscription_list_params.rb
Instance Attribute Summary collapse
-
#customer ⇒ Object
The ID of the Customer object.
-
#type ⇒ Object
A string identifying the type of the payer.
Instance Method Summary collapse
-
#initialize(customer: nil, type: nil) ⇒ Payer
constructor
A new instance of Payer.
Methods inherited from RequestParams
Constructor Details
#initialize(customer: nil, type: nil) ⇒ Payer
Returns a new instance of Payer.
14 15 16 17 |
# File 'lib/stripe/params/v2/billing/rate_card_subscription_list_params.rb', line 14 def initialize(customer: nil, type: nil) @customer = customer @type = type end |
Instance Attribute Details
#customer ⇒ Object
The ID of the Customer object. If provided, only the Rate Card Subscriptions that are subscribed on the Billing Cadences with the specified payer will be returned.
10 11 12 |
# File 'lib/stripe/params/v2/billing/rate_card_subscription_list_params.rb', line 10 def customer @customer end |
#type ⇒ Object
A string identifying the type of the payer. Currently the only supported value is ‘customer`.
12 13 14 |
# File 'lib/stripe/params/v2/billing/rate_card_subscription_list_params.rb', line 12 def type @type end |