Class: Stripe::V2::Billing::RateCardSubscriptionService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::V2::Billing::RateCardSubscriptionService
- Defined in:
- lib/stripe/services/v2/billing/rate_card_subscription_service.rb
Instance Method Summary collapse
-
#cancel(id, params = {}, opts = {}) ⇒ Object
Cancel an existing, active Rate Card Subscription.
-
#create(params = {}, opts = {}) ⇒ Object
Create a Rate Card Subscription to bill a Rate Card on a specified Billing Cadence.
-
#list(params = {}, opts = {}) ⇒ Object
List all Rate Card Subscription objects.
-
#retrieve(id, params = {}, opts = {}) ⇒ Object
Retrieve a Rate Card Subscription by ID.
-
#update(id, params = {}, opts = {}) ⇒ Object
Update fields on an existing, active Rate Card Subscription.
Methods inherited from StripeService
#initialize, #request, #request_stream
Constructor Details
This class inherits a constructor from Stripe::StripeService
Instance Method Details
#cancel(id, params = {}, opts = {}) ⇒ Object
Cancel an existing, active Rate Card Subscription.
9 10 11 12 13 14 15 16 17 |
# File 'lib/stripe/services/v2/billing/rate_card_subscription_service.rb', line 9 def cancel(id, params = {}, opts = {}) request( method: :post, path: format("/v2/billing/rate_card_subscriptions/%<id>s/cancel", { id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |
#create(params = {}, opts = {}) ⇒ Object
Create a Rate Card Subscription to bill a Rate Card on a specified Billing Cadence.
20 21 22 23 24 25 26 27 28 |
# File 'lib/stripe/services/v2/billing/rate_card_subscription_service.rb', line 20 def create(params = {}, opts = {}) request( method: :post, path: "/v2/billing/rate_card_subscriptions", params: params, opts: opts, base_address: :api ) end |
#list(params = {}, opts = {}) ⇒ Object
List all Rate Card Subscription objects.
31 32 33 34 35 36 37 38 39 |
# File 'lib/stripe/services/v2/billing/rate_card_subscription_service.rb', line 31 def list(params = {}, opts = {}) request( method: :get, path: "/v2/billing/rate_card_subscriptions", params: params, opts: opts, base_address: :api ) end |
#retrieve(id, params = {}, opts = {}) ⇒ Object
Retrieve a Rate Card Subscription by ID.
42 43 44 45 46 47 48 49 50 |
# File 'lib/stripe/services/v2/billing/rate_card_subscription_service.rb', line 42 def retrieve(id, params = {}, opts = {}) request( method: :get, path: format("/v2/billing/rate_card_subscriptions/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |
#update(id, params = {}, opts = {}) ⇒ Object
Update fields on an existing, active Rate Card Subscription.
53 54 55 56 57 58 59 60 61 |
# File 'lib/stripe/services/v2/billing/rate_card_subscription_service.rb', line 53 def update(id, params = {}, opts = {}) request( method: :post, path: format("/v2/billing/rate_card_subscriptions/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |