Class: Stripe::V2::Billing::RateCardUpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/v2/billing/rate_card_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(active: nil, display_name: nil, live_version: nil, lookup_key: nil, metadata: nil) ⇒ RateCardUpdateParams

Returns a new instance of RateCardUpdateParams.



22
23
24
25
26
27
28
29
30
31
32
33
34
# File 'lib/stripe/params/v2/billing/rate_card_update_params.rb', line 22

def initialize(
  active: nil,
  display_name: nil,
  live_version: nil,
  lookup_key: nil,
  metadata: nil
)
  @active = active
  @display_name = display_name
  @live_version = live_version
  @lookup_key = lookup_key
  @metadata = 
end

Instance Attribute Details

#activeObject

Sets whether the RateCard is active. Inactive RateCards cannot be used in new activations or have new rates added.



9
10
11
# File 'lib/stripe/params/v2/billing/rate_card_update_params.rb', line 9

def active
  @active
end

#display_nameObject

A customer-facing name for the RateCard. This name is used in Stripe-hosted products like the Customer Portal and Checkout. It does not show up on Invoices. Maximum length of 250 characters.



13
14
15
# File 'lib/stripe/params/v2/billing/rate_card_update_params.rb', line 13

def display_name
  @display_name
end

#live_versionObject

Changes the version that new RateCard activations will use. Providing ‘live_version = “latest”` will set the RateCard’s ‘live_version` to its latest version.



16
17
18
# File 'lib/stripe/params/v2/billing/rate_card_update_params.rb', line 16

def live_version
  @live_version
end

#lookup_keyObject

An internal key you can use to search for a particular RateCard. Maximum length of 200 characters.



18
19
20
# File 'lib/stripe/params/v2/billing/rate_card_update_params.rb', line 18

def lookup_key
  @lookup_key
end

#metadataObject

Set of [key-value pairs](/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



20
21
22
# File 'lib/stripe/params/v2/billing/rate_card_update_params.rb', line 20

def 
  @metadata
end