Class: Stripe::V2::Billing::RateCardVersion
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Billing::RateCardVersion
- Defined in:
- lib/stripe/resources/v2/billing/rate_card_version.rb
Constant Summary collapse
- OBJECT_NAME =
"v2.billing.rate_card_version"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#created ⇒ Object
readonly
Timestamp of when the object was created.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#rate_card_id ⇒ Object
readonly
The ID of the Rate Card that this version belongs to.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#created ⇒ Object (readonly)
Timestamp of when the object was created.
14 15 16 |
# File 'lib/stripe/resources/v2/billing/rate_card_version.rb', line 14 def created @created end |
#id ⇒ Object (readonly)
Unique identifier for the object.
16 17 18 |
# File 'lib/stripe/resources/v2/billing/rate_card_version.rb', line 16 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
22 23 24 |
# File 'lib/stripe/resources/v2/billing/rate_card_version.rb', line 22 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
18 19 20 |
# File 'lib/stripe/resources/v2/billing/rate_card_version.rb', line 18 def object @object end |
#rate_card_id ⇒ Object (readonly)
The ID of the Rate Card that this version belongs to.
20 21 22 |
# File 'lib/stripe/resources/v2/billing/rate_card_version.rb', line 20 def rate_card_id @rate_card_id end |
Class Method Details
.object_name ⇒ Object
9 10 11 |
# File 'lib/stripe/resources/v2/billing/rate_card_version.rb', line 9 def self.object_name "v2.billing.rate_card_version" end |