Class: Stripe::V2::Billing::RateCards::RateCreateParams::CustomPricingUnitAmount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::RateCards::RateCreateParams::CustomPricingUnitAmount
- Defined in:
- lib/stripe/params/v2/billing/rate_cards/rate_create_params.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
The id of the custom pricing unit.
-
#value ⇒ Object
The unit value for the custom pricing unit, as a string.
Instance Method Summary collapse
-
#initialize(id: nil, value: nil) ⇒ CustomPricingUnitAmount
constructor
A new instance of CustomPricingUnitAmount.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(id: nil, value: nil) ⇒ CustomPricingUnitAmount
Returns a new instance of CustomPricingUnitAmount.
15 16 17 18 |
# File 'lib/stripe/params/v2/billing/rate_cards/rate_create_params.rb', line 15 def initialize(id: nil, value: nil) @id = id @value = value end |
Instance Attribute Details
#id ⇒ Object
The id of the custom pricing unit.
11 12 13 |
# File 'lib/stripe/params/v2/billing/rate_cards/rate_create_params.rb', line 11 def id @id end |
#value ⇒ Object
The unit value for the custom pricing unit, as a string.
13 14 15 |
# File 'lib/stripe/params/v2/billing/rate_cards/rate_create_params.rb', line 13 def value @value end |