Class: Stripe::V2::Billing::RateCards::RateService::CreateParams::CustomPricingUnitAmount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::RateCards::RateService::CreateParams::CustomPricingUnitAmount
- Defined in:
- lib/stripe/services/v2/billing/rate_cards/rate_service.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
The id of the custom pricing unit.
-
#value ⇒ Object
The unit value for the custom pricing unit, as a string.
Instance Method Summary collapse
-
#initialize(id: nil, value: nil) ⇒ CustomPricingUnitAmount
constructor
A new instance of CustomPricingUnitAmount.
Methods inherited from RequestParams
Constructor Details
#initialize(id: nil, value: nil) ⇒ CustomPricingUnitAmount
Returns a new instance of CustomPricingUnitAmount.
31 32 33 34 |
# File 'lib/stripe/services/v2/billing/rate_cards/rate_service.rb', line 31 def initialize(id: nil, value: nil) @id = id @value = value end |
Instance Attribute Details
#id ⇒ Object
The id of the custom pricing unit.
27 28 29 |
# File 'lib/stripe/services/v2/billing/rate_cards/rate_service.rb', line 27 def id @id end |
#value ⇒ Object
The unit value for the custom pricing unit, as a string.
29 30 31 |
# File 'lib/stripe/services/v2/billing/rate_cards/rate_service.rb', line 29 def value @value end |