Class: Stripe::V2::Billing::RateCards::RateService::CreateParams::Tier

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/billing/rate_cards/rate_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(flat_amount: nil, unit_amount: nil, up_to_decimal: nil, up_to_inf: nil) ⇒ Tier

Returns a new instance of Tier.



49
50
51
52
53
54
# File 'lib/stripe/services/v2/billing/rate_cards/rate_service.rb', line 49

def initialize(flat_amount: nil, unit_amount: nil, up_to_decimal: nil, up_to_inf: nil)
  @flat_amount = flat_amount
  @unit_amount = unit_amount
  @up_to_decimal = up_to_decimal
  @up_to_inf = up_to_inf
end

Instance Attribute Details

#flat_amountObject

Price for the entire tier, represented as a decimal string in minor currency units with at most 12 decimal places.



39
40
41
# File 'lib/stripe/services/v2/billing/rate_cards/rate_service.rb', line 39

def flat_amount
  @flat_amount
end

#unit_amountObject

Per-unit price for units included in this tier, represented as a decimal string in minor currency units with at most 12 decimal places.



42
43
44
# File 'lib/stripe/services/v2/billing/rate_cards/rate_service.rb', line 42

def unit_amount
  @unit_amount
end

#up_to_decimalObject

Up to and including this quantity will be contained in the tier. Only one of ‘up_to_decimal` and `up_to_inf` may be set.



45
46
47
# File 'lib/stripe/services/v2/billing/rate_cards/rate_service.rb', line 45

def up_to_decimal
  @up_to_decimal
end

#up_to_infObject

No upper bound to this tier. Only one of ‘up_to_decimal` and `up_to_inf` may be set.



47
48
49
# File 'lib/stripe/services/v2/billing/rate_cards/rate_service.rb', line 47

def up_to_inf
  @up_to_inf
end