Class: Stripe::V2::Billing::ServiceAction::CreditGrantPerTenant

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/billing/service_action.rb

Defined Under Namespace

Classes: Amount, ApplicabilityConfig, ExpiryConfig

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

The amount of the credit grant.



216
217
218
# File 'lib/stripe/resources/v2/billing/service_action.rb', line 216

def amount
  @amount
end

#applicability_configObject (readonly)

Defines the scope where the credit grant is applicable.



218
219
220
# File 'lib/stripe/resources/v2/billing/service_action.rb', line 218

def applicability_config
  @applicability_config
end

#categoryObject (readonly)

The category of the credit grant.



220
221
222
# File 'lib/stripe/resources/v2/billing/service_action.rb', line 220

def category
  @category
end

#expiry_configObject (readonly)

The expiry configuration for the credit grant.



222
223
224
# File 'lib/stripe/resources/v2/billing/service_action.rb', line 222

def expiry_config
  @expiry_config
end

#nameObject (readonly)

Customer-facing name for the credit grant.



224
225
226
# File 'lib/stripe/resources/v2/billing/service_action.rb', line 224

def name
  @name
end

#priorityObject (readonly)

The desired priority for applying this credit grant. If not specified, it will be set to the default value of 50. The highest priority is 0 and the lowest is 100.



226
227
228
# File 'lib/stripe/resources/v2/billing/service_action.rb', line 226

def priority
  @priority
end

Class Method Details

.field_encodingsObject



240
241
242
243
244
245
246
247
# File 'lib/stripe/resources/v2/billing/service_action.rb', line 240

def self.field_encodings
  @field_encodings = {
    amount: {
      kind: :object,
      fields: { custom_pricing_unit: { kind: :object, fields: { value: :decimal_string } } },
    },
  }
end

.field_remappingsObject



236
237
238
# File 'lib/stripe/resources/v2/billing/service_action.rb', line 236

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



228
229
230
231
232
233
234
# File 'lib/stripe/resources/v2/billing/service_action.rb', line 228

def self.inner_class_types
  @inner_class_types = {
    amount: Amount,
    applicability_config: ApplicabilityConfig,
    expiry_config: ExpiryConfig,
  }
end