Class: Stripe::V2::Billing::ServiceAction::CreditGrantPerTenant::Amount
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::ServiceAction::CreditGrantPerTenant::Amount
- Defined in:
- lib/stripe/resources/v2/billing/service_action.rb
Defined Under Namespace
Classes: CustomPricingUnit
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#custom_pricing_unit ⇒ Object
readonly
The custom pricing unit amount of the credit grant.
-
#monetary ⇒ Object
readonly
The monetary amount of the credit grant.
-
#type ⇒ Object
readonly
The type of the credit grant amount.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#custom_pricing_unit ⇒ Object (readonly)
The custom pricing unit amount of the credit grant. Required if ‘type` is `custom_pricing_unit`.
65 66 67 |
# File 'lib/stripe/resources/v2/billing/service_action.rb', line 65 def custom_pricing_unit @custom_pricing_unit end |
#monetary ⇒ Object (readonly)
The monetary amount of the credit grant. Required if ‘type` is `monetary`.
67 68 69 |
# File 'lib/stripe/resources/v2/billing/service_action.rb', line 67 def monetary @monetary end |
#type ⇒ Object (readonly)
The type of the credit grant amount. We currently support ‘monetary` and `custom_pricing_unit` billing credits.
63 64 65 |
# File 'lib/stripe/resources/v2/billing/service_action.rb', line 63 def type @type end |