Class: Stripe::V2::Billing::ServiceAction::CreditGrantPerTenant::ApplicabilityConfig::Scope

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/billing/service_action.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#billable_itemsObject (readonly)

The billable items to apply the credit grant to.



179
180
181
# File 'lib/stripe/resources/v2/billing/service_action.rb', line 179

def billable_items
  @billable_items
end

#price_typeObject (readonly)

The price type that credit grants can apply to. Stripe supports the metered price type, which applies to metered prices and rate cards. Cannot be used in combination with billable_items.



181
182
183
# File 'lib/stripe/resources/v2/billing/service_action.rb', line 181

def price_type
  @price_type
end

Class Method Details

.field_remappingsObject



187
188
189
# File 'lib/stripe/resources/v2/billing/service_action.rb', line 187

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



183
184
185
# File 'lib/stripe/resources/v2/billing/service_action.rb', line 183

def self.inner_class_types
  @inner_class_types = {}
end