Class: Stripe::V2::Billing::ServiceActionCreateParams::CreditGrant::Amount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::ServiceActionCreateParams::CreditGrant::Amount
- Defined in:
- lib/stripe/params/v2/billing/service_action_create_params.rb
Defined Under Namespace
Classes: CustomPricingUnit
Instance Attribute Summary collapse
-
#custom_pricing_unit ⇒ Object
The custom pricing unit amount of the credit grant.
-
#monetary ⇒ Object
The monetary amount of the credit grant.
-
#type ⇒ Object
The type of the credit grant amount.
Instance Method Summary collapse
-
#initialize(type: nil, custom_pricing_unit: nil, monetary: nil) ⇒ Amount
constructor
A new instance of Amount.
Methods inherited from RequestParams
Constructor Details
#initialize(type: nil, custom_pricing_unit: nil, monetary: nil) ⇒ Amount
Returns a new instance of Amount.
28 29 30 31 32 |
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 28 def initialize(type: nil, custom_pricing_unit: nil, monetary: nil) @type = type @custom_pricing_unit = custom_pricing_unit @monetary = monetary end |
Instance Attribute Details
#custom_pricing_unit ⇒ Object
The custom pricing unit amount of the credit grant. Required if ‘type` is `custom_pricing_unit`.
24 25 26 |
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 24 def custom_pricing_unit @custom_pricing_unit end |
#monetary ⇒ Object
The monetary amount of the credit grant. Required if ‘type` is `monetary`.
26 27 28 |
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 26 def monetary @monetary end |
#type ⇒ Object
The type of the credit grant amount. We currently support ‘monetary` and `custom_pricing_unit` billing credits.
22 23 24 |
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 22 def type @type end |