Class: Stripe::V2::Billing::ServiceActionCreateParams::CreditGrant::Amount::CustomPricingUnit
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::ServiceActionCreateParams::CreditGrant::Amount::CustomPricingUnit
- Defined in:
- lib/stripe/params/v2/billing/service_action_create_params.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
The id of the custom pricing unit.
-
#value ⇒ Object
The value of the credit grant, decimal value represented as a string.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id: nil, value: nil) ⇒ CustomPricingUnit
constructor
A new instance of CustomPricingUnit.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(id: nil, value: nil) ⇒ CustomPricingUnit
Returns a new instance of CustomPricingUnit.
16 17 18 19 |
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 16 def initialize(id: nil, value: nil) @id = id @value = value end |
Instance Attribute Details
#id ⇒ Object
The id of the custom pricing unit.
12 13 14 |
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 12 def id @id end |
#value ⇒ Object
The value of the credit grant, decimal value represented as a string.
14 15 16 |
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 14 def value @value end |
Class Method Details
.field_encodings ⇒ Object
21 22 23 |
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 21 def self.field_encodings @field_encodings = { value: :decimal_string } end |