Class: Stripe::V2::Billing::ServiceActionCreateParams::CreditGrantPerTenant::Amount::CustomPricingUnit
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::ServiceActionCreateParams::CreditGrantPerTenant::Amount::CustomPricingUnit
- Defined in:
- lib/stripe/params/v2/billing/service_action_create_params.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
The id of the custom pricing unit.
-
#value ⇒ Object
The value of the credit grant, decimal value represented as a string.
Instance Method Summary collapse
-
#initialize(id: nil, value: nil) ⇒ CustomPricingUnit
constructor
A new instance of CustomPricingUnit.
Methods inherited from RequestParams
Constructor Details
#initialize(id: nil, value: nil) ⇒ CustomPricingUnit
Returns a new instance of CustomPricingUnit.
113 114 115 116 |
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 113 def initialize(id: nil, value: nil) @id = id @value = value end |
Instance Attribute Details
#id ⇒ Object
The id of the custom pricing unit.
109 110 111 |
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 109 def id @id end |
#value ⇒ Object
The value of the credit grant, decimal value represented as a string.
111 112 113 |
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 111 def value @value end |