Class: Stripe::V2::Billing::ServiceActionCreateParams::CreditGrantPerTenant::GrantCondition
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::ServiceActionCreateParams::CreditGrantPerTenant::GrantCondition
- Defined in:
- lib/stripe/params/v2/billing/service_action_create_params.rb
Defined Under Namespace
Classes: MeterEventFirstPerPeriod
Instance Attribute Summary collapse
-
#meter_event_first_per_period ⇒ Object
The grant condition for the meter event first per period.
-
#type ⇒ Object
The type of the grant condition.
Instance Method Summary collapse
-
#initialize(meter_event_first_per_period: nil, type: nil) ⇒ GrantCondition
constructor
A new instance of GrantCondition.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(meter_event_first_per_period: nil, type: nil) ⇒ GrantCondition
Returns a new instance of GrantCondition.
214 215 216 217 |
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 214 def initialize(meter_event_first_per_period: nil, type: nil) @meter_event_first_per_period = meter_event_first_per_period @type = type end |
Instance Attribute Details
#meter_event_first_per_period ⇒ Object
The grant condition for the meter event first per period.
210 211 212 |
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 210 def meter_event_first_per_period @meter_event_first_per_period end |
#type ⇒ Object
The type of the grant condition. We currently support ‘meter_event_first_per_period`.
212 213 214 |
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 212 def type @type end |