Class: Stripe::V2::Billing::ServiceActionService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::ServiceActionService::CreateParams
- Defined in:
- lib/stripe/services/v2/billing/service_action_service.rb
Defined Under Namespace
Classes: CreditGrant, CreditGrantPerTenant
Instance Attribute Summary collapse
-
#credit_grant ⇒ Object
Details for the credit grant.
-
#credit_grant_per_tenant ⇒ Object
Details for the credit grant per tenant.
-
#lookup_key ⇒ Object
An internal key you can use to search for this service action.
-
#service_interval ⇒ Object
The interval for assessing service.
-
#service_interval_count ⇒ Object
The length of the interval for assessing service.
-
#type ⇒ Object
The type of the service action.
Instance Method Summary collapse
-
#initialize(lookup_key: nil, service_interval: nil, service_interval_count: nil, type: nil, credit_grant: nil, credit_grant_per_tenant: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(lookup_key: nil, service_interval: nil, service_interval_count: nil, type: nil, credit_grant: nil, credit_grant_per_tenant: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 |
# File 'lib/stripe/services/v2/billing/service_action_service.rb', line 237 def initialize( lookup_key: nil, service_interval: nil, service_interval_count: nil, type: nil, credit_grant: nil, credit_grant_per_tenant: nil ) @lookup_key = lookup_key @service_interval = service_interval @service_interval_count = service_interval_count @type = type @credit_grant = credit_grant @credit_grant_per_tenant = credit_grant_per_tenant end |
Instance Attribute Details
#credit_grant ⇒ Object
Details for the credit grant. Required if ‘type` is `credit_grant`.
233 234 235 |
# File 'lib/stripe/services/v2/billing/service_action_service.rb', line 233 def credit_grant @credit_grant end |
#credit_grant_per_tenant ⇒ Object
Details for the credit grant per tenant. Required if ‘type` is `credit_grant_per_tenant`.
235 236 237 |
# File 'lib/stripe/services/v2/billing/service_action_service.rb', line 235 def credit_grant_per_tenant @credit_grant_per_tenant end |
#lookup_key ⇒ Object
An internal key you can use to search for this service action. Maximum length of 200 characters.
225 226 227 |
# File 'lib/stripe/services/v2/billing/service_action_service.rb', line 225 def lookup_key @lookup_key end |
#service_interval ⇒ Object
The interval for assessing service.
227 228 229 |
# File 'lib/stripe/services/v2/billing/service_action_service.rb', line 227 def service_interval @service_interval end |
#service_interval_count ⇒ Object
The length of the interval for assessing service.
229 230 231 |
# File 'lib/stripe/services/v2/billing/service_action_service.rb', line 229 def service_interval_count @service_interval_count end |
#type ⇒ Object
The type of the service action.
231 232 233 |
# File 'lib/stripe/services/v2/billing/service_action_service.rb', line 231 def type @type end |