Class: Stripe::V2::Billing::ServiceActionService::CreateParams::CreditGrant
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::ServiceActionService::CreateParams::CreditGrant
- Defined in:
- lib/stripe/services/v2/billing/service_action_service.rb
Defined Under Namespace
Classes: Amount, ApplicabilityConfig, ExpiryConfig
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount of the credit grant.
-
#applicability_config ⇒ Object
Defines the scope where the credit grant is applicable.
-
#expiry_config ⇒ Object
The expiry configuration for the credit grant.
-
#name ⇒ Object
A descriptive name shown in dashboard.
Instance Method Summary collapse
-
#initialize(amount: nil, applicability_config: nil, expiry_config: nil, name: nil) ⇒ CreditGrant
constructor
A new instance of CreditGrant.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, applicability_config: nil, expiry_config: nil, name: nil) ⇒ CreditGrant
Returns a new instance of CreditGrant.
73 74 75 76 77 78 |
# File 'lib/stripe/services/v2/billing/service_action_service.rb', line 73 def initialize(amount: nil, applicability_config: nil, expiry_config: nil, name: nil) @amount = amount @applicability_config = applicability_config @expiry_config = expiry_config @name = name end |
Instance Attribute Details
#amount ⇒ Object
The amount of the credit grant.
65 66 67 |
# File 'lib/stripe/services/v2/billing/service_action_service.rb', line 65 def amount @amount end |
#applicability_config ⇒ Object
Defines the scope where the credit grant is applicable.
67 68 69 |
# File 'lib/stripe/services/v2/billing/service_action_service.rb', line 67 def applicability_config @applicability_config end |
#expiry_config ⇒ Object
The expiry configuration for the credit grant.
69 70 71 |
# File 'lib/stripe/services/v2/billing/service_action_service.rb', line 69 def expiry_config @expiry_config end |
#name ⇒ Object
A descriptive name shown in dashboard.
71 72 73 |
# File 'lib/stripe/services/v2/billing/service_action_service.rb', line 71 def name @name end |