Class: Stripe::V2::Billing::ServiceActionService::CreateParams::CreditGrant::Amount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::ServiceActionService::CreateParams::CreditGrant::Amount
- Defined in:
- lib/stripe/services/v2/billing/service_action_service.rb
Defined Under Namespace
Classes: CustomPricingUnit
Instance Attribute Summary collapse
-
#custom_pricing_unit ⇒ Object
The custom pricing unit amount of the credit grant.
-
#monetary ⇒ Object
The monetary amount of the credit grant.
-
#type ⇒ Object
The type of the credit grant amount.
Instance Method Summary collapse
-
#initialize(type: nil, custom_pricing_unit: nil, monetary: nil) ⇒ Amount
constructor
A new instance of Amount.
Methods inherited from RequestParams
Constructor Details
#initialize(type: nil, custom_pricing_unit: nil, monetary: nil) ⇒ Amount
Returns a new instance of Amount.
29 30 31 32 33 |
# File 'lib/stripe/services/v2/billing/service_action_service.rb', line 29 def initialize(type: nil, custom_pricing_unit: nil, monetary: nil) @type = type @custom_pricing_unit = custom_pricing_unit @monetary = monetary end |
Instance Attribute Details
#custom_pricing_unit ⇒ Object
The custom pricing unit amount of the credit grant. Required if ‘type` is `custom_pricing_unit`.
25 26 27 |
# File 'lib/stripe/services/v2/billing/service_action_service.rb', line 25 def custom_pricing_unit @custom_pricing_unit end |
#monetary ⇒ Object
The monetary amount of the credit grant. Required if ‘type` is `monetary`.
27 28 29 |
# File 'lib/stripe/services/v2/billing/service_action_service.rb', line 27 def monetary @monetary end |
#type ⇒ Object
The type of the credit grant amount. We currently support ‘monetary` and `custom_pricing_unit` billing credits.
23 24 25 |
# File 'lib/stripe/services/v2/billing/service_action_service.rb', line 23 def type @type end |