Class: Stripe::V2::Billing::ServiceActionService::CreateParams::CreditGrantPerTenant

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/billing/service_action_service.rb

Defined Under Namespace

Classes: Amount, ApplicabilityConfig, ExpiryConfig, GrantCondition

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, applicability_config: nil, category: nil, expiry_config: nil, grant_condition: nil, name: nil, priority: nil) ⇒ CreditGrantPerTenant

Returns a new instance of CreditGrantPerTenant.



206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/stripe/services/v2/billing/service_action_service.rb', line 206

def initialize(
  amount: nil,
  applicability_config: nil,
  category: nil,
  expiry_config: nil,
  grant_condition: nil,
  name: nil,
  priority: nil
)
  @amount = amount
  @applicability_config = applicability_config
  @category = category
  @expiry_config = expiry_config
  @grant_condition = grant_condition
  @name = name
  @priority = priority
end

Instance Attribute Details

#amountObject

The amount of the credit grant.



192
193
194
# File 'lib/stripe/services/v2/billing/service_action_service.rb', line 192

def amount
  @amount
end

#applicability_configObject

Defines the scope where the credit grant is applicable.



194
195
196
# File 'lib/stripe/services/v2/billing/service_action_service.rb', line 194

def applicability_config
  @applicability_config
end

#categoryObject

The category of the credit grant.



196
197
198
# File 'lib/stripe/services/v2/billing/service_action_service.rb', line 196

def category
  @category
end

#expiry_configObject

The expiry configuration for the credit grant.



198
199
200
# File 'lib/stripe/services/v2/billing/service_action_service.rb', line 198

def expiry_config
  @expiry_config
end

#grant_conditionObject

The grant condition for the credit grant.



200
201
202
# File 'lib/stripe/services/v2/billing/service_action_service.rb', line 200

def grant_condition
  @grant_condition
end

#nameObject

Customer-facing name for the credit grant.



202
203
204
# File 'lib/stripe/services/v2/billing/service_action_service.rb', line 202

def name
  @name
end

#priorityObject

The desired priority for applying this credit grant. If not specified, it will be set to the default value of 50. The highest priority is 0 and the lowest is 100.



204
205
206
# File 'lib/stripe/services/v2/billing/service_action_service.rb', line 204

def priority
  @priority
end