Class: Stripe::V2::Billing::ServiceActionService::CreateParams::CreditGrantPerTenant::Amount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::ServiceActionService::CreateParams::CreditGrantPerTenant::Amount
- Defined in:
- lib/stripe/services/v2/billing/service_action_service.rb
Defined Under Namespace
Classes: CustomPricingUnit
Instance Attribute Summary collapse
-
#custom_pricing_unit ⇒ Object
The custom pricing unit amount of the credit grant.
-
#monetary ⇒ Object
The monetary amount of the credit grant.
-
#type ⇒ Object
The type of the credit grant amount.
Instance Method Summary collapse
-
#initialize(type: nil, custom_pricing_unit: nil, monetary: nil) ⇒ Amount
constructor
A new instance of Amount.
Methods inherited from RequestParams
Constructor Details
#initialize(type: nil, custom_pricing_unit: nil, monetary: nil) ⇒ Amount
Returns a new instance of Amount.
101 102 103 104 105 |
# File 'lib/stripe/services/v2/billing/service_action_service.rb', line 101 def initialize(type: nil, custom_pricing_unit: nil, monetary: nil) @type = type @custom_pricing_unit = custom_pricing_unit @monetary = monetary end |
Instance Attribute Details
#custom_pricing_unit ⇒ Object
The custom pricing unit amount of the credit grant. Required if ‘type` is `custom_pricing_unit`.
97 98 99 |
# File 'lib/stripe/services/v2/billing/service_action_service.rb', line 97 def custom_pricing_unit @custom_pricing_unit end |
#monetary ⇒ Object
The monetary amount of the credit grant. Required if ‘type` is `monetary`.
99 100 101 |
# File 'lib/stripe/services/v2/billing/service_action_service.rb', line 99 def monetary @monetary end |
#type ⇒ Object
The type of the credit grant amount. We currently support ‘monetary` and `custom_pricing_unit` billing credits.
95 96 97 |
# File 'lib/stripe/services/v2/billing/service_action_service.rb', line 95 def type @type end |