Class: Stripe::V2::Billing::ServiceActionService::CreateParams::CreditGrantPerTenant::Amount::CustomPricingUnit
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::ServiceActionService::CreateParams::CreditGrantPerTenant::Amount::CustomPricingUnit
- Defined in:
- lib/stripe/services/v2/billing/service_action_service.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
The id of the custom pricing unit.
-
#value ⇒ Object
The value of the credit grant, decimal value represented as a string.
Instance Method Summary collapse
-
#initialize(id: nil, value: nil) ⇒ CustomPricingUnit
constructor
A new instance of CustomPricingUnit.
Methods inherited from RequestParams
Constructor Details
#initialize(id: nil, value: nil) ⇒ CustomPricingUnit
Returns a new instance of CustomPricingUnit.
89 90 91 92 |
# File 'lib/stripe/services/v2/billing/service_action_service.rb', line 89 def initialize(id: nil, value: nil) @id = id @value = value end |
Instance Attribute Details
#id ⇒ Object
The id of the custom pricing unit.
85 86 87 |
# File 'lib/stripe/services/v2/billing/service_action_service.rb', line 85 def id @id end |
#value ⇒ Object
The value of the credit grant, decimal value represented as a string.
87 88 89 |
# File 'lib/stripe/services/v2/billing/service_action_service.rb', line 87 def value @value end |