Class: Stripe::V2::Billing::ServiceActionService::CreateParams::CreditGrantPerTenant::GrantCondition
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::ServiceActionService::CreateParams::CreditGrantPerTenant::GrantCondition
- Defined in:
- lib/stripe/services/v2/billing/service_action_service.rb
Defined Under Namespace
Classes: MeterEventFirstPerPeriod
Instance Attribute Summary collapse
-
#meter_event_first_per_period ⇒ Object
The grant condition for the meter event first per period.
-
#type ⇒ Object
The type of the grant condition.
Instance Method Summary collapse
-
#initialize(type: nil, meter_event_first_per_period: nil) ⇒ GrantCondition
constructor
A new instance of GrantCondition.
Methods inherited from RequestParams
Constructor Details
#initialize(type: nil, meter_event_first_per_period: nil) ⇒ GrantCondition
Returns a new instance of GrantCondition.
173 174 175 176 |
# File 'lib/stripe/services/v2/billing/service_action_service.rb', line 173 def initialize(type: nil, meter_event_first_per_period: nil) @type = type @meter_event_first_per_period = meter_event_first_per_period end |
Instance Attribute Details
#meter_event_first_per_period ⇒ Object
The grant condition for the meter event first per period.
171 172 173 |
# File 'lib/stripe/services/v2/billing/service_action_service.rb', line 171 def meter_event_first_per_period @meter_event_first_per_period end |
#type ⇒ Object
The type of the grant condition. We currently support ‘meter_event_first_per_period`.
169 170 171 |
# File 'lib/stripe/services/v2/billing/service_action_service.rb', line 169 def type @type end |