Class: Stripe::V2::Billing::ServiceActionUpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::ServiceActionUpdateParams
- Defined in:
- lib/stripe/params/v2/billing/service_action_update_params.rb
Defined Under Namespace
Classes: CreditGrant, CreditGrantPerTenant
Instance Attribute Summary collapse
-
#credit_grant ⇒ Object
Details for the credit grant.
-
#credit_grant_per_tenant ⇒ Object
Details for the credit grant per tenant.
-
#lookup_key ⇒ Object
An internal key you can use to search for this service action.
Instance Method Summary collapse
-
#initialize(credit_grant: nil, credit_grant_per_tenant: nil, lookup_key: nil) ⇒ ServiceActionUpdateParams
constructor
A new instance of ServiceActionUpdateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(credit_grant: nil, credit_grant_per_tenant: nil, lookup_key: nil) ⇒ ServiceActionUpdateParams
Returns a new instance of ServiceActionUpdateParams.
32 33 34 35 36 |
# File 'lib/stripe/params/v2/billing/service_action_update_params.rb', line 32 def initialize(credit_grant: nil, credit_grant_per_tenant: nil, lookup_key: nil) @credit_grant = credit_grant @credit_grant_per_tenant = credit_grant_per_tenant @lookup_key = lookup_key end |
Instance Attribute Details
#credit_grant ⇒ Object
Details for the credit grant. Can only be set if the service action’s ‘type` is `credit_grant`.
26 27 28 |
# File 'lib/stripe/params/v2/billing/service_action_update_params.rb', line 26 def credit_grant @credit_grant end |
#credit_grant_per_tenant ⇒ Object
Details for the credit grant per tenant. Can only be set if the service action’s ‘type` is `credit_grant_per_tenant`.
28 29 30 |
# File 'lib/stripe/params/v2/billing/service_action_update_params.rb', line 28 def credit_grant_per_tenant @credit_grant_per_tenant end |
#lookup_key ⇒ Object
An internal key you can use to search for this service action. Maximum length of 200 characters.
30 31 32 |
# File 'lib/stripe/params/v2/billing/service_action_update_params.rb', line 30 def lookup_key @lookup_key end |