Class: Stripe::V2::Commerce::ProductCatalog::ImportCreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/commerce/product_catalog/import_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(feed_type: nil, metadata: nil, mode: nil) ⇒ ImportCreateParams

Returns a new instance of ImportCreateParams.



16
17
18
19
20
# File 'lib/stripe/params/v2/commerce/product_catalog/import_create_params.rb', line 16

def initialize(feed_type: nil, metadata: nil, mode: nil)
  @feed_type = feed_type
  @metadata = 
  @mode = mode
end

Instance Attribute Details

#feed_typeObject

The type of catalog data to import.



10
11
12
# File 'lib/stripe/params/v2/commerce/product_catalog/import_create_params.rb', line 10

def feed_type
  @feed_type
end

#metadataObject

Additional information about the import in a structured format.



12
13
14
# File 'lib/stripe/params/v2/commerce/product_catalog/import_create_params.rb', line 12

def 
  @metadata
end

#modeObject

The strategy for handling existing catalog data during import.



14
15
16
# File 'lib/stripe/params/v2/commerce/product_catalog/import_create_params.rb', line 14

def mode
  @mode
end