Class: Stripe::V2::Commerce::ProductCatalog::ImportListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Commerce::ProductCatalog::ImportListParams
- Defined in:
- lib/stripe/params/v2/commerce/product_catalog/import_list_params.rb
Instance Attribute Summary collapse
-
#created ⇒ Object
Filter for objects created at the specified timestamp.
-
#created_gt ⇒ Object
Filter for objects created after the specified timestamp.
-
#created_gte ⇒ Object
Filter for objects created on or after the specified timestamp.
-
#created_lt ⇒ Object
Filter for objects created before the specified timestamp.
-
#created_lte ⇒ Object
Filter for objects created on or before the specified timestamp.
-
#feed_type ⇒ Object
Filter by the type of feed data being imported.
-
#limit ⇒ Object
The maximum number of results per page.
-
#status ⇒ Object
Filter by import status.
Instance Method Summary collapse
-
#initialize(created: nil, created_gt: nil, created_gte: nil, created_lt: nil, created_lte: nil, feed_type: nil, limit: nil, status: nil) ⇒ ImportListParams
constructor
A new instance of ImportListParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(created: nil, created_gt: nil, created_gte: nil, created_lt: nil, created_lte: nil, feed_type: nil, limit: nil, status: nil) ⇒ ImportListParams
Returns a new instance of ImportListParams.
31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 |
# File 'lib/stripe/params/v2/commerce/product_catalog/import_list_params.rb', line 31 def initialize( created: nil, created_gt: nil, created_gte: nil, created_lt: nil, created_lte: nil, feed_type: nil, limit: nil, status: nil ) @created = created @created_gt = created_gt @created_gte = created_gte @created_lt = created_lt @created_lte = created_lte @feed_type = feed_type @limit = limit @status = status end |
Instance Attribute Details
#created ⇒ Object
Filter for objects created at the specified timestamp. Must be an RFC 3339 date & time value, for example: 2022-09-18T13:22:00Z.
11 12 13 |
# File 'lib/stripe/params/v2/commerce/product_catalog/import_list_params.rb', line 11 def created @created end |
#created_gt ⇒ Object
Filter for objects created after the specified timestamp. Must be an RFC 3339 date & time value, for example: 2022-09-18T13:22:00Z.
14 15 16 |
# File 'lib/stripe/params/v2/commerce/product_catalog/import_list_params.rb', line 14 def created_gt @created_gt end |
#created_gte ⇒ Object
Filter for objects created on or after the specified timestamp. Must be an RFC 3339 date & time value, for example: 2022-09-18T13:22:00Z.
17 18 19 |
# File 'lib/stripe/params/v2/commerce/product_catalog/import_list_params.rb', line 17 def created_gte @created_gte end |
#created_lt ⇒ Object
Filter for objects created before the specified timestamp. Must be an RFC 3339 date & time value, for example: 2022-09-18T13:22:00Z.
20 21 22 |
# File 'lib/stripe/params/v2/commerce/product_catalog/import_list_params.rb', line 20 def created_lt @created_lt end |
#created_lte ⇒ Object
Filter for objects created on or before the specified timestamp. Must be an RFC 3339 date & time value, for example: 2022-09-18T13:22:00Z.
23 24 25 |
# File 'lib/stripe/params/v2/commerce/product_catalog/import_list_params.rb', line 23 def created_lte @created_lte end |
#feed_type ⇒ Object
Filter by the type of feed data being imported.
25 26 27 |
# File 'lib/stripe/params/v2/commerce/product_catalog/import_list_params.rb', line 25 def feed_type @feed_type end |
#limit ⇒ Object
The maximum number of results per page.
27 28 29 |
# File 'lib/stripe/params/v2/commerce/product_catalog/import_list_params.rb', line 27 def limit @limit end |
#status ⇒ Object
Filter by import status.
29 30 31 |
# File 'lib/stripe/params/v2/commerce/product_catalog/import_list_params.rb', line 29 def status @status end |