Class: Stripe::V2::Commerce::ProductCatalogImport

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/commerce/product_catalog_import.rb

Overview

The product catalog import object tracks the long-running background process that handles uploading, processing and validation.

Defined Under Namespace

Classes: StatusDetails

Constant Summary collapse

OBJECT_NAME =
"v2.commerce.product_catalog_import"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#createdObject (readonly)

The time this ProductCatalogImport was created.



224
225
226
# File 'lib/stripe/resources/v2/commerce/product_catalog_import.rb', line 224

def created
  @created
end

#feed_typeObject (readonly)

The type of feed data being imported into the product catalog.



226
227
228
# File 'lib/stripe/resources/v2/commerce/product_catalog_import.rb', line 226

def feed_type
  @feed_type
end

#idObject (readonly)

The unique identifier for this ProductCatalogImport.



228
229
230
# File 'lib/stripe/resources/v2/commerce/product_catalog_import.rb', line 228

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



230
231
232
# File 'lib/stripe/resources/v2/commerce/product_catalog_import.rb', line 230

def livemode
  @livemode
end

#metadataObject (readonly)

Additional information about the object in a structured format.



232
233
234
# File 'lib/stripe/resources/v2/commerce/product_catalog_import.rb', line 232

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



234
235
236
# File 'lib/stripe/resources/v2/commerce/product_catalog_import.rb', line 234

def object
  @object
end

#statusObject (readonly)

The current status of this ProductCatalogImport.



236
237
238
# File 'lib/stripe/resources/v2/commerce/product_catalog_import.rb', line 236

def status
  @status
end

#status_detailsObject (readonly)

Details about the current import status.



238
239
240
# File 'lib/stripe/resources/v2/commerce/product_catalog_import.rb', line 238

def status_details
  @status_details
end

Class Method Details

.field_encodingsObject



248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
# File 'lib/stripe/resources/v2/commerce/product_catalog_import.rb', line 248

def self.field_encodings
  @field_encodings = {
    status_details: {
      kind: :object,
      fields: {
        processing: {
          kind: :object,
          fields: { error_count: :int64_string, success_count: :int64_string },
        },
        succeeded: { kind: :object, fields: { success_count: :int64_string } },
        succeeded_with_errors: {
          kind: :object,
          fields: {
            error_count: :int64_string,
            error_file: { kind: :object, fields: { size: :int64_string } },
            samples: { kind: :array, element: { kind: :object, fields: { row: :int64_string } } },
            success_count: :int64_string,
          },
        },
      },
    },
  }
end

.field_remappingsObject



244
245
246
# File 'lib/stripe/resources/v2/commerce/product_catalog_import.rb', line 244

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



240
241
242
# File 'lib/stripe/resources/v2/commerce/product_catalog_import.rb', line 240

def self.inner_class_types
  @inner_class_types = { status_details: StatusDetails }
end

.object_nameObject



10
11
12
# File 'lib/stripe/resources/v2/commerce/product_catalog_import.rb', line 10

def self.object_name
  "v2.commerce.product_catalog_import"
end