Class: Stripe::V2::Core::Account::Configuration

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: Customer, Merchant, Recipient

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#customerObject (readonly)

The Customer Configuration allows the Account to be used in inbound payment flows (i.e. customer-facing payment and billing flows).



2074
2075
2076
# File 'lib/stripe/resources/v2/core/account.rb', line 2074

def customer
  @customer
end

#merchantObject (readonly)

Enables the Account to act as a connected account and collect payments facilitated by a Connect platform. You must onboard your platform to Connect before you can add this configuration to your connected accounts. Utilize this configuration when the Account will be the Merchant of Record, like with Direct charges or Destination Charges with on_behalf_of set.



2076
2077
2078
# File 'lib/stripe/resources/v2/core/account.rb', line 2076

def merchant
  @merchant
end

#recipientObject (readonly)

The Recipient Configuration allows the Account to receive funds. Utilize this configuration if the Account will not be the Merchant of Record, like with Separate Charges & Transfers, or Destination Charges without on_behalf_of set.



2078
2079
2080
# File 'lib/stripe/resources/v2/core/account.rb', line 2078

def recipient
  @recipient
end

Class Method Details

.field_remappingsObject



2084
2085
2086
# File 'lib/stripe/resources/v2/core/account.rb', line 2084

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2080
2081
2082
# File 'lib/stripe/resources/v2/core/account.rb', line 2080

def self.inner_class_types
  @inner_class_types = { customer: Customer, merchant: Merchant, recipient: Recipient }
end