Class: Stripe::V2::Core::Account::Configuration::Customer::AutomaticIndirectTax
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Configuration::Customer::AutomaticIndirectTax
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: Location
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#exempt ⇒ Object
readonly
The customer account’s tax exemption status: ‘none`, `exempt`, or `reverse`.
-
#ip_address ⇒ Object
readonly
A recent IP address of the customer used for tax reporting and tax location inference.
-
#location ⇒ Object
readonly
The customer account’s identified tax location, derived from ‘location_source`.
-
#location_source ⇒ Object
readonly
Data source used to identify the customer account’s tax location.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#exempt ⇒ Object (readonly)
The customer account’s tax exemption status: ‘none`, `exempt`, or `reverse`. When `reverse`, invoice and receipt PDFs include “Reverse charge”.
564 565 566 |
# File 'lib/stripe/resources/v2/core/account.rb', line 564 def exempt @exempt end |
#ip_address ⇒ Object (readonly)
A recent IP address of the customer used for tax reporting and tax location inference.
566 567 568 |
# File 'lib/stripe/resources/v2/core/account.rb', line 566 def ip_address @ip_address end |
#location ⇒ Object (readonly)
The customer account’s identified tax location, derived from ‘location_source`. Only rendered if the `automatic_indirect_tax` feature is requested and `active`.
568 569 570 |
# File 'lib/stripe/resources/v2/core/account.rb', line 568 def location @location end |
#location_source ⇒ Object (readonly)
Data source used to identify the customer account’s tax location. Defaults to ‘identity_address`. Used for automatic indirect tax calculation.
570 571 572 |
# File 'lib/stripe/resources/v2/core/account.rb', line 570 def location_source @location_source end |
Class Method Details
.field_remappings ⇒ Object
576 577 578 |
# File 'lib/stripe/resources/v2/core/account.rb', line 576 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
572 573 574 |
# File 'lib/stripe/resources/v2/core/account.rb', line 572 def self.inner_class_types @inner_class_types = { location: Location } end |