Class: Stripe::V2::Core::Account::Configuration::Customer::Billing
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Configuration::Customer::Billing
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: Invoice
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#default_payment_method ⇒ Object
readonly
The ID of a ‘PaymentMethod` attached to this Account’s ‘customer` configuration, used as the default payment method for invoices and subscriptions.
-
#invoice ⇒ Object
readonly
Default invoice settings for the customer account.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#default_payment_method ⇒ Object (readonly)
The ID of a ‘PaymentMethod` attached to this Account’s ‘customer` configuration, used as the default payment method for invoices and subscriptions.
101 102 103 |
# File 'lib/stripe/resources/v2/core/account.rb', line 101 def default_payment_method @default_payment_method end |
#invoice ⇒ Object (readonly)
Default invoice settings for the customer account.
103 104 105 |
# File 'lib/stripe/resources/v2/core/account.rb', line 103 def invoice @invoice end |
Class Method Details
.field_remappings ⇒ Object
109 110 111 |
# File 'lib/stripe/resources/v2/core/account.rb', line 109 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
105 106 107 |
# File 'lib/stripe/resources/v2/core/account.rb', line 105 def self.inner_class_types @inner_class_types = { invoice: Invoice } end |