Class: Stripe::V2::Core::Account::Configuration::Customer::Capabilities
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Configuration::Customer::Capabilities
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: AutomaticIndirectTax
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#automatic_indirect_tax ⇒ Object
readonly
Generates requirements for enabling automatic indirect tax calculation on this customer's invoices or subscriptions.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#automatic_indirect_tax ⇒ Object (readonly)
Generates requirements for enabling automatic indirect tax calculation on this customer's invoices or subscriptions. Recommended to request this capability if planning to enable automatic tax calculation on this customer's invoices or subscriptions.
2725 2726 2727 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2725 def automatic_indirect_tax @automatic_indirect_tax end |
Class Method Details
.field_encodings ⇒ Object
2735 2736 2737 2738 2739 2740 2741 2742 2743 2744 2745 2746 2747 2748 2749 2750 2751 2752 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2735 def self.field_encodings @field_encodings = { automatic_indirect_tax: { kind: :object, fields: { protections: { kind: :object, fields: { psp_migration: { kind: :object, fields: { expires_at: :int64_string, requested_at: :int64_string }, }, }, }, }, }, } end |
.field_remappings ⇒ Object
2731 2732 2733 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2731 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2727 2728 2729 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2727 def self.inner_class_types @inner_class_types = { automatic_indirect_tax: AutomaticIndirectTax } end |