Class: Stripe::V2::Core::Account::Configuration::Merchant::Branding

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#iconObject (readonly)

ID of a file upload: An icon for the merchant. Must be square and at least 128px x 128px.



238
239
240
# File 'lib/stripe/resources/v2/core/account.rb', line 238

def icon
  @icon
end

#logoObject (readonly)

ID of a file upload: A logo for the merchant that will be used in Checkout instead of the icon and without the merchant's name next to it if provided. Must be at least 128px x 128px.



240
241
242
# File 'lib/stripe/resources/v2/core/account.rb', line 240

def 
  
end

#primary_colorObject (readonly)

A CSS hex color value representing the primary branding color for the merchant.



242
243
244
# File 'lib/stripe/resources/v2/core/account.rb', line 242

def primary_color
  @primary_color
end

#secondary_colorObject (readonly)

A CSS hex color value representing the secondary branding color for the merchant.



244
245
246
# File 'lib/stripe/resources/v2/core/account.rb', line 244

def secondary_color
  @secondary_color
end

Class Method Details

.field_remappingsObject



250
251
252
# File 'lib/stripe/resources/v2/core/account.rb', line 250

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



246
247
248
# File 'lib/stripe/resources/v2/core/account.rb', line 246

def self.inner_class_types
  @inner_class_types = {}
end