Class: Stripe::V2::Core::Account::Configuration::Merchant::Capabilities

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: AchDebitPayments, AcssDebitPayments, AffirmPayments, AfterpayClearpayPayments, AlmaPayments, AmazonPayPayments, AuBecsDebitPayments, BacsDebitPayments, BancontactPayments, BlikPayments, BoletoPayments, CardPayments, CartesBancairesPayments, CashappPayments, EpsPayments, FpxPayments, GbBankTransferPayments, GrabpayPayments, IdealPayments, JcbPayments, JpBankTransferPayments, KakaoPayPayments, KlarnaPayments, KonbiniPayments, KrCardPayments, LinkPayments, MobilepayPayments, MultibancoPayments, MxBankTransferPayments, NaverPayPayments, OxxoPayments, P24Payments, PayByBankPayments, PaycoPayments, PaynowPayments, PromptpayPayments, RevolutPayPayments, SamsungPayPayments, SepaBankTransferPayments, SepaDebitPayments, StripeBalance, SunbitPayments, SwishPayments, TwintPayments, UsBankTransferPayments, ZipPayments

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#ach_debit_paymentsObject (readonly)

Allow the merchant to process ACH debit payments.



6913
6914
6915
# File 'lib/stripe/resources/v2/core/account.rb', line 6913

def ach_debit_payments
  @ach_debit_payments
end

#acss_debit_paymentsObject (readonly)

Allow the merchant to process ACSS debit payments.



6915
6916
6917
# File 'lib/stripe/resources/v2/core/account.rb', line 6915

def acss_debit_payments
  @acss_debit_payments
end

#affirm_paymentsObject (readonly)

Allow the merchant to process Affirm payments.



6917
6918
6919
# File 'lib/stripe/resources/v2/core/account.rb', line 6917

def affirm_payments
  @affirm_payments
end

#afterpay_clearpay_paymentsObject (readonly)

Allow the merchant to process Afterpay/Clearpay payments.



6919
6920
6921
# File 'lib/stripe/resources/v2/core/account.rb', line 6919

def afterpay_clearpay_payments
  @afterpay_clearpay_payments
end

#alma_paymentsObject (readonly)

Allow the merchant to process Alma payments.



6921
6922
6923
# File 'lib/stripe/resources/v2/core/account.rb', line 6921

def alma_payments
  @alma_payments
end

#amazon_pay_paymentsObject (readonly)

Allow the merchant to process Amazon Pay payments.



6923
6924
6925
# File 'lib/stripe/resources/v2/core/account.rb', line 6923

def amazon_pay_payments
  @amazon_pay_payments
end

#au_becs_debit_paymentsObject (readonly)

Allow the merchant to process Australian BECS Direct Debit payments.



6925
6926
6927
# File 'lib/stripe/resources/v2/core/account.rb', line 6925

def au_becs_debit_payments
  @au_becs_debit_payments
end

#bacs_debit_paymentsObject (readonly)

Allow the merchant to process BACS Direct Debit payments.



6927
6928
6929
# File 'lib/stripe/resources/v2/core/account.rb', line 6927

def bacs_debit_payments
  @bacs_debit_payments
end

#bancontact_paymentsObject (readonly)

Allow the merchant to process Bancontact payments.



6929
6930
6931
# File 'lib/stripe/resources/v2/core/account.rb', line 6929

def bancontact_payments
  @bancontact_payments
end

#blik_paymentsObject (readonly)

Allow the merchant to process BLIK payments.



6931
6932
6933
# File 'lib/stripe/resources/v2/core/account.rb', line 6931

def blik_payments
  @blik_payments
end

#boleto_paymentsObject (readonly)

Allow the merchant to process Boleto payments.



6933
6934
6935
# File 'lib/stripe/resources/v2/core/account.rb', line 6933

def boleto_payments
  @boleto_payments
end

#card_paymentsObject (readonly)

Allow the merchant to collect card payments.



6935
6936
6937
# File 'lib/stripe/resources/v2/core/account.rb', line 6935

def card_payments
  @card_payments
end

#cartes_bancaires_paymentsObject (readonly)

Allow the merchant to process Cartes Bancaires payments.



6937
6938
6939
# File 'lib/stripe/resources/v2/core/account.rb', line 6937

def cartes_bancaires_payments
  @cartes_bancaires_payments
end

#cashapp_paymentsObject (readonly)

Allow the merchant to process Cash App payments.



6939
6940
6941
# File 'lib/stripe/resources/v2/core/account.rb', line 6939

def cashapp_payments
  @cashapp_payments
end

#eps_paymentsObject (readonly)

Allow the merchant to process EPS payments.



6941
6942
6943
# File 'lib/stripe/resources/v2/core/account.rb', line 6941

def eps_payments
  @eps_payments
end

#fpx_paymentsObject (readonly)

Allow the merchant to process FPX payments.



6943
6944
6945
# File 'lib/stripe/resources/v2/core/account.rb', line 6943

def fpx_payments
  @fpx_payments
end

#gb_bank_transfer_paymentsObject (readonly)

Allow the merchant to process UK bank transfer payments.



6945
6946
6947
# File 'lib/stripe/resources/v2/core/account.rb', line 6945

def gb_bank_transfer_payments
  @gb_bank_transfer_payments
end

#grabpay_paymentsObject (readonly)

Allow the merchant to process GrabPay payments.



6947
6948
6949
# File 'lib/stripe/resources/v2/core/account.rb', line 6947

def grabpay_payments
  @grabpay_payments
end

#ideal_paymentsObject (readonly)

Allow the merchant to process iDEAL payments.



6949
6950
6951
# File 'lib/stripe/resources/v2/core/account.rb', line 6949

def ideal_payments
  @ideal_payments
end

#jcb_paymentsObject (readonly)

Allow the merchant to process JCB card payments.



6951
6952
6953
# File 'lib/stripe/resources/v2/core/account.rb', line 6951

def jcb_payments
  @jcb_payments
end

#jp_bank_transfer_paymentsObject (readonly)

Allow the merchant to process Japanese bank transfer payments.



6953
6954
6955
# File 'lib/stripe/resources/v2/core/account.rb', line 6953

def jp_bank_transfer_payments
  @jp_bank_transfer_payments
end

#kakao_pay_paymentsObject (readonly)

Allow the merchant to process Kakao Pay payments.



6955
6956
6957
# File 'lib/stripe/resources/v2/core/account.rb', line 6955

def kakao_pay_payments
  @kakao_pay_payments
end

#klarna_paymentsObject (readonly)

Allow the merchant to process Klarna payments.



6957
6958
6959
# File 'lib/stripe/resources/v2/core/account.rb', line 6957

def klarna_payments
  @klarna_payments
end

#konbini_paymentsObject (readonly)

Allow the merchant to process Konbini convenience store payments.



6959
6960
6961
# File 'lib/stripe/resources/v2/core/account.rb', line 6959

def konbini_payments
  @konbini_payments
end

#kr_card_paymentsObject (readonly)

Allow the merchant to process Korean card payments.



6961
6962
6963
# File 'lib/stripe/resources/v2/core/account.rb', line 6961

def kr_card_payments
  @kr_card_payments
end

Allow the merchant to process Link payments.



6963
6964
6965
# File 'lib/stripe/resources/v2/core/account.rb', line 6963

def link_payments
  @link_payments
end

#mobilepay_paymentsObject (readonly)

Allow the merchant to process MobilePay payments.



6965
6966
6967
# File 'lib/stripe/resources/v2/core/account.rb', line 6965

def mobilepay_payments
  @mobilepay_payments
end

#multibanco_paymentsObject (readonly)

Allow the merchant to process Multibanco payments.



6967
6968
6969
# File 'lib/stripe/resources/v2/core/account.rb', line 6967

def multibanco_payments
  @multibanco_payments
end

#mx_bank_transfer_paymentsObject (readonly)

Allow the merchant to process Mexican bank transfer payments.



6969
6970
6971
# File 'lib/stripe/resources/v2/core/account.rb', line 6969

def mx_bank_transfer_payments
  @mx_bank_transfer_payments
end

Allow the merchant to process Naver Pay payments.



6971
6972
6973
# File 'lib/stripe/resources/v2/core/account.rb', line 6971

def naver_pay_payments
  @naver_pay_payments
end

#oxxo_paymentsObject (readonly)

Allow the merchant to process OXXO payments.



6973
6974
6975
# File 'lib/stripe/resources/v2/core/account.rb', line 6973

def oxxo_payments
  @oxxo_payments
end

#p24_paymentsObject (readonly)

Allow the merchant to process Przelewy24 (P24) payments.



6975
6976
6977
# File 'lib/stripe/resources/v2/core/account.rb', line 6975

def p24_payments
  @p24_payments
end

#pay_by_bank_paymentsObject (readonly)

Allow the merchant to process Pay by Bank payments.



6977
6978
6979
# File 'lib/stripe/resources/v2/core/account.rb', line 6977

def pay_by_bank_payments
  @pay_by_bank_payments
end

#payco_paymentsObject (readonly)

Allow the merchant to process PAYCO payments.



6979
6980
6981
# File 'lib/stripe/resources/v2/core/account.rb', line 6979

def payco_payments
  @payco_payments
end

#paynow_paymentsObject (readonly)

Allow the merchant to process PayNow payments.



6981
6982
6983
# File 'lib/stripe/resources/v2/core/account.rb', line 6981

def paynow_payments
  @paynow_payments
end

#promptpay_paymentsObject (readonly)

Allow the merchant to process PromptPay payments.



6983
6984
6985
# File 'lib/stripe/resources/v2/core/account.rb', line 6983

def promptpay_payments
  @promptpay_payments
end

#revolut_pay_paymentsObject (readonly)

Allow the merchant to process Revolut Pay payments.



6985
6986
6987
# File 'lib/stripe/resources/v2/core/account.rb', line 6985

def revolut_pay_payments
  @revolut_pay_payments
end

#samsung_pay_paymentsObject (readonly)

Allow the merchant to process Samsung Pay payments.



6987
6988
6989
# File 'lib/stripe/resources/v2/core/account.rb', line 6987

def samsung_pay_payments
  @samsung_pay_payments
end

#sepa_bank_transfer_paymentsObject (readonly)

Allow the merchant to process SEPA bank transfer payments.



6989
6990
6991
# File 'lib/stripe/resources/v2/core/account.rb', line 6989

def sepa_bank_transfer_payments
  @sepa_bank_transfer_payments
end

#sepa_debit_paymentsObject (readonly)

Allow the merchant to process SEPA Direct Debit payments.



6991
6992
6993
# File 'lib/stripe/resources/v2/core/account.rb', line 6991

def sepa_debit_payments
  @sepa_debit_payments
end

#stripe_balanceObject (readonly)

Capabilities that enable the merchant to manage their Stripe Balance (/v1/balance).



6993
6994
6995
# File 'lib/stripe/resources/v2/core/account.rb', line 6993

def stripe_balance
  @stripe_balance
end

#sunbit_paymentsObject (readonly)

Allow the merchant to process Sunbit payments.



6995
6996
6997
# File 'lib/stripe/resources/v2/core/account.rb', line 6995

def sunbit_payments
  @sunbit_payments
end

#swish_paymentsObject (readonly)

Allow the merchant to process Swish payments.



6997
6998
6999
# File 'lib/stripe/resources/v2/core/account.rb', line 6997

def swish_payments
  @swish_payments
end

#twint_paymentsObject (readonly)

Allow the merchant to process TWINT payments.



6999
7000
7001
# File 'lib/stripe/resources/v2/core/account.rb', line 6999

def twint_payments
  @twint_payments
end

#us_bank_transfer_paymentsObject (readonly)

Allow the merchant to process US bank transfer payments.



7001
7002
7003
# File 'lib/stripe/resources/v2/core/account.rb', line 7001

def us_bank_transfer_payments
  @us_bank_transfer_payments
end

#zip_paymentsObject (readonly)

Allow the merchant to process Zip payments.



7003
7004
7005
# File 'lib/stripe/resources/v2/core/account.rb', line 7003

def zip_payments
  @zip_payments
end

Class Method Details

.field_encodingsObject



7060
7061
7062
7063
7064
7065
7066
7067
7068
7069
7070
7071
7072
7073
7074
7075
7076
7077
7078
7079
7080
7081
7082
7083
7084
7085
7086
7087
7088
7089
7090
7091
7092
7093
7094
7095
7096
7097
7098
7099
7100
7101
7102
7103
7104
7105
7106
7107
7108
7109
7110
7111
7112
7113
7114
7115
7116
7117
7118
7119
7120
7121
7122
7123
7124
7125
7126
7127
7128
7129
7130
7131
7132
7133
7134
7135
7136
7137
7138
7139
7140
7141
7142
7143
7144
7145
7146
7147
7148
7149
7150
7151
7152
7153
7154
7155
7156
7157
7158
7159
7160
7161
7162
7163
7164
7165
7166
7167
7168
7169
7170
7171
7172
7173
7174
7175
7176
7177
7178
7179
7180
7181
7182
7183
7184
7185
7186
7187
7188
7189
7190
7191
7192
7193
7194
7195
7196
7197
7198
7199
7200
7201
7202
7203
7204
7205
7206
7207
7208
7209
7210
7211
7212
7213
7214
7215
7216
7217
7218
7219
7220
7221
7222
7223
7224
7225
7226
7227
7228
7229
7230
7231
7232
7233
7234
7235
7236
7237
7238
7239
7240
7241
7242
7243
7244
7245
7246
7247
7248
7249
7250
7251
7252
7253
7254
7255
7256
7257
7258
7259
7260
7261
7262
7263
7264
7265
7266
7267
7268
7269
7270
7271
7272
7273
7274
7275
7276
7277
7278
7279
7280
7281
7282
7283
7284
7285
7286
7287
7288
7289
7290
7291
7292
7293
7294
7295
7296
7297
7298
7299
7300
7301
7302
7303
7304
7305
7306
7307
7308
7309
7310
7311
7312
7313
7314
7315
7316
7317
7318
7319
7320
7321
7322
7323
7324
7325
7326
7327
7328
7329
7330
7331
7332
7333
7334
7335
7336
7337
7338
7339
7340
7341
7342
7343
7344
7345
7346
7347
7348
7349
7350
7351
7352
7353
7354
7355
7356
7357
7358
7359
7360
7361
7362
7363
7364
7365
7366
7367
7368
7369
7370
7371
7372
7373
7374
7375
7376
7377
7378
7379
7380
7381
7382
7383
7384
7385
7386
7387
7388
7389
7390
7391
7392
7393
7394
7395
7396
7397
7398
7399
7400
7401
7402
7403
7404
7405
7406
7407
7408
7409
7410
7411
7412
7413
7414
7415
7416
7417
7418
7419
7420
7421
7422
7423
7424
7425
7426
7427
7428
7429
7430
7431
7432
7433
7434
7435
7436
7437
7438
7439
7440
7441
7442
7443
7444
7445
7446
7447
7448
7449
7450
7451
7452
7453
7454
7455
7456
7457
7458
7459
7460
7461
7462
7463
7464
7465
7466
7467
7468
7469
7470
7471
7472
7473
7474
7475
7476
7477
7478
7479
7480
7481
7482
7483
7484
7485
7486
7487
7488
7489
7490
7491
7492
7493
7494
7495
7496
7497
7498
7499
7500
7501
7502
7503
7504
7505
7506
7507
7508
7509
7510
7511
7512
7513
7514
7515
7516
7517
7518
7519
7520
7521
7522
7523
7524
7525
7526
7527
7528
7529
7530
7531
7532
7533
7534
7535
7536
7537
7538
7539
7540
7541
7542
7543
7544
7545
7546
7547
7548
7549
7550
7551
7552
7553
7554
7555
7556
7557
7558
7559
7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
7574
7575
7576
7577
7578
7579
7580
7581
7582
7583
7584
7585
7586
7587
7588
7589
7590
7591
7592
7593
7594
7595
7596
7597
7598
7599
7600
7601
7602
7603
7604
7605
7606
7607
7608
7609
7610
7611
7612
7613
7614
7615
7616
7617
7618
7619
7620
7621
7622
7623
7624
7625
7626
7627
7628
7629
7630
7631
7632
7633
7634
7635
7636
7637
7638
7639
7640
7641
7642
7643
7644
7645
7646
7647
7648
7649
7650
7651
7652
7653
7654
7655
7656
7657
7658
7659
7660
7661
7662
7663
7664
7665
7666
7667
7668
7669
7670
7671
7672
7673
7674
7675
7676
7677
7678
7679
7680
7681
7682
7683
7684
7685
7686
7687
7688
7689
7690
7691
7692
7693
7694
7695
7696
7697
7698
7699
7700
7701
7702
7703
7704
7705
7706
7707
7708
7709
7710
7711
7712
# File 'lib/stripe/resources/v2/core/account.rb', line 7060

def self.field_encodings
  @field_encodings = {
    ach_debit_payments: {
      kind: :object,
      fields: {
        protections: {
          kind: :object,
          fields: {
            psp_migration: {
              kind: :object,
              fields: { expires_at: :int64_string, requested_at: :int64_string },
            },
          },
        },
      },
    },
    acss_debit_payments: {
      kind: :object,
      fields: {
        protections: {
          kind: :object,
          fields: {
            psp_migration: {
              kind: :object,
              fields: { expires_at: :int64_string, requested_at: :int64_string },
            },
          },
        },
      },
    },
    affirm_payments: {
      kind: :object,
      fields: {
        protections: {
          kind: :object,
          fields: {
            psp_migration: {
              kind: :object,
              fields: { expires_at: :int64_string, requested_at: :int64_string },
            },
          },
        },
      },
    },
    afterpay_clearpay_payments: {
      kind: :object,
      fields: {
        protections: {
          kind: :object,
          fields: {
            psp_migration: {
              kind: :object,
              fields: { expires_at: :int64_string, requested_at: :int64_string },
            },
          },
        },
      },
    },
    alma_payments: {
      kind: :object,
      fields: {
        protections: {
          kind: :object,
          fields: {
            psp_migration: {
              kind: :object,
              fields: { expires_at: :int64_string, requested_at: :int64_string },
            },
          },
        },
      },
    },
    amazon_pay_payments: {
      kind: :object,
      fields: {
        protections: {
          kind: :object,
          fields: {
            psp_migration: {
              kind: :object,
              fields: { expires_at: :int64_string, requested_at: :int64_string },
            },
          },
        },
      },
    },
    au_becs_debit_payments: {
      kind: :object,
      fields: {
        protections: {
          kind: :object,
          fields: {
            psp_migration: {
              kind: :object,
              fields: { expires_at: :int64_string, requested_at: :int64_string },
            },
          },
        },
      },
    },
    bacs_debit_payments: {
      kind: :object,
      fields: {
        protections: {
          kind: :object,
          fields: {
            psp_migration: {
              kind: :object,
              fields: { expires_at: :int64_string, requested_at: :int64_string },
            },
          },
        },
      },
    },
    bancontact_payments: {
      kind: :object,
      fields: {
        protections: {
          kind: :object,
          fields: {
            psp_migration: {
              kind: :object,
              fields: { expires_at: :int64_string, requested_at: :int64_string },
            },
          },
        },
      },
    },
    blik_payments: {
      kind: :object,
      fields: {
        protections: {
          kind: :object,
          fields: {
            psp_migration: {
              kind: :object,
              fields: { expires_at: :int64_string, requested_at: :int64_string },
            },
          },
        },
      },
    },
    boleto_payments: {
      kind: :object,
      fields: {
        protections: {
          kind: :object,
          fields: {
            psp_migration: {
              kind: :object,
              fields: { expires_at: :int64_string, requested_at: :int64_string },
            },
          },
        },
      },
    },
    card_payments: {
      kind: :object,
      fields: {
        protections: {
          kind: :object,
          fields: {
            psp_migration: {
              kind: :object,
              fields: { expires_at: :int64_string, requested_at: :int64_string },
            },
          },
        },
      },
    },
    cartes_bancaires_payments: {
      kind: :object,
      fields: {
        protections: {
          kind: :object,
          fields: {
            psp_migration: {
              kind: :object,
              fields: { expires_at: :int64_string, requested_at: :int64_string },
            },
          },
        },
      },
    },
    cashapp_payments: {
      kind: :object,
      fields: {
        protections: {
          kind: :object,
          fields: {
            psp_migration: {
              kind: :object,
              fields: { expires_at: :int64_string, requested_at: :int64_string },
            },
          },
        },
      },
    },
    eps_payments: {
      kind: :object,
      fields: {
        protections: {
          kind: :object,
          fields: {
            psp_migration: {
              kind: :object,
              fields: { expires_at: :int64_string, requested_at: :int64_string },
            },
          },
        },
      },
    },
    fpx_payments: {
      kind: :object,
      fields: {
        protections: {
          kind: :object,
          fields: {
            psp_migration: {
              kind: :object,
              fields: { expires_at: :int64_string, requested_at: :int64_string },
            },
          },
        },
      },
    },
    gb_bank_transfer_payments: {
      kind: :object,
      fields: {
        protections: {
          kind: :object,
          fields: {
            psp_migration: {
              kind: :object,
              fields: { expires_at: :int64_string, requested_at: :int64_string },
            },
          },
        },
      },
    },
    grabpay_payments: {
      kind: :object,
      fields: {
        protections: {
          kind: :object,
          fields: {
            psp_migration: {
              kind: :object,
              fields: { expires_at: :int64_string, requested_at: :int64_string },
            },
          },
        },
      },
    },
    ideal_payments: {
      kind: :object,
      fields: {
        protections: {
          kind: :object,
          fields: {
            psp_migration: {
              kind: :object,
              fields: { expires_at: :int64_string, requested_at: :int64_string },
            },
          },
        },
      },
    },
    jcb_payments: {
      kind: :object,
      fields: {
        protections: {
          kind: :object,
          fields: {
            psp_migration: {
              kind: :object,
              fields: { expires_at: :int64_string, requested_at: :int64_string },
            },
          },
        },
      },
    },
    jp_bank_transfer_payments: {
      kind: :object,
      fields: {
        protections: {
          kind: :object,
          fields: {
            psp_migration: {
              kind: :object,
              fields: { expires_at: :int64_string, requested_at: :int64_string },
            },
          },
        },
      },
    },
    kakao_pay_payments: {
      kind: :object,
      fields: {
        protections: {
          kind: :object,
          fields: {
            psp_migration: {
              kind: :object,
              fields: { expires_at: :int64_string, requested_at: :int64_string },
            },
          },
        },
      },
    },
    klarna_payments: {
      kind: :object,
      fields: {
        protections: {
          kind: :object,
          fields: {
            psp_migration: {
              kind: :object,
              fields: { expires_at: :int64_string, requested_at: :int64_string },
            },
          },
        },
      },
    },
    konbini_payments: {
      kind: :object,
      fields: {
        protections: {
          kind: :object,
          fields: {
            psp_migration: {
              kind: :object,
              fields: { expires_at: :int64_string, requested_at: :int64_string },
            },
          },
        },
      },
    },
    kr_card_payments: {
      kind: :object,
      fields: {
        protections: {
          kind: :object,
          fields: {
            psp_migration: {
              kind: :object,
              fields: { expires_at: :int64_string, requested_at: :int64_string },
            },
          },
        },
      },
    },
    link_payments: {
      kind: :object,
      fields: {
        protections: {
          kind: :object,
          fields: {
            psp_migration: {
              kind: :object,
              fields: { expires_at: :int64_string, requested_at: :int64_string },
            },
          },
        },
      },
    },
    mobilepay_payments: {
      kind: :object,
      fields: {
        protections: {
          kind: :object,
          fields: {
            psp_migration: {
              kind: :object,
              fields: { expires_at: :int64_string, requested_at: :int64_string },
            },
          },
        },
      },
    },
    multibanco_payments: {
      kind: :object,
      fields: {
        protections: {
          kind: :object,
          fields: {
            psp_migration: {
              kind: :object,
              fields: { expires_at: :int64_string, requested_at: :int64_string },
            },
          },
        },
      },
    },
    mx_bank_transfer_payments: {
      kind: :object,
      fields: {
        protections: {
          kind: :object,
          fields: {
            psp_migration: {
              kind: :object,
              fields: { expires_at: :int64_string, requested_at: :int64_string },
            },
          },
        },
      },
    },
    naver_pay_payments: {
      kind: :object,
      fields: {
        protections: {
          kind: :object,
          fields: {
            psp_migration: {
              kind: :object,
              fields: { expires_at: :int64_string, requested_at: :int64_string },
            },
          },
        },
      },
    },
    oxxo_payments: {
      kind: :object,
      fields: {
        protections: {
          kind: :object,
          fields: {
            psp_migration: {
              kind: :object,
              fields: { expires_at: :int64_string, requested_at: :int64_string },
            },
          },
        },
      },
    },
    p24_payments: {
      kind: :object,
      fields: {
        protections: {
          kind: :object,
          fields: {
            psp_migration: {
              kind: :object,
              fields: { expires_at: :int64_string, requested_at: :int64_string },
            },
          },
        },
      },
    },
    pay_by_bank_payments: {
      kind: :object,
      fields: {
        protections: {
          kind: :object,
          fields: {
            psp_migration: {
              kind: :object,
              fields: { expires_at: :int64_string, requested_at: :int64_string },
            },
          },
        },
      },
    },
    payco_payments: {
      kind: :object,
      fields: {
        protections: {
          kind: :object,
          fields: {
            psp_migration: {
              kind: :object,
              fields: { expires_at: :int64_string, requested_at: :int64_string },
            },
          },
        },
      },
    },
    paynow_payments: {
      kind: :object,
      fields: {
        protections: {
          kind: :object,
          fields: {
            psp_migration: {
              kind: :object,
              fields: { expires_at: :int64_string, requested_at: :int64_string },
            },
          },
        },
      },
    },
    promptpay_payments: {
      kind: :object,
      fields: {
        protections: {
          kind: :object,
          fields: {
            psp_migration: {
              kind: :object,
              fields: { expires_at: :int64_string, requested_at: :int64_string },
            },
          },
        },
      },
    },
    revolut_pay_payments: {
      kind: :object,
      fields: {
        protections: {
          kind: :object,
          fields: {
            psp_migration: {
              kind: :object,
              fields: { expires_at: :int64_string, requested_at: :int64_string },
            },
          },
        },
      },
    },
    samsung_pay_payments: {
      kind: :object,
      fields: {
        protections: {
          kind: :object,
          fields: {
            psp_migration: {
              kind: :object,
              fields: { expires_at: :int64_string, requested_at: :int64_string },
            },
          },
        },
      },
    },
    sepa_bank_transfer_payments: {
      kind: :object,
      fields: {
        protections: {
          kind: :object,
          fields: {
            psp_migration: {
              kind: :object,
              fields: { expires_at: :int64_string, requested_at: :int64_string },
            },
          },
        },
      },
    },
    sepa_debit_payments: {
      kind: :object,
      fields: {
        protections: {
          kind: :object,
          fields: {
            psp_migration: {
              kind: :object,
              fields: { expires_at: :int64_string, requested_at: :int64_string },
            },
          },
        },
      },
    },
    stripe_balance: {
      kind: :object,
      fields: {
        payouts: {
          kind: :object,
          fields: {
            protections: {
              kind: :object,
              fields: {
                psp_migration: {
                  kind: :object,
                  fields: { expires_at: :int64_string, requested_at: :int64_string },
                },
              },
            },
          },
        },
      },
    },
    sunbit_payments: {
      kind: :object,
      fields: {
        protections: {
          kind: :object,
          fields: {
            psp_migration: {
              kind: :object,
              fields: { expires_at: :int64_string, requested_at: :int64_string },
            },
          },
        },
      },
    },
    swish_payments: {
      kind: :object,
      fields: {
        protections: {
          kind: :object,
          fields: {
            psp_migration: {
              kind: :object,
              fields: { expires_at: :int64_string, requested_at: :int64_string },
            },
          },
        },
      },
    },
    twint_payments: {
      kind: :object,
      fields: {
        protections: {
          kind: :object,
          fields: {
            psp_migration: {
              kind: :object,
              fields: { expires_at: :int64_string, requested_at: :int64_string },
            },
          },
        },
      },
    },
    us_bank_transfer_payments: {
      kind: :object,
      fields: {
        protections: {
          kind: :object,
          fields: {
            psp_migration: {
              kind: :object,
              fields: { expires_at: :int64_string, requested_at: :int64_string },
            },
          },
        },
      },
    },
    zip_payments: {
      kind: :object,
      fields: {
        protections: {
          kind: :object,
          fields: {
            psp_migration: {
              kind: :object,
              fields: { expires_at: :int64_string, requested_at: :int64_string },
            },
          },
        },
      },
    },
  }
end

.field_remappingsObject



7056
7057
7058
# File 'lib/stripe/resources/v2/core/account.rb', line 7056

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



7005
7006
7007
7008
7009
7010
7011
7012
7013
7014
7015
7016
7017
7018
7019
7020
7021
7022
7023
7024
7025
7026
7027
7028
7029
7030
7031
7032
7033
7034
7035
7036
7037
7038
7039
7040
7041
7042
7043
7044
7045
7046
7047
7048
7049
7050
7051
7052
7053
7054
# File 'lib/stripe/resources/v2/core/account.rb', line 7005

def self.inner_class_types
  @inner_class_types = {
    ach_debit_payments: AchDebitPayments,
    acss_debit_payments: AcssDebitPayments,
    affirm_payments: AffirmPayments,
    afterpay_clearpay_payments: AfterpayClearpayPayments,
    alma_payments: AlmaPayments,
    amazon_pay_payments: AmazonPayPayments,
    au_becs_debit_payments: AuBecsDebitPayments,
    bacs_debit_payments: BacsDebitPayments,
    bancontact_payments: BancontactPayments,
    blik_payments: BlikPayments,
    boleto_payments: BoletoPayments,
    card_payments: CardPayments,
    cartes_bancaires_payments: CartesBancairesPayments,
    cashapp_payments: CashappPayments,
    eps_payments: EpsPayments,
    fpx_payments: FpxPayments,
    gb_bank_transfer_payments: GbBankTransferPayments,
    grabpay_payments: GrabpayPayments,
    ideal_payments: IdealPayments,
    jcb_payments: JcbPayments,
    jp_bank_transfer_payments: JpBankTransferPayments,
    kakao_pay_payments: KakaoPayPayments,
    klarna_payments: KlarnaPayments,
    konbini_payments: KonbiniPayments,
    kr_card_payments: KrCardPayments,
    link_payments: LinkPayments,
    mobilepay_payments: MobilepayPayments,
    multibanco_payments: MultibancoPayments,
    mx_bank_transfer_payments: MxBankTransferPayments,
    naver_pay_payments: NaverPayPayments,
    oxxo_payments: OxxoPayments,
    p24_payments: P24Payments,
    pay_by_bank_payments: PayByBankPayments,
    payco_payments: PaycoPayments,
    paynow_payments: PaynowPayments,
    promptpay_payments: PromptpayPayments,
    revolut_pay_payments: RevolutPayPayments,
    samsung_pay_payments: SamsungPayPayments,
    sepa_bank_transfer_payments: SepaBankTransferPayments,
    sepa_debit_payments: SepaDebitPayments,
    stripe_balance: StripeBalance,
    sunbit_payments: SunbitPayments,
    swish_payments: SwishPayments,
    twint_payments: TwintPayments,
    us_bank_transfer_payments: UsBankTransferPayments,
    zip_payments: ZipPayments,
  }
end