Class: Stripe::V2::Core::Account::Configuration::Merchant::Capabilities::AffirmPayments
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Configuration::Merchant::Capabilities::AffirmPayments
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: Protections, StatusDetail
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#protections ⇒ Object
readonly
Protections applied to this capability, keyed by protection type (e.g. "psp_migration").
-
#status ⇒ Object
readonly
The status of the Capability.
-
#status_details ⇒ Object
readonly
Additional details about the capability's status.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#protections ⇒ Object (readonly)
Protections applied to this capability, keyed by protection type (e.g. "psp_migration").
3112 3113 3114 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3112 def protections @protections end |
#status ⇒ Object (readonly)
The status of the Capability.
3114 3115 3116 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3114 def status @status end |
#status_details ⇒ Object (readonly)
Additional details about the capability's status. This value is empty when status is active.
3116 3117 3118 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3116 def status_details @status_details end |
Class Method Details
.field_encodings ⇒ Object
3126 3127 3128 3129 3130 3131 3132 3133 3134 3135 3136 3137 3138 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3126 def self.field_encodings @field_encodings = { protections: { kind: :object, fields: { psp_migration: { kind: :object, fields: { expires_at: :int64_string, requested_at: :int64_string }, }, }, }, } end |
.field_remappings ⇒ Object
3122 3123 3124 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3122 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
3118 3119 3120 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3118 def self.inner_class_types @inner_class_types = { protections: Protections, status_details: StatusDetail } end |