Class: Stripe::V2::Core::Account::Configuration::Merchant::Capabilities::AmazonPayPayments
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Configuration::Merchant::Capabilities::AmazonPayPayments
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: Protections, StatusDetail
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#protections ⇒ Object
readonly
Protections applied to this capability, keyed by protection type (e.g. "psp_migration").
-
#status ⇒ Object
readonly
The status of the Capability.
-
#status_details ⇒ Object
readonly
Additional details about the capability's status.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#protections ⇒ Object (readonly)
Protections applied to this capability, keyed by protection type (e.g. "psp_migration").
3373 3374 3375 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3373 def protections @protections end |
#status ⇒ Object (readonly)
The status of the Capability.
3375 3376 3377 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3375 def status @status end |
#status_details ⇒ Object (readonly)
Additional details about the capability's status. This value is empty when status is active.
3377 3378 3379 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3377 def status_details @status_details end |
Class Method Details
.field_encodings ⇒ Object
3387 3388 3389 3390 3391 3392 3393 3394 3395 3396 3397 3398 3399 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3387 def self.field_encodings @field_encodings = { protections: { kind: :object, fields: { psp_migration: { kind: :object, fields: { expires_at: :int64_string, requested_at: :int64_string }, }, }, }, } end |
.field_remappings ⇒ Object
3383 3384 3385 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3383 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
3379 3380 3381 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3379 def self.inner_class_types @inner_class_types = { protections: Protections, status_details: StatusDetail } end |