Class: Stripe::V2::Core::Account::Configuration::Merchant::Capabilities::BlikPayments
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Configuration::Merchant::Capabilities::BlikPayments
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: Protections, StatusDetail
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#protections ⇒ Object
readonly
Protections applied to this capability, keyed by protection type (e.g. "psp_migration").
-
#status ⇒ Object
readonly
The status of the Capability.
-
#status_details ⇒ Object
readonly
Additional details about the capability's status.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#protections ⇒ Object (readonly)
Protections applied to this capability, keyed by protection type (e.g. "psp_migration").
3721 3722 3723 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3721 def protections @protections end |
#status ⇒ Object (readonly)
The status of the Capability.
3723 3724 3725 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3723 def status @status end |
#status_details ⇒ Object (readonly)
Additional details about the capability's status. This value is empty when status is active.
3725 3726 3727 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3725 def status_details @status_details end |
Class Method Details
.field_encodings ⇒ Object
3735 3736 3737 3738 3739 3740 3741 3742 3743 3744 3745 3746 3747 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3735 def self.field_encodings @field_encodings = { protections: { kind: :object, fields: { psp_migration: { kind: :object, fields: { expires_at: :int64_string, requested_at: :int64_string }, }, }, }, } end |
.field_remappings ⇒ Object
3731 3732 3733 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3731 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
3727 3728 3729 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3727 def self.inner_class_types @inner_class_types = { protections: Protections, status_details: StatusDetail } end |