Class: Stripe::V2::Core::Account::Configuration::Merchant::Capabilities::KakaoPayPayments
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Configuration::Merchant::Capabilities::KakaoPayPayments
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: Protections, StatusDetail
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#protections ⇒ Object
readonly
Protections applied to this capability, keyed by protection type (e.g. "psp_migration").
-
#status ⇒ Object
readonly
The status of the Capability.
-
#status_details ⇒ Object
readonly
Additional details about the capability's status.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#protections ⇒ Object (readonly)
Protections applied to this capability, keyed by protection type (e.g. "psp_migration").
4765 4766 4767 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4765 def protections @protections end |
#status ⇒ Object (readonly)
The status of the Capability.
4767 4768 4769 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4767 def status @status end |
#status_details ⇒ Object (readonly)
Additional details about the capability's status. This value is empty when status is active.
4769 4770 4771 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4769 def status_details @status_details end |
Class Method Details
.field_encodings ⇒ Object
4779 4780 4781 4782 4783 4784 4785 4786 4787 4788 4789 4790 4791 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4779 def self.field_encodings @field_encodings = { protections: { kind: :object, fields: { psp_migration: { kind: :object, fields: { expires_at: :int64_string, requested_at: :int64_string }, }, }, }, } end |
.field_remappings ⇒ Object
4775 4776 4777 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4775 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
4771 4772 4773 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4771 def self.inner_class_types @inner_class_types = { protections: Protections, status_details: StatusDetail } end |