Class: Stripe::V2::Core::Account::Configuration::Merchant::Capabilities::MobilepayPayments
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Configuration::Merchant::Capabilities::MobilepayPayments
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: Protections, StatusDetail
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#protections ⇒ Object
readonly
Protections applied to this capability, keyed by protection type (e.g. "psp_migration").
-
#status ⇒ Object
readonly
The status of the Capability.
-
#status_details ⇒ Object
readonly
Additional details about the capability's status.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#protections ⇒ Object (readonly)
Protections applied to this capability, keyed by protection type (e.g. "psp_migration").
5200 5201 5202 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5200 def protections @protections end |
#status ⇒ Object (readonly)
The status of the Capability.
5202 5203 5204 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5202 def status @status end |
#status_details ⇒ Object (readonly)
Additional details about the capability's status. This value is empty when status is active.
5204 5205 5206 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5204 def status_details @status_details end |
Class Method Details
.field_encodings ⇒ Object
5214 5215 5216 5217 5218 5219 5220 5221 5222 5223 5224 5225 5226 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5214 def self.field_encodings @field_encodings = { protections: { kind: :object, fields: { psp_migration: { kind: :object, fields: { expires_at: :int64_string, requested_at: :int64_string }, }, }, }, } end |
.field_remappings ⇒ Object
5210 5211 5212 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5210 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
5206 5207 5208 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5206 def self.inner_class_types @inner_class_types = { protections: Protections, status_details: StatusDetail } end |