Class: Stripe::V2::Core::Account::Configuration::Merchant::Capabilities::MultibancoPayments
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Configuration::Merchant::Capabilities::MultibancoPayments
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: Protections, StatusDetail
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#protections ⇒ Object
readonly
Protections applied to this capability, keyed by protection type (e.g. "psp_migration").
-
#status ⇒ Object
readonly
The status of the Capability.
-
#status_details ⇒ Object
readonly
Additional details about the capability's status.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#protections ⇒ Object (readonly)
Protections applied to this capability, keyed by protection type (e.g. "psp_migration").
5287 5288 5289 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5287 def protections @protections end |
#status ⇒ Object (readonly)
The status of the Capability.
5289 5290 5291 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5289 def status @status end |
#status_details ⇒ Object (readonly)
Additional details about the capability's status. This value is empty when status is active.
5291 5292 5293 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5291 def status_details @status_details end |
Class Method Details
.field_encodings ⇒ Object
5301 5302 5303 5304 5305 5306 5307 5308 5309 5310 5311 5312 5313 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5301 def self.field_encodings @field_encodings = { protections: { kind: :object, fields: { psp_migration: { kind: :object, fields: { expires_at: :int64_string, requested_at: :int64_string }, }, }, }, } end |
.field_remappings ⇒ Object
5297 5298 5299 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5297 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
5293 5294 5295 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5293 def self.inner_class_types @inner_class_types = { protections: Protections, status_details: StatusDetail } end |