Class: Stripe::V2::Core::Account::Configuration::Merchant::Capabilities::PaycoPayments
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Configuration::Merchant::Capabilities::PaycoPayments
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: Protections, StatusDetail
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#protections ⇒ Object
readonly
Protections applied to this capability, keyed by protection type (e.g. "psp_migration").
-
#status ⇒ Object
readonly
The status of the Capability.
-
#status_details ⇒ Object
readonly
Additional details about the capability's status.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#protections ⇒ Object (readonly)
Protections applied to this capability, keyed by protection type (e.g. "psp_migration").
5809 5810 5811 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5809 def protections @protections end |
#status ⇒ Object (readonly)
The status of the Capability.
5811 5812 5813 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5811 def status @status end |
#status_details ⇒ Object (readonly)
Additional details about the capability's status. This value is empty when status is active.
5813 5814 5815 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5813 def status_details @status_details end |
Class Method Details
.field_encodings ⇒ Object
5823 5824 5825 5826 5827 5828 5829 5830 5831 5832 5833 5834 5835 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5823 def self.field_encodings @field_encodings = { protections: { kind: :object, fields: { psp_migration: { kind: :object, fields: { expires_at: :int64_string, requested_at: :int64_string }, }, }, }, } end |
.field_remappings ⇒ Object
5819 5820 5821 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5819 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
5815 5816 5817 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5815 def self.inner_class_types @inner_class_types = { protections: Protections, status_details: StatusDetail } end |