Class: Stripe::V2::Core::Account::Configuration::Merchant::Capabilities::PaynowPayments
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Configuration::Merchant::Capabilities::PaynowPayments
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: Protections, StatusDetail
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#protections ⇒ Object
readonly
Protections applied to this capability, keyed by protection type (e.g. "psp_migration").
-
#status ⇒ Object
readonly
The status of the Capability.
-
#status_details ⇒ Object
readonly
Additional details about the capability's status.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#protections ⇒ Object (readonly)
Protections applied to this capability, keyed by protection type (e.g. "psp_migration").
5896 5897 5898 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5896 def protections @protections end |
#status ⇒ Object (readonly)
The status of the Capability.
5898 5899 5900 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5898 def status @status end |
#status_details ⇒ Object (readonly)
Additional details about the capability's status. This value is empty when status is active.
5900 5901 5902 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5900 def status_details @status_details end |
Class Method Details
.field_encodings ⇒ Object
5910 5911 5912 5913 5914 5915 5916 5917 5918 5919 5920 5921 5922 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5910 def self.field_encodings @field_encodings = { protections: { kind: :object, fields: { psp_migration: { kind: :object, fields: { expires_at: :int64_string, requested_at: :int64_string }, }, }, }, } end |
.field_remappings ⇒ Object
5906 5907 5908 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5906 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
5902 5903 5904 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5902 def self.inner_class_types @inner_class_types = { protections: Protections, status_details: StatusDetail } end |