Class: Stripe::V2::Core::Account::Configuration::Merchant::Capabilities::SamsungPayPayments
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Configuration::Merchant::Capabilities::SamsungPayPayments
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: Protections, StatusDetail
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#protections ⇒ Object
readonly
Protections applied to this capability, keyed by protection type (e.g. "psp_migration").
-
#status ⇒ Object
readonly
The status of the Capability.
-
#status_details ⇒ Object
readonly
Additional details about the capability's status.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#protections ⇒ Object (readonly)
Protections applied to this capability, keyed by protection type (e.g. "psp_migration").
6157 6158 6159 |
# File 'lib/stripe/resources/v2/core/account.rb', line 6157 def protections @protections end |
#status ⇒ Object (readonly)
The status of the Capability.
6159 6160 6161 |
# File 'lib/stripe/resources/v2/core/account.rb', line 6159 def status @status end |
#status_details ⇒ Object (readonly)
Additional details about the capability's status. This value is empty when status is active.
6161 6162 6163 |
# File 'lib/stripe/resources/v2/core/account.rb', line 6161 def status_details @status_details end |
Class Method Details
.field_encodings ⇒ Object
6171 6172 6173 6174 6175 6176 6177 6178 6179 6180 6181 6182 6183 |
# File 'lib/stripe/resources/v2/core/account.rb', line 6171 def self.field_encodings @field_encodings = { protections: { kind: :object, fields: { psp_migration: { kind: :object, fields: { expires_at: :int64_string, requested_at: :int64_string }, }, }, }, } end |
.field_remappings ⇒ Object
6167 6168 6169 |
# File 'lib/stripe/resources/v2/core/account.rb', line 6167 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
6163 6164 6165 |
# File 'lib/stripe/resources/v2/core/account.rb', line 6163 def self.inner_class_types @inner_class_types = { protections: Protections, status_details: StatusDetail } end |