Class: Stripe::V2::Core::Account::Configuration::Merchant::Capabilities::StripeBalance
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Configuration::Merchant::Capabilities::StripeBalance
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: Payouts
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#payouts ⇒ Object
readonly
Enables this Account to complete payouts from their Stripe Balance (/v1/balance).
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#payouts ⇒ Object (readonly)
Enables this Account to complete payouts from their Stripe Balance (/v1/balance).
6448 6449 6450 |
# File 'lib/stripe/resources/v2/core/account.rb', line 6448 def payouts @payouts end |
Class Method Details
.field_encodings ⇒ Object
6458 6459 6460 6461 6462 6463 6464 6465 6466 6467 6468 6469 6470 6471 6472 6473 6474 6475 |
# File 'lib/stripe/resources/v2/core/account.rb', line 6458 def self.field_encodings @field_encodings = { payouts: { kind: :object, fields: { protections: { kind: :object, fields: { psp_migration: { kind: :object, fields: { expires_at: :int64_string, requested_at: :int64_string }, }, }, }, }, }, } end |
.field_remappings ⇒ Object
6454 6455 6456 |
# File 'lib/stripe/resources/v2/core/account.rb', line 6454 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
6450 6451 6452 |
# File 'lib/stripe/resources/v2/core/account.rb', line 6450 def self.inner_class_types @inner_class_types = { payouts: Payouts } end |