Class: Stripe::V2::Core::Account::Configuration::Merchant::GrossSettlement
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Configuration::Merchant::GrossSettlement
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#payment_method ⇒ Object
readonly
The ID of the payment method to use for gross settlement payouts.
-
#payment_method_collection ⇒ Object
readonly
Whether to collect a payment method for gross settlement.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#payment_method ⇒ Object (readonly)
The ID of the payment method to use for gross settlement payouts.
7744 7745 7746 |
# File 'lib/stripe/resources/v2/core/account.rb', line 7744 def payment_method @payment_method end |
#payment_method_collection ⇒ Object (readonly)
Whether to collect a payment method for gross settlement.
7746 7747 7748 |
# File 'lib/stripe/resources/v2/core/account.rb', line 7746 def payment_method_collection @payment_method_collection end |
Class Method Details
.field_remappings ⇒ Object
7752 7753 7754 |
# File 'lib/stripe/resources/v2/core/account.rb', line 7752 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
7748 7749 7750 |
# File 'lib/stripe/resources/v2/core/account.rb', line 7748 def self.inner_class_types @inner_class_types = {} end |