Class: Stripe::V2::Core::Account::Configuration::Merchant::StatementDescriptor
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Configuration::Merchant::StatementDescriptor
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#descriptor ⇒ Object
readonly
The default text that appears on statements for non-card charges outside of Japan.
-
#prefix ⇒ Object
readonly
Default text that appears on statements for card charges outside of Japan, prefixing any dynamic statement_descriptor_suffix specified on the charge.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#descriptor ⇒ Object (readonly)
The default text that appears on statements for non-card charges outside of Japan. For card charges, if you don’t set a statement_descriptor_prefix, this text is also used as the statement descriptor prefix. In that case, if concatenating the statement descriptor suffix causes the combined statement descriptor to exceed 22 characters, we truncate the statement_descriptor text to limit the full descriptor to 22 characters. For more information about statement descriptors and their requirements, see the Merchant Configuration settings documentation.
1879 1880 1881 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1879 def descriptor @descriptor end |
#prefix ⇒ Object (readonly)
Default text that appears on statements for card charges outside of Japan, prefixing any dynamic statement_descriptor_suffix specified on the charge. To maximize space for the dynamic part of the descriptor, keep this text short. If you don’t specify this value, statement_descriptor is used as the prefix. For more information about statement descriptors and their requirements, see the Merchant Configuration settings documentation.
1881 1882 1883 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1881 def prefix @prefix end |
Class Method Details
.field_remappings ⇒ Object
1887 1888 1889 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1887 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1883 1884 1885 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1883 def self.inner_class_types @inner_class_types = {} end |