Class: Stripe::V2::Core::Account::Configuration::Merchant::Support
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Configuration::Merchant::Support
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: Address
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#address ⇒ Object
readonly
A publicly available mailing address for sending support issues to.
-
#email ⇒ Object
readonly
A publicly available email address for sending support issues to.
-
#phone ⇒ Object
readonly
A publicly available phone number to call with support issues.
-
#url ⇒ Object
readonly
A publicly available website for handling support issues.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#address ⇒ Object (readonly)
A publicly available mailing address for sending support issues to.
949 950 951 |
# File 'lib/stripe/resources/v2/core/account.rb', line 949 def address @address end |
#email ⇒ Object (readonly)
A publicly available email address for sending support issues to.
951 952 953 |
# File 'lib/stripe/resources/v2/core/account.rb', line 951 def email @email end |
#phone ⇒ Object (readonly)
A publicly available phone number to call with support issues.
953 954 955 |
# File 'lib/stripe/resources/v2/core/account.rb', line 953 def phone @phone end |
#url ⇒ Object (readonly)
A publicly available website for handling support issues.
955 956 957 |
# File 'lib/stripe/resources/v2/core/account.rb', line 955 def url @url end |