Class: Stripe::V2::Core::Account::Configuration::MoneyManager

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: Capabilities, RegulatedActivity

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#appliedObject (readonly)

Indicates whether the money manager configuration is active. You cannot deactivate (or reactivate) the money manager configuration by updating this property.



12573
12574
12575
# File 'lib/stripe/resources/v2/core/account.rb', line 12573

def applied
  @applied
end

#capabilitiesObject (readonly)

Capabilities that have been requested on the Money Manager Configuration.



12575
12576
12577
# File 'lib/stripe/resources/v2/core/account.rb', line 12575

def capabilities
  @capabilities
end

#high_risk_activitiesObject (readonly)

List of high-risk activities the business is involved in.



12577
12578
12579
# File 'lib/stripe/resources/v2/core/account.rb', line 12577

def high_risk_activities
  @high_risk_activities
end

#high_risk_activities_descriptionObject (readonly)

Description of the high-risk activities the business offers.



12579
12580
12581
# File 'lib/stripe/resources/v2/core/account.rb', line 12579

def high_risk_activities_description
  @high_risk_activities_description
end

#money_services_descriptionObject (readonly)

Description of the money services offered by the business.



12581
12582
12583
# File 'lib/stripe/resources/v2/core/account.rb', line 12581

def money_services_description
  @money_services_description
end

#operates_in_prohibited_countriesObject (readonly)

Indicates whether the business operates in any prohibited countries.



12583
12584
12585
# File 'lib/stripe/resources/v2/core/account.rb', line 12583

def operates_in_prohibited_countries
  @operates_in_prohibited_countries
end

#participates_in_regulated_activityObject (readonly)

Does the business participate in any regulated activity.



12585
12586
12587
# File 'lib/stripe/resources/v2/core/account.rb', line 12585

def participates_in_regulated_activity
  @participates_in_regulated_activity
end

#purpose_of_fundsObject (readonly)

Primary purpose of the stored funds.



12587
12588
12589
# File 'lib/stripe/resources/v2/core/account.rb', line 12587

def purpose_of_funds
  @purpose_of_funds
end

#purpose_of_funds_descriptionObject (readonly)

Description of the purpose of the stored funds.



12589
12590
12591
# File 'lib/stripe/resources/v2/core/account.rb', line 12589

def purpose_of_funds_description
  @purpose_of_funds_description
end

#regulated_activityObject (readonly)

Details of the regulated activity if the business participates in one.



12591
12592
12593
# File 'lib/stripe/resources/v2/core/account.rb', line 12591

def regulated_activity
  @regulated_activity
end

#source_of_fundsObject (readonly)

The source of funds for the business, e.g. profits, income, venture capital, etc.



12593
12594
12595
# File 'lib/stripe/resources/v2/core/account.rb', line 12593

def source_of_funds
  @source_of_funds
end

#source_of_funds_descriptionObject (readonly)

Description of the source of funds for the business' account.



12595
12596
12597
# File 'lib/stripe/resources/v2/core/account.rb', line 12595

def source_of_funds_description
  @source_of_funds_description
end

Class Method Details

.field_encodingsObject



12608
12609
12610
12611
12612
12613
12614
12615
12616
12617
12618
12619
12620
12621
12622
12623
12624
12625
12626
12627
12628
12629
12630
12631
12632
12633
12634
12635
12636
12637
12638
12639
12640
12641
12642
12643
12644
12645
12646
12647
12648
12649
12650
12651
12652
12653
12654
12655
12656
12657
12658
12659
12660
12661
12662
12663
12664
12665
12666
12667
12668
12669
12670
12671
12672
12673
12674
12675
12676
12677
12678
12679
12680
12681
12682
12683
12684
12685
12686
12687
12688
12689
12690
12691
12692
12693
12694
12695
12696
12697
12698
12699
12700
12701
12702
12703
12704
12705
12706
12707
12708
12709
12710
12711
12712
12713
12714
12715
12716
12717
12718
12719
12720
12721
12722
12723
12724
12725
12726
12727
12728
12729
12730
12731
12732
12733
12734
12735
12736
12737
12738
12739
12740
12741
12742
12743
12744
12745
12746
12747
12748
12749
12750
12751
12752
12753
12754
12755
12756
12757
12758
12759
12760
12761
12762
12763
12764
12765
12766
12767
12768
12769
12770
12771
12772
12773
12774
12775
12776
12777
12778
12779
12780
12781
12782
12783
12784
12785
12786
12787
12788
12789
12790
12791
12792
12793
12794
12795
12796
12797
12798
12799
12800
12801
12802
12803
12804
12805
12806
12807
12808
12809
12810
12811
12812
12813
12814
12815
12816
12817
12818
12819
12820
12821
12822
12823
12824
12825
12826
12827
12828
12829
12830
12831
12832
12833
12834
12835
12836
12837
12838
12839
12840
12841
12842
12843
12844
12845
12846
12847
12848
12849
12850
12851
12852
12853
12854
12855
12856
12857
12858
12859
12860
12861
12862
12863
12864
12865
12866
12867
12868
12869
12870
12871
12872
12873
12874
12875
12876
12877
12878
12879
12880
12881
12882
12883
12884
12885
12886
12887
12888
12889
12890
12891
12892
12893
12894
12895
12896
12897
12898
12899
12900
12901
12902
12903
12904
12905
12906
12907
12908
12909
12910
12911
12912
12913
12914
12915
12916
12917
12918
12919
12920
12921
12922
12923
12924
12925
12926
12927
12928
12929
12930
12931
12932
12933
12934
12935
12936
12937
12938
12939
12940
12941
12942
12943
12944
12945
12946
12947
12948
12949
12950
12951
12952
12953
12954
12955
12956
12957
12958
12959
12960
12961
12962
12963
12964
12965
12966
12967
12968
12969
12970
12971
12972
12973
12974
12975
12976
12977
12978
12979
12980
12981
12982
12983
12984
12985
12986
12987
12988
12989
12990
12991
12992
12993
12994
12995
12996
12997
12998
12999
13000
13001
13002
13003
13004
13005
13006
13007
13008
13009
13010
13011
13012
13013
13014
13015
13016
13017
13018
13019
13020
13021
13022
13023
13024
13025
13026
13027
13028
13029
13030
13031
13032
13033
13034
13035
13036
13037
13038
13039
13040
13041
13042
13043
13044
13045
13046
13047
13048
13049
13050
13051
13052
13053
13054
13055
13056
13057
13058
13059
13060
13061
13062
13063
13064
13065
13066
13067
13068
13069
13070
13071
13072
13073
13074
13075
13076
13077
13078
13079
13080
13081
13082
13083
13084
13085
13086
13087
13088
13089
13090
13091
13092
13093
13094
13095
13096
13097
13098
13099
13100
13101
13102
13103
13104
13105
13106
13107
13108
13109
13110
13111
# File 'lib/stripe/resources/v2/core/account.rb', line 12608

def self.field_encodings
  @field_encodings = {
    capabilities: {
      kind: :object,
      fields: {
        business_storage: {
          kind: :object,
          fields: {
            inbound: {
              kind: :object,
              fields: {
                aud: {
                  kind: :object,
                  fields: {
                    protections: {
                      kind: :object,
                      fields: {
                        psp_migration: {
                          kind: :object,
                          fields: {
                            expires_at: :int64_string,
                            requested_at: :int64_string,
                          },
                        },
                      },
                    },
                  },
                },
                cad: {
                  kind: :object,
                  fields: {
                    protections: {
                      kind: :object,
                      fields: {
                        psp_migration: {
                          kind: :object,
                          fields: {
                            expires_at: :int64_string,
                            requested_at: :int64_string,
                          },
                        },
                      },
                    },
                  },
                },
                eur: {
                  kind: :object,
                  fields: {
                    protections: {
                      kind: :object,
                      fields: {
                        psp_migration: {
                          kind: :object,
                          fields: {
                            expires_at: :int64_string,
                            requested_at: :int64_string,
                          },
                        },
                      },
                    },
                  },
                },
                gbp: {
                  kind: :object,
                  fields: {
                    protections: {
                      kind: :object,
                      fields: {
                        psp_migration: {
                          kind: :object,
                          fields: {
                            expires_at: :int64_string,
                            requested_at: :int64_string,
                          },
                        },
                      },
                    },
                  },
                },
                usd: {
                  kind: :object,
                  fields: {
                    protections: {
                      kind: :object,
                      fields: {
                        psp_migration: {
                          kind: :object,
                          fields: {
                            expires_at: :int64_string,
                            requested_at: :int64_string,
                          },
                        },
                      },
                    },
                  },
                },
                usdc: {
                  kind: :object,
                  fields: {
                    protections: {
                      kind: :object,
                      fields: {
                        psp_migration: {
                          kind: :object,
                          fields: {
                            expires_at: :int64_string,
                            requested_at: :int64_string,
                          },
                        },
                      },
                    },
                  },
                },
              },
            },
            outbound: {
              kind: :object,
              fields: {
                aud: {
                  kind: :object,
                  fields: {
                    protections: {
                      kind: :object,
                      fields: {
                        psp_migration: {
                          kind: :object,
                          fields: {
                            expires_at: :int64_string,
                            requested_at: :int64_string,
                          },
                        },
                      },
                    },
                  },
                },
                cad: {
                  kind: :object,
                  fields: {
                    protections: {
                      kind: :object,
                      fields: {
                        psp_migration: {
                          kind: :object,
                          fields: {
                            expires_at: :int64_string,
                            requested_at: :int64_string,
                          },
                        },
                      },
                    },
                  },
                },
                eur: {
                  kind: :object,
                  fields: {
                    protections: {
                      kind: :object,
                      fields: {
                        psp_migration: {
                          kind: :object,
                          fields: {
                            expires_at: :int64_string,
                            requested_at: :int64_string,
                          },
                        },
                      },
                    },
                  },
                },
                gbp: {
                  kind: :object,
                  fields: {
                    protections: {
                      kind: :object,
                      fields: {
                        psp_migration: {
                          kind: :object,
                          fields: {
                            expires_at: :int64_string,
                            requested_at: :int64_string,
                          },
                        },
                      },
                    },
                  },
                },
                usd: {
                  kind: :object,
                  fields: {
                    protections: {
                      kind: :object,
                      fields: {
                        psp_migration: {
                          kind: :object,
                          fields: {
                            expires_at: :int64_string,
                            requested_at: :int64_string,
                          },
                        },
                      },
                    },
                  },
                },
                usdc: {
                  kind: :object,
                  fields: {
                    protections: {
                      kind: :object,
                      fields: {
                        psp_migration: {
                          kind: :object,
                          fields: {
                            expires_at: :int64_string,
                            requested_at: :int64_string,
                          },
                        },
                      },
                    },
                  },
                },
              },
            },
          },
        },
        consumer_storage: {
          kind: :object,
          fields: {
            inbound: {
              kind: :object,
              fields: {
                usd: {
                  kind: :object,
                  fields: {
                    protections: {
                      kind: :object,
                      fields: {
                        psp_migration: {
                          kind: :object,
                          fields: {
                            expires_at: :int64_string,
                            requested_at: :int64_string,
                          },
                        },
                      },
                    },
                  },
                },
                usdc: {
                  kind: :object,
                  fields: {
                    protections: {
                      kind: :object,
                      fields: {
                        psp_migration: {
                          kind: :object,
                          fields: {
                            expires_at: :int64_string,
                            requested_at: :int64_string,
                          },
                        },
                      },
                    },
                  },
                },
              },
            },
            outbound: {
              kind: :object,
              fields: {
                usd: {
                  kind: :object,
                  fields: {
                    protections: {
                      kind: :object,
                      fields: {
                        psp_migration: {
                          kind: :object,
                          fields: {
                            expires_at: :int64_string,
                            requested_at: :int64_string,
                          },
                        },
                      },
                    },
                  },
                },
                usdc: {
                  kind: :object,
                  fields: {
                    protections: {
                      kind: :object,
                      fields: {
                        psp_migration: {
                          kind: :object,
                          fields: {
                            expires_at: :int64_string,
                            requested_at: :int64_string,
                          },
                        },
                      },
                    },
                  },
                },
              },
            },
          },
        },
        inbound_transfers: {
          kind: :object,
          fields: {
            bank_accounts: {
              kind: :object,
              fields: {
                protections: {
                  kind: :object,
                  fields: {
                    psp_migration: {
                      kind: :object,
                      fields: { expires_at: :int64_string, requested_at: :int64_string },
                    },
                  },
                },
              },
            },
          },
        },
        outbound_payments: {
          kind: :object,
          fields: {
            bank_accounts: {
              kind: :object,
              fields: {
                protections: {
                  kind: :object,
                  fields: {
                    psp_migration: {
                      kind: :object,
                      fields: { expires_at: :int64_string, requested_at: :int64_string },
                    },
                  },
                },
              },
            },
            cards: {
              kind: :object,
              fields: {
                protections: {
                  kind: :object,
                  fields: {
                    psp_migration: {
                      kind: :object,
                      fields: { expires_at: :int64_string, requested_at: :int64_string },
                    },
                  },
                },
              },
            },
            crypto_wallets: {
              kind: :object,
              fields: {
                protections: {
                  kind: :object,
                  fields: {
                    psp_migration: {
                      kind: :object,
                      fields: { expires_at: :int64_string, requested_at: :int64_string },
                    },
                  },
                },
              },
            },
            financial_accounts: {
              kind: :object,
              fields: {
                protections: {
                  kind: :object,
                  fields: {
                    psp_migration: {
                      kind: :object,
                      fields: { expires_at: :int64_string, requested_at: :int64_string },
                    },
                  },
                },
              },
            },
            paper_checks: {
              kind: :object,
              fields: {
                protections: {
                  kind: :object,
                  fields: {
                    psp_migration: {
                      kind: :object,
                      fields: { expires_at: :int64_string, requested_at: :int64_string },
                    },
                  },
                },
              },
            },
          },
        },
        outbound_transfers: {
          kind: :object,
          fields: {
            bank_accounts: {
              kind: :object,
              fields: {
                protections: {
                  kind: :object,
                  fields: {
                    psp_migration: {
                      kind: :object,
                      fields: { expires_at: :int64_string, requested_at: :int64_string },
                    },
                  },
                },
              },
            },
            crypto_wallets: {
              kind: :object,
              fields: {
                protections: {
                  kind: :object,
                  fields: {
                    psp_migration: {
                      kind: :object,
                      fields: { expires_at: :int64_string, requested_at: :int64_string },
                    },
                  },
                },
              },
            },
            financial_accounts: {
              kind: :object,
              fields: {
                protections: {
                  kind: :object,
                  fields: {
                    psp_migration: {
                      kind: :object,
                      fields: { expires_at: :int64_string, requested_at: :int64_string },
                    },
                  },
                },
              },
            },
          },
        },
        received_credits: {
          kind: :object,
          fields: {
            bank_accounts: {
              kind: :object,
              fields: {
                protections: {
                  kind: :object,
                  fields: {
                    psp_migration: {
                      kind: :object,
                      fields: { expires_at: :int64_string, requested_at: :int64_string },
                    },
                  },
                },
              },
            },
            crypto_wallets: {
              kind: :object,
              fields: {
                protections: {
                  kind: :object,
                  fields: {
                    psp_migration: {
                      kind: :object,
                      fields: { expires_at: :int64_string, requested_at: :int64_string },
                    },
                  },
                },
              },
            },
          },
        },
        received_debits: {
          kind: :object,
          fields: {
            bank_accounts: {
              kind: :object,
              fields: {
                protections: {
                  kind: :object,
                  fields: {
                    psp_migration: {
                      kind: :object,
                      fields: { expires_at: :int64_string, requested_at: :int64_string },
                    },
                  },
                },
              },
            },
          },
        },
      },
    },
  }
end

.field_remappingsObject



12604
12605
12606
# File 'lib/stripe/resources/v2/core/account.rb', line 12604

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



12597
12598
12599
12600
12601
12602
# File 'lib/stripe/resources/v2/core/account.rb', line 12597

def self.inner_class_types
  @inner_class_types = {
    capabilities: Capabilities,
    regulated_activity: RegulatedActivity,
  }
end