Class: Stripe::V2::Core::Account::Configuration::MoneyManager::Capabilities::InboundTransfers
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Configuration::MoneyManager::Capabilities::InboundTransfers
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: BankAccounts
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bank_accounts ⇒ Object
readonly
Can pull funds into a FinancialAccount from an external bank account owned by the user.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bank_accounts ⇒ Object (readonly)
Can pull funds into a FinancialAccount from an external bank account owned by the user.
10790 10791 10792 |
# File 'lib/stripe/resources/v2/core/account.rb', line 10790 def bank_accounts @bank_accounts end |
Class Method Details
.field_encodings ⇒ Object
10800 10801 10802 10803 10804 10805 10806 10807 10808 10809 10810 10811 10812 10813 10814 10815 10816 10817 |
# File 'lib/stripe/resources/v2/core/account.rb', line 10800 def self.field_encodings @field_encodings = { bank_accounts: { kind: :object, fields: { protections: { kind: :object, fields: { psp_migration: { kind: :object, fields: { expires_at: :int64_string, requested_at: :int64_string }, }, }, }, }, }, } end |
.field_remappings ⇒ Object
10796 10797 10798 |
# File 'lib/stripe/resources/v2/core/account.rb', line 10796 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
10792 10793 10794 |
# File 'lib/stripe/resources/v2/core/account.rb', line 10792 def self.inner_class_types @inner_class_types = { bank_accounts: BankAccounts } end |