Class: Stripe::V2::Core::Account::Configuration::MoneyManager::Capabilities::OutboundTransfers

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: BankAccounts, CryptoWallets, FinancialAccounts

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_accountsObject (readonly)

Can send funds from a FinancialAccount to a bank account belonging to the same user.



11618
11619
11620
# File 'lib/stripe/resources/v2/core/account.rb', line 11618

def bank_accounts
  @bank_accounts
end

#crypto_walletsObject (readonly)

Can send funds from a FinancialAccount to a crypto wallet belonging to the same user.



11620
11621
11622
# File 'lib/stripe/resources/v2/core/account.rb', line 11620

def crypto_wallets
  @crypto_wallets
end

#financial_accountsObject (readonly)

Can send funds from a FinancialAccount to another FinancialAccount belonging to the same user.



11622
11623
11624
# File 'lib/stripe/resources/v2/core/account.rb', line 11622

def financial_accounts
  @financial_accounts
end

Class Method Details

.field_encodingsObject



11636
11637
11638
11639
11640
11641
11642
11643
11644
11645
11646
11647
11648
11649
11650
11651
11652
11653
11654
11655
11656
11657
11658
11659
11660
11661
11662
11663
11664
11665
11666
11667
11668
11669
11670
11671
11672
11673
11674
11675
11676
11677
11678
11679
11680
11681
# File 'lib/stripe/resources/v2/core/account.rb', line 11636

def self.field_encodings
  @field_encodings = {
    bank_accounts: {
      kind: :object,
      fields: {
        protections: {
          kind: :object,
          fields: {
            psp_migration: {
              kind: :object,
              fields: { expires_at: :int64_string, requested_at: :int64_string },
            },
          },
        },
      },
    },
    crypto_wallets: {
      kind: :object,
      fields: {
        protections: {
          kind: :object,
          fields: {
            psp_migration: {
              kind: :object,
              fields: { expires_at: :int64_string, requested_at: :int64_string },
            },
          },
        },
      },
    },
    financial_accounts: {
      kind: :object,
      fields: {
        protections: {
          kind: :object,
          fields: {
            psp_migration: {
              kind: :object,
              fields: { expires_at: :int64_string, requested_at: :int64_string },
            },
          },
        },
      },
    },
  }
end

.field_remappingsObject



11632
11633
11634
# File 'lib/stripe/resources/v2/core/account.rb', line 11632

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



11624
11625
11626
11627
11628
11629
11630
# File 'lib/stripe/resources/v2/core/account.rb', line 11624

def self.inner_class_types
  @inner_class_types = {
    bank_accounts: BankAccounts,
    crypto_wallets: CryptoWallets,
    financial_accounts: FinancialAccounts,
  }
end