Class: Stripe::V2::Core::Account::Configuration::MoneyManager::Capabilities::ReceivedCredits
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Configuration::MoneyManager::Capabilities::ReceivedCredits
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: BankAccounts, CryptoWallets
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bank_accounts ⇒ Object
readonly
Can receive credits to a bank-account like financial address to credit a FinancialAccount.
-
#crypto_wallets ⇒ Object
readonly
Can receive credits to a crypto wallet like financial address to credit a FinancialAccount.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bank_accounts ⇒ Object (readonly)
Can receive credits to a bank-account like financial address to credit a FinancialAccount.
11859 11860 11861 |
# File 'lib/stripe/resources/v2/core/account.rb', line 11859 def bank_accounts @bank_accounts end |
#crypto_wallets ⇒ Object (readonly)
Can receive credits to a crypto wallet like financial address to credit a FinancialAccount.
11861 11862 11863 |
# File 'lib/stripe/resources/v2/core/account.rb', line 11861 def crypto_wallets @crypto_wallets end |
Class Method Details
.field_encodings ⇒ Object
11871 11872 11873 11874 11875 11876 11877 11878 11879 11880 11881 11882 11883 11884 11885 11886 11887 11888 11889 11890 11891 11892 11893 11894 11895 11896 11897 11898 11899 11900 11901 11902 |
# File 'lib/stripe/resources/v2/core/account.rb', line 11871 def self.field_encodings @field_encodings = { bank_accounts: { kind: :object, fields: { protections: { kind: :object, fields: { psp_migration: { kind: :object, fields: { expires_at: :int64_string, requested_at: :int64_string }, }, }, }, }, }, crypto_wallets: { kind: :object, fields: { protections: { kind: :object, fields: { psp_migration: { kind: :object, fields: { expires_at: :int64_string, requested_at: :int64_string }, }, }, }, }, }, } end |
.field_remappings ⇒ Object
11867 11868 11869 |
# File 'lib/stripe/resources/v2/core/account.rb', line 11867 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
11863 11864 11865 |
# File 'lib/stripe/resources/v2/core/account.rb', line 11863 def self.inner_class_types @inner_class_types = { bank_accounts: BankAccounts, crypto_wallets: CryptoWallets } end |