Class: Stripe::V2::Core::Account::Configuration::Recipient::Capabilities

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: BankAccounts, Cards, CryptoWallets, PaperChecks, StripeBalance

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_accountsObject (readonly)

Capabilities that enable OutboundPayments to a bank account linked to this Account.



14966
14967
14968
# File 'lib/stripe/resources/v2/core/account.rb', line 14966

def bank_accounts
  @bank_accounts
end

#cardsObject (readonly)

Enables this Account to receive OutboundPayments to a linked debit card.



14968
14969
14970
# File 'lib/stripe/resources/v2/core/account.rb', line 14968

def cards
  @cards
end

#crypto_walletsObject (readonly)

Enables this Account to receive OutboundPayments to a linked crypto wallet.



14970
14971
14972
# File 'lib/stripe/resources/v2/core/account.rb', line 14970

def crypto_wallets
  @crypto_wallets
end

#paper_checksObject (readonly)

Capabilities that enable OutboundPayments via paper check.



14972
14973
14974
# File 'lib/stripe/resources/v2/core/account.rb', line 14972

def paper_checks
  @paper_checks
end

#stripe_balanceObject (readonly)

Capabilities that enable the recipient to manage their Stripe Balance (/v1/balance).



14974
14975
14976
# File 'lib/stripe/resources/v2/core/account.rb', line 14974

def stripe_balance
  @stripe_balance
end

Class Method Details

.field_encodingsObject



14990
14991
14992
14993
14994
14995
14996
14997
14998
14999
15000
15001
15002
15003
15004
15005
15006
15007
15008
15009
15010
15011
15012
15013
15014
15015
15016
15017
15018
15019
15020
15021
15022
15023
15024
15025
15026
15027
15028
15029
15030
15031
15032
15033
15034
15035
15036
15037
15038
15039
15040
15041
15042
15043
15044
15045
15046
15047
15048
15049
15050
15051
15052
15053
15054
15055
15056
15057
15058
15059
15060
15061
15062
15063
15064
15065
15066
15067
15068
15069
15070
15071
15072
15073
15074
15075
15076
15077
15078
15079
15080
15081
15082
15083
15084
15085
15086
15087
15088
15089
15090
15091
15092
15093
15094
15095
15096
15097
15098
15099
15100
15101
15102
15103
15104
15105
15106
15107
15108
15109
15110
15111
15112
15113
15114
15115
15116
15117
15118
15119
15120
15121
15122
15123
15124
15125
15126
15127
15128
15129
15130
15131
15132
15133
15134
15135
15136
15137
15138
15139
15140
15141
15142
15143
15144
15145
15146
15147
15148
15149
15150
15151
15152
15153
15154
15155
15156
15157
15158
15159
15160
15161
15162
15163
15164
15165
15166
15167
15168
15169
15170
15171
15172
15173
15174
15175
15176
15177
15178
15179
15180
15181
15182
15183
15184
15185
15186
15187
15188
15189
15190
15191
15192
15193
15194
15195
15196
15197
15198
15199
15200
15201
15202
15203
15204
15205
15206
15207
15208
15209
15210
15211
15212
15213
15214
15215
15216
15217
15218
15219
15220
15221
15222
15223
15224
15225
15226
15227
15228
15229
15230
15231
15232
15233
15234
15235
15236
15237
15238
15239
15240
15241
15242
15243
15244
15245
15246
15247
15248
15249
15250
15251
15252
15253
15254
15255
# File 'lib/stripe/resources/v2/core/account.rb', line 14990

def self.field_encodings
  @field_encodings = {
    bank_accounts: {
      kind: :object,
      fields: {
        ach: {
          kind: :object,
          fields: {
            protections: {
              kind: :object,
              fields: {
                psp_migration: {
                  kind: :object,
                  fields: { expires_at: :int64_string, requested_at: :int64_string },
                },
              },
            },
          },
        },
        becs: {
          kind: :object,
          fields: {
            protections: {
              kind: :object,
              fields: {
                psp_migration: {
                  kind: :object,
                  fields: { expires_at: :int64_string, requested_at: :int64_string },
                },
              },
            },
          },
        },
        eft: {
          kind: :object,
          fields: {
            protections: {
              kind: :object,
              fields: {
                psp_migration: {
                  kind: :object,
                  fields: { expires_at: :int64_string, requested_at: :int64_string },
                },
              },
            },
          },
        },
        fedwire: {
          kind: :object,
          fields: {
            protections: {
              kind: :object,
              fields: {
                psp_migration: {
                  kind: :object,
                  fields: { expires_at: :int64_string, requested_at: :int64_string },
                },
              },
            },
          },
        },
        fps: {
          kind: :object,
          fields: {
            protections: {
              kind: :object,
              fields: {
                psp_migration: {
                  kind: :object,
                  fields: { expires_at: :int64_string, requested_at: :int64_string },
                },
              },
            },
          },
        },
        instant: {
          kind: :object,
          fields: {
            protections: {
              kind: :object,
              fields: {
                psp_migration: {
                  kind: :object,
                  fields: { expires_at: :int64_string, requested_at: :int64_string },
                },
              },
            },
          },
        },
        local: {
          kind: :object,
          fields: {
            protections: {
              kind: :object,
              fields: {
                psp_migration: {
                  kind: :object,
                  fields: { expires_at: :int64_string, requested_at: :int64_string },
                },
              },
            },
          },
        },
        npp: {
          kind: :object,
          fields: {
            protections: {
              kind: :object,
              fields: {
                psp_migration: {
                  kind: :object,
                  fields: { expires_at: :int64_string, requested_at: :int64_string },
                },
              },
            },
          },
        },
        rtp: {
          kind: :object,
          fields: {
            protections: {
              kind: :object,
              fields: {
                psp_migration: {
                  kind: :object,
                  fields: { expires_at: :int64_string, requested_at: :int64_string },
                },
              },
            },
          },
        },
        sepa_credit: {
          kind: :object,
          fields: {
            protections: {
              kind: :object,
              fields: {
                psp_migration: {
                  kind: :object,
                  fields: { expires_at: :int64_string, requested_at: :int64_string },
                },
              },
            },
          },
        },
        sepa_instant: {
          kind: :object,
          fields: {
            protections: {
              kind: :object,
              fields: {
                psp_migration: {
                  kind: :object,
                  fields: { expires_at: :int64_string, requested_at: :int64_string },
                },
              },
            },
          },
        },
        swift: {
          kind: :object,
          fields: {
            protections: {
              kind: :object,
              fields: {
                psp_migration: {
                  kind: :object,
                  fields: { expires_at: :int64_string, requested_at: :int64_string },
                },
              },
            },
          },
        },
        wire: {
          kind: :object,
          fields: {
            protections: {
              kind: :object,
              fields: {
                psp_migration: {
                  kind: :object,
                  fields: { expires_at: :int64_string, requested_at: :int64_string },
                },
              },
            },
          },
        },
      },
    },
    cards: {
      kind: :object,
      fields: {
        protections: {
          kind: :object,
          fields: {
            psp_migration: {
              kind: :object,
              fields: { expires_at: :int64_string, requested_at: :int64_string },
            },
          },
        },
      },
    },
    crypto_wallets: {
      kind: :object,
      fields: {
        protections: {
          kind: :object,
          fields: {
            psp_migration: {
              kind: :object,
              fields: { expires_at: :int64_string, requested_at: :int64_string },
            },
          },
        },
      },
    },
    paper_checks: {
      kind: :object,
      fields: {
        protections: {
          kind: :object,
          fields: {
            psp_migration: {
              kind: :object,
              fields: { expires_at: :int64_string, requested_at: :int64_string },
            },
          },
        },
      },
    },
    stripe_balance: {
      kind: :object,
      fields: {
        payouts: {
          kind: :object,
          fields: {
            protections: {
              kind: :object,
              fields: {
                psp_migration: {
                  kind: :object,
                  fields: { expires_at: :int64_string, requested_at: :int64_string },
                },
              },
            },
          },
        },
        stripe_transfers: {
          kind: :object,
          fields: {
            protections: {
              kind: :object,
              fields: {
                psp_migration: {
                  kind: :object,
                  fields: { expires_at: :int64_string, requested_at: :int64_string },
                },
              },
            },
          },
        },
      },
    },
  }
end

.field_remappingsObject



14986
14987
14988
# File 'lib/stripe/resources/v2/core/account.rb', line 14986

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



14976
14977
14978
14979
14980
14981
14982
14983
14984
# File 'lib/stripe/resources/v2/core/account.rb', line 14976

def self.inner_class_types
  @inner_class_types = {
    bank_accounts: BankAccounts,
    cards: Cards,
    crypto_wallets: CryptoWallets,
    paper_checks: PaperChecks,
    stripe_balance: StripeBalance,
  }
end