Class: Stripe::V2::Core::Account::Configuration::Recipient::Capabilities::BankAccounts
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Configuration::Recipient::Capabilities::BankAccounts
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: Ach, Becs, Eft, Fedwire, Fps, Instant, Local, Npp, Rtp, SepaCredit, SepaInstant, Swift, Wire
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#ach ⇒ Object
readonly
Enables this Account to receive OutboundPayments to linked bank accounts over ACH rails.
-
#becs ⇒ Object
readonly
Enables this Account to receive OutboundPayments to linked bank accounts over BECS rails.
-
#eft ⇒ Object
readonly
Enables this Account to receive OutboundPayments to linked bank accounts over EFT rails.
-
#fedwire ⇒ Object
readonly
Enables this Account to receive OutboundPayments to linked bank accounts over Fedwire or CHIPS.
-
#fps ⇒ Object
readonly
Enables this Account to receive OutboundPayments to linked bank accounts over FPS rails.
-
#instant ⇒ Object
readonly
Enables this Account to receive OutboundPayments to linked bank accounts over real time rails.
-
#local ⇒ Object
readonly
Enables this Account to receive OutboundPayments to linked bank accounts over local networks.
-
#npp ⇒ Object
readonly
Enables this Account to receive OutboundPayments to linked bank accounts over NPP (real time) rails.
-
#rtp ⇒ Object
readonly
Enables this Account to receive OutboundPayments to linked bank accounts over RTP rails.
-
#sepa_credit ⇒ Object
readonly
Enables this Account to receive OutboundPayments to linked bank accounts over SEPA credit rails.
-
#sepa_instant ⇒ Object
readonly
Enables this Account to receive OutboundPayments to linked bank accounts over SEPA instant (real time) rails.
-
#swift ⇒ Object
readonly
Enables this Account to receive OutboundPayments to linked bank accounts over SWIFT.
-
#wire ⇒ Object
readonly
Enables this Account to receive OutboundPayments to linked bank accounts over wire.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#ach ⇒ Object (readonly)
Enables this Account to receive OutboundPayments to linked bank accounts over ACH rails.
14248 14249 14250 |
# File 'lib/stripe/resources/v2/core/account.rb', line 14248 def ach @ach end |
#becs ⇒ Object (readonly)
Enables this Account to receive OutboundPayments to linked bank accounts over BECS rails.
14250 14251 14252 |
# File 'lib/stripe/resources/v2/core/account.rb', line 14250 def becs @becs end |
#eft ⇒ Object (readonly)
Enables this Account to receive OutboundPayments to linked bank accounts over EFT rails.
14252 14253 14254 |
# File 'lib/stripe/resources/v2/core/account.rb', line 14252 def eft @eft end |
#fedwire ⇒ Object (readonly)
Enables this Account to receive OutboundPayments to linked bank accounts over Fedwire or CHIPS.
14254 14255 14256 |
# File 'lib/stripe/resources/v2/core/account.rb', line 14254 def fedwire @fedwire end |
#fps ⇒ Object (readonly)
Enables this Account to receive OutboundPayments to linked bank accounts over FPS rails.
14256 14257 14258 |
# File 'lib/stripe/resources/v2/core/account.rb', line 14256 def fps @fps end |
#instant ⇒ Object (readonly)
Enables this Account to receive OutboundPayments to linked bank accounts over real time rails.
14258 14259 14260 |
# File 'lib/stripe/resources/v2/core/account.rb', line 14258 def instant @instant end |
#local ⇒ Object (readonly)
Enables this Account to receive OutboundPayments to linked bank accounts over local networks.
14260 14261 14262 |
# File 'lib/stripe/resources/v2/core/account.rb', line 14260 def local @local end |
#npp ⇒ Object (readonly)
Enables this Account to receive OutboundPayments to linked bank accounts over NPP (real time) rails.
14262 14263 14264 |
# File 'lib/stripe/resources/v2/core/account.rb', line 14262 def npp @npp end |
#rtp ⇒ Object (readonly)
Enables this Account to receive OutboundPayments to linked bank accounts over RTP rails.
14264 14265 14266 |
# File 'lib/stripe/resources/v2/core/account.rb', line 14264 def rtp @rtp end |
#sepa_credit ⇒ Object (readonly)
Enables this Account to receive OutboundPayments to linked bank accounts over SEPA credit rails.
14266 14267 14268 |
# File 'lib/stripe/resources/v2/core/account.rb', line 14266 def sepa_credit @sepa_credit end |
#sepa_instant ⇒ Object (readonly)
Enables this Account to receive OutboundPayments to linked bank accounts over SEPA instant (real time) rails.
14268 14269 14270 |
# File 'lib/stripe/resources/v2/core/account.rb', line 14268 def sepa_instant @sepa_instant end |
#swift ⇒ Object (readonly)
Enables this Account to receive OutboundPayments to linked bank accounts over SWIFT.
14270 14271 14272 |
# File 'lib/stripe/resources/v2/core/account.rb', line 14270 def swift @swift end |
#wire ⇒ Object (readonly)
Enables this Account to receive OutboundPayments to linked bank accounts over wire.
14272 14273 14274 |
# File 'lib/stripe/resources/v2/core/account.rb', line 14272 def wire @wire end |
Class Method Details
.field_encodings ⇒ Object
14296 14297 14298 14299 14300 14301 14302 14303 14304 14305 14306 14307 14308 14309 14310 14311 14312 14313 14314 14315 14316 14317 14318 14319 14320 14321 14322 14323 14324 14325 14326 14327 14328 14329 14330 14331 14332 14333 14334 14335 14336 14337 14338 14339 14340 14341 14342 14343 14344 14345 14346 14347 14348 14349 14350 14351 14352 14353 14354 14355 14356 14357 14358 14359 14360 14361 14362 14363 14364 14365 14366 14367 14368 14369 14370 14371 14372 14373 14374 14375 14376 14377 14378 14379 14380 14381 14382 14383 14384 14385 14386 14387 14388 14389 14390 14391 14392 14393 14394 14395 14396 14397 14398 14399 14400 14401 14402 14403 14404 14405 14406 14407 14408 14409 14410 14411 14412 14413 14414 14415 14416 14417 14418 14419 14420 14421 14422 14423 14424 14425 14426 14427 14428 14429 14430 14431 14432 14433 14434 14435 14436 14437 14438 14439 14440 14441 14442 14443 14444 14445 14446 14447 14448 14449 14450 14451 14452 14453 14454 14455 14456 14457 14458 14459 14460 14461 14462 14463 14464 14465 14466 14467 14468 14469 14470 14471 14472 14473 14474 14475 14476 14477 14478 14479 14480 14481 |
# File 'lib/stripe/resources/v2/core/account.rb', line 14296 def self.field_encodings @field_encodings = { ach: { kind: :object, fields: { protections: { kind: :object, fields: { psp_migration: { kind: :object, fields: { expires_at: :int64_string, requested_at: :int64_string }, }, }, }, }, }, becs: { kind: :object, fields: { protections: { kind: :object, fields: { psp_migration: { kind: :object, fields: { expires_at: :int64_string, requested_at: :int64_string }, }, }, }, }, }, eft: { kind: :object, fields: { protections: { kind: :object, fields: { psp_migration: { kind: :object, fields: { expires_at: :int64_string, requested_at: :int64_string }, }, }, }, }, }, fedwire: { kind: :object, fields: { protections: { kind: :object, fields: { psp_migration: { kind: :object, fields: { expires_at: :int64_string, requested_at: :int64_string }, }, }, }, }, }, fps: { kind: :object, fields: { protections: { kind: :object, fields: { psp_migration: { kind: :object, fields: { expires_at: :int64_string, requested_at: :int64_string }, }, }, }, }, }, instant: { kind: :object, fields: { protections: { kind: :object, fields: { psp_migration: { kind: :object, fields: { expires_at: :int64_string, requested_at: :int64_string }, }, }, }, }, }, local: { kind: :object, fields: { protections: { kind: :object, fields: { psp_migration: { kind: :object, fields: { expires_at: :int64_string, requested_at: :int64_string }, }, }, }, }, }, npp: { kind: :object, fields: { protections: { kind: :object, fields: { psp_migration: { kind: :object, fields: { expires_at: :int64_string, requested_at: :int64_string }, }, }, }, }, }, rtp: { kind: :object, fields: { protections: { kind: :object, fields: { psp_migration: { kind: :object, fields: { expires_at: :int64_string, requested_at: :int64_string }, }, }, }, }, }, sepa_credit: { kind: :object, fields: { protections: { kind: :object, fields: { psp_migration: { kind: :object, fields: { expires_at: :int64_string, requested_at: :int64_string }, }, }, }, }, }, sepa_instant: { kind: :object, fields: { protections: { kind: :object, fields: { psp_migration: { kind: :object, fields: { expires_at: :int64_string, requested_at: :int64_string }, }, }, }, }, }, swift: { kind: :object, fields: { protections: { kind: :object, fields: { psp_migration: { kind: :object, fields: { expires_at: :int64_string, requested_at: :int64_string }, }, }, }, }, }, wire: { kind: :object, fields: { protections: { kind: :object, fields: { psp_migration: { kind: :object, fields: { expires_at: :int64_string, requested_at: :int64_string }, }, }, }, }, }, } end |
.field_remappings ⇒ Object
14292 14293 14294 |
# File 'lib/stripe/resources/v2/core/account.rb', line 14292 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
14274 14275 14276 14277 14278 14279 14280 14281 14282 14283 14284 14285 14286 14287 14288 14289 14290 |
# File 'lib/stripe/resources/v2/core/account.rb', line 14274 def self.inner_class_types @inner_class_types = { ach: Ach, becs: Becs, eft: Eft, fedwire: Fedwire, fps: Fps, instant: Instant, local: Local, npp: Npp, rtp: Rtp, sepa_credit: SepaCredit, sepa_instant: SepaInstant, swift: Swift, wire: Wire, } end |