Class: Stripe::V2::Core::Account::Configuration::Recipient::Capabilities::Cards
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Configuration::Recipient::Capabilities::Cards
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: Protections, StatusDetail
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#protections ⇒ Object
readonly
Protections applied to this capability, keyed by protection type (e.g. "psp_migration").
-
#status ⇒ Object
readonly
The status of the Capability.
-
#status_details ⇒ Object
readonly
Additional details about the capability's status.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#protections ⇒ Object (readonly)
Protections applied to this capability, keyed by protection type (e.g. "psp_migration").
14542 14543 14544 |
# File 'lib/stripe/resources/v2/core/account.rb', line 14542 def protections @protections end |
#status ⇒ Object (readonly)
The status of the Capability.
14544 14545 14546 |
# File 'lib/stripe/resources/v2/core/account.rb', line 14544 def status @status end |
#status_details ⇒ Object (readonly)
Additional details about the capability's status. This value is empty when status is active.
14546 14547 14548 |
# File 'lib/stripe/resources/v2/core/account.rb', line 14546 def status_details @status_details end |
Class Method Details
.field_encodings ⇒ Object
14556 14557 14558 14559 14560 14561 14562 14563 14564 14565 14566 14567 14568 |
# File 'lib/stripe/resources/v2/core/account.rb', line 14556 def self.field_encodings @field_encodings = { protections: { kind: :object, fields: { psp_migration: { kind: :object, fields: { expires_at: :int64_string, requested_at: :int64_string }, }, }, }, } end |
.field_remappings ⇒ Object
14552 14553 14554 |
# File 'lib/stripe/resources/v2/core/account.rb', line 14552 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
14548 14549 14550 |
# File 'lib/stripe/resources/v2/core/account.rb', line 14548 def self.inner_class_types @inner_class_types = { protections: Protections, status_details: StatusDetail } end |