Class: Stripe::V2::Core::Account::Configuration::Recipient::Capabilities::CryptoWallets
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Configuration::Recipient::Capabilities::CryptoWallets
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: Protections, StatusDetail
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#protections ⇒ Object
readonly
Protections applied to this capability, keyed by protection type (e.g. "psp_migration").
-
#status ⇒ Object
readonly
The status of the Capability.
-
#status_details ⇒ Object
readonly
Additional details about the capability's status.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#protections ⇒ Object (readonly)
Protections applied to this capability, keyed by protection type (e.g. "psp_migration").
14629 14630 14631 |
# File 'lib/stripe/resources/v2/core/account.rb', line 14629 def protections @protections end |
#status ⇒ Object (readonly)
The status of the Capability.
14631 14632 14633 |
# File 'lib/stripe/resources/v2/core/account.rb', line 14631 def status @status end |
#status_details ⇒ Object (readonly)
Additional details about the capability's status. This value is empty when status is active.
14633 14634 14635 |
# File 'lib/stripe/resources/v2/core/account.rb', line 14633 def status_details @status_details end |
Class Method Details
.field_encodings ⇒ Object
14643 14644 14645 14646 14647 14648 14649 14650 14651 14652 14653 14654 14655 |
# File 'lib/stripe/resources/v2/core/account.rb', line 14643 def self.field_encodings @field_encodings = { protections: { kind: :object, fields: { psp_migration: { kind: :object, fields: { expires_at: :int64_string, requested_at: :int64_string }, }, }, }, } end |
.field_remappings ⇒ Object
14639 14640 14641 |
# File 'lib/stripe/resources/v2/core/account.rb', line 14639 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
14635 14636 14637 |
# File 'lib/stripe/resources/v2/core/account.rb', line 14635 def self.inner_class_types @inner_class_types = { protections: Protections, status_details: StatusDetail } end |