Class: Stripe::V2::Core::Account::Configuration::Recipient::Capabilities::StripeBalance
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Configuration::Recipient::Capabilities::StripeBalance
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: Payouts, StripeTransfers
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#payouts ⇒ Object
readonly
Enables this Account to complete payouts from their Stripe Balance (/v1/balance).
-
#stripe_transfers ⇒ Object
readonly
Enables this Account to receive /v1/transfers into their Stripe Balance (/v1/balance).
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#payouts ⇒ Object (readonly)
Enables this Account to complete payouts from their Stripe Balance (/v1/balance).
14920 14921 14922 |
# File 'lib/stripe/resources/v2/core/account.rb', line 14920 def payouts @payouts end |
#stripe_transfers ⇒ Object (readonly)
Enables this Account to receive /v1/transfers into their Stripe Balance (/v1/balance).
14922 14923 14924 |
# File 'lib/stripe/resources/v2/core/account.rb', line 14922 def stripe_transfers @stripe_transfers end |
Class Method Details
.field_encodings ⇒ Object
14932 14933 14934 14935 14936 14937 14938 14939 14940 14941 14942 14943 14944 14945 14946 14947 14948 14949 14950 14951 14952 14953 14954 14955 14956 14957 14958 14959 14960 14961 14962 14963 |
# File 'lib/stripe/resources/v2/core/account.rb', line 14932 def self.field_encodings @field_encodings = { payouts: { kind: :object, fields: { protections: { kind: :object, fields: { psp_migration: { kind: :object, fields: { expires_at: :int64_string, requested_at: :int64_string }, }, }, }, }, }, stripe_transfers: { kind: :object, fields: { protections: { kind: :object, fields: { psp_migration: { kind: :object, fields: { expires_at: :int64_string, requested_at: :int64_string }, }, }, }, }, }, } end |
.field_remappings ⇒ Object
14928 14929 14930 |
# File 'lib/stripe/resources/v2/core/account.rb', line 14928 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
14924 14925 14926 |
# File 'lib/stripe/resources/v2/core/account.rb', line 14924 def self.inner_class_types @inner_class_types = { payouts: Payouts, stripe_transfers: StripeTransfers } end |