Class: Stripe::V2::Core::Account::Configuration::Storer::Capabilities
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Configuration::Storer::Capabilities
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: FinancialAddresses, HoldsCurrencies, InboundTransfers, OutboundPayments, OutboundTransfers
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#financial_addresses ⇒ Object
readonly
Can provision a financial address to credit/debit a FinancialAccount.
-
#holds_currencies ⇒ Object
readonly
Can hold storage-type funds on Stripe.
-
#inbound_transfers ⇒ Object
readonly
Can pull funds from an external source, owned by yourself, to a FinancialAccount.
-
#outbound_payments ⇒ Object
readonly
Can send funds from a FinancialAccount to a destination owned by someone else.
-
#outbound_transfers ⇒ Object
readonly
Can send funds from a FinancialAccount to a destination owned by yourself.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#financial_addresses ⇒ Object (readonly)
Can provision a financial address to credit/debit a FinancialAccount.
3023 3024 3025 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3023 def financial_addresses @financial_addresses end |
#holds_currencies ⇒ Object (readonly)
Can hold storage-type funds on Stripe.
3025 3026 3027 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3025 def holds_currencies @holds_currencies end |
#inbound_transfers ⇒ Object (readonly)
Can pull funds from an external source, owned by yourself, to a FinancialAccount.
3027 3028 3029 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3027 def inbound_transfers @inbound_transfers end |
#outbound_payments ⇒ Object (readonly)
Can send funds from a FinancialAccount to a destination owned by someone else.
3029 3030 3031 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3029 def outbound_payments @outbound_payments end |
#outbound_transfers ⇒ Object (readonly)
Can send funds from a FinancialAccount to a destination owned by yourself.
3031 3032 3033 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3031 def outbound_transfers @outbound_transfers end |
Class Method Details
.field_remappings ⇒ Object
3043 3044 3045 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3043 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
3033 3034 3035 3036 3037 3038 3039 3040 3041 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3033 def self.inner_class_types @inner_class_types = { financial_addresses: FinancialAddresses, holds_currencies: HoldsCurrencies, inbound_transfers: InboundTransfers, outbound_payments: OutboundPayments, outbound_transfers: OutboundTransfers, } end |