Class: Stripe::V2::Core::Account::Configuration::Storer::RegulatedActivity

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#descriptionObject (readonly)

A detailed description of the regulated activities the business is licensed to conduct.



3436
3437
3438
# File 'lib/stripe/resources/v2/core/account.rb', line 3436

def description
  @description
end

#license_numberObject (readonly)

The license number or registration number assigned by the business’s primary regulator.



3438
3439
3440
# File 'lib/stripe/resources/v2/core/account.rb', line 3438

def license_number
  @license_number
end

#primary_regulatory_authority_countryObject (readonly)

The country of the primary regulatory authority that oversees the business’s regulated activities.



3440
3441
3442
# File 'lib/stripe/resources/v2/core/account.rb', line 3440

def primary_regulatory_authority_country
  @primary_regulatory_authority_country
end

#primary_regulatory_authority_nameObject (readonly)

The name of the primary regulatory authority that oversees the business’s regulated activities.



3442
3443
3444
# File 'lib/stripe/resources/v2/core/account.rb', line 3442

def primary_regulatory_authority_name
  @primary_regulatory_authority_name
end

Class Method Details

.field_remappingsObject



3448
3449
3450
# File 'lib/stripe/resources/v2/core/account.rb', line 3448

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



3444
3445
3446
# File 'lib/stripe/resources/v2/core/account.rb', line 3444

def self.inner_class_types
  @inner_class_types = {}
end