Class: Stripe::V2::Core::Account::Defaults
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Defaults
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: Profile, Responsibilities
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#currency ⇒ Object
readonly
Three-letter ISO currency code, in lowercase.
-
#locales ⇒ Object
readonly
The Account's preferred locales (languages), ordered by preference.
-
#profile ⇒ Object
readonly
Account profile information.
-
#responsibilities ⇒ Object
readonly
Default responsibilities held by either Stripe or the platform.
-
#timezone ⇒ Object
readonly
The Account's local timezone.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#currency ⇒ Object (readonly)
Three-letter ISO currency code, in lowercase. Must be a supported currency.
17470 17471 17472 |
# File 'lib/stripe/resources/v2/core/account.rb', line 17470 def currency @currency end |
#locales ⇒ Object (readonly)
The Account's preferred locales (languages), ordered by preference.
17472 17473 17474 |
# File 'lib/stripe/resources/v2/core/account.rb', line 17472 def locales @locales end |
#profile ⇒ Object (readonly)
Account profile information.
17474 17475 17476 |
# File 'lib/stripe/resources/v2/core/account.rb', line 17474 def profile @profile end |
#responsibilities ⇒ Object (readonly)
Default responsibilities held by either Stripe or the platform.
17476 17477 17478 |
# File 'lib/stripe/resources/v2/core/account.rb', line 17476 def responsibilities @responsibilities end |
#timezone ⇒ Object (readonly)
The Account's local timezone. A list of possible time zone values is maintained at the IANA Time Zone Database.
17478 17479 17480 |
# File 'lib/stripe/resources/v2/core/account.rb', line 17478 def timezone @timezone end |
Class Method Details
.field_remappings ⇒ Object
17484 17485 17486 |
# File 'lib/stripe/resources/v2/core/account.rb', line 17484 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
17480 17481 17482 |
# File 'lib/stripe/resources/v2/core/account.rb', line 17480 def self.inner_class_types @inner_class_types = { profile: Profile, responsibilities: Responsibilities } end |