Class: Stripe::V2::Core::Account::Defaults::Profile

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#business_urlObject (readonly)

The business’s publicly-available website.



2060
2061
2062
# File 'lib/stripe/resources/v2/core/account.rb', line 2060

def business_url
  @business_url
end

#doing_business_asObject (readonly)

The customer-facing business name.



2062
2063
2064
# File 'lib/stripe/resources/v2/core/account.rb', line 2062

def doing_business_as
  @doing_business_as
end

#product_descriptionObject (readonly)

Internal-only description of the product sold or service provided by the business. It’s used by Stripe for risk and underwriting purposes.



2064
2065
2066
# File 'lib/stripe/resources/v2/core/account.rb', line 2064

def product_description
  @product_description
end

Class Method Details

.field_remappingsObject



2070
2071
2072
# File 'lib/stripe/resources/v2/core/account.rb', line 2070

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2066
2067
2068
# File 'lib/stripe/resources/v2/core/account.rb', line 2066

def self.inner_class_types
  @inner_class_types = {}
end