Class: Stripe::V2::Core::Account::Defaults::Responsibilities
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Defaults::Responsibilities
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#fees_collector ⇒ Object
readonly
A value indicating the responsible payer of a bundle of Stripe fees for pricing-control eligible products on this Account.
-
#losses_collector ⇒ Object
readonly
A value indicating who is responsible for losses when this Account can’t pay back negative balances from payments.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#fees_collector ⇒ Object (readonly)
A value indicating the responsible payer of a bundle of Stripe fees for pricing-control eligible products on this Account.
3148 3149 3150 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3148 def fees_collector @fees_collector end |
#losses_collector ⇒ Object (readonly)
A value indicating who is responsible for losses when this Account can’t pay back negative balances from payments.
3150 3151 3152 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3150 def losses_collector @losses_collector end |
Class Method Details
.field_remappings ⇒ Object
3156 3157 3158 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3156 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
3152 3153 3154 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3152 def self.inner_class_types @inner_class_types = {} end |