Class: Stripe::V2::Core::Account::FutureRequirements::Entry

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: Error, Impact, MinimumDeadline, Reference, RequestedReason

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#awaiting_action_fromObject (readonly)

Indicates whether the platform or Stripe is currently responsible for taking action on the requirement. Value can be user or stripe.



2243
2244
2245
# File 'lib/stripe/resources/v2/core/account.rb', line 2243

def awaiting_action_from
  @awaiting_action_from
end

#descriptionObject (readonly)

Machine-readable string describing the requirement.



2245
2246
2247
# File 'lib/stripe/resources/v2/core/account.rb', line 2245

def description
  @description
end

#errorsObject (readonly)

Descriptions of why the requirement must be collected, or why the collected information isn't satisfactory to Stripe.



2247
2248
2249
# File 'lib/stripe/resources/v2/core/account.rb', line 2247

def errors
  @errors
end

#impactObject (readonly)

A hash describing the impact of not collecting the requirement, or Stripe not being able to verify the collected information.



2249
2250
2251
# File 'lib/stripe/resources/v2/core/account.rb', line 2249

def impact
  @impact
end

#minimum_deadlineObject (readonly)

The soonest point when the account will be impacted by not providing the requirement.



2251
2252
2253
# File 'lib/stripe/resources/v2/core/account.rb', line 2251

def minimum_deadline
  @minimum_deadline
end

#referenceObject (readonly)

A reference to the location of the requirement.



2253
2254
2255
# File 'lib/stripe/resources/v2/core/account.rb', line 2253

def reference
  @reference
end

#requested_reasonsObject (readonly)

A list of reasons why Stripe is collecting the requirement.



2255
2256
2257
# File 'lib/stripe/resources/v2/core/account.rb', line 2255

def requested_reasons
  @requested_reasons
end

Class Method Details

.field_remappingsObject



2267
2268
2269
# File 'lib/stripe/resources/v2/core/account.rb', line 2267

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2257
2258
2259
2260
2261
2262
2263
2264
2265
# File 'lib/stripe/resources/v2/core/account.rb', line 2257

def self.inner_class_types
  @inner_class_types = {
    errors: Error,
    impact: Impact,
    minimum_deadline: MinimumDeadline,
    reference: Reference,
    requested_reasons: RequestedReason,
  }
end