Class: Stripe::V2::Core::Account::Identity
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Identity
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: Attestations, BusinessDetails, Individual
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#attestations ⇒ Object
readonly
Attestations from the identity’s key people, e.g.
-
#business_details ⇒ Object
readonly
Information about the company or business.
-
#country ⇒ Object
readonly
The country in which the account holder resides, or in which the business is legally established.
-
#entity_type ⇒ Object
readonly
The entity type.
-
#individual ⇒ Object
readonly
Information about the individual represented by the Account.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#attestations ⇒ Object (readonly)
Attestations from the identity’s key people, e.g. owners, executives, directors, representatives.
3335 3336 3337 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3335 def attestations @attestations end |
#business_details ⇒ Object (readonly)
Information about the company or business.
3337 3338 3339 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3337 def business_details @business_details end |
#country ⇒ Object (readonly)
The country in which the account holder resides, or in which the business is legally established. This should be an [ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2) country code.
3339 3340 3341 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3339 def country @country end |
#entity_type ⇒ Object (readonly)
The entity type.
3341 3342 3343 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3341 def entity_type @entity_type end |
#individual ⇒ Object (readonly)
Information about the individual represented by the Account. This property is null unless entity_type is set to individual.
3343 3344 3345 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3343 def individual @individual end |
Class Method Details
.field_remappings ⇒ Object
3353 3354 3355 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3353 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
3345 3346 3347 3348 3349 3350 3351 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3345 def self.inner_class_types @inner_class_types = { attestations: Attestations, business_details: BusinessDetails, individual: Individual, } end |