Class: Stripe::V2::Core::Account::Identity::Attestations

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: DirectorshipDeclaration, OwnershipDeclaration, PersonsProvided, RepresentativeDeclaration, TermsOfService

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#directorship_declarationObject (readonly)

This hash is used to attest that the directors information provided to Stripe is both current and correct.



4915
4916
4917
# File 'lib/stripe/resources/v2/core/account.rb', line 4915

def directorship_declaration
  @directorship_declaration
end

#ownership_declarationObject (readonly)

This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.



4917
4918
4919
# File 'lib/stripe/resources/v2/core/account.rb', line 4917

def ownership_declaration
  @ownership_declaration
end

#persons_providedObject (readonly)

Attestation that all Persons with a specific Relationship value have been provided.



4919
4920
4921
# File 'lib/stripe/resources/v2/core/account.rb', line 4919

def persons_provided
  @persons_provided
end

#representative_declarationObject (readonly)

This hash is used to attest that the representative is authorized to act as the representative of their legal entity.



4921
4922
4923
# File 'lib/stripe/resources/v2/core/account.rb', line 4921

def representative_declaration
  @representative_declaration
end

#terms_of_serviceObject (readonly)

Attestations of accepted terms of service agreements.



4923
4924
4925
# File 'lib/stripe/resources/v2/core/account.rb', line 4923

def terms_of_service
  @terms_of_service
end

Class Method Details

.field_remappingsObject



4935
4936
4937
# File 'lib/stripe/resources/v2/core/account.rb', line 4935

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



4925
4926
4927
4928
4929
4930
4931
4932
4933
# File 'lib/stripe/resources/v2/core/account.rb', line 4925

def self.inner_class_types
  @inner_class_types = {
    directorship_declaration: DirectorshipDeclaration,
    ownership_declaration: OwnershipDeclaration,
    persons_provided: PersonsProvided,
    representative_declaration: RepresentativeDeclaration,
    terms_of_service: TermsOfService,
  }
end