Class: Stripe::V2::Core::Account::Identity::Attestations::DirectorshipDeclaration

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#dateObject (readonly)

The time marking when the director attestation was made. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



2862
2863
2864
# File 'lib/stripe/resources/v2/core/account.rb', line 2862

def date
  @date
end

#ipObject (readonly)

The IP address from which the director attestation was made.



2864
2865
2866
# File 'lib/stripe/resources/v2/core/account.rb', line 2864

def ip
  @ip
end

#user_agentObject (readonly)

The user agent of the browser from which the director attestation was made.



2866
2867
2868
# File 'lib/stripe/resources/v2/core/account.rb', line 2866

def user_agent
  @user_agent
end

Class Method Details

.field_remappingsObject



2872
2873
2874
# File 'lib/stripe/resources/v2/core/account.rb', line 2872

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2868
2869
2870
# File 'lib/stripe/resources/v2/core/account.rb', line 2868

def self.inner_class_types
  @inner_class_types = {}
end