Class: Stripe::V2::Core::Account::Identity::Attestations::PersonsProvided

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#directorsObject (readonly)

Whether the company’s directors have been provided. Set this Boolean to true after creating all the company’s directors with the [Persons API](docs.stripe.com/api/v2/core/accounts/createperson).



3810
3811
3812
# File 'lib/stripe/resources/v2/core/account.rb', line 3810

def directors
  @directors
end

#executivesObject (readonly)

Whether the company’s executives have been provided. Set this Boolean to true after creating all the company’s executives with the [Persons API](docs.stripe.com/api/v2/core/accounts/createperson).



3812
3813
3814
# File 'lib/stripe/resources/v2/core/account.rb', line 3812

def executives
  @executives
end

#ownersObject (readonly)

Whether the company’s owners have been provided. Set this Boolean to true after creating all the company’s owners with the [Persons API](docs.stripe.com/api/v2/core/accounts/createperson).



3814
3815
3816
# File 'lib/stripe/resources/v2/core/account.rb', line 3814

def owners
  @owners
end

#ownership_exemption_reasonObject (readonly)

Reason for why the company is exempt from providing ownership information.



3816
3817
3818
# File 'lib/stripe/resources/v2/core/account.rb', line 3816

def ownership_exemption_reason
  @ownership_exemption_reason
end

Class Method Details

.field_remappingsObject



3822
3823
3824
# File 'lib/stripe/resources/v2/core/account.rb', line 3822

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



3818
3819
3820
# File 'lib/stripe/resources/v2/core/account.rb', line 3818

def self.inner_class_types
  @inner_class_types = {}
end