Class: Stripe::V2::Core::Account::Identity::Attestations::RepresentativeDeclaration

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#dateObject (readonly)

The time marking when the representative attestation was made. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



2915
2916
2917
# File 'lib/stripe/resources/v2/core/account.rb', line 2915

def date
  @date
end

#ipObject (readonly)

The IP address from which the representative attestation was made.



2917
2918
2919
# File 'lib/stripe/resources/v2/core/account.rb', line 2917

def ip
  @ip
end

#user_agentObject (readonly)

The user agent of the browser from which the representative attestation was made.



2919
2920
2921
# File 'lib/stripe/resources/v2/core/account.rb', line 2919

def user_agent
  @user_agent
end

Class Method Details

.field_remappingsObject



2925
2926
2927
# File 'lib/stripe/resources/v2/core/account.rb', line 2925

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2921
2922
2923
# File 'lib/stripe/resources/v2/core/account.rb', line 2921

def self.inner_class_types
  @inner_class_types = {}
end