Class: Stripe::V2::Core::Account::Identity::BusinessDetails

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: AdditionalAddress, Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, RegistrationDate, ScriptAddresses, ScriptNames

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#additional_addresses ⇒ Object (readonly)

Additional addresses associated with the business.



2986
2987
2988
# File 'lib/stripe/resources/v2/core/account.rb', line 2986

def additional_addresses
  @additional_addresses
end

#address ⇒ Object (readonly)

The company's primary address.



2988
2989
2990
# File 'lib/stripe/resources/v2/core/account.rb', line 2988

def address
  @address
end

#annual_revenue ⇒ Object (readonly)

The business gross annual revenue for its preceding fiscal year.



2990
2991
2992
# File 'lib/stripe/resources/v2/core/account.rb', line 2990

def annual_revenue
  @annual_revenue
end

#documents ⇒ Object (readonly)

Documents that may be submitted to satisfy various informational requests.



2992
2993
2994
# File 'lib/stripe/resources/v2/core/account.rb', line 2992

def documents
  @documents
end

#estimated_worker_count ⇒ Object (readonly)

Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).



2994
2995
2996
# File 'lib/stripe/resources/v2/core/account.rb', line 2994

def estimated_worker_count
  @estimated_worker_count
end

#id_numbers ⇒ Object (readonly)

The provided ID numbers of a business entity.



2996
2997
2998
# File 'lib/stripe/resources/v2/core/account.rb', line 2996

def id_numbers
  @id_numbers
end

#monthly_estimated_revenue ⇒ Object (readonly)

An estimate of the monthly revenue of the business. Only accepted for accounts in Brazil and India.



2998
2999
3000
# File 'lib/stripe/resources/v2/core/account.rb', line 2998

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#phone ⇒ Object (readonly)

The company's phone number (used for verification).



3000
3001
3002
# File 'lib/stripe/resources/v2/core/account.rb', line 3000

def phone
  @phone
end

#registered_name ⇒ Object (readonly)

The business legal name.



3002
3003
3004
# File 'lib/stripe/resources/v2/core/account.rb', line 3002

def registered_name
  @registered_name
end

#registration_date ⇒ Object (readonly)

When the business was incorporated or registered.



3004
3005
3006
# File 'lib/stripe/resources/v2/core/account.rb', line 3004

def registration_date
  @registration_date
end

#script_addresses ⇒ Object (readonly)

The business registration address of the business entity in non latin script.



3006
3007
3008
# File 'lib/stripe/resources/v2/core/account.rb', line 3006

def script_addresses
  @script_addresses
end

#script_names ⇒ Object (readonly)

The business legal name in non latin script.



3008
3009
3010
# File 'lib/stripe/resources/v2/core/account.rb', line 3008

def script_names
  @script_names
end

#structure ⇒ Object (readonly)

The category identifying the legal structure of the business.



3010
3011
3012
# File 'lib/stripe/resources/v2/core/account.rb', line 3010

def structure
  @structure
end

Class Method Details

.field_remappings ⇒ Object



3026
3027
3028
# File 'lib/stripe/resources/v2/core/account.rb', line 3026

def self.field_remappings
  @field_remappings = {}
end

.inner_class_types ⇒ Object



3012
3013
3014
3015
3016
3017
3018
3019
3020
3021
3022
3023
3024
# File 'lib/stripe/resources/v2/core/account.rb', line 3012

def self.inner_class_types
  @inner_class_types = {
    additional_addresses: AdditionalAddress,
    address: Address,
    annual_revenue: AnnualRevenue,
    documents: Documents,
    id_numbers: IdNumber,
    monthly_estimated_revenue: MonthlyEstimatedRevenue,
    registration_date: RegistrationDate,
    script_addresses: ScriptAddresses,
    script_names: ScriptNames,
  }
end