Class: Stripe::V2::Core::Account::Identity::BusinessDetails::AnnualRevenue

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

A non-negative integer representing the amount in the smallest currency unit.



2799
2800
2801
# File 'lib/stripe/resources/v2/core/account.rb', line 2799

def amount
  @amount
end

#fiscal_year_endObject (readonly)

The close-out date of the preceding fiscal year in ISO 8601 format. E.g. 2023-12-31 for the 31st of December, 2023.



2801
2802
2803
# File 'lib/stripe/resources/v2/core/account.rb', line 2801

def fiscal_year_end
  @fiscal_year_end
end

Class Method Details

.field_remappingsObject



2807
2808
2809
# File 'lib/stripe/resources/v2/core/account.rb', line 2807

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2803
2804
2805
# File 'lib/stripe/resources/v2/core/account.rb', line 2803

def self.inner_class_types
  @inner_class_types = {}
end