Class: Stripe::V2::Core::Account::Identity::BusinessDetails::Documents

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: BankAccountOwnershipVerification, CompanyLicense, CompanyMemorandumOfAssociation, CompanyMinisterialDecree, CompanyRegistrationVerification, CompanyTaxIdVerification, PrimaryVerification, ProofOfAddress, ProofOfRegistration, ProofOfUltimateBeneficialOwnership

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_account_ownership_verification ⇒ Object (readonly)

One or more documents that support the Bank account ownership verification requirement. Must be a document associated with the account's primary active bank account that displays the last 4 digits of the account number, either a statement or a check.



2797
2798
2799
# File 'lib/stripe/resources/v2/core/account.rb', line 2797

def 
  
end

#company_license ⇒ Object (readonly)

One or more documents that demonstrate proof of a company's license to operate.



2799
2800
2801
# File 'lib/stripe/resources/v2/core/account.rb', line 2799

def company_license
  @company_license
end

#company_memorandum_of_association ⇒ Object (readonly)

One or more documents showing the company's Memorandum of Association.



2801
2802
2803
# File 'lib/stripe/resources/v2/core/account.rb', line 2801

def company_memorandum_of_association
  @company_memorandum_of_association
end

#company_ministerial_decree ⇒ Object (readonly)

Certain countries only: One or more documents showing the ministerial decree legalizing the company's establishment.



2803
2804
2805
# File 'lib/stripe/resources/v2/core/account.rb', line 2803

def company_ministerial_decree
  @company_ministerial_decree
end

#company_registration_verification ⇒ Object (readonly)

One or more documents that demonstrate proof of a company's registration with the appropriate local authorities.



2805
2806
2807
# File 'lib/stripe/resources/v2/core/account.rb', line 2805

def company_registration_verification
  @company_registration_verification
end

#company_tax_id_verification ⇒ Object (readonly)

One or more documents that demonstrate proof of a company's tax ID.



2807
2808
2809
# File 'lib/stripe/resources/v2/core/account.rb', line 2807

def company_tax_id_verification
  @company_tax_id_verification
end

#primary_verification ⇒ Object (readonly)

A document verifying the business.



2809
2810
2811
# File 'lib/stripe/resources/v2/core/account.rb', line 2809

def primary_verification
  @primary_verification
end

#proof_of_address ⇒ Object (readonly)

One or more documents that demonstrate proof of address.



2811
2812
2813
# File 'lib/stripe/resources/v2/core/account.rb', line 2811

def proof_of_address
  @proof_of_address
end

#proof_of_registration ⇒ Object (readonly)

One or more documents showing the company's proof of registration with the national business registry.



2813
2814
2815
# File 'lib/stripe/resources/v2/core/account.rb', line 2813

def proof_of_registration
  @proof_of_registration
end

#proof_of_ultimate_beneficial_ownership ⇒ Object (readonly)

One or more documents that demonstrate proof of ultimate beneficial ownership.



2815
2816
2817
# File 'lib/stripe/resources/v2/core/account.rb', line 2815

def proof_of_ultimate_beneficial_ownership
  @proof_of_ultimate_beneficial_ownership
end

Class Method Details

.field_remappings ⇒ Object



2832
2833
2834
# File 'lib/stripe/resources/v2/core/account.rb', line 2832

def self.field_remappings
  @field_remappings = {}
end

.inner_class_types ⇒ Object



2817
2818
2819
2820
2821
2822
2823
2824
2825
2826
2827
2828
2829
2830
# File 'lib/stripe/resources/v2/core/account.rb', line 2817

def self.inner_class_types
  @inner_class_types = {
    bank_account_ownership_verification: BankAccountOwnershipVerification,
    company_license: CompanyLicense,
    company_memorandum_of_association: CompanyMemorandumOfAssociation,
    company_ministerial_decree: CompanyMinisterialDecree,
    company_registration_verification: CompanyRegistrationVerification,
    company_tax_id_verification: CompanyTaxIdVerification,
    primary_verification: PrimaryVerification,
    proof_of_address: ProofOfAddress,
    proof_of_registration: ProofOfRegistration,
    proof_of_ultimate_beneficial_ownership: ProofOfUltimateBeneficialOwnership,
  }
end