Class: Stripe::V2::Core::Account::Identity::BusinessDetails::Documents::PrimaryVerification::FrontBack
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Identity::BusinessDetails::Documents::PrimaryVerification::FrontBack
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#back ⇒ Object
readonly
A file upload token representing the back of the verification document.
-
#front ⇒ Object
readonly
A file upload token representing the front of the verification document.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#back ⇒ Object (readonly)
A file upload token representing the back of the verification document. The purpose of the uploaded file should be 'identity_document'. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.
2602 2603 2604 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2602 def back @back end |
#front ⇒ Object (readonly)
A file upload token representing the front of the verification document. The purpose of the uploaded file should be 'identity_document'. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.
2604 2605 2606 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2604 def front @front end |
Class Method Details
.field_remappings ⇒ Object
2610 2611 2612 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2610 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2606 2607 2608 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2606 def self.inner_class_types @inner_class_types = {} end |