Class: Stripe::V2::Core::Account::Identity::BusinessDetails::MonthlyEstimatedRevenue
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Identity::BusinessDetails::MonthlyEstimatedRevenue
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
Estimated monthly revenue amount in minor currency units (for example, ‘123’ for 1.23 USD).
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
Estimated monthly revenue amount in minor currency units (for example, ‘123’ for 1.23 USD).
3266 3267 3268 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3266 def amount @amount end |
Class Method Details
.field_remappings ⇒ Object
3272 3273 3274 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3272 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
3268 3269 3270 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3268 def self.inner_class_types @inner_class_types = {} end |