Class: Stripe::V2::Core::Account::Identity::Individual::Documents
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Identity::Individual::Documents
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: CompanyAuthorization, Passport, PrimaryVerification, SecondaryVerification, Visa
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#company_authorization ⇒ Object
readonly
One or more documents that demonstrate proof that this person is authorized to represent the company.
-
#passport ⇒ Object
readonly
One or more documents showing the person's passport page with photo and personal data.
-
#primary_verification ⇒ Object
readonly
An identifying document showing the person's name, either a passport or local ID card.
-
#secondary_verification ⇒ Object
readonly
A document showing address, either a passport, local ID card, or utility bill from a well-known utility company.
-
#visa ⇒ Object
readonly
One or more documents showing the person's visa required for living in the country where they are residing.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#company_authorization ⇒ Object (readonly)
One or more documents that demonstrate proof that this person is authorized to represent the company.
3253 3254 3255 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3253 def @company_authorization end |
#passport ⇒ Object (readonly)
One or more documents showing the person's passport page with photo and personal data.
3255 3256 3257 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3255 def passport @passport end |
#primary_verification ⇒ Object (readonly)
An identifying document showing the person's name, either a passport or local ID card.
3257 3258 3259 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3257 def primary_verification @primary_verification end |
#secondary_verification ⇒ Object (readonly)
A document showing address, either a passport, local ID card, or utility bill from a well-known utility company.
3259 3260 3261 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3259 def secondary_verification @secondary_verification end |
#visa ⇒ Object (readonly)
One or more documents showing the person's visa required for living in the country where they are residing.
3261 3262 3263 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3261 def visa @visa end |
Class Method Details
.field_remappings ⇒ Object
3273 3274 3275 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3273 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
3263 3264 3265 3266 3267 3268 3269 3270 3271 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3263 def self.inner_class_types @inner_class_types = { company_authorization: CompanyAuthorization, passport: Passport, primary_verification: PrimaryVerification, secondary_verification: SecondaryVerification, visa: Visa, } end |