Class: Stripe::V2::Core::Account::Requirements
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Requirements
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#collector ⇒ Object
readonly
A value indicating responsibility for collecting requirements on this account.
-
#entries ⇒ Object
readonly
A list of requirements for the Account.
-
#summary ⇒ Object
readonly
An object containing an overview of requirements for the Account.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#collector ⇒ Object (readonly)
A value indicating responsibility for collecting requirements on this account.
1903 1904 1905 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1903 def collector @collector end |
#entries ⇒ Object (readonly)
A list of requirements for the Account.
1905 1906 1907 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1905 def entries @entries end |
#summary ⇒ Object (readonly)
An object containing an overview of requirements for the Account.
1907 1908 1909 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1907 def summary @summary end |