Class: Stripe::V2::Core::Account::Requirements::Entry::Impact
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Requirements::Entry::Impact
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: RestrictsCapability
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#restricts_capabilities ⇒ Object
readonly
The Capabilities that will be restricted if the requirement is not collected and satisfactory to Stripe.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#restricts_capabilities ⇒ Object (readonly)
The Capabilities that will be restricted if the requirement is not collected and satisfactory to Stripe.
3992 3993 3994 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3992 def restricts_capabilities @restricts_capabilities end |
Class Method Details
.field_remappings ⇒ Object
3998 3999 4000 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3998 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
3994 3995 3996 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3994 def self.inner_class_types @inner_class_types = { restricts_capabilities: RestrictsCapability } end |