Class: Stripe::V2::Core::Account::Requirements::Entry::Impact::RestrictsCapability

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: Deadline

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#capability ⇒ Object (readonly)

The name of the Capability which will be restricted.



3568
3569
3570
# File 'lib/stripe/resources/v2/core/account.rb', line 3568

def capability
  @capability
end

#configuration ⇒ Object (readonly)

The configuration which specifies the Capability which will be restricted.



3570
3571
3572
# File 'lib/stripe/resources/v2/core/account.rb', line 3570

def configuration
  @configuration
end

#deadline ⇒ Object (readonly)

Details about when in the account lifecycle the requirement must be collected by the avoid the Capability restriction.



3572
3573
3574
# File 'lib/stripe/resources/v2/core/account.rb', line 3572

def deadline
  @deadline
end

Class Method Details

.field_remappings ⇒ Object



3578
3579
3580
# File 'lib/stripe/resources/v2/core/account.rb', line 3578

def self.field_remappings
  @field_remappings = {}
end

.inner_class_types ⇒ Object



3574
3575
3576
# File 'lib/stripe/resources/v2/core/account.rb', line 3574

def self.inner_class_types
  @inner_class_types = { deadline: Deadline }
end