Class: Stripe::V2::Core::Account::Requirements::Entry::Impact::RestrictsPayouts
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Requirements::Entry::Impact::RestrictsPayouts
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: Deadline
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#deadline ⇒ Object
readonly
Details about when in the Account’s lifecycle the requirement must be collected by the avoid the earliest specified impact.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#deadline ⇒ Object (readonly)
Details about when in the Account’s lifecycle the requirement must be collected by the avoid the earliest specified impact.
1629 1630 1631 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1629 def deadline @deadline end |