Class: Stripe::V2::Core::AccountCreateParams::Configuration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: CardCreator, Customer, Merchant, MoneyManager, Recipient

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(card_creator: nil, customer: nil, merchant: nil, money_manager: nil, recipient: nil) ⇒ Configuration

Returns a new instance of Configuration.



4061
4062
4063
4064
4065
4066
4067
4068
4069
4070
4071
4072
4073
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 4061

def initialize(
  card_creator: nil,
  customer: nil,
  merchant: nil,
  money_manager: nil,
  recipient: nil
)
  @card_creator = card_creator
  @customer = customer
  @merchant = merchant
  @money_manager = money_manager
  @recipient = recipient
end

Instance Attribute Details

#card_creatorObject

The CardCreator Configuration allows the Account to create and issue cards to users.



4051
4052
4053
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 4051

def card_creator
  @card_creator
end

#customerObject

The Customer Configuration allows the Account to be used in inbound payment flows (i.e. customer-facing payment and billing flows).



4053
4054
4055
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 4053

def customer
  @customer
end

#merchantObject

Enables the Account to act as a connected account and collect payments facilitated by a Connect platform. You must onboard your platform to Connect before you can add this configuration to your connected accounts. Utilize this configuration when the Account will be the Merchant of Record, like with Direct charges or Destination Charges with on_behalf_of set.



4055
4056
4057
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 4055

def merchant
  @merchant
end

#money_managerObject

The Money Manager Configuration allows the Account to store and move funds using FinancialAccounts.



4057
4058
4059
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 4057

def money_manager
  @money_manager
end

#recipientObject

The Recipient Configuration allows the Account to receive funds. Utilize this configuration if the Account will not be the Merchant of Record, like with Separate Charges & Transfers, or Destination Charges without on_behalf_of set.



4059
4060
4061
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 4059

def recipient
  @recipient
end