Class: Stripe::V2::Core::AccountCreateParams::Configuration::Customer::Billing::Invoice
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Configuration::Customer::Billing::Invoice
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: CustomField, Rendering
Instance Attribute Summary collapse
-
#custom_fields ⇒ Object
The list of up to 4 default custom fields to be displayed on invoices for this customer.
-
#footer ⇒ Object
Default invoice footer.
-
#next_sequence ⇒ Object
Sequence number to use on the customer account's next invoice.
-
#prefix ⇒ Object
Prefix used to generate unique invoice numbers.
-
#rendering ⇒ Object
Default invoice PDF rendering options.
Instance Method Summary collapse
-
#initialize(custom_fields: nil, footer: nil, next_sequence: nil, prefix: nil, rendering: nil) ⇒ Invoice
constructor
A new instance of Invoice.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(custom_fields: nil, footer: nil, next_sequence: nil, prefix: nil, rendering: nil) ⇒ Invoice
Returns a new instance of Invoice.
594 595 596 597 598 599 600 601 602 603 604 605 606 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 594 def initialize( custom_fields: nil, footer: nil, next_sequence: nil, prefix: nil, rendering: nil ) @custom_fields = custom_fields @footer = @next_sequence = next_sequence @prefix = prefix @rendering = rendering end |
Instance Attribute Details
#custom_fields ⇒ Object
The list of up to 4 default custom fields to be displayed on invoices for this customer.
584 585 586 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 584 def custom_fields @custom_fields end |
#footer ⇒ Object
Default invoice footer.
586 587 588 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 586 def @footer end |
#next_sequence ⇒ Object
Sequence number to use on the customer account's next invoice. Defaults to 1.
588 589 590 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 588 def next_sequence @next_sequence end |
#prefix ⇒ Object
Prefix used to generate unique invoice numbers. Must be 3-12 uppercase letters or numbers.
590 591 592 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 590 def prefix @prefix end |
#rendering ⇒ Object
Default invoice PDF rendering options.
592 593 594 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 592 def rendering @rendering end |