Class: Stripe::V2::Core::AccountCreateParams::Configuration::Merchant

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: BacsDebitPayments, Branding, Capabilities, CardPayments, KonbiniPayments, ScriptStatementDescriptor, SepaDebitPayments, StatementDescriptor, Support

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h

Constructor Details

#initialize(bacs_debit_payments: nil, branding: nil, capabilities: nil, card_payments: nil, konbini_payments: nil, mcc: nil, script_statement_descriptor: nil, sepa_debit_payments: nil, statement_descriptor: nil, support: nil) ⇒ Merchant

Returns a new instance of Merchant.



1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
1026
1027
1028
1029
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1007

def initialize(
  bacs_debit_payments: nil,
  branding: nil,
  capabilities: nil,
  card_payments: nil,
  konbini_payments: nil,
  mcc: nil,
  script_statement_descriptor: nil,
  sepa_debit_payments: nil,
  statement_descriptor: nil,
  support: nil
)
  @bacs_debit_payments = bacs_debit_payments
  @branding = branding
  @capabilities = capabilities
  @card_payments = card_payments
  @konbini_payments = konbini_payments
  @mcc = mcc
  @script_statement_descriptor = script_statement_descriptor
  @sepa_debit_payments = sepa_debit_payments
  @statement_descriptor = statement_descriptor
  @support = support
end

Instance Attribute Details

#bacs_debit_payments ⇒ Object

Settings used for Bacs debit payments.



987
988
989
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 987

def bacs_debit_payments
  @bacs_debit_payments
end

#branding ⇒ Object

Settings used to apply the merchant's branding to email receipts, invoices, Checkout, and other products.



989
990
991
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 989

def branding
  @branding
end

#capabilities ⇒ Object

Capabilities to request on the Merchant Configuration.



991
992
993
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 991

def capabilities
  @capabilities
end

#card_payments ⇒ Object

Card payments settings.



993
994
995
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 993

def card_payments
  @card_payments
end

#konbini_payments ⇒ Object

Settings specific to Konbini payments on the account.



995
996
997
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 995

def konbini_payments
  @konbini_payments
end

#mcc ⇒ Object

The Merchant Category Code (MCC) for the Merchant Configuration. MCCs classify businesses based on the goods or services they provide.



997
998
999
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 997

def mcc
  @mcc
end

#script_statement_descriptor ⇒ Object

Settings for the default text that appears on statements for language variations.



999
1000
1001
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 999

def script_statement_descriptor
  @script_statement_descriptor
end

#sepa_debit_payments ⇒ Object

Settings used for SEPA Direct Debit payments.



1001
1002
1003
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1001

def sepa_debit_payments
  @sepa_debit_payments
end

#statement_descriptor ⇒ Object

Statement descriptor.



1003
1004
1005
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1003

def statement_descriptor
  @statement_descriptor
end

#support ⇒ Object

Publicly available contact information for sending support issues to.



1005
1006
1007
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1005

def support
  @support
end