Class: Stripe::V2::Core::AccountCreateParams::Configuration::Merchant::Capabilities

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: AchDebitPayments, AcssDebitPayments, AffirmPayments, AfterpayClearpayPayments, AlmaPayments, AmazonPayPayments, AuBecsDebitPayments, BacsDebitPayments, BancontactPayments, BlikPayments, BoletoPayments, CardPayments, CartesBancairesPayments, CashappPayments, EpsPayments, FpxPayments, GbBankTransferPayments, GrabpayPayments, IdealPayments, JcbPayments, JpBankTransferPayments, KakaoPayPayments, KlarnaPayments, KonbiniPayments, KrCardPayments, LinkPayments, MobilepayPayments, MultibancoPayments, MxBankTransferPayments, NaverPayPayments, OxxoPayments, P24Payments, PayByBankPayments, PaycoPayments, PaynowPayments, PromptpayPayments, RevolutPayPayments, SamsungPayPayments, SepaBankTransferPayments, SepaDebitPayments, SunbitPayments, SwishPayments, TwintPayments, UsBankTransferPayments, ZipPayments

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(ach_debit_payments: nil, acss_debit_payments: nil, affirm_payments: nil, afterpay_clearpay_payments: nil, alma_payments: nil, amazon_pay_payments: nil, au_becs_debit_payments: nil, bacs_debit_payments: nil, bancontact_payments: nil, blik_payments: nil, boleto_payments: nil, card_payments: nil, cartes_bancaires_payments: nil, cashapp_payments: nil, eps_payments: nil, fpx_payments: nil, gb_bank_transfer_payments: nil, grabpay_payments: nil, ideal_payments: nil, jcb_payments: nil, jp_bank_transfer_payments: nil, kakao_pay_payments: nil, klarna_payments: nil, konbini_payments: nil, kr_card_payments: nil, link_payments: nil, mobilepay_payments: nil, multibanco_payments: nil, mx_bank_transfer_payments: nil, naver_pay_payments: nil, oxxo_payments: nil, p24_payments: nil, pay_by_bank_payments: nil, payco_payments: nil, paynow_payments: nil, promptpay_payments: nil, revolut_pay_payments: nil, samsung_pay_payments: nil, sepa_bank_transfer_payments: nil, sepa_debit_payments: nil, sunbit_payments: nil, swish_payments: nil, twint_payments: nil, us_bank_transfer_payments: nil, zip_payments: nil) ⇒ Capabilities

Returns a new instance of Capabilities.



2101
2102
2103
2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
2124
2125
2126
2127
2128
2129
2130
2131
2132
2133
2134
2135
2136
2137
2138
2139
2140
2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
2154
2155
2156
2157
2158
2159
2160
2161
2162
2163
2164
2165
2166
2167
2168
2169
2170
2171
2172
2173
2174
2175
2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
2188
2189
2190
2191
2192
2193
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2101

def initialize(
  ach_debit_payments: nil,
  acss_debit_payments: nil,
  affirm_payments: nil,
  afterpay_clearpay_payments: nil,
  alma_payments: nil,
  amazon_pay_payments: nil,
  au_becs_debit_payments: nil,
  bacs_debit_payments: nil,
  bancontact_payments: nil,
  blik_payments: nil,
  boleto_payments: nil,
  card_payments: nil,
  cartes_bancaires_payments: nil,
  cashapp_payments: nil,
  eps_payments: nil,
  fpx_payments: nil,
  gb_bank_transfer_payments: nil,
  grabpay_payments: nil,
  ideal_payments: nil,
  jcb_payments: nil,
  jp_bank_transfer_payments: nil,
  kakao_pay_payments: nil,
  klarna_payments: nil,
  konbini_payments: nil,
  kr_card_payments: nil,
  link_payments: nil,
  mobilepay_payments: nil,
  multibanco_payments: nil,
  mx_bank_transfer_payments: nil,
  naver_pay_payments: nil,
  oxxo_payments: nil,
  p24_payments: nil,
  pay_by_bank_payments: nil,
  payco_payments: nil,
  paynow_payments: nil,
  promptpay_payments: nil,
  revolut_pay_payments: nil,
  samsung_pay_payments: nil,
  sepa_bank_transfer_payments: nil,
  sepa_debit_payments: nil,
  sunbit_payments: nil,
  swish_payments: nil,
  twint_payments: nil,
  us_bank_transfer_payments: nil,
  zip_payments: nil
)
  @ach_debit_payments = ach_debit_payments
  @acss_debit_payments = acss_debit_payments
  @affirm_payments = affirm_payments
  @afterpay_clearpay_payments = afterpay_clearpay_payments
  @alma_payments = alma_payments
  @amazon_pay_payments = amazon_pay_payments
  @au_becs_debit_payments = au_becs_debit_payments
  @bacs_debit_payments = bacs_debit_payments
  @bancontact_payments = bancontact_payments
  @blik_payments = blik_payments
  @boleto_payments = boleto_payments
  @card_payments = card_payments
  @cartes_bancaires_payments = cartes_bancaires_payments
  @cashapp_payments = cashapp_payments
  @eps_payments = eps_payments
  @fpx_payments = fpx_payments
  @gb_bank_transfer_payments = gb_bank_transfer_payments
  @grabpay_payments = grabpay_payments
  @ideal_payments = ideal_payments
  @jcb_payments = jcb_payments
  @jp_bank_transfer_payments = jp_bank_transfer_payments
  @kakao_pay_payments = kakao_pay_payments
  @klarna_payments = klarna_payments
  @konbini_payments = konbini_payments
  @kr_card_payments = kr_card_payments
  @link_payments = link_payments
  @mobilepay_payments = mobilepay_payments
  @multibanco_payments = multibanco_payments
  @mx_bank_transfer_payments = mx_bank_transfer_payments
  @naver_pay_payments = naver_pay_payments
  @oxxo_payments = oxxo_payments
  @p24_payments = p24_payments
  @pay_by_bank_payments = pay_by_bank_payments
  @payco_payments = payco_payments
  @paynow_payments = paynow_payments
  @promptpay_payments = promptpay_payments
  @revolut_pay_payments = revolut_pay_payments
  @samsung_pay_payments = samsung_pay_payments
  @sepa_bank_transfer_payments = sepa_bank_transfer_payments
  @sepa_debit_payments = sepa_debit_payments
  @sunbit_payments = sunbit_payments
  @swish_payments = swish_payments
  @twint_payments = twint_payments
  @us_bank_transfer_payments = us_bank_transfer_payments
  @zip_payments = zip_payments
end

Instance Attribute Details

#ach_debit_paymentsObject

Allow the merchant to process ACH debit payments.



2011
2012
2013
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2011

def ach_debit_payments
  @ach_debit_payments
end

#acss_debit_paymentsObject

Allow the merchant to process ACSS debit payments.



2013
2014
2015
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2013

def acss_debit_payments
  @acss_debit_payments
end

#affirm_paymentsObject

Allow the merchant to process Affirm payments.



2015
2016
2017
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2015

def affirm_payments
  @affirm_payments
end

#afterpay_clearpay_paymentsObject

Allow the merchant to process Afterpay/Clearpay payments.



2017
2018
2019
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2017

def afterpay_clearpay_payments
  @afterpay_clearpay_payments
end

#alma_paymentsObject

Allow the merchant to process Alma payments.



2019
2020
2021
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2019

def alma_payments
  @alma_payments
end

#amazon_pay_paymentsObject

Allow the merchant to process Amazon Pay payments.



2021
2022
2023
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2021

def amazon_pay_payments
  @amazon_pay_payments
end

#au_becs_debit_paymentsObject

Allow the merchant to process Australian BECS Direct Debit payments.



2023
2024
2025
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2023

def au_becs_debit_payments
  @au_becs_debit_payments
end

#bacs_debit_paymentsObject

Allow the merchant to process BACS Direct Debit payments.



2025
2026
2027
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2025

def bacs_debit_payments
  @bacs_debit_payments
end

#bancontact_paymentsObject

Allow the merchant to process Bancontact payments.



2027
2028
2029
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2027

def bancontact_payments
  @bancontact_payments
end

#blik_paymentsObject

Allow the merchant to process BLIK payments.



2029
2030
2031
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2029

def blik_payments
  @blik_payments
end

#boleto_paymentsObject

Allow the merchant to process Boleto payments.



2031
2032
2033
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2031

def boleto_payments
  @boleto_payments
end

#card_paymentsObject

Allow the merchant to collect card payments.



2033
2034
2035
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2033

def card_payments
  @card_payments
end

#cartes_bancaires_paymentsObject

Allow the merchant to process Cartes Bancaires payments.



2035
2036
2037
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2035

def cartes_bancaires_payments
  @cartes_bancaires_payments
end

#cashapp_paymentsObject

Allow the merchant to process Cash App payments.



2037
2038
2039
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2037

def cashapp_payments
  @cashapp_payments
end

#eps_paymentsObject

Allow the merchant to process EPS payments.



2039
2040
2041
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2039

def eps_payments
  @eps_payments
end

#fpx_paymentsObject

Allow the merchant to process FPX payments.



2041
2042
2043
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2041

def fpx_payments
  @fpx_payments
end

#gb_bank_transfer_paymentsObject

Allow the merchant to process UK bank transfer payments.



2043
2044
2045
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2043

def gb_bank_transfer_payments
  @gb_bank_transfer_payments
end

#grabpay_paymentsObject

Allow the merchant to process GrabPay payments.



2045
2046
2047
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2045

def grabpay_payments
  @grabpay_payments
end

#ideal_paymentsObject

Allow the merchant to process iDEAL payments.



2047
2048
2049
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2047

def ideal_payments
  @ideal_payments
end

#jcb_paymentsObject

Allow the merchant to process JCB card payments.



2049
2050
2051
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2049

def jcb_payments
  @jcb_payments
end

#jp_bank_transfer_paymentsObject

Allow the merchant to process Japanese bank transfer payments.



2051
2052
2053
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2051

def jp_bank_transfer_payments
  @jp_bank_transfer_payments
end

#kakao_pay_paymentsObject

Allow the merchant to process Kakao Pay payments.



2053
2054
2055
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2053

def kakao_pay_payments
  @kakao_pay_payments
end

#klarna_paymentsObject

Allow the merchant to process Klarna payments.



2055
2056
2057
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2055

def klarna_payments
  @klarna_payments
end

#konbini_paymentsObject

Allow the merchant to process Konbini convenience store payments.



2057
2058
2059
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2057

def konbini_payments
  @konbini_payments
end

#kr_card_paymentsObject

Allow the merchant to process Korean card payments.



2059
2060
2061
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2059

def kr_card_payments
  @kr_card_payments
end

Allow the merchant to process Link payments.



2061
2062
2063
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2061

def link_payments
  @link_payments
end

#mobilepay_paymentsObject

Allow the merchant to process MobilePay payments.



2063
2064
2065
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2063

def mobilepay_payments
  @mobilepay_payments
end

#multibanco_paymentsObject

Allow the merchant to process Multibanco payments.



2065
2066
2067
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2065

def multibanco_payments
  @multibanco_payments
end

#mx_bank_transfer_paymentsObject

Allow the merchant to process Mexican bank transfer payments.



2067
2068
2069
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2067

def mx_bank_transfer_payments
  @mx_bank_transfer_payments
end

Allow the merchant to process Naver Pay payments.



2069
2070
2071
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2069

def naver_pay_payments
  @naver_pay_payments
end

#oxxo_paymentsObject

Allow the merchant to process OXXO payments.



2071
2072
2073
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2071

def oxxo_payments
  @oxxo_payments
end

#p24_paymentsObject

Allow the merchant to process Przelewy24 (P24) payments.



2073
2074
2075
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2073

def p24_payments
  @p24_payments
end

#pay_by_bank_paymentsObject

Allow the merchant to process Pay by Bank payments.



2075
2076
2077
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2075

def pay_by_bank_payments
  @pay_by_bank_payments
end

#payco_paymentsObject

Allow the merchant to process PAYCO payments.



2077
2078
2079
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2077

def payco_payments
  @payco_payments
end

#paynow_paymentsObject

Allow the merchant to process PayNow payments.



2079
2080
2081
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2079

def paynow_payments
  @paynow_payments
end

#promptpay_paymentsObject

Allow the merchant to process PromptPay payments.



2081
2082
2083
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2081

def promptpay_payments
  @promptpay_payments
end

#revolut_pay_paymentsObject

Allow the merchant to process Revolut Pay payments.



2083
2084
2085
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2083

def revolut_pay_payments
  @revolut_pay_payments
end

#samsung_pay_paymentsObject

Allow the merchant to process Samsung Pay payments.



2085
2086
2087
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2085

def samsung_pay_payments
  @samsung_pay_payments
end

#sepa_bank_transfer_paymentsObject

Allow the merchant to process SEPA bank transfer payments.



2087
2088
2089
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2087

def sepa_bank_transfer_payments
  @sepa_bank_transfer_payments
end

#sepa_debit_paymentsObject

Allow the merchant to process SEPA Direct Debit payments.



2089
2090
2091
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2089

def sepa_debit_payments
  @sepa_debit_payments
end

#sunbit_paymentsObject

Allow the merchant to process Sunbit payments.



2091
2092
2093
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2091

def sunbit_payments
  @sunbit_payments
end

#swish_paymentsObject

Allow the merchant to process Swish payments.



2093
2094
2095
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2093

def swish_payments
  @swish_payments
end

#twint_paymentsObject

Allow the merchant to process TWINT payments.



2095
2096
2097
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2095

def twint_payments
  @twint_payments
end

#us_bank_transfer_paymentsObject

Allow the merchant to process US bank transfer payments.



2097
2098
2099
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2097

def us_bank_transfer_payments
  @us_bank_transfer_payments
end

#zip_paymentsObject

Allow the merchant to process Zip payments.



2099
2100
2101
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2099

def zip_payments
  @zip_payments
end