Class: Stripe::V2::Core::AccountCreateParams::Configuration::Merchant::Capabilities::AchDebitPayments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Configuration::Merchant::Capabilities::AchDebitPayments
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: Protections
Instance Attribute Summary collapse
-
#protections ⇒ Object
Protection types to request for this capability (e.g. "psp_migration").
-
#requested ⇒ Object
To request a new Capability for an account, pass true.
Instance Method Summary collapse
-
#initialize(protections: nil, requested: nil) ⇒ AchDebitPayments
constructor
A new instance of AchDebitPayments.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(protections: nil, requested: nil) ⇒ AchDebitPayments
Returns a new instance of AchDebitPayments.
773 774 775 776 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 773 def initialize(protections: nil, requested: nil) @protections = protections @requested = requested end |
Instance Attribute Details
#protections ⇒ Object
Protection types to request for this capability (e.g. "psp_migration").
769 770 771 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 769 def protections @protections end |
#requested ⇒ Object
To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
771 772 773 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 771 def requested @requested end |