Class: Stripe::V2::Core::AccountCreateParams::Configuration::Merchant::Capabilities::BancontactPayments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(requested: nil) ⇒ BancontactPayments

Returns a new instance of BancontactPayments.



275
276
277
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 275

def initialize(requested: nil)
  @requested = requested
end

Instance Attribute Details

#requestedObject

To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.



273
274
275
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 273

def requested
  @requested
end