Class: Stripe::V2::Core::AccountCreateParams::Configuration::Merchant::Capabilities::CartesBancairesPayments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: Protections

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(protections: nil, requested: nil) ⇒ CartesBancairesPayments

Returns a new instance of CartesBancairesPayments.



1109
1110
1111
1112
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1109

def initialize(protections: nil, requested: nil)
  @protections = protections
  @requested = requested
end

Instance Attribute Details

#protectionsObject

Protection types to request for this capability (e.g. "psp_migration").



1105
1106
1107
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1105

def protections
  @protections
end

#requestedObject

To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.



1107
1108
1109
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1107

def requested
  @requested
end