Class: Stripe::V2::Core::AccountCreateParams::Configuration::Merchant::Capabilities::GbBankTransferPayments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(requested: nil) ⇒ GbBankTransferPayments

Returns a new instance of GbBankTransferPayments.



484
485
486
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 484

def initialize(requested: nil)
  @requested = requested
end

Instance Attribute Details

#requestedObject

To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.



482
483
484
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 482

def requested
  @requested
end