Class: Stripe::V2::Core::AccountCreateParams::Configuration::Merchant::Capabilities::IdealPayments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Configuration::Merchant::Capabilities::IdealPayments
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: Protections
Instance Attribute Summary collapse
-
#protections ⇒ Object
Protection types to request for this capability (e.g. "psp_migration").
-
#requested ⇒ Object
To request a new Capability for an account, pass true.
Instance Method Summary collapse
-
#initialize(protections: nil, requested: nil) ⇒ IdealPayments
constructor
A new instance of IdealPayments.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(protections: nil, requested: nil) ⇒ IdealPayments
Returns a new instance of IdealPayments.
1277 1278 1279 1280 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1277 def initialize(protections: nil, requested: nil) @protections = protections @requested = requested end |
Instance Attribute Details
#protections ⇒ Object
Protection types to request for this capability (e.g. "psp_migration").
1273 1274 1275 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1273 def protections @protections end |
#requested ⇒ Object
To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
1275 1276 1277 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1275 def requested @requested end |