Class: Stripe::V2::Core::AccountCreateParams::Configuration::Merchant::Capabilities::MobilepayPayments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: Protections

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(protections: nil, requested: nil) ⇒ MobilepayPayments

Returns a new instance of MobilepayPayments.



1501
1502
1503
1504
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1501

def initialize(protections: nil, requested: nil)
  @protections = protections
  @requested = requested
end

Instance Attribute Details

#protectionsObject

Protection types to request for this capability (e.g. "psp_migration").



1497
1498
1499
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1497

def protections
  @protections
end

#requestedObject

To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.



1499
1500
1501
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1499

def requested
  @requested
end