Class: Stripe::V2::Core::AccountCreateParams::Configuration::Merchant::Capabilities::P24Payments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Configuration::Merchant::Capabilities::P24Payments
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: Protections
Instance Attribute Summary collapse
-
#protections ⇒ Object
Protection types to request for this capability (e.g. "psp_migration").
-
#requested ⇒ Object
To request a new Capability for an account, pass true.
Instance Method Summary collapse
-
#initialize(protections: nil, requested: nil) ⇒ P24Payments
constructor
A new instance of P24Payments.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(protections: nil, requested: nil) ⇒ P24Payments
Returns a new instance of P24Payments.
1641 1642 1643 1644 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1641 def initialize(protections: nil, requested: nil) @protections = protections @requested = requested end |
Instance Attribute Details
#protections ⇒ Object
Protection types to request for this capability (e.g. "psp_migration").
1637 1638 1639 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1637 def protections @protections end |
#requested ⇒ Object
To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
1639 1640 1641 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1639 def requested @requested end |