Class: Stripe::V2::Core::AccountCreateParams::Configuration::Merchant::Capabilities::PaycoPayments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(requested: nil) ⇒ PaycoPayments

Returns a new instance of PaycoPayments.



755
756
757
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 755

def initialize(requested: nil)
  @requested = requested
end

Instance Attribute Details

#requestedObject

To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.



753
754
755
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 753

def requested
  @requested
end