Class: Stripe::V2::Core::AccountCreateParams::Configuration::Merchant::Capabilities::PromptpayPayments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: Protections

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(protections: nil, requested: nil) ⇒ PromptpayPayments

Returns a new instance of PromptpayPayments.



1753
1754
1755
1756
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1753

def initialize(protections: nil, requested: nil)
  @protections = protections
  @requested = requested
end

Instance Attribute Details

#protectionsObject

Protection types to request for this capability (e.g. "psp_migration").



1749
1750
1751
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1749

def protections
  @protections
end

#requestedObject

To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.



1751
1752
1753
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1751

def requested
  @requested
end