Class: Stripe::V2::Core::AccountCreateParams::Configuration::Merchant::Capabilities::SwishPayments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: Protections

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(protections: nil, requested: nil) ⇒ SwishPayments

Returns a new instance of SwishPayments.



1921
1922
1923
1924
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1921

def initialize(protections: nil, requested: nil)
  @protections = protections
  @requested = requested
end

Instance Attribute Details

#protectionsObject

Protection types to request for this capability (e.g. "psp_migration").



1917
1918
1919
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1917

def protections
  @protections
end

#requestedObject

To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.



1919
1920
1921
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1919

def requested
  @requested
end