Class: Stripe::V2::Core::AccountCreateParams::Configuration::Merchant::Capabilities::ZipPayments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: Protections

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(protections: nil, requested: nil) ⇒ ZipPayments

Returns a new instance of ZipPayments.



2005
2006
2007
2008
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2005

def initialize(protections: nil, requested: nil)
  @protections = protections
  @requested = requested
end

Instance Attribute Details

#protectionsObject

Protection types to request for this capability (e.g. "psp_migration").



2001
2002
2003
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2001

def protections
  @protections
end

#requestedObject

To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.



2003
2004
2005
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2003

def requested
  @requested
end