Class: Stripe::V2::Core::AccountCreateParams::Configuration::Merchant::GrossSettlement

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(payment_method: nil, payment_method_collection: nil) ⇒ GrossSettlement

Returns a new instance of GrossSettlement.



2222
2223
2224
2225
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2222

def initialize(payment_method: nil, payment_method_collection: nil)
  @payment_method = payment_method
  @payment_method_collection = payment_method_collection
end

Instance Attribute Details

#payment_methodObject

The ID of the payment method to use for gross settlement payouts.



2218
2219
2220
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2218

def payment_method
  @payment_method
end

#payment_method_collectionObject

Whether to collect a payment method for gross settlement.



2220
2221
2222
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2220

def payment_method_collection
  @payment_method_collection
end