Class: Stripe::V2::Core::AccountCreateParams::Configuration::Merchant::Support

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(address: nil, email: nil, phone: nil, url: nil) ⇒ Support

Returns a new instance of Support.



2370
2371
2372
2373
2374
2375
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2370

def initialize(address: nil, email: nil, phone: nil, url: nil)
  @address = address
  @email = email
  @phone = phone
  @url = url
end

Instance Attribute Details

#addressObject

A publicly available mailing address for sending support issues to.



2362
2363
2364
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2362

def address
  @address
end

#emailObject

A publicly available email address for sending support issues to.



2364
2365
2366
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2364

def email
  @email
end

#phoneObject

A publicly available phone number to call with support issues.



2366
2367
2368
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2366

def phone
  @phone
end

#urlObject

A publicly available website for handling support issues.



2368
2369
2370
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2368

def url
  @url
end