Class: Stripe::V2::Core::AccountCreateParams::Configuration::MoneyManager::Capabilities
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Configuration::MoneyManager::Capabilities
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: BusinessStorage, ConsumerStorage, InboundTransfers, OutboundPayments, OutboundTransfers, ReceivedCredits, ReceivedDebits
Instance Attribute Summary collapse
-
#business_storage ⇒ Object
Can send or receive business storage-type funds on Stripe.
-
#consumer_storage ⇒ Object
Can send or receive consumer storage-type funds on Stripe.
-
#inbound_transfers ⇒ Object
Can pull funds from an external source, owned by yourself, to a FinancialAccount.
-
#outbound_payments ⇒ Object
Can send funds from a FinancialAccount to a destination owned by someone else.
-
#outbound_transfers ⇒ Object
Can send funds from a FinancialAccount to a destination owned by yourself.
-
#received_credits ⇒ Object
Can receive funds into a FinancialAccount.
-
#received_debits ⇒ Object
Can receive debits to a FinancialAccount.
Instance Method Summary collapse
-
#initialize(business_storage: nil, consumer_storage: nil, inbound_transfers: nil, outbound_payments: nil, outbound_transfers: nil, received_credits: nil, received_debits: nil) ⇒ Capabilities
constructor
A new instance of Capabilities.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(business_storage: nil, consumer_storage: nil, inbound_transfers: nil, outbound_payments: nil, outbound_transfers: nil, received_credits: nil, received_debits: nil) ⇒ Capabilities
Returns a new instance of Capabilities.
3384 3385 3386 3387 3388 3389 3390 3391 3392 3393 3394 3395 3396 3397 3398 3399 3400 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3384 def initialize( business_storage: nil, consumer_storage: nil, inbound_transfers: nil, outbound_payments: nil, outbound_transfers: nil, received_credits: nil, received_debits: nil ) @business_storage = business_storage @consumer_storage = consumer_storage @inbound_transfers = inbound_transfers @outbound_payments = outbound_payments @outbound_transfers = outbound_transfers @received_credits = received_credits @received_debits = received_debits end |
Instance Attribute Details
#business_storage ⇒ Object
Can send or receive business storage-type funds on Stripe.
3370 3371 3372 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3370 def business_storage @business_storage end |
#consumer_storage ⇒ Object
Can send or receive consumer storage-type funds on Stripe.
3372 3373 3374 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3372 def consumer_storage @consumer_storage end |
#inbound_transfers ⇒ Object
Can pull funds from an external source, owned by yourself, to a FinancialAccount.
3374 3375 3376 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3374 def inbound_transfers @inbound_transfers end |
#outbound_payments ⇒ Object
Can send funds from a FinancialAccount to a destination owned by someone else.
3376 3377 3378 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3376 def outbound_payments @outbound_payments end |
#outbound_transfers ⇒ Object
Can send funds from a FinancialAccount to a destination owned by yourself.
3378 3379 3380 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3378 def outbound_transfers @outbound_transfers end |
#received_credits ⇒ Object
Can receive funds into a FinancialAccount.
3380 3381 3382 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3380 def received_credits @received_credits end |
#received_debits ⇒ Object
Can receive debits to a FinancialAccount.
3382 3383 3384 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3382 def received_debits @received_debits end |