Class: Stripe::V2::Core::AccountCreateParams::Configuration::MoneyManager::Capabilities::InboundTransfers
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Configuration::MoneyManager::Capabilities::InboundTransfers
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: BankAccounts
Instance Attribute Summary collapse
-
#bank_accounts ⇒ Object
Can pull funds from an external bank account owned by yourself to a FinancialAccount.
Instance Method Summary collapse
-
#initialize(bank_accounts: nil) ⇒ InboundTransfers
constructor
A new instance of InboundTransfers.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(bank_accounts: nil) ⇒ InboundTransfers
Returns a new instance of InboundTransfers.
1159 1160 1161 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1159 def initialize(bank_accounts: nil) @bank_accounts = bank_accounts end |
Instance Attribute Details
#bank_accounts ⇒ Object
Can pull funds from an external bank account owned by yourself to a FinancialAccount.
1157 1158 1159 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1157 def bank_accounts @bank_accounts end |