Class: Stripe::V2::Core::AccountCreateParams::Configuration::MoneyManager::Capabilities::OutboundPayments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: BankAccounts, Cards, CryptoWallets, FinancialAccounts, PaperChecks

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(bank_accounts: nil, cards: nil, crypto_wallets: nil, financial_accounts: nil, paper_checks: nil) ⇒ OutboundPayments

Returns a new instance of OutboundPayments.



3154
3155
3156
3157
3158
3159
3160
3161
3162
3163
3164
3165
3166
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3154

def initialize(
  bank_accounts: nil,
  cards: nil,
  crypto_wallets: nil,
  financial_accounts: nil,
  paper_checks: nil
)
  @bank_accounts = bank_accounts
  @cards = cards
  @crypto_wallets = crypto_wallets
  @financial_accounts = financial_accounts
  @paper_checks = paper_checks
end

Instance Attribute Details

#bank_accountsObject

Can send funds from a FinancialAccount to a bank account owned by someone else.



3144
3145
3146
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3144

def bank_accounts
  @bank_accounts
end

#cardsObject

Can send funds from a FinancialAccount to a debit card owned by someone else.



3146
3147
3148
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3146

def cards
  @cards
end

#crypto_walletsObject

Can send funds from a FinancialAccount to a crypto wallet owned by someone else.



3148
3149
3150
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3148

def crypto_wallets
  @crypto_wallets
end

#financial_accountsObject

Can send funds from a FinancialAccount to another FinancialAccount owned by someone else.



3150
3151
3152
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3150

def financial_accounts
  @financial_accounts
end

#paper_checksObject

Can send funds from a FinancialAccount to someone else via paper check.



3152
3153
3154
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3152

def paper_checks
  @paper_checks
end