Class: Stripe::V2::Core::AccountCreateParams::Configuration::MoneyManager::RegulatedActivity

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(description: nil, license_number: nil, primary_regulatory_authority_country: nil, primary_regulatory_authority_name: nil) ⇒ RegulatedActivity

Returns a new instance of RegulatedActivity.



3413
3414
3415
3416
3417
3418
3419
3420
3421
3422
3423
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3413

def initialize(
  description: nil,
  license_number: nil,
  primary_regulatory_authority_country: nil,
  primary_regulatory_authority_name: nil
)
  @description = description
  @license_number = license_number
  @primary_regulatory_authority_country = primary_regulatory_authority_country
  @primary_regulatory_authority_name = primary_regulatory_authority_name
end

Instance Attribute Details

#descriptionObject

A detailed description of the regulated activities the business is licensed to conduct.



3405
3406
3407
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3405

def description
  @description
end

#license_numberObject

The license number or registration number assigned by the business's primary regulator.



3407
3408
3409
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3407

def license_number
  @license_number
end

#primary_regulatory_authority_countryObject

The country of the primary regulatory authority that oversees the business's regulated activities.



3409
3410
3411
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3409

def primary_regulatory_authority_country
  @primary_regulatory_authority_country
end

#primary_regulatory_authority_nameObject

The name of the primary regulatory authority that oversees the business's regulated activities.



3411
3412
3413
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3411

def primary_regulatory_authority_name
  @primary_regulatory_authority_name
end