Class: Stripe::V2::Core::AccountCreateParams::Configuration::Recipient::Capabilities

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: BankAccounts, Cards, CryptoWallets, PaperChecks, StripeBalance

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(bank_accounts: nil, cards: nil, crypto_wallets: nil, paper_checks: nil, stripe_balance: nil) ⇒ Capabilities

Returns a new instance of Capabilities.



4029
4030
4031
4032
4033
4034
4035
4036
4037
4038
4039
4040
4041
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 4029

def initialize(
  bank_accounts: nil,
  cards: nil,
  crypto_wallets: nil,
  paper_checks: nil,
  stripe_balance: nil
)
  @bank_accounts = bank_accounts
  @cards = cards
  @crypto_wallets = crypto_wallets
  @paper_checks = paper_checks
  @stripe_balance = stripe_balance
end

Instance Attribute Details

#bank_accountsObject

Capabilities that enable OutboundPayments to a bank account linked to this Account.



4019
4020
4021
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 4019

def bank_accounts
  @bank_accounts
end

#cardsObject

Capabilities that enable OutboundPayments to a card linked to this Account.



4021
4022
4023
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 4021

def cards
  @cards
end

#crypto_walletsObject

Capabilities that enable OutboundPayments to a crypto wallet linked to this Account.



4023
4024
4025
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 4023

def crypto_wallets
  @crypto_wallets
end

#paper_checksObject

Capabilities that enable OutboundPayments via paper check.



4025
4026
4027
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 4025

def paper_checks
  @paper_checks
end

#stripe_balanceObject

Capabilities that enable the recipient to manage their Stripe Balance (/v1/balance).



4027
4028
4029
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 4027

def stripe_balance
  @stripe_balance
end