Class: Stripe::V2::Core::AccountCreateParams::Configuration::Recipient::Capabilities::BankAccounts

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: Ach, Becs, Eft, Fedwire, Fps, Instant, Local, Npp, Rtp, SepaCredit, SepaInstant, Swift, Wire

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(ach: nil, becs: nil, eft: nil, fedwire: nil, fps: nil, instant: nil, local: nil, npp: nil, rtp: nil, sepa_credit: nil, sepa_instant: nil, swift: nil, wire: nil) ⇒ BankAccounts

Returns a new instance of BankAccounts.



3868
3869
3870
3871
3872
3873
3874
3875
3876
3877
3878
3879
3880
3881
3882
3883
3884
3885
3886
3887
3888
3889
3890
3891
3892
3893
3894
3895
3896
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3868

def initialize(
  ach: nil,
  becs: nil,
  eft: nil,
  fedwire: nil,
  fps: nil,
  instant: nil,
  local: nil,
  npp: nil,
  rtp: nil,
  sepa_credit: nil,
  sepa_instant: nil,
  swift: nil,
  wire: nil
)
  @ach = ach
  @becs = becs
  @eft = eft
  @fedwire = fedwire
  @fps = fps
  @instant = instant
  @local = local
  @npp = npp
  @rtp = rtp
  @sepa_credit = sepa_credit
  @sepa_instant = sepa_instant
  @swift = swift
  @wire = wire
end

Instance Attribute Details

#achObject

Enables this Account to receive OutboundPayments to linked bank accounts over ACH rails.



3842
3843
3844
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3842

def ach
  @ach
end

#becsObject

Enables this Account to receive OutboundPayments to linked bank accounts over BECS rails.



3844
3845
3846
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3844

def becs
  @becs
end

#eftObject

Enables this Account to receive OutboundPayments to linked bank accounts over EFT rails.



3846
3847
3848
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3846

def eft
  @eft
end

#fedwireObject

Enables this Account to receive OutboundPayments to linked bank accounts over Fedwire or CHIPS.



3848
3849
3850
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3848

def fedwire
  @fedwire
end

#fpsObject

Enables this Account to receive OutboundPayments to linked bank accounts over FPS rails.



3850
3851
3852
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3850

def fps
  @fps
end

#instantObject

Enables this Account to receive OutboundPayments to linked bank accounts over real time rails.



3852
3853
3854
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3852

def instant
  @instant
end

#localObject

Enables this Account to receive OutboundPayments to linked bank accounts over local networks.



3854
3855
3856
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3854

def local
  @local
end

#nppObject

Enables this Account to receive OutboundPayments to linked bank accounts over NPP (real time) rails.



3856
3857
3858
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3856

def npp
  @npp
end

#rtpObject

Enables this Account to receive OutboundPayments to linked bank accounts over RTP rails.



3858
3859
3860
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3858

def rtp
  @rtp
end

#sepa_creditObject

Enables this Account to receive OutboundPayments to linked bank accounts over SEPA credit rails.



3860
3861
3862
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3860

def sepa_credit
  @sepa_credit
end

#sepa_instantObject

Enables this Account to receive OutboundPayments to linked bank accounts over SEPA instant (real time) rails.



3862
3863
3864
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3862

def sepa_instant
  @sepa_instant
end

#swiftObject

Enables this Account to receive OutboundPayments to linked bank accounts over SWIFT.



3864
3865
3866
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3864

def swift
  @swift
end

#wireObject

Enables this Account to receive OutboundPayments to linked bank accounts over wire.



3866
3867
3868
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3866

def wire
  @wire
end