Class: Stripe::V2::Core::AccountCreateParams::Configuration::Recipient::Capabilities::PaperChecks
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Configuration::Recipient::Capabilities::PaperChecks
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: Protections
Instance Attribute Summary collapse
-
#protections ⇒ Object
Protection types to request for this capability (e.g. "psp_migration").
-
#requested ⇒ Object
To request a new Capability for an account, pass true.
Instance Method Summary collapse
-
#initialize(protections: nil, requested: nil) ⇒ PaperChecks
constructor
A new instance of PaperChecks.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(protections: nil, requested: nil) ⇒ PaperChecks
Returns a new instance of PaperChecks.
3977 3978 3979 3980 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3977 def initialize(protections: nil, requested: nil) @protections = protections @requested = requested end |
Instance Attribute Details
#protections ⇒ Object
Protection types to request for this capability (e.g. "psp_migration").
3973 3974 3975 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3973 def protections @protections end |
#requested ⇒ Object
To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
3975 3976 3977 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3975 def requested @requested end |