Class: Stripe::V2::Core::AccountCreateParams::Configuration::Storer::RegulatedActivity
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Configuration::Storer::RegulatedActivity
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Instance Attribute Summary collapse
-
#description ⇒ Object
A detailed description of the regulated activities the business is licensed to conduct.
-
#license_number ⇒ Object
The license number or registration number assigned by the business’s primary regulator.
-
#primary_regulatory_authority_country ⇒ Object
The country of the primary regulatory authority that oversees the business’s regulated activities.
-
#primary_regulatory_authority_name ⇒ Object
The name of the primary regulatory authority that oversees the business’s regulated activities.
Instance Method Summary collapse
-
#initialize(description: nil, license_number: nil, primary_regulatory_authority_country: nil, primary_regulatory_authority_name: nil) ⇒ RegulatedActivity
constructor
A new instance of RegulatedActivity.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(description: nil, license_number: nil, primary_regulatory_authority_country: nil, primary_regulatory_authority_name: nil) ⇒ RegulatedActivity
Returns a new instance of RegulatedActivity.
1604 1605 1606 1607 1608 1609 1610 1611 1612 1613 1614 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1604 def initialize( description: nil, license_number: nil, primary_regulatory_authority_country: nil, primary_regulatory_authority_name: nil ) @description = description @license_number = license_number @primary_regulatory_authority_country = @primary_regulatory_authority_name = end |
Instance Attribute Details
#description ⇒ Object
A detailed description of the regulated activities the business is licensed to conduct.
1596 1597 1598 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1596 def description @description end |
#license_number ⇒ Object
The license number or registration number assigned by the business’s primary regulator.
1598 1599 1600 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1598 def license_number @license_number end |
#primary_regulatory_authority_country ⇒ Object
The country of the primary regulatory authority that oversees the business’s regulated activities.
1600 1601 1602 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1600 def @primary_regulatory_authority_country end |
#primary_regulatory_authority_name ⇒ Object
The name of the primary regulatory authority that oversees the business’s regulated activities.
1602 1603 1604 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1602 def @primary_regulatory_authority_name end |