Class: Stripe::V2::Core::AccountCreateParams::Defaults::Profile

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(business_url: nil, doing_business_as: nil, product_description: nil) ⇒ Profile

Returns a new instance of Profile.



1726
1727
1728
1729
1730
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1726

def initialize(business_url: nil, doing_business_as: nil, product_description: nil)
  @business_url = business_url
  @doing_business_as = doing_business_as
  @product_description = product_description
end

Instance Attribute Details

#business_urlObject

The business’s publicly-available website.



1720
1721
1722
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1720

def business_url
  @business_url
end

#doing_business_asObject

The name which is used by the business.



1722
1723
1724
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1722

def doing_business_as
  @doing_business_as
end

#product_descriptionObject

Internal-only description of the product sold or service provided by the business. It’s used by Stripe for risk and underwriting purposes.



1724
1725
1726
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1724

def product_description
  @product_description
end