Class: Stripe::V2::Core::AccountCreateParams::Identity

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: Attestations, BusinessDetails, Individual

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(attestations: nil, business_details: nil, country: nil, entity_type: nil, individual: nil) ⇒ Identity

Returns a new instance of Identity.



6159
6160
6161
6162
6163
6164
6165
6166
6167
6168
6169
6170
6171
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 6159

def initialize(
  attestations: nil,
  business_details: nil,
  country: nil,
  entity_type: nil,
  individual: nil
)
  @attestations = attestations
  @business_details = business_details
  @country = country
  @entity_type = entity_type
  @individual = individual
end

Instance Attribute Details

#attestationsObject

Attestations from the identity's key people, e.g. owners, executives, directors, representatives.



6149
6150
6151
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 6149

def attestations
  @attestations
end

#business_detailsObject

Information about the company or business.



6151
6152
6153
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 6151

def business_details
  @business_details
end

#countryObject

The country in which the account holder resides, or in which the business is legally established. This should be an ISO 3166-1 alpha-2 country code.



6153
6154
6155
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 6153

def country
  @country
end

#entity_typeObject

The entity type represented by the Account. Ensure this field is accurate before adding configurations that rely on identity information, as it determines which identity fields apply and how the Account is validated.



6155
6156
6157
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 6155

def entity_type
  @entity_type
end

#individualObject

Information about the person represented by the account.



6157
6158
6159
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 6157

def individual
  @individual
end

Class Method Details

.field_encodingsObject



6173
6174
6175
6176
6177
6178
6179
6180
6181
6182
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 6173

def self.field_encodings
  @field_encodings = {
    individual: {
      kind: :object,
      fields: {
        relationship: { kind: :object, fields: { percent_ownership: :decimal_string } },
      },
    },
  }
end