Class: Stripe::V2::Core::AccountCreateParams::Identity::Attestations::DirectorshipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ DirectorshipDeclaration

Returns a new instance of DirectorshipDeclaration.



1795
1796
1797
1798
1799
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1795

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The time marking when the director attestation was made. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



1789
1790
1791
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1789

def date
  @date
end

#ipObject

The IP address from which the director attestation was made.



1791
1792
1793
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1791

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the director attestation was made.



1793
1794
1795
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1793

def user_agent
  @user_agent
end