Class: Stripe::V2::Core::AccountCreateParams::Identity::Attestations::PersonsProvided

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(directors: nil, executives: nil, owners: nil, ownership_exemption_reason: nil) ⇒ PersonsProvided

Returns a new instance of PersonsProvided.



4174
4175
4176
4177
4178
4179
4180
4181
4182
4183
4184
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 4174

def initialize(
  directors: nil,
  executives: nil,
  owners: nil,
  ownership_exemption_reason: nil
)
  @directors = directors
  @executives = executives
  @owners = owners
  @ownership_exemption_reason = ownership_exemption_reason
end

Instance Attribute Details

#directorsObject

Whether the company’s directors have been provided. Set this Boolean to true after creating all the company’s directors with the Persons API.



4166
4167
4168
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 4166

def directors
  @directors
end

#executivesObject

Whether the company’s executives have been provided. Set this Boolean to true after creating all the company’s executives with the Persons API.



4168
4169
4170
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 4168

def executives
  @executives
end

#ownersObject

Whether the company’s owners have been provided. Set this Boolean to true after creating all the company’s owners with the Persons API.



4170
4171
4172
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 4170

def owners
  @owners
end

#ownership_exemption_reasonObject

Reason for why the company is exempt from providing ownership information.



4172
4173
4174
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 4172

def ownership_exemption_reason
  @ownership_exemption_reason
end