Class: Stripe::V2::Core::AccountCreateParams::Identity::Attestations::RepresentativeDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ RepresentativeDeclaration

Returns a new instance of RepresentativeDeclaration.



1513
1514
1515
1516
1517
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1513

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The time marking when the representative attestation was made. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



1507
1508
1509
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1507

def date
  @date
end

#ipObject

The IP address from which the representative attestation was made.



1509
1510
1511
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1509

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the representative attestation was made.



1511
1512
1513
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1511

def user_agent
  @user_agent
end