Class: Stripe::V2::Core::AccountCreateParams::Identity::Attestations::TermsOfService::Account
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Identity::Attestations::TermsOfService::Account
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The time when the Account’s representative accepted the terms of service.
-
#ip ⇒ Object
The IP address from which the Account’s representative accepted the terms of service.
-
#user_agent ⇒ Object
The user agent of the browser from which the Account’s representative accepted the terms of service.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ Account
constructor
A new instance of Account.
Methods inherited from RequestParams
Constructor Details
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ Account
Returns a new instance of Account.
1658 1659 1660 1661 1662 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1658 def initialize(date: nil, ip: nil, user_agent: nil) @date = date @ip = ip @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The time when the Account’s representative accepted the terms of service. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
1652 1653 1654 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1652 def date @date end |
#ip ⇒ Object
The IP address from which the Account’s representative accepted the terms of service.
1654 1655 1656 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1654 def ip @ip end |
#user_agent ⇒ Object
The user agent of the browser from which the Account’s representative accepted the terms of service.
1656 1657 1658 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1656 def user_agent @user_agent end |