Class: Stripe::V2::Core::AccountCreateParams::Identity::BusinessDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Identity::BusinessDetails
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: AdditionalAddress, Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, RegistrationDate, ScriptAddresses, ScriptNames
Instance Attribute Summary collapse
-
#additional_addresses ⇒ Object
Additional addresses associated with the business.
-
#address ⇒ Object
The business registration address of the business entity.
-
#annual_revenue ⇒ Object
The business gross annual revenue for its preceding fiscal year.
-
#documents ⇒ Object
A document verifying the business.
-
#estimated_worker_count ⇒ Object
Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).
-
#id_numbers ⇒ Object
The ID numbers of a business entity.
-
#monthly_estimated_revenue ⇒ Object
An estimate of the monthly revenue of the business.
-
#phone ⇒ Object
The phone number of the Business Entity.
-
#registered_name ⇒ Object
The business legal name.
-
#registration_date ⇒ Object
When the business was incorporated or registered.
-
#script_addresses ⇒ Object
The business registration address of the business entity in non latin script.
-
#script_names ⇒ Object
The business legal name in non latin script.
-
#structure ⇒ Object
The category identifying the legal structure of the business.
Instance Method Summary collapse
-
#initialize(additional_addresses: nil, address: nil, annual_revenue: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails
constructor
A new instance of BusinessDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(additional_addresses: nil, address: nil, annual_revenue: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails
Returns a new instance of BusinessDetails.
1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 1727 1728 1729 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1701 def initialize( additional_addresses: nil, address: nil, annual_revenue: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil ) @additional_addresses = additional_addresses @address = address @annual_revenue = annual_revenue @documents = documents @estimated_worker_count = estimated_worker_count @id_numbers = id_numbers @monthly_estimated_revenue = monthly_estimated_revenue @phone = phone @registered_name = registered_name @registration_date = registration_date @script_addresses = script_addresses @script_names = script_names @structure = structure end |
Instance Attribute Details
#additional_addresses ⇒ Object
Additional addresses associated with the business.
1675 1676 1677 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1675 def additional_addresses @additional_addresses end |
#address ⇒ Object
The business registration address of the business entity.
1677 1678 1679 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1677 def address @address end |
#annual_revenue ⇒ Object
The business gross annual revenue for its preceding fiscal year.
1679 1680 1681 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1679 def annual_revenue @annual_revenue end |
#documents ⇒ Object
A document verifying the business.
1681 1682 1683 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1681 def documents @documents end |
#estimated_worker_count ⇒ Object
Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).
1683 1684 1685 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1683 def estimated_worker_count @estimated_worker_count end |
#id_numbers ⇒ Object
The ID numbers of a business entity.
1685 1686 1687 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1685 def id_numbers @id_numbers end |
#monthly_estimated_revenue ⇒ Object
An estimate of the monthly revenue of the business.
1687 1688 1689 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1687 def monthly_estimated_revenue @monthly_estimated_revenue end |
#phone ⇒ Object
The phone number of the Business Entity.
1689 1690 1691 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1689 def phone @phone end |
#registered_name ⇒ Object
The business legal name.
1691 1692 1693 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1691 def registered_name @registered_name end |
#registration_date ⇒ Object
When the business was incorporated or registered.
1693 1694 1695 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1693 def registration_date @registration_date end |
#script_addresses ⇒ Object
The business registration address of the business entity in non latin script.
1695 1696 1697 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1695 def script_addresses @script_addresses end |
#script_names ⇒ Object
The business legal name in non latin script.
1697 1698 1699 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1697 def script_names @script_names end |
#structure ⇒ Object
The category identifying the legal structure of the business.
1699 1700 1701 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1699 def structure @structure end |