Class: Stripe::V2::Core::AccountCreateParams::Identity::BusinessDetails::AnnualRevenue::Amount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Identity::BusinessDetails::AnnualRevenue::Amount
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Instance Attribute Summary collapse
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#value ⇒ Object
A non-negative integer representing how much to charge in the [smallest currency unit](docs.stripe.com/currencies#minor-units).
Instance Method Summary collapse
-
#initialize(value: nil, currency: nil) ⇒ Amount
constructor
A new instance of Amount.
Methods inherited from RequestParams
Constructor Details
#initialize(value: nil, currency: nil) ⇒ Amount
Returns a new instance of Amount.
2740 2741 2742 2743 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2740 def initialize(value: nil, currency: nil) @value = value @currency = currency end |
Instance Attribute Details
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
2738 2739 2740 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2738 def currency @currency end |
#value ⇒ Object
A non-negative integer representing how much to charge in the [smallest currency unit](docs.stripe.com/currencies#minor-units).
2736 2737 2738 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2736 def value @value end |