Class: Stripe::V2::Core::AccountCreateParams::Identity::BusinessDetails::Documents::BankAccountOwnershipVerification
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Identity::BusinessDetails::Documents::BankAccountOwnershipVerification
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Instance Attribute Summary collapse
-
#files ⇒ Object
One or more document IDs returned by a file upload with a purpose value of
account_requirement. -
#type ⇒ Object
The format of the document.
Instance Method Summary collapse
-
#initialize(files: nil, type: nil) ⇒ BankAccountOwnershipVerification
constructor
A new instance of BankAccountOwnershipVerification.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(files: nil, type: nil) ⇒ BankAccountOwnershipVerification
Returns a new instance of BankAccountOwnershipVerification.
1680 1681 1682 1683 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1680 def initialize(files: nil, type: nil) @files = files @type = type end |
Instance Attribute Details
#files ⇒ Object
One or more document IDs returned by a file upload with a purpose value of account_requirement.
1676 1677 1678 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1676 def files @files end |
#type ⇒ Object
The format of the document. Currently supports files only.
1678 1679 1680 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1678 def type @type end |