Class: Stripe::V2::Core::AccountCreateParams::Identity::BusinessDetails::Documents::PrimaryVerification::FrontBack

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h

Constructor Details

#initialize(back: nil, front: nil) ⇒ FrontBack

Returns a new instance of FrontBack.



1355
1356
1357
1358
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1355

def initialize(back: nil, front: nil)
  @back = back
  @front = front
end

Instance Attribute Details

#backObject

A file upload token representing the back of the verification document. The purpose of the uploaded file should be 'identity_document'. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.



1351
1352
1353
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1351

def back
  @back
end

#frontObject

A file upload token representing the front of the verification document. The purpose of the uploaded file should be 'identity_document'. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.



1353
1354
1355
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1353

def front
  @front
end