Class: Stripe::V2::Core::AccountCreateParams::Identity::BusinessDetails::Documents::ProofOfRegistration
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Identity::BusinessDetails::Documents::ProofOfRegistration
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: Signer
Instance Attribute Summary collapse
-
#files ⇒ Object
One or more document IDs returned by a file upload with a purpose value of
account_requirement. -
#signer ⇒ Object
Person that is signing the document.
-
#type ⇒ Object
The format of the document.
Instance Method Summary collapse
-
#initialize(files: nil, signer: nil, type: nil) ⇒ ProofOfRegistration
constructor
A new instance of ProofOfRegistration.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(files: nil, signer: nil, type: nil) ⇒ ProofOfRegistration
Returns a new instance of ProofOfRegistration.
5410 5411 5412 5413 5414 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 5410 def initialize(files: nil, signer: nil, type: nil) @files = files @signer = signer @type = type end |
Instance Attribute Details
#files ⇒ Object
One or more document IDs returned by a file upload with a purpose value of account_requirement.
5404 5405 5406 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 5404 def files @files end |
#signer ⇒ Object
Person that is signing the document.
5406 5407 5408 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 5406 def signer @signer end |
#type ⇒ Object
The format of the document. Currently supports files only.
5408 5409 5410 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 5408 def type @type end |