Class: Stripe::V2::Core::AccountCreateParams::Identity::BusinessDetails::Documents::ProofOfUltimateBeneficialOwnership
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Identity::BusinessDetails::Documents::ProofOfUltimateBeneficialOwnership
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: Signer
Instance Attribute Summary collapse
-
#files ⇒ Object
One or more document IDs returned by a file upload with a purpose value of
account_requirement. -
#signer ⇒ Object
Person that is signing the document.
-
#type ⇒ Object
The format of the document.
Instance Method Summary collapse
-
#initialize(files: nil, signer: nil, type: nil) ⇒ ProofOfUltimateBeneficialOwnership
constructor
A new instance of ProofOfUltimateBeneficialOwnership.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(files: nil, signer: nil, type: nil) ⇒ ProofOfUltimateBeneficialOwnership
Returns a new instance of ProofOfUltimateBeneficialOwnership.
5433 5434 5435 5436 5437 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 5433 def initialize(files: nil, signer: nil, type: nil) @files = files @signer = signer @type = type end |
Instance Attribute Details
#files ⇒ Object
One or more document IDs returned by a file upload with a purpose value of account_requirement.
5427 5428 5429 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 5427 def files @files end |
#signer ⇒ Object
Person that is signing the document.
5429 5430 5431 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 5429 def signer @signer end |
#type ⇒ Object
The format of the document. Currently supports files only.
5431 5432 5433 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 5431 def type @type end |