Class: Stripe::V2::Core::AccountCreateParams::Identity::Individual::Documents::PrimaryVerification
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Identity::Individual::Documents::PrimaryVerification
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: FrontBack
Instance Attribute Summary collapse
-
#front_back ⇒ Object
The file upload tokens referring to each side of the document.
-
#type ⇒ Object
The format of the verification document.
Instance Method Summary collapse
-
#initialize(front_back: nil, type: nil) ⇒ PrimaryVerification
constructor
A new instance of PrimaryVerification.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(front_back: nil, type: nil) ⇒ PrimaryVerification
Returns a new instance of PrimaryVerification.
2228 2229 2230 2231 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2228 def initialize(front_back: nil, type: nil) @front_back = front_back @type = type end |
Instance Attribute Details
#front_back ⇒ Object
The file upload tokens referring to each side of the document.
2224 2225 2226 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2224 def front_back @front_back end |
#type ⇒ Object
The format of the verification document. Currently supports front_back only.
2226 2227 2228 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2226 def type @type end |