Class: Stripe::V2::Core::AccountCreateParams::Identity::Individual::Documents::PrimaryVerification::FrontBack
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Identity::Individual::Documents::PrimaryVerification::FrontBack
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Instance Attribute Summary collapse
-
#back ⇒ Object
A file upload token representing the back of the verification document.
-
#front ⇒ Object
A file upload token representing the front of the verification document.
Instance Method Summary collapse
-
#initialize(back: nil, front: nil) ⇒ FrontBack
constructor
A new instance of FrontBack.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(back: nil, front: nil) ⇒ FrontBack
1820 1821 1822 1823 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1820 def initialize(back: nil, front: nil) @back = back @front = front end |
Instance Attribute Details
#back ⇒ Object
A file upload token representing the back of the verification document. The purpose of the uploaded file should be 'identity_document'. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.
1816 1817 1818 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1816 def back @back end |
#front ⇒ Object
A file upload token representing the front of the verification document. The purpose of the uploaded file should be 'identity_document'. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.
1818 1819 1820 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1818 def front @front end |