Class: Stripe::V2::Core::AccountCreateParams::Identity::Individual::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship

Returns a new instance of Relationship.



2318
2319
2320
2321
2322
2323
2324
2325
2326
2327
2328
2329
2330
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2318

def initialize(
  director: nil,
  executive: nil,
  owner: nil,
  percent_ownership: nil,
  title: nil
)
  @director = director
  @executive = executive
  @owner = owner
  @percent_ownership = percent_ownership
  @title = title
end

Instance Attribute Details

#directorObject

Whether the person is a director of the account's identity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



2308
2309
2310
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2308

def director
  @director
end

#executiveObject

Whether the person has significant responsibility to control, manage, or direct the organization.



2310
2311
2312
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2310

def executive
  @executive
end

#ownerObject

Whether the person is an owner of the account’s identity.



2312
2313
2314
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2312

def owner
  @owner
end

#percent_ownershipObject

The percent owned by the person of the account's legal entity.



2314
2315
2316
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2314

def percent_ownership
  @percent_ownership
end

#titleObject

The person's title (e.g., CEO, Support Engineer).



2316
2317
2318
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2316

def title
  @title
end

Class Method Details

.field_encodingsObject



2332
2333
2334
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2332

def self.field_encodings
  @field_encodings = { percent_ownership: :decimal_string }
end