Class: Stripe::V2::Core::AccountEvaluation
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Core::AccountEvaluation
- Defined in:
- lib/stripe/resources/v2/core/account_evaluation.rb
Overview
Account Evaluation resource.
Defined Under Namespace
Classes: AccountData
Constant Summary collapse
- OBJECT_NAME =
"v2.core.account_evaluation"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account ⇒ Object
readonly
The account ID if this evaluation is for an existing account.
-
#account_data ⇒ Object
readonly
Account data if this evaluation is for an account without an existing Stripe entity.
-
#created ⇒ Object
readonly
Timestamp at which the evaluation was created.
-
#evaluations_triggered ⇒ Object
readonly
List of signals that were triggered for evaluation.
-
#id ⇒ Object
readonly
Unique identifier for the account evaluation.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account ⇒ Object (readonly)
The account ID if this evaluation is for an existing account.
82 83 84 |
# File 'lib/stripe/resources/v2/core/account_evaluation.rb', line 82 def account @account end |
#account_data ⇒ Object (readonly)
Account data if this evaluation is for an account without an existing Stripe entity.
84 85 86 |
# File 'lib/stripe/resources/v2/core/account_evaluation.rb', line 84 def account_data @account_data end |
#created ⇒ Object (readonly)
Timestamp at which the evaluation was created.
86 87 88 |
# File 'lib/stripe/resources/v2/core/account_evaluation.rb', line 86 def created @created end |
#evaluations_triggered ⇒ Object (readonly)
List of signals that were triggered for evaluation.
88 89 90 |
# File 'lib/stripe/resources/v2/core/account_evaluation.rb', line 88 def evaluations_triggered @evaluations_triggered end |
#id ⇒ Object (readonly)
Unique identifier for the account evaluation.
90 91 92 |
# File 'lib/stripe/resources/v2/core/account_evaluation.rb', line 90 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
92 93 94 |
# File 'lib/stripe/resources/v2/core/account_evaluation.rb', line 92 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
94 95 96 |
# File 'lib/stripe/resources/v2/core/account_evaluation.rb', line 94 def object @object end |
Class Method Details
.field_remappings ⇒ Object
100 101 102 |
# File 'lib/stripe/resources/v2/core/account_evaluation.rb', line 100 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
96 97 98 |
# File 'lib/stripe/resources/v2/core/account_evaluation.rb', line 96 def self.inner_class_types @inner_class_types = { account_data: AccountData } end |
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/v2/core/account_evaluation.rb', line 10 def self.object_name "v2.core.account_evaluation" end |