Class: Stripe::V2::Core::AccountLink
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Core::AccountLink
- Defined in:
- lib/stripe/resources/v2/core/account_link.rb
Overview
Account Links let a platform create a temporary, single-use URL that an account can use to access a Stripe-hosted flow for collecting or updating required information.
Defined Under Namespace
Classes: UseCase
Constant Summary collapse
- OBJECT_NAME =
"v2.core.account_link"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account ⇒ Object
readonly
The ID of the connected account this Account Link applies to.
-
#created ⇒ Object
readonly
The timestamp at which this Account Link was created.
-
#expires_at ⇒ Object
readonly
The timestamp at which this Account Link will expire.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#url ⇒ Object
readonly
The URL at which the account can access the Stripe-hosted flow.
-
#use_case ⇒ Object
readonly
Hash containing usage options.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account ⇒ Object (readonly)
The ID of the connected account this Account Link applies to.
171 172 173 |
# File 'lib/stripe/resources/v2/core/account_link.rb', line 171 def account @account end |
#created ⇒ Object (readonly)
The timestamp at which this Account Link was created.
173 174 175 |
# File 'lib/stripe/resources/v2/core/account_link.rb', line 173 def created @created end |
#expires_at ⇒ Object (readonly)
The timestamp at which this Account Link will expire.
175 176 177 |
# File 'lib/stripe/resources/v2/core/account_link.rb', line 175 def expires_at @expires_at end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
177 178 179 |
# File 'lib/stripe/resources/v2/core/account_link.rb', line 177 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
179 180 181 |
# File 'lib/stripe/resources/v2/core/account_link.rb', line 179 def object @object end |
#url ⇒ Object (readonly)
The URL at which the account can access the Stripe-hosted flow.
181 182 183 |
# File 'lib/stripe/resources/v2/core/account_link.rb', line 181 def url @url end |
#use_case ⇒ Object (readonly)
Hash containing usage options.
183 184 185 |
# File 'lib/stripe/resources/v2/core/account_link.rb', line 183 def use_case @use_case end |
Class Method Details
.field_remappings ⇒ Object
189 190 191 |
# File 'lib/stripe/resources/v2/core/account_link.rb', line 189 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
185 186 187 |
# File 'lib/stripe/resources/v2/core/account_link.rb', line 185 def self.inner_class_types @inner_class_types = { use_case: UseCase } end |
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/v2/core/account_link.rb', line 10 def self.object_name "v2.core.account_link" end |