Class: Stripe::V2::Core::AccountLink::UseCase::AccountUpdate
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::AccountLink::UseCase::AccountUpdate
- Defined in:
- lib/stripe/resources/v2/core/account_link.rb
Defined Under Namespace
Classes: CollectionOptions
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#collection_options ⇒ Object
readonly
Specifies the requirements that Stripe collects from v2/core/accounts in the Onboarding flow.
-
#configurations ⇒ Object
readonly
Open Enum.
-
#refresh_url ⇒ Object
readonly
The URL the user will be redirected to if the AccountLink is expired, has been used, or is otherwise invalid.
-
#return_url ⇒ Object
readonly
The URL that the user will be redirected to upon completing the linked flow.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#collection_options ⇒ Object (readonly)
Specifies the requirements that Stripe collects from v2/core/accounts in the Onboarding flow.
40 41 42 |
# File 'lib/stripe/resources/v2/core/account_link.rb', line 40 def @collection_options end |
#configurations ⇒ Object (readonly)
Open Enum. A v2/account can be configured to enable certain functionality. The configuration param targets the v2/account_link to collect information for the specified v2/account configuration/s.
42 43 44 |
# File 'lib/stripe/resources/v2/core/account_link.rb', line 42 def configurations @configurations end |
#refresh_url ⇒ Object (readonly)
The URL the user will be redirected to if the AccountLink is expired, has been used, or is otherwise invalid. The URL you specify should attempt to generate a new AccountLink with the same parameters used to create the original AccountLink, then redirect the user to the new AccountLink’s URL so they can continue the flow. If a new AccountLink cannot be generated or the redirect fails you should display a useful error to the user. Please make sure to implement authentication before redirecting the user in case this URL is leaked to a third party.
44 45 46 |
# File 'lib/stripe/resources/v2/core/account_link.rb', line 44 def refresh_url @refresh_url end |
#return_url ⇒ Object (readonly)
The URL that the user will be redirected to upon completing the linked flow.
46 47 48 |
# File 'lib/stripe/resources/v2/core/account_link.rb', line 46 def return_url @return_url end |