Class: Stripe::V2::Core::AccountLink::UseCase::RecipientUpdate
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::AccountLink::UseCase::RecipientUpdate
- Defined in:
- lib/stripe/resources/v2/core/account_link.rb
Defined Under Namespace
Classes: CollectionOptions
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#collection_options ⇒ Object
readonly
Specifies the requirements that Stripe collects from v2/core/accounts in the Update flow.
-
#configurations ⇒ Object
readonly
Open Enum.
-
#refresh_url ⇒ Object
readonly
The URL the user will be redirected to if the Account Link is expired, has been used, or is otherwise invalid.
-
#return_url ⇒ Object
readonly
The URL that the user will be redirected to upon completing the linked flow.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#collection_options ⇒ Object (readonly)
Specifies the requirements that Stripe collects from v2/core/accounts in the Update flow.
130 131 132 |
# File 'lib/stripe/resources/v2/core/account_link.rb', line 130 def @collection_options end |
#configurations ⇒ Object (readonly)
Open Enum. A v2/account can be configured to enable certain functionality. The configuration param targets the v2/account_link to collect information for the specified v2/account configuration/s.
132 133 134 |
# File 'lib/stripe/resources/v2/core/account_link.rb', line 132 def configurations @configurations end |
#refresh_url ⇒ Object (readonly)
The URL the user will be redirected to if the Account Link is expired, has been used, or is otherwise invalid. The URL you specify should attempt to generate a new Account Link with the same parameters used to create the original Account Link, then redirect the user to the new Account Link URL so they can continue the flow. Make sure to authenticate the user before redirecting to the new Account Link, in case the URL leaks to a third party. If a new Account Link can’t be generated, or if the redirect fails, you should display a useful error to the user.
134 135 136 |
# File 'lib/stripe/resources/v2/core/account_link.rb', line 134 def refresh_url @refresh_url end |
#return_url ⇒ Object (readonly)
The URL that the user will be redirected to upon completing the linked flow.
136 137 138 |
# File 'lib/stripe/resources/v2/core/account_link.rb', line 136 def return_url @return_url end |
Class Method Details
.field_remappings ⇒ Object
142 143 144 |
# File 'lib/stripe/resources/v2/core/account_link.rb', line 142 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
138 139 140 |
# File 'lib/stripe/resources/v2/core/account_link.rb', line 138 def self.inner_class_types @inner_class_types = { collection_options: CollectionOptions } end |