Class: Stripe::V2::Core::AccountLinkCreateParams::UseCase

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_link_create_params.rb

Defined Under Namespace

Classes: AccountOnboarding, AccountUpdate, RecipientOnboarding, RecipientUpdate

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(type: nil, account_onboarding: nil, account_update: nil, recipient_onboarding: nil, recipient_update: nil) ⇒ UseCase

Returns a new instance of UseCase.



155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/stripe/params/v2/core/account_link_create_params.rb', line 155

def initialize(
  type: nil,
  account_onboarding: nil,
  account_update: nil,
  recipient_onboarding: nil,
  recipient_update: nil
)
  @type = type
  @account_onboarding = 
  @account_update = 
  @recipient_onboarding = recipient_onboarding
  @recipient_update = recipient_update
end

Instance Attribute Details

#account_onboardingObject

Hash containing configuration options for an Account Link object that onboards a new account.



147
148
149
# File 'lib/stripe/params/v2/core/account_link_create_params.rb', line 147

def 
  @account_onboarding
end

#account_updateObject

Hash containing configuration options for an Account Link that updates an existing account.



149
150
151
# File 'lib/stripe/params/v2/core/account_link_create_params.rb', line 149

def 
  @account_update
end

#recipient_onboardingObject

Hash containing configuration options for an Account Link object that onboards a new recipient.



151
152
153
# File 'lib/stripe/params/v2/core/account_link_create_params.rb', line 151

def recipient_onboarding
  @recipient_onboarding
end

#recipient_updateObject

Hash containing configuration options for an Account Link that updates an existing recipient.



153
154
155
# File 'lib/stripe/params/v2/core/account_link_create_params.rb', line 153

def recipient_update
  @recipient_update
end

#typeObject

Open Enum. The type of Account Link the user is requesting.



145
146
147
# File 'lib/stripe/params/v2/core/account_link_create_params.rb', line 145

def type
  @type
end