Class: Stripe::V2::Core::AccountLinkCreateParams::UseCase::RecipientOnboarding

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_link_create_params.rb

Defined Under Namespace

Classes: CollectionOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(collection_options: nil, configurations: nil, refresh_url: nil, return_url: nil) ⇒ RecipientOnboarding

Returns a new instance of RecipientOnboarding.



98
99
100
101
102
103
104
105
106
107
108
# File 'lib/stripe/params/v2/core/account_link_create_params.rb', line 98

def initialize(
  collection_options: nil,
  configurations: nil,
  refresh_url: nil,
  return_url: nil
)
  @collection_options = collection_options
  @configurations = configurations
  @refresh_url = refresh_url
  @return_url = return_url
end

Instance Attribute Details

#collection_optionsObject

Specifies the requirements that Stripe collects from v2/core/accounts in the Onboarding flow.



90
91
92
# File 'lib/stripe/params/v2/core/account_link_create_params.rb', line 90

def collection_options
  @collection_options
end

#configurationsObject

Open Enum. A v2/core/account can be configured to enable certain functionality. The configuration param targets the v2/core/account_link to collect information for the specified v2/core/account configuration/s.



92
93
94
# File 'lib/stripe/params/v2/core/account_link_create_params.rb', line 92

def configurations
  @configurations
end

#refresh_urlObject

The URL the user will be redirected to if the AccountLink is expired, has been used, or is otherwise invalid. The URL you specify should attempt to generate a new AccountLink with the same parameters used to create the original AccountLink, then redirect the user to the new AccountLink’s URL so they can continue the flow. If a new AccountLink cannot be generated or the redirect fails you should display a useful error to the user. Please make sure to implement authentication before redirecting the user in case this URL is leaked to a third party.



94
95
96
# File 'lib/stripe/params/v2/core/account_link_create_params.rb', line 94

def refresh_url
  @refresh_url
end

#return_urlObject

The URL that the user will be redirected to upon completing the linked flow.



96
97
98
# File 'lib/stripe/params/v2/core/account_link_create_params.rb', line 96

def return_url
  @return_url
end