Class: Stripe::V2::Core::AccountLinkService

Inherits:
StripeService show all
Defined in:
lib/stripe/services/v2/core/account_link_service.rb

Defined Under Namespace

Classes: CreateParams

Instance Method Summary collapse

Methods inherited from StripeService

#initialize, #request, #request_stream

Constructor Details

This class inherits a constructor from Stripe::StripeService

Instance Method Details

#create(params = {}, opts = {}) ⇒ Object

Creates an AccountLink object that includes a single-use Stripe URL that the merchant can redirect their user to in order to take them to a Stripe-hosted application such as Recipient Onboarding.



64
65
66
67
68
69
70
71
72
# File 'lib/stripe/services/v2/core/account_link_service.rb', line 64

def create(params = {}, opts = {})
  request(
    method: :post,
    path: "/v2/core/account_links",
    params: params,
    opts: opts,
    base_address: :api
  )
end