Class: Stripe::V2::Core::AccountLinkService::CreateParams::UseCase::AccountOnboarding

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/core/account_link_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(configurations: nil, refresh_url: nil, return_url: nil) ⇒ AccountOnboarding

Returns a new instance of AccountOnboarding.



18
19
20
21
22
# File 'lib/stripe/services/v2/core/account_link_service.rb', line 18

def initialize(configurations: nil, refresh_url: nil, return_url: nil)
  @configurations = configurations
  @refresh_url = refresh_url
  @return_url = return_url
end

Instance Attribute Details

#configurationsObject

Open Enum. A v2/account can be configured to enable certain functionality. The configuration param targets the v2/account_link to collect information for the specified v2/account configuration/s.



12
13
14
# File 'lib/stripe/services/v2/core/account_link_service.rb', line 12

def configurations
  @configurations
end

#refresh_urlObject

The URL the user will be redirected to if the AccountLink is expired, has been used, or is otherwise invalid. The URL you specify should attempt to generate a new AccountLink with the same parameters used to create the original AccountLink, then redirect the user to the new AccountLink’s URL so they can continue the flow. If a new AccountLink cannot be generated or the redirect fails you should display a useful error to the user. Please make sure to implement authentication before redirecting the user in case this URL is leaked to a third party.



14
15
16
# File 'lib/stripe/services/v2/core/account_link_service.rb', line 14

def refresh_url
  @refresh_url
end

#return_urlObject

The URL that the user will be redirected to upon completing the linked flow.



16
17
18
# File 'lib/stripe/services/v2/core/account_link_service.rb', line 16

def return_url
  @return_url
end