Class: Stripe::V2::Core::AccountListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/v2/core/account_list_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(applied_configurations: nil, closed: nil, limit: nil, related_network_object: nil) ⇒ AccountListParams

Returns a new instance of AccountListParams.



17
18
19
20
21
22
23
24
25
26
27
# File 'lib/stripe/params/v2/core/account_list_params.rb', line 17

def initialize(
  applied_configurations: nil,
  closed: nil,
  limit: nil,
  related_network_object: nil
)
  @applied_configurations = applied_configurations
  @closed = closed
  @limit = limit
  @related_network_object = related_network_object
end

Instance Attribute Details

#applied_configurationsObject

Filter only accounts that have all of the configurations specified. If omitted, returns all accounts regardless of which configurations they have.



9
10
11
# File 'lib/stripe/params/v2/core/account_list_params.rb', line 9

def applied_configurations
  @applied_configurations
end

#closedObject

Filter by whether the account is closed. If omitted, returns only Accounts that are not closed.



11
12
13
# File 'lib/stripe/params/v2/core/account_list_params.rb', line 11

def closed
  @closed
end

#limitObject

The upper limit on the number of accounts returned by the List Account request.



13
14
15
# File 'lib/stripe/params/v2/core/account_list_params.rb', line 13

def limit
  @limit
end

Filter by the network object related to the account. If omitted, returns all Accounts regardless of the network object they have.



15
16
17
# File 'lib/stripe/params/v2/core/account_list_params.rb', line 15

def related_network_object
  @related_network_object
end