Class: Stripe::V2::Core::AccountService::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/core/account_service.rb

Defined Under Namespace

Classes: Configuration, Defaults, Identity

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(configuration: nil, contact_email: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



2209
2210
2211
2212
2213
2214
2215
2216
2217
2218
2219
2220
2221
2222
2223
2224
2225
2226
2227
# File 'lib/stripe/services/v2/core/account_service.rb', line 2209

def initialize(
  configuration: nil,
  contact_email: nil,
  dashboard: nil,
  defaults: nil,
  display_name: nil,
  identity: nil,
  include: nil,
  metadata: nil
)
  @configuration = configuration
  @contact_email = contact_email
  @dashboard = dashboard
  @defaults = defaults
  @display_name = display_name
  @identity = identity
  @include = include
  @metadata = 
end

Instance Attribute Details

#configurationObject

An Account Configuration which allows the Account to take on a key persona across Stripe products.



2193
2194
2195
# File 'lib/stripe/services/v2/core/account_service.rb', line 2193

def configuration
  @configuration
end

#contact_emailObject

The default contact email address for the Account. Required when configuring the account as a merchant or recipient.



2195
2196
2197
# File 'lib/stripe/services/v2/core/account_service.rb', line 2195

def contact_email
  @contact_email
end

#dashboardObject

A value indicating the Stripe dashboard this Account has access to. This will depend on which configurations are enabled for this account.



2197
2198
2199
# File 'lib/stripe/services/v2/core/account_service.rb', line 2197

def dashboard
  @dashboard
end

#defaultsObject

Default values to be used on Account Configurations.



2199
2200
2201
# File 'lib/stripe/services/v2/core/account_service.rb', line 2199

def defaults
  @defaults
end

#display_nameObject

A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.



2201
2202
2203
# File 'lib/stripe/services/v2/core/account_service.rb', line 2201

def display_name
  @display_name
end

#identityObject

Information about the company, individual, and business represented by the Account.



2203
2204
2205
# File 'lib/stripe/services/v2/core/account_service.rb', line 2203

def identity
  @identity
end

#includeObject

Additional fields to include in the response.



2205
2206
2207
# File 'lib/stripe/services/v2/core/account_service.rb', line 2205

def include
  @include
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



2207
2208
2209
# File 'lib/stripe/services/v2/core/account_service.rb', line 2207

def 
  @metadata
end