Class: Stripe::V2::Core::AccountService::CreateParams::Configuration::Recipient::Capabilities
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountService::CreateParams::Configuration::Recipient::Capabilities
- Defined in:
- lib/stripe/services/v2/core/account_service.rb
Defined Under Namespace
Classes: BankAccounts, Cards, StripeBalance
Instance Attribute Summary collapse
-
#bank_accounts ⇒ Object
Capabilities that enable OutboundPayments to a bank account linked to this Account.
-
#cards ⇒ Object
Capabilities that enable OutboundPayments to a card linked to this Account.
-
#stripe_balance ⇒ Object
Capabilities that enable the recipient to manage their Stripe Balance (/v1/balance).
Instance Method Summary collapse
-
#initialize(bank_accounts: nil, cards: nil, stripe_balance: nil) ⇒ Capabilities
constructor
A new instance of Capabilities.
Methods inherited from RequestParams
Constructor Details
#initialize(bank_accounts: nil, cards: nil, stripe_balance: nil) ⇒ Capabilities
Returns a new instance of Capabilities.
973 974 975 976 977 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 973 def initialize(bank_accounts: nil, cards: nil, stripe_balance: nil) @bank_accounts = bank_accounts @cards = cards @stripe_balance = stripe_balance end |
Instance Attribute Details
#bank_accounts ⇒ Object
Capabilities that enable OutboundPayments to a bank account linked to this Account.
967 968 969 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 967 def bank_accounts @bank_accounts end |
#cards ⇒ Object
Capabilities that enable OutboundPayments to a card linked to this Account.
969 970 971 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 969 def cards @cards end |
#stripe_balance ⇒ Object
Capabilities that enable the recipient to manage their Stripe Balance (/v1/balance).
971 972 973 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 971 def stripe_balance @stripe_balance end |