Class: Stripe::V2::Core::AccountService::CreateParams::Identity
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountService::CreateParams::Identity
- Defined in:
- lib/stripe/services/v2/core/account_service.rb
Defined Under Namespace
Classes: Attestations, BusinessDetails, Individual
Instance Attribute Summary collapse
-
#attestations ⇒ Object
Attestations from the identity’s key people, e.g.
-
#business_details ⇒ Object
Information about the company or business.
-
#country ⇒ Object
The country in which the account holder resides, or in which the business is legally established.
-
#entity_type ⇒ Object
The entity type.
-
#individual ⇒ Object
Information about the person represented by the account.
Instance Method Summary collapse
-
#initialize(attestations: nil, business_details: nil, country: nil, entity_type: nil, individual: nil) ⇒ Identity
constructor
A new instance of Identity.
Methods inherited from RequestParams
Constructor Details
#initialize(attestations: nil, business_details: nil, country: nil, entity_type: nil, individual: nil) ⇒ Identity
Returns a new instance of Identity.
2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 2160 def initialize( attestations: nil, business_details: nil, country: nil, entity_type: nil, individual: nil ) @attestations = attestations @business_details = business_details @country = country @entity_type = entity_type @individual = individual end |
Instance Attribute Details
#attestations ⇒ Object
Attestations from the identity’s key people, e.g. owners, executives, directors.
2150 2151 2152 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 2150 def attestations @attestations end |
#business_details ⇒ Object
Information about the company or business.
2152 2153 2154 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 2152 def business_details @business_details end |
#country ⇒ Object
The country in which the account holder resides, or in which the business is legally established. This should be an [ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2) country code.
2154 2155 2156 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 2154 def country @country end |
#entity_type ⇒ Object
The entity type.
2156 2157 2158 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 2156 def entity_type @entity_type end |
#individual ⇒ Object
Information about the person represented by the account.
2158 2159 2160 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 2158 def individual @individual end |