Class: Stripe::V2::Core::AccountService::CreateParams::Identity::Attestations

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/core/account_service.rb

Defined Under Namespace

Classes: DirectorshipDeclaration, OwnershipDeclaration, PersonsProvided, TermsOfService

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(directorship_declaration: nil, ownership_declaration: nil, persons_provided: nil, terms_of_service: nil) ⇒ Attestations

Returns a new instance of Attestations.



1291
1292
1293
1294
1295
1296
1297
1298
1299
1300
1301
# File 'lib/stripe/services/v2/core/account_service.rb', line 1291

def initialize(
  directorship_declaration: nil,
  ownership_declaration: nil,
  persons_provided: nil,
  terms_of_service: nil
)
  @directorship_declaration = directorship_declaration
  @ownership_declaration = ownership_declaration
  @persons_provided = persons_provided
  @terms_of_service = terms_of_service
end

Instance Attribute Details

#directorship_declarationObject

This hash is used to attest that the directors information provided to Stripe is both current and correct.



1283
1284
1285
# File 'lib/stripe/services/v2/core/account_service.rb', line 1283

def directorship_declaration
  @directorship_declaration
end

#ownership_declarationObject

This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.



1285
1286
1287
# File 'lib/stripe/services/v2/core/account_service.rb', line 1285

def ownership_declaration
  @ownership_declaration
end

#persons_providedObject

Attestation that all Persons with a specific Relationship value have been provided.



1287
1288
1289
# File 'lib/stripe/services/v2/core/account_service.rb', line 1287

def persons_provided
  @persons_provided
end

#terms_of_serviceObject

Attestations of accepted terms of service agreements.



1289
1290
1291
# File 'lib/stripe/services/v2/core/account_service.rb', line 1289

def terms_of_service
  @terms_of_service
end