Class: Stripe::V2::Core::AccountService::CreateParams::Identity::BusinessDetails::AnnualRevenue

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/core/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, fiscal_year_end: nil) ⇒ AnnualRevenue

Returns a new instance of AnnualRevenue.



1346
1347
1348
1349
# File 'lib/stripe/services/v2/core/account_service.rb', line 1346

def initialize(amount: nil, fiscal_year_end: nil)
  @amount = amount
  @fiscal_year_end = fiscal_year_end
end

Instance Attribute Details

#amountObject

A non-negative integer representing the amount in the smallest currency unit.



1342
1343
1344
# File 'lib/stripe/services/v2/core/account_service.rb', line 1342

def amount
  @amount
end

#fiscal_year_endObject

The close-out date of the preceding fiscal year in ISO 8601 format. E.g. 2023-12-31 for the 31st of December, 2023.



1344
1345
1346
# File 'lib/stripe/services/v2/core/account_service.rb', line 1344

def fiscal_year_end
  @fiscal_year_end
end