Class: Stripe::V2::Core::AccountService::CreateParams::Identity::Individual::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/core/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship

Returns a new instance of Relationship.



1964
1965
1966
1967
1968
1969
1970
1971
1972
1973
1974
1975
1976
# File 'lib/stripe/services/v2/core/account_service.rb', line 1964

def initialize(
  director: nil,
  executive: nil,
  owner: nil,
  percent_ownership: nil,
  title: nil
)
  @director = director
  @executive = executive
  @owner = owner
  @percent_ownership = percent_ownership
  @title = title
end

Instance Attribute Details

#directorObject

Whether the person is a director of the account’s identity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



1954
1955
1956
# File 'lib/stripe/services/v2/core/account_service.rb', line 1954

def director
  @director
end

#executiveObject

Whether the person has significant responsibility to control, manage, or direct the organization.



1956
1957
1958
# File 'lib/stripe/services/v2/core/account_service.rb', line 1956

def executive
  @executive
end

#ownerObject

Whether the person is an owner of the account’s identity.



1958
1959
1960
# File 'lib/stripe/services/v2/core/account_service.rb', line 1958

def owner
  @owner
end

#percent_ownershipObject

The percent owned by the person of the account’s legal entity.



1960
1961
1962
# File 'lib/stripe/services/v2/core/account_service.rb', line 1960

def percent_ownership
  @percent_ownership
end

#titleObject

The person’s title (e.g., CEO, Support Engineer).



1962
1963
1964
# File 'lib/stripe/services/v2/core/account_service.rb', line 1962

def title
  @title
end