Class: Stripe::V2::Core::AccountService::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountService::ListParams
- Defined in:
- lib/stripe/services/v2/core/account_service.rb
Instance Attribute Summary collapse
-
#applied_configurations ⇒ Object
Filter only accounts that have all of the configurations specified.
-
#limit ⇒ Object
The upper limit on the number of accounts returned by the List Account request.
Instance Method Summary collapse
-
#initialize(applied_configurations: nil, limit: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(applied_configurations: nil, limit: nil) ⇒ ListParams
Returns a new instance of ListParams.
21 22 23 24 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 21 def initialize(applied_configurations: nil, limit: nil) @applied_configurations = applied_configurations @limit = limit end |
Instance Attribute Details
#applied_configurations ⇒ Object
Filter only accounts that have all of the configurations specified. If omitted, returns all accounts regardless of which configurations they have.
17 18 19 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 17 def applied_configurations @applied_configurations end |
#limit ⇒ Object
The upper limit on the number of accounts returned by the List Account request.
19 20 21 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 19 def limit @limit end |