Class: Stripe::V2::Core::AccountService::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/core/account_service.rb

Defined Under Namespace

Classes: Configuration, Defaults, Identity

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(configuration: nil, contact_email: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



4449
4450
4451
4452
4453
4454
4455
4456
4457
4458
4459
4460
4461
4462
4463
4464
4465
4466
4467
# File 'lib/stripe/services/v2/core/account_service.rb', line 4449

def initialize(
  configuration: nil,
  contact_email: nil,
  dashboard: nil,
  defaults: nil,
  display_name: nil,
  identity: nil,
  include: nil,
  metadata: nil
)
  @configuration = configuration
  @contact_email = contact_email
  @dashboard = dashboard
  @defaults = defaults
  @display_name = display_name
  @identity = identity
  @include = include
  @metadata = 
end

Instance Attribute Details

#configurationObject

An Account Configuration which allows the Account to take on a key persona across Stripe products.



4433
4434
4435
# File 'lib/stripe/services/v2/core/account_service.rb', line 4433

def configuration
  @configuration
end

#contact_emailObject

The default contact email address for the Account. Required when configuring the account as a merchant or recipient.



4435
4436
4437
# File 'lib/stripe/services/v2/core/account_service.rb', line 4435

def contact_email
  @contact_email
end

#dashboardObject

A value indicating the Stripe dashboard this Account has access to. This will depend on which configurations are enabled for this account.



4437
4438
4439
# File 'lib/stripe/services/v2/core/account_service.rb', line 4437

def dashboard
  @dashboard
end

#defaultsObject

Default values to be used on Account Configurations.



4439
4440
4441
# File 'lib/stripe/services/v2/core/account_service.rb', line 4439

def defaults
  @defaults
end

#display_nameObject

A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.



4441
4442
4443
# File 'lib/stripe/services/v2/core/account_service.rb', line 4441

def display_name
  @display_name
end

#identityObject

Information about the company, individual, and business represented by the Account.



4443
4444
4445
# File 'lib/stripe/services/v2/core/account_service.rb', line 4443

def identity
  @identity
end

#includeObject

Additional fields to include in the response.



4445
4446
4447
# File 'lib/stripe/services/v2/core/account_service.rb', line 4445

def include
  @include
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



4447
4448
4449
# File 'lib/stripe/services/v2/core/account_service.rb', line 4447

def 
  @metadata
end