Class: Stripe::V2::Core::AccountService::UpdateParams::Configuration::Customer::AutomaticIndirectTax
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountService::UpdateParams::Configuration::Customer::AutomaticIndirectTax
- Defined in:
- lib/stripe/services/v2/core/account_service.rb
Instance Attribute Summary collapse
-
#exempt ⇒ Object
Describes the customer’s tax exemption status, which is ‘none`, `exempt`, or `reverse`.
-
#ip_address ⇒ Object
A recent IP address of the customer used for tax reporting and tax location inference.
-
#location_source ⇒ Object
The data source used to identify the customer’s tax location - defaults to ‘identity_address’.
-
#validate_location ⇒ Object
A per-request flag that indicates when Stripe should validate the customer tax location - defaults to ‘auto’.
Instance Method Summary collapse
-
#initialize(exempt: nil, ip_address: nil, location_source: nil, validate_location: nil) ⇒ AutomaticIndirectTax
constructor
A new instance of AutomaticIndirectTax.
Methods inherited from RequestParams
Constructor Details
#initialize(exempt: nil, ip_address: nil, location_source: nil, validate_location: nil) ⇒ AutomaticIndirectTax
Returns a new instance of AutomaticIndirectTax.
2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 2262 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 2252 def initialize( exempt: nil, ip_address: nil, location_source: nil, validate_location: nil ) @exempt = exempt @ip_address = ip_address @location_source = location_source @validate_location = validate_location end |
Instance Attribute Details
#exempt ⇒ Object
Describes the customer’s tax exemption status, which is ‘none`, `exempt`, or `reverse`. When set to reverse, invoice and receipt PDFs include the following text: “Reverse charge”.
2244 2245 2246 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 2244 def exempt @exempt end |
#ip_address ⇒ Object
A recent IP address of the customer used for tax reporting and tax location inference.
2246 2247 2248 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 2246 def ip_address @ip_address end |
#location_source ⇒ Object
The data source used to identify the customer’s tax location - defaults to ‘identity_address’. Will only be used for automatic tax calculation on the customer’s Invoices and Subscriptions.
2248 2249 2250 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 2248 def location_source @location_source end |
#validate_location ⇒ Object
A per-request flag that indicates when Stripe should validate the customer tax location - defaults to ‘auto’.
2250 2251 2252 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 2250 def validate_location @validate_location end |