Class: Stripe::V2::Core::AccountService::UpdateParams::Configuration::Customer::Billing
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountService::UpdateParams::Configuration::Customer::Billing
- Defined in:
- lib/stripe/services/v2/core/account_service.rb
Defined Under Namespace
Classes: Invoice
Instance Attribute Summary collapse
-
#default_payment_method ⇒ Object
ID of a payment method that’s attached to the customer, to be used as the customer’s default payment method for invoices and subscriptions.
-
#invoice ⇒ Object
Default settings used on invoices for this customer.
Instance Method Summary collapse
-
#initialize(default_payment_method: nil, invoice: nil) ⇒ Billing
constructor
A new instance of Billing.
Methods inherited from RequestParams
Constructor Details
#initialize(default_payment_method: nil, invoice: nil) ⇒ Billing
Returns a new instance of Billing.
2302 2303 2304 2305 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 2302 def initialize(default_payment_method: nil, invoice: nil) @default_payment_method = default_payment_method @invoice = invoice end |
Instance Attribute Details
#default_payment_method ⇒ Object
ID of a payment method that’s attached to the customer, to be used as the customer’s default payment method for invoices and subscriptions.
2298 2299 2300 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 2298 def default_payment_method @default_payment_method end |
#invoice ⇒ Object
Default settings used on invoices for this customer.
2300 2301 2302 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 2300 def invoice @invoice end |