Class: Stripe::V2::Core::AccountService::UpdateParams::Configuration::Merchant::Capabilities

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/core/account_service.rb

Defined Under Namespace

Classes: AchDebitPayments, AcssDebitPayments, AffirmPayments, AfterpayClearpayPayments, AlmaPayments, AmazonPayPayments, AuBecsDebitPayments, BacsDebitPayments, BancontactPayments, BlikPayments, BoletoPayments, CardPayments, CartesBancairesPayments, CashappPayments, EpsPayments, FpxPayments, GbBankTransferPayments, GrabpayPayments, IdealPayments, JcbPayments, JpBankTransferPayments, KakaoPayPayments, KlarnaPayments, KonbiniPayments, KrCardPayments, LinkPayments, MobilepayPayments, MultibancoPayments, MxBankTransferPayments, NaverPayPayments, OxxoPayments, P24Payments, PayByBankPayments, PaycoPayments, PaynowPayments, PromptpayPayments, RevolutPayPayments, SamsungPayPayments, SepaBankTransferPayments, SepaDebitPayments, SwishPayments, TwintPayments, UsBankTransferPayments, ZipPayments

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(ach_debit_payments: nil, acss_debit_payments: nil, affirm_payments: nil, afterpay_clearpay_payments: nil, alma_payments: nil, amazon_pay_payments: nil, au_becs_debit_payments: nil, bacs_debit_payments: nil, bancontact_payments: nil, blik_payments: nil, boleto_payments: nil, card_payments: nil, cartes_bancaires_payments: nil, cashapp_payments: nil, eps_payments: nil, fpx_payments: nil, gb_bank_transfer_payments: nil, grabpay_payments: nil, ideal_payments: nil, jcb_payments: nil, jp_bank_transfer_payments: nil, kakao_pay_payments: nil, klarna_payments: nil, konbini_payments: nil, kr_card_payments: nil, link_payments: nil, mobilepay_payments: nil, multibanco_payments: nil, mx_bank_transfer_payments: nil, naver_pay_payments: nil, oxxo_payments: nil, p24_payments: nil, pay_by_bank_payments: nil, payco_payments: nil, paynow_payments: nil, promptpay_payments: nil, revolut_pay_payments: nil, samsung_pay_payments: nil, sepa_bank_transfer_payments: nil, sepa_debit_payments: nil, swish_payments: nil, twint_payments: nil, us_bank_transfer_payments: nil, zip_payments: nil) ⇒ Capabilities

Returns a new instance of Capabilities.



2750
2751
2752
2753
2754
2755
2756
2757
2758
2759
2760
2761
2762
2763
2764
2765
2766
2767
2768
2769
2770
2771
2772
2773
2774
2775
2776
2777
2778
2779
2780
2781
2782
2783
2784
2785
2786
2787
2788
2789
2790
2791
2792
2793
2794
2795
2796
2797
2798
2799
2800
2801
2802
2803
2804
2805
2806
2807
2808
2809
2810
2811
2812
2813
2814
2815
2816
2817
2818
2819
2820
2821
2822
2823
2824
2825
2826
2827
2828
2829
2830
2831
2832
2833
2834
2835
2836
2837
2838
2839
2840
# File 'lib/stripe/services/v2/core/account_service.rb', line 2750

def initialize(
  ach_debit_payments: nil,
  acss_debit_payments: nil,
  affirm_payments: nil,
  afterpay_clearpay_payments: nil,
  alma_payments: nil,
  amazon_pay_payments: nil,
  au_becs_debit_payments: nil,
  bacs_debit_payments: nil,
  bancontact_payments: nil,
  blik_payments: nil,
  boleto_payments: nil,
  card_payments: nil,
  cartes_bancaires_payments: nil,
  cashapp_payments: nil,
  eps_payments: nil,
  fpx_payments: nil,
  gb_bank_transfer_payments: nil,
  grabpay_payments: nil,
  ideal_payments: nil,
  jcb_payments: nil,
  jp_bank_transfer_payments: nil,
  kakao_pay_payments: nil,
  klarna_payments: nil,
  konbini_payments: nil,
  kr_card_payments: nil,
  link_payments: nil,
  mobilepay_payments: nil,
  multibanco_payments: nil,
  mx_bank_transfer_payments: nil,
  naver_pay_payments: nil,
  oxxo_payments: nil,
  p24_payments: nil,
  pay_by_bank_payments: nil,
  payco_payments: nil,
  paynow_payments: nil,
  promptpay_payments: nil,
  revolut_pay_payments: nil,
  samsung_pay_payments: nil,
  sepa_bank_transfer_payments: nil,
  sepa_debit_payments: nil,
  swish_payments: nil,
  twint_payments: nil,
  us_bank_transfer_payments: nil,
  zip_payments: nil
)
  @ach_debit_payments = ach_debit_payments
  @acss_debit_payments = acss_debit_payments
  @affirm_payments = affirm_payments
  @afterpay_clearpay_payments = afterpay_clearpay_payments
  @alma_payments = alma_payments
  @amazon_pay_payments = amazon_pay_payments
  @au_becs_debit_payments = au_becs_debit_payments
  @bacs_debit_payments = bacs_debit_payments
  @bancontact_payments = bancontact_payments
  @blik_payments = blik_payments
  @boleto_payments = boleto_payments
  @card_payments = card_payments
  @cartes_bancaires_payments = cartes_bancaires_payments
  @cashapp_payments = cashapp_payments
  @eps_payments = eps_payments
  @fpx_payments = fpx_payments
  @gb_bank_transfer_payments = gb_bank_transfer_payments
  @grabpay_payments = grabpay_payments
  @ideal_payments = ideal_payments
  @jcb_payments = jcb_payments
  @jp_bank_transfer_payments = jp_bank_transfer_payments
  @kakao_pay_payments = kakao_pay_payments
  @klarna_payments = klarna_payments
  @konbini_payments = konbini_payments
  @kr_card_payments = kr_card_payments
  @link_payments = link_payments
  @mobilepay_payments = mobilepay_payments
  @multibanco_payments = multibanco_payments
  @mx_bank_transfer_payments = mx_bank_transfer_payments
  @naver_pay_payments = naver_pay_payments
  @oxxo_payments = oxxo_payments
  @p24_payments = p24_payments
  @pay_by_bank_payments = pay_by_bank_payments
  @payco_payments = payco_payments
  @paynow_payments = paynow_payments
  @promptpay_payments = promptpay_payments
  @revolut_pay_payments = revolut_pay_payments
  @samsung_pay_payments = samsung_pay_payments
  @sepa_bank_transfer_payments = sepa_bank_transfer_payments
  @sepa_debit_payments = sepa_debit_payments
  @swish_payments = swish_payments
  @twint_payments = twint_payments
  @us_bank_transfer_payments = us_bank_transfer_payments
  @zip_payments = zip_payments
end

Instance Attribute Details

#ach_debit_paymentsObject

Allow the merchant to process ACH debit payments.



2662
2663
2664
# File 'lib/stripe/services/v2/core/account_service.rb', line 2662

def ach_debit_payments
  @ach_debit_payments
end

#acss_debit_paymentsObject

Allow the merchant to process ACSS debit payments.



2664
2665
2666
# File 'lib/stripe/services/v2/core/account_service.rb', line 2664

def acss_debit_payments
  @acss_debit_payments
end

#affirm_paymentsObject

Allow the merchant to process Affirm payments.



2666
2667
2668
# File 'lib/stripe/services/v2/core/account_service.rb', line 2666

def affirm_payments
  @affirm_payments
end

#afterpay_clearpay_paymentsObject

Allow the merchant to process Afterpay/Clearpay payments.



2668
2669
2670
# File 'lib/stripe/services/v2/core/account_service.rb', line 2668

def afterpay_clearpay_payments
  @afterpay_clearpay_payments
end

#alma_paymentsObject

Allow the merchant to process Alma payments.



2670
2671
2672
# File 'lib/stripe/services/v2/core/account_service.rb', line 2670

def alma_payments
  @alma_payments
end

#amazon_pay_paymentsObject

Allow the merchant to process Amazon Pay payments.



2672
2673
2674
# File 'lib/stripe/services/v2/core/account_service.rb', line 2672

def amazon_pay_payments
  @amazon_pay_payments
end

#au_becs_debit_paymentsObject

Allow the merchant to process Australian BECS Direct Debit payments.



2674
2675
2676
# File 'lib/stripe/services/v2/core/account_service.rb', line 2674

def au_becs_debit_payments
  @au_becs_debit_payments
end

#bacs_debit_paymentsObject

Allow the merchant to process BACS Direct Debit payments.



2676
2677
2678
# File 'lib/stripe/services/v2/core/account_service.rb', line 2676

def bacs_debit_payments
  @bacs_debit_payments
end

#bancontact_paymentsObject

Allow the merchant to process Bancontact payments.



2678
2679
2680
# File 'lib/stripe/services/v2/core/account_service.rb', line 2678

def bancontact_payments
  @bancontact_payments
end

#blik_paymentsObject

Allow the merchant to process BLIK payments.



2680
2681
2682
# File 'lib/stripe/services/v2/core/account_service.rb', line 2680

def blik_payments
  @blik_payments
end

#boleto_paymentsObject

Allow the merchant to process Boleto payments.



2682
2683
2684
# File 'lib/stripe/services/v2/core/account_service.rb', line 2682

def boleto_payments
  @boleto_payments
end

#card_paymentsObject

Allow the merchant to collect card payments.



2684
2685
2686
# File 'lib/stripe/services/v2/core/account_service.rb', line 2684

def card_payments
  @card_payments
end

#cartes_bancaires_paymentsObject

Allow the merchant to process Cartes Bancaires payments.



2686
2687
2688
# File 'lib/stripe/services/v2/core/account_service.rb', line 2686

def cartes_bancaires_payments
  @cartes_bancaires_payments
end

#cashapp_paymentsObject

Allow the merchant to process Cash App payments.



2688
2689
2690
# File 'lib/stripe/services/v2/core/account_service.rb', line 2688

def cashapp_payments
  @cashapp_payments
end

#eps_paymentsObject

Allow the merchant to process EPS payments.



2690
2691
2692
# File 'lib/stripe/services/v2/core/account_service.rb', line 2690

def eps_payments
  @eps_payments
end

#fpx_paymentsObject

Allow the merchant to process FPX payments.



2692
2693
2694
# File 'lib/stripe/services/v2/core/account_service.rb', line 2692

def fpx_payments
  @fpx_payments
end

#gb_bank_transfer_paymentsObject

Allow the merchant to process UK bank transfer payments.



2694
2695
2696
# File 'lib/stripe/services/v2/core/account_service.rb', line 2694

def gb_bank_transfer_payments
  @gb_bank_transfer_payments
end

#grabpay_paymentsObject

Allow the merchant to process GrabPay payments.



2696
2697
2698
# File 'lib/stripe/services/v2/core/account_service.rb', line 2696

def grabpay_payments
  @grabpay_payments
end

#ideal_paymentsObject

Allow the merchant to process iDEAL payments.



2698
2699
2700
# File 'lib/stripe/services/v2/core/account_service.rb', line 2698

def ideal_payments
  @ideal_payments
end

#jcb_paymentsObject

Allow the merchant to process JCB card payments.



2700
2701
2702
# File 'lib/stripe/services/v2/core/account_service.rb', line 2700

def jcb_payments
  @jcb_payments
end

#jp_bank_transfer_paymentsObject

Allow the merchant to process Japanese bank transfer payments.



2702
2703
2704
# File 'lib/stripe/services/v2/core/account_service.rb', line 2702

def jp_bank_transfer_payments
  @jp_bank_transfer_payments
end

#kakao_pay_paymentsObject

Allow the merchant to process Kakao Pay payments.



2704
2705
2706
# File 'lib/stripe/services/v2/core/account_service.rb', line 2704

def kakao_pay_payments
  @kakao_pay_payments
end

#klarna_paymentsObject

Allow the merchant to process Klarna payments.



2706
2707
2708
# File 'lib/stripe/services/v2/core/account_service.rb', line 2706

def klarna_payments
  @klarna_payments
end

#konbini_paymentsObject

Allow the merchant to process Konbini convenience store payments.



2708
2709
2710
# File 'lib/stripe/services/v2/core/account_service.rb', line 2708

def konbini_payments
  @konbini_payments
end

#kr_card_paymentsObject

Allow the merchant to process Korean card payments.



2710
2711
2712
# File 'lib/stripe/services/v2/core/account_service.rb', line 2710

def kr_card_payments
  @kr_card_payments
end

Allow the merchant to process Link payments.



2712
2713
2714
# File 'lib/stripe/services/v2/core/account_service.rb', line 2712

def link_payments
  @link_payments
end

#mobilepay_paymentsObject

Allow the merchant to process MobilePay payments.



2714
2715
2716
# File 'lib/stripe/services/v2/core/account_service.rb', line 2714

def mobilepay_payments
  @mobilepay_payments
end

#multibanco_paymentsObject

Allow the merchant to process Multibanco payments.



2716
2717
2718
# File 'lib/stripe/services/v2/core/account_service.rb', line 2716

def multibanco_payments
  @multibanco_payments
end

#mx_bank_transfer_paymentsObject

Allow the merchant to process Mexican bank transfer payments.



2718
2719
2720
# File 'lib/stripe/services/v2/core/account_service.rb', line 2718

def mx_bank_transfer_payments
  @mx_bank_transfer_payments
end

Allow the merchant to process Naver Pay payments.



2720
2721
2722
# File 'lib/stripe/services/v2/core/account_service.rb', line 2720

def naver_pay_payments
  @naver_pay_payments
end

#oxxo_paymentsObject

Allow the merchant to process OXXO payments.



2722
2723
2724
# File 'lib/stripe/services/v2/core/account_service.rb', line 2722

def oxxo_payments
  @oxxo_payments
end

#p24_paymentsObject

Allow the merchant to process Przelewy24 (P24) payments.



2724
2725
2726
# File 'lib/stripe/services/v2/core/account_service.rb', line 2724

def p24_payments
  @p24_payments
end

#pay_by_bank_paymentsObject

Allow the merchant to process Pay by Bank payments.



2726
2727
2728
# File 'lib/stripe/services/v2/core/account_service.rb', line 2726

def pay_by_bank_payments
  @pay_by_bank_payments
end

#payco_paymentsObject

Allow the merchant to process PAYCO payments.



2728
2729
2730
# File 'lib/stripe/services/v2/core/account_service.rb', line 2728

def payco_payments
  @payco_payments
end

#paynow_paymentsObject

Allow the merchant to process PayNow payments.



2730
2731
2732
# File 'lib/stripe/services/v2/core/account_service.rb', line 2730

def paynow_payments
  @paynow_payments
end

#promptpay_paymentsObject

Allow the merchant to process PromptPay payments.



2732
2733
2734
# File 'lib/stripe/services/v2/core/account_service.rb', line 2732

def promptpay_payments
  @promptpay_payments
end

#revolut_pay_paymentsObject

Allow the merchant to process Revolut Pay payments.



2734
2735
2736
# File 'lib/stripe/services/v2/core/account_service.rb', line 2734

def revolut_pay_payments
  @revolut_pay_payments
end

#samsung_pay_paymentsObject

Allow the merchant to process Samsung Pay payments.



2736
2737
2738
# File 'lib/stripe/services/v2/core/account_service.rb', line 2736

def samsung_pay_payments
  @samsung_pay_payments
end

#sepa_bank_transfer_paymentsObject

Allow the merchant to process SEPA bank transfer payments.



2738
2739
2740
# File 'lib/stripe/services/v2/core/account_service.rb', line 2738

def sepa_bank_transfer_payments
  @sepa_bank_transfer_payments
end

#sepa_debit_paymentsObject

Allow the merchant to process SEPA Direct Debit payments.



2740
2741
2742
# File 'lib/stripe/services/v2/core/account_service.rb', line 2740

def sepa_debit_payments
  @sepa_debit_payments
end

#swish_paymentsObject

Allow the merchant to process Swish payments.



2742
2743
2744
# File 'lib/stripe/services/v2/core/account_service.rb', line 2742

def swish_payments
  @swish_payments
end

#twint_paymentsObject

Allow the merchant to process TWINT payments.



2744
2745
2746
# File 'lib/stripe/services/v2/core/account_service.rb', line 2744

def twint_payments
  @twint_payments
end

#us_bank_transfer_paymentsObject

Allow the merchant to process US bank transfer payments.



2746
2747
2748
# File 'lib/stripe/services/v2/core/account_service.rb', line 2746

def us_bank_transfer_payments
  @us_bank_transfer_payments
end

#zip_paymentsObject

Allow the merchant to process Zip payments.



2748
2749
2750
# File 'lib/stripe/services/v2/core/account_service.rb', line 2748

def zip_payments
  @zip_payments
end