Class: Stripe::V2::Core::AccountService::UpdateParams::Configuration::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/core/account_service.rb

Defined Under Namespace

Classes: Capabilities

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(applied: nil, capabilities: nil, default_outbound_destination: nil) ⇒ Recipient

Returns a new instance of Recipient.



3220
3221
3222
3223
3224
# File 'lib/stripe/services/v2/core/account_service.rb', line 3220

def initialize(applied: nil, capabilities: nil, default_outbound_destination: nil)
  @applied = applied
  @capabilities = capabilities
  @default_outbound_destination = default_outbound_destination
end

Instance Attribute Details

#appliedObject

Represents the state of the configuration, and can be updated to deactivate or re-apply a configuration.



3214
3215
3216
# File 'lib/stripe/services/v2/core/account_service.rb', line 3214

def applied
  @applied
end

#capabilitiesObject

Capabilities to request on the Recipient Configuration.



3216
3217
3218
# File 'lib/stripe/services/v2/core/account_service.rb', line 3216

def capabilities
  @capabilities
end

#default_outbound_destinationObject

The payout method id to be used as a default outbound destination. This will allow the PayoutMethod to be omitted on OutboundPayments made through API or sending payouts via dashboard. Can also be explicitly set to ‘null` to clear the existing default outbound destination.



3218
3219
3220
# File 'lib/stripe/services/v2/core/account_service.rb', line 3218

def default_outbound_destination
  @default_outbound_destination
end