Class: Stripe::V2::Core::AccountService::UpdateParams::Configuration::Storer
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountService::UpdateParams::Configuration::Storer
- Defined in:
- lib/stripe/services/v2/core/account_service.rb
Defined Under Namespace
Classes: Capabilities
Instance Attribute Summary collapse
-
#applied ⇒ Object
Represents the state of the configuration, and can be updated to deactivate or re-apply a configuration.
-
#capabilities ⇒ Object
Capabilities to request on the Storer Configuration.
Instance Method Summary collapse
-
#initialize(applied: nil, capabilities: nil) ⇒ Storer
constructor
A new instance of Storer.
Methods inherited from RequestParams
Constructor Details
#initialize(applied: nil, capabilities: nil) ⇒ Storer
Returns a new instance of Storer.
3379 3380 3381 3382 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3379 def initialize(applied: nil, capabilities: nil) @applied = applied @capabilities = capabilities end |
Instance Attribute Details
#applied ⇒ Object
Represents the state of the configuration, and can be updated to deactivate or re-apply a configuration.
3375 3376 3377 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3375 def applied @applied end |
#capabilities ⇒ Object
Capabilities to request on the Storer Configuration.
3377 3378 3379 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3377 def capabilities @capabilities end |