Class: Stripe::V2::Core::AccountService::UpdateParams::Identity
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountService::UpdateParams::Identity
- Defined in:
- lib/stripe/services/v2/core/account_service.rb
Defined Under Namespace
Classes: Attestations, BusinessDetails, Individual
Instance Attribute Summary collapse
-
#attestations ⇒ Object
Attestations from the identity’s key people, e.g.
-
#business_details ⇒ Object
Information about the company or business.
-
#country ⇒ Object
The country in which the account holder resides, or in which the business is legally established.
-
#entity_type ⇒ Object
The entity type.
-
#individual ⇒ Object
Information about the individual represented by the Account.
Instance Method Summary collapse
-
#initialize(attestations: nil, business_details: nil, country: nil, entity_type: nil, individual: nil) ⇒ Identity
constructor
A new instance of Identity.
Methods inherited from RequestParams
Constructor Details
#initialize(attestations: nil, business_details: nil, country: nil, entity_type: nil, individual: nil) ⇒ Identity
Returns a new instance of Identity.
4404 4405 4406 4407 4408 4409 4410 4411 4412 4413 4414 4415 4416 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 4404 def initialize( attestations: nil, business_details: nil, country: nil, entity_type: nil, individual: nil ) @attestations = attestations @business_details = business_details @country = country @entity_type = entity_type @individual = individual end |
Instance Attribute Details
#attestations ⇒ Object
Attestations from the identity’s key people, e.g. owners, executives, directors.
4394 4395 4396 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 4394 def attestations @attestations end |
#business_details ⇒ Object
Information about the company or business.
4396 4397 4398 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 4396 def business_details @business_details end |
#country ⇒ Object
The country in which the account holder resides, or in which the business is legally established. This should be an [ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2) country code.
4398 4399 4400 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 4398 def country @country end |
#entity_type ⇒ Object
The entity type.
4400 4401 4402 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 4400 def entity_type @entity_type end |
#individual ⇒ Object
Information about the individual represented by the Account. This property is ‘null` unless `entity_type` is set to `individual`.
4402 4403 4404 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 4402 def individual @individual end |