Class: Stripe::V2::Core::AccountService::UpdateParams::Identity::Attestations

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/core/account_service.rb

Defined Under Namespace

Classes: DirectorshipDeclaration, OwnershipDeclaration, PersonsProvided, TermsOfService

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(directorship_declaration: nil, ownership_declaration: nil, persons_provided: nil, terms_of_service: nil) ⇒ Attestations

Returns a new instance of Attestations.



3531
3532
3533
3534
3535
3536
3537
3538
3539
3540
3541
# File 'lib/stripe/services/v2/core/account_service.rb', line 3531

def initialize(
  directorship_declaration: nil,
  ownership_declaration: nil,
  persons_provided: nil,
  terms_of_service: nil
)
  @directorship_declaration = directorship_declaration
  @ownership_declaration = ownership_declaration
  @persons_provided = persons_provided
  @terms_of_service = terms_of_service
end

Instance Attribute Details

#directorship_declarationObject

This hash is used to attest that the directors information provided to Stripe is both current and correct.



3523
3524
3525
# File 'lib/stripe/services/v2/core/account_service.rb', line 3523

def directorship_declaration
  @directorship_declaration
end

#ownership_declarationObject

This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.



3525
3526
3527
# File 'lib/stripe/services/v2/core/account_service.rb', line 3525

def ownership_declaration
  @ownership_declaration
end

#persons_providedObject

Attestation that all Persons with a specific Relationship value have been provided.



3527
3528
3529
# File 'lib/stripe/services/v2/core/account_service.rb', line 3527

def persons_provided
  @persons_provided
end

#terms_of_serviceObject

Attestations of accepted terms of service agreements.



3529
3530
3531
# File 'lib/stripe/services/v2/core/account_service.rb', line 3529

def terms_of_service
  @terms_of_service
end