Class: Stripe::V2::Core::AccountService::UpdateParams::Identity::Attestations::PersonsProvided
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountService::UpdateParams::Identity::Attestations::PersonsProvided
- Defined in:
- lib/stripe/services/v2/core/account_service.rb
Instance Attribute Summary collapse
-
#directors ⇒ Object
Whether the company’s directors have been provided.
-
#executives ⇒ Object
Whether the company’s executives have been provided.
-
#owners ⇒ Object
Whether the company’s owners have been provided.
-
#ownership_exemption_reason ⇒ Object
Reason for why the company is exempt from providing ownership information.
Instance Method Summary collapse
-
#initialize(directors: nil, executives: nil, owners: nil, ownership_exemption_reason: nil) ⇒ PersonsProvided
constructor
A new instance of PersonsProvided.
Methods inherited from RequestParams
Constructor Details
#initialize(directors: nil, executives: nil, owners: nil, ownership_exemption_reason: nil) ⇒ PersonsProvided
Returns a new instance of PersonsProvided.
3455 3456 3457 3458 3459 3460 3461 3462 3463 3464 3465 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3455 def initialize( directors: nil, executives: nil, owners: nil, ownership_exemption_reason: nil ) @directors = directors @executives = executives @owners = owners @ownership_exemption_reason = ownership_exemption_reason end |
Instance Attribute Details
#directors ⇒ Object
Whether the company’s directors have been provided. Set this Boolean to true after creating all the company’s directors with the [Persons API](docs.stripe.com/api/v2/core/accounts/createperson).
3447 3448 3449 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3447 def directors @directors end |
#executives ⇒ Object
Whether the company’s executives have been provided. Set this Boolean to true after creating all the company’s executives with the [Persons API](docs.stripe.com/api/v2/core/accounts/createperson).
3449 3450 3451 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3449 def executives @executives end |
#owners ⇒ Object
Whether the company’s owners have been provided. Set this Boolean to true after creating all the company’s owners with the [Persons API](docs.stripe.com/api/v2/core/accounts/createperson).
3451 3452 3453 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3451 def owners @owners end |
#ownership_exemption_reason ⇒ Object
Reason for why the company is exempt from providing ownership information.
3453 3454 3455 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3453 def ownership_exemption_reason @ownership_exemption_reason end |