Class: Stripe::V2::Core::AccountService::UpdateParams::Identity::BusinessDetails::AnnualRevenue

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/core/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, fiscal_year_end: nil) ⇒ AnnualRevenue

Returns a new instance of AnnualRevenue.



3536
3537
3538
3539
# File 'lib/stripe/services/v2/core/account_service.rb', line 3536

def initialize(amount: nil, fiscal_year_end: nil)
  @amount = amount
  @fiscal_year_end = fiscal_year_end
end

Instance Attribute Details

#amountObject

A non-negative integer representing the amount in the smallest currency unit.



3532
3533
3534
# File 'lib/stripe/services/v2/core/account_service.rb', line 3532

def amount
  @amount
end

#fiscal_year_endObject

The close-out date of the preceding fiscal year in ISO 8601 format. E.g. 2023-12-31 for the 31st of December, 2023.



3534
3535
3536
# File 'lib/stripe/services/v2/core/account_service.rb', line 3534

def fiscal_year_end
  @fiscal_year_end
end