Class: Stripe::V2::Core::AccountService::UpdateParams::Identity::BusinessDetails::MonthlyEstimatedRevenue
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountService::UpdateParams::Identity::BusinessDetails::MonthlyEstimatedRevenue
- Defined in:
- lib/stripe/services/v2/core/account_service.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
A non-negative integer representing the amount in the smallest currency unit.
Instance Method Summary collapse
-
#initialize(amount: nil) ⇒ MonthlyEstimatedRevenue
constructor
A new instance of MonthlyEstimatedRevenue.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil) ⇒ MonthlyEstimatedRevenue
Returns a new instance of MonthlyEstimatedRevenue.
3399 3400 3401 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3399 def initialize(amount: nil) @amount = amount end |
Instance Attribute Details
#amount ⇒ Object
A non-negative integer representing the amount in the smallest currency unit.
3397 3398 3399 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3397 def amount @amount end |