Class: Stripe::V2::Core::AccountService::UpdateParams::Identity::Individual::Documents

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/core/account_service.rb

Defined Under Namespace

Classes: CompanyAuthorization, Passport, PrimaryVerification, SecondaryVerification, Visa

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(company_authorization: nil, passport: nil, primary_verification: nil, secondary_verification: nil, visa: nil) ⇒ Documents

Returns a new instance of Documents.



4165
4166
4167
4168
4169
4170
4171
4172
4173
4174
4175
4176
4177
# File 'lib/stripe/services/v2/core/account_service.rb', line 4165

def initialize(
  company_authorization: nil,
  passport: nil,
  primary_verification: nil,
  secondary_verification: nil,
  visa: nil
)
  @company_authorization = company_authorization
  @passport = passport
  @primary_verification = primary_verification
  @secondary_verification = secondary_verification
  @visa = visa
end

Instance Attribute Details

#company_authorizationObject

One or more documents that demonstrate proof that this person is authorized to represent the company.



4155
4156
4157
# File 'lib/stripe/services/v2/core/account_service.rb', line 4155

def company_authorization
  @company_authorization
end

#passportObject

One or more documents showing the person’s passport page with photo and personal data.



4157
4158
4159
# File 'lib/stripe/services/v2/core/account_service.rb', line 4157

def passport
  @passport
end

#primary_verificationObject

An identifying document showing the person’s name, either a passport or local ID card.



4159
4160
4161
# File 'lib/stripe/services/v2/core/account_service.rb', line 4159

def primary_verification
  @primary_verification
end

#secondary_verificationObject

A document showing address, either a passport, local ID card, or utility bill from a well-known utility company.



4161
4162
4163
# File 'lib/stripe/services/v2/core/account_service.rb', line 4161

def secondary_verification
  @secondary_verification
end

#visaObject

One or more documents showing the person’s visa required for living in the country where they are residing.



4163
4164
4165
# File 'lib/stripe/services/v2/core/account_service.rb', line 4163

def visa
  @visa
end