Class: Stripe::V2::Core::AccountService::UpdateParams::Identity::Individual::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/core/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship

Returns a new instance of Relationship.



4204
4205
4206
4207
4208
4209
4210
4211
4212
4213
4214
4215
4216
# File 'lib/stripe/services/v2/core/account_service.rb', line 4204

def initialize(
  director: nil,
  executive: nil,
  owner: nil,
  percent_ownership: nil,
  title: nil
)
  @director = director
  @executive = executive
  @owner = owner
  @percent_ownership = percent_ownership
  @title = title
end

Instance Attribute Details

#directorObject

Whether the person is a director of the account’s identity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



4194
4195
4196
# File 'lib/stripe/services/v2/core/account_service.rb', line 4194

def director
  @director
end

#executiveObject

Whether the person has significant responsibility to control, manage, or direct the organization.



4196
4197
4198
# File 'lib/stripe/services/v2/core/account_service.rb', line 4196

def executive
  @executive
end

#ownerObject

Whether the person is an owner of the account’s identity.



4198
4199
4200
# File 'lib/stripe/services/v2/core/account_service.rb', line 4198

def owner
  @owner
end

#percent_ownershipObject

The percent owned by the person of the account’s legal entity.



4200
4201
4202
# File 'lib/stripe/services/v2/core/account_service.rb', line 4200

def percent_ownership
  @percent_ownership
end

#titleObject

The person’s title (e.g., CEO, Support Engineer).



4202
4203
4204
# File 'lib/stripe/services/v2/core/account_service.rb', line 4202

def title
  @title
end