Class: Stripe::V2::Core::AccountTokenCreateParams::Identity::Attestations::TermsOfService

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_token_create_params.rb

Defined Under Namespace

Classes: Account, CardCreator, CryptoMoneyManager, MoneyManager

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(account: nil, card_creator: nil, crypto_money_manager: nil, money_manager: nil) ⇒ TermsOfService

Returns a new instance of TermsOfService.



313
314
315
316
317
318
319
320
321
322
323
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 313

def initialize(
  account: nil,
  card_creator: nil,
  crypto_money_manager: nil,
  money_manager: nil
)
  @account = 
  @card_creator = card_creator
  @crypto_money_manager = crypto_money_manager
  @money_manager = money_manager
end

Instance Attribute Details

#accountObject

Details on the Account's acceptance of the [Stripe Services Agreement]; IP, date, and User Agent are expanded by Stripe.



305
306
307
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 305

def 
  @account
end

#card_creatorObject

Details on the Account's acceptance of Issuing-specific terms of service.



307
308
309
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 307

def card_creator
  @card_creator
end

#crypto_money_managerObject

Details on the Account's acceptance of Crypto-specific terms of service; IP, date, and User Agent are expanded by Stripe.



309
310
311
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 309

def crypto_money_manager
  @crypto_money_manager
end

#money_managerObject

Details on the Account's acceptance of Treasury-specific terms of service; IP, date, and User Agent are expanded by Stripe.



311
312
313
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 311

def money_manager
  @money_manager
end