Class: Stripe::V2::Core::AccountTokenCreateParams::Identity::BusinessDetails::Documents

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_token_create_params.rb

Defined Under Namespace

Classes: BankAccountOwnershipVerification, CompanyLicense, CompanyMemorandumOfAssociation, CompanyMinisterialDecree, CompanyRegistrationVerification, CompanyTaxIdVerification, PrimaryVerification, ProofOfAddress, ProofOfRegistration, ProofOfUltimateBeneficialOwnership

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(bank_account_ownership_verification: nil, company_license: nil, company_memorandum_of_association: nil, company_ministerial_decree: nil, company_registration_verification: nil, company_tax_id_verification: nil, primary_verification: nil, proof_of_address: nil, proof_of_registration: nil, proof_of_ultimate_beneficial_ownership: nil) ⇒ Documents

Returns a new instance of Documents.



612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 612

def initialize(
  bank_account_ownership_verification: nil,
  company_license: nil,
  company_memorandum_of_association: nil,
  company_ministerial_decree: nil,
  company_registration_verification: nil,
  company_tax_id_verification: nil,
  primary_verification: nil,
  proof_of_address: nil,
  proof_of_registration: nil,
  proof_of_ultimate_beneficial_ownership: nil
)
  @bank_account_ownership_verification = 
  @company_license = company_license
  @company_memorandum_of_association = company_memorandum_of_association
  @company_ministerial_decree = company_ministerial_decree
  @company_registration_verification = company_registration_verification
  @company_tax_id_verification = company_tax_id_verification
  @primary_verification = primary_verification
  @proof_of_address = proof_of_address
  @proof_of_registration = proof_of_registration
  @proof_of_ultimate_beneficial_ownership = proof_of_ultimate_beneficial_ownership
end

Instance Attribute Details

#bank_account_ownership_verificationObject

One or more documents that support the bank account ownership verification requirement. Must be a document associated with the account's primary active bank account that displays the last 4 digits of the account number, either a statement or a check.



592
593
594
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 592

def 
  @bank_account_ownership_verification
end

#company_licenseObject

One or more documents that demonstrate proof of a company's license to operate.



594
595
596
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 594

def company_license
  @company_license
end

#company_memorandum_of_associationObject

One or more documents showing the company's Memorandum of Association.



596
597
598
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 596

def company_memorandum_of_association
  @company_memorandum_of_association
end

#company_ministerial_decreeObject

Certain countries only: One or more documents showing the ministerial decree legalizing the company's establishment.



598
599
600
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 598

def company_ministerial_decree
  @company_ministerial_decree
end

#company_registration_verificationObject

One or more documents that demonstrate proof of a company's registration with the appropriate local authorities.



600
601
602
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 600

def company_registration_verification
  @company_registration_verification
end

#company_tax_id_verificationObject

One or more documents that demonstrate proof of a company's tax ID.



602
603
604
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 602

def company_tax_id_verification
  @company_tax_id_verification
end

#primary_verificationObject

A document verifying the business.



604
605
606
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 604

def primary_verification
  @primary_verification
end

#proof_of_addressObject

One or more documents that demonstrate proof of address.



606
607
608
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 606

def proof_of_address
  @proof_of_address
end

#proof_of_registrationObject

One or more documents that demonstrate proof of ultimate beneficial ownership.



608
609
610
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 608

def proof_of_registration
  @proof_of_registration
end

#proof_of_ultimate_beneficial_ownershipObject

One or more documents that demonstrate proof of ultimate beneficial ownership.



610
611
612
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 610

def proof_of_ultimate_beneficial_ownership
  @proof_of_ultimate_beneficial_ownership
end