Class: Stripe::V2::Core::AccountTokenCreateParams::Identity::BusinessDetails::Documents::CompanyRegistrationVerification
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountTokenCreateParams::Identity::BusinessDetails::Documents::CompanyRegistrationVerification
- Defined in:
- lib/stripe/params/v2/core/account_token_create_params.rb
Instance Attribute Summary collapse
-
#files ⇒ Object
One or more document IDs returned by a file upload with a purpose value of
account_requirement. -
#type ⇒ Object
The format of the document.
Instance Method Summary collapse
-
#initialize(files: nil, type: nil) ⇒ CompanyRegistrationVerification
constructor
A new instance of CompanyRegistrationVerification.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(files: nil, type: nil) ⇒ CompanyRegistrationVerification
Returns a new instance of CompanyRegistrationVerification.
256 257 258 259 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 256 def initialize(files: nil, type: nil) @files = files @type = type end |
Instance Attribute Details
#files ⇒ Object
One or more document IDs returned by a file upload with a purpose value of account_requirement.
252 253 254 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 252 def files @files end |
#type ⇒ Object
The format of the document. Currently supports files only.
254 255 256 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 254 def type @type end |