Class: Stripe::V2::Core::AccountTokenCreateParams::Identity::Individual
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountTokenCreateParams::Identity::Individual
- Defined in:
- lib/stripe/params/v2/core/account_token_create_params.rb
Defined Under Namespace
Classes: AdditionalAddress, AdditionalName, Address, DateOfBirth, Documents, IdNumber, Relationship, ScriptAddresses, ScriptNames
Instance Attribute Summary collapse
-
#additional_addresses ⇒ Object
Additional addresses associated with the individual.
-
#additional_names ⇒ Object
Additional names (e.g. aliases) associated with the individual.
-
#address ⇒ Object
The individual’s residential address.
-
#date_of_birth ⇒ Object
The individual’s date of birth.
-
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
-
#email ⇒ Object
The individual’s email address.
-
#given_name ⇒ Object
The individual’s first name.
-
#id_numbers ⇒ Object
The identification numbers (e.g., SSN) associated with the individual.
-
#legal_gender ⇒ Object
The individual’s gender (International regulations require either “male” or “female”).
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#nationalities ⇒ Object
The countries where the individual is a national.
-
#phone ⇒ Object
The individual’s phone number.
-
#political_exposure ⇒ Object
The individual’s political exposure.
-
#relationship ⇒ Object
The relationship that this individual has with the account’s identity.
-
#script_addresses ⇒ Object
The script addresses (e.g., non-Latin characters) associated with the individual.
-
#script_names ⇒ Object
The individuals primary name in non latin script.
-
#surname ⇒ Object
The individual’s last name.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(additional_addresses: nil, additional_names: nil, address: nil, date_of_birth: nil, documents: nil, email: nil, given_name: nil, id_numbers: nil, legal_gender: nil, metadata: nil, nationalities: nil, phone: nil, political_exposure: nil, relationship: nil, script_addresses: nil, script_names: nil, surname: nil) ⇒ Individual
constructor
A new instance of Individual.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(additional_addresses: nil, additional_names: nil, address: nil, date_of_birth: nil, documents: nil, email: nil, given_name: nil, id_numbers: nil, legal_gender: nil, metadata: nil, nationalities: nil, phone: nil, political_exposure: nil, relationship: nil, script_addresses: nil, script_names: nil, surname: nil) ⇒ Individual
Returns a new instance of Individual.
1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 1224 1225 1226 1227 1228 1229 1230 1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1208 def initialize( additional_addresses: nil, additional_names: nil, address: nil, date_of_birth: nil, documents: nil, email: nil, given_name: nil, id_numbers: nil, legal_gender: nil, metadata: nil, nationalities: nil, phone: nil, political_exposure: nil, relationship: nil, script_addresses: nil, script_names: nil, surname: nil ) @additional_addresses = additional_addresses @additional_names = additional_names @address = address @date_of_birth = date_of_birth @documents = documents @email = email @given_name = given_name @id_numbers = id_numbers @legal_gender = legal_gender @metadata = @nationalities = nationalities @phone = phone @political_exposure = political_exposure @relationship = relationship @script_addresses = script_addresses @script_names = script_names @surname = surname end |
Instance Attribute Details
#additional_addresses ⇒ Object
Additional addresses associated with the individual.
1174 1175 1176 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1174 def additional_addresses @additional_addresses end |
#additional_names ⇒ Object
Additional names (e.g. aliases) associated with the individual.
1176 1177 1178 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1176 def additional_names @additional_names end |
#address ⇒ Object
The individual’s residential address.
1178 1179 1180 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1178 def address @address end |
#date_of_birth ⇒ Object
The individual’s date of birth.
1180 1181 1182 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1180 def date_of_birth @date_of_birth end |
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
1182 1183 1184 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1182 def documents @documents end |
#email ⇒ Object
The individual’s email address. You can only set this field when the Account is configured as a ‘merchant` or `recipient`. Use `contact_email` as the primary contact email for this Account.
1184 1185 1186 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1184 def email @email end |
#given_name ⇒ Object
The individual’s first name.
1186 1187 1188 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1186 def given_name @given_name end |
#id_numbers ⇒ Object
The identification numbers (e.g., SSN) associated with the individual.
1188 1189 1190 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1188 def id_numbers @id_numbers end |
#legal_gender ⇒ Object
The individual’s gender (International regulations require either “male” or “female”).
1190 1191 1192 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1190 def legal_gender @legal_gender end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
1192 1193 1194 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1192 def @metadata end |
#nationalities ⇒ Object
The countries where the individual is a national. Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
1194 1195 1196 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1194 def nationalities @nationalities end |
#phone ⇒ Object
The individual’s phone number.
1196 1197 1198 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1196 def phone @phone end |
#political_exposure ⇒ Object
The individual’s political exposure.
1198 1199 1200 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1198 def political_exposure @political_exposure end |
#relationship ⇒ Object
The relationship that this individual has with the account’s identity.
1200 1201 1202 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1200 def relationship @relationship end |
#script_addresses ⇒ Object
The script addresses (e.g., non-Latin characters) associated with the individual.
1202 1203 1204 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1202 def script_addresses @script_addresses end |
#script_names ⇒ Object
The individuals primary name in non latin script.
1204 1205 1206 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1204 def script_names @script_names end |
#surname ⇒ Object
The individual’s last name.
1206 1207 1208 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1206 def surname @surname end |
Class Method Details
.field_encodings ⇒ Object
1246 1247 1248 1249 1250 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1246 def self.field_encodings @field_encodings = { relationship: { kind: :object, fields: { percent_ownership: :decimal_string } }, } end |