Class: Stripe::V2::Core::AccountTokenCreateParams::Identity::Individual::Documents

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_token_create_params.rb

Defined Under Namespace

Classes: CompanyAuthorization, Passport, PrimaryVerification, SecondaryVerification, Visa

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(company_authorization: nil, passport: nil, primary_verification: nil, secondary_verification: nil, visa: nil) ⇒ Documents

Returns a new instance of Documents.



730
731
732
733
734
735
736
737
738
739
740
741
742
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 730

def initialize(
  company_authorization: nil,
  passport: nil,
  primary_verification: nil,
  secondary_verification: nil,
  visa: nil
)
  @company_authorization = company_authorization
  @passport = passport
  @primary_verification = primary_verification
  @secondary_verification = secondary_verification
  @visa = visa
end

Instance Attribute Details

#company_authorizationObject

One or more documents that demonstrate proof that this person is authorized to represent the company.



720
721
722
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 720

def company_authorization
  @company_authorization
end

#passportObject

One or more documents showing the person’s passport page with photo and personal data.



722
723
724
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 722

def passport
  @passport
end

#primary_verificationObject

An identifying document showing the person’s name, either a passport or local ID card.



724
725
726
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 724

def primary_verification
  @primary_verification
end

#secondary_verificationObject

A document showing address, either a passport, local ID card, or utility bill from a well-known utility company.



726
727
728
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 726

def secondary_verification
  @secondary_verification
end

#visaObject

One or more documents showing the person’s visa required for living in the country where they are residing.



728
729
730
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 728

def visa
  @visa
end