Class: Stripe::V2::Core::AccountTokenCreateParams::Identity::Individual::Documents::PrimaryVerification::FrontBack
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountTokenCreateParams::Identity::Individual::Documents::PrimaryVerification::FrontBack
- Defined in:
- lib/stripe/params/v2/core/account_token_create_params.rb
Instance Attribute Summary collapse
-
#back ⇒ Object
A [file upload](docs.stripe.com/api/persons/update#create_file) token representing the back of the verification document.
-
#front ⇒ Object
A [file upload](docs.stripe.com/api/persons/update#create_file) token representing the front of the verification document.
Instance Method Summary collapse
-
#initialize(back: nil, front: nil) ⇒ FrontBack
constructor
A new instance of FrontBack.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(back: nil, front: nil) ⇒ FrontBack
Returns a new instance of FrontBack.
669 670 671 672 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 669 def initialize(back: nil, front: nil) @back = back @front = front end |
Instance Attribute Details
#back ⇒ Object
A [file upload](docs.stripe.com/api/persons/update#create_file) token representing the back of the verification document. The purpose of the uploaded file should be ‘identity_document’. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.
665 666 667 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 665 def back @back end |
#front ⇒ Object
A [file upload](docs.stripe.com/api/persons/update#create_file) token representing the front of the verification document. The purpose of the uploaded file should be ‘identity_document’. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.
667 668 669 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 667 def front @front end |