Class: Stripe::V2::Core::AccountTokenCreateParams::Identity::Individual::Documents::SecondaryVerification::FrontBack

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_token_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(back: nil, front: nil) ⇒ FrontBack

Returns a new instance of FrontBack.



692
693
694
695
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 692

def initialize(back: nil, front: nil)
  @back = back
  @front = front
end

Instance Attribute Details

#backObject

A [file upload](docs.stripe.com/api/persons/update#create_file) token representing the back of the verification document. The purpose of the uploaded file should be ‘identity_document’. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.



688
689
690
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 688

def back
  @back
end

#frontObject

A [file upload](docs.stripe.com/api/persons/update#create_file) token representing the front of the verification document. The purpose of the uploaded file should be ‘identity_document’. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.



690
691
692
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 690

def front
  @front
end