Class: Stripe::V2::Core::AccountTokenCreateParams::Identity::Individual::Relationship
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountTokenCreateParams::Identity::Individual::Relationship
- Defined in:
- lib/stripe/params/v2/core/account_token_create_params.rb
Instance Attribute Summary collapse
-
#director ⇒ Object
Whether the person is a director of the account's identity.
-
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
-
#owner ⇒ Object
Whether the person is an owner of the account's identity.
-
#percent_ownership ⇒ Object
The percent owned by the person of the account's legal entity.
-
#title ⇒ Object
The person's title (e.g., CEO, Support Engineer).
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
constructor
A new instance of Relationship.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
Returns a new instance of Relationship.
1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1087 def initialize( director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil ) @director = director @executive = executive @owner = owner @percent_ownership = percent_ownership @title = title end |
Instance Attribute Details
#director ⇒ Object
Whether the person is a director of the account's identity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.
1077 1078 1079 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1077 def director @director end |
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
1079 1080 1081 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1079 def executive @executive end |
#owner ⇒ Object
Whether the person is an owner of the account's identity.
1081 1082 1083 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1081 def owner @owner end |
#percent_ownership ⇒ Object
The percent owned by the person of the account's legal entity.
1083 1084 1085 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1083 def percent_ownership @percent_ownership end |
#title ⇒ Object
The person's title (e.g., CEO, Support Engineer).
1085 1086 1087 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1085 def title @title end |
Class Method Details
.field_encodings ⇒ Object
1101 1102 1103 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1101 def self.field_encodings @field_encodings = { percent_ownership: :decimal_string } end |