Class: Stripe::V2::Core::AccountUpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: Configuration, Defaults, Identity

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(account_token: nil, configuration: nil, contact_email: nil, contact_phone: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ AccountUpdateParams

Returns a new instance of AccountUpdateParams.



2165
2166
2167
2168
2169
2170
2171
2172
2173
2174
2175
2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2165

def initialize(
  account_token: nil,
  configuration: nil,
  contact_email: nil,
  contact_phone: nil,
  dashboard: nil,
  defaults: nil,
  display_name: nil,
  identity: nil,
  include: nil,
  metadata: nil
)
  @account_token = 
  @configuration = configuration
  @contact_email = contact_email
  @contact_phone = contact_phone
  @dashboard = dashboard
  @defaults = defaults
  @display_name = display_name
  @identity = identity
  @include = include
   = 
end

Instance Attribute Details

#account_tokenObject

The account token generated by the account token api.



2145
2146
2147
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2145

def 
  @account_token
end

#configurationObject

An Account Configuration which allows the Account to take on a key persona across Stripe products.



2147
2148
2149
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2147

def configuration
  @configuration
end

#contact_emailObject

The default contact email address for the Account. Required when configuring the account as a merchant or recipient.



2149
2150
2151
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2149

def contact_email
  @contact_email
end

#contact_phoneObject

The default contact phone for the Account.



2151
2152
2153
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2151

def contact_phone
  @contact_phone
end

#dashboardObject

A value indicating the Stripe dashboard this Account has access to. This will depend on which configurations are enabled for this account.



2153
2154
2155
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2153

def dashboard
  @dashboard
end

#defaultsObject

Default values to be used on Account Configurations.



2155
2156
2157
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2155

def defaults
  @defaults
end

#display_nameObject

A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.



2157
2158
2159
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2157

def display_name
  @display_name
end

#identityObject

Information about the company, individual, and business represented by the Account.



2159
2160
2161
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2159

def identity
  @identity
end

#includeObject

Additional fields to include in the response.



2161
2162
2163
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2161

def include
  @include
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



2163
2164
2165
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2163

def 
  
end

Class Method Details

.field_encodingsObject



2189
2190
2191
2192
2193
2194
2195
2196
2197
2198
2199
2200
2201
2202
2203
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2189

def self.field_encodings
  @field_encodings = {
    identity: {
      kind: :object,
      fields: {
        individual: {
          kind: :object,
          fields: {
            relationship: { kind: :object, fields: { percent_ownership: :decimal_string } },
          },
        },
      },
    },
  }
end