Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Customer

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: AutomaticIndirectTax, Billing, Capabilities, Shipping

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(applied: nil, automatic_indirect_tax: nil, billing: nil, capabilities: nil, shipping: nil, test_clock: nil) ⇒ Customer

Returns a new instance of Customer.



723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 723

def initialize(
  applied: nil,
  automatic_indirect_tax: nil,
  billing: nil,
  capabilities: nil,
  shipping: nil,
  test_clock: nil
)
  @applied = applied
  @automatic_indirect_tax = automatic_indirect_tax
  @billing = billing
  @capabilities = capabilities
  @shipping = shipping
  @test_clock = test_clock
end

Instance Attribute Details

#appliedObject

Represents the state of the configuration, and can be updated to deactivate or re-apply a configuration.



711
712
713
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 711

def applied
  @applied
end

#automatic_indirect_taxObject

Automatic indirect tax settings to be used when automatic tax calculation is enabled on the customer's invoices, subscriptions, checkout sessions, or payment links. Surfaces if automatic tax calculation is possible given the current customer location information.



713
714
715
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 713

def automatic_indirect_tax
  @automatic_indirect_tax
end

#billingObject

Billing settings - default settings used for this customer in Billing flows such as Invoices and Subscriptions.



715
716
717
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 715

def billing
  @billing
end

#capabilitiesObject

Capabilities that have been requested on the Customer Configuration.



717
718
719
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 717

def capabilities
  @capabilities
end

#shippingObject

The customer's shipping information. Appears on invoices emailed to this customer.



719
720
721
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 719

def shipping
  @shipping
end

#test_clockObject

ID of the test clock to attach to the customer. Can only be set on testmode Accounts, and when the Customer Configuration is first set on an Account.



721
722
723
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 721

def test_clock
  @test_clock
end