Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Customer::Billing
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Configuration::Customer::Billing
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: Invoice
Instance Attribute Summary collapse
-
#default_payment_method ⇒ Object
ID of a PaymentMethod attached to the customer account to use as the default for invoices and subscriptions.
-
#invoice ⇒ Object
Default invoice settings for the customer account.
Instance Method Summary collapse
-
#initialize(default_payment_method: nil, invoice: nil) ⇒ Billing
constructor
A new instance of Billing.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(default_payment_method: nil, invoice: nil) ⇒ Billing
Returns a new instance of Billing.
88 89 90 91 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 88 def initialize(default_payment_method: nil, invoice: nil) @default_payment_method = default_payment_method @invoice = invoice end |
Instance Attribute Details
#default_payment_method ⇒ Object
ID of a PaymentMethod attached to the customer account to use as the default for invoices and subscriptions.
84 85 86 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 84 def default_payment_method @default_payment_method end |
#invoice ⇒ Object
Default invoice settings for the customer account.
86 87 88 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 86 def invoice @invoice end |