Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Customer::Billing::Invoice
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Configuration::Customer::Billing::Invoice
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: CustomField, Rendering
Instance Attribute Summary collapse
-
#custom_fields ⇒ Object
The list of up to 4 default custom fields to be displayed on invoices for this customer.
-
#footer ⇒ Object
Default invoice footer.
-
#next_sequence ⇒ Object
Sequence number to use on the customer account’s next invoice.
-
#prefix ⇒ Object
Prefix used to generate unique invoice numbers.
-
#rendering ⇒ Object
Default invoice PDF rendering options.
Instance Method Summary collapse
-
#initialize(custom_fields: nil, footer: nil, next_sequence: nil, prefix: nil, rendering: nil) ⇒ Invoice
constructor
A new instance of Invoice.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(custom_fields: nil, footer: nil, next_sequence: nil, prefix: nil, rendering: nil) ⇒ Invoice
Returns a new instance of Invoice.
327 328 329 330 331 332 333 334 335 336 337 338 339 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 327 def initialize( custom_fields: nil, footer: nil, next_sequence: nil, prefix: nil, rendering: nil ) @custom_fields = custom_fields @footer = @next_sequence = next_sequence @prefix = prefix @rendering = rendering end |
Instance Attribute Details
#custom_fields ⇒ Object
The list of up to 4 default custom fields to be displayed on invoices for this customer.
317 318 319 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 317 def custom_fields @custom_fields end |
#footer ⇒ Object
Default invoice footer.
319 320 321 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 319 def @footer end |
#next_sequence ⇒ Object
Sequence number to use on the customer account’s next invoice. Defaults to 1.
321 322 323 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 321 def next_sequence @next_sequence end |
#prefix ⇒ Object
Prefix used to generate unique invoice numbers. Must be 3-12 uppercase letters or numbers.
323 324 325 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 323 def prefix @prefix end |
#rendering ⇒ Object
Default invoice PDF rendering options.
325 326 327 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 325 def rendering @rendering end |