Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Customer::Billing::Invoice::Rendering

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h

Constructor Details

#initialize(amount_tax_display: nil, template: nil) ⇒ Rendering

Returns a new instance of Rendering.



45
46
47
48
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 45

def initialize(amount_tax_display: nil, template: nil)
  @amount_tax_display = amount_tax_display
  @template = template
end

Instance Attribute Details

#amount_tax_displayObject

Indicates whether displayed line item prices and amounts on invoice PDFs include inclusive tax amounts. Must be either include_inclusive_tax or exclude_tax.



41
42
43
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 41

def amount_tax_display
  @amount_tax_display
end

#templateObject

ID of the invoice rendering template to use for future invoices.



43
44
45
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 43

def template
  @template
end