Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Customer::Capabilities::AutomaticIndirectTax
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Configuration::Customer::Capabilities::AutomaticIndirectTax
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: Protections
Instance Attribute Summary collapse
-
#protections ⇒ Object
Protection types to request for this capability (e.g. "psp_migration").
-
#requested ⇒ Object
To request a new Capability for an account, pass true.
Instance Method Summary collapse
-
#initialize(protections: nil, requested: nil) ⇒ AutomaticIndirectTax
constructor
A new instance of AutomaticIndirectTax.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(protections: nil, requested: nil) ⇒ AutomaticIndirectTax
Returns a new instance of AutomaticIndirectTax.
653 654 655 656 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 653 def initialize(protections: nil, requested: nil) @protections = protections @requested = requested end |
Instance Attribute Details
#protections ⇒ Object
Protection types to request for this capability (e.g. "psp_migration").
649 650 651 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 649 def protections @protections end |
#requested ⇒ Object
To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
651 652 653 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 651 def requested @requested end |