Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Merchant

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: BacsDebitPayments, Branding, Capabilities, CardPayments, GrossSettlement, KonbiniPayments, ScriptStatementDescriptor, SmartDisputes, StatementDescriptor, Support

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(applied: nil, bacs_debit_payments: nil, branding: nil, capabilities: nil, card_payments: nil, gross_settlement: nil, konbini_payments: nil, mcc: nil, script_statement_descriptor: nil, smart_disputes: nil, statement_descriptor: nil, support: nil) ⇒ Merchant

Returns a new instance of Merchant.



2420
2421
2422
2423
2424
2425
2426
2427
2428
2429
2430
2431
2432
2433
2434
2435
2436
2437
2438
2439
2440
2441
2442
2443
2444
2445
2446
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2420

def initialize(
  applied: nil,
  bacs_debit_payments: nil,
  branding: nil,
  capabilities: nil,
  card_payments: nil,
  gross_settlement: nil,
  konbini_payments: nil,
  mcc: nil,
  script_statement_descriptor: nil,
  smart_disputes: nil,
  statement_descriptor: nil,
  support: nil
)
  @applied = applied
  @bacs_debit_payments = bacs_debit_payments
  @branding = branding
  @capabilities = capabilities
  @card_payments = card_payments
  @gross_settlement = gross_settlement
  @konbini_payments = konbini_payments
  @mcc = mcc
  @script_statement_descriptor = script_statement_descriptor
  @smart_disputes = smart_disputes
  @statement_descriptor = statement_descriptor
  @support = support
end

Instance Attribute Details

#appliedObject

Represents the state of the configuration, and can be updated to deactivate or re-apply a configuration.



2396
2397
2398
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2396

def applied
  @applied
end

#bacs_debit_paymentsObject

Settings for Bacs Direct Debit payments.



2398
2399
2400
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2398

def bacs_debit_payments
  @bacs_debit_payments
end

#brandingObject

Settings used to apply the merchant's branding to email receipts, invoices, Checkout, and other products.



2400
2401
2402
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2400

def branding
  @branding
end

#capabilitiesObject

Capabilities to request on the Merchant Configuration.



2402
2403
2404
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2402

def capabilities
  @capabilities
end

#card_paymentsObject

Card payments settings.



2404
2405
2406
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2404

def card_payments
  @card_payments
end

#gross_settlementObject

Settings for gross settlement.



2406
2407
2408
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2406

def gross_settlement
  @gross_settlement
end

#konbini_paymentsObject

Settings specific to Konbini payments on the account.



2408
2409
2410
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2408

def konbini_payments
  @konbini_payments
end

#mccObject

The Merchant Category Code (MCC) for the merchant. MCCs classify businesses based on the goods or services they provide.



2410
2411
2412
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2410

def mcc
  @mcc
end

#script_statement_descriptorObject

Settings for the default text that appears on statements for language variations.



2412
2413
2414
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2412

def script_statement_descriptor
  @script_statement_descriptor
end

#smart_disputesObject

Settings for Smart Disputes automatic response feature.



2414
2415
2416
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2414

def smart_disputes
  @smart_disputes
end

#statement_descriptorObject

Settings for the default statement descriptor text.



2416
2417
2418
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2416

def statement_descriptor
  @statement_descriptor
end

#supportObject

Publicly available contact information for sending support issues to.



2418
2419
2420
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2418

def support
  @support
end