Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Merchant::Capabilities::AcssDebitPayments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Configuration::Merchant::Capabilities::AcssDebitPayments
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: Protections
Instance Attribute Summary collapse
-
#protections ⇒ Object
Protection types to request for this capability (e.g. "psp_migration").
-
#requested ⇒ Object
To request a new Capability for an account, pass true.
Instance Method Summary collapse
-
#initialize(protections: nil, requested: nil) ⇒ AcssDebitPayments
constructor
A new instance of AcssDebitPayments.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(protections: nil, requested: nil) ⇒ AcssDebitPayments
Returns a new instance of AcssDebitPayments.
819 820 821 822 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 819 def initialize(protections: nil, requested: nil) @protections = protections @requested = requested end |
Instance Attribute Details
#protections ⇒ Object
Protection types to request for this capability (e.g. "psp_migration").
815 816 817 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 815 def protections @protections end |
#requested ⇒ Object
To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
817 818 819 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 817 def requested @requested end |