Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Merchant::Capabilities::AlmaPayments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: Protections

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(protections: nil, requested: nil) ⇒ AlmaPayments

Returns a new instance of AlmaPayments.



903
904
905
906
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 903

def initialize(protections: nil, requested: nil)
  @protections = protections
  @requested = requested
end

Instance Attribute Details

#protectionsObject

Protection types to request for this capability (e.g. "psp_migration").



899
900
901
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 899

def protections
  @protections
end

#requestedObject

To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.



901
902
903
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 901

def requested
  @requested
end