Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Merchant::Capabilities::MobilepayPayments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: Protections

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(protections: nil, requested: nil) ⇒ MobilepayPayments

Returns a new instance of MobilepayPayments.



1519
1520
1521
1522
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1519

def initialize(protections: nil, requested: nil)
  @protections = protections
  @requested = requested
end

Instance Attribute Details

#protectionsObject

Protection types to request for this capability (e.g. "psp_migration").



1515
1516
1517
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1515

def protections
  @protections
end

#requestedObject

To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.



1517
1518
1519
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1517

def requested
  @requested
end