Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Merchant::Capabilities::MultibancoPayments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: Protections

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(protections: nil, requested: nil) ⇒ MultibancoPayments

Returns a new instance of MultibancoPayments.



1547
1548
1549
1550
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1547

def initialize(protections: nil, requested: nil)
  @protections = protections
  @requested = requested
end

Instance Attribute Details

#protectionsObject

Protection types to request for this capability (e.g. "psp_migration").



1543
1544
1545
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1543

def protections
  @protections
end

#requestedObject

To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.



1545
1546
1547
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1545

def requested
  @requested
end