Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Merchant::Capabilities::OxxoPayments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Configuration::Merchant::Capabilities::OxxoPayments
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: Protections
Instance Attribute Summary collapse
-
#protections ⇒ Object
Protection types to request for this capability (e.g. "psp_migration").
-
#requested ⇒ Object
To request a new Capability for an account, pass true.
Instance Method Summary collapse
-
#initialize(protections: nil, requested: nil) ⇒ OxxoPayments
constructor
A new instance of OxxoPayments.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(protections: nil, requested: nil) ⇒ OxxoPayments
Returns a new instance of OxxoPayments.
1631 1632 1633 1634 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1631 def initialize(protections: nil, requested: nil) @protections = protections @requested = requested end |
Instance Attribute Details
#protections ⇒ Object
Protection types to request for this capability (e.g. "psp_migration").
1627 1628 1629 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1627 def protections @protections end |
#requested ⇒ Object
To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
1629 1630 1631 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1629 def requested @requested end |