Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Merchant::Capabilities::P24Payments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: Protections

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(protections: nil, requested: nil) ⇒ P24Payments

Returns a new instance of P24Payments.



1659
1660
1661
1662
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1659

def initialize(protections: nil, requested: nil)
  @protections = protections
  @requested = requested
end

Instance Attribute Details

#protectionsObject

Protection types to request for this capability (e.g. "psp_migration").



1655
1656
1657
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1655

def protections
  @protections
end

#requestedObject

To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.



1657
1658
1659
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1657

def requested
  @requested
end