Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Merchant::Capabilities::PaycoPayments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: Protections

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(protections: nil, requested: nil) ⇒ PaycoPayments

Returns a new instance of PaycoPayments.



1715
1716
1717
1718
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1715

def initialize(protections: nil, requested: nil)
  @protections = protections
  @requested = requested
end

Instance Attribute Details

#protectionsObject

Protection types to request for this capability (e.g. "psp_migration").



1711
1712
1713
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1711

def protections
  @protections
end

#requestedObject

To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.



1713
1714
1715
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1713

def requested
  @requested
end