Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Merchant::Capabilities::PaynowPayments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: Protections

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(protections: nil, requested: nil) ⇒ PaynowPayments

Returns a new instance of PaynowPayments.



1743
1744
1745
1746
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1743

def initialize(protections: nil, requested: nil)
  @protections = protections
  @requested = requested
end

Instance Attribute Details

#protectionsObject

Protection types to request for this capability (e.g. "psp_migration").



1739
1740
1741
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1739

def protections
  @protections
end

#requestedObject

To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.



1741
1742
1743
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1741

def requested
  @requested
end