Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Merchant::Capabilities::RevolutPayPayments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: Protections

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(protections: nil, requested: nil) ⇒ RevolutPayPayments

Returns a new instance of RevolutPayPayments.



1799
1800
1801
1802
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1799

def initialize(protections: nil, requested: nil)
  @protections = protections
  @requested = requested
end

Instance Attribute Details

#protectionsObject

Protection types to request for this capability (e.g. "psp_migration").



1795
1796
1797
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1795

def protections
  @protections
end

#requestedObject

To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.



1797
1798
1799
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1797

def requested
  @requested
end