Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Merchant::Capabilities::SepaDebitPayments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: Protections

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(protections: nil, requested: nil) ⇒ SepaDebitPayments

Returns a new instance of SepaDebitPayments.



1883
1884
1885
1886
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1883

def initialize(protections: nil, requested: nil)
  @protections = protections
  @requested = requested
end

Instance Attribute Details

#protectionsObject

Protection types to request for this capability (e.g. "psp_migration").



1879
1880
1881
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1879

def protections
  @protections
end

#requestedObject

To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.



1881
1882
1883
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1881

def requested
  @requested
end