Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Merchant::Capabilities::SwishPayments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: Protections

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(protections: nil, requested: nil) ⇒ SwishPayments

Returns a new instance of SwishPayments.



1939
1940
1941
1942
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1939

def initialize(protections: nil, requested: nil)
  @protections = protections
  @requested = requested
end

Instance Attribute Details

#protectionsObject

Protection types to request for this capability (e.g. "psp_migration").



1935
1936
1937
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1935

def protections
  @protections
end

#requestedObject

To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.



1937
1938
1939
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1937

def requested
  @requested
end