Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Merchant::Capabilities::TwintPayments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: Protections

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(protections: nil, requested: nil) ⇒ TwintPayments

Returns a new instance of TwintPayments.



1967
1968
1969
1970
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1967

def initialize(protections: nil, requested: nil)
  @protections = protections
  @requested = requested
end

Instance Attribute Details

#protectionsObject

Protection types to request for this capability (e.g. "psp_migration").



1963
1964
1965
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1963

def protections
  @protections
end

#requestedObject

To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.



1965
1966
1967
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1965

def requested
  @requested
end