Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Merchant::Capabilities::UsBankTransferPayments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: Protections

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(protections: nil, requested: nil) ⇒ UsBankTransferPayments

Returns a new instance of UsBankTransferPayments.



1995
1996
1997
1998
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1995

def initialize(protections: nil, requested: nil)
  @protections = protections
  @requested = requested
end

Instance Attribute Details

#protectionsObject

Protection types to request for this capability (e.g. "psp_migration").



1991
1992
1993
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1991

def protections
  @protections
end

#requestedObject

To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.



1993
1994
1995
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1993

def requested
  @requested
end