Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Merchant::Capabilities::ZipPayments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: Protections

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(protections: nil, requested: nil) ⇒ ZipPayments

Returns a new instance of ZipPayments.



2023
2024
2025
2026
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2023

def initialize(protections: nil, requested: nil)
  @protections = protections
  @requested = requested
end

Instance Attribute Details

#protectionsObject

Protection types to request for this capability (e.g. "psp_migration").



2019
2020
2021
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2019

def protections
  @protections
end

#requestedObject

To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.



2021
2022
2023
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2021

def requested
  @requested
end