Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Merchant::CardPayments::DeclineOn

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(avs_failure: nil, cvc_failure: nil) ⇒ DeclineOn

Returns a new instance of DeclineOn.



2221
2222
2223
2224
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2221

def initialize(avs_failure: nil, cvc_failure: nil)
  @avs_failure = avs_failure
  @cvc_failure = cvc_failure
end

Instance Attribute Details

#avs_failureObject

Whether Stripe automatically declines charges with an incorrect ZIP or postal code. This setting only applies when a ZIP or postal code is provided and they fail bank verification.



2217
2218
2219
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2217

def avs_failure
  @avs_failure
end

#cvc_failureObject

Whether Stripe automatically declines charges with an incorrect CVC. This setting only applies when a CVC is provided and it fails bank verification.



2219
2220
2221
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2219

def cvc_failure
  @cvc_failure
end