Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Merchant::GrossSettlement

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(payment_method: nil, payment_method_collection: nil) ⇒ GrossSettlement

Returns a new instance of GrossSettlement.



2240
2241
2242
2243
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2240

def initialize(payment_method: nil, payment_method_collection: nil)
  @payment_method = payment_method
  @payment_method_collection = payment_method_collection
end

Instance Attribute Details

#payment_methodObject

The ID of the payment method to use for gross settlement payouts.



2236
2237
2238
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2236

def payment_method
  @payment_method
end

#payment_method_collectionObject

Whether to collect a payment method for gross settlement.



2238
2239
2240
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2238

def payment_method_collection
  @payment_method_collection
end