Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Merchant::Support
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Configuration::Merchant::Support
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
A publicly available mailing address for sending support issues to.
-
#email ⇒ Object
A publicly available email address for sending support issues to.
-
#phone ⇒ Object
A publicly available phone number to call with support issues.
-
#url ⇒ Object
A publicly available website for handling support issues.
Instance Method Summary collapse
-
#initialize(address: nil, email: nil, phone: nil, url: nil) ⇒ Support
constructor
A new instance of Support.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(address: nil, email: nil, phone: nil, url: nil) ⇒ Support
Returns a new instance of Support.
2388 2389 2390 2391 2392 2393 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2388 def initialize(address: nil, email: nil, phone: nil, url: nil) @address = address @email = email @phone = phone @url = url end |
Instance Attribute Details
#address ⇒ Object
A publicly available mailing address for sending support issues to.
2380 2381 2382 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2380 def address @address end |
#email ⇒ Object
A publicly available email address for sending support issues to.
2382 2383 2384 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2382 def email @email end |
#phone ⇒ Object
A publicly available phone number to call with support issues.
2384 2385 2386 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2384 def phone @phone end |
#url ⇒ Object
A publicly available website for handling support issues.
2386 2387 2388 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2386 def url @url end |