Class: Stripe::V2::Core::AccountUpdateParams::Configuration::MoneyManager

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: Capabilities, RegulatedActivity

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(applied: nil, capabilities: nil, high_risk_activities: nil, high_risk_activities_description: nil, money_services_description: nil, operates_in_prohibited_countries: nil, participates_in_regulated_activity: nil, purpose_of_funds: nil, purpose_of_funds_description: nil, regulated_activity: nil, source_of_funds: nil, source_of_funds_description: nil) ⇒ MoneyManager

Returns a new instance of MoneyManager.



3472
3473
3474
3475
3476
3477
3478
3479
3480
3481
3482
3483
3484
3485
3486
3487
3488
3489
3490
3491
3492
3493
3494
3495
3496
3497
3498
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3472

def initialize(
  applied: nil,
  capabilities: nil,
  high_risk_activities: nil,
  high_risk_activities_description: nil,
  money_services_description: nil,
  operates_in_prohibited_countries: nil,
  participates_in_regulated_activity: nil,
  purpose_of_funds: nil,
  purpose_of_funds_description: nil,
  regulated_activity: nil,
  source_of_funds: nil,
  source_of_funds_description: nil
)
  @applied = applied
  @capabilities = capabilities
  @high_risk_activities = high_risk_activities
  @high_risk_activities_description = high_risk_activities_description
  @money_services_description = money_services_description
  @operates_in_prohibited_countries = operates_in_prohibited_countries
  @participates_in_regulated_activity = participates_in_regulated_activity
  @purpose_of_funds = purpose_of_funds
  @purpose_of_funds_description = purpose_of_funds_description
  @regulated_activity = regulated_activity
  @source_of_funds = source_of_funds
  @source_of_funds_description = source_of_funds_description
end

Instance Attribute Details

#appliedObject

Represents the state of the configuration, and can be updated to deactivate or re-apply a configuration.



3448
3449
3450
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3448

def applied
  @applied
end

#capabilitiesObject

Capabilities to request on the Money Manager Configuration.



3450
3451
3452
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3450

def capabilities
  @capabilities
end

#high_risk_activitiesObject

List of high-risk activities the business is involved in.



3452
3453
3454
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3452

def high_risk_activities
  @high_risk_activities
end

#high_risk_activities_descriptionObject

Description of the high-risk activities the business offers.



3454
3455
3456
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3454

def high_risk_activities_description
  @high_risk_activities_description
end

#money_services_descriptionObject

Description of the money services offered by the business.



3456
3457
3458
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3456

def money_services_description
  @money_services_description
end

#operates_in_prohibited_countriesObject

Does the business operate in any prohibited countries.



3458
3459
3460
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3458

def operates_in_prohibited_countries
  @operates_in_prohibited_countries
end

#participates_in_regulated_activityObject

Indicates whether the business participates in any regulated activity.



3460
3461
3462
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3460

def participates_in_regulated_activity
  @participates_in_regulated_activity
end

#purpose_of_fundsObject

Primary purpose of the stored funds.



3462
3463
3464
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3462

def purpose_of_funds
  @purpose_of_funds
end

#purpose_of_funds_descriptionObject

Description of the purpose of the stored funds.



3464
3465
3466
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3464

def purpose_of_funds_description
  @purpose_of_funds_description
end

#regulated_activityObject

Details of the regulated activity if the business participates in one.



3466
3467
3468
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3466

def regulated_activity
  @regulated_activity
end

#source_of_fundsObject

The source of funds for the business, e.g. profits, income, venture capital, etc.



3468
3469
3470
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3468

def source_of_funds
  @source_of_funds
end

#source_of_funds_descriptionObject

Description of the source of funds for the business' account.



3470
3471
3472
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3470

def source_of_funds_description
  @source_of_funds_description
end