Class: Stripe::V2::Core::AccountUpdateParams::Configuration::MoneyManager::Capabilities

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: BusinessStorage, ConsumerStorage, InboundTransfers, OutboundPayments, OutboundTransfers, ReceivedCredits, ReceivedDebits

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(business_storage: nil, consumer_storage: nil, inbound_transfers: nil, outbound_payments: nil, outbound_transfers: nil, received_credits: nil, received_debits: nil) ⇒ Capabilities

Returns a new instance of Capabilities.



3406
3407
3408
3409
3410
3411
3412
3413
3414
3415
3416
3417
3418
3419
3420
3421
3422
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3406

def initialize(
  business_storage: nil,
  consumer_storage: nil,
  inbound_transfers: nil,
  outbound_payments: nil,
  outbound_transfers: nil,
  received_credits: nil,
  received_debits: nil
)
  @business_storage = business_storage
  @consumer_storage = consumer_storage
  @inbound_transfers = inbound_transfers
  @outbound_payments = outbound_payments
  @outbound_transfers = outbound_transfers
  @received_credits = received_credits
  @received_debits = received_debits
end

Instance Attribute Details

#business_storageObject

Can send or receive business storage-type funds on Stripe.



3392
3393
3394
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3392

def business_storage
  @business_storage
end

#consumer_storageObject

Can send or receive consumer storage-type funds on Stripe.



3394
3395
3396
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3394

def consumer_storage
  @consumer_storage
end

#inbound_transfersObject

Can pull funds from an external source, owned by yourself, to a FinancialAccount.



3396
3397
3398
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3396

def inbound_transfers
  @inbound_transfers
end

#outbound_paymentsObject

Can send funds from a FinancialAccount to a destination owned by someone else.



3398
3399
3400
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3398

def outbound_payments
  @outbound_payments
end

#outbound_transfersObject

Can send funds from a FinancialAccount to a destination owned by yourself.



3400
3401
3402
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3400

def outbound_transfers
  @outbound_transfers
end

#received_creditsObject

Can receive funds on a financial address to credit a FinancialAccount.



3402
3403
3404
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3402

def received_credits
  @received_credits
end

#received_debitsObject

Can receive debits to a FinancialAccount.



3404
3405
3406
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3404

def received_debits
  @received_debits
end