Class: Stripe::V2::Core::AccountUpdateParams::Configuration::MoneyManager::Capabilities::InboundTransfers
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Configuration::MoneyManager::Capabilities::InboundTransfers
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: BankAccounts
Instance Attribute Summary collapse
-
#bank_accounts ⇒ Object
Can pull funds from an external bank account owned by yourself to a FinancialAccount.
Instance Method Summary collapse
-
#initialize(bank_accounts: nil) ⇒ InboundTransfers
constructor
A new instance of InboundTransfers.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(bank_accounts: nil) ⇒ InboundTransfers
Returns a new instance of InboundTransfers.
1178 1179 1180 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1178 def initialize(bank_accounts: nil) @bank_accounts = bank_accounts end |
Instance Attribute Details
#bank_accounts ⇒ Object
Can pull funds from an external bank account owned by yourself to a FinancialAccount.
1176 1177 1178 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1176 def bank_accounts @bank_accounts end |