Class: Stripe::V2::Core::AccountUpdateParams::Configuration::MoneyManager::Capabilities::ReceivedCredits
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Configuration::MoneyManager::Capabilities::ReceivedCredits
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: BankAccounts, CryptoWallets
Instance Attribute Summary collapse
-
#bank_accounts ⇒ Object
Can receive funds on a bank-account-like financial address (VBAN) to credit a FinancialAccount.
-
#crypto_wallets ⇒ Object
Can receive funds on a crypto wallet like financial address to credit a FinancialAccount.
Instance Method Summary collapse
-
#initialize(bank_accounts: nil, crypto_wallets: nil) ⇒ ReceivedCredits
constructor
A new instance of ReceivedCredits.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(bank_accounts: nil, crypto_wallets: nil) ⇒ ReceivedCredits
Returns a new instance of ReceivedCredits.
3350 3351 3352 3353 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3350 def initialize(bank_accounts: nil, crypto_wallets: nil) @bank_accounts = bank_accounts @crypto_wallets = crypto_wallets end |
Instance Attribute Details
#bank_accounts ⇒ Object
Can receive funds on a bank-account-like financial address (VBAN) to credit a FinancialAccount.
3346 3347 3348 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3346 def bank_accounts @bank_accounts end |
#crypto_wallets ⇒ Object
Can receive funds on a crypto wallet like financial address to credit a FinancialAccount.
3348 3349 3350 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3348 def crypto_wallets @crypto_wallets end |