Class: Stripe::V2::Core::AccountUpdateParams::Configuration::MoneyManager::RegulatedActivity

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(description: nil, license_number: nil, primary_regulatory_authority_country: nil, primary_regulatory_authority_name: nil) ⇒ RegulatedActivity

Returns a new instance of RegulatedActivity.



3435
3436
3437
3438
3439
3440
3441
3442
3443
3444
3445
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3435

def initialize(
  description: nil,
  license_number: nil,
  primary_regulatory_authority_country: nil,
  primary_regulatory_authority_name: nil
)
  @description = description
  @license_number = license_number
  @primary_regulatory_authority_country = primary_regulatory_authority_country
  @primary_regulatory_authority_name = primary_regulatory_authority_name
end

Instance Attribute Details

#descriptionObject

A detailed description of the regulated activities the business is licensed to conduct.



3427
3428
3429
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3427

def description
  @description
end

#license_numberObject

The license number or registration number assigned by the business's primary regulator.



3429
3430
3431
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3429

def license_number
  @license_number
end

#primary_regulatory_authority_countryObject

The country of the primary regulatory authority that oversees the business's regulated activities.



3431
3432
3433
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3431

def primary_regulatory_authority_country
  @primary_regulatory_authority_country
end

#primary_regulatory_authority_nameObject

The name of the primary regulatory authority that oversees the business's regulated activities.



3433
3434
3435
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3433

def primary_regulatory_authority_name
  @primary_regulatory_authority_name
end