Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Configuration::Recipient
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: Capabilities
Instance Attribute Summary collapse
-
#applied ⇒ Object
Represents the state of the configuration, and can be updated to deactivate or re-apply a configuration.
-
#capabilities ⇒ Object
Capabilities to request on the Recipient Configuration.
-
#default_outbound_destination ⇒ Object
The payout method id to be used as a default outbound destination.
Instance Method Summary collapse
-
#initialize(applied: nil, capabilities: nil, default_outbound_destination: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(applied: nil, capabilities: nil, default_outbound_destination: nil) ⇒ Recipient
Returns a new instance of Recipient.
1086 1087 1088 1089 1090 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1086 def initialize(applied: nil, capabilities: nil, default_outbound_destination: nil) @applied = applied @capabilities = capabilities @default_outbound_destination = default_outbound_destination end |
Instance Attribute Details
#applied ⇒ Object
Represents the state of the configuration, and can be updated to deactivate or re-apply a configuration.
1080 1081 1082 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1080 def applied @applied end |
#capabilities ⇒ Object
Capabilities to request on the Recipient Configuration.
1082 1083 1084 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1082 def capabilities @capabilities end |
#default_outbound_destination ⇒ Object
The payout method id to be used as a default outbound destination. This will allow the PayoutMethod to be omitted on OutboundPayments made through API or sending payouts via dashboard. Can also be explicitly set to ‘null` to clear the existing default outbound destination. For further details about creating an Outbound Destination, see [Collect recipient’s payment details](docs.stripe.com/global-payouts-private-preview/quickstart?dashboard-or-api=api#collect-bank-account-details).
1084 1085 1086 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1084 def default_outbound_destination @default_outbound_destination end |