Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Recipient::Capabilities
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Configuration::Recipient::Capabilities
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: BankAccounts, Cards, CryptoWallets, PaperChecks, StripeBalance
Instance Attribute Summary collapse
-
#bank_accounts ⇒ Object
Capabilities that enable OutboundPayments to a bank account linked to this Account.
-
#cards ⇒ Object
Capability that enable OutboundPayments to a debit card linked to this Account.
-
#crypto_wallets ⇒ Object
Capabilities that enable OutboundPayments to a crypto wallet linked to this Account.
-
#paper_checks ⇒ Object
Capabilities that enable OutboundPayments via paper check.
-
#stripe_balance ⇒ Object
Capabilities that enable the recipient to manage their Stripe Balance (/v1/balance).
Instance Method Summary collapse
-
#initialize(bank_accounts: nil, cards: nil, crypto_wallets: nil, paper_checks: nil, stripe_balance: nil) ⇒ Capabilities
constructor
A new instance of Capabilities.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(bank_accounts: nil, cards: nil, crypto_wallets: nil, paper_checks: nil, stripe_balance: nil) ⇒ Capabilities
Returns a new instance of Capabilities.
4055 4056 4057 4058 4059 4060 4061 4062 4063 4064 4065 4066 4067 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 4055 def initialize( bank_accounts: nil, cards: nil, crypto_wallets: nil, paper_checks: nil, stripe_balance: nil ) @bank_accounts = bank_accounts @cards = cards @crypto_wallets = crypto_wallets @paper_checks = paper_checks @stripe_balance = stripe_balance end |
Instance Attribute Details
#bank_accounts ⇒ Object
Capabilities that enable OutboundPayments to a bank account linked to this Account.
4045 4046 4047 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 4045 def bank_accounts @bank_accounts end |
#cards ⇒ Object
Capability that enable OutboundPayments to a debit card linked to this Account.
4047 4048 4049 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 4047 def cards @cards end |
#crypto_wallets ⇒ Object
Capabilities that enable OutboundPayments to a crypto wallet linked to this Account.
4049 4050 4051 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 4049 def crypto_wallets @crypto_wallets end |
#paper_checks ⇒ Object
Capabilities that enable OutboundPayments via paper check.
4051 4052 4053 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 4051 def paper_checks @paper_checks end |
#stripe_balance ⇒ Object
Capabilities that enable the recipient to manage their Stripe Balance (/v1/balance).
4053 4054 4055 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 4053 def stripe_balance @stripe_balance end |