Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Recipient::Capabilities::Cards

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: Protections

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(protections: nil, requested: nil) ⇒ Cards

Returns a new instance of Cards.



3947
3948
3949
3950
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3947

def initialize(protections: nil, requested: nil)
  @protections = protections
  @requested = requested
end

Instance Attribute Details

#protectionsObject

Protection types to request for this capability (e.g. "psp_migration").



3943
3944
3945
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3943

def protections
  @protections
end

#requestedObject

To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.



3945
3946
3947
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3945

def requested
  @requested
end