Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Recipient::Capabilities::CryptoWallets
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Configuration::Recipient::Capabilities::CryptoWallets
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: Protections
Instance Attribute Summary collapse
-
#protections ⇒ Object
Protection types to request for this capability (e.g. "psp_migration").
-
#requested ⇒ Object
To request a new Capability for an account, pass true.
Instance Method Summary collapse
-
#initialize(protections: nil, requested: nil) ⇒ CryptoWallets
constructor
A new instance of CryptoWallets.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(protections: nil, requested: nil) ⇒ CryptoWallets
Returns a new instance of CryptoWallets.
3975 3976 3977 3978 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3975 def initialize(protections: nil, requested: nil) @protections = protections @requested = requested end |
Instance Attribute Details
#protections ⇒ Object
Protection types to request for this capability (e.g. "psp_migration").
3971 3972 3973 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3971 def protections @protections end |
#requested ⇒ Object
To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
3973 3974 3975 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3973 def requested @requested end |