Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Recipient::Capabilities::PaperChecks
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Configuration::Recipient::Capabilities::PaperChecks
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: Protections
Instance Attribute Summary collapse
-
#protections ⇒ Object
Protection types to request for this capability (e.g. "psp_migration").
-
#requested ⇒ Object
To request a new Capability for an account, pass true.
Instance Method Summary collapse
-
#initialize(protections: nil, requested: nil) ⇒ PaperChecks
constructor
A new instance of PaperChecks.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(protections: nil, requested: nil) ⇒ PaperChecks
Returns a new instance of PaperChecks.
4003 4004 4005 4006 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 4003 def initialize(protections: nil, requested: nil) @protections = protections @requested = requested end |
Instance Attribute Details
#protections ⇒ Object
Protection types to request for this capability (e.g. "psp_migration").
3999 4000 4001 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3999 def protections @protections end |
#requested ⇒ Object
To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
4001 4002 4003 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 4001 def requested @requested end |