Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Storer

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: Capabilities, RegulatedActivity

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(applied: nil, capabilities: nil, high_risk_activities: nil, high_risk_activities_description: nil, money_services_description: nil, operates_in_prohibited_countries: nil, participates_in_regulated_activity: nil, purpose_of_funds: nil, purpose_of_funds_description: nil, regulated_activity: nil, source_of_funds: nil, source_of_funds_description: nil) ⇒ Storer

Returns a new instance of Storer.



1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1707

def initialize(
  applied: nil,
  capabilities: nil,
  high_risk_activities: nil,
  high_risk_activities_description: nil,
  money_services_description: nil,
  operates_in_prohibited_countries: nil,
  participates_in_regulated_activity: nil,
  purpose_of_funds: nil,
  purpose_of_funds_description: nil,
  regulated_activity: nil,
  source_of_funds: nil,
  source_of_funds_description: nil
)
  @applied = applied
  @capabilities = capabilities
  @high_risk_activities = high_risk_activities
  @high_risk_activities_description = high_risk_activities_description
  @money_services_description = money_services_description
  @operates_in_prohibited_countries = operates_in_prohibited_countries
  @participates_in_regulated_activity = participates_in_regulated_activity
  @purpose_of_funds = purpose_of_funds
  @purpose_of_funds_description = purpose_of_funds_description
  @regulated_activity = regulated_activity
  @source_of_funds = source_of_funds
  @source_of_funds_description = source_of_funds_description
end

Instance Attribute Details

#appliedObject

Represents the state of the configuration, and can be updated to deactivate or re-apply a configuration.



1683
1684
1685
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1683

def applied
  @applied
end

#capabilitiesObject

Capabilities to request on the Storer Configuration.



1685
1686
1687
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1685

def capabilities
  @capabilities
end

#high_risk_activitiesObject

List of high-risk activities the business is involved in.



1687
1688
1689
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1687

def high_risk_activities
  @high_risk_activities
end

#high_risk_activities_descriptionObject

Description of the high-risk activities the business offers.



1689
1690
1691
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1689

def high_risk_activities_description
  @high_risk_activities_description
end

#money_services_descriptionObject

Description of the money services offered by the business.



1691
1692
1693
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1691

def money_services_description
  @money_services_description
end

#operates_in_prohibited_countriesObject

Does the business operate in any prohibited countries.



1693
1694
1695
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1693

def operates_in_prohibited_countries
  @operates_in_prohibited_countries
end

#participates_in_regulated_activityObject

Indicates whether the business participates in any regulated activity.



1695
1696
1697
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1695

def participates_in_regulated_activity
  @participates_in_regulated_activity
end

#purpose_of_fundsObject

Primary purpose of the stored funds.



1697
1698
1699
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1697

def purpose_of_funds
  @purpose_of_funds
end

#purpose_of_funds_descriptionObject

Description of the purpose of the stored funds.



1699
1700
1701
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1699

def purpose_of_funds_description
  @purpose_of_funds_description
end

#regulated_activityObject

Details of the regulated activity if the business participates in one.



1701
1702
1703
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1701

def regulated_activity
  @regulated_activity
end

#source_of_fundsObject

The source of funds for the business, e.g. profits, income, venture capital, etc.



1703
1704
1705
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1703

def source_of_funds
  @source_of_funds
end

#source_of_funds_descriptionObject

Description of the source of funds for the business’ account.



1705
1706
1707
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1705

def source_of_funds_description
  @source_of_funds_description
end