Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Storer::Capabilities
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Configuration::Storer::Capabilities
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: Consumer, FinancialAddresses, HoldsCurrencies, InboundTransfers, OutboundPayments, OutboundTransfers
Instance Attribute Summary collapse
-
#consumer ⇒ Object
Can provision a consumer financial account.
-
#financial_addresses ⇒ Object
Can provision a financial address to credit/debit a FinancialAccount.
-
#holds_currencies ⇒ Object
Can hold storage-type funds on Stripe.
-
#inbound_transfers ⇒ Object
Can pull funds from an external source, owned by yourself, to a FinancialAccount.
-
#outbound_payments ⇒ Object
Can send funds from a FinancialAccount to a destination owned by someone else.
-
#outbound_transfers ⇒ Object
Can send funds from a FinancialAccount to a destination owned by yourself.
Instance Method Summary collapse
-
#initialize(consumer: nil, financial_addresses: nil, holds_currencies: nil, inbound_transfers: nil, outbound_payments: nil, outbound_transfers: nil) ⇒ Capabilities
constructor
A new instance of Capabilities.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(consumer: nil, financial_addresses: nil, holds_currencies: nil, inbound_transfers: nil, outbound_payments: nil, outbound_transfers: nil) ⇒ Capabilities
Returns a new instance of Capabilities.
1643 1644 1645 1646 1647 1648 1649 1650 1651 1652 1653 1654 1655 1656 1657 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1643 def initialize( consumer: nil, financial_addresses: nil, holds_currencies: nil, inbound_transfers: nil, outbound_payments: nil, outbound_transfers: nil ) @consumer = consumer @financial_addresses = financial_addresses @holds_currencies = holds_currencies @inbound_transfers = inbound_transfers @outbound_payments = outbound_payments @outbound_transfers = outbound_transfers end |
Instance Attribute Details
#consumer ⇒ Object
Can provision a consumer financial account.
1631 1632 1633 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1631 def consumer @consumer end |
#financial_addresses ⇒ Object
Can provision a financial address to credit/debit a FinancialAccount.
1633 1634 1635 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1633 def financial_addresses @financial_addresses end |
#holds_currencies ⇒ Object
Can hold storage-type funds on Stripe.
1635 1636 1637 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1635 def holds_currencies @holds_currencies end |
#inbound_transfers ⇒ Object
Can pull funds from an external source, owned by yourself, to a FinancialAccount.
1637 1638 1639 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1637 def inbound_transfers @inbound_transfers end |
#outbound_payments ⇒ Object
Can send funds from a FinancialAccount to a destination owned by someone else.
1639 1640 1641 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1639 def outbound_payments @outbound_payments end |
#outbound_transfers ⇒ Object
Can send funds from a FinancialAccount to a destination owned by yourself.
1641 1642 1643 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1641 def outbound_transfers @outbound_transfers end |