Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Storer::RegulatedActivity

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(description: nil, license_number: nil, primary_regulatory_authority_country: nil, primary_regulatory_authority_name: nil) ⇒ RegulatedActivity

Returns a new instance of RegulatedActivity.



1670
1671
1672
1673
1674
1675
1676
1677
1678
1679
1680
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1670

def initialize(
  description: nil,
  license_number: nil,
  primary_regulatory_authority_country: nil,
  primary_regulatory_authority_name: nil
)
  @description = description
  @license_number = license_number
  @primary_regulatory_authority_country = primary_regulatory_authority_country
  @primary_regulatory_authority_name = primary_regulatory_authority_name
end

Instance Attribute Details

#descriptionObject

A detailed description of the regulated activities the business is licensed to conduct.



1662
1663
1664
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1662

def description
  @description
end

#license_numberObject

The license number or registration number assigned by the business’s primary regulator.



1664
1665
1666
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1664

def license_number
  @license_number
end

#primary_regulatory_authority_countryObject

The country of the primary regulatory authority that oversees the business’s regulated activities.



1666
1667
1668
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1666

def primary_regulatory_authority_country
  @primary_regulatory_authority_country
end

#primary_regulatory_authority_nameObject

The name of the primary regulatory authority that oversees the business’s regulated activities.



1668
1669
1670
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1668

def primary_regulatory_authority_name
  @primary_regulatory_authority_name
end