Class: Stripe::V2::Core::AccountUpdateParams::Defaults::Profile
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Defaults::Profile
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Instance Attribute Summary collapse
-
#business_url ⇒ Object
The business’s publicly-available website.
-
#doing_business_as ⇒ Object
The name which is used by the business.
-
#product_description ⇒ Object
Internal-only description of the product sold or service provided by the business.
Instance Method Summary collapse
-
#initialize(business_url: nil, doing_business_as: nil, product_description: nil) ⇒ Profile
constructor
A new instance of Profile.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(business_url: nil, doing_business_as: nil, product_description: nil) ⇒ Profile
Returns a new instance of Profile.
1300 1301 1302 1303 1304 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1300 def initialize(business_url: nil, doing_business_as: nil, product_description: nil) @business_url = business_url @doing_business_as = doing_business_as @product_description = product_description end |
Instance Attribute Details
#business_url ⇒ Object
The business’s publicly-available website.
1294 1295 1296 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1294 def business_url @business_url end |
#doing_business_as ⇒ Object
The name which is used by the business.
1296 1297 1298 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1296 def doing_business_as @doing_business_as end |
#product_description ⇒ Object
Internal-only description of the product sold or service provided by the business. It’s used by Stripe for risk and underwriting purposes.
1298 1299 1300 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1298 def product_description @product_description end |