Class: Stripe::V2::Core::AccountUpdateParams::Identity::Attestations::OwnershipDeclaration
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity::Attestations::OwnershipDeclaration
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The time marking when the beneficial owner attestation was made.
-
#ip ⇒ Object
The IP address from which the beneficial owner attestation was made.
-
#user_agent ⇒ Object
The user agent of the browser from which the beneficial owner attestation was made.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ OwnershipDeclaration
constructor
A new instance of OwnershipDeclaration.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ OwnershipDeclaration
Returns a new instance of OwnershipDeclaration.
1369 1370 1371 1372 1373 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1369 def initialize(date: nil, ip: nil, user_agent: nil) @date = date @ip = ip @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The time marking when the beneficial owner attestation was made. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
1363 1364 1365 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1363 def date @date end |
#ip ⇒ Object
The IP address from which the beneficial owner attestation was made.
1365 1366 1367 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1365 def ip @ip end |
#user_agent ⇒ Object
The user agent of the browser from which the beneficial owner attestation was made.
1367 1368 1369 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1367 def user_agent @user_agent end |