Class: Stripe::V2::Core::AccountUpdateParams::Identity::Attestations::PersonsProvided

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(directors: nil, executives: nil, owners: nil, ownership_exemption_reason: nil) ⇒ PersonsProvided

Returns a new instance of PersonsProvided.



1386
1387
1388
1389
1390
1391
1392
1393
1394
1395
1396
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1386

def initialize(
  directors: nil,
  executives: nil,
  owners: nil,
  ownership_exemption_reason: nil
)
  @directors = directors
  @executives = executives
  @owners = owners
  @ownership_exemption_reason = ownership_exemption_reason
end

Instance Attribute Details

#directorsObject

Whether the company’s directors have been provided. Set this Boolean to true after creating all the company’s directors with the [Persons API](docs.stripe.com/api/v2/core/accounts/createperson).



1378
1379
1380
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1378

def directors
  @directors
end

#executivesObject

Whether the company’s executives have been provided. Set this Boolean to true after creating all the company’s executives with the [Persons API](docs.stripe.com/api/v2/core/accounts/createperson).



1380
1381
1382
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1380

def executives
  @executives
end

#ownersObject

Whether the company’s owners have been provided. Set this Boolean to true after creating all the company’s owners with the [Persons API](docs.stripe.com/api/v2/core/accounts/createperson).



1382
1383
1384
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1382

def owners
  @owners
end

#ownership_exemption_reasonObject

Reason for why the company is exempt from providing ownership information.



1384
1385
1386
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1384

def ownership_exemption_reason
  @ownership_exemption_reason
end