Class: Stripe::V2::Core::AccountUpdateParams::Identity::Attestations::RepresentativeDeclaration
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity::Attestations::RepresentativeDeclaration
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The time marking when the representative attestation was made.
-
#ip ⇒ Object
The IP address from which the representative attestation was made.
-
#user_agent ⇒ Object
The user agent of the browser from which the representative attestation was made.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ RepresentativeDeclaration
constructor
A new instance of RepresentativeDeclaration.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ RepresentativeDeclaration
Returns a new instance of RepresentativeDeclaration.
1877 1878 1879 1880 1881 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1877 def initialize(date: nil, ip: nil, user_agent: nil) @date = date @ip = ip @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The time marking when the representative attestation was made. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
1871 1872 1873 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1871 def date @date end |
#ip ⇒ Object
The IP address from which the representative attestation was made.
1873 1874 1875 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1873 def ip @ip end |
#user_agent ⇒ Object
The user agent of the browser from which the representative attestation was made.
1875 1876 1877 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1875 def user_agent @user_agent end |