Class: Stripe::V2::Core::AccountUpdateParams::Identity::Attestations::TermsOfService::ConsumerMoneyManager
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity::Attestations::TermsOfService::ConsumerMoneyManager
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The time when the Account's representative accepted the terms of service.
-
#ip ⇒ Object
The IP address from which the Account's representative accepted the terms of service.
-
#user_agent ⇒ Object
The user agent of the browser from which the Account's representative accepted the terms of service.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ ConsumerMoneyManager
constructor
A new instance of ConsumerMoneyManager.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ ConsumerMoneyManager
Returns a new instance of ConsumerMoneyManager.
5125 5126 5127 5128 5129 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 5125 def initialize(date: nil, ip: nil, user_agent: nil) @date = date @ip = ip @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The time when the Account's representative accepted the terms of service. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
5119 5120 5121 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 5119 def date @date end |
#ip ⇒ Object
The IP address from which the Account's representative accepted the terms of service.
5121 5122 5123 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 5121 def ip @ip end |
#user_agent ⇒ Object
The user agent of the browser from which the Account's representative accepted the terms of service.
5123 5124 5125 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 5123 def user_agent @user_agent end |