Class: Stripe::V2::Core::AccountUpdateParams::Identity::Attestations::TermsOfService::ConsumerPrivacyDisclosures
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity::Attestations::TermsOfService::ConsumerPrivacyDisclosures
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The time when the Account’s representative accepted the terms of service.
-
#ip ⇒ Object
The IP address from which the Account’s representative accepted the terms of service.
-
#user_agent ⇒ Object
The user agent of the browser from which the Account’s representative accepted the terms of service.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ ConsumerPrivacyDisclosures
constructor
A new instance of ConsumerPrivacyDisclosures.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ ConsumerPrivacyDisclosures
Returns a new instance of ConsumerPrivacyDisclosures.
2778 2779 2780 2781 2782 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2778 def initialize(date: nil, ip: nil, user_agent: nil) @date = date @ip = ip @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The time when the Account’s representative accepted the terms of service. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
2772 2773 2774 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2772 def date @date end |
#ip ⇒ Object
The IP address from which the Account’s representative accepted the terms of service.
2774 2775 2776 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2774 def ip @ip end |
#user_agent ⇒ Object
The user agent of the browser from which the Account’s representative accepted the terms of service.
2776 2777 2778 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2776 def user_agent @user_agent end |