Class: Stripe::V2::Core::AccountUpdateParams::Identity::Attestations::TermsOfService::CryptoMoneyManager
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity::Attestations::TermsOfService::CryptoMoneyManager
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The time when the Account's representative accepted the terms of service.
-
#ip ⇒ Object
The IP address from which the Account's representative accepted the terms of service.
-
#user_agent ⇒ Object
The user agent of the browser from which the Account's representative accepted the terms of service.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ CryptoMoneyManager
constructor
A new instance of CryptoMoneyManager.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ CryptoMoneyManager
Returns a new instance of CryptoMoneyManager.
1181 1182 1183 1184 1185 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1181 def initialize(date: nil, ip: nil, user_agent: nil) @date = date @ip = ip @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The time when the Account's representative accepted the terms of service. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
1175 1176 1177 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1175 def date @date end |
#ip ⇒ Object
The IP address from which the Account's representative accepted the terms of service.
1177 1178 1179 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1177 def ip @ip end |
#user_agent ⇒ Object
The user agent of the browser from which the Account's representative accepted the terms of service.
1179 1180 1181 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1179 def user_agent @user_agent end |