Class: Stripe::V2::Core::AccountUpdateParams::Identity::BusinessDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: AdditionalAddress, Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, RegistrationDate, ScriptAddresses, ScriptNames

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(additional_addresses: nil, address: nil, annual_revenue: nil, compliance_screening_description: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails

Returns a new instance of BusinessDetails.



5694
5695
5696
5697
5698
5699
5700
5701
5702
5703
5704
5705
5706
5707
5708
5709
5710
5711
5712
5713
5714
5715
5716
5717
5718
5719
5720
5721
5722
5723
5724
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 5694

def initialize(
  additional_addresses: nil,
  address: nil,
  annual_revenue: nil,
  compliance_screening_description: nil,
  documents: nil,
  estimated_worker_count: nil,
  id_numbers: nil,
  monthly_estimated_revenue: nil,
  phone: nil,
  registered_name: nil,
  registration_date: nil,
  script_addresses: nil,
  script_names: nil,
  structure: nil
)
  @additional_addresses = additional_addresses
  @address = address
  @annual_revenue = annual_revenue
  @compliance_screening_description = compliance_screening_description
  @documents = documents
  @estimated_worker_count = estimated_worker_count
  @id_numbers = id_numbers
  @monthly_estimated_revenue = monthly_estimated_revenue
  @phone = phone
  @registered_name = registered_name
  @registration_date = registration_date
  @script_addresses = script_addresses
  @script_names = script_names
  @structure = structure
end

Instance Attribute Details

#additional_addressesObject

Additional addresses associated with the business.



5666
5667
5668
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 5666

def additional_addresses
  @additional_addresses
end

#addressObject

The business registration address of the business entity.



5668
5669
5670
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 5668

def address
  @address
end

#annual_revenueObject

The business gross annual revenue for its preceding fiscal year.



5670
5671
5672
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 5670

def annual_revenue
  @annual_revenue
end

#compliance_screening_descriptionObject

A detailed description of the business's compliance and anti-money laundering controls and practices.



5672
5673
5674
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 5672

def compliance_screening_description
  @compliance_screening_description
end

#documentsObject

A document verifying the business.



5674
5675
5676
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 5674

def documents
  @documents
end

#estimated_worker_countObject

Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).



5676
5677
5678
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 5676

def estimated_worker_count
  @estimated_worker_count
end

#id_numbersObject

The ID numbers of a business entity.



5678
5679
5680
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 5678

def id_numbers
  @id_numbers
end

#monthly_estimated_revenueObject

An estimate of the monthly revenue of the business.



5680
5681
5682
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 5680

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#phoneObject

The phone number of the Business Entity.



5682
5683
5684
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 5682

def phone
  @phone
end

#registered_nameObject

The business legal name.



5684
5685
5686
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 5684

def registered_name
  @registered_name
end

#registration_dateObject

When the business was incorporated or registered.



5686
5687
5688
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 5686

def registration_date
  @registration_date
end

#script_addressesObject

The business registration address of the business entity in non latin script.



5688
5689
5690
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 5688

def script_addresses
  @script_addresses
end

#script_namesObject

The business legal name in non latin script.



5690
5691
5692
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 5690

def script_names
  @script_names
end

#structureObject

The category identifying the legal structure of the business.



5692
5693
5694
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 5692

def structure
  @structure
end