Class: Stripe::V2::Core::AccountUpdateParams::Identity::BusinessDetails::AnnualRevenue

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, fiscal_year_end: nil) ⇒ AnnualRevenue

Returns a new instance of AnnualRevenue.



1540
1541
1542
1543
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1540

def initialize(amount: nil, fiscal_year_end: nil)
  @amount = amount
  @fiscal_year_end = fiscal_year_end
end

Instance Attribute Details

#amountObject

A non-negative integer representing the amount in the smallest currency unit.



1536
1537
1538
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1536

def amount
  @amount
end

#fiscal_year_endObject

The close-out date of the preceding fiscal year in ISO 8601 format. E.g. 2023-12-31 for the 31st of December, 2023.



1538
1539
1540
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1538

def fiscal_year_end
  @fiscal_year_end
end