Class: Stripe::V2::Core::AccountUpdateParams::Identity::BusinessDetails::AnnualRevenue::Amount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity::BusinessDetails::AnnualRevenue::Amount
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Instance Attribute Summary collapse
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#value ⇒ Object
A non-negative integer representing how much to charge in the [smallest currency unit](docs.stripe.com/currencies#minor-units).
Instance Method Summary collapse
-
#initialize(value: nil, currency: nil) ⇒ Amount
constructor
A new instance of Amount.
Methods inherited from RequestParams
Constructor Details
#initialize(value: nil, currency: nil) ⇒ Amount
Returns a new instance of Amount.
2200 2201 2202 2203 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2200 def initialize(value: nil, currency: nil) @value = value @currency = currency end |
Instance Attribute Details
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
2198 2199 2200 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2198 def currency @currency end |
#value ⇒ Object
A non-negative integer representing how much to charge in the [smallest currency unit](docs.stripe.com/currencies#minor-units).
2196 2197 2198 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2196 def value @value end |