Class: Stripe::V2::Core::AccountUpdateParams::Identity::BusinessDetails::Documents::CompanyMemorandumOfAssociation
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity::BusinessDetails::Documents::CompanyMemorandumOfAssociation
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Instance Attribute Summary collapse
-
#files ⇒ Object
One or more document IDs returned by a file upload with a purpose value of
account_requirement. -
#type ⇒ Object
The format of the document.
Instance Method Summary collapse
-
#initialize(files: nil, type: nil) ⇒ CompanyMemorandumOfAssociation
constructor
A new instance of CompanyMemorandumOfAssociation.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(files: nil, type: nil) ⇒ CompanyMemorandumOfAssociation
Returns a new instance of CompanyMemorandumOfAssociation.
1359 1360 1361 1362 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1359 def initialize(files: nil, type: nil) @files = files @type = type end |
Instance Attribute Details
#files ⇒ Object
One or more document IDs returned by a file upload with a purpose value of account_requirement.
1355 1356 1357 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1355 def files @files end |
#type ⇒ Object
The format of the document. Currently supports files only.
1357 1358 1359 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1357 def type @type end |