Class: Stripe::V2::Core::AccountUpdateParams::Identity::BusinessDetails::Documents::CompanyMinisterialDecree
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity::BusinessDetails::Documents::CompanyMinisterialDecree
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Instance Attribute Summary collapse
-
#files ⇒ Object
One or more document IDs returned by a file upload with a purpose value of
account_requirement. -
#type ⇒ Object
The format of the document.
Instance Method Summary collapse
-
#initialize(files: nil, type: nil) ⇒ CompanyMinisterialDecree
constructor
A new instance of CompanyMinisterialDecree.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(files: nil, type: nil) ⇒ CompanyMinisterialDecree
Returns a new instance of CompanyMinisterialDecree.
1762 1763 1764 1765 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1762 def initialize(files: nil, type: nil) @files = files @type = type end |
Instance Attribute Details
#files ⇒ Object
One or more document IDs returned by a file upload with a purpose value of account_requirement.
1758 1759 1760 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1758 def files @files end |
#type ⇒ Object
The format of the document. Currently supports files only.
1760 1761 1762 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1760 def type @type end |