Class: Stripe::V2::Core::AccountUpdateParams::Identity::BusinessDetails::Documents::ProofOfRegistration
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity::BusinessDetails::Documents::ProofOfRegistration
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: Signer
Instance Attribute Summary collapse
-
#files ⇒ Object
One or more document IDs returned by a file upload with a purpose value of
account_requirement. -
#signer ⇒ Object
Person that is signing the document.
-
#type ⇒ Object
The format of the document.
Instance Method Summary collapse
-
#initialize(files: nil, signer: nil, type: nil) ⇒ ProofOfRegistration
constructor
A new instance of ProofOfRegistration.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(files: nil, signer: nil, type: nil) ⇒ ProofOfRegistration
Returns a new instance of ProofOfRegistration.
1847 1848 1849 1850 1851 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1847 def initialize(files: nil, signer: nil, type: nil) @files = files @signer = signer @type = type end |
Instance Attribute Details
#files ⇒ Object
One or more document IDs returned by a file upload with a purpose value of account_requirement.
1841 1842 1843 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1841 def files @files end |
#signer ⇒ Object
Person that is signing the document.
1843 1844 1845 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1843 def signer @signer end |
#type ⇒ Object
The format of the document. Currently supports files only.
1845 1846 1847 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1845 def type @type end |