Class: Stripe::V2::Core::AccountUpdateParams::Identity::BusinessDetails::Documents::ProofOfUltimateBeneficialOwnership
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity::BusinessDetails::Documents::ProofOfUltimateBeneficialOwnership
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: Signer
Instance Attribute Summary collapse
-
#files ⇒ Object
One or more document IDs returned by a file upload with a purpose value of
account_requirement. -
#signer ⇒ Object
Person that is signing the document.
-
#type ⇒ Object
The format of the document.
Instance Method Summary collapse
-
#initialize(files: nil, signer: nil, type: nil) ⇒ ProofOfUltimateBeneficialOwnership
constructor
A new instance of ProofOfUltimateBeneficialOwnership.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(files: nil, signer: nil, type: nil) ⇒ ProofOfUltimateBeneficialOwnership
Returns a new instance of ProofOfUltimateBeneficialOwnership.
1866 1867 1868 1869 1870 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1866 def initialize(files: nil, signer: nil, type: nil) @files = files @signer = signer @type = type end |
Instance Attribute Details
#files ⇒ Object
One or more document IDs returned by a file upload with a purpose value of account_requirement.
1860 1861 1862 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1860 def files @files end |
#signer ⇒ Object
Person that is signing the document.
1862 1863 1864 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1862 def signer @signer end |
#type ⇒ Object
The format of the document. Currently supports files only.
1864 1865 1866 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1864 def type @type end |