Class: Stripe::V2::Core::AccountUpdateParams::Identity::BusinessDetails::MonthlyEstimatedRevenue
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity::BusinessDetails::MonthlyEstimatedRevenue
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
A non-negative integer representing the amount in the smallest currency unit.
Instance Method Summary collapse
-
#initialize(amount: nil) ⇒ MonthlyEstimatedRevenue
constructor
A new instance of MonthlyEstimatedRevenue.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil) ⇒ MonthlyEstimatedRevenue
Returns a new instance of MonthlyEstimatedRevenue.
2300 2301 2302 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2300 def initialize(amount: nil) @amount = amount end |
Instance Attribute Details
#amount ⇒ Object
A non-negative integer representing the amount in the smallest currency unit.
2298 2299 2300 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2298 def amount @amount end |