Class: Stripe::V2::Core::AccountUpdateParams::Identity::Individual
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity::Individual
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: AdditionalAddress, AdditionalName, Address, DateOfBirth, Documents, IdNumber, Relationship, ScriptAddresses, ScriptNames
Instance Attribute Summary collapse
-
#additional_addresses ⇒ Object
Additional addresses associated with the individual.
-
#additional_names ⇒ Object
Additional names (e.g. aliases) associated with the individual.
-
#address ⇒ Object
The individual's residential address.
-
#date_of_birth ⇒ Object
The individual's date of birth.
-
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
-
#email ⇒ Object
The individual's email address.
-
#given_name ⇒ Object
The individual's first name.
-
#id_numbers ⇒ Object
The identification numbers (e.g., SSN) associated with the individual.
-
#legal_gender ⇒ Object
The individual's gender (International regulations require either "male" or "female").
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#nationalities ⇒ Object
The countries where the individual is a national.
-
#phone ⇒ Object
The individual's phone number.
-
#political_exposure ⇒ Object
The individual's political exposure.
-
#relationship ⇒ Object
The relationship that this individual has with the account's identity.
-
#script_addresses ⇒ Object
The script addresses (e.g., non-Latin characters) associated with the individual.
-
#script_names ⇒ Object
The individuals primary name in non latin script.
-
#surname ⇒ Object
The individual's last name.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(additional_addresses: nil, additional_names: nil, address: nil, date_of_birth: nil, documents: nil, email: nil, given_name: nil, id_numbers: nil, legal_gender: nil, metadata: nil, nationalities: nil, phone: nil, political_exposure: nil, relationship: nil, script_addresses: nil, script_names: nil, surname: nil) ⇒ Individual
constructor
A new instance of Individual.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, new, #to_h
Constructor Details
#initialize(additional_addresses: nil, additional_names: nil, address: nil, date_of_birth: nil, documents: nil, email: nil, given_name: nil, id_numbers: nil, legal_gender: nil, metadata: nil, nationalities: nil, phone: nil, political_exposure: nil, relationship: nil, script_addresses: nil, script_names: nil, surname: nil) ⇒ Individual
Returns a new instance of Individual.
2194 2195 2196 2197 2198 2199 2200 2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2194 def initialize( additional_addresses: nil, additional_names: nil, address: nil, date_of_birth: nil, documents: nil, email: nil, given_name: nil, id_numbers: nil, legal_gender: nil, metadata: nil, nationalities: nil, phone: nil, political_exposure: nil, relationship: nil, script_addresses: nil, script_names: nil, surname: nil ) @additional_addresses = additional_addresses @additional_names = additional_names @address = address @date_of_birth = date_of_birth @documents = documents @email = email @given_name = given_name @id_numbers = id_numbers @legal_gender = legal_gender @metadata = @nationalities = nationalities @phone = phone @political_exposure = political_exposure @relationship = relationship @script_addresses = script_addresses @script_names = script_names @surname = surname end |
Instance Attribute Details
#additional_addresses ⇒ Object
Additional addresses associated with the individual.
2160 2161 2162 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2160 def additional_addresses @additional_addresses end |
#additional_names ⇒ Object
Additional names (e.g. aliases) associated with the individual.
2162 2163 2164 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2162 def additional_names @additional_names end |
#address ⇒ Object
The individual's residential address.
2164 2165 2166 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2164 def address @address end |
#date_of_birth ⇒ Object
The individual's date of birth.
2166 2167 2168 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2166 def date_of_birth @date_of_birth end |
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
2168 2169 2170 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2168 def documents @documents end |
#email ⇒ Object
The individual's email address. You can only set this field when the Account is configured as a merchant or recipient. Use contact_email as the primary contact email for this Account.
2170 2171 2172 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2170 def email @email end |
#given_name ⇒ Object
The individual's first name.
2172 2173 2174 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2172 def given_name @given_name end |
#id_numbers ⇒ Object
The identification numbers (e.g., SSN) associated with the individual.
2174 2175 2176 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2174 def id_numbers @id_numbers end |
#legal_gender ⇒ Object
The individual's gender (International regulations require either "male" or "female").
2176 2177 2178 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2176 def legal_gender @legal_gender end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
2178 2179 2180 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2178 def @metadata end |
#nationalities ⇒ Object
The countries where the individual is a national. Two-letter country code (ISO 3166-1 alpha-2).
2180 2181 2182 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2180 def nationalities @nationalities end |
#phone ⇒ Object
The individual's phone number.
2182 2183 2184 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2182 def phone @phone end |
#political_exposure ⇒ Object
The individual's political exposure.
2184 2185 2186 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2184 def political_exposure @political_exposure end |
#relationship ⇒ Object
The relationship that this individual has with the account's identity.
2186 2187 2188 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2186 def relationship @relationship end |
#script_addresses ⇒ Object
The script addresses (e.g., non-Latin characters) associated with the individual.
2188 2189 2190 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2188 def script_addresses @script_addresses end |
#script_names ⇒ Object
The individuals primary name in non latin script.
2190 2191 2192 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2190 def script_names @script_names end |
#surname ⇒ Object
The individual's last name.
2192 2193 2194 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2192 def surname @surname end |
Class Method Details
.field_encodings ⇒ Object
2232 2233 2234 2235 2236 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2232 def self.field_encodings @field_encodings = { relationship: { kind: :object, fields: { percent_ownership: :decimal_string } }, } end |