Class: Stripe::V2::Core::AccountUpdateParams::Identity::Individual::Documents

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: CompanyAuthorization, Passport, PrimaryVerification, SecondaryVerification, Visa

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(company_authorization: nil, passport: nil, primary_verification: nil, secondary_verification: nil, visa: nil) ⇒ Documents

Returns a new instance of Documents.



5928
5929
5930
5931
5932
5933
5934
5935
5936
5937
5938
5939
5940
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 5928

def initialize(
  company_authorization: nil,
  passport: nil,
  primary_verification: nil,
  secondary_verification: nil,
  visa: nil
)
  @company_authorization = company_authorization
  @passport = passport
  @primary_verification = primary_verification
  @secondary_verification = secondary_verification
  @visa = visa
end

Instance Attribute Details

#company_authorizationObject

One or more documents that demonstrate proof that this person is authorized to represent the company.



5918
5919
5920
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 5918

def company_authorization
  @company_authorization
end

#passportObject

One or more documents showing the person's passport page with photo and personal data.



5920
5921
5922
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 5920

def passport
  @passport
end

#primary_verificationObject

An identifying document showing the person's name, either a passport or local ID card.



5922
5923
5924
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 5922

def primary_verification
  @primary_verification
end

#secondary_verificationObject

A document showing address, either a passport, local ID card, or utility bill from a well-known utility company.



5924
5925
5926
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 5924

def secondary_verification
  @secondary_verification
end

#visaObject

One or more documents showing the person's visa required for living in the country where they are residing.



5926
5927
5928
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 5926

def visa
  @visa
end