Class: Stripe::V2::Core::AccountUpdateParams::Identity::Individual::Documents::Passport
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity::Individual::Documents::Passport
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Instance Attribute Summary collapse
-
#files ⇒ Object
One or more document IDs returned by a file upload with a purpose value of
account_requirement. -
#type ⇒ Object
The format of the document.
Instance Method Summary collapse
-
#initialize(files: nil, type: nil) ⇒ Passport
constructor
A new instance of Passport.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(files: nil, type: nil) ⇒ Passport
Returns a new instance of Passport.
1860 1861 1862 1863 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1860 def initialize(files: nil, type: nil) @files = files @type = type end |
Instance Attribute Details
#files ⇒ Object
One or more document IDs returned by a file upload with a purpose value of account_requirement.
1856 1857 1858 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1856 def files @files end |
#type ⇒ Object
The format of the document. Currently supports files only.
1858 1859 1860 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1858 def type @type end |