Class: Stripe::V2::Core::AccountUpdateParams::Identity::Individual::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, new, #to_h

Constructor Details

#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship

Returns a new instance of Relationship.



2025
2026
2027
2028
2029
2030
2031
2032
2033
2034
2035
2036
2037
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2025

def initialize(
  director: nil,
  executive: nil,
  owner: nil,
  percent_ownership: nil,
  title: nil
)
  @director = director
  @executive = executive
  @owner = owner
  @percent_ownership = percent_ownership
  @title = title
end

Instance Attribute Details

#director ⇒ Object

Whether the person is a director of the account's identity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



2015
2016
2017
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2015

def director
  @director
end

#executive ⇒ Object

Whether the person has significant responsibility to control, manage, or direct the organization.



2017
2018
2019
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2017

def executive
  @executive
end

#owner ⇒ Object

Whether the person is an owner of the account's identity.



2019
2020
2021
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2019

def owner
  @owner
end

#percent_ownership ⇒ Object

The percent owned by the person of the account's legal entity.



2021
2022
2023
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2021

def percent_ownership
  @percent_ownership
end

#title ⇒ Object

The person's title (e.g., CEO, Support Engineer).



2023
2024
2025
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2023

def title
  @title
end

Class Method Details

.field_encodings ⇒ Object



2039
2040
2041
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2039

def self.field_encodings
  @field_encodings = { percent_ownership: :decimal_string }
end