Class: Stripe::V2::Core::Accounts::PersonCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::Accounts::PersonCreateParams
- Defined in:
- lib/stripe/params/v2/core/accounts/person_create_params.rb
Defined Under Namespace
Classes: AdditionalAddress, AdditionalName, AdditionalTermsOfService, Address, DateOfBirth, Documents, IdNumber, Relationship, ScriptAddresses, ScriptNames
Instance Attribute Summary collapse
-
#additional_addresses ⇒ Object
Additional addresses associated with the person.
-
#additional_names ⇒ Object
Additional names (e.g. aliases) associated with the person.
-
#additional_terms_of_service ⇒ Object
Attestations of accepted terms of service agreements.
-
#address ⇒ Object
The person’s residential address.
-
#date_of_birth ⇒ Object
The person’s date of birth.
-
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
-
#email ⇒ Object
Email.
-
#given_name ⇒ Object
The person’s first name.
-
#id_numbers ⇒ Object
The identification numbers (e.g., SSN) associated with the person.
-
#legal_gender ⇒ Object
The person’s gender (International regulations require either “male” or “female”).
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#nationalities ⇒ Object
The nationalities (countries) this person is associated with.
-
#person_token ⇒ Object
The person token generated by the person token api.
-
#phone ⇒ Object
The phone number for this person.
-
#political_exposure ⇒ Object
The person’s political exposure.
-
#relationship ⇒ Object
The relationship that this person has with the Account’s business or legal entity.
-
#script_addresses ⇒ Object
The script addresses (e.g., non-Latin characters) associated with the person.
-
#script_names ⇒ Object
The script names (e.g. non-Latin characters) associated with the person.
-
#surname ⇒ Object
The person’s last name.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(additional_addresses: nil, additional_names: nil, additional_terms_of_service: nil, address: nil, date_of_birth: nil, documents: nil, email: nil, given_name: nil, id_numbers: nil, legal_gender: nil, metadata: nil, nationalities: nil, person_token: nil, phone: nil, political_exposure: nil, relationship: nil, script_addresses: nil, script_names: nil, surname: nil) ⇒ PersonCreateParams
constructor
A new instance of PersonCreateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(additional_addresses: nil, additional_names: nil, additional_terms_of_service: nil, address: nil, date_of_birth: nil, documents: nil, email: nil, given_name: nil, id_numbers: nil, legal_gender: nil, metadata: nil, nationalities: nil, person_token: nil, phone: nil, political_exposure: nil, relationship: nil, script_addresses: nil, script_names: nil, surname: nil) ⇒ PersonCreateParams
Returns a new instance of PersonCreateParams.
456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 |
# File 'lib/stripe/params/v2/core/accounts/person_create_params.rb', line 456 def initialize( additional_addresses: nil, additional_names: nil, additional_terms_of_service: nil, address: nil, date_of_birth: nil, documents: nil, email: nil, given_name: nil, id_numbers: nil, legal_gender: nil, metadata: nil, nationalities: nil, person_token: nil, phone: nil, political_exposure: nil, relationship: nil, script_addresses: nil, script_names: nil, surname: nil ) @additional_addresses = additional_addresses @additional_names = additional_names @additional_terms_of_service = additional_terms_of_service @address = address @date_of_birth = date_of_birth @documents = documents @email = email @given_name = given_name @id_numbers = id_numbers @legal_gender = legal_gender @metadata = @nationalities = nationalities @person_token = person_token @phone = phone @political_exposure = political_exposure @relationship = relationship @script_addresses = script_addresses @script_names = script_names @surname = surname end |
Instance Attribute Details
#additional_addresses ⇒ Object
Additional addresses associated with the person.
418 419 420 |
# File 'lib/stripe/params/v2/core/accounts/person_create_params.rb', line 418 def additional_addresses @additional_addresses end |
#additional_names ⇒ Object
Additional names (e.g. aliases) associated with the person.
420 421 422 |
# File 'lib/stripe/params/v2/core/accounts/person_create_params.rb', line 420 def additional_names @additional_names end |
#additional_terms_of_service ⇒ Object
Attestations of accepted terms of service agreements.
422 423 424 |
# File 'lib/stripe/params/v2/core/accounts/person_create_params.rb', line 422 def additional_terms_of_service @additional_terms_of_service end |
#address ⇒ Object
The person’s residential address.
424 425 426 |
# File 'lib/stripe/params/v2/core/accounts/person_create_params.rb', line 424 def address @address end |
#date_of_birth ⇒ Object
The person’s date of birth.
426 427 428 |
# File 'lib/stripe/params/v2/core/accounts/person_create_params.rb', line 426 def date_of_birth @date_of_birth end |
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
428 429 430 |
# File 'lib/stripe/params/v2/core/accounts/person_create_params.rb', line 428 def documents @documents end |
#email ⇒ Object
Email.
430 431 432 |
# File 'lib/stripe/params/v2/core/accounts/person_create_params.rb', line 430 def email @email end |
#given_name ⇒ Object
The person’s first name.
432 433 434 |
# File 'lib/stripe/params/v2/core/accounts/person_create_params.rb', line 432 def given_name @given_name end |
#id_numbers ⇒ Object
The identification numbers (e.g., SSN) associated with the person.
434 435 436 |
# File 'lib/stripe/params/v2/core/accounts/person_create_params.rb', line 434 def id_numbers @id_numbers end |
#legal_gender ⇒ Object
The person’s gender (International regulations require either “male” or “female”).
436 437 438 |
# File 'lib/stripe/params/v2/core/accounts/person_create_params.rb', line 436 def legal_gender @legal_gender end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
438 439 440 |
# File 'lib/stripe/params/v2/core/accounts/person_create_params.rb', line 438 def @metadata end |
#nationalities ⇒ Object
The nationalities (countries) this person is associated with.
440 441 442 |
# File 'lib/stripe/params/v2/core/accounts/person_create_params.rb', line 440 def nationalities @nationalities end |
#person_token ⇒ Object
The person token generated by the person token api.
442 443 444 |
# File 'lib/stripe/params/v2/core/accounts/person_create_params.rb', line 442 def person_token @person_token end |
#phone ⇒ Object
The phone number for this person.
444 445 446 |
# File 'lib/stripe/params/v2/core/accounts/person_create_params.rb', line 444 def phone @phone end |
#political_exposure ⇒ Object
The person’s political exposure.
446 447 448 |
# File 'lib/stripe/params/v2/core/accounts/person_create_params.rb', line 446 def political_exposure @political_exposure end |
#relationship ⇒ Object
The relationship that this person has with the Account’s business or legal entity.
448 449 450 |
# File 'lib/stripe/params/v2/core/accounts/person_create_params.rb', line 448 def relationship @relationship end |
#script_addresses ⇒ Object
The script addresses (e.g., non-Latin characters) associated with the person.
450 451 452 |
# File 'lib/stripe/params/v2/core/accounts/person_create_params.rb', line 450 def script_addresses @script_addresses end |
#script_names ⇒ Object
The script names (e.g. non-Latin characters) associated with the person.
452 453 454 |
# File 'lib/stripe/params/v2/core/accounts/person_create_params.rb', line 452 def script_names @script_names end |
#surname ⇒ Object
The person’s last name.
454 455 456 |
# File 'lib/stripe/params/v2/core/accounts/person_create_params.rb', line 454 def surname @surname end |
Class Method Details
.field_encodings ⇒ Object
498 499 500 501 502 |
# File 'lib/stripe/params/v2/core/accounts/person_create_params.rb', line 498 def self.field_encodings @field_encodings = { relationship: { kind: :object, fields: { percent_ownership: :decimal_string } }, } end |