Class: Stripe::V2::Core::Accounts::PersonService::CreateParams::Relationship
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::Accounts::PersonService::CreateParams::Relationship
- Defined in:
- lib/stripe/services/v2/core/accounts/person_service.rb
Instance Attribute Summary collapse
-
#authorizer ⇒ Object
Whether the individual is an authorizer of the Account’s legal entity.
-
#director ⇒ Object
Indicates whether the person is a director of the associated legal entity.
-
#executive ⇒ Object
Indicates whether the person is an executive of the associated legal entity.
-
#legal_guardian ⇒ Object
Indicates whether the person is a legal guardian of the associated legal entity.
-
#owner ⇒ Object
Indicates whether the person is an owner of the associated legal entity.
-
#percent_ownership ⇒ Object
The percentage of ownership the person has in the associated legal entity.
-
#representative ⇒ Object
Indicates whether the person is a representative of the associated legal entity.
-
#title ⇒ Object
The title or position the person holds in the associated legal entity.
Instance Method Summary collapse
-
#initialize(authorizer: nil, director: nil, executive: nil, legal_guardian: nil, owner: nil, percent_ownership: nil, representative: nil, title: nil) ⇒ Relationship
constructor
A new instance of Relationship.
Methods inherited from RequestParams
Constructor Details
#initialize(authorizer: nil, director: nil, executive: nil, legal_guardian: nil, owner: nil, percent_ownership: nil, representative: nil, title: nil) ⇒ Relationship
Returns a new instance of Relationship.
287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 |
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 287 def initialize( authorizer: nil, director: nil, executive: nil, legal_guardian: nil, owner: nil, percent_ownership: nil, representative: nil, title: nil ) @authorizer = @director = director @executive = executive @legal_guardian = legal_guardian @owner = owner @percent_ownership = percent_ownership @representative = representative @title = title end |
Instance Attribute Details
#authorizer ⇒ Object
Whether the individual is an authorizer of the Account’s legal entity.
271 272 273 |
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 271 def @authorizer end |
#director ⇒ Object
Indicates whether the person is a director of the associated legal entity.
273 274 275 |
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 273 def director @director end |
#executive ⇒ Object
Indicates whether the person is an executive of the associated legal entity.
275 276 277 |
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 275 def executive @executive end |
#legal_guardian ⇒ Object
Indicates whether the person is a legal guardian of the associated legal entity.
277 278 279 |
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 277 def legal_guardian @legal_guardian end |
#owner ⇒ Object
Indicates whether the person is an owner of the associated legal entity.
279 280 281 |
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 279 def owner @owner end |
#percent_ownership ⇒ Object
The percentage of ownership the person has in the associated legal entity.
281 282 283 |
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 281 def percent_ownership @percent_ownership end |
#representative ⇒ Object
Indicates whether the person is a representative of the associated legal entity.
283 284 285 |
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 283 def representative @representative end |
#title ⇒ Object
The title or position the person holds in the associated legal entity.
285 286 287 |
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 285 def title @title end |