Class: Stripe::V2::Core::Accounts::PersonService::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::Accounts::PersonService::ListParams
- Defined in:
- lib/stripe/services/v2/core/accounts/person_service.rb
Instance Attribute Summary collapse
-
#limit ⇒ Object
The upper limit on the number of accounts returned by the List Account request.
Instance Method Summary collapse
-
#initialize(limit: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(limit: nil) ⇒ ListParams
Returns a new instance of ListParams.
498 499 500 |
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 498 def initialize(limit: nil) @limit = limit end |
Instance Attribute Details
#limit ⇒ Object
The upper limit on the number of accounts returned by the List Account request.
496 497 498 |
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 496 def limit @limit end |