Class: Stripe::V2::Core::Accounts::PersonService::UpdateParams::Relationship
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::Accounts::PersonService::UpdateParams::Relationship
- Defined in:
- lib/stripe/services/v2/core/accounts/person_service.rb
Instance Attribute Summary collapse
-
#authorizer ⇒ Object
Whether the individual is an authorizer of the Account’s legal entity.
-
#director ⇒ Object
Indicates whether the person is a director of the associated legal entity.
-
#executive ⇒ Object
Indicates whether the person is an executive of the associated legal entity.
-
#legal_guardian ⇒ Object
Indicates whether the person is a legal guardian of the associated legal entity.
-
#owner ⇒ Object
Indicates whether the person is an owner of the associated legal entity.
-
#percent_ownership ⇒ Object
The percentage of ownership the person has in the associated legal entity.
-
#representative ⇒ Object
Indicates whether the person is a representative of the associated legal entity.
-
#title ⇒ Object
The title or position the person holds in the associated legal entity.
Instance Method Summary collapse
-
#initialize(authorizer: nil, director: nil, executive: nil, legal_guardian: nil, owner: nil, percent_ownership: nil, representative: nil, title: nil) ⇒ Relationship
constructor
A new instance of Relationship.
Methods inherited from RequestParams
Constructor Details
#initialize(authorizer: nil, director: nil, executive: nil, legal_guardian: nil, owner: nil, percent_ownership: nil, representative: nil, title: nil) ⇒ Relationship
Returns a new instance of Relationship.
773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 |
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 773 def initialize( authorizer: nil, director: nil, executive: nil, legal_guardian: nil, owner: nil, percent_ownership: nil, representative: nil, title: nil ) @authorizer = @director = director @executive = executive @legal_guardian = legal_guardian @owner = owner @percent_ownership = percent_ownership @representative = representative @title = title end |
Instance Attribute Details
#authorizer ⇒ Object
Whether the individual is an authorizer of the Account’s legal entity.
757 758 759 |
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 757 def @authorizer end |
#director ⇒ Object
Indicates whether the person is a director of the associated legal entity.
759 760 761 |
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 759 def director @director end |
#executive ⇒ Object
Indicates whether the person is an executive of the associated legal entity.
761 762 763 |
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 761 def executive @executive end |
#legal_guardian ⇒ Object
Indicates whether the person is a legal guardian of the associated legal entity.
763 764 765 |
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 763 def legal_guardian @legal_guardian end |
#owner ⇒ Object
Indicates whether the person is an owner of the associated legal entity.
765 766 767 |
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 765 def owner @owner end |
#percent_ownership ⇒ Object
The percentage of ownership the person has in the associated legal entity.
767 768 769 |
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 767 def percent_ownership @percent_ownership end |
#representative ⇒ Object
Indicates whether the person is a representative of the associated legal entity.
769 770 771 |
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 769 def representative @representative end |
#title ⇒ Object
The title or position the person holds in the associated legal entity.
771 772 773 |
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 771 def title @title end |