Class: Stripe::V2::Core::BatchJob::StatusDetails::InProgress
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::BatchJob::StatusDetails::InProgress
- Defined in:
- lib/stripe/resources/v2/core/batch_job.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#failure_count ⇒ Object
readonly
The number of records that failed processing so far.
-
#success_count ⇒ Object
readonly
The number of records that were successfully processed so far.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#failure_count ⇒ Object (readonly)
The number of records that failed processing so far.
148 149 150 |
# File 'lib/stripe/resources/v2/core/batch_job.rb', line 148 def failure_count @failure_count end |
#success_count ⇒ Object (readonly)
The number of records that were successfully processed so far.
150 151 152 |
# File 'lib/stripe/resources/v2/core/batch_job.rb', line 150 def success_count @success_count end |
Class Method Details
.field_encodings ⇒ Object
160 161 162 |
# File 'lib/stripe/resources/v2/core/batch_job.rb', line 160 def self.field_encodings @field_encodings = { failure_count: :int64_string, success_count: :int64_string } end |
.field_remappings ⇒ Object
156 157 158 |
# File 'lib/stripe/resources/v2/core/batch_job.rb', line 156 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
152 153 154 |
# File 'lib/stripe/resources/v2/core/batch_job.rb', line 152 def self.inner_class_types @inner_class_types = {} end |