Class: Stripe::V2::Core::BatchJob::StatusDetails::Timeout

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/batch_job.rb

Defined Under Namespace

Classes: OutputFile

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#failure_countObject (readonly)

The total number of records that failed processing.



228
229
230
# File 'lib/stripe/resources/v2/core/batch_job.rb', line 228

def failure_count
  @failure_count
end

#output_fileObject (readonly)

The output file details. If BatchJob is cancelled it’s provided only if there is already output at this point.



230
231
232
# File 'lib/stripe/resources/v2/core/batch_job.rb', line 230

def output_file
  @output_file
end

#success_countObject (readonly)

The total number of records that were successfully processed.



232
233
234
# File 'lib/stripe/resources/v2/core/batch_job.rb', line 232

def success_count
  @success_count
end

Class Method Details

.field_encodingsObject



242
243
244
245
246
247
248
# File 'lib/stripe/resources/v2/core/batch_job.rb', line 242

def self.field_encodings
  @field_encodings = {
    failure_count: :int64_string,
    output_file: { kind: :object, fields: { size: :int64_string } },
    success_count: :int64_string,
  }
end

.field_remappingsObject



238
239
240
# File 'lib/stripe/resources/v2/core/batch_job.rb', line 238

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



234
235
236
# File 'lib/stripe/resources/v2/core/batch_job.rb', line 234

def self.inner_class_types
  @inner_class_types = { output_file: OutputFile }
end