Class: Stripe::V2::Core::BatchJobCreateParams::Endpoint

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/batch_job_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(http_method: nil, path: nil) ⇒ Endpoint

Returns a new instance of Endpoint.



16
17
18
19
# File 'lib/stripe/params/v2/core/batch_job_create_params.rb', line 16

def initialize(http_method: nil, path: nil)
  @http_method = http_method
  @path = path
end

Instance Attribute Details

#http_methodObject

The HTTP method to use when calling the endpoint.



10
11
12
# File 'lib/stripe/params/v2/core/batch_job_create_params.rb', line 10

def http_method
  @http_method
end

#pathObject

The path of the endpoint to run this batch job against. In the form used in the documentation. For instance, for subscription migration this would be ‘/v1/subscriptions/:id/migrate`.



14
15
16
# File 'lib/stripe/params/v2/core/batch_job_create_params.rb', line 14

def path
  @path
end