Class: Stripe::V2::Core::ClaimableSandbox::OnboardingLinkDetails

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/claimable_sandbox.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#expires_atObject (readonly)

The timestamp the onboarding link expires.



22
23
24
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 22

def expires_at
  @expires_at
end

#refresh_urlObject (readonly)

The URL the user will be redirected to if the onboarding link is expired or invalid. The URL specified should attempt to generate a new onboarding link, and re-direct the user to this new onboarding link so that they can proceed with the onboarding flow.



26
27
28
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 26

def refresh_url
  @refresh_url
end

#urlObject (readonly)

URL that will redirect the user to either claim or onboard the claimable sandbox depending on its status.



28
29
30
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 28

def url
  @url
end

Class Method Details

.field_remappingsObject



34
35
36
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 34

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



30
31
32
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 30

def self.inner_class_types
  @inner_class_types = {}
end