Class: Stripe::V2::Core::ClaimableSandbox::OwnerDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::ClaimableSandbox::OwnerDetails
- Defined in:
- lib/stripe/resources/v2/core/claimable_sandbox.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account ⇒ Object
readonly
The ID of the livemode Stripe account that owns the sandbox.
-
#app_install_status ⇒ Object
readonly
Indicates whether the platform app is installed on the sandbox’s livemode owner account.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account ⇒ Object (readonly)
The ID of the livemode Stripe account that owns the sandbox. This field is only set when owner_details.app_install_status is ‘installed`.
42 43 44 |
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 42 def account @account end |
#app_install_status ⇒ Object (readonly)
Indicates whether the platform app is installed on the sandbox’s livemode owner account.
44 45 46 |
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 44 def app_install_status @app_install_status end |
Class Method Details
.field_remappings ⇒ Object
50 51 52 |
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 50 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
46 47 48 |
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 46 def self.inner_class_types @inner_class_types = {} end |