Class: Stripe::V2::Core::ClaimableSandbox::Prefill
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::ClaimableSandbox::Prefill
- Defined in:
- lib/stripe/resources/v2/core/claimable_sandbox.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#country ⇒ Object
readonly
Country in which the account holder resides, or in which the business is legally established.
-
#email ⇒ Object
readonly
Email that this sandbox is meant to be claimed by.
-
#name ⇒ Object
readonly
Name for the sandbox.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#country ⇒ Object (readonly)
Country in which the account holder resides, or in which the business is legally established. Use two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
58 59 60 |
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 58 def country @country end |
#email ⇒ Object (readonly)
Email that this sandbox is meant to be claimed by. Stripe will send an email to this email address before the sandbox expires.
61 62 63 |
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 61 def email @email end |
#name ⇒ Object (readonly)
Name for the sandbox.
63 64 65 |
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 63 def name @name end |
Class Method Details
.field_remappings ⇒ Object
69 70 71 |
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 69 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
65 66 67 |
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 65 def self.inner_class_types @inner_class_types = {} end |