Class: Stripe::V2::Core::ClaimableSandboxCreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/claimable_sandbox_create_params.rb

Defined Under Namespace

Classes: OnboardingLinkDetails, Prefill

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(app_channel: nil, enable_mcp_access: nil, onboarding_link_details: nil, prefill: nil) ⇒ ClaimableSandboxCreateParams

Returns a new instance of ClaimableSandboxCreateParams.



45
46
47
48
49
50
51
52
53
54
55
# File 'lib/stripe/params/v2/core/claimable_sandbox_create_params.rb', line 45

def initialize(
  app_channel: nil,
  enable_mcp_access: nil,
  onboarding_link_details: nil,
  prefill: nil
)
  @app_channel = app_channel
  @enable_mcp_access = enable_mcp_access
  @onboarding_link_details = onboarding_link_details
  @prefill = prefill
end

Instance Attribute Details

#app_channelObject

The app channel that will be used when pre-installing your app on the claimable sandbox. This field defaults to ‘public` if omitted.



37
38
39
# File 'lib/stripe/params/v2/core/claimable_sandbox_create_params.rb', line 37

def app_channel
  @app_channel
end

#enable_mcp_accessObject

If true, returns a key that can be used with [Stripe’s MCP server](docs.stripe.com/mcp).



39
40
41
# File 'lib/stripe/params/v2/core/claimable_sandbox_create_params.rb', line 39

def enable_mcp_access
  @enable_mcp_access
end

Details about the onboarding link.



41
42
43
# File 'lib/stripe/params/v2/core/claimable_sandbox_create_params.rb', line 41

def onboarding_link_details
  @onboarding_link_details
end

#prefillObject

Values that are prefilled when a user claims the sandbox. When a user claims the sandbox, they will be able to update these values.



43
44
45
# File 'lib/stripe/params/v2/core/claimable_sandbox_create_params.rb', line 43

def prefill
  @prefill
end