Class: Stripe::V2::Core::ClaimableSandboxCreateParams::Prefill

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/claimable_sandbox_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(country: nil, email: nil, name: nil) ⇒ Prefill

Returns a new instance of Prefill.



29
30
31
32
33
# File 'lib/stripe/params/v2/core/claimable_sandbox_create_params.rb', line 29

def initialize(country: nil, email: nil, name: nil)
  @country = country
  @email = email
  @name = name
end

Instance Attribute Details

#countryObject

Country in which the account holder resides, or in which the business is legally established. Use two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).



22
23
24
# File 'lib/stripe/params/v2/core/claimable_sandbox_create_params.rb', line 22

def country
  @country
end

#emailObject

Email that this sandbox is meant to be claimed by. Stripe will notify this email address before the sandbox expires.



25
26
27
# File 'lib/stripe/params/v2/core/claimable_sandbox_create_params.rb', line 25

def email
  @email
end

#nameObject

Name for the sandbox.



27
28
29
# File 'lib/stripe/params/v2/core/claimable_sandbox_create_params.rb', line 27

def name
  @name
end