Class: Stripe::V2::Core::ClaimableSandboxRenewOnboardingLinkParams::OnboardingLinkDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::ClaimableSandboxRenewOnboardingLinkParams::OnboardingLinkDetails
- Defined in:
- lib/stripe/params/v2/core/claimable_sandbox_renew_onboarding_link_params.rb
Instance Attribute Summary collapse
-
#refresh_url ⇒ Object
The URL the user will be redirected to if the onboarding link is expired or invalid.
Instance Method Summary collapse
-
#initialize(refresh_url: nil) ⇒ OnboardingLinkDetails
constructor
A new instance of OnboardingLinkDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(refresh_url: nil) ⇒ OnboardingLinkDetails
Returns a new instance of OnboardingLinkDetails.
14 15 16 |
# File 'lib/stripe/params/v2/core/claimable_sandbox_renew_onboarding_link_params.rb', line 14 def initialize(refresh_url: nil) @refresh_url = refresh_url end |
Instance Attribute Details
#refresh_url ⇒ Object
The URL the user will be redirected to if the onboarding link is expired or invalid. The URL specified should attempt to generate a new onboarding link, and re-direct the user to this new onboarding link so that they can proceed with the onboarding flow.
12 13 14 |
# File 'lib/stripe/params/v2/core/claimable_sandbox_renew_onboarding_link_params.rb', line 12 def refresh_url @refresh_url end |