Class: Stripe::V2::Core::ClaimableSandboxService::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/core/claimable_sandbox_service.rb

Defined Under Namespace

Classes: Prefill

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(enable_mcp_access: nil, prefill: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



30
31
32
33
# File 'lib/stripe/services/v2/core/claimable_sandbox_service.rb', line 30

def initialize(enable_mcp_access: nil, prefill: nil)
  @enable_mcp_access = enable_mcp_access
  @prefill = prefill
end

Instance Attribute Details

#enable_mcp_accessObject

If true, returns a key that can be used with [Stripe’s MCP server](docs.stripe.com/mcp).



26
27
28
# File 'lib/stripe/services/v2/core/claimable_sandbox_service.rb', line 26

def enable_mcp_access
  @enable_mcp_access
end

#prefillObject

Values that are prefilled when a user claims the sandbox.



28
29
30
# File 'lib/stripe/services/v2/core/claimable_sandbox_service.rb', line 28

def prefill
  @prefill
end