Class: Stripe::V2::Core::ClaimableSandboxService::CreateParams::Prefill

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/core/claimable_sandbox_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(country: nil, email: nil, name: nil) ⇒ Prefill

Returns a new instance of Prefill.



19
20
21
22
23
# File 'lib/stripe/services/v2/core/claimable_sandbox_service.rb', line 19

def initialize(country: nil, email: nil, name: nil)
  @country = country
  @email = email
  @name = name
end

Instance Attribute Details

#countryObject

Country in which the account holder resides, or in which the business is legally established. Use two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).



12
13
14
# File 'lib/stripe/services/v2/core/claimable_sandbox_service.rb', line 12

def country
  @country
end

#emailObject

Email that this sandbox is meant to be claimed by. Stripe will notify this email address before the sandbox expires.



15
16
17
# File 'lib/stripe/services/v2/core/claimable_sandbox_service.rb', line 15

def email
  @email
end

#nameObject

Name for the sandbox. If not provided, this will be generated.



17
18
19
# File 'lib/stripe/services/v2/core/claimable_sandbox_service.rb', line 17

def name
  @name
end