Class: Stripe::V2::Core::ConnectionSession

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/core/connection_session.rb

Overview

A short-lived, single-use session used to launch client-side Link onboarding that connects an Account to a Link consumer account.

Defined Under Namespace

Classes: Connection

Constant Summary collapse

OBJECT_NAME =
"v2.core.connection_session"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#accountObject (readonly)

The Account this Connection Session was created for.



30
31
32
# File 'lib/stripe/resources/v2/core/connection_session.rb', line 30

def 
  @account
end

#allowed_connection_typesObject (readonly)

The Connection types that the Connection Session is allowed to establish.



32
33
34
# File 'lib/stripe/resources/v2/core/connection_session.rb', line 32

def allowed_connection_types
  @allowed_connection_types
end

#client_secretObject (readonly)

The client secret of this Connection Session. Used on the client to set up secure access to the given Account.



34
35
36
# File 'lib/stripe/resources/v2/core/connection_session.rb', line 34

def client_secret
  @client_secret
end

#connectionObject (readonly)

The Connection created by the ConnectionSession.



36
37
38
# File 'lib/stripe/resources/v2/core/connection_session.rb', line 36

def connection
  @connection
end

#createdObject (readonly)

Time at which the ConnectionSession was created.



38
39
40
# File 'lib/stripe/resources/v2/core/connection_session.rb', line 38

def created
  @created
end

#idObject (readonly)

The unique identifier for this ConnectionSession.



40
41
42
# File 'lib/stripe/resources/v2/core/connection_session.rb', line 40

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



42
43
44
# File 'lib/stripe/resources/v2/core/connection_session.rb', line 42

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



44
45
46
# File 'lib/stripe/resources/v2/core/connection_session.rb', line 44

def object
  @object
end

#requested_accessObject (readonly)

The access that is collected with the Connection Session.



46
47
48
# File 'lib/stripe/resources/v2/core/connection_session.rb', line 46

def requested_access
  @requested_access
end

Class Method Details

.field_remappingsObject



52
53
54
# File 'lib/stripe/resources/v2/core/connection_session.rb', line 52

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



48
49
50
# File 'lib/stripe/resources/v2/core/connection_session.rb', line 48

def self.inner_class_types
  @inner_class_types = { connection: Connection }
end

.object_nameObject



11
12
13
# File 'lib/stripe/resources/v2/core/connection_session.rb', line 11

def self.object_name
  "v2.core.connection_session"
end