Class: Stripe::V2::Core::ConnectionSessionCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::ConnectionSessionCreateParams
- Defined in:
- lib/stripe/params/v2/core/connection_session_create_params.rb
Instance Attribute Summary collapse
-
#account ⇒ Object
The Account the ConnectionSession will create a connection for.
-
#allowed_connection_types ⇒ Object
The Connection types that the ConnectionSession is allowed to establish.
-
#requested_access ⇒ Object
The access that should be collected with the ConnectionSession.
Instance Method Summary collapse
-
#initialize(account: nil, allowed_connection_types: nil, requested_access: nil) ⇒ ConnectionSessionCreateParams
constructor
A new instance of ConnectionSessionCreateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(account: nil, allowed_connection_types: nil, requested_access: nil) ⇒ ConnectionSessionCreateParams
Returns a new instance of ConnectionSessionCreateParams.
15 16 17 18 19 |
# File 'lib/stripe/params/v2/core/connection_session_create_params.rb', line 15 def initialize(account: nil, allowed_connection_types: nil, requested_access: nil) @account = account @allowed_connection_types = allowed_connection_types @requested_access = requested_access end |
Instance Attribute Details
#account ⇒ Object
The Account the ConnectionSession will create a connection for.
9 10 11 |
# File 'lib/stripe/params/v2/core/connection_session_create_params.rb', line 9 def account @account end |
#allowed_connection_types ⇒ Object
The Connection types that the ConnectionSession is allowed to establish.
11 12 13 |
# File 'lib/stripe/params/v2/core/connection_session_create_params.rb', line 11 def allowed_connection_types @allowed_connection_types end |
#requested_access ⇒ Object
The access that should be collected with the ConnectionSession.
13 14 15 |
# File 'lib/stripe/params/v2/core/connection_session_create_params.rb', line 13 def requested_access @requested_access end |