Class: Stripe::V2::Core::EventDestinationCreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/event_destination_create_params.rb

Defined Under Namespace

Classes: AmazonEventbridge, AzureEventGrid, WebhookEndpoint

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h

Constructor Details

#initialize(amazon_eventbridge: nil, azure_event_grid: nil, description: nil, enabled_events: nil, event_payload: nil, events_from: nil, include: nil, metadata: nil, name: nil, snapshot_api_version: nil, type: nil, webhook_endpoint: nil) ⇒ EventDestinationCreateParams

Returns a new instance of EventDestinationCreateParams.



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/stripe/params/v2/core/event_destination_create_params.rb', line 76

def initialize(
  amazon_eventbridge: nil,
  azure_event_grid: nil,
  description: nil,
  enabled_events: nil,
  event_payload: nil,
  events_from: nil,
  include: nil,
  metadata: nil,
  name: nil,
  snapshot_api_version: nil,
  type: nil,
  webhook_endpoint: nil
)
  @amazon_eventbridge = amazon_eventbridge
  @azure_event_grid = azure_event_grid
  @description = description
  @enabled_events = enabled_events
  @event_payload = event_payload
  @events_from = events_from
  @include = include
  @metadata = 
  @name = name
  @snapshot_api_version = snapshot_api_version
  @type = type
  @webhook_endpoint = webhook_endpoint
end

Instance Attribute Details

#amazon_eventbridge ⇒ Object

AWS account and region where Stripe creates the EventBridge partner event source.



48
49
50
# File 'lib/stripe/params/v2/core/event_destination_create_params.rb', line 48

def amazon_eventbridge
  @amazon_eventbridge
end

#azure_event_grid ⇒ Object

Azure subscription, resource group, and region where Stripe creates the partner topic.



50
51
52
# File 'lib/stripe/params/v2/core/event_destination_create_params.rb', line 50

def azure_event_grid
  @azure_event_grid
end

#description ⇒ Object

An optional user-defined description of the destination's purpose.



52
53
54
# File 'lib/stripe/params/v2/core/event_destination_create_params.rb', line 52

def description
  @description
end

#enabled_events ⇒ Object

The list of event types enabled for delivery to this destination.



54
55
56
# File 'lib/stripe/params/v2/core/event_destination_create_params.rb', line 54

def enabled_events
  @enabled_events
end

#event_payload ⇒ Object

Whether to deliver as snapshot or thin events.



56
57
58
# File 'lib/stripe/params/v2/core/event_destination_create_params.rb', line 56

def event_payload
  @event_payload
end

#events_from ⇒ Object

The account or organization scopes that can supply events. Use this with enabled_events to define the subscription. @self: Receive events from the account that owns the event destination. @accounts: Receive events emitted from other accounts you manage, including your v1 and v2 accounts. @organization_members: Receive events from accounts directly linked to the organization. @organization_members/@accounts: Receive events from all accounts connected to any platform accounts in the organization.



62
63
64
# File 'lib/stripe/params/v2/core/event_destination_create_params.rb', line 62

def events_from
  @events_from
end

#include ⇒ Object

Include normally redacted webhook fields in the create response. Public API clients must include webhook_endpoint.signing_secret to receive the signing secret.



64
65
66
# File 'lib/stripe/params/v2/core/event_destination_create_params.rb', line 64

def include
  @include
end

#metadata ⇒ Object

User-defined key/value data for the destination.



66
67
68
# File 'lib/stripe/params/v2/core/event_destination_create_params.rb', line 66

def 
  @metadata
end

#name ⇒ Object

A user-defined label for identifying the destination.



68
69
70
# File 'lib/stripe/params/v2/core/event_destination_create_params.rb', line 68

def name
  @name
end

#snapshot_api_version ⇒ Object

For snapshot events only, the Stripe API version used to render event objects; do not provide this for thin events.



70
71
72
# File 'lib/stripe/params/v2/core/event_destination_create_params.rb', line 70

def snapshot_api_version
  @snapshot_api_version
end

#type ⇒ Object

The delivery transport. Chosen when the destination is created and cannot be changed by update.



72
73
74
# File 'lib/stripe/params/v2/core/event_destination_create_params.rb', line 72

def type
  @type
end

#webhook_endpoint ⇒ Object

Delivery target for the webhook endpoint. Live mode requires HTTPS; sandbox mode also supports HTTP.



74
75
76
# File 'lib/stripe/params/v2/core/event_destination_create_params.rb', line 74

def webhook_endpoint
  @webhook_endpoint
end