Class: Stripe::V2::Core::EventDestinationService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::EventDestinationService::CreateParams
- Defined in:
- lib/stripe/services/v2/core/event_destination_service.rb
Defined Under Namespace
Classes: AmazonEventbridge, WebhookEndpoint
Instance Attribute Summary collapse
-
#amazon_eventbridge ⇒ Object
Amazon EventBridge configuration.
-
#description ⇒ Object
An optional description of what the event destination is used for.
-
#enabled_events ⇒ Object
The list of events to enable for this endpoint.
-
#event_payload ⇒ Object
Payload type of events being subscribed to.
-
#events_from ⇒ Object
Where events should be routed from.
-
#include ⇒ Object
Additional fields to include in the response.
-
#metadata ⇒ Object
Metadata.
-
#name ⇒ Object
Event destination name.
-
#snapshot_api_version ⇒ Object
If using the snapshot event payload, the API version events are rendered as.
-
#type ⇒ Object
Event destination type.
-
#webhook_endpoint ⇒ Object
Webhook endpoint configuration.
Instance Method Summary collapse
-
#initialize(description: nil, enabled_events: nil, event_payload: nil, events_from: nil, include: nil, metadata: nil, name: nil, snapshot_api_version: nil, type: nil, amazon_eventbridge: nil, webhook_endpoint: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(description: nil, enabled_events: nil, event_payload: nil, events_from: nil, include: nil, metadata: nil, name: nil, snapshot_api_version: nil, type: nil, amazon_eventbridge: nil, webhook_endpoint: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/stripe/services/v2/core/event_destination_service.rb', line 64 def initialize( description: nil, enabled_events: nil, event_payload: nil, events_from: nil, include: nil, metadata: nil, name: nil, snapshot_api_version: nil, type: nil, amazon_eventbridge: nil, webhook_endpoint: nil ) @description = description @enabled_events = enabled_events @event_payload = event_payload @events_from = events_from @include = include @metadata = @name = name @snapshot_api_version = snapshot_api_version @type = type @amazon_eventbridge = amazon_eventbridge @webhook_endpoint = webhook_endpoint end |
Instance Attribute Details
#amazon_eventbridge ⇒ Object
Amazon EventBridge configuration.
60 61 62 |
# File 'lib/stripe/services/v2/core/event_destination_service.rb', line 60 def amazon_eventbridge @amazon_eventbridge end |
#description ⇒ Object
An optional description of what the event destination is used for.
42 43 44 |
# File 'lib/stripe/services/v2/core/event_destination_service.rb', line 42 def description @description end |
#enabled_events ⇒ Object
The list of events to enable for this endpoint.
44 45 46 |
# File 'lib/stripe/services/v2/core/event_destination_service.rb', line 44 def enabled_events @enabled_events end |
#event_payload ⇒ Object
Payload type of events being subscribed to.
46 47 48 |
# File 'lib/stripe/services/v2/core/event_destination_service.rb', line 46 def event_payload @event_payload end |
#events_from ⇒ Object
Where events should be routed from.
48 49 50 |
# File 'lib/stripe/services/v2/core/event_destination_service.rb', line 48 def events_from @events_from end |
#include ⇒ Object
Additional fields to include in the response.
50 51 52 |
# File 'lib/stripe/services/v2/core/event_destination_service.rb', line 50 def include @include end |
#metadata ⇒ Object
Metadata.
52 53 54 |
# File 'lib/stripe/services/v2/core/event_destination_service.rb', line 52 def @metadata end |
#name ⇒ Object
Event destination name.
54 55 56 |
# File 'lib/stripe/services/v2/core/event_destination_service.rb', line 54 def name @name end |
#snapshot_api_version ⇒ Object
If using the snapshot event payload, the API version events are rendered as.
56 57 58 |
# File 'lib/stripe/services/v2/core/event_destination_service.rb', line 56 def snapshot_api_version @snapshot_api_version end |
#type ⇒ Object
Event destination type.
58 59 60 |
# File 'lib/stripe/services/v2/core/event_destination_service.rb', line 58 def type @type end |
#webhook_endpoint ⇒ Object
Webhook endpoint configuration.
62 63 64 |
# File 'lib/stripe/services/v2/core/event_destination_service.rb', line 62 def webhook_endpoint @webhook_endpoint end |