Class: Stripe::V2::Core::EventDestinationService::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/core/event_destination_service.rb

Defined Under Namespace

Classes: WebhookEndpoint

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, enabled_events: nil, include: nil, metadata: nil, name: nil, webhook_endpoint: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
# File 'lib/stripe/services/v2/core/event_destination_service.rb', line 128

def initialize(
  description: nil,
  enabled_events: nil,
  include: nil,
  metadata: nil,
  name: nil,
  webhook_endpoint: nil
)
  @description = description
  @enabled_events = enabled_events
  @include = include
  @metadata = 
  @name = name
  @webhook_endpoint = webhook_endpoint
end

Instance Attribute Details

#descriptionObject

An optional description of what the event destination is used for.



116
117
118
# File 'lib/stripe/services/v2/core/event_destination_service.rb', line 116

def description
  @description
end

#enabled_eventsObject

The list of events to enable for this endpoint.



118
119
120
# File 'lib/stripe/services/v2/core/event_destination_service.rb', line 118

def enabled_events
  @enabled_events
end

#includeObject

Additional fields to include in the response. Currently supports ‘webhook_endpoint.url`.



120
121
122
# File 'lib/stripe/services/v2/core/event_destination_service.rb', line 120

def include
  @include
end

#metadataObject

Metadata.



122
123
124
# File 'lib/stripe/services/v2/core/event_destination_service.rb', line 122

def 
  @metadata
end

#nameObject

Event destination name.



124
125
126
# File 'lib/stripe/services/v2/core/event_destination_service.rb', line 124

def name
  @name
end

#webhook_endpointObject

Webhook endpoint configuration.



126
127
128
# File 'lib/stripe/services/v2/core/event_destination_service.rb', line 126

def webhook_endpoint
  @webhook_endpoint
end