Class: Stripe::V2::Core::FeeBatch

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/core/fee_batch.rb

Overview

A FeeBatch represents a settlement grouping of fees. It bridges the fee domain with actual money movement, tracking what was settled and how.

Defined Under Namespace

Classes: Adjustments, Amount, CollectedBy, CollectionRecord, StatusTransitions, Tax

Constant Summary collapse

OBJECT_NAME =
"v2.core.fee_batch"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#adjustmentsObject (readonly)

Adjustments applied to this batch.



186
187
188
# File 'lib/stripe/resources/v2/core/fee_batch.rb', line 186

def adjustments
  @adjustments
end

#amountObject (readonly)

The total fee amount billed in this batch.



188
189
190
# File 'lib/stripe/resources/v2/core/fee_batch.rb', line 188

def amount
  @amount
end

#collected_byObject (readonly)

The entity that collected this batch.



190
191
192
# File 'lib/stripe/resources/v2/core/fee_batch.rb', line 190

def collected_by
  @collected_by
end

#collection_recordsObject (readonly)

The money movement records associated with collecting this batch.



192
193
194
# File 'lib/stripe/resources/v2/core/fee_batch.rb', line 192

def collection_records
  @collection_records
end

#createdObject (readonly)

Timestamp of when this batch was created.



194
195
196
# File 'lib/stripe/resources/v2/core/fee_batch.rb', line 194

def created
  @created
end

#idObject (readonly)

Unique identifier for the FeeBatch.



196
197
198
# File 'lib/stripe/resources/v2/core/fee_batch.rb', line 196

def id
  @id
end

#livemodeObject (readonly)

Has the value true if the object exists in live mode, or false if in test mode.



198
199
200
# File 'lib/stripe/resources/v2/core/fee_batch.rb', line 198

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object's type. Objects of the same type share the same value of the object field.



200
201
202
# File 'lib/stripe/resources/v2/core/fee_batch.rb', line 200

def object
  @object
end

#statusObject (readonly)

The current state of this batch.



202
203
204
# File 'lib/stripe/resources/v2/core/fee_batch.rb', line 202

def status
  @status
end

#status_transitionsObject (readonly)

Timestamps for each status transition.



204
205
206
# File 'lib/stripe/resources/v2/core/fee_batch.rb', line 204

def status_transitions
  @status_transitions
end

#taxObject (readonly)

The tax amount included in this batch.



206
207
208
# File 'lib/stripe/resources/v2/core/fee_batch.rb', line 206

def tax
  @tax
end

Class Method Details

.field_remappingsObject



219
220
221
# File 'lib/stripe/resources/v2/core/fee_batch.rb', line 219

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



208
209
210
211
212
213
214
215
216
217
# File 'lib/stripe/resources/v2/core/fee_batch.rb', line 208

def self.inner_class_types
  @inner_class_types = {
    adjustments: Adjustments,
    amount: Amount,
    collected_by: CollectedBy,
    collection_records: CollectionRecord,
    status_transitions: StatusTransitions,
    tax: Tax,
  }
end

.object_nameObject



11
12
13
# File 'lib/stripe/resources/v2/core/fee_batch.rb', line 11

def self.object_name
  "v2.core.fee_batch"
end