Class: Stripe::V2::Core::FeeEntry
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Core::FeeEntry
- Defined in:
- lib/stripe/resources/v2/core/fee_entry.rb
Overview
A FeeEntry is the atomic, append-only record of an assessed fee.
Defined Under Namespace
Classes: Amount, ChargedBy, IncurredBy, Tax
Constant Summary collapse
- OBJECT_NAME =
"v2.core.fee_entry"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The fee amount.
-
#charged_by ⇒ Object
readonly
The entity that assessed this fee.
-
#created ⇒ Object
readonly
Timestamp of when this fee entry was created.
-
#fee_batch ⇒ Object
readonly
The ID of the FeeBatch that collected this fee, if any.
-
#id ⇒ Object
readonly
Unique identifier for the FeeEntry.
-
#incurred_by ⇒ Object
readonly
The usage event that caused this fee to be assessed.
-
#livemode ⇒ Object
readonly
Has the value
trueif the object exists in live mode, orfalseif in test mode. -
#object ⇒ Object
readonly
String representing the object's type.
-
#reason ⇒ Object
readonly
The reason this fee entry was created.
-
#tax ⇒ Object
readonly
The tax portion of the fee, if applicable.
-
#type ⇒ Object
readonly
The category of this fee.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The fee amount.
136 137 138 |
# File 'lib/stripe/resources/v2/core/fee_entry.rb', line 136 def amount @amount end |
#charged_by ⇒ Object (readonly)
The entity that assessed this fee.
138 139 140 |
# File 'lib/stripe/resources/v2/core/fee_entry.rb', line 138 def charged_by @charged_by end |
#created ⇒ Object (readonly)
Timestamp of when this fee entry was created.
140 141 142 |
# File 'lib/stripe/resources/v2/core/fee_entry.rb', line 140 def created @created end |
#fee_batch ⇒ Object (readonly)
The ID of the FeeBatch that collected this fee, if any.
142 143 144 |
# File 'lib/stripe/resources/v2/core/fee_entry.rb', line 142 def fee_batch @fee_batch end |
#id ⇒ Object (readonly)
Unique identifier for the FeeEntry.
144 145 146 |
# File 'lib/stripe/resources/v2/core/fee_entry.rb', line 144 def id @id end |
#incurred_by ⇒ Object (readonly)
The usage event that caused this fee to be assessed.
146 147 148 |
# File 'lib/stripe/resources/v2/core/fee_entry.rb', line 146 def incurred_by @incurred_by end |
#livemode ⇒ Object (readonly)
Has the value true if the object exists in live mode, or false if in test mode.
148 149 150 |
# File 'lib/stripe/resources/v2/core/fee_entry.rb', line 148 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object's type. Objects of the same type share the same value of the object field.
150 151 152 |
# File 'lib/stripe/resources/v2/core/fee_entry.rb', line 150 def object @object end |
#reason ⇒ Object (readonly)
The reason this fee entry was created.
152 153 154 |
# File 'lib/stripe/resources/v2/core/fee_entry.rb', line 152 def reason @reason end |
#tax ⇒ Object (readonly)
The tax portion of the fee, if applicable.
154 155 156 |
# File 'lib/stripe/resources/v2/core/fee_entry.rb', line 154 def tax @tax end |
#type ⇒ Object (readonly)
The category of this fee.
156 157 158 |
# File 'lib/stripe/resources/v2/core/fee_entry.rb', line 156 def type @type end |
Class Method Details
.field_remappings ⇒ Object
167 168 169 |
# File 'lib/stripe/resources/v2/core/fee_entry.rb', line 167 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
158 159 160 161 162 163 164 165 |
# File 'lib/stripe/resources/v2/core/fee_entry.rb', line 158 def self.inner_class_types @inner_class_types = { amount: Amount, charged_by: ChargedBy, incurred_by: IncurredBy, tax: Tax, } end |
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/v2/core/fee_entry.rb', line 10 def self.object_name "v2.core.fee_entry" end |