Class: Stripe::V2::Core::FeeEntry::ChargedBy

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/v2/core/fee_entry.rb

Defined Under Namespace

Classes: Application, Network, Stripe

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#applicationObject (readonly)

Details for a fee charged by a Connect application.



71
72
73
# File 'lib/stripe/resources/v2/core/fee_entry.rb', line 71

def application
  @application
end

#networkObject (readonly)

Details for a fee charged by the payment network.



73
74
75
# File 'lib/stripe/resources/v2/core/fee_entry.rb', line 73

def network
  @network
end

#stripeObject (readonly)

Details for a fee charged by Stripe.



75
76
77
# File 'lib/stripe/resources/v2/core/fee_entry.rb', line 75

def stripe
  @stripe
end

#typeObject (readonly)

The type of entity that charged this fee.



77
78
79
# File 'lib/stripe/resources/v2/core/fee_entry.rb', line 77

def type
  @type
end

Class Method Details

.field_remappingsObject



83
84
85
# File 'lib/stripe/resources/v2/core/fee_entry.rb', line 83

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



79
80
81
# File 'lib/stripe/resources/v2/core/fee_entry.rb', line 79

def self.inner_class_types
  @inner_class_types = { application: Application, network: Network, stripe: Stripe }
end