Class: Stripe::V2::Core::Health::Alert::AuthorizationRateDrop
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Health::Alert::AuthorizationRateDrop
- Defined in:
- lib/stripe/resources/v2/core/health/alert.rb
Defined Under Namespace
Classes: Dimension
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#charge_type ⇒ Object
readonly
The type of the charge.
-
#current_percentage ⇒ Object
readonly
The current authorization rate percentage.
-
#dimensions ⇒ Object
readonly
Dimensions that describe what subset of payments are impacted.
-
#payment_method_type ⇒ Object
readonly
The type of the payment method.
-
#previous_percentage ⇒ Object
readonly
The previous authorization rate percentage.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#charge_type ⇒ Object (readonly)
The type of the charge.
141 142 143 |
# File 'lib/stripe/resources/v2/core/health/alert.rb', line 141 def charge_type @charge_type end |
#current_percentage ⇒ Object (readonly)
The current authorization rate percentage.
143 144 145 |
# File 'lib/stripe/resources/v2/core/health/alert.rb', line 143 def current_percentage @current_percentage end |
#dimensions ⇒ Object (readonly)
Dimensions that describe what subset of payments are impacted.
145 146 147 |
# File 'lib/stripe/resources/v2/core/health/alert.rb', line 145 def dimensions @dimensions end |
#payment_method_type ⇒ Object (readonly)
The type of the payment method.
147 148 149 |
# File 'lib/stripe/resources/v2/core/health/alert.rb', line 147 def payment_method_type @payment_method_type end |
#previous_percentage ⇒ Object (readonly)
The previous authorization rate percentage.
149 150 151 |
# File 'lib/stripe/resources/v2/core/health/alert.rb', line 149 def previous_percentage @previous_percentage end |
Class Method Details
.field_encodings ⇒ Object
159 160 161 162 163 164 |
# File 'lib/stripe/resources/v2/core/health/alert.rb', line 159 def self.field_encodings @field_encodings = { current_percentage: :decimal_string, previous_percentage: :decimal_string, } end |
.field_remappings ⇒ Object
155 156 157 |
# File 'lib/stripe/resources/v2/core/health/alert.rb', line 155 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
151 152 153 |
# File 'lib/stripe/resources/v2/core/health/alert.rb', line 151 def self.inner_class_types @inner_class_types = { dimensions: Dimension } end |