Class: Stripe::V2::Core::Health::Alert::InvoiceCountDropped

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/health/alert.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#observed_countObject (readonly)

The observed number of invoices within the time window.



249
250
251
# File 'lib/stripe/resources/v2/core/health/alert.rb', line 249

def observed_count
  @observed_count
end

#threshold_countObject (readonly)

The expected threshold number of invoices within the time window.



251
252
253
# File 'lib/stripe/resources/v2/core/health/alert.rb', line 251

def threshold_count
  @threshold_count
end

#time_windowObject (readonly)

The size of the observation time window.



253
254
255
# File 'lib/stripe/resources/v2/core/health/alert.rb', line 253

def time_window
  @time_window
end

Class Method Details

.field_encodingsObject



263
264
265
# File 'lib/stripe/resources/v2/core/health/alert.rb', line 263

def self.field_encodings
  @field_encodings = { observed_count: :decimal_string, threshold_count: :decimal_string }
end

.field_remappingsObject



259
260
261
# File 'lib/stripe/resources/v2/core/health/alert.rb', line 259

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



255
256
257
# File 'lib/stripe/resources/v2/core/health/alert.rb', line 255

def self.inner_class_types
  @inner_class_types = {}
end