Class: Stripe::V2::Core::Health::AlertHistoryEntry

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/core/health/alert_history_entry.rb

Overview

An alert history entry representing a state transition of a health alert.

Defined Under Namespace

Classes: ApiError, ApiLatency, AuthorizationRateDrop, ElementsError, EventGenerationFailure, FraudRate, InvoiceCountDropped, IssuingAuthorizationRequestErrors, IssuingAuthorizationRequestTimeout, MeterEventSummariesDelayed, MetronomeNotificationLatency, PaymentMethodError, SepaDebitDelayed, TrafficVolumeDrop, WebhookLatency

Constant Summary collapse

OBJECT_NAME =
"v2.core.health.alert_history_entry"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#api_errorObject (readonly)

Populated when type is api_error.



419
420
421
# File 'lib/stripe/resources/v2/core/health/alert_history_entry.rb', line 419

def api_error
  @api_error
end

#api_latencyObject (readonly)

Populated when type is api_latency.



421
422
423
# File 'lib/stripe/resources/v2/core/health/alert_history_entry.rb', line 421

def api_latency
  @api_latency
end

#atObject (readonly)

The time at which this transition occurred.



423
424
425
# File 'lib/stripe/resources/v2/core/health/alert_history_entry.rb', line 423

def at
  @at
end

#authorization_rate_dropObject (readonly)

Populated when type is authorization_rate_drop.



425
426
427
# File 'lib/stripe/resources/v2/core/health/alert_history_entry.rb', line 425

def authorization_rate_drop
  @authorization_rate_drop
end

#elements_errorObject (readonly)

Populated when type is elements_error.



427
428
429
# File 'lib/stripe/resources/v2/core/health/alert_history_entry.rb', line 427

def elements_error
  @elements_error
end

#event_generation_failureObject (readonly)

Populated when type is event_generation_failure.



429
430
431
# File 'lib/stripe/resources/v2/core/health/alert_history_entry.rb', line 429

def event_generation_failure
  @event_generation_failure
end

#fraud_rateObject (readonly)

Populated when type is fraud_rate.



431
432
433
# File 'lib/stripe/resources/v2/core/health/alert_history_entry.rb', line 431

def fraud_rate
  @fraud_rate
end

#idObject (readonly)

Unique identifier for the alert history entry.



433
434
435
# File 'lib/stripe/resources/v2/core/health/alert_history_entry.rb', line 433

def id
  @id
end

#invoice_count_droppedObject (readonly)

Populated when type is invoice_count_dropped.



435
436
437
# File 'lib/stripe/resources/v2/core/health/alert_history_entry.rb', line 435

def invoice_count_dropped
  @invoice_count_dropped
end

#issuing_authorization_request_errorsObject (readonly)

Populated when type is issuing_authorization_request_errors.



437
438
439
# File 'lib/stripe/resources/v2/core/health/alert_history_entry.rb', line 437

def issuing_authorization_request_errors
  @issuing_authorization_request_errors
end

#issuing_authorization_request_timeoutObject (readonly)

Populated when type is issuing_authorization_request_timeout.



439
440
441
# File 'lib/stripe/resources/v2/core/health/alert_history_entry.rb', line 439

def issuing_authorization_request_timeout
  @issuing_authorization_request_timeout
end

#livemodeObject (readonly)

Has the value true if the object exists in live mode or the value false if the object exists in test mode.



441
442
443
# File 'lib/stripe/resources/v2/core/health/alert_history_entry.rb', line 441

def livemode
  @livemode
end

#meter_event_summaries_delayedObject (readonly)

Populated when type is meter_event_summaries_delayed.



443
444
445
# File 'lib/stripe/resources/v2/core/health/alert_history_entry.rb', line 443

def meter_event_summaries_delayed
  @meter_event_summaries_delayed
end

#metronome_notification_latencyObject (readonly)

Populated when type is metronome_notification_latency.



445
446
447
# File 'lib/stripe/resources/v2/core/health/alert_history_entry.rb', line 445

def metronome_notification_latency
  @metronome_notification_latency
end

#objectObject (readonly)

String representing the object's type. Objects of the same type share the same value of the object field.



447
448
449
# File 'lib/stripe/resources/v2/core/health/alert_history_entry.rb', line 447

def object
  @object
end

#payment_method_errorObject (readonly)

Populated when type is payment_method_error.



449
450
451
# File 'lib/stripe/resources/v2/core/health/alert_history_entry.rb', line 449

def payment_method_error
  @payment_method_error
end

#sepa_debit_delayedObject (readonly)

Populated when type is sepa_debit_delayed.



451
452
453
# File 'lib/stripe/resources/v2/core/health/alert_history_entry.rb', line 451

def sepa_debit_delayed
  @sepa_debit_delayed
end

#traffic_volume_dropObject (readonly)

Populated when type is traffic_volume_drop.



453
454
455
# File 'lib/stripe/resources/v2/core/health/alert_history_entry.rb', line 453

def traffic_volume_drop
  @traffic_volume_drop
end

#transitionObject (readonly)

The type of transition that occurred.



455
456
457
# File 'lib/stripe/resources/v2/core/health/alert_history_entry.rb', line 455

def transition
  @transition
end

#typeObject (readonly)

The type of the alert. Determines which sub-hash field is populated.



457
458
459
# File 'lib/stripe/resources/v2/core/health/alert_history_entry.rb', line 457

def type
  @type
end

#webhook_latencyObject (readonly)

Populated when type is webhook_latency.



459
460
461
# File 'lib/stripe/resources/v2/core/health/alert_history_entry.rb', line 459

def webhook_latency
  @webhook_latency
end

Class Method Details

.field_encodingsObject



485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
# File 'lib/stripe/resources/v2/core/health/alert_history_entry.rb', line 485

def self.field_encodings
  @field_encodings = {
    api_error: {
      kind: :object,
      fields: {
        impacted_requests_percentage: :decimal_string,
        top_impacted_accounts: {
          kind: :array,
          element: {
            kind: :object,
            fields: { impacted_requests_percentage: :decimal_string },
          },
        },
      },
    },
    api_latency: {
      kind: :object,
      fields: {
        impacted_requests_percentage: :decimal_string,
        top_impacted_accounts: {
          kind: :array,
          element: {
            kind: :object,
            fields: { impacted_requests_percentage: :decimal_string },
          },
        },
      },
    },
    authorization_rate_drop: {
      kind: :object,
      fields: { current_percentage: :decimal_string, previous_percentage: :decimal_string },
    },
    invoice_count_dropped: {
      kind: :object,
      fields: { observed_count: :decimal_string, threshold_count: :decimal_string },
    },
    payment_method_error: {
      kind: :object,
      fields: {
        impacted_requests_percentage: :decimal_string,
        top_impacted_accounts: {
          kind: :array,
          element: {
            kind: :object,
            fields: { impacted_requests_percentage: :decimal_string },
          },
        },
      },
    },
    sepa_debit_delayed: {
      kind: :object,
      fields: { impacted_payments_percentage: :decimal_string },
    },
  }
end

.field_remappingsObject



481
482
483
# File 'lib/stripe/resources/v2/core/health/alert_history_entry.rb', line 481

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
# File 'lib/stripe/resources/v2/core/health/alert_history_entry.rb', line 461

def self.inner_class_types
  @inner_class_types = {
    api_error: ApiError,
    api_latency: ApiLatency,
    authorization_rate_drop: AuthorizationRateDrop,
    elements_error: ElementsError,
    event_generation_failure: EventGenerationFailure,
    fraud_rate: FraudRate,
    invoice_count_dropped: InvoiceCountDropped,
    issuing_authorization_request_errors: IssuingAuthorizationRequestErrors,
    issuing_authorization_request_timeout: IssuingAuthorizationRequestTimeout,
    meter_event_summaries_delayed: MeterEventSummariesDelayed,
    metronome_notification_latency: MetronomeNotificationLatency,
    payment_method_error: PaymentMethodError,
    sepa_debit_delayed: SepaDebitDelayed,
    traffic_volume_drop: TrafficVolumeDrop,
    webhook_latency: WebhookLatency,
  }
end

.object_nameObject



11
12
13
# File 'lib/stripe/resources/v2/core/health/alert_history_entry.rb', line 11

def self.object_name
  "v2.core.health.alert_history_entry"
end