Class: Stripe::V2::Core::Health::AlertListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/v2/core/health/alert_list_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(created: nil, created_gt: nil, created_gte: nil, created_lt: nil, created_lte: nil, limit: nil, severity: nil, status: nil, types: nil) ⇒ AlertListParams

Returns a new instance of AlertListParams.



28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
# File 'lib/stripe/params/v2/core/health/alert_list_params.rb', line 28

def initialize(
  created: nil,
  created_gt: nil,
  created_gte: nil,
  created_lt: nil,
  created_lte: nil,
  limit: nil,
  severity: nil,
  status: nil,
  types: nil
)
  @created = created
  @created_gt = created_gt
  @created_gte = created_gte
  @created_lt = created_lt
  @created_lte = created_lte
  @limit = limit
  @severity = severity
  @status = status
  @types = types
end

Instance Attribute Details

#createdObject

Filter for alerts created at the specified timestamp.



10
11
12
# File 'lib/stripe/params/v2/core/health/alert_list_params.rb', line 10

def created
  @created
end

#created_gtObject

Filter for alerts created after the specified timestamp.



12
13
14
# File 'lib/stripe/params/v2/core/health/alert_list_params.rb', line 12

def created_gt
  @created_gt
end

#created_gteObject

Filter for alerts created on or after the specified timestamp.



14
15
16
# File 'lib/stripe/params/v2/core/health/alert_list_params.rb', line 14

def created_gte
  @created_gte
end

#created_ltObject

Filter for alerts created before the specified timestamp.



16
17
18
# File 'lib/stripe/params/v2/core/health/alert_list_params.rb', line 16

def created_lt
  @created_lt
end

#created_lteObject

Filter for alerts created on or before the specified timestamp.



18
19
20
# File 'lib/stripe/params/v2/core/health/alert_list_params.rb', line 18

def created_lte
  @created_lte
end

#limitObject

The page limit.



20
21
22
# File 'lib/stripe/params/v2/core/health/alert_list_params.rb', line 20

def limit
  @limit
end

#severityObject

Filter by alert severity.



22
23
24
# File 'lib/stripe/params/v2/core/health/alert_list_params.rb', line 22

def severity
  @severity
end

#statusObject

Filter by alert status.



24
25
26
# File 'lib/stripe/params/v2/core/health/alert_list_params.rb', line 24

def status
  @status
end

#typesObject

Filter by alert types.



26
27
28
# File 'lib/stripe/params/v2/core/health/alert_list_params.rb', line 26

def types
  @types
end