Class: Stripe::V2::Core::Person

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/core/person.rb

Overview

Person retrieval response schema.

Defined Under Namespace

Classes: AdditionalAddress, AdditionalName, AdditionalTermsOfService, Address, DateOfBirth, Documents, IdNumber, Relationship, ScriptAddresses, ScriptNames

Constant Summary collapse

OBJECT_NAME =
"v2.core.account_person"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#accountObject (readonly)

The account ID which the individual belongs to.



408
409
410
# File 'lib/stripe/resources/v2/core/person.rb', line 408

def 
  @account
end

#additional_addressesObject (readonly)

Additional addresses associated with the person.



410
411
412
# File 'lib/stripe/resources/v2/core/person.rb', line 410

def additional_addresses
  @additional_addresses
end

#additional_namesObject (readonly)

Additional names (e.g. aliases) associated with the person.



412
413
414
# File 'lib/stripe/resources/v2/core/person.rb', line 412

def additional_names
  @additional_names
end

#additional_terms_of_serviceObject (readonly)

Attestations of accepted terms of service agreements.



414
415
416
# File 'lib/stripe/resources/v2/core/person.rb', line 414

def additional_terms_of_service
  @additional_terms_of_service
end

#addressObject (readonly)

The person’s residential address.



416
417
418
# File 'lib/stripe/resources/v2/core/person.rb', line 416

def address
  @address
end

#createdObject (readonly)

Time at which the object was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



418
419
420
# File 'lib/stripe/resources/v2/core/person.rb', line 418

def created
  @created
end

#date_of_birthObject (readonly)

The person’s date of birth.



420
421
422
# File 'lib/stripe/resources/v2/core/person.rb', line 420

def date_of_birth
  @date_of_birth
end

#documentsObject (readonly)

Documents that may be submitted to satisfy various informational requests.



422
423
424
# File 'lib/stripe/resources/v2/core/person.rb', line 422

def documents
  @documents
end

#emailObject (readonly)

The person’s email address.



424
425
426
# File 'lib/stripe/resources/v2/core/person.rb', line 424

def email
  @email
end

#given_nameObject (readonly)

The person’s first name.



426
427
428
# File 'lib/stripe/resources/v2/core/person.rb', line 426

def given_name
  @given_name
end

#idObject (readonly)

Unique identifier for the Person.



428
429
430
# File 'lib/stripe/resources/v2/core/person.rb', line 428

def id
  @id
end

#id_numbersObject (readonly)

The identification numbers (e.g., SSN) associated with the person.



430
431
432
# File 'lib/stripe/resources/v2/core/person.rb', line 430

def id_numbers
  @id_numbers
end

The person’s gender (International regulations require either “male” or “female”).



432
433
434
# File 'lib/stripe/resources/v2/core/person.rb', line 432

def legal_gender
  @legal_gender
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



454
455
456
# File 'lib/stripe/resources/v2/core/person.rb', line 454

def livemode
  @livemode
end

#metadataObject (readonly)

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



434
435
436
# File 'lib/stripe/resources/v2/core/person.rb', line 434

def 
  @metadata
end

#nationalitiesObject (readonly)

The countries where the person is a national. Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).



436
437
438
# File 'lib/stripe/resources/v2/core/person.rb', line 436

def nationalities
  @nationalities
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



438
439
440
# File 'lib/stripe/resources/v2/core/person.rb', line 438

def object
  @object
end

#phoneObject (readonly)

The person’s phone number.



440
441
442
# File 'lib/stripe/resources/v2/core/person.rb', line 440

def phone
  @phone
end

#political_exposureObject (readonly)

The person’s political exposure.



442
443
444
# File 'lib/stripe/resources/v2/core/person.rb', line 442

def political_exposure
  @political_exposure
end

#relationshipObject (readonly)

The relationship that this person has with the Account’s business or legal entity.



444
445
446
# File 'lib/stripe/resources/v2/core/person.rb', line 444

def relationship
  @relationship
end

#script_addressesObject (readonly)

The script addresses (e.g., non-Latin characters) associated with the person.



446
447
448
# File 'lib/stripe/resources/v2/core/person.rb', line 446

def script_addresses
  @script_addresses
end

#script_namesObject (readonly)

The script names (e.g. non-Latin characters) associated with the person.



448
449
450
# File 'lib/stripe/resources/v2/core/person.rb', line 448

def script_names
  @script_names
end

#surnameObject (readonly)

The person’s last name.



450
451
452
# File 'lib/stripe/resources/v2/core/person.rb', line 450

def surname
  @surname
end

#updatedObject (readonly)

Time at which the object was last updated. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



452
453
454
# File 'lib/stripe/resources/v2/core/person.rb', line 452

def updated
  @updated
end

Class Method Details

.field_remappingsObject



471
472
473
# File 'lib/stripe/resources/v2/core/person.rb', line 471

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



456
457
458
459
460
461
462
463
464
465
466
467
468
469
# File 'lib/stripe/resources/v2/core/person.rb', line 456

def self.inner_class_types
  @inner_class_types = {
    additional_addresses: AdditionalAddress,
    additional_names: AdditionalName,
    additional_terms_of_service: AdditionalTermsOfService,
    address: Address,
    date_of_birth: DateOfBirth,
    documents: Documents,
    id_numbers: IdNumber,
    relationship: Relationship,
    script_addresses: ScriptAddresses,
    script_names: ScriptNames,
  }
end

.object_nameObject



10
11
12
# File 'lib/stripe/resources/v2/core/person.rb', line 10

def self.object_name
  "v2.core.account_person"
end