Class: Stripe::V2::Core::Person::Documents::PrimaryVerification
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Person::Documents::PrimaryVerification
- Defined in:
- lib/stripe/resources/v2/core/person.rb
Defined Under Namespace
Classes: FrontBack
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#front_back ⇒ Object
readonly
The [file upload](docs.stripe.com/api/persons/update#create_file) tokens for the front and back of the verification document.
-
#type ⇒ Object
readonly
The format of the verification document.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#front_back ⇒ Object (readonly)
The [file upload](docs.stripe.com/api/persons/update#create_file) tokens for the front and back of the verification document.
106 107 108 |
# File 'lib/stripe/resources/v2/core/person.rb', line 106 def front_back @front_back end |
#type ⇒ Object (readonly)
The format of the verification document. Currently supports ‘front_back` only.
108 109 110 |
# File 'lib/stripe/resources/v2/core/person.rb', line 108 def type @type end |