Class: Stripe::V2::Core::Person::Documents::PrimaryVerification::FrontBack
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Person::Documents::PrimaryVerification::FrontBack
- Defined in:
- lib/stripe/resources/v2/core/person.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#back ⇒ Object
readonly
A [file upload](docs.stripe.com/api/persons/update#create_file) token representing the back of the verification document.
-
#front ⇒ Object
readonly
A [file upload](docs.stripe.com/api/persons/update#create_file) token representing the front of the verification document.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#back ⇒ Object (readonly)
A [file upload](docs.stripe.com/api/persons/update#create_file) token representing the back of the verification document. The purpose of the uploaded file should be ‘identity_document’. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.
101 102 103 |
# File 'lib/stripe/resources/v2/core/person.rb', line 101 def back @back end |
#front ⇒ Object (readonly)
A [file upload](docs.stripe.com/api/persons/update#create_file) token representing the front of the verification document. The purpose of the uploaded file should be ‘identity_document’. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.
103 104 105 |
# File 'lib/stripe/resources/v2/core/person.rb', line 103 def front @front end |