Class: Stripe::V2::Core::Vault::GbBankAccount

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/core/vault/gb_bank_account.rb

Overview

Use the GBBankAccounts API to create and manage GB bank account objects

Defined Under Namespace

Classes: AlternativeReference, ConfirmationOfPayee

Constant Summary collapse

OBJECT_NAME =
"v2.core.vault.gb_bank_account"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#alternative_referenceObject (readonly)

The alternative reference for this payout method, if it’s a projected payout method.



95
96
97
# File 'lib/stripe/resources/v2/core/vault/gb_bank_account.rb', line 95

def alternative_reference
  @alternative_reference
end

#archivedObject (readonly)

Whether this bank account object was archived. Bank account objects can be archived through the /archive API, and they will not be automatically archived by Stripe. Archived bank account objects cannot be used as outbound destinations and will not appear in the outbound destination list.



99
100
101
# File 'lib/stripe/resources/v2/core/vault/gb_bank_account.rb', line 99

def archived
  @archived
end

#bank_account_typeObject (readonly)

Closed Enum. The type of the bank account (checking or savings).



101
102
103
# File 'lib/stripe/resources/v2/core/vault/gb_bank_account.rb', line 101

def 
  @bank_account_type
end

#bank_nameObject (readonly)

The name of the bank.



103
104
105
# File 'lib/stripe/resources/v2/core/vault/gb_bank_account.rb', line 103

def bank_name
  @bank_name
end

#confirmation_of_payeeObject (readonly)

Information around the status of Confirmation of Payee matching done on this bank account. Confirmation of Payee is a name matching service that must be done before making OutboundPayments in the UK.



106
107
108
# File 'lib/stripe/resources/v2/core/vault/gb_bank_account.rb', line 106

def confirmation_of_payee
  @confirmation_of_payee
end

#createdObject (readonly)

Creation time.



108
109
110
# File 'lib/stripe/resources/v2/core/vault/gb_bank_account.rb', line 108

def created
  @created
end

#idObject (readonly)

The ID of the GBBankAccount object.



110
111
112
# File 'lib/stripe/resources/v2/core/vault/gb_bank_account.rb', line 110

def id
  @id
end

#last4Object (readonly)

The last 4 digits of the account number or IBAN.



112
113
114
# File 'lib/stripe/resources/v2/core/vault/gb_bank_account.rb', line 112

def last4
  @last4
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



114
115
116
# File 'lib/stripe/resources/v2/core/vault/gb_bank_account.rb', line 114

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



116
117
118
# File 'lib/stripe/resources/v2/core/vault/gb_bank_account.rb', line 116

def object
  @object
end

#sort_codeObject (readonly)

The Sort Code of the bank account.



118
119
120
# File 'lib/stripe/resources/v2/core/vault/gb_bank_account.rb', line 118

def sort_code
  @sort_code
end

#supported_currenciesObject (readonly)

The list of currencies supported by this bank account.



120
121
122
# File 'lib/stripe/resources/v2/core/vault/gb_bank_account.rb', line 120

def supported_currencies
  @supported_currencies
end

Class Method Details

.field_remappingsObject



129
130
131
# File 'lib/stripe/resources/v2/core/vault/gb_bank_account.rb', line 129

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



122
123
124
125
126
127
# File 'lib/stripe/resources/v2/core/vault/gb_bank_account.rb', line 122

def self.inner_class_types
  @inner_class_types = {
    alternative_reference: AlternativeReference,
    confirmation_of_payee: ConfirmationOfPayee,
  }
end

.object_nameObject



11
12
13
# File 'lib/stripe/resources/v2/core/vault/gb_bank_account.rb', line 11

def self.object_name
  "v2.core.vault.gb_bank_account"
end