Class: Stripe::V2::Core::Vault::GbBankAccount::ConfirmationOfPayee
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Vault::GbBankAccount::ConfirmationOfPayee
- Defined in:
- lib/stripe/resources/v2/core/vault/gb_bank_account.rb
Defined Under Namespace
Classes: Result
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#result ⇒ Object
readonly
The result of the Confirmation of Payee check, once the check has been initiated.
-
#status ⇒ Object
readonly
The current state of Confirmation of Payee on this bank account.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#result ⇒ Object (readonly)
The result of the Confirmation of Payee check, once the check has been initiated. Closed enum.
43 44 45 |
# File 'lib/stripe/resources/v2/core/vault/gb_bank_account.rb', line 43 def result @result end |
#status ⇒ Object (readonly)
The current state of Confirmation of Payee on this bank account. Closed enum.
45 46 47 |
# File 'lib/stripe/resources/v2/core/vault/gb_bank_account.rb', line 45 def status @status end |