Class: Stripe::V2::Core::Vault::GbBankAccount::ConfirmationOfPayee::Result::Provided
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Vault::GbBankAccount::ConfirmationOfPayee::Result::Provided
- Defined in:
- lib/stripe/resources/v2/core/vault/gb_bank_account.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#business_type ⇒ Object
readonly
The provided or Legal Entity business type to match against the CoP service.
-
#name ⇒ Object
readonly
The provided or Legal Entity name to match against the CoP service.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#business_type ⇒ Object (readonly)
The provided or Legal Entity business type to match against the CoP service. Closed enum.
50 51 52 |
# File 'lib/stripe/resources/v2/core/vault/gb_bank_account.rb', line 50 def business_type @business_type end |
#name ⇒ Object (readonly)
The provided or Legal Entity name to match against the CoP service.
52 53 54 |
# File 'lib/stripe/resources/v2/core/vault/gb_bank_account.rb', line 52 def name @name end |
Class Method Details
.field_remappings ⇒ Object
58 59 60 |
# File 'lib/stripe/resources/v2/core/vault/gb_bank_account.rb', line 58 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
54 55 56 |
# File 'lib/stripe/resources/v2/core/vault/gb_bank_account.rb', line 54 def self.inner_class_types @inner_class_types = {} end |