Class: Stripe::V2::Core::Vault::GbBankAccountCreateParams::ConfirmationOfPayee
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::Vault::GbBankAccountCreateParams::ConfirmationOfPayee
- Defined in:
- lib/stripe/params/v2/core/vault/gb_bank_account_create_params.rb
Instance Attribute Summary collapse
-
#business_type ⇒ Object
The business type to be checked against.
-
#initiate ⇒ Object
User specifies whether Confirmation of Payee is automatically initiated when creating the bank account.
-
#name ⇒ Object
The name to be checked against.
Instance Method Summary collapse
-
#initialize(business_type: nil, initiate: nil, name: nil) ⇒ ConfirmationOfPayee
constructor
A new instance of ConfirmationOfPayee.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(business_type: nil, initiate: nil, name: nil) ⇒ ConfirmationOfPayee
Returns a new instance of ConfirmationOfPayee.
18 19 20 21 22 |
# File 'lib/stripe/params/v2/core/vault/gb_bank_account_create_params.rb', line 18 def initialize(business_type: nil, initiate: nil, name: nil) @business_type = business_type @initiate = initiate @name = name end |
Instance Attribute Details
#business_type ⇒ Object
The business type to be checked against. Legal entity information will be used if unspecified. Closed enum.
12 13 14 |
# File 'lib/stripe/params/v2/core/vault/gb_bank_account_create_params.rb', line 12 def business_type @business_type end |
#initiate ⇒ Object
User specifies whether Confirmation of Payee is automatically initiated when creating the bank account.
14 15 16 |
# File 'lib/stripe/params/v2/core/vault/gb_bank_account_create_params.rb', line 14 def initiate @initiate end |
#name ⇒ Object
The name to be checked against. Legal entity information will be used if unspecified.
16 17 18 |
# File 'lib/stripe/params/v2/core/vault/gb_bank_account_create_params.rb', line 16 def name @name end |