Class: Stripe::V2::Core::Vault::GbBankAccountInitiateConfirmationOfPayeeParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::Vault::GbBankAccountInitiateConfirmationOfPayeeParams
- Defined in:
- lib/stripe/params/v2/core/vault/gb_bank_account_initiate_confirmation_of_payee_params.rb
Instance Attribute Summary collapse
-
#business_type ⇒ Object
The business type to be checked against.
-
#name ⇒ Object
The name of the user to be checked against.
Instance Method Summary collapse
-
#initialize(business_type: nil, name: nil) ⇒ GbBankAccountInitiateConfirmationOfPayeeParams
constructor
A new instance of GbBankAccountInitiateConfirmationOfPayeeParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(business_type: nil, name: nil) ⇒ GbBankAccountInitiateConfirmationOfPayeeParams
Returns a new instance of GbBankAccountInitiateConfirmationOfPayeeParams.
14 15 16 17 |
# File 'lib/stripe/params/v2/core/vault/gb_bank_account_initiate_confirmation_of_payee_params.rb', line 14 def initialize(business_type: nil, name: nil) @business_type = business_type @name = name end |
Instance Attribute Details
#business_type ⇒ Object
The business type to be checked against. Legal entity information will be used if unspecified.
10 11 12 |
# File 'lib/stripe/params/v2/core/vault/gb_bank_account_initiate_confirmation_of_payee_params.rb', line 10 def business_type @business_type end |
#name ⇒ Object
The name of the user to be checked against. Legal entity information will be used if unspecified.
12 13 14 |
# File 'lib/stripe/params/v2/core/vault/gb_bank_account_initiate_confirmation_of_payee_params.rb', line 12 def name @name end |