Class: Stripe::V2::Core::Vault::GbBankAccountListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::Vault::GbBankAccountListParams
- Defined in:
- lib/stripe/params/v2/core/vault/gb_bank_account_list_params.rb
Instance Attribute Summary collapse
-
#limit ⇒ Object
Optionally set the maximum number of results per page.
Instance Method Summary collapse
-
#initialize(limit: nil) ⇒ GbBankAccountListParams
constructor
A new instance of GbBankAccountListParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(limit: nil) ⇒ GbBankAccountListParams
Returns a new instance of GbBankAccountListParams.
12 13 14 |
# File 'lib/stripe/params/v2/core/vault/gb_bank_account_list_params.rb', line 12 def initialize(limit: nil) @limit = limit end |
Instance Attribute Details
#limit ⇒ Object
Optionally set the maximum number of results per page. Defaults to 10.
10 11 12 |
# File 'lib/stripe/params/v2/core/vault/gb_bank_account_list_params.rb', line 10 def limit @limit end |