Class: Stripe::V2::Core::Vault::GbBankAccountService::InitiateConfirmationOfPayeeParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::Vault::GbBankAccountService::InitiateConfirmationOfPayeeParams
- Defined in:
- lib/stripe/services/v2/core/vault/gb_bank_account_service.rb
Instance Attribute Summary collapse
-
#business_type ⇒ Object
The business type to be checked against.
-
#name ⇒ Object
The name of the user to be checked against.
Instance Method Summary collapse
-
#initialize(business_type: nil, name: nil) ⇒ InitiateConfirmationOfPayeeParams
constructor
A new instance of InitiateConfirmationOfPayeeParams.
Methods inherited from RequestParams
Constructor Details
#initialize(business_type: nil, name: nil) ⇒ InitiateConfirmationOfPayeeParams
Returns a new instance of InitiateConfirmationOfPayeeParams.
58 59 60 61 |
# File 'lib/stripe/services/v2/core/vault/gb_bank_account_service.rb', line 58 def initialize(business_type: nil, name: nil) @business_type = business_type @name = name end |
Instance Attribute Details
#business_type ⇒ Object
The business type to be checked against. Legal entity information will be used if unspecified.
54 55 56 |
# File 'lib/stripe/services/v2/core/vault/gb_bank_account_service.rb', line 54 def business_type @business_type end |
#name ⇒ Object
The name of the user to be checked against. Legal entity information will be used if unspecified.
56 57 58 |
# File 'lib/stripe/services/v2/core/vault/gb_bank_account_service.rb', line 56 def name @name end |