Class: Stripe::V2::Core::Workflow
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Core::Workflow
- Defined in:
- lib/stripe/resources/v2/core/workflow.rb
Overview
A Stripe Workflow is a sequence of actions, like Stripe API calls, that are taken in response to an initiating trigger. A trigger can be a Stripe API event, or a manual invocation.
Defined Under Namespace
Classes: Trigger
Constant Summary collapse
- OBJECT_NAME =
"v2.core.workflow"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#created ⇒ Object
readonly
When the Workflow was created.
-
#description ⇒ Object
readonly
Workflow description.
-
#id ⇒ Object
readonly
The unique ID of the Workflow.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#status ⇒ Object
readonly
Whether this Workflow is active, inactive, or in some other state.
-
#triggers ⇒ Object
readonly
Under what conditions will this Workflow launch.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#created ⇒ Object (readonly)
When the Workflow was created.
57 58 59 |
# File 'lib/stripe/resources/v2/core/workflow.rb', line 57 def created @created end |
#description ⇒ Object (readonly)
Workflow description.
59 60 61 |
# File 'lib/stripe/resources/v2/core/workflow.rb', line 59 def description @description end |
#id ⇒ Object (readonly)
The unique ID of the Workflow.
61 62 63 |
# File 'lib/stripe/resources/v2/core/workflow.rb', line 61 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
63 64 65 |
# File 'lib/stripe/resources/v2/core/workflow.rb', line 63 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
65 66 67 |
# File 'lib/stripe/resources/v2/core/workflow.rb', line 65 def object @object end |
#status ⇒ Object (readonly)
Whether this Workflow is active, inactive, or in some other state. Only active Workflows may be invoked.
67 68 69 |
# File 'lib/stripe/resources/v2/core/workflow.rb', line 67 def status @status end |
#triggers ⇒ Object (readonly)
Under what conditions will this Workflow launch.
69 70 71 |
# File 'lib/stripe/resources/v2/core/workflow.rb', line 69 def triggers @triggers end |
Class Method Details
.field_remappings ⇒ Object
75 76 77 |
# File 'lib/stripe/resources/v2/core/workflow.rb', line 75 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
71 72 73 |
# File 'lib/stripe/resources/v2/core/workflow.rb', line 71 def self.inner_class_types @inner_class_types = { triggers: Trigger } end |
.object_name ⇒ Object
11 12 13 |
# File 'lib/stripe/resources/v2/core/workflow.rb', line 11 def self.object_name "v2.core.workflow" end |