Class: Stripe::V2::Core::WorkflowRun
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Core::WorkflowRun
- Defined in:
- lib/stripe/resources/v2/core/workflow_run.rb
Overview
An execution of a Workflow in response to a triggering event.
Defined Under Namespace
Classes: StatusDetails, StatusTransitions, Trigger
Constant Summary collapse
- OBJECT_NAME =
"v2.core.workflow_run"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#created ⇒ Object
readonly
When the Workflow Run was created.
-
#id ⇒ Object
readonly
The unique ID of the Workflow Run.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#status ⇒ Object
readonly
The current Workflow Run execution status.
-
#status_details ⇒ Object
readonly
Details about the Workflow Run’s status transitions.
-
#status_transitions ⇒ Object
readonly
Summary information about the Workflow Run’s status transitions.
-
#trigger ⇒ Object
readonly
A record of the trigger that launched this Workflow Run.
-
#workflow ⇒ Object
readonly
The Workflow this Run belongs to.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#created ⇒ Object (readonly)
When the Workflow Run was created.
133 134 135 |
# File 'lib/stripe/resources/v2/core/workflow_run.rb', line 133 def created @created end |
#id ⇒ Object (readonly)
The unique ID of the Workflow Run.
135 136 137 |
# File 'lib/stripe/resources/v2/core/workflow_run.rb', line 135 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
137 138 139 |
# File 'lib/stripe/resources/v2/core/workflow_run.rb', line 137 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
139 140 141 |
# File 'lib/stripe/resources/v2/core/workflow_run.rb', line 139 def object @object end |
#status ⇒ Object (readonly)
The current Workflow Run execution status.
141 142 143 |
# File 'lib/stripe/resources/v2/core/workflow_run.rb', line 141 def status @status end |
#status_details ⇒ Object (readonly)
Details about the Workflow Run’s status transitions.
143 144 145 |
# File 'lib/stripe/resources/v2/core/workflow_run.rb', line 143 def status_details @status_details end |
#status_transitions ⇒ Object (readonly)
Summary information about the Workflow Run’s status transitions.
145 146 147 |
# File 'lib/stripe/resources/v2/core/workflow_run.rb', line 145 def status_transitions @status_transitions end |
#trigger ⇒ Object (readonly)
A record of the trigger that launched this Workflow Run.
147 148 149 |
# File 'lib/stripe/resources/v2/core/workflow_run.rb', line 147 def trigger @trigger end |
#workflow ⇒ Object (readonly)
The Workflow this Run belongs to.
149 150 151 |
# File 'lib/stripe/resources/v2/core/workflow_run.rb', line 149 def workflow @workflow end |
Class Method Details
.field_remappings ⇒ Object
159 160 161 |
# File 'lib/stripe/resources/v2/core/workflow_run.rb', line 159 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
151 152 153 154 155 156 157 |
# File 'lib/stripe/resources/v2/core/workflow_run.rb', line 151 def self.inner_class_types @inner_class_types = { status_details: StatusDetails, status_transitions: StatusTransitions, trigger: Trigger, } end |
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/v2/core/workflow_run.rb', line 10 def self.object_name "v2.core.workflow_run" end |