Class: Stripe::V2::Data::Analytics::MetricQueryCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Data::Analytics::MetricQueryCreateParams
- Defined in:
- lib/stripe/params/v2/data/analytics/metric_query_create_params.rb
Defined Under Namespace
Classes: Metric
Instance Attribute Summary collapse
-
#currency ⇒ Object
Which currency to return monetary metric results in.
-
#ends_at ⇒ Object
Timestamp denoting the end of the time range to request data for.
-
#filters ⇒ Object
Which dimension values to filter on; keys are dimension names, values are arrays of dimension values to filter on.
-
#granularity ⇒ Object
The time granularity to aggregate results by.
-
#group_by ⇒ Object
Which dimension keys to group by; if not specified no grouping is performed.
-
#limit ⇒ Object
The maximum number of rows in the response.
-
#metrics ⇒ Object
A list of the metrics to be returned; all metrics must share the same metric namespace.
-
#page ⇒ Object
Pagination future-proofing: page token for navigating to next/previous batch of rows.
-
#starts_at ⇒ Object
Timestamp denoting the beginning of the time range to request data for.
-
#timezone ⇒ Object
The timezone results should be in; defaults to the merchant’s timezone.
Instance Method Summary collapse
-
#initialize(currency: nil, ends_at: nil, filters: nil, granularity: nil, group_by: nil, limit: nil, metrics: nil, page: nil, starts_at: nil, timezone: nil) ⇒ MetricQueryCreateParams
constructor
A new instance of MetricQueryCreateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(currency: nil, ends_at: nil, filters: nil, granularity: nil, group_by: nil, limit: nil, metrics: nil, page: nil, starts_at: nil, timezone: nil) ⇒ MetricQueryCreateParams
Returns a new instance of MetricQueryCreateParams.
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/stripe/params/v2/data/analytics/metric_query_create_params.rb', line 41 def initialize( currency: nil, ends_at: nil, filters: nil, granularity: nil, group_by: nil, limit: nil, metrics: nil, page: nil, starts_at: nil, timezone: nil ) @currency = currency @ends_at = ends_at @filters = filters @granularity = granularity @group_by = group_by @limit = limit @metrics = metrics @page = page @starts_at = starts_at @timezone = timezone end |
Instance Attribute Details
#currency ⇒ Object
Which currency to return monetary metric results in.
21 22 23 |
# File 'lib/stripe/params/v2/data/analytics/metric_query_create_params.rb', line 21 def currency @currency end |
#ends_at ⇒ Object
Timestamp denoting the end of the time range to request data for.
23 24 25 |
# File 'lib/stripe/params/v2/data/analytics/metric_query_create_params.rb', line 23 def ends_at @ends_at end |
#filters ⇒ Object
Which dimension values to filter on; keys are dimension names, values are arrays of dimension values to filter on.
25 26 27 |
# File 'lib/stripe/params/v2/data/analytics/metric_query_create_params.rb', line 25 def filters @filters end |
#granularity ⇒ Object
The time granularity to aggregate results by.
27 28 29 |
# File 'lib/stripe/params/v2/data/analytics/metric_query_create_params.rb', line 27 def granularity @granularity end |
#group_by ⇒ Object
Which dimension keys to group by; if not specified no grouping is performed.
29 30 31 |
# File 'lib/stripe/params/v2/data/analytics/metric_query_create_params.rb', line 29 def group_by @group_by end |
#limit ⇒ Object
The maximum number of rows in the response.
31 32 33 |
# File 'lib/stripe/params/v2/data/analytics/metric_query_create_params.rb', line 31 def limit @limit end |
#metrics ⇒ Object
A list of the metrics to be returned; all metrics must share the same metric namespace.
33 34 35 |
# File 'lib/stripe/params/v2/data/analytics/metric_query_create_params.rb', line 33 def metrics @metrics end |
#page ⇒ Object
Pagination future-proofing: page token for navigating to next/previous batch of rows.
35 36 37 |
# File 'lib/stripe/params/v2/data/analytics/metric_query_create_params.rb', line 35 def page @page end |
#starts_at ⇒ Object
Timestamp denoting the beginning of the time range to request data for.
37 38 39 |
# File 'lib/stripe/params/v2/data/analytics/metric_query_create_params.rb', line 37 def starts_at @starts_at end |
#timezone ⇒ Object
The timezone results should be in; defaults to the merchant’s timezone.
39 40 41 |
# File 'lib/stripe/params/v2/data/analytics/metric_query_create_params.rb', line 39 def timezone @timezone end |