Class: Stripe::V2::Data::Reporting::QueryRunCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Data::Reporting::QueryRunCreateParams
- Defined in:
- lib/stripe/params/v2/data/reporting/query_run_create_params.rb
Defined Under Namespace
Classes: ResultOptions
Instance Attribute Summary collapse
-
#result_options ⇒ Object
Optional settings to customize the results of the ‘QueryRun`.
-
#sql ⇒ Object
The SQL to execute.
Instance Method Summary collapse
-
#initialize(result_options: nil, sql: nil) ⇒ QueryRunCreateParams
constructor
A new instance of QueryRunCreateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(result_options: nil, sql: nil) ⇒ QueryRunCreateParams
Returns a new instance of QueryRunCreateParams.
23 24 25 26 |
# File 'lib/stripe/params/v2/data/reporting/query_run_create_params.rb', line 23 def initialize(result_options: nil, sql: nil) @result_options = @sql = sql end |
Instance Attribute Details
#result_options ⇒ Object
Optional settings to customize the results of the ‘QueryRun`.
19 20 21 |
# File 'lib/stripe/params/v2/data/reporting/query_run_create_params.rb', line 19 def @result_options end |
#sql ⇒ Object
The SQL to execute.
21 22 23 |
# File 'lib/stripe/params/v2/data/reporting/query_run_create_params.rb', line 21 def sql @sql end |