Class: Stripe::V2::Data::Reporting::QueryRunCreateParams::ResultOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Data::Reporting::QueryRunCreateParams::ResultOptions
- Defined in:
- lib/stripe/params/v2/data/reporting/query_run_create_params.rb
Instance Attribute Summary collapse
-
#compress_file ⇒ Object
If set, the generated results file will be compressed into a ZIP folder.
Instance Method Summary collapse
-
#initialize(compress_file: nil) ⇒ ResultOptions
constructor
A new instance of ResultOptions.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(compress_file: nil) ⇒ ResultOptions
Returns a new instance of ResultOptions.
14 15 16 |
# File 'lib/stripe/params/v2/data/reporting/query_run_create_params.rb', line 14 def initialize(compress_file: nil) @compress_file = compress_file end |
Instance Attribute Details
#compress_file ⇒ Object
If set, the generated results file will be compressed into a ZIP folder. This is useful for reducing file size and download time for large results.
12 13 14 |
# File 'lib/stripe/params/v2/data/reporting/query_run_create_params.rb', line 12 def compress_file @compress_file end |