Class: Stripe::V2::Event
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Event
- Defined in:
- lib/stripe/resources/v2/event.rb
Overview
Events are generated to keep you informed of activity in your business account. APIs in the /v2 namespace generate [thin events](docs.stripe.com/event-destinations#benefits-of-thin-events) which have small, unversioned payloads that include a reference to the ID of the object that has changed. The Events v2 API returns these new thin events. [Retrieve the event object](docs.stripe.com/event-destinations#fetch-data) for additional data about the event. Use the related object ID in the event payload to [fetch the API resource](docs.stripe.com/event-destinations#retrieve-the-object-associated-with-thin-events) of the object associated with the event. Comparatively, events generated by most API v1 include a versioned snapshot of an API object in their payload.
Direct Known Subclasses
Stripe::V1BillingMeterErrorReportTriggeredEvent, Stripe::V1BillingMeterNoMeterFoundEvent, Stripe::V2BillingCadenceBilledEvent, Stripe::V2BillingCadenceCanceledEvent, Stripe::V2BillingCadenceCreatedEvent, Stripe::V2BillingCadenceErroredEvent, Stripe::V2BillingLicenseFeeCreatedEvent, Stripe::V2BillingLicenseFeeUpdatedEvent, Stripe::V2BillingLicenseFeeVersionCreatedEvent, Stripe::V2BillingLicensedItemCreatedEvent, Stripe::V2BillingLicensedItemUpdatedEvent, Stripe::V2BillingMeteredItemCreatedEvent, Stripe::V2BillingMeteredItemUpdatedEvent, Stripe::V2BillingPricingPlanComponentCreatedEvent, Stripe::V2BillingPricingPlanComponentUpdatedEvent, Stripe::V2BillingPricingPlanCreatedEvent, Stripe::V2BillingPricingPlanSubscriptionCollectionAwaitingCustomerActionEvent, Stripe::V2BillingPricingPlanSubscriptionCollectionCurrentEvent, Stripe::V2BillingPricingPlanSubscriptionCollectionPastDueEvent, Stripe::V2BillingPricingPlanSubscriptionCollectionPausedEvent, Stripe::V2BillingPricingPlanSubscriptionCollectionUnpaidEvent, Stripe::V2BillingPricingPlanSubscriptionServicingActivatedEvent, Stripe::V2BillingPricingPlanSubscriptionServicingCanceledEvent, Stripe::V2BillingPricingPlanSubscriptionServicingPausedEvent, Stripe::V2BillingPricingPlanUpdatedEvent, Stripe::V2BillingPricingPlanVersionCreatedEvent, Stripe::V2BillingRateCardCreatedEvent, Stripe::V2BillingRateCardRateCreatedEvent, Stripe::V2BillingRateCardSubscriptionActivatedEvent, Stripe::V2BillingRateCardSubscriptionCanceledEvent, Stripe::V2BillingRateCardSubscriptionCollectionAwaitingCustomerActionEvent, Stripe::V2BillingRateCardSubscriptionCollectionCurrentEvent, Stripe::V2BillingRateCardSubscriptionCollectionPastDueEvent, Stripe::V2BillingRateCardSubscriptionCollectionPausedEvent, Stripe::V2BillingRateCardSubscriptionCollectionUnpaidEvent, Stripe::V2BillingRateCardSubscriptionServicingActivatedEvent, Stripe::V2BillingRateCardSubscriptionServicingCanceledEvent, Stripe::V2BillingRateCardSubscriptionServicingPausedEvent, Stripe::V2BillingRateCardUpdatedEvent, Stripe::V2BillingRateCardVersionCreatedEvent, Stripe::V2CoreAccountClosedEvent, Stripe::V2CoreAccountCreatedEvent, Stripe::V2CoreAccountIncludingConfigurationCustomerCapabilityStatusUpdatedEvent, Stripe::V2CoreAccountIncludingConfigurationCustomerUpdatedEvent, Stripe::V2CoreAccountIncludingConfigurationMerchantCapabilityStatusUpdatedEvent, Stripe::V2CoreAccountIncludingConfigurationMerchantUpdatedEvent, Stripe::V2CoreAccountIncludingConfigurationRecipientCapabilityStatusUpdatedEvent, Stripe::V2CoreAccountIncludingConfigurationRecipientUpdatedEvent, Stripe::V2CoreAccountIncludingConfigurationStorerCapabilityStatusUpdatedEvent, Stripe::V2CoreAccountIncludingConfigurationStorerUpdatedEvent, Stripe::V2CoreAccountIncludingDefaultsUpdatedEvent, Stripe::V2CoreAccountIncludingIdentityUpdatedEvent, Stripe::V2CoreAccountIncludingRequirementsUpdatedEvent, Stripe::V2CoreAccountLinkReturnedEvent, Stripe::V2CoreAccountPersonCreatedEvent, Stripe::V2CoreAccountPersonDeletedEvent, Stripe::V2CoreAccountPersonUpdatedEvent, Stripe::V2CoreAccountUpdatedEvent, Stripe::V2CoreEventDestinationPingEvent, Stripe::V2CoreHealthApiErrorFiringEvent, Stripe::V2CoreHealthApiErrorResolvedEvent, Stripe::V2CoreHealthApiLatencyFiringEvent, Stripe::V2CoreHealthApiLatencyResolvedEvent, Stripe::V2CoreHealthAuthorizationRateDropFiringEvent, Stripe::V2CoreHealthAuthorizationRateDropResolvedEvent, Stripe::V2CoreHealthEventGenerationFailureResolvedEvent, Stripe::V2CoreHealthFraudRateIncreasedEvent, Stripe::V2CoreHealthIssuingAuthorizationRequestTimeoutFiringEvent, Stripe::V2CoreHealthIssuingAuthorizationRequestTimeoutResolvedEvent, Stripe::V2CoreHealthPaymentMethodErrorFiringEvent, Stripe::V2CoreHealthPaymentMethodErrorResolvedEvent, Stripe::V2CoreHealthTrafficVolumeDropFiringEvent, Stripe::V2CoreHealthTrafficVolumeDropResolvedEvent, Stripe::V2CoreHealthWebhookLatencyFiringEvent, Stripe::V2CoreHealthWebhookLatencyResolvedEvent, Stripe::V2MoneyManagementAdjustmentCreatedEvent, Stripe::V2MoneyManagementFinancialAccountCreatedEvent, Stripe::V2MoneyManagementFinancialAccountUpdatedEvent, Stripe::V2MoneyManagementFinancialAddressActivatedEvent, Stripe::V2MoneyManagementFinancialAddressFailedEvent, Stripe::V2MoneyManagementInboundTransferAvailableEvent, Stripe::V2MoneyManagementInboundTransferBankDebitFailedEvent, Stripe::V2MoneyManagementInboundTransferBankDebitProcessingEvent, Stripe::V2MoneyManagementInboundTransferBankDebitQueuedEvent, Stripe::V2MoneyManagementInboundTransferBankDebitReturnedEvent, Stripe::V2MoneyManagementInboundTransferBankDebitSucceededEvent, Stripe::V2MoneyManagementOutboundPaymentCanceledEvent, Stripe::V2MoneyManagementOutboundPaymentCreatedEvent, Stripe::V2MoneyManagementOutboundPaymentFailedEvent, Stripe::V2MoneyManagementOutboundPaymentPostedEvent, Stripe::V2MoneyManagementOutboundPaymentReturnedEvent, Stripe::V2MoneyManagementOutboundPaymentUpdatedEvent, Stripe::V2MoneyManagementOutboundTransferCanceledEvent, Stripe::V2MoneyManagementOutboundTransferCreatedEvent, Stripe::V2MoneyManagementOutboundTransferFailedEvent, Stripe::V2MoneyManagementOutboundTransferPostedEvent, Stripe::V2MoneyManagementOutboundTransferReturnedEvent, Stripe::V2MoneyManagementOutboundTransferUpdatedEvent, Stripe::V2MoneyManagementPayoutMethodUpdatedEvent, Stripe::V2MoneyManagementReceivedCreditAvailableEvent, Stripe::V2MoneyManagementReceivedCreditFailedEvent, Stripe::V2MoneyManagementReceivedCreditReturnedEvent, Stripe::V2MoneyManagementReceivedCreditSucceededEvent, Stripe::V2MoneyManagementReceivedDebitCanceledEvent, Stripe::V2MoneyManagementReceivedDebitFailedEvent, Stripe::V2MoneyManagementReceivedDebitPendingEvent, Stripe::V2MoneyManagementReceivedDebitSucceededEvent, Stripe::V2MoneyManagementReceivedDebitUpdatedEvent, Stripe::V2MoneyManagementTransactionCreatedEvent, Stripe::V2MoneyManagementTransactionUpdatedEvent, Stripe::V2PaymentsOffSessionPaymentAuthorizationAttemptFailedEvent, Stripe::V2PaymentsOffSessionPaymentAuthorizationAttemptStartedEvent, Stripe::V2PaymentsOffSessionPaymentCanceledEvent, Stripe::V2PaymentsOffSessionPaymentCreatedEvent, Stripe::V2PaymentsOffSessionPaymentFailedEvent, Stripe::V2PaymentsOffSessionPaymentSucceededEvent, Stripe::V2ReportingReportRunCreatedEvent, Stripe::V2ReportingReportRunFailedEvent, Stripe::V2ReportingReportRunSucceededEvent, Stripe::V2ReportingReportRunUpdatedEvent
Defined Under Namespace
Classes: Reason
Constant Summary collapse
- OBJECT_NAME =
"v2.core.event"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#changes ⇒ Object
readonly
Before and after changes for the primary related object.
-
#context ⇒ Object
readonly
Authentication context needed to fetch the event or related object.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#id ⇒ Object
readonly
Unique identifier for the event.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#reason ⇒ Object
readonly
Reason for the event.
-
#type ⇒ Object
readonly
The type of the event.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#changes ⇒ Object (readonly)
Before and after changes for the primary related object.
26 27 28 |
# File 'lib/stripe/resources/v2/event.rb', line 26 def changes @changes end |
#context ⇒ Object (readonly)
Authentication context needed to fetch the event or related object.
28 29 30 |
# File 'lib/stripe/resources/v2/event.rb', line 28 def context @context end |
#created ⇒ Object (readonly)
Time at which the object was created.
30 31 32 |
# File 'lib/stripe/resources/v2/event.rb', line 30 def created @created end |
#id ⇒ Object (readonly)
Unique identifier for the event.
32 33 34 |
# File 'lib/stripe/resources/v2/event.rb', line 32 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
40 41 42 |
# File 'lib/stripe/resources/v2/event.rb', line 40 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
34 35 36 |
# File 'lib/stripe/resources/v2/event.rb', line 34 def object @object end |
#reason ⇒ Object (readonly)
Reason for the event.
36 37 38 |
# File 'lib/stripe/resources/v2/event.rb', line 36 def reason @reason end |
#type ⇒ Object (readonly)
The type of the event.
38 39 40 |
# File 'lib/stripe/resources/v2/event.rb', line 38 def type @type end |
Class Method Details
.object_name ⇒ Object
9 10 11 |
# File 'lib/stripe/resources/v2/event.rb', line 9 def self.object_name "v2.core.event" end |