Class: Stripe::V2::EventDestination

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/event_destination.rb

Defined Under Namespace

Classes: AmazonEventbridge, StatusDetails, WebhookEndpoint

Constant Summary collapse

OBJECT_NAME =
"v2.core.event_destination"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amazon_eventbridgeObject (readonly)

Amazon EventBridge configuration.



85
86
87
# File 'lib/stripe/resources/v2/event_destination.rb', line 85

def amazon_eventbridge
  @amazon_eventbridge
end

#createdObject (readonly)

Time at which the object was created.



40
41
42
# File 'lib/stripe/resources/v2/event_destination.rb', line 40

def created
  @created
end

#descriptionObject (readonly)

An optional description of what the event destination is used for.



43
44
45
# File 'lib/stripe/resources/v2/event_destination.rb', line 43

def description
  @description
end

#enabled_eventsObject (readonly)

The list of events to enable for this endpoint.



46
47
48
# File 'lib/stripe/resources/v2/event_destination.rb', line 46

def enabled_events
  @enabled_events
end

#event_payloadObject (readonly)

Payload type of events being subscribed to.



49
50
51
# File 'lib/stripe/resources/v2/event_destination.rb', line 49

def event_payload
  @event_payload
end

#events_fromObject (readonly)

Where events should be routed from.



52
53
54
# File 'lib/stripe/resources/v2/event_destination.rb', line 52

def events_from
  @events_from
end

#idObject (readonly)

Unique identifier for the object.



55
56
57
# File 'lib/stripe/resources/v2/event_destination.rb', line 55

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



58
59
60
# File 'lib/stripe/resources/v2/event_destination.rb', line 58

def livemode
  @livemode
end

#metadataObject (readonly)

Metadata.



61
62
63
# File 'lib/stripe/resources/v2/event_destination.rb', line 61

def 
  @metadata
end

#nameObject (readonly)

Event destination name.



64
65
66
# File 'lib/stripe/resources/v2/event_destination.rb', line 64

def name
  @name
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



67
68
69
# File 'lib/stripe/resources/v2/event_destination.rb', line 67

def object
  @object
end

#snapshot_api_versionObject (readonly)

If using the snapshot event payload, the API version events are rendered as.



70
71
72
# File 'lib/stripe/resources/v2/event_destination.rb', line 70

def snapshot_api_version
  @snapshot_api_version
end

#statusObject (readonly)

Status. It can be set to either enabled or disabled.



73
74
75
# File 'lib/stripe/resources/v2/event_destination.rb', line 73

def status
  @status
end

#status_detailsObject (readonly)

Additional information about event destination status.



76
77
78
# File 'lib/stripe/resources/v2/event_destination.rb', line 76

def status_details
  @status_details
end

#typeObject (readonly)

Event destination type.



79
80
81
# File 'lib/stripe/resources/v2/event_destination.rb', line 79

def type
  @type
end

#updatedObject (readonly)

Time at which the object was last updated.



82
83
84
# File 'lib/stripe/resources/v2/event_destination.rb', line 82

def updated
  @updated
end

#webhook_endpointObject (readonly)

Webhook endpoint configuration.



88
89
90
# File 'lib/stripe/resources/v2/event_destination.rb', line 88

def webhook_endpoint
  @webhook_endpoint
end

Class Method Details

.object_nameObject



8
9
10
# File 'lib/stripe/resources/v2/event_destination.rb', line 8

def self.object_name
  "v2.core.event_destination"
end