Class: Stripe::V2::Extend::Workflow

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/extend/workflow.rb

Overview

A Stripe Workflow is a sequence of actions, like Stripe API calls, that are taken in response to an initiating trigger. A trigger can be a Stripe API event, or a manual invocation.

Defined Under Namespace

Classes: Trigger

Constant Summary collapse

OBJECT_NAME =
"v2.extend.workflow"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#createdObject (readonly)

When the Workflow was created.



56
57
58
# File 'lib/stripe/resources/v2/extend/workflow.rb', line 56

def created
  @created
end

#idObject (readonly)

The unique ID of the Workflow.



58
59
60
# File 'lib/stripe/resources/v2/extend/workflow.rb', line 58

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



60
61
62
# File 'lib/stripe/resources/v2/extend/workflow.rb', line 60

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



62
63
64
# File 'lib/stripe/resources/v2/extend/workflow.rb', line 62

def object
  @object
end

#statusObject (readonly)

Whether this Workflow is active, inactive, or in some other state. Only active Workflows may be invoked.



64
65
66
# File 'lib/stripe/resources/v2/extend/workflow.rb', line 64

def status
  @status
end

#titleObject (readonly)

Workflow title.



66
67
68
# File 'lib/stripe/resources/v2/extend/workflow.rb', line 66

def title
  @title
end

#triggersObject (readonly)

Under what conditions will this Workflow launch.



68
69
70
# File 'lib/stripe/resources/v2/extend/workflow.rb', line 68

def triggers
  @triggers
end

Class Method Details

.field_remappingsObject



74
75
76
# File 'lib/stripe/resources/v2/extend/workflow.rb', line 74

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



70
71
72
# File 'lib/stripe/resources/v2/extend/workflow.rb', line 70

def self.inner_class_types
  @inner_class_types = { triggers: Trigger }
end

.object_nameObject



11
12
13
# File 'lib/stripe/resources/v2/extend/workflow.rb', line 11

def self.object_name
  "v2.extend.workflow"
end