Class: Stripe::V2::Extend::Workflow::Trigger
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Extend::Workflow::Trigger
- Defined in:
- lib/stripe/resources/v2/extend/workflow.rb
Defined Under Namespace
Classes: EventTrigger, Manual
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#event_trigger ⇒ Object
readonly
The Workflow can be launched when Stripe emits a certain event.
-
#manual ⇒ Object
readonly
The Workflow can be launched through a direct call, using either the Dashboard or the Stripe API.
-
#type ⇒ Object
readonly
Which type of trigger this is.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#event_trigger ⇒ Object (readonly)
The Workflow can be launched when Stripe emits a certain event.
41 42 43 |
# File 'lib/stripe/resources/v2/extend/workflow.rb', line 41 def event_trigger @event_trigger end |
#manual ⇒ Object (readonly)
The Workflow can be launched through a direct call, using either the Dashboard or the Stripe API.
43 44 45 |
# File 'lib/stripe/resources/v2/extend/workflow.rb', line 43 def manual @manual end |
#type ⇒ Object (readonly)
Which type of trigger this is.
45 46 47 |
# File 'lib/stripe/resources/v2/extend/workflow.rb', line 45 def type @type end |
Class Method Details
.field_remappings ⇒ Object
51 52 53 |
# File 'lib/stripe/resources/v2/extend/workflow.rb', line 51 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
47 48 49 |
# File 'lib/stripe/resources/v2/extend/workflow.rb', line 47 def self.inner_class_types @inner_class_types = { event_trigger: EventTrigger, manual: Manual } end |