Class: Stripe::V2::Extend::WorkflowListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/v2/extend/workflow_list_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(limit: nil, status: nil) ⇒ WorkflowListParams

Returns a new instance of WorkflowListParams.



14
15
16
17
# File 'lib/stripe/params/v2/extend/workflow_list_params.rb', line 14

def initialize(limit: nil, status: nil)
  @limit = limit
  @status = status
end

Instance Attribute Details

#limitObject

Restrict page size to no more than this number.



9
10
11
# File 'lib/stripe/params/v2/extend/workflow_list_params.rb', line 9

def limit
  @limit
end

#statusObject

When retrieving Workflows, include only those with the specified status values. If not specified, all Workflows in active and inactive status are returned.



12
13
14
# File 'lib/stripe/params/v2/extend/workflow_list_params.rb', line 12

def status
  @status
end