Class: Stripe::V2::Extend::WorkflowRun::Trigger
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Extend::WorkflowRun::Trigger
- Defined in:
- lib/stripe/resources/v2/extend/workflow_run.rb
Defined Under Namespace
Classes: EventTrigger, Manual
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#event_trigger ⇒ Object
readonly
The Workflow Run was launched when Stripe emitted a certain event.
-
#manual ⇒ Object
readonly
The Workflow Run was launched through a direct call, using either the Dashboard or the Stripe API.
-
#type ⇒ Object
readonly
Which type of trigger this is.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#event_trigger ⇒ Object (readonly)
The Workflow Run was launched when Stripe emitted a certain event.
111 112 113 |
# File 'lib/stripe/resources/v2/extend/workflow_run.rb', line 111 def event_trigger @event_trigger end |
#manual ⇒ Object (readonly)
The Workflow Run was launched through a direct call, using either the Dashboard or the Stripe API.
113 114 115 |
# File 'lib/stripe/resources/v2/extend/workflow_run.rb', line 113 def manual @manual end |
#type ⇒ Object (readonly)
Which type of trigger this is.
115 116 117 |
# File 'lib/stripe/resources/v2/extend/workflow_run.rb', line 115 def type @type end |
Class Method Details
.field_remappings ⇒ Object
121 122 123 |
# File 'lib/stripe/resources/v2/extend/workflow_run.rb', line 121 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
117 118 119 |
# File 'lib/stripe/resources/v2/extend/workflow_run.rb', line 117 def self.inner_class_types @inner_class_types = { event_trigger: EventTrigger, manual: Manual } end |