Class: Stripe::V2::Extend::WorkflowRunListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/v2/extend/workflow_run_list_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(limit: nil, status: nil, workflow: nil) ⇒ WorkflowRunListParams

Returns a new instance of WorkflowRunListParams.



15
16
17
18
19
# File 'lib/stripe/params/v2/extend/workflow_run_list_params.rb', line 15

def initialize(limit: nil, status: nil, workflow: nil)
  @limit = limit
  @status = status
  @workflow = workflow
end

Instance Attribute Details

#limitObject

Restrict page size to no more than this number.



9
10
11
# File 'lib/stripe/params/v2/extend/workflow_run_list_params.rb', line 9

def limit
  @limit
end

#statusObject

When retrieving Workflow Runs, include only those with the specified status values. If not specified, all Runs are returned.



11
12
13
# File 'lib/stripe/params/v2/extend/workflow_run_list_params.rb', line 11

def status
  @status
end

#workflowObject

When retrieving Workflow Runs, include only those associated with the Workflows specified. If not specified, all Runs are returned.



13
14
15
# File 'lib/stripe/params/v2/extend/workflow_run_list_params.rb', line 13

def workflow
  @workflow
end