Class: Stripe::V2::Extend::WorkflowService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::V2::Extend::WorkflowService
- Defined in:
- lib/stripe/services/v2/extend/workflow_service.rb
Instance Method Summary collapse
-
#invoke(id, params = {}, opts = {}) ⇒ Object
Invokes an on-demand Workflow with parameters, to launch a new Workflow Run.
-
#list(params = {}, opts = {}) ⇒ Object
List all Workflows.
-
#retrieve(id, params = {}, opts = {}) ⇒ Object
Retrieves the details of a Workflow by ID.
Methods inherited from StripeService
#initialize, #request, #request_stream
Constructor Details
This class inherits a constructor from Stripe::StripeService
Instance Method Details
#invoke(id, params = {}, opts = {}) ⇒ Object
Invokes an on-demand Workflow with parameters, to launch a new Workflow Run.
** raises CannotProceedError
11 12 13 14 15 16 17 18 19 |
# File 'lib/stripe/services/v2/extend/workflow_service.rb', line 11 def invoke(id, params = {}, opts = {}) request( method: :post, path: format("/v2/extend/workflows/%<id>s/invoke", { id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |
#list(params = {}, opts = {}) ⇒ Object
List all Workflows.
22 23 24 25 26 27 28 29 30 |
# File 'lib/stripe/services/v2/extend/workflow_service.rb', line 22 def list(params = {}, opts = {}) request( method: :get, path: "/v2/extend/workflows", params: params, opts: opts, base_address: :api ) end |
#retrieve(id, params = {}, opts = {}) ⇒ Object
Retrieves the details of a Workflow by ID.
33 34 35 36 37 38 39 40 41 |
# File 'lib/stripe/services/v2/extend/workflow_service.rb', line 33 def retrieve(id, params = {}, opts = {}) request( method: :get, path: format("/v2/extend/workflows/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |