Class: Stripe::V2::FinancialAddressGeneratedMicrodeposits
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::FinancialAddressGeneratedMicrodeposits
- Defined in:
- lib/stripe/resources/v2/financial_address_generated_microdeposits.rb
Overview
Generated Microdeposits represent verification deposits sent to a financial address for ownership verification, containing the deposited amounts and status.
Constant Summary collapse
- OBJECT_NAME =
"financial_address_generated_microdeposits"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amounts ⇒ Object
readonly
The amounts of the microdeposits that were generated.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#status ⇒ Object
readonly
Closed Enum.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amounts ⇒ Object (readonly)
The amounts of the microdeposits that were generated.
14 15 16 |
# File 'lib/stripe/resources/v2/financial_address_generated_microdeposits.rb', line 14 def amounts @amounts end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
16 17 18 |
# File 'lib/stripe/resources/v2/financial_address_generated_microdeposits.rb', line 16 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
18 19 20 |
# File 'lib/stripe/resources/v2/financial_address_generated_microdeposits.rb', line 18 def object @object end |
#status ⇒ Object (readonly)
Closed Enum. The status of the request.
20 21 22 |
# File 'lib/stripe/resources/v2/financial_address_generated_microdeposits.rb', line 20 def status @status end |
Class Method Details
.field_remappings ⇒ Object
26 27 28 |
# File 'lib/stripe/resources/v2/financial_address_generated_microdeposits.rb', line 26 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
22 23 24 |
# File 'lib/stripe/resources/v2/financial_address_generated_microdeposits.rb', line 22 def self.inner_class_types @inner_class_types = {} end |
.object_name ⇒ Object
9 10 11 |
# File 'lib/stripe/resources/v2/financial_address_generated_microdeposits.rb', line 9 def self.object_name "financial_address_generated_microdeposits" end |