Class: Stripe::V2::Iam::ActivityLog

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/iam/activity_log.rb

Overview

An activity log records a single action performed on an account.

Defined Under Namespace

Classes: Actor, Details

Constant Summary collapse

OBJECT_NAME =
"v2.iam.activity_log"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#actorObject (readonly)

The actor that performed the action.



161
162
163
# File 'lib/stripe/resources/v2/iam/activity_log.rb', line 161

def actor
  @actor
end

#contextObject (readonly)

The account on which the action was performed.



163
164
165
# File 'lib/stripe/resources/v2/iam/activity_log.rb', line 163

def context
  @context
end

#createdObject (readonly)

Timestamp when the activity log entry was created.



165
166
167
# File 'lib/stripe/resources/v2/iam/activity_log.rb', line 165

def created
  @created
end

#detailsObject (readonly)

Action-specific details of the activity log entry.



167
168
169
# File 'lib/stripe/resources/v2/iam/activity_log.rb', line 167

def details
  @details
end

#idObject (readonly)

Unique identifier of the activity log entry.



169
170
171
# File 'lib/stripe/resources/v2/iam/activity_log.rb', line 169

def id
  @id
end

#livemodeObject (readonly)

Whether the action was performed in live mode.



171
172
173
# File 'lib/stripe/resources/v2/iam/activity_log.rb', line 171

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



173
174
175
# File 'lib/stripe/resources/v2/iam/activity_log.rb', line 173

def object
  @object
end

#typeObject (readonly)

The type of action that was performed.



175
176
177
# File 'lib/stripe/resources/v2/iam/activity_log.rb', line 175

def type
  @type
end

Class Method Details

.field_remappingsObject



181
182
183
# File 'lib/stripe/resources/v2/iam/activity_log.rb', line 181

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



177
178
179
# File 'lib/stripe/resources/v2/iam/activity_log.rb', line 177

def self.inner_class_types
  @inner_class_types = { actor: Actor, details: Details }
end

.object_nameObject



10
11
12
# File 'lib/stripe/resources/v2/iam/activity_log.rb', line 10

def self.object_name
  "v2.iam.activity_log"
end