Class: Stripe::V2::Iam::ApiKeyCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Iam::ApiKeyCreateParams
- Defined in:
- lib/stripe/params/v2/iam/api_key_create_params.rb
Defined Under Namespace
Classes: PublicKey
Instance Attribute Summary collapse
-
#connect_permissions ⇒ Object
List of connect permissions for this API key.
-
#expires_at ⇒ Object
Timestamp at which the key expires.
-
#name ⇒ Object
Name for the API key.
-
#note ⇒ Object
Note or description for the API key.
-
#permissions ⇒ Object
List of permissions for this API key.
-
#public_key ⇒ Object
Public key for encrypting the API key secret.
-
#type ⇒ Object
Type of the API key to create (secret or publishable).
Instance Method Summary collapse
-
#initialize(connect_permissions: nil, expires_at: nil, name: nil, note: nil, permissions: nil, public_key: nil, type: nil) ⇒ ApiKeyCreateParams
constructor
A new instance of ApiKeyCreateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(connect_permissions: nil, expires_at: nil, name: nil, note: nil, permissions: nil, public_key: nil, type: nil) ⇒ ApiKeyCreateParams
Returns a new instance of ApiKeyCreateParams.
48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/stripe/params/v2/iam/api_key_create_params.rb', line 48 def initialize( connect_permissions: nil, expires_at: nil, name: nil, note: nil, permissions: nil, public_key: nil, type: nil ) @connect_permissions = @expires_at = expires_at @name = name @note = note @permissions = @public_key = public_key @type = type end |
Instance Attribute Details
#connect_permissions ⇒ Object
List of connect permissions for this API key.
31 32 33 |
# File 'lib/stripe/params/v2/iam/api_key_create_params.rb', line 31 def @connect_permissions end |
#expires_at ⇒ Object
Timestamp at which the key expires. If not provided, the key never expires.
33 34 35 |
# File 'lib/stripe/params/v2/iam/api_key_create_params.rb', line 33 def expires_at @expires_at end |
#name ⇒ Object
Name for the API key.
35 36 37 |
# File 'lib/stripe/params/v2/iam/api_key_create_params.rb', line 35 def name @name end |
#note ⇒ Object
Note or description for the API key.
37 38 39 |
# File 'lib/stripe/params/v2/iam/api_key_create_params.rb', line 37 def note @note end |
#permissions ⇒ Object
List of permissions for this API key.
39 40 41 |
# File 'lib/stripe/params/v2/iam/api_key_create_params.rb', line 39 def @permissions end |
#public_key ⇒ Object
Public key for encrypting the API key secret. This must a PEM-formatted RSA key suitable for encryption, >= 2048 bits. A public key is required when creating secret keys. Publishable keys are not encrypted and a public key should not be included.
44 45 46 |
# File 'lib/stripe/params/v2/iam/api_key_create_params.rb', line 44 def public_key @public_key end |
#type ⇒ Object
Type of the API key to create (secret or publishable).
46 47 48 |
# File 'lib/stripe/params/v2/iam/api_key_create_params.rb', line 46 def type @type end |