Class: Stripe::V2::MoneyManagement::AdjustmentListParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/money_management/adjustment_list_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(adjusted_flow: nil, created: nil, created_gt: nil, created_gte: nil, created_lt: nil, created_lte: nil, limit: nil) ⇒ AdjustmentListParams

Returns a new instance of AdjustmentListParams.



28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
# File 'lib/stripe/params/v2/money_management/adjustment_list_params.rb', line 28

def initialize(
  adjusted_flow: nil,
  created: nil,
  created_gt: nil,
  created_gte: nil,
  created_lt: nil,
  created_lte: nil,
  limit: nil
)
  @adjusted_flow = adjusted_flow
  @created = created
  @created_gt = created_gt
  @created_gte = created_gte
  @created_lt = created_lt
  @created_lte = created_lte
  @limit = limit
end

Instance Attribute Details

#adjusted_flowObject

Filter for Adjustments linked to a Flow.



9
10
11
# File 'lib/stripe/params/v2/money_management/adjustment_list_params.rb', line 9

def adjusted_flow
  @adjusted_flow
end

#createdObject

Filter for objects created at the specified timestamp. Must be an RFC 3339 date & time value, for example: 2022-09-18T13:22:00Z.



12
13
14
# File 'lib/stripe/params/v2/money_management/adjustment_list_params.rb', line 12

def created
  @created
end

#created_gtObject

Filter for objects created after the specified timestamp. Must be an RFC 3339 date & time value, for example: 2022-09-18T13:22:00Z.



15
16
17
# File 'lib/stripe/params/v2/money_management/adjustment_list_params.rb', line 15

def created_gt
  @created_gt
end

#created_gteObject

Filter for objects created on or after the specified timestamp. Must be an RFC 3339 date & time value, for example: 2022-09-18T13:22:00Z.



18
19
20
# File 'lib/stripe/params/v2/money_management/adjustment_list_params.rb', line 18

def created_gte
  @created_gte
end

#created_ltObject

Filter for objects created before the specified timestamp. Must be an RFC 3339 date & time value, for example: 2022-09-18T13:22:00Z.



21
22
23
# File 'lib/stripe/params/v2/money_management/adjustment_list_params.rb', line 21

def created_lt
  @created_lt
end

#created_lteObject

Filter for objects created on or before the specified timestamp. Must be an RFC 3339 date & time value, for example: 2022-09-18T13:22:00Z.



24
25
26
# File 'lib/stripe/params/v2/money_management/adjustment_list_params.rb', line 24

def created_lte
  @created_lte
end

#limitObject

The page limit.



26
27
28
# File 'lib/stripe/params/v2/money_management/adjustment_list_params.rb', line 26

def limit
  @limit
end