Class: Stripe::V2::MoneyManagement::AdjustmentService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::V2::MoneyManagement::AdjustmentService
- Defined in:
- lib/stripe/services/v2/money_management/adjustment_service.rb
Defined Under Namespace
Classes: ListParams, RetrieveParams
Instance Method Summary collapse
-
#list(params = {}, opts = {}) ⇒ Object
Returns a list of Adjustments that match the provided filters.
-
#retrieve(id, params = {}, opts = {}) ⇒ Object
Retrieves the details of an Adjustment by ID.
Methods inherited from StripeService
#initialize, #request, #request_stream
Constructor Details
This class inherits a constructor from Stripe::StripeService
Instance Method Details
#list(params = {}, opts = {}) ⇒ Object
Returns a list of Adjustments that match the provided filters.
51 52 53 54 55 56 57 58 59 |
# File 'lib/stripe/services/v2/money_management/adjustment_service.rb', line 51 def list(params = {}, opts = {}) request( method: :get, path: "/v2/money_management/adjustments", params: params, opts: opts, base_address: :api ) end |
#retrieve(id, params = {}, opts = {}) ⇒ Object
Retrieves the details of an Adjustment by ID.
62 63 64 65 66 67 68 69 70 |
# File 'lib/stripe/services/v2/money_management/adjustment_service.rb', line 62 def retrieve(id, params = {}, opts = {}) request( method: :get, path: format("/v2/money_management/adjustments/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |