Class: Stripe::V2::MoneyManagement::CurrencyConversionCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::MoneyManagement::CurrencyConversionCreateParams
- Defined in:
- lib/stripe/params/v2/money_management/currency_conversion_create_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#financial_account ⇒ Object
The FinancialAccount id to create the CurrencyConversion on.
-
#from ⇒ Object
From amount object indicating the from currency or optional amount.
-
#fx_quote ⇒ Object
The FX quote to use for the conversion.
-
#to ⇒ Object
To amount object indicating the to currency or optional amount.
Instance Method Summary collapse
-
#initialize(financial_account: nil, from: nil, fx_quote: nil, to: nil) ⇒ CurrencyConversionCreateParams
constructor
A new instance of CurrencyConversionCreateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(financial_account: nil, from: nil, fx_quote: nil, to: nil) ⇒ CurrencyConversionCreateParams
Returns a new instance of CurrencyConversionCreateParams.
40 41 42 43 44 45 |
# File 'lib/stripe/params/v2/money_management/currency_conversion_create_params.rb', line 40 def initialize(financial_account: nil, from: nil, fx_quote: nil, to: nil) @financial_account = financial_account @from = from @fx_quote = fx_quote @to = to end |
Instance Attribute Details
#financial_account ⇒ Object
The FinancialAccount id to create the CurrencyConversion on.
32 33 34 |
# File 'lib/stripe/params/v2/money_management/currency_conversion_create_params.rb', line 32 def financial_account @financial_account end |
#from ⇒ Object
From amount object indicating the from currency or optional amount.
34 35 36 |
# File 'lib/stripe/params/v2/money_management/currency_conversion_create_params.rb', line 34 def from @from end |
#fx_quote ⇒ Object
The FX quote to use for the conversion.
36 37 38 |
# File 'lib/stripe/params/v2/money_management/currency_conversion_create_params.rb', line 36 def fx_quote @fx_quote end |
#to ⇒ Object
To amount object indicating the to currency or optional amount.
38 39 40 |
# File 'lib/stripe/params/v2/money_management/currency_conversion_create_params.rb', line 38 def to @to end |