Class: Stripe::V2::MoneyManagement::CurrencyConversionCreateParams::To::Amount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::MoneyManagement::CurrencyConversionCreateParams::To::Amount
- Defined in:
- lib/stripe/params/v2/money_management/currency_conversion_create_params.rb
Instance Attribute Summary collapse
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#value ⇒ Object
A non-negative integer representing how much to charge in the [smallest currency unit](docs.stripe.com/currencies#minor-units).
Instance Method Summary collapse
-
#initialize(value: nil, currency: nil) ⇒ Amount
constructor
A new instance of Amount.
Methods inherited from RequestParams
Constructor Details
#initialize(value: nil, currency: nil) ⇒ Amount
Returns a new instance of Amount.
38 39 40 41 |
# File 'lib/stripe/params/v2/money_management/currency_conversion_create_params.rb', line 38 def initialize(value: nil, currency: nil) @value = value @currency = currency end |
Instance Attribute Details
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
36 37 38 |
# File 'lib/stripe/params/v2/money_management/currency_conversion_create_params.rb', line 36 def currency @currency end |
#value ⇒ Object
A non-negative integer representing how much to charge in the [smallest currency unit](docs.stripe.com/currencies#minor-units).
34 35 36 |
# File 'lib/stripe/params/v2/money_management/currency_conversion_create_params.rb', line 34 def value @value end |