Class: Stripe::V2::MoneyManagement::CurrencyConversionService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::V2::MoneyManagement::CurrencyConversionService
- Defined in:
- lib/stripe/services/v2/money_management/currency_conversion_service.rb
Instance Method Summary collapse
-
#create(params = {}, opts = {}) ⇒ Object
Create a CurrencyConversion.
-
#list(params = {}, opts = {}) ⇒ Object
List all CurrencyConversion on an account with the option to filter by FinancialAccount.
-
#retrieve(id, params = {}, opts = {}) ⇒ Object
Retrieve details of a CurrencyConversion by id.
Methods inherited from StripeService
#initialize, #request, #request_stream
Constructor Details
This class inherits a constructor from Stripe::StripeService
Instance Method Details
#create(params = {}, opts = {}) ⇒ Object
Create a CurrencyConversion.
** raises FeatureNotEnabledError
11 12 13 14 15 16 17 18 19 |
# File 'lib/stripe/services/v2/money_management/currency_conversion_service.rb', line 11 def create(params = {}, opts = {}) request( method: :post, path: "/v2/money_management/currency_conversions", params: params, opts: opts, base_address: :api ) end |
#list(params = {}, opts = {}) ⇒ Object
List all CurrencyConversion on an account with the option to filter by FinancialAccount.
22 23 24 25 26 27 28 29 30 |
# File 'lib/stripe/services/v2/money_management/currency_conversion_service.rb', line 22 def list(params = {}, opts = {}) request( method: :get, path: "/v2/money_management/currency_conversions", params: params, opts: opts, base_address: :api ) end |
#retrieve(id, params = {}, opts = {}) ⇒ Object
Retrieve details of a CurrencyConversion by id.
33 34 35 36 37 38 39 40 41 |
# File 'lib/stripe/services/v2/money_management/currency_conversion_service.rb', line 33 def retrieve(id, params = {}, opts = {}) request( method: :get, path: format("/v2/money_management/currency_conversions/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |