Class: Stripe::V2::MoneyManagement::DebitDispute::BankTransfer
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::MoneyManagement::DebitDispute::BankTransfer
- Defined in:
- lib/stripe/resources/v2/money_management/debit_dispute.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#network ⇒ Object
readonly
The bank network the dispute was originated on.
-
#reason ⇒ Object
readonly
The reason for the dispute.
-
#statement_descriptor ⇒ Object
readonly
The statement descriptor set by the originator of the debit.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#network ⇒ Object (readonly)
The bank network the dispute was originated on.
16 17 18 |
# File 'lib/stripe/resources/v2/money_management/debit_dispute.rb', line 16 def network @network end |
#reason ⇒ Object (readonly)
The reason for the dispute.
18 19 20 |
# File 'lib/stripe/resources/v2/money_management/debit_dispute.rb', line 18 def reason @reason end |
#statement_descriptor ⇒ Object (readonly)
The statement descriptor set by the originator of the debit.
20 21 22 |
# File 'lib/stripe/resources/v2/money_management/debit_dispute.rb', line 20 def statement_descriptor @statement_descriptor end |
Class Method Details
.field_remappings ⇒ Object
26 27 28 |
# File 'lib/stripe/resources/v2/money_management/debit_dispute.rb', line 26 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
22 23 24 |
# File 'lib/stripe/resources/v2/money_management/debit_dispute.rb', line 22 def self.inner_class_types @inner_class_types = {} end |