Class: Stripe::V2::MoneyManagement::FinancialAccount::Balance

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/money_management/financial_account.rb

Defined Under Namespace

Classes: Available, InboundPending, OutboundPending

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#availableObject (readonly)

Balance that can be used for money movement.



75
76
77
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 75

def available
  @available
end

#inbound_pendingObject (readonly)

Balance of inbound funds that will later transition to the ‘available` balance.



77
78
79
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 77

def inbound_pending
  @inbound_pending
end

#outbound_pendingObject (readonly)

Balance of funds that are being used for a pending outbound money movement.



79
80
81
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 79

def outbound_pending
  @outbound_pending
end

Class Method Details

.field_remappingsObject



89
90
91
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 89

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



81
82
83
84
85
86
87
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 81

def self.inner_class_types
  @inner_class_types = {
    available: Available,
    inbound_pending: InboundPending,
    outbound_pending: OutboundPending,
  }
end