Class: Stripe::V2::MoneyManagement::FinancialAccount::Payments

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/money_management/financial_account.rb

Defined Under Namespace

Classes: BalanceByFundsType, StartingBalance

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#balance_by_funds_typeObject (readonly)

The balance of the payments FinancialAccount is a mix of payment processing and stored value funds, and this field describes the breakdown between the two. The sum will match the balance of the FinancialAccount.



181
182
183
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 181

def balance_by_funds_type
  @balance_by_funds_type
end

#default_currencyObject (readonly)

The currency that non-settlement currency payments will be converted to.



183
184
185
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 183

def default_currency
  @default_currency
end

#settlement_currenciesObject (readonly)

Settlement currencies enabled for this FinancialAccount. Payments in other currencies will be automatically converted to default_currency.



185
186
187
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 185

def settlement_currencies
  @settlement_currencies
end

#starting_balanceObject (readonly)

Describes the available balance when it was projected.



187
188
189
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 187

def starting_balance
  @starting_balance
end

Class Method Details

.field_remappingsObject



196
197
198
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 196

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



189
190
191
192
193
194
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 189

def self.inner_class_types
  @inner_class_types = {
    balance_by_funds_type: BalanceByFundsType,
    starting_balance: StartingBalance,
  }
end