Class: Stripe::V2::MoneyManagement::FinancialAccountStatement
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::MoneyManagement::FinancialAccountStatement
- Defined in:
- lib/stripe/resources/v2/money_management/financial_account_statement.rb
Overview
A Financial Account Statement represents a monthly statement for a Financial Account.
Defined Under Namespace
Classes: FilesByCurrency, Period
Constant Summary collapse
- OBJECT_NAME =
"v2.money_management.financial_account_statement"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#created ⇒ Object
readonly
Time at which the statement was created, in ISO 8601 format (UTC).
-
#ending_balance ⇒ Object
readonly
Available balance at the end of the statement period.
-
#files_by_currency ⇒ Object
readonly
Currency-specific files and file metadata.
-
#financial_account ⇒ Object
readonly
The Financial Account this statement belongs to.
-
#id ⇒ Object
readonly
Unique identifier for the statement.
-
#livemode ⇒ Object
readonly
True if the object exists in live mode, false if in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#period ⇒ Object
readonly
The time period covered by this statement.
-
#restated_by ⇒ Object
readonly
The ID of the statement that replaced this one.
-
#restated_statement ⇒ Object
readonly
The ID of the statement this one replaces.
-
#starting_balance ⇒ Object
readonly
Available balance at the start of the statement period.
-
#status ⇒ Object
readonly
The status of the statement.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#created ⇒ Object (readonly)
Time at which the statement was created, in ISO 8601 format (UTC).
66 67 68 |
# File 'lib/stripe/resources/v2/money_management/financial_account_statement.rb', line 66 def created @created end |
#ending_balance ⇒ Object (readonly)
Available balance at the end of the statement period.
68 69 70 |
# File 'lib/stripe/resources/v2/money_management/financial_account_statement.rb', line 68 def ending_balance @ending_balance end |
#files_by_currency ⇒ Object (readonly)
Currency-specific files and file metadata. Null by default, populated by specifying include=files_by_currency in the Retrieve endpoint.
70 71 72 |
# File 'lib/stripe/resources/v2/money_management/financial_account_statement.rb', line 70 def files_by_currency @files_by_currency end |
#financial_account ⇒ Object (readonly)
The Financial Account this statement belongs to.
72 73 74 |
# File 'lib/stripe/resources/v2/money_management/financial_account_statement.rb', line 72 def financial_account @financial_account end |
#id ⇒ Object (readonly)
Unique identifier for the statement.
74 75 76 |
# File 'lib/stripe/resources/v2/money_management/financial_account_statement.rb', line 74 def id @id end |
#livemode ⇒ Object (readonly)
True if the object exists in live mode, false if in test mode.
76 77 78 |
# File 'lib/stripe/resources/v2/money_management/financial_account_statement.rb', line 76 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
78 79 80 |
# File 'lib/stripe/resources/v2/money_management/financial_account_statement.rb', line 78 def object @object end |
#period ⇒ Object (readonly)
The time period covered by this statement.
80 81 82 |
# File 'lib/stripe/resources/v2/money_management/financial_account_statement.rb', line 80 def period @period end |
#restated_by ⇒ Object (readonly)
The ID of the statement that replaced this one. Only present on statements that have been restated.
82 83 84 |
# File 'lib/stripe/resources/v2/money_management/financial_account_statement.rb', line 82 def restated_by @restated_by end |
#restated_statement ⇒ Object (readonly)
The ID of the statement this one replaces. Only present on restatements.
84 85 86 |
# File 'lib/stripe/resources/v2/money_management/financial_account_statement.rb', line 84 def restated_statement @restated_statement end |
#starting_balance ⇒ Object (readonly)
Available balance at the start of the statement period.
86 87 88 |
# File 'lib/stripe/resources/v2/money_management/financial_account_statement.rb', line 86 def starting_balance @starting_balance end |
#status ⇒ Object (readonly)
The status of the statement. A statement is “active” by default. When a statement is replaced by a restatement, its status becomes “restated”.
89 90 91 |
# File 'lib/stripe/resources/v2/money_management/financial_account_statement.rb', line 89 def status @status end |
Class Method Details
.field_remappings ⇒ Object
95 96 97 |
# File 'lib/stripe/resources/v2/money_management/financial_account_statement.rb', line 95 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
91 92 93 |
# File 'lib/stripe/resources/v2/money_management/financial_account_statement.rb', line 91 def self.inner_class_types @inner_class_types = { files_by_currency: FilesByCurrency, period: Period } end |
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/v2/money_management/financial_account_statement.rb', line 10 def self.object_name "v2.money_management.financial_account_statement" end |