Class: Stripe::V2::MoneyManagement::FinancialAccounts::StatementService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::V2::MoneyManagement::FinancialAccounts::StatementService
- Defined in:
- lib/stripe/services/v2/money_management/financial_accounts/statement_service.rb
Instance Method Summary collapse
-
#list(financial_account_id, params = {}, opts = {}) ⇒ Object
Returns a list of statements for a Financial Account.
-
#retrieve(financial_account_id, id, params = {}, opts = {}) ⇒ Object
Retrieves the details of a Financial Account Statement.
Methods inherited from StripeService
#initialize, #request, #request_stream
Constructor Details
This class inherits a constructor from Stripe::StripeService
Instance Method Details
#list(financial_account_id, params = {}, opts = {}) ⇒ Object
Returns a list of statements for a Financial Account.
10 11 12 13 14 15 16 17 18 |
# File 'lib/stripe/services/v2/money_management/financial_accounts/statement_service.rb', line 10 def list(financial_account_id, params = {}, opts = {}) request( method: :get, path: format("/v2/money_management/financial_accounts/%<financial_account_id>s/statements", { financial_account_id: CGI.escape(financial_account_id) }), params: params, opts: opts, base_address: :api ) end |
#retrieve(financial_account_id, id, params = {}, opts = {}) ⇒ Object
Retrieves the details of a Financial Account Statement.
21 22 23 24 25 26 27 28 29 |
# File 'lib/stripe/services/v2/money_management/financial_accounts/statement_service.rb', line 21 def retrieve(financial_account_id, id, params = {}, opts = {}) request( method: :get, path: format("/v2/money_management/financial_accounts/%<financial_account_id>s/statements/%<id>s", { financial_account_id: CGI.escape(financial_account_id), id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |