Class: Stripe::V2::MoneyManagement::FinancialAddress::Credentials::CaBankAccount

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/money_management/financial_address.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_holder_nameObject (readonly)

The account holder name to be used during bank transfers.



17
18
19
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 17

def 
  @account_holder_name
end

#account_numberObject (readonly)

The account number of the Canadian Bank Account.



19
20
21
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 19

def 
  @account_number
end

#bank_nameObject (readonly)

The name of the Bank.



21
22
23
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 21

def bank_name
  @bank_name
end

#institution_numberObject (readonly)

The institution number of the Canadian Bank Account.



23
24
25
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 23

def institution_number
  @institution_number
end

#last4Object (readonly)

The last four digits of the Canadian Bank Account number. This will always be returned. To view the full account number when retrieving or listing FinancialAddresses, use the ‘include` request parameter.



26
27
28
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 26

def last4
  @last4
end

#transit_numberObject (readonly)

The transit number of the Canadian Bank Account.



28
29
30
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 28

def transit_number
  @transit_number
end

Class Method Details

.field_remappingsObject



34
35
36
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 34

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



30
31
32
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 30

def self.inner_class_types
  @inner_class_types = {}
end