Class: Stripe::V2::MoneyManagement::FinancialAddress::Credentials::SepaBankAccount
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::MoneyManagement::FinancialAddress::Credentials::SepaBankAccount
- Defined in:
- lib/stripe/resources/v2/money_management/financial_address.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
readonly
The account holder name to be used during bank transfers.
-
#bank_name ⇒ Object
readonly
The name of the Bank.
-
#bic ⇒ Object
readonly
The BIC of the SEPA Bank Account.
-
#country ⇒ Object
readonly
The originating country of the SEPA Bank account.
-
#iban ⇒ Object
readonly
The IBAN of the SEPA Bank Account.
-
#last4 ⇒ Object
readonly
The last four digits of the SEPA Bank Account number.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_holder_name ⇒ Object (readonly)
The account holder name to be used during bank transfers.
93 94 95 |
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 93 def account_holder_name @account_holder_name end |
#bank_name ⇒ Object (readonly)
The name of the Bank.
95 96 97 |
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 95 def bank_name @bank_name end |
#bic ⇒ Object (readonly)
The BIC of the SEPA Bank Account.
97 98 99 |
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 97 def bic @bic end |
#country ⇒ Object (readonly)
The originating country of the SEPA Bank account.
99 100 101 |
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 99 def country @country end |
#iban ⇒ Object (readonly)
The IBAN of the SEPA Bank Account.
101 102 103 |
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 101 def iban @iban end |
#last4 ⇒ Object (readonly)
The last four digits of the SEPA Bank Account number. This will always be returned. To view the full account number when retrieving or listing FinancialAddresses, use the ‘include` request parameter.
104 105 106 |
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 104 def last4 @last4 end |
Class Method Details
.field_remappings ⇒ Object
110 111 112 |
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 110 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
106 107 108 |
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 106 def self.inner_class_types @inner_class_types = {} end |