Class: Stripe::V2::MoneyManagement::FinancialAddressCreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/money_management/financial_address_create_params.rb

Defined Under Namespace

Classes: CryptoProperties, SepaBankAccount

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(crypto_properties: nil, financial_account: nil, sepa_bank_account: nil, settlement_currency: nil, type: nil) ⇒ FinancialAddressCreateParams

Returns a new instance of FinancialAddressCreateParams.



36
37
38
39
40
41
42
43
44
45
46
47
48
# File 'lib/stripe/params/v2/money_management/financial_address_create_params.rb', line 36

def initialize(
  crypto_properties: nil,
  financial_account: nil,
  sepa_bank_account: nil,
  settlement_currency: nil,
  type: nil
)
  @crypto_properties = crypto_properties
  @financial_account = 
  @sepa_bank_account = 
  @settlement_currency = settlement_currency
  @type = type
end

Instance Attribute Details

#crypto_propertiesObject

Properties needed to create a FinancialAddress for an FA with USDC currency.



26
27
28
# File 'lib/stripe/params/v2/money_management/financial_address_create_params.rb', line 26

def crypto_properties
  @crypto_properties
end

#financial_accountObject

The ID of the FinancialAccount the new FinancialAddress should be associated with.



28
29
30
# File 'lib/stripe/params/v2/money_management/financial_address_create_params.rb', line 28

def 
  @financial_account
end

#sepa_bank_accountObject

Optional SEPA Bank account options, used to configure the type of SEPA Bank account to create, such as the originating country.



30
31
32
# File 'lib/stripe/params/v2/money_management/financial_address_create_params.rb', line 30

def 
  @sepa_bank_account
end

#settlement_currencyObject

Open Enum. The currency the FinancialAddress settles into the FinancialAccount. Currently, only the ‘usd`, `gbp` and `usdc` values are supported.



32
33
34
# File 'lib/stripe/params/v2/money_management/financial_address_create_params.rb', line 32

def settlement_currency
  @settlement_currency
end

#typeObject

The type of FinancialAddress details to provision.



34
35
36
# File 'lib/stripe/params/v2/money_management/financial_address_create_params.rb', line 34

def type
  @type
end