Class: Stripe::V2::MoneyManagement::FinancialAddressDebitSimulation

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/money_management/financial_address_debit_simulation.rb

Overview

Debit Simulations represent a simulated debit transaction applied to financial addresses for testing purposes.

Constant Summary collapse

OBJECT_NAME =
"v2.money_management.financial_address_debit_simulation"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#livemodeObject (readonly)

Has the value true if the object exists in live mode or the value false if the object exists in test mode.



15
16
17
# File 'lib/stripe/resources/v2/money_management/financial_address_debit_simulation.rb', line 15

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object's type. Objects of the same type share the same value of the object field.



17
18
19
# File 'lib/stripe/resources/v2/money_management/financial_address_debit_simulation.rb', line 17

def object
  @object
end

#statusObject (readonly)

The status of the request, signifying whether a simulated debit was initiated.



19
20
21
# File 'lib/stripe/resources/v2/money_management/financial_address_debit_simulation.rb', line 19

def status
  @status
end

Class Method Details

.field_remappingsObject



25
26
27
# File 'lib/stripe/resources/v2/money_management/financial_address_debit_simulation.rb', line 25

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



21
22
23
# File 'lib/stripe/resources/v2/money_management/financial_address_debit_simulation.rb', line 21

def self.inner_class_types
  @inner_class_types = {}
end

.object_nameObject



10
11
12
# File 'lib/stripe/resources/v2/money_management/financial_address_debit_simulation.rb', line 10

def self.object_name
  "v2.money_management.financial_address_debit_simulation"
end