Class: Stripe::V2::MoneyManagement::InboundTransferCreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/money_management/inbound_transfer_create_params.rb

Defined Under Namespace

Classes: From, To

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, description: nil, from: nil, to: nil) ⇒ InboundTransferCreateParams

Returns a new instance of InboundTransferCreateParams.



41
42
43
44
45
46
# File 'lib/stripe/params/v2/money_management/inbound_transfer_create_params.rb', line 41

def initialize(amount: nil, description: nil, from: nil, to: nil)
  @amount = amount
  @description = description
  @from = from
  @to = to
end

Instance Attribute Details

#amountObject

The amount, in specified currency, by which the FinancialAccount balance will increase due to the InboundTransfer.



33
34
35
# File 'lib/stripe/params/v2/money_management/inbound_transfer_create_params.rb', line 33

def amount
  @amount
end

#descriptionObject

An optional, freeform description field intended to store metadata.



35
36
37
# File 'lib/stripe/params/v2/money_management/inbound_transfer_create_params.rb', line 35

def description
  @description
end

#fromObject

Object containing details about where the funds will originate from.



37
38
39
# File 'lib/stripe/params/v2/money_management/inbound_transfer_create_params.rb', line 37

def from
  @from
end

#toObject

Object containing details about where the funds will land.



39
40
41
# File 'lib/stripe/params/v2/money_management/inbound_transfer_create_params.rb', line 39

def to
  @to
end