Class: Stripe::V2::MoneyManagement::OutboundPayment::DeliveryOptions::PaperCheck
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::MoneyManagement::OutboundPayment::DeliveryOptions::PaperCheck
- Defined in:
- lib/stripe/resources/v2/money_management/outbound_payment.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#memo ⇒ Object
readonly
Memo printed on the memo field of the check.
-
#shipping_speed ⇒ Object
readonly
Open Enum.
-
#signature ⇒ Object
readonly
Signature for the paper check.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#memo ⇒ Object (readonly)
Memo printed on the memo field of the check.
17 18 19 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 17 def memo @memo end |
#shipping_speed ⇒ Object (readonly)
Open Enum. Shipping speed of the paper check.
19 20 21 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 19 def shipping_speed @shipping_speed end |
#signature ⇒ Object (readonly)
Signature for the paper check.
21 22 23 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 21 def signature @signature end |
Class Method Details
.field_remappings ⇒ Object
27 28 29 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 27 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
23 24 25 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 23 def self.inner_class_types @inner_class_types = {} end |