Class: Stripe::V2::MoneyManagement::OutboundPaymentCreateParams::Amount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::MoneyManagement::OutboundPaymentCreateParams::Amount
- Defined in:
- lib/stripe/params/v2/money_management/outbound_payment_create_params.rb
Instance Attribute Summary collapse
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#value ⇒ Object
A non-negative integer representing how much to charge in the [smallest currency unit](docs.stripe.com/currencies#minor-units).
Instance Method Summary collapse
-
#initialize(value: nil, currency: nil) ⇒ Amount
constructor
A new instance of Amount.
Methods inherited from RequestParams
Constructor Details
#initialize(value: nil, currency: nil) ⇒ Amount
Returns a new instance of Amount.
14 15 16 17 |
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 14 def initialize(value: nil, currency: nil) @value = value @currency = currency end |
Instance Attribute Details
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
12 13 14 |
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 12 def currency @currency end |
#value ⇒ Object
A non-negative integer representing how much to charge in the [smallest currency unit](docs.stripe.com/currencies#minor-units).
10 11 12 |
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 10 def value @value end |