Class: Stripe::V2::MoneyManagement::OutboundPaymentCreateParams::DeliveryOptions::PaperCheck

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/money_management/outbound_payment_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(attachment: nil, memo: nil, shipping_speed: nil, signature: nil) ⇒ PaperCheck

Returns a new instance of PaperCheck.



19
20
21
22
23
24
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 19

def initialize(attachment: nil, memo: nil, shipping_speed: nil, signature: nil)
  @attachment = attachment
  @memo = memo
  @shipping_speed = shipping_speed
  @signature = signature
end

Instance Attribute Details

#attachmentObject

The ID of a file to include as an attachment with the paper check.



11
12
13
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 11

def attachment
  @attachment
end

#memoObject

Memo printed on the memo field of the check.



13
14
15
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 13

def memo
  @memo
end

#shipping_speedObject

Open Enum. Shipping speed of the paper check. Defaults to standard.



15
16
17
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 15

def shipping_speed
  @shipping_speed
end

#signatureObject

Signature for the paper check.



17
18
19
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 17

def signature
  @signature
end