Class: Stripe::V2::MoneyManagement::OutboundPaymentQuote

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/money_management/outbound_payment_quote.rb

Overview

OutboundPaymentQuote represents a quote that provides fee and amount estimates for OutboundPayment.

Defined Under Namespace

Classes: DeliveryOptions, EstimatedFee, From, FxQuote, To

Constant Summary collapse

OBJECT_NAME =
"v2.money_management.outbound_payment_quote"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

The "presentment amount" for the OutboundPaymentQuote.



179
180
181
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 179

def amount
  @amount
end

#createdObject (readonly)

Time at which the OutboundPaymentQuote was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



182
183
184
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 182

def created
  @created
end

#delivery_optionsObject (readonly)

Delivery options to be used to send the OutboundPayment.



184
185
186
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 184

def delivery_options
  @delivery_options
end

#estimated_feesObject (readonly)

The estimated fees for the OutboundPaymentQuote.



186
187
188
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 186

def estimated_fees
  @estimated_fees
end

#fromObject (readonly)

Details about the sender of an OutboundPaymentQuote.



188
189
190
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 188

def from
  @from
end

#fx_quoteObject (readonly)

The underlying FXQuote details for the OutboundPaymentQuote.



190
191
192
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 190

def fx_quote
  @fx_quote
end

#idObject (readonly)

Unique identifier for the OutboundPaymentQuote.



192
193
194
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 192

def id
  @id
end

#livemodeObject (readonly)

Has the value true if the object exists in live mode or the value false if the object exists in test mode.



194
195
196
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 194

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object's type. Objects of the same type share the same value of the object field.



196
197
198
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 196

def object
  @object
end

#toObject (readonly)

Details about the recipient of an OutboundPaymentQuote.



198
199
200
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 198

def to
  @to
end

Class Method Details

.field_remappingsObject



210
211
212
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 210

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



200
201
202
203
204
205
206
207
208
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 200

def self.inner_class_types
  @inner_class_types = {
    delivery_options: DeliveryOptions,
    estimated_fees: EstimatedFee,
    from: From,
    fx_quote: FxQuote,
    to: To,
  }
end

.object_nameObject



10
11
12
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 10

def self.object_name
  "v2.money_management.outbound_payment_quote"
end