Class: Stripe::V2::MoneyManagement::OutboundPaymentQuote::From
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::MoneyManagement::OutboundPaymentQuote::From
- Defined in:
- lib/stripe/resources/v2/money_management/outbound_payment_quote.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#debited ⇒ Object
readonly
The monetary amount debited from the sender, only set on responses.
-
#financial_account ⇒ Object
readonly
The FinancialAccount that funds were pulled from.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#debited ⇒ Object (readonly)
The monetary amount debited from the sender, only set on responses.
28 29 30 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 28 def debited @debited end |
#financial_account ⇒ Object (readonly)
The FinancialAccount that funds were pulled from.
30 31 32 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 30 def financial_account @financial_account end |