Class: Stripe::V2::MoneyManagement::OutboundPaymentQuote::FxQuote
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::MoneyManagement::OutboundPaymentQuote::FxQuote
- Defined in:
- lib/stripe/resources/v2/money_management/outbound_payment_quote.rb
Defined Under Namespace
Classes: Rates
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#lock_duration ⇒ Object
readonly
The duration the exchange rate lock remains valid from creation time.
-
#lock_expires_at ⇒ Object
readonly
Time at which the rate lock will expire, measured in seconds since the Unix epoch.
-
#lock_status ⇒ Object
readonly
Lock status of the quote.
-
#rates ⇒ Object
readonly
Key pair: from currency Value: exchange rate going from_currency -> to_currency.
-
#to_currency ⇒ Object
readonly
The currency that the transaction is exchanging to.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#lock_duration ⇒ Object (readonly)
The duration the exchange rate lock remains valid from creation time. Allowed value is five_minutes or none.
71 72 73 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 71 def lock_duration @lock_duration end |
#lock_expires_at ⇒ Object (readonly)
Time at which the rate lock will expire, measured in seconds since the Unix epoch. Null when rate locking is not supported.
73 74 75 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 73 def lock_expires_at @lock_expires_at end |
#lock_status ⇒ Object (readonly)
Lock status of the quote. Transitions from active to expired once past the lock_expires_at timestamp. Value can be active, expired or none.
75 76 77 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 75 def lock_status @lock_status end |
#rates ⇒ Object (readonly)
Key pair: from currency Value: exchange rate going from_currency -> to_currency.
77 78 79 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 77 def rates @rates end |
#to_currency ⇒ Object (readonly)
The currency that the transaction is exchanging to.
79 80 81 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 79 def to_currency @to_currency end |
Class Method Details
.field_remappings ⇒ Object
85 86 87 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 85 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
81 82 83 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 81 def self.inner_class_types @inner_class_types = { rates: Rates } end |