Class: Stripe::V2::MoneyManagement::OutboundPaymentQuoteService::CreateParams::To

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/money_management/outbound_payment_quote_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(currency: nil, payout_method: nil, recipient: nil) ⇒ To

Returns a new instance of To.



44
45
46
47
48
# File 'lib/stripe/services/v2/money_management/outbound_payment_quote_service.rb', line 44

def initialize(currency: nil, payout_method: nil, recipient: nil)
  @currency = currency
  @payout_method = payout_method
  @recipient = recipient
end

Instance Attribute Details

#currencyObject

Describes the currency to send to the recipient. If included, this currency must match a currency supported by the destination. Can be omitted in the following cases:

  • destination only supports one currency

  • destination supports multiple currencies and one of the currencies matches the FA currency

  • destination supports multiple currencies and one of the currencies matches the presentment currency

Note - when both FA currency and presentment currency are supported, we pick the FA currency to minimize FX.



38
39
40
# File 'lib/stripe/services/v2/money_management/outbound_payment_quote_service.rb', line 38

def currency
  @currency
end

#payout_methodObject

The payout method which the OutboundPayment uses to send payout.



40
41
42
# File 'lib/stripe/services/v2/money_management/outbound_payment_quote_service.rb', line 40

def payout_method
  @payout_method
end

#recipientObject

To which account the OutboundPayment is sent.



42
43
44
# File 'lib/stripe/services/v2/money_management/outbound_payment_quote_service.rb', line 42

def recipient
  @recipient
end