Class: Stripe::V2::MoneyManagement::OutboundSetupIntentCreateParams::PayoutMethodData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::MoneyManagement::OutboundSetupIntentCreateParams::PayoutMethodData
- Defined in:
- lib/stripe/params/v2/money_management/outbound_setup_intent_create_params.rb
Defined Under Namespace
Classes: BankAccount, Card, CryptoWallet
Instance Attribute Summary collapse
-
#bank_account ⇒ Object
The type specific details of the bank account payout method.
-
#card ⇒ Object
The type specific details of the card payout method.
-
#crypto_wallet ⇒ Object
The type specific details of the crypto wallet payout method.
-
#type ⇒ Object
Closed Enum.
Instance Method Summary collapse
-
#initialize(bank_account: nil, card: nil, crypto_wallet: nil, type: nil) ⇒ PayoutMethodData
constructor
A new instance of PayoutMethodData.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(bank_account: nil, card: nil, crypto_wallet: nil, type: nil) ⇒ PayoutMethodData
Returns a new instance of PayoutMethodData.
85 86 87 88 89 90 |
# File 'lib/stripe/params/v2/money_management/outbound_setup_intent_create_params.rb', line 85 def initialize(bank_account: nil, card: nil, crypto_wallet: nil, type: nil) @bank_account = bank_account @card = card @crypto_wallet = crypto_wallet @type = type end |
Instance Attribute Details
#bank_account ⇒ Object
The type specific details of the bank account payout method.
77 78 79 |
# File 'lib/stripe/params/v2/money_management/outbound_setup_intent_create_params.rb', line 77 def bank_account @bank_account end |
#card ⇒ Object
The type specific details of the card payout method.
79 80 81 |
# File 'lib/stripe/params/v2/money_management/outbound_setup_intent_create_params.rb', line 79 def card @card end |
#crypto_wallet ⇒ Object
The type specific details of the crypto wallet payout method.
81 82 83 |
# File 'lib/stripe/params/v2/money_management/outbound_setup_intent_create_params.rb', line 81 def crypto_wallet @crypto_wallet end |
#type ⇒ Object
Closed Enum. The type of payout method to be created.
83 84 85 |
# File 'lib/stripe/params/v2/money_management/outbound_setup_intent_create_params.rb', line 83 def type @type end |