Class: Stripe::V2::MoneyManagement::OutboundSetupIntentCreateParams::PayoutMethodData::BankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/money_management/outbound_setup_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(account_number: nil, bank_account_type: nil, branch_number: nil, country: nil, currency: nil, routing_number: nil, swift_code: nil) ⇒ BankAccount

Returns a new instance of BankAccount.



25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
# File 'lib/stripe/params/v2/money_management/outbound_setup_intent_create_params.rb', line 25

def initialize(
  account_number: nil,
  bank_account_type: nil,
  branch_number: nil,
  country: nil,
  currency: nil,
  routing_number: nil,
  swift_code: nil
)
  @account_number = 
  @bank_account_type = 
  @branch_number = branch_number
  @country = country
  @currency = currency
  @routing_number = routing_number
  @swift_code = swift_code
end

Instance Attribute Details

#account_numberObject

The account number or IBAN of the bank account.



11
12
13
# File 'lib/stripe/params/v2/money_management/outbound_setup_intent_create_params.rb', line 11

def 
  @account_number
end

#bank_account_typeObject

Closed Enum. The type of the bank account (checking or savings).



13
14
15
# File 'lib/stripe/params/v2/money_management/outbound_setup_intent_create_params.rb', line 13

def 
  @bank_account_type
end

#branch_numberObject

The branch number of the bank account, if present.



15
16
17
# File 'lib/stripe/params/v2/money_management/outbound_setup_intent_create_params.rb', line 15

def branch_number
  @branch_number
end

#countryObject

The country code of the bank account.



17
18
19
# File 'lib/stripe/params/v2/money_management/outbound_setup_intent_create_params.rb', line 17

def country
  @country
end

#currencyObject

The currency of the bank account.



19
20
21
# File 'lib/stripe/params/v2/money_management/outbound_setup_intent_create_params.rb', line 19

def currency
  @currency
end

#routing_numberObject

The routing number of the bank account, if present.



21
22
23
# File 'lib/stripe/params/v2/money_management/outbound_setup_intent_create_params.rb', line 21

def routing_number
  @routing_number
end

#swift_codeObject

The swift code of the bank account, if present.



23
24
25
# File 'lib/stripe/params/v2/money_management/outbound_setup_intent_create_params.rb', line 23

def swift_code
  @swift_code
end