Class: Stripe::V2::MoneyManagement::OutboundSetupIntentCreateParams::PayoutMethodData::CryptoWallet
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::MoneyManagement::OutboundSetupIntentCreateParams::PayoutMethodData::CryptoWallet
- Defined in:
- lib/stripe/params/v2/money_management/outbound_setup_intent_create_params.rb
Instance Attribute Summary collapse
-
#address ⇒ Object
Crypto wallet address.
-
#memo ⇒ Object
Optional field, required if network supports memos (only “stellar” currently).
-
#network ⇒ Object
Which rail we should use to make an Outbound money movement to this wallet.
Instance Method Summary collapse
-
#initialize(address: nil, memo: nil, network: nil) ⇒ CryptoWallet
constructor
A new instance of CryptoWallet.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(address: nil, memo: nil, network: nil) ⇒ CryptoWallet
Returns a new instance of CryptoWallet.
70 71 72 73 74 |
# File 'lib/stripe/params/v2/money_management/outbound_setup_intent_create_params.rb', line 70 def initialize(address: nil, memo: nil, network: nil) @address = address @memo = memo @network = network end |
Instance Attribute Details
#address ⇒ Object
Crypto wallet address.
64 65 66 |
# File 'lib/stripe/params/v2/money_management/outbound_setup_intent_create_params.rb', line 64 def address @address end |
#memo ⇒ Object
Optional field, required if network supports memos (only “stellar” currently).
66 67 68 |
# File 'lib/stripe/params/v2/money_management/outbound_setup_intent_create_params.rb', line 66 def memo @memo end |
#network ⇒ Object
Which rail we should use to make an Outbound money movement to this wallet.
68 69 70 |
# File 'lib/stripe/params/v2/money_management/outbound_setup_intent_create_params.rb', line 68 def network @network end |