Class: Stripe::V2::MoneyManagement::OutboundSetupIntentService::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/money_management/outbound_setup_intent_service.rb

Defined Under Namespace

Classes: PayoutMethodData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(payout_method: nil, payout_method_data: nil, usage_intent: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



81
82
83
84
85
# File 'lib/stripe/services/v2/money_management/outbound_setup_intent_service.rb', line 81

def initialize(payout_method: nil, payout_method_data: nil, usage_intent: nil)
  @payout_method = payout_method
  @payout_method_data = payout_method_data
  @usage_intent = usage_intent
end

Instance Attribute Details

#payout_methodObject

If provided, the existing payout method resource to link to this setup intent. Any payout_method_data provided is used to update information on this linked payout method resource.



73
74
75
# File 'lib/stripe/services/v2/money_management/outbound_setup_intent_service.rb', line 73

def payout_method
  @payout_method
end

#payout_method_dataObject

If no payout_method provided, used to create the underlying credential that is set up for outbound money movement. If a payout_method provided, used to update data on the credential linked to this setup intent.



76
77
78
# File 'lib/stripe/services/v2/money_management/outbound_setup_intent_service.rb', line 76

def payout_method_data
  @payout_method_data
end

#usage_intentObject

Specify which type of outbound money movement this credential should be set up for (payment | transfer). If not provided, defaults to payment.



79
80
81
# File 'lib/stripe/services/v2/money_management/outbound_setup_intent_service.rb', line 79

def usage_intent
  @usage_intent
end