Class: Stripe::V2::MoneyManagement::OutboundSetupIntentService::CreateParams::PayoutMethodData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/money_management/outbound_setup_intent_service.rb

Defined Under Namespace

Classes: BankAccount, Card

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(type: nil, bank_account: nil, card: nil) ⇒ PayoutMethodData

Returns a new instance of PayoutMethodData.



65
66
67
68
69
# File 'lib/stripe/services/v2/money_management/outbound_setup_intent_service.rb', line 65

def initialize(type: nil, bank_account: nil, card: nil)
  @type = type
  @bank_account = 
  @card = card
end

Instance Attribute Details

#bank_accountObject

The type specific details of the bank account payout method.



61
62
63
# File 'lib/stripe/services/v2/money_management/outbound_setup_intent_service.rb', line 61

def 
  @bank_account
end

#cardObject

The type specific details of the card payout method.



63
64
65
# File 'lib/stripe/services/v2/money_management/outbound_setup_intent_service.rb', line 63

def card
  @card
end

#typeObject

Closed Enum. The type of payout method to be created.



59
60
61
# File 'lib/stripe/services/v2/money_management/outbound_setup_intent_service.rb', line 59

def type
  @type
end