Class: Stripe::V2::MoneyManagement::OutboundSetupIntentService::CreateParams::PayoutMethodData::BankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/money_management/outbound_setup_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_number: nil, bank_account_type: nil, branch_number: nil, country: nil, routing_number: nil, swift_code: nil) ⇒ BankAccount

Returns a new instance of BankAccount.



33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
# File 'lib/stripe/services/v2/money_management/outbound_setup_intent_service.rb', line 33

def initialize(
  account_number: nil,
  bank_account_type: nil,
  branch_number: nil,
  country: nil,
  routing_number: nil,
  swift_code: nil
)
  @account_number = 
  @bank_account_type = 
  @branch_number = branch_number
  @country = country
  @routing_number = routing_number
  @swift_code = swift_code
end

Instance Attribute Details

#account_numberObject

The account number or IBAN of the bank account.



21
22
23
# File 'lib/stripe/services/v2/money_management/outbound_setup_intent_service.rb', line 21

def 
  @account_number
end

#bank_account_typeObject

Closed Enum. The type of the bank account (checking or savings).



23
24
25
# File 'lib/stripe/services/v2/money_management/outbound_setup_intent_service.rb', line 23

def 
  @bank_account_type
end

#branch_numberObject

The branch number of the bank account, if present.



25
26
27
# File 'lib/stripe/services/v2/money_management/outbound_setup_intent_service.rb', line 25

def branch_number
  @branch_number
end

#countryObject

The country code of the bank account.



27
28
29
# File 'lib/stripe/services/v2/money_management/outbound_setup_intent_service.rb', line 27

def country
  @country
end

#routing_numberObject

The routing number of the bank account, if present.



29
30
31
# File 'lib/stripe/services/v2/money_management/outbound_setup_intent_service.rb', line 29

def routing_number
  @routing_number
end

#swift_codeObject

The swift code of the bank account, if present.



31
32
33
# File 'lib/stripe/services/v2/money_management/outbound_setup_intent_service.rb', line 31

def swift_code
  @swift_code
end