Class: Stripe::V2::MoneyManagement::OutboundSetupIntentService::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::MoneyManagement::OutboundSetupIntentService::UpdateParams
- Defined in:
- lib/stripe/services/v2/money_management/outbound_setup_intent_service.rb
Defined Under Namespace
Classes: PayoutMethodData
Instance Attribute Summary collapse
-
#payout_method ⇒ Object
If provided, the existing payout method resource to link to this outbound setup intent.
-
#payout_method_data ⇒ Object
If no payout_method provided, used to create the underlying credential that is set up for outbound money movement.
Instance Method Summary collapse
-
#initialize(payout_method: nil, payout_method_data: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(payout_method: nil, payout_method_data: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
162 163 164 165 |
# File 'lib/stripe/services/v2/money_management/outbound_setup_intent_service.rb', line 162 def initialize(payout_method: nil, payout_method_data: nil) @payout_method = payout_method @payout_method_data = payout_method_data end |
Instance Attribute Details
#payout_method ⇒ Object
If provided, the existing payout method resource to link to this outbound setup intent.
157 158 159 |
# File 'lib/stripe/services/v2/money_management/outbound_setup_intent_service.rb', line 157 def payout_method @payout_method end |
#payout_method_data ⇒ Object
If no payout_method provided, used to create the underlying credential that is set up for outbound money movement. If a payout_method provided, used to update data on the credential linked to this setup intent.
160 161 162 |
# File 'lib/stripe/services/v2/money_management/outbound_setup_intent_service.rb', line 160 def payout_method_data @payout_method_data end |