Class: Stripe::V2::MoneyManagement::OutboundSetupIntentService::UpdateParams::PayoutMethodData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::MoneyManagement::OutboundSetupIntentService::UpdateParams::PayoutMethodData
- Defined in:
- lib/stripe/services/v2/money_management/outbound_setup_intent_service.rb
Defined Under Namespace
Classes: BankAccount, Card
Instance Attribute Summary collapse
-
#bank_account ⇒ Object
The type specific details of the bank account payout method.
-
#card ⇒ Object
The type specific details of the card payout method.
-
#type ⇒ Object
Closed Enum.
Instance Method Summary collapse
-
#initialize(type: nil, bank_account: nil, card: nil) ⇒ PayoutMethodData
constructor
A new instance of PayoutMethodData.
Methods inherited from RequestParams
Constructor Details
#initialize(type: nil, bank_account: nil, card: nil) ⇒ PayoutMethodData
Returns a new instance of PayoutMethodData.
152 153 154 155 156 |
# File 'lib/stripe/services/v2/money_management/outbound_setup_intent_service.rb', line 152 def initialize(type: nil, bank_account: nil, card: nil) @type = type @bank_account = bank_account @card = card end |
Instance Attribute Details
#bank_account ⇒ Object
The type specific details of the bank account payout method.
148 149 150 |
# File 'lib/stripe/services/v2/money_management/outbound_setup_intent_service.rb', line 148 def bank_account @bank_account end |
#card ⇒ Object
The type specific details of the card payout method.
150 151 152 |
# File 'lib/stripe/services/v2/money_management/outbound_setup_intent_service.rb', line 150 def card @card end |
#type ⇒ Object
Closed Enum. The type of payout method to be created/updated.
146 147 148 |
# File 'lib/stripe/services/v2/money_management/outbound_setup_intent_service.rb', line 146 def type @type end |