Class: Stripe::V2::MoneyManagement::OutboundSetupIntentService::UpdateParams::PayoutMethodData::Card

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/money_management/outbound_setup_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(exp_month: nil, exp_year: nil, number: nil) ⇒ Card

Returns a new instance of Card.



137
138
139
140
141
# File 'lib/stripe/services/v2/money_management/outbound_setup_intent_service.rb', line 137

def initialize(exp_month: nil, exp_year: nil, number: nil)
  @exp_month = exp_month
  @exp_year = exp_year
  @number = number
end

Instance Attribute Details

#exp_monthObject

The expiration month of the card.



131
132
133
# File 'lib/stripe/services/v2/money_management/outbound_setup_intent_service.rb', line 131

def exp_month
  @exp_month
end

#exp_yearObject

The expiration year of the card.



133
134
135
# File 'lib/stripe/services/v2/money_management/outbound_setup_intent_service.rb', line 133

def exp_year
  @exp_year
end

#numberObject

The card number. This can only be passed when creating a new credential on an outbound setup intent in the requires_payout_method state.



135
136
137
# File 'lib/stripe/services/v2/money_management/outbound_setup_intent_service.rb', line 135

def number
  @number
end