Class: Stripe::V2::MoneyManagement::OutboundSetupIntentUpdateParams::PayoutMethodData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/money_management/outbound_setup_intent_update_params.rb

Defined Under Namespace

Classes: BankAccount, Card

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(bank_account: nil, card: nil, type: nil) ⇒ PayoutMethodData

Returns a new instance of PayoutMethodData.



68
69
70
71
72
# File 'lib/stripe/params/v2/money_management/outbound_setup_intent_update_params.rb', line 68

def initialize(bank_account: nil, card: nil, type: nil)
  @bank_account = 
  @card = card
  @type = type
end

Instance Attribute Details

#bank_accountObject

The type specific details of the bank account payout method.



62
63
64
# File 'lib/stripe/params/v2/money_management/outbound_setup_intent_update_params.rb', line 62

def 
  @bank_account
end

#cardObject

The type specific details of the card payout method.



64
65
66
# File 'lib/stripe/params/v2/money_management/outbound_setup_intent_update_params.rb', line 64

def card
  @card
end

#typeObject

Closed Enum. The type of payout method to be created/updated.



66
67
68
# File 'lib/stripe/params/v2/money_management/outbound_setup_intent_update_params.rb', line 66

def type
  @type
end