Class: Stripe::V2::MoneyManagement::OutboundSetupIntentUpdateParams::PayoutMethodData::Card
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::MoneyManagement::OutboundSetupIntentUpdateParams::PayoutMethodData::Card
- Defined in:
- lib/stripe/params/v2/money_management/outbound_setup_intent_update_params.rb
Instance Attribute Summary collapse
-
#currency ⇒ Object
The currency of the card.
-
#exp_month ⇒ Object
The expiration month of the card.
-
#exp_year ⇒ Object
The expiration year of the card.
-
#number ⇒ Object
The card number.
Instance Method Summary collapse
-
#initialize(currency: nil, exp_month: nil, exp_year: nil, number: nil) ⇒ Card
constructor
A new instance of Card.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(currency: nil, exp_month: nil, exp_year: nil, number: nil) ⇒ Card
Returns a new instance of Card.
54 55 56 57 58 59 |
# File 'lib/stripe/params/v2/money_management/outbound_setup_intent_update_params.rb', line 54 def initialize(currency: nil, exp_month: nil, exp_year: nil, number: nil) @currency = currency @exp_month = exp_month @exp_year = exp_year @number = number end |
Instance Attribute Details
#currency ⇒ Object
The currency of the card.
46 47 48 |
# File 'lib/stripe/params/v2/money_management/outbound_setup_intent_update_params.rb', line 46 def currency @currency end |
#exp_month ⇒ Object
The expiration month of the card.
48 49 50 |
# File 'lib/stripe/params/v2/money_management/outbound_setup_intent_update_params.rb', line 48 def exp_month @exp_month end |
#exp_year ⇒ Object
The expiration year of the card.
50 51 52 |
# File 'lib/stripe/params/v2/money_management/outbound_setup_intent_update_params.rb', line 50 def exp_year @exp_year end |
#number ⇒ Object
The card number. This can only be passed when creating a new credential on an outbound setup intent in the requires_payout_method state.
52 53 54 |
# File 'lib/stripe/params/v2/money_management/outbound_setup_intent_update_params.rb', line 52 def number @number end |