Class: Stripe::V2::MoneyManagement::OutboundTransferCreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/money_management/outbound_transfer_create_params.rb

Defined Under Namespace

Classes: DeliveryOptions, From, To

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, delivery_options: nil, description: nil, from: nil, metadata: nil, recipient_verification: nil, statement_descriptor: nil, to: nil) ⇒ OutboundTransferCreateParams

Returns a new instance of OutboundTransferCreateParams.



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/stripe/params/v2/money_management/outbound_transfer_create_params.rb', line 82

def initialize(
  amount: nil,
  delivery_options: nil,
  description: nil,
  from: nil,
  metadata: nil,
  recipient_verification: nil,
  statement_descriptor: nil,
  to: nil
)
  @amount = amount
  @delivery_options = delivery_options
  @description = description
  @from = from
  @metadata = 
  @recipient_verification = recipient_verification
  @statement_descriptor = statement_descriptor
  @to = to
end

Instance Attribute Details

#amountObject

The "presentment amount" for the OutboundPayment.



66
67
68
# File 'lib/stripe/params/v2/money_management/outbound_transfer_create_params.rb', line 66

def amount
  @amount
end

#delivery_optionsObject

Delivery options to be used to send the OutboundTransfer.



68
69
70
# File 'lib/stripe/params/v2/money_management/outbound_transfer_create_params.rb', line 68

def delivery_options
  @delivery_options
end

#descriptionObject

An arbitrary string attached to the OutboundTransfer. Often useful for displaying to users.



70
71
72
# File 'lib/stripe/params/v2/money_management/outbound_transfer_create_params.rb', line 70

def description
  @description
end

#fromObject

The FinancialAccount to pull funds from.



72
73
74
# File 'lib/stripe/params/v2/money_management/outbound_transfer_create_params.rb', line 72

def from
  @from
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



74
75
76
# File 'lib/stripe/params/v2/money_management/outbound_transfer_create_params.rb', line 74

def 
  @metadata
end

#recipient_verificationObject

The recipient verification id for this OutboundTransfer. Only required for countries with regulatory mandates to verify recipient names before OutboundTransfer creation.



76
77
78
# File 'lib/stripe/params/v2/money_management/outbound_transfer_create_params.rb', line 76

def recipient_verification
  @recipient_verification
end

#statement_descriptorObject

The description that appears on the receiving end for an OutboundTransfer (for example, on a bank statement). Must be between 3 and 22 characters long for most destinations (500 for FinancialAccount destinations), and not contain profanity.



78
79
80
# File 'lib/stripe/params/v2/money_management/outbound_transfer_create_params.rb', line 78

def statement_descriptor
  @statement_descriptor
end

#toObject

To which payout method to send the OutboundTransfer.



80
81
82
# File 'lib/stripe/params/v2/money_management/outbound_transfer_create_params.rb', line 80

def to
  @to
end