Class: Stripe::V2::MoneyManagement::OutboundTransferCreateParams::To
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::MoneyManagement::OutboundTransferCreateParams::To
- Defined in:
- lib/stripe/params/v2/money_management/outbound_transfer_create_params.rb
Defined Under Namespace
Classes: PayoutMethodOptions
Instance Attribute Summary collapse
-
#currency ⇒ Object
Describes the currency to send to the recipient.
-
#payout_method ⇒ Object
The payout method which the OutboundTransfer uses to send payout.
-
#payout_method_options ⇒ Object
Payout method options for the OutboundTransfer.
Instance Method Summary collapse
-
#initialize(currency: nil, payout_method: nil, payout_method_options: nil) ⇒ To
constructor
A new instance of To.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(currency: nil, payout_method: nil, payout_method_options: nil) ⇒ To
Returns a new instance of To.
59 60 61 62 63 |
# File 'lib/stripe/params/v2/money_management/outbound_transfer_create_params.rb', line 59 def initialize(currency: nil, payout_method: nil, payout_method_options: nil) @currency = currency @payout_method = payout_method @payout_method_options = end |
Instance Attribute Details
#currency ⇒ Object
Describes the currency to send to the recipient. If included, this currency must match a currency supported by the destination. Can be omitted in the following cases:
- destination only supports one currency
- destination supports multiple currencies and one of the currencies matches the FA currency
- destination supports multiple currencies and one of the currencies matches the presentment currency Note - when both FA currency and presentment currency are supported, we pick the FA currency to minimize FX.
53 54 55 |
# File 'lib/stripe/params/v2/money_management/outbound_transfer_create_params.rb', line 53 def currency @currency end |
#payout_method ⇒ Object
The payout method which the OutboundTransfer uses to send payout.
55 56 57 |
# File 'lib/stripe/params/v2/money_management/outbound_transfer_create_params.rb', line 55 def payout_method @payout_method end |
#payout_method_options ⇒ Object
Payout method options for the OutboundTransfer.
57 58 59 |
# File 'lib/stripe/params/v2/money_management/outbound_transfer_create_params.rb', line 57 def @payout_method_options end |