Class: Stripe::V2::MoneyManagement::OutboundTransferListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::MoneyManagement::OutboundTransferListParams
- Defined in:
- lib/stripe/params/v2/money_management/outbound_transfer_list_params.rb
Instance Attribute Summary collapse
-
#created ⇒ Object
Filter for objects created at the specified timestamp.
-
#created_gt ⇒ Object
Filter for objects created after the specified timestamp.
-
#created_gte ⇒ Object
Filter for objects created on or after the specified timestamp.
-
#created_lt ⇒ Object
Filter for objects created before the specified timestamp.
-
#created_lte ⇒ Object
Filter for objects created on or before the specified timestamp.
-
#limit ⇒ Object
The maximum number of results to return.
-
#status ⇒ Object
Closed Enum.
Instance Method Summary collapse
-
#initialize(created: nil, created_gt: nil, created_gte: nil, created_lt: nil, created_lte: nil, limit: nil, status: nil) ⇒ OutboundTransferListParams
constructor
A new instance of OutboundTransferListParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(created: nil, created_gt: nil, created_gte: nil, created_lt: nil, created_lte: nil, limit: nil, status: nil) ⇒ OutboundTransferListParams
Returns a new instance of OutboundTransferListParams.
28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 |
# File 'lib/stripe/params/v2/money_management/outbound_transfer_list_params.rb', line 28 def initialize( created: nil, created_gt: nil, created_gte: nil, created_lt: nil, created_lte: nil, limit: nil, status: nil ) @created = created @created_gt = created_gt @created_gte = created_gte @created_lt = created_lt @created_lte = created_lte @limit = limit @status = status end |
Instance Attribute Details
#created ⇒ Object
Filter for objects created at the specified timestamp. Must be an RFC 3339 date & time value, for example: 2022-09-18T13:22:00Z.
10 11 12 |
# File 'lib/stripe/params/v2/money_management/outbound_transfer_list_params.rb', line 10 def created @created end |
#created_gt ⇒ Object
Filter for objects created after the specified timestamp. Must be an RFC 3339 date & time value, for example: 2022-09-18T13:22:00Z.
13 14 15 |
# File 'lib/stripe/params/v2/money_management/outbound_transfer_list_params.rb', line 13 def created_gt @created_gt end |
#created_gte ⇒ Object
Filter for objects created on or after the specified timestamp. Must be an RFC 3339 date & time value, for example: 2022-09-18T13:22:00Z.
16 17 18 |
# File 'lib/stripe/params/v2/money_management/outbound_transfer_list_params.rb', line 16 def created_gte @created_gte end |
#created_lt ⇒ Object
Filter for objects created before the specified timestamp. Must be an RFC 3339 date & time value, for example: 2022-09-18T13:22:00Z.
19 20 21 |
# File 'lib/stripe/params/v2/money_management/outbound_transfer_list_params.rb', line 19 def created_lt @created_lt end |
#created_lte ⇒ Object
Filter for objects created on or before the specified timestamp. Must be an RFC 3339 date & time value, for example: 2022-09-18T13:22:00Z.
22 23 24 |
# File 'lib/stripe/params/v2/money_management/outbound_transfer_list_params.rb', line 22 def created_lte @created_lte end |
#limit ⇒ Object
The maximum number of results to return.
24 25 26 |
# File 'lib/stripe/params/v2/money_management/outbound_transfer_list_params.rb', line 24 def limit @limit end |
#status ⇒ Object
Closed Enum. Only return OutboundTransfers with this status.
26 27 28 |
# File 'lib/stripe/params/v2/money_management/outbound_transfer_list_params.rb', line 26 def status @status end |