Class: Stripe::V2::MoneyManagement::OutboundTransferService::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/money_management/outbound_transfer_service.rb

Defined Under Namespace

Classes: DeliveryOptions, From, To

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, delivery_options: nil, description: nil, from: nil, metadata: nil, to: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/stripe/services/v2/money_management/outbound_transfer_service.rb', line 100

def initialize(
  amount: nil,
  delivery_options: nil,
  description: nil,
  from: nil,
  metadata: nil,
  to: nil
)
  @amount = amount
  @delivery_options = delivery_options
  @description = description
  @from = from
  @metadata = 
  @to = to
end

Instance Attribute Details

#amountObject

The “presentment amount” for the OutboundPayment.



88
89
90
# File 'lib/stripe/services/v2/money_management/outbound_transfer_service.rb', line 88

def amount
  @amount
end

#delivery_optionsObject

Delivery options to be used to send the OutboundTransfer.



90
91
92
# File 'lib/stripe/services/v2/money_management/outbound_transfer_service.rb', line 90

def delivery_options
  @delivery_options
end

#descriptionObject

An arbitrary string attached to the OutboundTransfer. Often useful for displaying to users.



92
93
94
# File 'lib/stripe/services/v2/money_management/outbound_transfer_service.rb', line 92

def description
  @description
end

#fromObject

The FinancialAccount to pull funds from.



94
95
96
# File 'lib/stripe/services/v2/money_management/outbound_transfer_service.rb', line 94

def from
  @from
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



96
97
98
# File 'lib/stripe/services/v2/money_management/outbound_transfer_service.rb', line 96

def 
  @metadata
end

#toObject

To which payout method to send the OutboundTransfer.



98
99
100
# File 'lib/stripe/services/v2/money_management/outbound_transfer_service.rb', line 98

def to
  @to
end