Class: Stripe::V2::MoneyManagement::OutboundTransferService::CreateParams::To

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/money_management/outbound_transfer_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(currency: nil, payout_method: nil) ⇒ To

Returns a new instance of To.



44
45
46
47
# File 'lib/stripe/services/v2/money_management/outbound_transfer_service.rb', line 44

def initialize(currency: nil, payout_method: nil)
  @currency = currency
  @payout_method = payout_method
end

Instance Attribute Details

#currencyObject

Describes the currency to send to the recipient. If included, this currency must match a currency supported by the destination. Can be omitted in the following cases:

  • destination only supports one currency

  • destination supports multiple currencies and one of the currencies matches the FA currency

  • destination supports multiple currencies and one of the currencies matches the presentment currency

Note - when both FA currency and presentment currency are supported, we pick the FA currency to minimize FX.



40
41
42
# File 'lib/stripe/services/v2/money_management/outbound_transfer_service.rb', line 40

def currency
  @currency
end

#payout_methodObject

The payout method which the OutboundTransfer uses to send payout.



42
43
44
# File 'lib/stripe/services/v2/money_management/outbound_transfer_service.rb', line 42

def payout_method
  @payout_method
end