Class: Stripe::V2::MoneyManagement::PayoutIntent

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/money_management/payout_intent.rb

Overview

PayoutIntent represents an intent to send funds from a Financial Account to a payout method.

Defined Under Namespace

Classes: EstimatedFee, From, FxQuote, LatestPayout, NextAction, RecipientNotification, ScheduleOptions, StatusTransitions, To

Constant Summary collapse

OBJECT_NAME =
"v2.money_management.payout_intent"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

The monetary amount to be sent.



278
279
280
# File 'lib/stripe/resources/v2/money_management/payout_intent.rb', line 278

def amount
  @amount
end

#confirmation_methodObject (readonly)

Controls whether the intent requires explicit confirmation before transitioning to pending.



280
281
282
# File 'lib/stripe/resources/v2/money_management/payout_intent.rb', line 280

def confirmation_method
  @confirmation_method
end

#createdObject (readonly)

Time at which the PayoutIntent was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



283
284
285
# File 'lib/stripe/resources/v2/money_management/payout_intent.rb', line 283

def created
  @created
end

#descriptionObject (readonly)

An arbitrary string attached to the PayoutIntent. Often useful for displaying to users.



285
286
287
# File 'lib/stripe/resources/v2/money_management/payout_intent.rb', line 285

def description
  @description
end

#estimated_feesObject (readonly)

Estimated fees and taxes.



287
288
289
# File 'lib/stripe/resources/v2/money_management/payout_intent.rb', line 287

def estimated_fees
  @estimated_fees
end

#fromObject (readonly)

The FinancialAccount that funds are pulled from.



289
290
291
# File 'lib/stripe/resources/v2/money_management/payout_intent.rb', line 289

def from
  @from
end

#fx_quoteObject (readonly)

FX rate information for fee transparency.



291
292
293
# File 'lib/stripe/resources/v2/money_management/payout_intent.rb', line 291

def fx_quote
  @fx_quote
end

#idObject (readonly)

Unique identifier for the PayoutIntent.



293
294
295
# File 'lib/stripe/resources/v2/money_management/payout_intent.rb', line 293

def id
  @id
end

#latest_payoutObject (readonly)

Details about the latest payout associated with this PayoutIntent.



295
296
297
# File 'lib/stripe/resources/v2/money_management/payout_intent.rb', line 295

def latest_payout
  @latest_payout
end

#livemodeObject (readonly)

Has the value true if the object exists in live mode or the value false if the object exists in test mode.



297
298
299
# File 'lib/stripe/resources/v2/money_management/payout_intent.rb', line 297

def livemode
  @livemode
end

#metadataObject (readonly)

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



299
300
301
# File 'lib/stripe/resources/v2/money_management/payout_intent.rb', line 299

def 
  @metadata
end

#next_actionObject (readonly)

Next action required for a PayoutIntent in the requires_action state. Populated when status is requires_action.



301
302
303
# File 'lib/stripe/resources/v2/money_management/payout_intent.rb', line 301

def next_action
  @next_action
end

#objectObject (readonly)

String representing the object's type. Objects of the same type share the same value of the object field.



303
304
305
# File 'lib/stripe/resources/v2/money_management/payout_intent.rb', line 303

def object
  @object
end

#recipient_notificationObject (readonly)

Details about the OutboundPayment notification settings for recipient. Only applicable to OutboundPayment.



305
306
307
# File 'lib/stripe/resources/v2/money_management/payout_intent.rb', line 305

def recipient_notification
  @recipient_notification
end

#schedule_optionsObject (readonly)

Scheduling options for the payout. If this is nil, we assume immediate execution.



307
308
309
# File 'lib/stripe/resources/v2/money_management/payout_intent.rb', line 307

def schedule_options
  @schedule_options
end

#statement_descriptorObject (readonly)

The description that appears on the receiving end for the payout (for example, on a bank statement).



309
310
311
# File 'lib/stripe/resources/v2/money_management/payout_intent.rb', line 309

def statement_descriptor
  @statement_descriptor
end

#statusObject (readonly)

Open Enum. Current status of the PayoutIntent: pending, processing, posted, canceled, requires_action.



311
312
313
# File 'lib/stripe/resources/v2/money_management/payout_intent.rb', line 311

def status
  @status
end

#status_transitionsObject (readonly)

Hash containing timestamps of when transitioned to a particular status.



313
314
315
# File 'lib/stripe/resources/v2/money_management/payout_intent.rb', line 313

def status_transitions
  @status_transitions
end

#toObject (readonly)

To which payout method the payout is sent.



315
316
317
# File 'lib/stripe/resources/v2/money_management/payout_intent.rb', line 315

def to
  @to
end

Class Method Details

.field_remappingsObject



331
332
333
# File 'lib/stripe/resources/v2/money_management/payout_intent.rb', line 331

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



317
318
319
320
321
322
323
324
325
326
327
328
329
# File 'lib/stripe/resources/v2/money_management/payout_intent.rb', line 317

def self.inner_class_types
  @inner_class_types = {
    estimated_fees: EstimatedFee,
    from: From,
    fx_quote: FxQuote,
    latest_payout: LatestPayout,
    next_action: NextAction,
    recipient_notification: RecipientNotification,
    schedule_options: ScheduleOptions,
    status_transitions: StatusTransitions,
    to: To,
  }
end

.object_nameObject



10
11
12
# File 'lib/stripe/resources/v2/money_management/payout_intent.rb', line 10

def self.object_name
  "v2.money_management.payout_intent"
end