Class: Stripe::V2::MoneyManagement::PayoutIntent::To
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::MoneyManagement::PayoutIntent::To
- Defined in:
- lib/stripe/resources/v2/money_management/payout_intent.rb
Defined Under Namespace
Classes: PayoutMethodOptions
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#credited ⇒ Object
readonly
Estimated amount to be credited to the recipient in the destination currency.
-
#currency ⇒ Object
readonly
The currency to send to the recipient.
-
#payout_method ⇒ Object
readonly
The payout method ID.
-
#payout_method_options ⇒ Object
readonly
Payout method options for the PayoutIntent.
-
#recipient ⇒ Object
readonly
The recipient ID.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#credited ⇒ Object (readonly)
Estimated amount to be credited to the recipient in the destination currency.
259 260 261 |
# File 'lib/stripe/resources/v2/money_management/payout_intent.rb', line 259 def credited @credited end |
#currency ⇒ Object (readonly)
The currency to send to the recipient.
261 262 263 |
# File 'lib/stripe/resources/v2/money_management/payout_intent.rb', line 261 def currency @currency end |
#payout_method ⇒ Object (readonly)
The payout method ID. Optional for OutboundPayment if recipient has default payment method. Required for OutboundTransfer.
263 264 265 |
# File 'lib/stripe/resources/v2/money_management/payout_intent.rb', line 263 def payout_method @payout_method end |
#payout_method_options ⇒ Object (readonly)
Payout method options for the PayoutIntent.
265 266 267 |
# File 'lib/stripe/resources/v2/money_management/payout_intent.rb', line 265 def @payout_method_options end |
#recipient ⇒ Object (readonly)
The recipient ID. Only relevant for OutboundPayment.
267 268 269 |
# File 'lib/stripe/resources/v2/money_management/payout_intent.rb', line 267 def recipient @recipient end |
Class Method Details
.field_remappings ⇒ Object
273 274 275 |
# File 'lib/stripe/resources/v2/money_management/payout_intent.rb', line 273 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
269 270 271 |
# File 'lib/stripe/resources/v2/money_management/payout_intent.rb', line 269 def self.inner_class_types @inner_class_types = { payout_method_options: PayoutMethodOptions } end |