Class: Stripe::V2::MoneyManagement::PayoutIntentCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::MoneyManagement::PayoutIntentCreateParams
- Defined in:
- lib/stripe/params/v2/money_management/payout_intent_create_params.rb
Defined Under Namespace
Classes: From, RecipientNotification, ScheduleOptions, To
Instance Attribute Summary collapse
-
#amount ⇒ Object
The monetary amount to be sent.
-
#confirmation_method ⇒ Object
Controls whether the intent requires explicit confirmation before transitioning to pending.
-
#description ⇒ Object
An arbitrary string attached to the PayoutIntent.
-
#from ⇒ Object
The FinancialAccount that funds are pulled from.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#recipient_notification ⇒ Object
Details about the OutboundPayment notification settings for recipient.
-
#schedule_options ⇒ Object
Scheduling options for the payout.
-
#statement_descriptor ⇒ Object
The description that appears on the receiving end for the payout (for example, on a bank statement).
-
#to ⇒ Object
To which payout method the payout is sent.
Instance Method Summary collapse
-
#initialize(amount: nil, confirmation_method: nil, description: nil, from: nil, metadata: nil, recipient_notification: nil, schedule_options: nil, statement_descriptor: nil, to: nil) ⇒ PayoutIntentCreateParams
constructor
A new instance of PayoutIntentCreateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, confirmation_method: nil, description: nil, from: nil, metadata: nil, recipient_notification: nil, schedule_options: nil, statement_descriptor: nil, to: nil) ⇒ PayoutIntentCreateParams
Returns a new instance of PayoutIntentCreateParams.
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/stripe/params/v2/money_management/payout_intent_create_params.rb', line 118 def initialize( amount: nil, confirmation_method: nil, description: nil, from: nil, metadata: nil, recipient_notification: nil, schedule_options: nil, statement_descriptor: nil, to: nil ) @amount = amount @confirmation_method = confirmation_method @description = description @from = from @metadata = @recipient_notification = recipient_notification @schedule_options = @statement_descriptor = statement_descriptor @to = to end |
Instance Attribute Details
#amount ⇒ Object
The monetary amount to be sent.
100 101 102 |
# File 'lib/stripe/params/v2/money_management/payout_intent_create_params.rb', line 100 def amount @amount end |
#confirmation_method ⇒ Object
Controls whether the intent requires explicit confirmation before transitioning to pending. Defaults to automatic.
102 103 104 |
# File 'lib/stripe/params/v2/money_management/payout_intent_create_params.rb', line 102 def confirmation_method @confirmation_method end |
#description ⇒ Object
An arbitrary string attached to the PayoutIntent. Often useful for displaying to users.
104 105 106 |
# File 'lib/stripe/params/v2/money_management/payout_intent_create_params.rb', line 104 def description @description end |
#from ⇒ Object
The FinancialAccount that funds are pulled from.
106 107 108 |
# File 'lib/stripe/params/v2/money_management/payout_intent_create_params.rb', line 106 def from @from end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
108 109 110 |
# File 'lib/stripe/params/v2/money_management/payout_intent_create_params.rb', line 108 def @metadata end |
#recipient_notification ⇒ Object
Details about the OutboundPayment notification settings for recipient. Only applicable to OutboundPayment.
110 111 112 |
# File 'lib/stripe/params/v2/money_management/payout_intent_create_params.rb', line 110 def recipient_notification @recipient_notification end |
#schedule_options ⇒ Object
Scheduling options for the payout. If this is nil, we assume immediate execution.
112 113 114 |
# File 'lib/stripe/params/v2/money_management/payout_intent_create_params.rb', line 112 def @schedule_options end |
#statement_descriptor ⇒ Object
The description that appears on the receiving end for the payout (for example, on a bank statement).
114 115 116 |
# File 'lib/stripe/params/v2/money_management/payout_intent_create_params.rb', line 114 def statement_descriptor @statement_descriptor end |
#to ⇒ Object
To which payout method the payout is sent.
116 117 118 |
# File 'lib/stripe/params/v2/money_management/payout_intent_create_params.rb', line 116 def to @to end |