Class: Stripe::V2::MoneyManagement::PayoutIntentUpdateParams::ScheduleOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::MoneyManagement::PayoutIntentUpdateParams::ScheduleOptions
- Defined in:
- lib/stripe/params/v2/money_management/payout_intent_update_params.rb
Instance Attribute Summary collapse
-
#execute_on ⇒ Object
The date when the payout should be executed, in YYYY-MM-DD format.
Instance Method Summary collapse
-
#initialize(execute_on: nil) ⇒ ScheduleOptions
constructor
A new instance of ScheduleOptions.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(execute_on: nil) ⇒ ScheduleOptions
Returns a new instance of ScheduleOptions.
34 35 36 |
# File 'lib/stripe/params/v2/money_management/payout_intent_update_params.rb', line 34 def initialize(execute_on: nil) @execute_on = execute_on end |
Instance Attribute Details
#execute_on ⇒ Object
The date when the payout should be executed, in YYYY-MM-DD format.
32 33 34 |
# File 'lib/stripe/params/v2/money_management/payout_intent_update_params.rb', line 32 def execute_on @execute_on end |