Class: Stripe::V2::MoneyManagement::PayoutMethodsBankAccountSpec

Inherits:
SingletonAPIResource show all
Defined in:
lib/stripe/resources/v2/money_management/payout_methods_bank_account_spec.rb

Overview

The PayoutMethodsBankAccountSpec object.

Defined Under Namespace

Classes: Countries

Constant Summary collapse

OBJECT_NAME =
"v2.money_management.payout_methods_bank_account_spec"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from SingletonAPIResource

resource_url, #resource_url, retrieve

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#countriesObject (readonly)

The list of specs by country.



67
68
69
# File 'lib/stripe/resources/v2/money_management/payout_methods_bank_account_spec.rb', line 67

def countries
  @countries
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



69
70
71
# File 'lib/stripe/resources/v2/money_management/payout_methods_bank_account_spec.rb', line 69

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



71
72
73
# File 'lib/stripe/resources/v2/money_management/payout_methods_bank_account_spec.rb', line 71

def object
  @object
end

Class Method Details

.field_remappingsObject



77
78
79
# File 'lib/stripe/resources/v2/money_management/payout_methods_bank_account_spec.rb', line 77

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



73
74
75
# File 'lib/stripe/resources/v2/money_management/payout_methods_bank_account_spec.rb', line 73

def self.inner_class_types
  @inner_class_types = { countries: Countries }
end

.object_nameObject



10
11
12
# File 'lib/stripe/resources/v2/money_management/payout_methods_bank_account_spec.rb', line 10

def self.object_name
  "v2.money_management.payout_methods_bank_account_spec"
end