Class: Stripe::V2::MoneyManagement::PayoutMethodsBankAccountSpec::Countries::Field
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::MoneyManagement::PayoutMethodsBankAccountSpec::Countries::Field
- Defined in:
- lib/stripe/resources/v2/money_management/payout_methods_bank_account_spec.rb
Defined Under Namespace
Classes: LocalNameHuman
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#currencies ⇒ Object
readonly
The currencies supported by the corresponding credentials for bank accounts in the specified country.
-
#local_name ⇒ Object
readonly
The local name of the field.
-
#local_name_human ⇒ Object
readonly
The human readable local name of the field.
-
#max_length ⇒ Object
readonly
The maximum length of the field.
-
#min_length ⇒ Object
readonly
THe minimum length of the field.
-
#placeholder ⇒ Object
readonly
The placeholder value of the field.
-
#stripe_name ⇒ Object
readonly
The stripe name of the field.
-
#validation_regex ⇒ Object
readonly
The validation regex of the field.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#currencies ⇒ Object (readonly)
The currencies supported by the corresponding credentials for bank accounts in the specified country.
31 32 33 |
# File 'lib/stripe/resources/v2/money_management/payout_methods_bank_account_spec.rb', line 31 def currencies @currencies end |
#local_name ⇒ Object (readonly)
The local name of the field.
33 34 35 |
# File 'lib/stripe/resources/v2/money_management/payout_methods_bank_account_spec.rb', line 33 def local_name @local_name end |
#local_name_human ⇒ Object (readonly)
The human readable local name of the field.
35 36 37 |
# File 'lib/stripe/resources/v2/money_management/payout_methods_bank_account_spec.rb', line 35 def local_name_human @local_name_human end |
#max_length ⇒ Object (readonly)
The maximum length of the field.
37 38 39 |
# File 'lib/stripe/resources/v2/money_management/payout_methods_bank_account_spec.rb', line 37 def max_length @max_length end |
#min_length ⇒ Object (readonly)
THe minimum length of the field.
39 40 41 |
# File 'lib/stripe/resources/v2/money_management/payout_methods_bank_account_spec.rb', line 39 def min_length @min_length end |
#placeholder ⇒ Object (readonly)
The placeholder value of the field.
41 42 43 |
# File 'lib/stripe/resources/v2/money_management/payout_methods_bank_account_spec.rb', line 41 def placeholder @placeholder end |
#stripe_name ⇒ Object (readonly)
The stripe name of the field.
43 44 45 |
# File 'lib/stripe/resources/v2/money_management/payout_methods_bank_account_spec.rb', line 43 def stripe_name @stripe_name end |
#validation_regex ⇒ Object (readonly)
The validation regex of the field.
45 46 47 |
# File 'lib/stripe/resources/v2/money_management/payout_methods_bank_account_spec.rb', line 45 def validation_regex @validation_regex end |
Class Method Details
.field_remappings ⇒ Object
51 52 53 |
# File 'lib/stripe/resources/v2/money_management/payout_methods_bank_account_spec.rb', line 51 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
47 48 49 |
# File 'lib/stripe/resources/v2/money_management/payout_methods_bank_account_spec.rb', line 47 def self.inner_class_types @inner_class_types = { local_name_human: LocalNameHuman } end |