Class: Stripe::V2::MoneyManagement::PayoutMethodsBankAccountSpecRetrieveParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::MoneyManagement::PayoutMethodsBankAccountSpecRetrieveParams
- Defined in:
- lib/stripe/params/v2/money_management/payout_methods_bank_account_spec_retrieve_params.rb
Instance Attribute Summary collapse
-
#countries ⇒ Object
The countries to fetch the bank account spec for.
Instance Method Summary collapse
-
#initialize(countries: nil) ⇒ PayoutMethodsBankAccountSpecRetrieveParams
constructor
A new instance of PayoutMethodsBankAccountSpecRetrieveParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(countries: nil) ⇒ PayoutMethodsBankAccountSpecRetrieveParams
Returns a new instance of PayoutMethodsBankAccountSpecRetrieveParams.
11 12 13 |
# File 'lib/stripe/params/v2/money_management/payout_methods_bank_account_spec_retrieve_params.rb', line 11 def initialize(countries: nil) @countries = countries end |
Instance Attribute Details
#countries ⇒ Object
The countries to fetch the bank account spec for.
9 10 11 |
# File 'lib/stripe/params/v2/money_management/payout_methods_bank_account_spec_retrieve_params.rb', line 9 def countries @countries end |