Class: Stripe::V2::MoneyManagement::ReceivedCredit
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::MoneyManagement::ReceivedCredit
- Defined in:
- lib/stripe/resources/v2/money_management/received_credit.rb
Overview
Use ReceivedCredits API to retrieve information on when, where, and how funds are sent into your FinancialAccount.
Defined Under Namespace
Classes: BalanceTransfer, BankTransfer, CardSpend, CryptoWalletTransfer, StatusDetails, StatusTransitions, StripeBalancePayment, StripeNetworkTransfer
Constant Summary collapse
- OBJECT_NAME =
"v2.money_management.received_credit"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The amount and currency of the ReceivedCredit.
-
#balance_transfer ⇒ Object
readonly
This object stores details about the originating Stripe transaction that resulted in the ReceivedCredit.
-
#bank_transfer ⇒ Object
readonly
This object stores details about the originating banking transaction that resulted in the ReceivedCredit.
-
#card_spend ⇒ Object
readonly
This object stores details about the originating issuing card spend that resulted in the ReceivedCredit.
-
#created ⇒ Object
readonly
Time at which the ReceivedCredit was created.
-
#crypto_wallet_transfer ⇒ Object
readonly
This object stores details about the originating crypto transaction that resulted in the ReceivedCredit.
-
#description ⇒ Object
readonly
Freeform string set by originator of the ReceivedCredit.
-
#external_amount ⇒ Object
readonly
The amount and currency of the original/external credit request.
-
#financial_account ⇒ Object
readonly
Financial Account ID on which funds for ReceivedCredit were received.
-
#id ⇒ Object
readonly
Unique identifier for the ReceivedCredit.
-
#livemode ⇒ Object
readonly
Has the value
trueif the object exists in live mode or the valuefalseif the object exists in test mode. -
#object ⇒ Object
readonly
String representing the object's type.
-
#receipt_url ⇒ Object
readonly
A hosted transaction receipt URL that is provided when money movement is considered regulated under Stripe’s money transmission licenses.
-
#status ⇒ Object
readonly
Open Enum.
-
#status_details ⇒ Object
readonly
This hash contains detailed information that elaborates on the specific status of the ReceivedCredit.
-
#status_transitions ⇒ Object
readonly
Hash containing timestamps of when the object transitioned to a particular status.
-
#stripe_balance_payment ⇒ Object
readonly
This object stores details about the stripe balance pay refund that resulted in the ReceivedCredit.
-
#stripe_network_transfer ⇒ Object
readonly
This object stores details about the Stripe network transfer that resulted in the ReceivedCredit.
-
#type ⇒ Object
readonly
Open Enum.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The amount and currency of the ReceivedCredit.
376 377 378 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 376 def amount @amount end |
#balance_transfer ⇒ Object (readonly)
This object stores details about the originating Stripe transaction that resulted in the ReceivedCredit. Present if type field value is balance_transfer.
378 379 380 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 378 def balance_transfer @balance_transfer end |
#bank_transfer ⇒ Object (readonly)
This object stores details about the originating banking transaction that resulted in the ReceivedCredit. Present if type field value is bank_transfer.
380 381 382 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 380 def bank_transfer @bank_transfer end |
#card_spend ⇒ Object (readonly)
This object stores details about the originating issuing card spend that resulted in the ReceivedCredit. Present if type field value is card_spend.
382 383 384 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 382 def card_spend @card_spend end |
#created ⇒ Object (readonly)
Time at which the ReceivedCredit was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
385 386 387 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 385 def created @created end |
#crypto_wallet_transfer ⇒ Object (readonly)
This object stores details about the originating crypto transaction that resulted in the ReceivedCredit. Present if type field value is crypto_wallet_transfer.
387 388 389 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 387 def crypto_wallet_transfer @crypto_wallet_transfer end |
#description ⇒ Object (readonly)
Freeform string set by originator of the ReceivedCredit.
389 390 391 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 389 def description @description end |
#external_amount ⇒ Object (readonly)
The amount and currency of the original/external credit request.
391 392 393 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 391 def external_amount @external_amount end |
#financial_account ⇒ Object (readonly)
Financial Account ID on which funds for ReceivedCredit were received.
393 394 395 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 393 def financial_account @financial_account end |
#id ⇒ Object (readonly)
Unique identifier for the ReceivedCredit.
395 396 397 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 395 def id @id end |
#livemode ⇒ Object (readonly)
Has the value true if the object exists in live mode or the value false if the object exists in test mode.
397 398 399 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 397 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object's type. Objects of the same type share the same value of the object field.
399 400 401 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 399 def object @object end |
#receipt_url ⇒ Object (readonly)
A hosted transaction receipt URL that is provided when money movement is considered regulated under Stripe’s money transmission licenses.
401 402 403 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 401 def receipt_url @receipt_url end |
#status ⇒ Object (readonly)
Open Enum. The status of the ReceivedCredit.
403 404 405 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 403 def status @status end |
#status_details ⇒ Object (readonly)
This hash contains detailed information that elaborates on the specific status of the ReceivedCredit. e.g the reason behind a failure if the status is marked as failed.
405 406 407 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 405 def status_details @status_details end |
#status_transitions ⇒ Object (readonly)
Hash containing timestamps of when the object transitioned to a particular status.
407 408 409 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 407 def status_transitions @status_transitions end |
#stripe_balance_payment ⇒ Object (readonly)
This object stores details about the stripe balance pay refund that resulted in the ReceivedCredit. Present if type field value is stripe_balance_payment.
409 410 411 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 409 def stripe_balance_payment @stripe_balance_payment end |
#stripe_network_transfer ⇒ Object (readonly)
This object stores details about the Stripe network transfer that resulted in the ReceivedCredit. Present if type field value is stripe_network_transfer.
411 412 413 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 411 def stripe_network_transfer @stripe_network_transfer end |
#type ⇒ Object (readonly)
Open Enum. The type of flow that caused the ReceivedCredit.
413 414 415 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 413 def type @type end |
Class Method Details
.field_remappings ⇒ Object
428 429 430 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 428 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
415 416 417 418 419 420 421 422 423 424 425 426 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 415 def self.inner_class_types @inner_class_types = { balance_transfer: BalanceTransfer, bank_transfer: BankTransfer, card_spend: CardSpend, crypto_wallet_transfer: CryptoWalletTransfer, status_details: StatusDetails, status_transitions: StatusTransitions, stripe_balance_payment: StripeBalancePayment, stripe_network_transfer: StripeNetworkTransfer, } end |
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 10 def self.object_name "v2.money_management.received_credit" end |