Class: Stripe::V2::MoneyManagement::ReceivedCredit::BankTransfer
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::MoneyManagement::ReceivedCredit::BankTransfer
- Defined in:
- lib/stripe/resources/v2/money_management/received_credit.rb
Defined Under Namespace
Classes: CaBankAccount, GbBankAccount, SepaBankAccount, UsBankAccount
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#ca_bank_account ⇒ Object
readonly
Hash containing the transaction bank details.
-
#financial_address ⇒ Object
readonly
Financial Address on which funds for ReceivedCredit were received.
-
#gb_bank_account ⇒ Object
readonly
Hash containing the transaction bank details.
-
#origin_type ⇒ Object
readonly
Open Enum.
-
#sepa_bank_account ⇒ Object
readonly
Hash containing the transaction bank details.
-
#statement_descriptor ⇒ Object
readonly
Freeform string set by originator of the external ReceivedCredit.
-
#us_bank_account ⇒ Object
readonly
Hash containing the transaction bank details.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#ca_bank_account ⇒ Object (readonly)
Hash containing the transaction bank details. Present if ‘origin_type` field value is `ca_bank_account`.
121 122 123 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 121 def ca_bank_account @ca_bank_account end |
#financial_address ⇒ Object (readonly)
Financial Address on which funds for ReceivedCredit were received.
123 124 125 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 123 def financial_address @financial_address end |
#gb_bank_account ⇒ Object (readonly)
Hash containing the transaction bank details. Present if ‘origin_type` field value is `gb_bank_account`.
125 126 127 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 125 def gb_bank_account @gb_bank_account end |
#origin_type ⇒ Object (readonly)
Open Enum. Indicates the origin of source from which external funds originated from.
127 128 129 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 127 def origin_type @origin_type end |
#sepa_bank_account ⇒ Object (readonly)
Hash containing the transaction bank details. Present if ‘origin_type` field value is `sepa_bank_account`.
129 130 131 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 129 def sepa_bank_account @sepa_bank_account end |
#statement_descriptor ⇒ Object (readonly)
Freeform string set by originator of the external ReceivedCredit.
131 132 133 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 131 def statement_descriptor @statement_descriptor end |
#us_bank_account ⇒ Object (readonly)
Hash containing the transaction bank details. Present if ‘origin_type` field value is `us_bank_account`.
133 134 135 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 133 def us_bank_account @us_bank_account end |
Class Method Details
.field_remappings ⇒ Object
144 145 146 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 144 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
135 136 137 138 139 140 141 142 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 135 def self.inner_class_types @inner_class_types = { ca_bank_account: CaBankAccount, gb_bank_account: GbBankAccount, sepa_bank_account: SepaBankAccount, us_bank_account: UsBankAccount, } end |