Class: Stripe::V2::MoneyManagement::ReceivedCredit::BankTransfer::CaBankAccount
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::MoneyManagement::ReceivedCredit::BankTransfer::CaBankAccount
- Defined in:
- lib/stripe/resources/v2/money_management/received_credit.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
readonly
The account holder name of the bank account the transfer was received from.
-
#bank_name ⇒ Object
readonly
The bank name the transfer was received from.
-
#last4 ⇒ Object
readonly
The last 4 digits of the account number that originated the transfer.
-
#network ⇒ Object
readonly
Open Enum.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_holder_name ⇒ Object (readonly)
The account holder name of the bank account the transfer was received from.
40 41 42 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 40 def account_holder_name @account_holder_name end |
#bank_name ⇒ Object (readonly)
The bank name the transfer was received from.
42 43 44 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 42 def bank_name @bank_name end |
#last4 ⇒ Object (readonly)
The last 4 digits of the account number that originated the transfer. Depending on the bank, this may instead be the last 4 digits of the return account number.
45 46 47 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 45 def last4 @last4 end |
#network ⇒ Object (readonly)
Open Enum. The money transmission network used to send funds for this ReceivedCredit.
47 48 49 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 47 def network @network end |
Class Method Details
.field_remappings ⇒ Object
53 54 55 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 53 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
49 50 51 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 49 def self.inner_class_types @inner_class_types = {} end |