Class: Stripe::V2::MoneyManagement::ReceivedCredit::BankTransfer::SepaBankAccount

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/money_management/received_credit.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_holder_nameObject (readonly)

The account holder name of the bank account the transfer was received from.



121
122
123
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 121

def 
  @account_holder_name
end

#bank_nameObject (readonly)

The bank name the transfer was received from.



123
124
125
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 123

def bank_name
  @bank_name
end

#bicObject (readonly)

The BIC of the SEPA account.



125
126
127
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 125

def bic
  @bic
end

#countryObject (readonly)

The origination country of the bank transfer.



127
128
129
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 127

def country
  @country
end

#ibanObject (readonly)

The IBAN that originated the transfer.



129
130
131
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 129

def iban
  @iban
end

#networkObject (readonly)

The money transmission network used to send funds for this ReceivedCredit.



131
132
133
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 131

def network
  @network
end

Class Method Details

.field_remappingsObject



137
138
139
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 137

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



133
134
135
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 133

def self.inner_class_types
  @inner_class_types = {}
end