Class: Stripe::V2::MoneyManagement::ReceivedCredit::BankTransfer::UsBankAccount
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::MoneyManagement::ReceivedCredit::BankTransfer::UsBankAccount
- Defined in:
- lib/stripe/resources/v2/money_management/received_credit.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bank_name ⇒ Object
readonly
The bank name the transfer was received from.
-
#last4 ⇒ Object
readonly
The last 4 digits of the account number that originated the transfer.
-
#network ⇒ Object
readonly
Open Enum.
-
#routing_number ⇒ Object
readonly
The routing number of the account that originated the transfer.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bank_name ⇒ Object (readonly)
The bank name the transfer was received from.
84 85 86 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 84 def bank_name @bank_name end |
#last4 ⇒ Object (readonly)
The last 4 digits of the account number that originated the transfer.
86 87 88 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 86 def last4 @last4 end |
#network ⇒ Object (readonly)
Open Enum. The money transmission network used to send funds for this ReceivedCredit.
88 89 90 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 88 def network @network end |
#routing_number ⇒ Object (readonly)
The routing number of the account that originated the transfer.
90 91 92 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 90 def routing_number @routing_number end |
Class Method Details
.field_remappings ⇒ Object
96 97 98 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 96 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
92 93 94 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 92 def self.inner_class_types @inner_class_types = {} end |