Class: Stripe::V2::MoneyManagement::ReceivedCredit::CryptoWalletTransfer

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/money_management/received_credit.rb

Defined Under Namespace

Classes: CryptoWallet

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#crypto_walletObject (readonly)

Hash containing the transaction crypto wallet details.



255
256
257
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 255

def crypto_wallet
  @crypto_wallet
end

#financial_addressObject (readonly)

Financial Address on which funds for ReceivedCredit were received.



257
258
259
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 257

def financial_address
  @financial_address
end

#origin_typeObject (readonly)

Open Enum. Indicates the origin of source from which external funds originated from.



259
260
261
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 259

def origin_type
  @origin_type
end

#statement_descriptorObject (readonly)

Freeform string set by originator of the external ReceivedCredit.



261
262
263
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 261

def statement_descriptor
  @statement_descriptor
end

Class Method Details

.field_remappingsObject



267
268
269
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 267

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



263
264
265
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 263

def self.inner_class_types
  @inner_class_types = { crypto_wallet: CryptoWallet }
end