Class: Stripe::V2::MoneyManagement::ReceivedCredit::StatusDetails

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/money_management/received_credit.rb

Defined Under Namespace

Classes: Failed, Returned

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#failedObject (readonly)

Hash that provides additional information regarding the reason behind a ‘failed` ReceivedCredit status. It is only present when the ReceivedCredit status is `failed`.



153
154
155
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 153

def failed
  @failed
end

#returnedObject (readonly)

Hash that provides additional information regarding the reason behind a ‘returned` ReceivedCredit status. It is only present when the ReceivedCredit status is `returned`.



155
156
157
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 155

def returned
  @returned
end

Class Method Details

.field_remappingsObject



161
162
163
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 161

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



157
158
159
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 157

def self.inner_class_types
  @inner_class_types = { failed: Failed, returned: Returned }
end