Class: Stripe::V2::MoneyManagement::ReceivedDebit
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::MoneyManagement::ReceivedDebit
- Defined in:
- lib/stripe/resources/v2/money_management/received_debit.rb
Overview
ReceivedDebit resource
Defined Under Namespace
Classes: BalanceTransfer, BankTransfer, CardSpend, DisputeDetails, StatusDetails, StatusTransitions, StripeBalancePayment
Constant Summary collapse
- OBJECT_NAME =
"v2.money_management.received_debit"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
Amount and currency of the ReceivedDebit.
-
#balance_transfer ⇒ Object
readonly
This object stores details about the balance transfer object that resulted in the ReceivedDebit.
-
#bank_transfer ⇒ Object
readonly
This object stores details about the originating banking transaction that resulted in the ReceivedDebit.
-
#card_spend ⇒ Object
readonly
This object stores details about the issuing transactions that resulted in the ReceivedDebit.
-
#created ⇒ Object
readonly
The time at which the ReceivedDebit was created.
-
#description ⇒ Object
readonly
Freeform string sent by the originator of the ReceivedDebit.
-
#dispute_details ⇒ Object
readonly
The dispute details.
-
#external_amount ⇒ Object
readonly
The amount and currency of the original/external debit request.
-
#financial_account ⇒ Object
readonly
Financial Account on which funds for ReceivedDebit were debited.
-
#id ⇒ Object
readonly
Unique identifier for the ReceivedDebit.
-
#livemode ⇒ Object
readonly
Has the value
trueif the object exists in live mode or the valuefalseif the object exists in test mode. -
#object ⇒ Object
readonly
String representing the object's type.
-
#receipt_url ⇒ Object
readonly
A link to the Stripe-hosted receipt for this ReceivedDebit.
-
#settles_at ⇒ Object
readonly
The time at which the scheduled ReceivedDebit is expected to settle.
-
#status ⇒ Object
readonly
Open Enum.
-
#status_details ⇒ Object
readonly
Detailed information about the status of the ReceivedDebit.
-
#status_transitions ⇒ Object
readonly
The time at which the ReceivedDebit transitioned to a particular status.
-
#stripe_balance_payment ⇒ Object
readonly
This object stores details about the Stripe Balance Payment that resulted in the ReceivedDebit.
-
#type ⇒ Object
readonly
Open Enum.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
Amount and currency of the ReceivedDebit.
234 235 236 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 234 def amount @amount end |
#balance_transfer ⇒ Object (readonly)
This object stores details about the balance transfer object that resulted in the ReceivedDebit.
236 237 238 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 236 def balance_transfer @balance_transfer end |
#bank_transfer ⇒ Object (readonly)
This object stores details about the originating banking transaction that resulted in the ReceivedDebit. Present if type field value is bank_transfer.
238 239 240 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 238 def bank_transfer @bank_transfer end |
#card_spend ⇒ Object (readonly)
This object stores details about the issuing transactions that resulted in the ReceivedDebit. Present if type field value is card_spend.
240 241 242 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 240 def card_spend @card_spend end |
#created ⇒ Object (readonly)
The time at which the ReceivedDebit was created.
Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
243 244 245 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 243 def created @created end |
#description ⇒ Object (readonly)
Freeform string sent by the originator of the ReceivedDebit.
245 246 247 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 245 def description @description end |
#dispute_details ⇒ Object (readonly)
The dispute details.
247 248 249 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 247 def dispute_details @dispute_details end |
#external_amount ⇒ Object (readonly)
The amount and currency of the original/external debit request.
249 250 251 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 249 def external_amount @external_amount end |
#financial_account ⇒ Object (readonly)
Financial Account on which funds for ReceivedDebit were debited.
251 252 253 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 251 def financial_account @financial_account end |
#id ⇒ Object (readonly)
Unique identifier for the ReceivedDebit.
253 254 255 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 253 def id @id end |
#livemode ⇒ Object (readonly)
Has the value true if the object exists in live mode or the value false if the object exists in test mode.
255 256 257 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 255 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object's type. Objects of the same type share the same value of the object field.
257 258 259 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 257 def object @object end |
#receipt_url ⇒ Object (readonly)
A link to the Stripe-hosted receipt for this ReceivedDebit.
259 260 261 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 259 def receipt_url @receipt_url end |
#settles_at ⇒ Object (readonly)
The time at which the scheduled ReceivedDebit is expected to settle.
Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
Only present when status is scheduled.
263 264 265 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 263 def settles_at @settles_at end |
#status ⇒ Object (readonly)
Open Enum. The status of the ReceivedDebit.
265 266 267 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 265 def status @status end |
#status_details ⇒ Object (readonly)
Detailed information about the status of the ReceivedDebit.
267 268 269 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 267 def status_details @status_details end |
#status_transitions ⇒ Object (readonly)
The time at which the ReceivedDebit transitioned to a particular status.
269 270 271 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 269 def status_transitions @status_transitions end |
#stripe_balance_payment ⇒ Object (readonly)
This object stores details about the Stripe Balance Payment that resulted in the ReceivedDebit.
271 272 273 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 271 def stripe_balance_payment @stripe_balance_payment end |
#type ⇒ Object (readonly)
Open Enum. The type of the ReceivedDebit.
273 274 275 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 273 def type @type end |
Class Method Details
.field_remappings ⇒ Object
287 288 289 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 287 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
275 276 277 278 279 280 281 282 283 284 285 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 275 def self.inner_class_types @inner_class_types = { balance_transfer: BalanceTransfer, bank_transfer: BankTransfer, card_spend: CardSpend, dispute_details: DisputeDetails, status_details: StatusDetails, status_transitions: StatusTransitions, stripe_balance_payment: StripeBalancePayment, } end |
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 10 def self.object_name "v2.money_management.received_debit" end |