Class: Stripe::V2::MoneyManagement::ReceivedDebit::BankTransfer

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/money_management/received_debit.rb

Defined Under Namespace

Classes: UsBankAccount

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#financial_addressObject (readonly)

The Financial Address that was debited.



47
48
49
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 47

def financial_address
  @financial_address
end

#origin_typeObject (readonly)

Open Enum. Indicates the origin type through which this debit was initiated.



49
50
51
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 49

def origin_type
  @origin_type
end

#payment_method_typeObject (readonly)

Open Enum. The type of the payment method used to originate the debit.



51
52
53
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 51

def payment_method_type
  @payment_method_type
end

#statement_descriptorObject (readonly)

The statement descriptor set by the originator of the debit.



53
54
55
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 53

def statement_descriptor
  @statement_descriptor
end

#us_bank_accountObject (readonly)

The payment method used to originate the debit.



55
56
57
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 55

def 
  @us_bank_account
end

Class Method Details

.field_remappingsObject



61
62
63
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 61

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



57
58
59
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 57

def self.inner_class_types
  @inner_class_types = { us_bank_account: UsBankAccount }
end