Class: Stripe::V2::MoneyManagement::ReceivedDebit::BankTransfer::GbBankAccount

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/money_management/received_debit.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_holder_nameObject (readonly)

The name of the account holder that originated the debit.



32
33
34
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 32

def 
  @account_holder_name
end

#bank_nameObject (readonly)

The name of the bank the debit originated from.



34
35
36
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 34

def bank_name
  @bank_name
end

#last4Object (readonly)

Last 4 digits of the bank account number.



36
37
38
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 36

def last4
  @last4
end

#networkObject (readonly)

Open Enum. The bank network the debit was originated on.



38
39
40
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 38

def network
  @network
end

#received_debit_mandateObject (readonly)

The ID of the mandate associated with this debit.



40
41
42
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 40

def received_debit_mandate
  @received_debit_mandate
end

#sort_codeObject (readonly)

The sort code of the bank that originated the debit.



42
43
44
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 42

def sort_code
  @sort_code
end

Class Method Details

.field_remappingsObject



48
49
50
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 48

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



44
45
46
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 44

def self.inner_class_types
  @inner_class_types = {}
end