Class: Stripe::V2::MoneyManagement::ReceivedDebit::BankTransfer::UsBankAccount

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/money_management/received_debit.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_nameObject (readonly)

The name of the bank the debit originated from.



17
18
19
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 17

def bank_name
  @bank_name
end

#networkObject (readonly)

Open Enum. The bank network the debit was originated on.



19
20
21
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 19

def network
  @network
end

#routing_numberObject (readonly)

The routing number of the bank that originated the debit.



21
22
23
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 21

def routing_number
  @routing_number
end

Class Method Details

.field_remappingsObject



27
28
29
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 27

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



23
24
25
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 23

def self.inner_class_types
  @inner_class_types = {}
end