Class: Stripe::V2::MoneyManagement::ReceivedDebit::CardSpend
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::MoneyManagement::ReceivedDebit::CardSpend
- Defined in:
- lib/stripe/resources/v2/money_management/received_debit.rb
Defined Under Namespace
Classes: Authorization, CardTransaction
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#authorization ⇒ Object
readonly
The Issuing Authorization for this card_spend.
-
#card_transactions ⇒ Object
readonly
The list of card spend transactions.
-
#card_v1_id ⇒ Object
readonly
The reference to the card object that resulted in the debit.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#authorization ⇒ Object (readonly)
The Issuing Authorization for this card_spend. Contains the reference id and the amount.
70 71 72 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 70 def @authorization end |
#card_transactions ⇒ Object (readonly)
The list of card spend transactions. These contain the transaction reference ID and the amount.
72 73 74 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 72 def card_transactions @card_transactions end |
#card_v1_id ⇒ Object (readonly)
The reference to the card object that resulted in the debit.
74 75 76 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 74 def card_v1_id @card_v1_id end |