Class: Stripe::V2::MoneyManagement::ReceivedDebitMandate

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/money_management/received_debit_mandate.rb

Overview

A ReceivedDebitMandate represents an authorization from a third party to debit a financial account on a recurring basis.

Defined Under Namespace

Classes: BankTransfer, StatusDetails, StatusTransitions

Constant Summary collapse

OBJECT_NAME =
"v2.money_management.received_debit_mandate"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_transferObject (readonly)

This object stores details about the originating bank transfer that resulted in the ReceivedDebitMandate. Present if type field value is bank_transfer.



84
85
86
# File 'lib/stripe/resources/v2/money_management/received_debit_mandate.rb', line 84

def bank_transfer
  @bank_transfer
end

#createdObject (readonly)

The time at which the ReceivedDebitMandate was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2026-06-03T13:22:18.123Z.



87
88
89
# File 'lib/stripe/resources/v2/money_management/received_debit_mandate.rb', line 87

def created
  @created
end

#currencyObject (readonly)

The currency of the ReceivedDebitMandate in ISO 4217 format. This is the currency that debits will be collected in.



89
90
91
# File 'lib/stripe/resources/v2/money_management/received_debit_mandate.rb', line 89

def currency
  @currency
end

#financial_accountObject (readonly)

Financial account ID associated with this mandate.



91
92
93
# File 'lib/stripe/resources/v2/money_management/received_debit_mandate.rb', line 91

def 
  @financial_account
end

#idObject (readonly)

The unique identifier for the ReceivedDebitMandate.



93
94
95
# File 'lib/stripe/resources/v2/money_management/received_debit_mandate.rb', line 93

def id
  @id
end

#livemodeObject (readonly)

Has the value true if the object exists in live mode or the value false if the object exists in test mode.



95
96
97
# File 'lib/stripe/resources/v2/money_management/received_debit_mandate.rb', line 95

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object's type. Objects of the same type share the same value of the object field.



97
98
99
# File 'lib/stripe/resources/v2/money_management/received_debit_mandate.rb', line 97

def object
  @object
end

#statusObject (readonly)

The status of the ReceivedDebitMandate.



99
100
101
# File 'lib/stripe/resources/v2/money_management/received_debit_mandate.rb', line 99

def status
  @status
end

#status_detailsObject (readonly)

Detailed information that elaborates on the specific status of the ReceivedDebitMandate.



101
102
103
# File 'lib/stripe/resources/v2/money_management/received_debit_mandate.rb', line 101

def status_details
  @status_details
end

#status_transitionsObject (readonly)

Timestamps describing when the mandate changed status.



103
104
105
# File 'lib/stripe/resources/v2/money_management/received_debit_mandate.rb', line 103

def status_transitions
  @status_transitions
end

#typeObject (readonly)

The type of the ReceivedDebitMandate.



105
106
107
# File 'lib/stripe/resources/v2/money_management/received_debit_mandate.rb', line 105

def type
  @type
end

Class Method Details

.field_remappingsObject



115
116
117
# File 'lib/stripe/resources/v2/money_management/received_debit_mandate.rb', line 115

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



107
108
109
110
111
112
113
# File 'lib/stripe/resources/v2/money_management/received_debit_mandate.rb', line 107

def self.inner_class_types
  @inner_class_types = {
    bank_transfer: BankTransfer,
    status_details: StatusDetails,
    status_transitions: StatusTransitions,
  }
end

.object_nameObject



10
11
12
# File 'lib/stripe/resources/v2/money_management/received_debit_mandate.rb', line 10

def self.object_name
  "v2.money_management.received_debit_mandate"
end