Class: Stripe::V2::MoneyManagement::RecipientVerification
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::MoneyManagement::RecipientVerification
- Defined in:
- lib/stripe/resources/v2/money_management/recipient_verification.rb
Overview
RecipientVerification represents a verification of recipient you intend to send funds to.
Defined Under Namespace
Classes: MatchResultDetails, StatusTransitions
Constant Summary collapse
- OBJECT_NAME =
"v2.money_management.recipient_verification"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#consumed_by ⇒ Object
readonly
The OBP/OBT ID that consumed this verification, present if one is successfully created.
-
#created ⇒ Object
readonly
Time at which the RecipientVerification was created.
-
#expires_at ⇒ Object
readonly
Time at which the RecipientVerification expires, 5 minutes after the creation.
-
#id ⇒ Object
readonly
The ID of the RecipientVerification.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#match_result ⇒ Object
readonly
Closed Enum.
-
#match_result_details ⇒ Object
readonly
Details for the match result.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#status ⇒ Object
readonly
Closed Enum.
-
#status_transitions ⇒ Object
readonly
Hash containing timestamps of when the object transitioned to a particular status.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#consumed_by ⇒ Object (readonly)
The OBP/OBT ID that consumed this verification, present if one is successfully created.
48 49 50 |
# File 'lib/stripe/resources/v2/money_management/recipient_verification.rb', line 48 def consumed_by @consumed_by end |
#created ⇒ Object (readonly)
Time at which the RecipientVerification was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
51 52 53 |
# File 'lib/stripe/resources/v2/money_management/recipient_verification.rb', line 51 def created @created end |
#expires_at ⇒ Object (readonly)
Time at which the RecipientVerification expires, 5 minutes after the creation. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
54 55 56 |
# File 'lib/stripe/resources/v2/money_management/recipient_verification.rb', line 54 def expires_at @expires_at end |
#id ⇒ Object (readonly)
The ID of the RecipientVerification.
56 57 58 |
# File 'lib/stripe/resources/v2/money_management/recipient_verification.rb', line 56 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
68 69 70 |
# File 'lib/stripe/resources/v2/money_management/recipient_verification.rb', line 68 def livemode @livemode end |
#match_result ⇒ Object (readonly)
Closed Enum. Match level of the RecipientVerification: ‘match`, `close_match`, `no_match`, `unavailable`.
58 59 60 |
# File 'lib/stripe/resources/v2/money_management/recipient_verification.rb', line 58 def match_result @match_result end |
#match_result_details ⇒ Object (readonly)
Details for the match result.
60 61 62 |
# File 'lib/stripe/resources/v2/money_management/recipient_verification.rb', line 60 def match_result_details @match_result_details end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
62 63 64 |
# File 'lib/stripe/resources/v2/money_management/recipient_verification.rb', line 62 def object @object end |
#status ⇒ Object (readonly)
Closed Enum. Current status of the RecipientVerification: ‘verified`, `consumed`, `expired`, `awaiting_acknowledgement`, `acknowledged`.
64 65 66 |
# File 'lib/stripe/resources/v2/money_management/recipient_verification.rb', line 64 def status @status end |
#status_transitions ⇒ Object (readonly)
Hash containing timestamps of when the object transitioned to a particular status.
66 67 68 |
# File 'lib/stripe/resources/v2/money_management/recipient_verification.rb', line 66 def status_transitions @status_transitions end |
Class Method Details
.field_remappings ⇒ Object
77 78 79 |
# File 'lib/stripe/resources/v2/money_management/recipient_verification.rb', line 77 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
70 71 72 73 74 75 |
# File 'lib/stripe/resources/v2/money_management/recipient_verification.rb', line 70 def self.inner_class_types @inner_class_types = { match_result_details: MatchResultDetails, status_transitions: StatusTransitions, } end |
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/v2/money_management/recipient_verification.rb', line 10 def self.object_name "v2.money_management.recipient_verification" end |