Class: Stripe::V2::MoneyManagement::RecipientVerificationService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::V2::MoneyManagement::RecipientVerificationService
- Defined in:
- lib/stripe/services/v2/money_management/recipient_verification_service.rb
Instance Method Summary collapse
-
#acknowledge(id, params = {}, opts = {}) ⇒ Object
Acknowledges an existing RecipientVerification.
-
#create(params = {}, opts = {}) ⇒ Object
Creates a RecipientVerification to verify the recipient you intend to send funds to.
-
#retrieve(id, params = {}, opts = {}) ⇒ Object
Retrieves the details of an existing RecipientVerification by passing the unique RecipientVerification ID.
Methods inherited from StripeService
#initialize, #request, #request_stream
Constructor Details
This class inherits a constructor from Stripe::StripeService
Instance Method Details
#acknowledge(id, params = {}, opts = {}) ⇒ Object
Acknowledges an existing RecipientVerification. Only RecipientVerification awaiting acknowledgement can be acknowledged.
9 10 11 12 13 14 15 16 17 |
# File 'lib/stripe/services/v2/money_management/recipient_verification_service.rb', line 9 def acknowledge(id, params = {}, opts = {}) request( method: :post, path: format("/v2/money_management/recipient_verifications/%<id>s/acknowledge", { id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |
#create(params = {}, opts = {}) ⇒ Object
Creates a RecipientVerification to verify the recipient you intend to send funds to.
20 21 22 23 24 25 26 27 28 |
# File 'lib/stripe/services/v2/money_management/recipient_verification_service.rb', line 20 def create(params = {}, opts = {}) request( method: :post, path: "/v2/money_management/recipient_verifications", params: params, opts: opts, base_address: :api ) end |
#retrieve(id, params = {}, opts = {}) ⇒ Object
Retrieves the details of an existing RecipientVerification by passing the unique RecipientVerification ID.
31 32 33 34 35 36 37 38 39 |
# File 'lib/stripe/services/v2/money_management/recipient_verification_service.rb', line 31 def retrieve(id, params = {}, opts = {}) request( method: :get, path: format("/v2/money_management/recipient_verifications/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |