Class: Stripe::V2::MoneyManagement::TestHelpers::FinancialAddressDebitParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::MoneyManagement::TestHelpers::FinancialAddressDebitParams
- Defined in:
- lib/stripe/params/v2/money_management/test_helpers/financial_address_debit_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
Object containing the amount value and currency to debit.
-
#network ⇒ Object
The network to use in simulating the funds flow.
-
#statement_descriptor ⇒ Object
String explaining funds flow.
Instance Method Summary collapse
-
#initialize(amount: nil, network: nil, statement_descriptor: nil) ⇒ FinancialAddressDebitParams
constructor
A new instance of FinancialAddressDebitParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, network: nil, statement_descriptor: nil) ⇒ FinancialAddressDebitParams
Returns a new instance of FinancialAddressDebitParams.
16 17 18 19 20 |
# File 'lib/stripe/params/v2/money_management/test_helpers/financial_address_debit_params.rb', line 16 def initialize(amount: nil, network: nil, statement_descriptor: nil) @amount = amount @network = network @statement_descriptor = statement_descriptor end |
Instance Attribute Details
#amount ⇒ Object
Object containing the amount value and currency to debit.
10 11 12 |
# File 'lib/stripe/params/v2/money_management/test_helpers/financial_address_debit_params.rb', line 10 def amount @amount end |
#network ⇒ Object
The network to use in simulating the funds flow. This will be reflected in the resulting ReceivedDebit.
12 13 14 |
# File 'lib/stripe/params/v2/money_management/test_helpers/financial_address_debit_params.rb', line 12 def network @network end |
#statement_descriptor ⇒ Object
String explaining funds flow. Use this field to populate the statement descriptor of the ReceivedDebit created as an eventual result of this simulation.
14 15 16 |
# File 'lib/stripe/params/v2/money_management/test_helpers/financial_address_debit_params.rb', line 14 def statement_descriptor @statement_descriptor end |