Class: Stripe::V2::MoneyManagement::Transaction::Flow

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/money_management/transaction.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#adjustmentObject (readonly)

If applicable, the ID of the Adjustment that created this Transaction.



46
47
48
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 46

def adjustment
  @adjustment
end

#application_feeObject (readonly)

If applicable, the ID of the Application Fee that created this Transaction.



48
49
50
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 48

def application_fee
  @application_fee
end

#application_fee_refundObject (readonly)

If applicable, the ID of the Application Fee Refund that created this Transaction.



50
51
52
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 50

def application_fee_refund
  @application_fee_refund
end

#chargeObject (readonly)

If applicable, the ID of the Charge that created this Transaction.



52
53
54
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 52

def charge
  @charge
end

#currency_conversionObject (readonly)

In the future, this will be the ID of the currency conversion that created this Transaction. For now, this field is always null.



54
55
56
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 54

def currency_conversion
  @currency_conversion
end

#disputeObject (readonly)

If applicable, the ID of the Dispute that created this Transaction.



56
57
58
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 56

def dispute
  @dispute
end

#fee_transactionObject (readonly)

If applicable, the ID of the FeeTransaction that created this Transaction.



58
59
60
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 58

def fee_transaction
  @fee_transaction
end

#inbound_transferObject (readonly)

If applicable, the ID of the InboundTransfer that created this Transaction.



60
61
62
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 60

def inbound_transfer
  @inbound_transfer
end

#outbound_paymentObject (readonly)

If applicable, the ID of the OutboundPayment that created this Transaction.



62
63
64
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 62

def outbound_payment
  @outbound_payment
end

#outbound_transferObject (readonly)

If applicable, the ID of the OutboundTransfer that created this Transaction.



64
65
66
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 64

def outbound_transfer
  @outbound_transfer
end

#payoutObject (readonly)

If applicable, the ID of the Payout that created this Transaction.



66
67
68
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 66

def payout
  @payout
end

#received_creditObject (readonly)

If applicable, the ID of the ReceivedCredit that created this Transaction.



68
69
70
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 68

def received_credit
  @received_credit
end

#received_debitObject (readonly)

If applicable, the ID of the ReceivedDebit that created this Transaction.



70
71
72
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 70

def received_debit
  @received_debit
end

#refundObject (readonly)

If applicable, the ID of the Refund that created this Transaction.



72
73
74
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 72

def refund
  @refund
end

#reserve_holdObject (readonly)

If applicable, the ID of the Reserve Hold that created this Transaction.



74
75
76
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 74

def reserve_hold
  @reserve_hold
end

#reserve_releaseObject (readonly)

If applicable, the ID of the Reserve Release that created this Transaction.



76
77
78
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 76

def reserve_release
  @reserve_release
end

#topupObject (readonly)

If applicable, the ID of the Topup that created this Transaction.



78
79
80
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 78

def topup
  @topup
end

#transferObject (readonly)

If applicable, the ID of the Transfer that created this Transaction.



80
81
82
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 80

def transfer
  @transfer
end

#transfer_reversalObject (readonly)

If applicable, the ID of the Transfer Reversal that created this Transaction.



82
83
84
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 82

def transfer_reversal
  @transfer_reversal
end

#treasury_credit_reversalObject (readonly)

If applicable, the ID of the Treasury CreditReversal that created this Transaction.



84
85
86
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 84

def treasury_credit_reversal
  @treasury_credit_reversal
end

#treasury_debit_reversalObject (readonly)

If applicable, the ID of the Treasury DebitReversal that created this Transaction.



86
87
88
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 86

def treasury_debit_reversal
  @treasury_debit_reversal
end

#treasury_inbound_transferObject (readonly)

If applicable, the ID of the Treasury InboundTransfer that created this Transaction.



88
89
90
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 88

def treasury_inbound_transfer
  @treasury_inbound_transfer
end

#treasury_issuing_authorizationObject (readonly)

If applicable, the ID of the Treasury IssuingAuthorization that created this Transaction.



90
91
92
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 90

def treasury_issuing_authorization
  @treasury_issuing_authorization
end

#treasury_outbound_paymentObject (readonly)

If applicable, the ID of the Treasury OutboundPayment that created this Transaction.



92
93
94
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 92

def treasury_outbound_payment
  @treasury_outbound_payment
end

#treasury_outbound_transferObject (readonly)

If applicable, the ID of the Treasury OutboundTransfer that created this Transaction.



94
95
96
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 94

def treasury_outbound_transfer
  @treasury_outbound_transfer
end

#treasury_received_creditObject (readonly)

If applicable, the ID of the Treasury ReceivedCredit that created this Transaction.



96
97
98
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 96

def treasury_received_credit
  @treasury_received_credit
end

#treasury_received_debitObject (readonly)

If applicable, the ID of the Treasury ReceivedDebit that created this Transaction.



98
99
100
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 98

def treasury_received_debit
  @treasury_received_debit
end

#typeObject (readonly)

Open Enum. Type of the flow that created the Transaction. The field matching this value will contain the ID of the flow.



100
101
102
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 100

def type
  @type
end

Class Method Details

.field_remappingsObject



106
107
108
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 106

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



102
103
104
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 102

def self.inner_class_types
  @inner_class_types = {}
end