Class: Stripe::V2::MoneyManagement::TransactionEntry

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/money_management/transaction_entry.rb

Overview

TransactionEntries represent individual money movements across different states within a Transaction.

Defined Under Namespace

Classes: BalanceImpact, TransactionDetails

Constant Summary collapse

OBJECT_NAME =
"v2.money_management.transaction_entry"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#balance_impactObject (readonly)

The delta to the FinancialAccount’s balance.



76
77
78
# File 'lib/stripe/resources/v2/money_management/transaction_entry.rb', line 76

def balance_impact
  @balance_impact
end

#createdObject (readonly)

Time at which the object was created.



78
79
80
# File 'lib/stripe/resources/v2/money_management/transaction_entry.rb', line 78

def created
  @created
end

#effective_atObject (readonly)

Time at which the entry impacted (or will impact if it’s in the future) the FinancialAccount balance.



80
81
82
# File 'lib/stripe/resources/v2/money_management/transaction_entry.rb', line 80

def effective_at
  @effective_at
end

#idObject (readonly)

Unique identifier for the object.



82
83
84
# File 'lib/stripe/resources/v2/money_management/transaction_entry.rb', line 82

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



84
85
86
# File 'lib/stripe/resources/v2/money_management/transaction_entry.rb', line 84

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



86
87
88
# File 'lib/stripe/resources/v2/money_management/transaction_entry.rb', line 86

def object
  @object
end

#transactionObject (readonly)

The Transaction that this TransactionEntry belongs to.



88
89
90
# File 'lib/stripe/resources/v2/money_management/transaction_entry.rb', line 88

def transaction
  @transaction
end

#transaction_detailsObject (readonly)

Details copied from the transaction that this TransactionEntry belongs to.



90
91
92
# File 'lib/stripe/resources/v2/money_management/transaction_entry.rb', line 90

def transaction_details
  @transaction_details
end

Class Method Details

.field_remappingsObject



99
100
101
# File 'lib/stripe/resources/v2/money_management/transaction_entry.rb', line 99

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



92
93
94
95
96
97
# File 'lib/stripe/resources/v2/money_management/transaction_entry.rb', line 92

def self.inner_class_types
  @inner_class_types = {
    balance_impact: BalanceImpact,
    transaction_details: TransactionDetails,
  }
end

.object_nameObject



10
11
12
# File 'lib/stripe/resources/v2/money_management/transaction_entry.rb', line 10

def self.object_name
  "v2.money_management.transaction_entry"
end