Class: Stripe::V2::MoneyManagement::TransactionEntryListParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/money_management/transaction_entry_list_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(created: nil, created_gt: nil, created_gte: nil, created_lt: nil, created_lte: nil, limit: nil, transaction: nil) ⇒ TransactionEntryListParams

Returns a new instance of TransactionEntryListParams.



23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
# File 'lib/stripe/params/v2/money_management/transaction_entry_list_params.rb', line 23

def initialize(
  created: nil,
  created_gt: nil,
  created_gte: nil,
  created_lt: nil,
  created_lte: nil,
  limit: nil,
  transaction: nil
)
  @created = created
  @created_gt = created_gt
  @created_gte = created_gte
  @created_lt = created_lt
  @created_lte = created_lte
  @limit = limit
  @transaction = transaction
end

Instance Attribute Details

#createdObject

Filter for Transactions created at an exact time.



9
10
11
# File 'lib/stripe/params/v2/money_management/transaction_entry_list_params.rb', line 9

def created
  @created
end

#created_gtObject

Filter for Transactions created after the specified timestamp.



11
12
13
# File 'lib/stripe/params/v2/money_management/transaction_entry_list_params.rb', line 11

def created_gt
  @created_gt
end

#created_gteObject

Filter for Transactions created at or after the specified timestamp.



13
14
15
# File 'lib/stripe/params/v2/money_management/transaction_entry_list_params.rb', line 13

def created_gte
  @created_gte
end

#created_ltObject

Filter for Transactions created before the specified timestamp.



15
16
17
# File 'lib/stripe/params/v2/money_management/transaction_entry_list_params.rb', line 15

def created_lt
  @created_lt
end

#created_lteObject

Filter for Transactions created at or before the specified timestamp.



17
18
19
# File 'lib/stripe/params/v2/money_management/transaction_entry_list_params.rb', line 17

def created_lte
  @created_lte
end

#limitObject

The page limit.



19
20
21
# File 'lib/stripe/params/v2/money_management/transaction_entry_list_params.rb', line 19

def limit
  @limit
end

#transactionObject

Filter for TransactionEntries belonging to a Transaction.



21
22
23
# File 'lib/stripe/params/v2/money_management/transaction_entry_list_params.rb', line 21

def transaction
  @transaction
end