Class: Stripe::V2::MoneyManagement::TransactionEntryService::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::MoneyManagement::TransactionEntryService::ListParams
- Defined in:
- lib/stripe/services/v2/money_management/transaction_entry_service.rb
Instance Attribute Summary collapse
-
#created ⇒ Object
Filter for Transactions created at an exact time.
-
#created_gt ⇒ Object
Filter for Transactions created after the specified timestamp.
-
#created_gte ⇒ Object
Filter for Transactions created at or after the specified timestamp.
-
#created_lt ⇒ Object
Filter for Transactions created before the specified timestamp.
-
#created_lte ⇒ Object
Filter for Transactions created at or before the specified timestamp.
-
#limit ⇒ Object
The page limit.
-
#transaction ⇒ Object
Filter for TransactionEntries belonging to a Transaction.
Instance Method Summary collapse
-
#initialize(created: nil, created_gt: nil, created_gte: nil, created_lt: nil, created_lte: nil, limit: nil, transaction: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(created: nil, created_gt: nil, created_gte: nil, created_lt: nil, created_lte: nil, limit: nil, transaction: nil) ⇒ ListParams
Returns a new instance of ListParams.
24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 |
# File 'lib/stripe/services/v2/money_management/transaction_entry_service.rb', line 24 def initialize( created: nil, created_gt: nil, created_gte: nil, created_lt: nil, created_lte: nil, limit: nil, transaction: nil ) @created = created @created_gt = created_gt @created_gte = created_gte @created_lt = created_lt @created_lte = created_lte @limit = limit @transaction = transaction end |
Instance Attribute Details
#created ⇒ Object
Filter for Transactions created at an exact time.
10 11 12 |
# File 'lib/stripe/services/v2/money_management/transaction_entry_service.rb', line 10 def created @created end |
#created_gt ⇒ Object
Filter for Transactions created after the specified timestamp.
12 13 14 |
# File 'lib/stripe/services/v2/money_management/transaction_entry_service.rb', line 12 def created_gt @created_gt end |
#created_gte ⇒ Object
Filter for Transactions created at or after the specified timestamp.
14 15 16 |
# File 'lib/stripe/services/v2/money_management/transaction_entry_service.rb', line 14 def created_gte @created_gte end |
#created_lt ⇒ Object
Filter for Transactions created before the specified timestamp.
16 17 18 |
# File 'lib/stripe/services/v2/money_management/transaction_entry_service.rb', line 16 def created_lt @created_lt end |
#created_lte ⇒ Object
Filter for Transactions created at or before the specified timestamp.
18 19 20 |
# File 'lib/stripe/services/v2/money_management/transaction_entry_service.rb', line 18 def created_lte @created_lte end |
#limit ⇒ Object
The page limit.
20 21 22 |
# File 'lib/stripe/services/v2/money_management/transaction_entry_service.rb', line 20 def limit @limit end |
#transaction ⇒ Object
Filter for TransactionEntries belonging to a Transaction.
22 23 24 |
# File 'lib/stripe/services/v2/money_management/transaction_entry_service.rb', line 22 def transaction @transaction end |