Class: Stripe::V2::MoneyManagement::TransactionListParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/money_management/transaction_list_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(created: nil, created_gt: nil, created_gte: nil, created_lt: nil, created_lte: nil, financial_account: nil, flow: nil, limit: nil) ⇒ TransactionListParams

Returns a new instance of TransactionListParams.



25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
# File 'lib/stripe/params/v2/money_management/transaction_list_params.rb', line 25

def initialize(
  created: nil,
  created_gt: nil,
  created_gte: nil,
  created_lt: nil,
  created_lte: nil,
  financial_account: nil,
  flow: nil,
  limit: nil
)
  @created = created
  @created_gt = created_gt
  @created_gte = created_gte
  @created_lt = created_lt
  @created_lte = created_lte
  @financial_account = 
  @flow = flow
  @limit = limit
end

Instance Attribute Details

#createdObject

Filter for Transactions created at an exact time.



9
10
11
# File 'lib/stripe/params/v2/money_management/transaction_list_params.rb', line 9

def created
  @created
end

#created_gtObject

Filter for Transactions created after the specified timestamp.



11
12
13
# File 'lib/stripe/params/v2/money_management/transaction_list_params.rb', line 11

def created_gt
  @created_gt
end

#created_gteObject

Filter for Transactions created at or after the specified timestamp.



13
14
15
# File 'lib/stripe/params/v2/money_management/transaction_list_params.rb', line 13

def created_gte
  @created_gte
end

#created_ltObject

Filter for Transactions created before the specified timestamp.



15
16
17
# File 'lib/stripe/params/v2/money_management/transaction_list_params.rb', line 15

def created_lt
  @created_lt
end

#created_lteObject

Filter for Transactions created at or before the specified timestamp.



17
18
19
# File 'lib/stripe/params/v2/money_management/transaction_list_params.rb', line 17

def created_lte
  @created_lte
end

#financial_accountObject

Filter for Transactions belonging to a FinancialAccount.



19
20
21
# File 'lib/stripe/params/v2/money_management/transaction_list_params.rb', line 19

def 
  @financial_account
end

#flowObject

Filter for Transactions corresponding to a Flow.



21
22
23
# File 'lib/stripe/params/v2/money_management/transaction_list_params.rb', line 21

def flow
  @flow
end

#limitObject

The page limit.



23
24
25
# File 'lib/stripe/params/v2/money_management/transaction_list_params.rb', line 23

def limit
  @limit
end