Class: Stripe::V2::MoneyManagement::TransactionService::ListParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/money_management/transaction_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(created: nil, created_gt: nil, created_gte: nil, created_lt: nil, created_lte: nil, financial_account: nil, flow: nil, limit: nil) ⇒ ListParams

Returns a new instance of ListParams.



26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
# File 'lib/stripe/services/v2/money_management/transaction_service.rb', line 26

def initialize(
  created: nil,
  created_gt: nil,
  created_gte: nil,
  created_lt: nil,
  created_lte: nil,
  financial_account: nil,
  flow: nil,
  limit: nil
)
  @created = created
  @created_gt = created_gt
  @created_gte = created_gte
  @created_lt = created_lt
  @created_lte = created_lte
  @financial_account = 
  @flow = flow
  @limit = limit
end

Instance Attribute Details

#createdObject

Filter for Transactions created at an exact time.



10
11
12
# File 'lib/stripe/services/v2/money_management/transaction_service.rb', line 10

def created
  @created
end

#created_gtObject

Filter for Transactions created after the specified timestamp.



12
13
14
# File 'lib/stripe/services/v2/money_management/transaction_service.rb', line 12

def created_gt
  @created_gt
end

#created_gteObject

Filter for Transactions created at or after the specified timestamp.



14
15
16
# File 'lib/stripe/services/v2/money_management/transaction_service.rb', line 14

def created_gte
  @created_gte
end

#created_ltObject

Filter for Transactions created before the specified timestamp.



16
17
18
# File 'lib/stripe/services/v2/money_management/transaction_service.rb', line 16

def created_lt
  @created_lt
end

#created_lteObject

Filter for Transactions created at or before the specified timestamp.



18
19
20
# File 'lib/stripe/services/v2/money_management/transaction_service.rb', line 18

def created_lte
  @created_lte
end

#financial_accountObject

Filter for Transactions belonging to a FinancialAccount.



20
21
22
# File 'lib/stripe/services/v2/money_management/transaction_service.rb', line 20

def 
  @financial_account
end

#flowObject

Filter for Transactions corresponding to a Flow.



22
23
24
# File 'lib/stripe/services/v2/money_management/transaction_service.rb', line 22

def flow
  @flow
end

#limitObject

The page limit.



24
25
26
# File 'lib/stripe/services/v2/money_management/transaction_service.rb', line 24

def limit
  @limit
end