Class: Stripe::V2::Network::BusinessProfile::Branding

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/network/business_profile.rb

Defined Under Namespace

Classes: Icon, Logo

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#iconObject (readonly)

URL of the icon for the business. The image will be square and at least 128px x 128px.



41
42
43
# File 'lib/stripe/resources/v2/network/business_profile.rb', line 41

def icon
  @icon
end

#logoObject (readonly)

URL of the logo for the business. The image will be at least 128px x 128px.



43
44
45
# File 'lib/stripe/resources/v2/network/business_profile.rb', line 43

def 
  @logo
end

#primary_colorObject (readonly)

A CSS hex color value representing the primary branding color for this business.



45
46
47
# File 'lib/stripe/resources/v2/network/business_profile.rb', line 45

def primary_color
  @primary_color
end

#secondary_colorObject (readonly)

A CSS hex color value representing the secondary branding color for this business.



47
48
49
# File 'lib/stripe/resources/v2/network/business_profile.rb', line 47

def secondary_color
  @secondary_color
end

Class Method Details

.field_remappingsObject



53
54
55
# File 'lib/stripe/resources/v2/network/business_profile.rb', line 53

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



49
50
51
# File 'lib/stripe/resources/v2/network/business_profile.rb', line 49

def self.inner_class_types
  @inner_class_types = { icon: Icon, logo: Logo }
end