Class: Stripe::V2::Network::BusinessProfileService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::V2::Network::BusinessProfileService
- Defined in:
- lib/stripe/services/v2/network/business_profile_service.rb
Instance Method Summary collapse
-
#me(params = {}, opts = {}) ⇒ Object
Retrieve the Stripe profile associated with the requesting merchant and livemode.
-
#retrieve(id, params = {}, opts = {}) ⇒ Object
Retrieve a Stripe profile by its Network ID.
Methods inherited from StripeService
#initialize, #request, #request_stream
Constructor Details
This class inherits a constructor from Stripe::StripeService
Instance Method Details
#me(params = {}, opts = {}) ⇒ Object
Retrieve the Stripe profile associated with the requesting merchant and livemode.
9 10 11 12 13 14 15 16 17 |
# File 'lib/stripe/services/v2/network/business_profile_service.rb', line 9 def me(params = {}, opts = {}) request( method: :get, path: "/v2/network/business_profiles/me", params: params, opts: opts, base_address: :api ) end |
#retrieve(id, params = {}, opts = {}) ⇒ Object
Retrieve a Stripe profile by its Network ID.
20 21 22 23 24 25 26 27 28 |
# File 'lib/stripe/services/v2/network/business_profile_service.rb', line 20 def retrieve(id, params = {}, opts = {}) request( method: :get, path: format("/v2/network/business_profiles/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |