Class: Stripe::V2::OrchestratedCommerce::Agreement

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/orchestrated_commerce/agreement.rb

Overview

An Orchestrated Commerce Agreement represents a mutual agreement between a seller and an orchestrator/agent on the Stripe network.

Defined Under Namespace

Classes: OrchestratorDetails, SellerDetails, StatusTransitions

Constant Summary collapse

OBJECT_NAME =
"v2.orchestrated_commerce.agreement"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#createdObject (readonly)

The time at which the agreement was created.



59
60
61
# File 'lib/stripe/resources/v2/orchestrated_commerce/agreement.rb', line 59

def created
  @created
end

#idObject (readonly)

The unique identifier for the agreement.



61
62
63
# File 'lib/stripe/resources/v2/orchestrated_commerce/agreement.rb', line 61

def id
  @id
end

#initiated_byObject (readonly)

The party that initiated the agreement.



63
64
65
# File 'lib/stripe/resources/v2/orchestrated_commerce/agreement.rb', line 63

def initiated_by
  @initiated_by
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



65
66
67
# File 'lib/stripe/resources/v2/orchestrated_commerce/agreement.rb', line 65

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



67
68
69
# File 'lib/stripe/resources/v2/orchestrated_commerce/agreement.rb', line 67

def object
  @object
end

#orchestrator_detailsObject (readonly)

Details about the orchestrator.



69
70
71
# File 'lib/stripe/resources/v2/orchestrated_commerce/agreement.rb', line 69

def orchestrator_details
  @orchestrator_details
end

#seller_detailsObject (readonly)

Details about the seller.



71
72
73
# File 'lib/stripe/resources/v2/orchestrated_commerce/agreement.rb', line 71

def seller_details
  @seller_details
end

#statusObject (readonly)

The current status of the agreement.



73
74
75
# File 'lib/stripe/resources/v2/orchestrated_commerce/agreement.rb', line 73

def status
  @status
end

#status_transitionsObject (readonly)

Timestamps of key status transitions for the agreement.



75
76
77
# File 'lib/stripe/resources/v2/orchestrated_commerce/agreement.rb', line 75

def status_transitions
  @status_transitions
end

#terminated_byObject (readonly)

The party that terminated the agreement, if applicable.



77
78
79
# File 'lib/stripe/resources/v2/orchestrated_commerce/agreement.rb', line 77

def terminated_by
  @terminated_by
end

Class Method Details

.field_remappingsObject



87
88
89
# File 'lib/stripe/resources/v2/orchestrated_commerce/agreement.rb', line 87

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



79
80
81
82
83
84
85
# File 'lib/stripe/resources/v2/orchestrated_commerce/agreement.rb', line 79

def self.inner_class_types
  @inner_class_types = {
    orchestrator_details: OrchestratorDetails,
    seller_details: SellerDetails,
    status_transitions: StatusTransitions,
  }
end

.object_nameObject



10
11
12
# File 'lib/stripe/resources/v2/orchestrated_commerce/agreement.rb', line 10

def self.object_name
  "v2.orchestrated_commerce.agreement"
end