Class: Stripe::V2::OrchestratedCommerce::Agreement::StatusTransitions
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::OrchestratedCommerce::Agreement::StatusTransitions
- Defined in:
- lib/stripe/resources/v2/orchestrated_commerce/agreement.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#orchestrator_confirmed_at ⇒ Object
readonly
The time at which the orchestrator confirmed the agreement.
-
#seller_confirmed_at ⇒ Object
readonly
The time at which the seller confirmed the agreement.
-
#terminated_at ⇒ Object
readonly
The time at which the agreement was terminated.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#orchestrator_confirmed_at ⇒ Object (readonly)
The time at which the orchestrator confirmed the agreement.
44 45 46 |
# File 'lib/stripe/resources/v2/orchestrated_commerce/agreement.rb', line 44 def orchestrator_confirmed_at @orchestrator_confirmed_at end |
#seller_confirmed_at ⇒ Object (readonly)
The time at which the seller confirmed the agreement.
46 47 48 |
# File 'lib/stripe/resources/v2/orchestrated_commerce/agreement.rb', line 46 def seller_confirmed_at @seller_confirmed_at end |
#terminated_at ⇒ Object (readonly)
The time at which the agreement was terminated.
48 49 50 |
# File 'lib/stripe/resources/v2/orchestrated_commerce/agreement.rb', line 48 def terminated_at @terminated_at end |
Class Method Details
.field_remappings ⇒ Object
54 55 56 |
# File 'lib/stripe/resources/v2/orchestrated_commerce/agreement.rb', line 54 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
50 51 52 |
# File 'lib/stripe/resources/v2/orchestrated_commerce/agreement.rb', line 50 def self.inner_class_types @inner_class_types = {} end |