Class: Stripe::V2::OrchestratedCommerce::AgreementCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::OrchestratedCommerce::AgreementCreateParams
- Defined in:
- lib/stripe/params/v2/orchestrated_commerce/agreement_create_params.rb
Instance Attribute Summary collapse
-
#orchestrator ⇒ Object
The Network ID of the orchestrator to create an agreement with.
Instance Method Summary collapse
-
#initialize(orchestrator: nil) ⇒ AgreementCreateParams
constructor
A new instance of AgreementCreateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(orchestrator: nil) ⇒ AgreementCreateParams
Returns a new instance of AgreementCreateParams.
11 12 13 |
# File 'lib/stripe/params/v2/orchestrated_commerce/agreement_create_params.rb', line 11 def initialize(orchestrator: nil) @orchestrator = orchestrator end |
Instance Attribute Details
#orchestrator ⇒ Object
The Network ID of the orchestrator to create an agreement with.
9 10 11 |
# File 'lib/stripe/params/v2/orchestrated_commerce/agreement_create_params.rb', line 9 def orchestrator @orchestrator end |