Class: Stripe::V2::OrchestratedCommerce::AgreementService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::V2::OrchestratedCommerce::AgreementService
- Defined in:
- lib/stripe/services/v2/orchestrated_commerce/agreement_service.rb
Instance Method Summary collapse
-
#confirm(id, params = {}, opts = {}) ⇒ Object
Confirm an Agreement.
-
#create(params = {}, opts = {}) ⇒ Object
Create a new Agreement.
-
#list(params = {}, opts = {}) ⇒ Object
List Agreements for the profile associated with the authenticated merchant.
-
#retrieve(id, params = {}, opts = {}) ⇒ Object
Retrieve an Agreement by ID.
-
#terminate(id, params = {}, opts = {}) ⇒ Object
Terminate an Agreement.
Methods inherited from StripeService
#initialize, #request, #request_stream
Constructor Details
This class inherits a constructor from Stripe::StripeService
Instance Method Details
#confirm(id, params = {}, opts = {}) ⇒ Object
Confirm an Agreement.
9 10 11 12 13 14 15 16 17 |
# File 'lib/stripe/services/v2/orchestrated_commerce/agreement_service.rb', line 9 def confirm(id, params = {}, opts = {}) request( method: :post, path: format("/v2/orchestrated_commerce/agreements/%<id>s/confirm", { id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |
#create(params = {}, opts = {}) ⇒ Object
Create a new Agreement.
20 21 22 23 24 25 26 27 28 |
# File 'lib/stripe/services/v2/orchestrated_commerce/agreement_service.rb', line 20 def create(params = {}, opts = {}) request( method: :post, path: "/v2/orchestrated_commerce/agreements", params: params, opts: opts, base_address: :api ) end |
#list(params = {}, opts = {}) ⇒ Object
List Agreements for the profile associated with the authenticated merchant.
31 32 33 34 35 36 37 38 39 |
# File 'lib/stripe/services/v2/orchestrated_commerce/agreement_service.rb', line 31 def list(params = {}, opts = {}) request( method: :get, path: "/v2/orchestrated_commerce/agreements", params: params, opts: opts, base_address: :api ) end |
#retrieve(id, params = {}, opts = {}) ⇒ Object
Retrieve an Agreement by ID.
42 43 44 45 46 47 48 49 50 |
# File 'lib/stripe/services/v2/orchestrated_commerce/agreement_service.rb', line 42 def retrieve(id, params = {}, opts = {}) request( method: :get, path: format("/v2/orchestrated_commerce/agreements/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |
#terminate(id, params = {}, opts = {}) ⇒ Object
Terminate an Agreement.
53 54 55 56 57 58 59 60 61 |
# File 'lib/stripe/services/v2/orchestrated_commerce/agreement_service.rb', line 53 def terminate(id, params = {}, opts = {}) request( method: :post, path: format("/v2/orchestrated_commerce/agreements/%<id>s/terminate", { id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |