Class: Stripe::V2::Payments::OffSessionPayment::RetryDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Payments::OffSessionPayment::RetryDetails
- Defined in:
- lib/stripe/resources/v2/payments/off_session_payment.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#attempts ⇒ Object
readonly
Number of authorization attempts so far.
-
#retry_policy ⇒ Object
readonly
The pre-configured retry policy to use for the payment.
-
#retry_strategy ⇒ Object
readonly
Indicates the strategy for how you want Stripe to retry the payment.
-
#retry_until ⇒ Object
readonly
The timestamp when this payment is no longer eligible to be retried.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#attempts ⇒ Object (readonly)
Number of authorization attempts so far.
168 169 170 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 168 def attempts @attempts end |
#retry_policy ⇒ Object (readonly)
The pre-configured retry policy to use for the payment.
170 171 172 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 170 def retry_policy @retry_policy end |
#retry_strategy ⇒ Object (readonly)
Indicates the strategy for how you want Stripe to retry the payment.
172 173 174 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 172 def retry_strategy @retry_strategy end |
#retry_until ⇒ Object (readonly)
The timestamp when this payment is no longer eligible to be retried. When this timestamp is reached, the payment will be marked as failed.
174 175 176 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 174 def retry_until @retry_until end |
Class Method Details
.field_remappings ⇒ Object
180 181 182 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 180 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
176 177 178 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 176 def self.inner_class_types @inner_class_types = {} end |