Class: Stripe::V2::Payments::OffSessionPaymentCaptureParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/payments/off_session_payment_capture_params.rb

Defined Under Namespace

Classes: AmountDetails, PaymentDetails, TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount_details: nil, amount_to_capture: nil, application_fee_amount: nil, metadata: nil, payment_details: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil) ⇒ OffSessionPaymentCaptureParams

Returns a new instance of OffSessionPaymentCaptureParams.



156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'lib/stripe/params/v2/payments/off_session_payment_capture_params.rb', line 156

def initialize(
  amount_details: nil,
  amount_to_capture: nil,
  application_fee_amount: nil,
  metadata: nil,
  payment_details: nil,
  statement_descriptor: nil,
  statement_descriptor_suffix: nil,
  transfer_data: nil
)
  @amount_details = amount_details
  @amount_to_capture = amount_to_capture
  @application_fee_amount = application_fee_amount
  @metadata = 
  @payment_details = payment_details
  @statement_descriptor = statement_descriptor
  @statement_descriptor_suffix = statement_descriptor_suffix
  @transfer_data = transfer_data
end

Instance Attribute Details

#amount_detailsObject

Provides industry-specific information about the amount.



132
133
134
# File 'lib/stripe/params/v2/payments/off_session_payment_capture_params.rb', line 132

def amount_details
  @amount_details
end

#amount_to_captureObject

The amount to capture.



134
135
136
# File 'lib/stripe/params/v2/payments/off_session_payment_capture_params.rb', line 134

def amount_to_capture
  @amount_to_capture
end

#application_fee_amountObject

The amount of the application fee for this capture.



136
137
138
# File 'lib/stripe/params/v2/payments/off_session_payment_capture_params.rb', line 136

def application_fee_amount
  @application_fee_amount
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Learn more about [storing information in metadata](docs.stripe.com/payments/payment-intents#storing-information-in-metadata).



141
142
143
# File 'lib/stripe/params/v2/payments/off_session_payment_capture_params.rb', line 141

def 
  @metadata
end

#payment_detailsObject

Provides industry-specific information about the payment.



143
144
145
# File 'lib/stripe/params/v2/payments/off_session_payment_capture_params.rb', line 143

def payment_details
  @payment_details
end

#statement_descriptorObject

Text that appears on the customer’s statement as the statement descriptor for a non-card charge. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see the [Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).



148
149
150
# File 'lib/stripe/params/v2/payments/off_session_payment_capture_params.rb', line 148

def statement_descriptor
  @statement_descriptor
end

#statement_descriptor_suffixObject

Provides information about a card charge. Concatenated to the account’s [statement descriptor prefix](docs.stripe.com/get-started/account/statement-descriptors#static) to form the complete statement descriptor that appears on the customer’s statement.



152
153
154
# File 'lib/stripe/params/v2/payments/off_session_payment_capture_params.rb', line 152

def statement_descriptor_suffix
  @statement_descriptor_suffix
end

#transfer_dataObject

The data that automatically creates a Transfer after the payment finalizes. Learn more about the use case for [connected accounts](docs.stripe.com/payments/connected-accounts).



154
155
156
# File 'lib/stripe/params/v2/payments/off_session_payment_capture_params.rb', line 154

def transfer_data
  @transfer_data
end