Class: Stripe::V2::Payments::OffSessionPaymentCaptureParams::PaymentDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/payments/off_session_payment_capture_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(customer_reference: nil, order_reference: nil) ⇒ PaymentDetails

Returns a new instance of PaymentDetails.



111
112
113
114
# File 'lib/stripe/params/v2/payments/off_session_payment_capture_params.rb', line 111

def initialize(customer_reference: nil, order_reference: nil)
  @customer_reference = customer_reference
  @order_reference = order_reference
end

Instance Attribute Details

#customer_referenceObject

A unique value to identify the customer. This field is applicable only for card payments. For card payments, this field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks.



106
107
108
# File 'lib/stripe/params/v2/payments/off_session_payment_capture_params.rb', line 106

def customer_reference
  @customer_reference
end

#order_referenceObject

A unique value assigned by the business to identify the transaction. Required for L2 and L3 rates. For Cards, this field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks.



109
110
111
# File 'lib/stripe/params/v2/payments/off_session_payment_capture_params.rb', line 109

def order_reference
  @order_reference
end