Class: Stripe::V2::Payments::OffSessionPaymentCaptureParams::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/payments/off_session_payment_capture_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil) ⇒ TransferData

Returns a new instance of TransferData.



127
128
129
# File 'lib/stripe/params/v2/payments/off_session_payment_capture_params.rb', line 127

def initialize(amount: nil)
  @amount = amount
end

Instance Attribute Details

#amountObject

The amount transferred to the destination account. This transfer will occur automatically after the payment succeeds. If no amount is specified, by default the entire payment amount is transferred to the destination account. The amount must be less than or equal to the [amount_requested](docs.stripe.com/api/v2/off-session-payments/object?api-version=2025-05-28.preview#v2_off_session_payment_object-amount_requested), and must be a positive integer representing how much to transfer in the smallest currency unit (e.g., 100 cents to charge $1.00).



125
126
127
# File 'lib/stripe/params/v2/payments/off_session_payment_capture_params.rb', line 125

def amount
  @amount
end