Class: Stripe::V2::Payments::OffSessionPaymentCreateParams::AmountDetails::LineItem::Tax
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Payments::OffSessionPaymentCreateParams::AmountDetails::LineItem::Tax
- Defined in:
- lib/stripe/params/v2/payments/off_session_payment_create_params.rb
Instance Attribute Summary collapse
-
#total_tax_amount ⇒ Object
Total portion of the amount that is for tax.
Instance Method Summary collapse
-
#initialize(total_tax_amount: nil) ⇒ Tax
constructor
A new instance of Tax.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(total_tax_amount: nil) ⇒ Tax
Returns a new instance of Tax.
14 15 16 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 14 def initialize(total_tax_amount: nil) @total_tax_amount = total_tax_amount end |
Instance Attribute Details
#total_tax_amount ⇒ Object
Total portion of the amount that is for tax.
12 13 14 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 12 def total_tax_amount @total_tax_amount end |