Class: Stripe::V2::Payments::OffSessionPaymentCreateParams::PaymentMethodData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Payments::OffSessionPaymentCreateParams::PaymentMethodData
- Defined in:
- lib/stripe/params/v2/payments/off_session_payment_create_params.rb
Defined Under Namespace
Classes: BillingDetails, Card
Instance Attribute Summary collapse
-
#billing_details ⇒ Object
Billing information associated with the payment method.
-
#card ⇒ Object
Contains card details that can be used to create a card PaymentMethod for PCI compliant users.
-
#type ⇒ Object
The type of the PaymentMethod.
Instance Method Summary collapse
-
#initialize(billing_details: nil, card: nil, type: nil) ⇒ PaymentMethodData
constructor
A new instance of PaymentMethodData.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(billing_details: nil, card: nil, type: nil) ⇒ PaymentMethodData
Returns a new instance of PaymentMethodData.
199 200 201 202 203 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 199 def initialize(billing_details: nil, card: nil, type: nil) @billing_details = billing_details @card = card @type = type end |
Instance Attribute Details
#billing_details ⇒ Object
Billing information associated with the payment method.
193 194 195 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 193 def billing_details @billing_details end |
#card ⇒ Object
Contains card details that can be used to create a card PaymentMethod for PCI compliant users.
195 196 197 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 195 def card @card end |
#type ⇒ Object
The type of the PaymentMethod. An additional hash is included on the PaymentMethod with a name matching this value. It contains additional information specific to the PaymentMethod type.
197 198 199 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 197 def type @type end |