Class: Stripe::V2::Payments::OffSessionPaymentCreateParams::PaymentsOrchestration
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Payments::OffSessionPaymentCreateParams::PaymentsOrchestration
- Defined in:
- lib/stripe/params/v2/payments/off_session_payment_create_params.rb
Instance Attribute Summary collapse
-
#enabled ⇒ Object
True when you want to enable payments orchestration for this off-session payment.
Instance Method Summary collapse
-
#initialize(enabled: nil) ⇒ PaymentsOrchestration
constructor
A new instance of PaymentsOrchestration.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(enabled: nil) ⇒ PaymentsOrchestration
Returns a new instance of PaymentsOrchestration.
235 236 237 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 235 def initialize(enabled: nil) @enabled = enabled end |
Instance Attribute Details
#enabled ⇒ Object
True when you want to enable payments orchestration for this off-session payment. False otherwise.
233 234 235 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 233 def enabled @enabled end |