Class: Stripe::V2::Payments::OffSessionPaymentCreateParams::RetryDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Payments::OffSessionPaymentCreateParams::RetryDetails
- Defined in:
- lib/stripe/params/v2/payments/off_session_payment_create_params.rb
Instance Attribute Summary collapse
-
#retry_policy ⇒ Object
The pre-configured retry policy to use for the payment.
-
#retry_strategy ⇒ Object
Indicates the strategy for how you want Stripe to retry the payment.
Instance Method Summary collapse
-
#initialize(retry_policy: nil, retry_strategy: nil) ⇒ RetryDetails
constructor
A new instance of RetryDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(retry_policy: nil, retry_strategy: nil) ⇒ RetryDetails
Returns a new instance of RetryDetails.
134 135 136 137 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 134 def initialize(retry_policy: nil, retry_strategy: nil) @retry_policy = retry_policy @retry_strategy = retry_strategy end |
Instance Attribute Details
#retry_policy ⇒ Object
The pre-configured retry policy to use for the payment.
130 131 132 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 130 def retry_policy @retry_policy end |
#retry_strategy ⇒ Object
Indicates the strategy for how you want Stripe to retry the payment.
132 133 134 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 132 def retry_strategy @retry_strategy end |