Class: Stripe::V2::Payments::OffSessionPaymentService::CreateParams::RetryDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Payments::OffSessionPaymentService::CreateParams::RetryDetails
- Defined in:
- lib/stripe/services/v2/payments/off_session_payment_service.rb
Instance Attribute Summary collapse
-
#retry_strategy ⇒ Object
Indicates the strategy for how you want Stripe to retry the payment.
Instance Method Summary collapse
-
#initialize(retry_strategy: nil) ⇒ RetryDetails
constructor
A new instance of RetryDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(retry_strategy: nil) ⇒ RetryDetails
Returns a new instance of RetryDetails.
22 23 24 |
# File 'lib/stripe/services/v2/payments/off_session_payment_service.rb', line 22 def initialize(retry_strategy: nil) @retry_strategy = retry_strategy end |
Instance Attribute Details
#retry_strategy ⇒ Object
Indicates the strategy for how you want Stripe to retry the payment.
20 21 22 |
# File 'lib/stripe/services/v2/payments/off_session_payment_service.rb', line 20 def retry_strategy @retry_strategy end |