Class: Stripe::V2::Payments::OffSessionPaymentService::CreateParams::TransferData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Payments::OffSessionPaymentService::CreateParams::TransferData
- Defined in:
- lib/stripe/services/v2/payments/off_session_payment_service.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount transferred to the destination account.
-
#destination ⇒ Object
The account (if any) that the payment is attributed to for tax reporting, and where funds from the payment are transferred to after payment success.
Instance Method Summary collapse
-
#initialize(amount: nil, destination: nil) ⇒ TransferData
constructor
A new instance of TransferData.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, destination: nil) ⇒ TransferData
Returns a new instance of TransferData.
40 41 42 43 |
# File 'lib/stripe/services/v2/payments/off_session_payment_service.rb', line 40 def initialize(amount: nil, destination: nil) @amount = amount @destination = destination end |
Instance Attribute Details
#amount ⇒ Object
The amount transferred to the destination account. This transfer will occur automatically after the payment succeeds. If no amount is specified, by default the entire payment amount is transferred to the destination account. The amount must be less than or equal to the [amount_requested](docs.corp.stripe.com/api/v2/off-session-payments/object?api-version=2025-05-28.preview#v2_off_session_payment_object-amount_requested), and must be a positive integer representing how much to transfer in the smallest currency unit (e.g., 100 cents to charge $1.00).
35 36 37 |
# File 'lib/stripe/services/v2/payments/off_session_payment_service.rb', line 35 def amount @amount end |
#destination ⇒ Object
The account (if any) that the payment is attributed to for tax reporting, and where funds from the payment are transferred to after payment success.
38 39 40 |
# File 'lib/stripe/services/v2/payments/off_session_payment_service.rb', line 38 def destination @destination end |