Class: Stripe::V2::Payments::SettlementAllocationIntent
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Payments::SettlementAllocationIntent
- Defined in:
- lib/stripe/resources/v2/payments/settlement_allocation_intent.rb
Overview
SettlementAllocationIntent resource.
Defined Under Namespace
Classes: StatusDetails
Constant Summary collapse
- OBJECT_NAME =
"v2.payments.settlement_allocation_intent"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The amount and currency of the SettlementAllocationIntent.
-
#created ⇒ Object
readonly
Timestamp at which SettlementAllocationIntent was created .
-
#expected_settlement_date ⇒ Object
readonly
Date when we expect to receive the funds.
-
#financial_account ⇒ Object
readonly
FinancialAccount ID where the funds are expected.
-
#id ⇒ Object
readonly
Unique identifier for the SettlementAllocationIntent.
-
#linked_credits ⇒ Object
readonly
List of ReceivedCredits that matched with the SettlementAllocationIntent.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#metadata ⇒ Object
readonly
Metadata associated with the SettlementAllocationIntent.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#reference ⇒ Object
readonly
Reference for the SettlementAllocationIntent.
-
#status ⇒ Object
readonly
SettlementAllocationIntent status.
-
#status_details ⇒ Object
readonly
Status details for a SettlementAllocationIntent in ‘errored` state.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The amount and currency of the SettlementAllocationIntent.
43 44 45 |
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent.rb', line 43 def amount @amount end |
#created ⇒ Object (readonly)
Timestamp at which SettlementAllocationIntent was created .
45 46 47 |
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent.rb', line 45 def created @created end |
#expected_settlement_date ⇒ Object (readonly)
Date when we expect to receive the funds.
47 48 49 |
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent.rb', line 47 def expected_settlement_date @expected_settlement_date end |
#financial_account ⇒ Object (readonly)
FinancialAccount ID where the funds are expected.
49 50 51 |
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent.rb', line 49 def financial_account @financial_account end |
#id ⇒ Object (readonly)
Unique identifier for the SettlementAllocationIntent.
51 52 53 |
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent.rb', line 51 def id @id end |
#linked_credits ⇒ Object (readonly)
List of ReceivedCredits that matched with the SettlementAllocationIntent.
53 54 55 |
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent.rb', line 53 def linked_credits @linked_credits end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
55 56 57 |
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent.rb', line 55 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Metadata associated with the SettlementAllocationIntent.
57 58 59 |
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent.rb', line 57 def @metadata end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
59 60 61 |
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent.rb', line 59 def object @object end |
#reference ⇒ Object (readonly)
Reference for the SettlementAllocationIntent. This is the transaction reference used by payments processor to send funds to Stripe .
61 62 63 |
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent.rb', line 61 def reference @reference end |
#status ⇒ Object (readonly)
SettlementAllocationIntent status.
63 64 65 |
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent.rb', line 63 def status @status end |
#status_details ⇒ Object (readonly)
Status details for a SettlementAllocationIntent in ‘errored` state.
65 66 67 |
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent.rb', line 65 def status_details @status_details end |
Class Method Details
.field_remappings ⇒ Object
71 72 73 |
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent.rb', line 71 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
67 68 69 |
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent.rb', line 67 def self.inner_class_types @inner_class_types = { status_details: StatusDetails } end |
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent.rb', line 10 def self.object_name "v2.payments.settlement_allocation_intent" end |