Class: Stripe::V2::Payments::SettlementAllocationIntent::StatusDetails::Errored
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Payments::SettlementAllocationIntent::StatusDetails::Errored
- Defined in:
- lib/stripe/resources/v2/payments/settlement_allocation_intent.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#doc_url ⇒ Object
readonly
Stripe doc link to debug the issue.
-
#message ⇒ Object
readonly
User Message detailing the reason code and possible resolution .
-
#reason_code ⇒ Object
readonly
Open Enum.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#doc_url ⇒ Object (readonly)
Stripe doc link to debug the issue.
32 33 34 |
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent.rb', line 32 def doc_url @doc_url end |
#message ⇒ Object (readonly)
User Message detailing the reason code and possible resolution .
34 35 36 |
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent.rb', line 34 def @message end |
#reason_code ⇒ Object (readonly)
Open Enum. The ‘errored` status reason.
36 37 38 |
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent.rb', line 36 def reason_code @reason_code end |
Class Method Details
.field_remappings ⇒ Object
42 43 44 |
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent.rb', line 42 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
38 39 40 |
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent.rb', line 38 def self.inner_class_types @inner_class_types = {} end |