Class: Stripe::V2::Payments::SettlementAllocationIntentCreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/payments/settlement_allocation_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, expected_settlement_date: nil, financial_account: nil, metadata: nil, reference: nil) ⇒ SettlementAllocationIntentCreateParams

Returns a new instance of SettlementAllocationIntentCreateParams.



19
20
21
22
23
24
25
26
27
28
29
30
31
# File 'lib/stripe/params/v2/payments/settlement_allocation_intent_create_params.rb', line 19

def initialize(
  amount: nil,
  expected_settlement_date: nil,
  financial_account: nil,
  metadata: nil,
  reference: nil
)
  @amount = amount
  @expected_settlement_date = expected_settlement_date
  @financial_account = 
  @metadata = 
  @reference = reference
end

Instance Attribute Details

#amountObject

The amount and currency of the SettlementAllocationIntent. Allowed Currencies are ‘gbp` | `eur`.



9
10
11
# File 'lib/stripe/params/v2/payments/settlement_allocation_intent_create_params.rb', line 9

def amount
  @amount
end

#expected_settlement_dateObject

Date when we expect to receive the funds. Must be in future .



11
12
13
# File 'lib/stripe/params/v2/payments/settlement_allocation_intent_create_params.rb', line 11

def expected_settlement_date
  @expected_settlement_date
end

#financial_accountObject

Financial Account Id where the funds are expected for this SettlementAllocationIntent.



13
14
15
# File 'lib/stripe/params/v2/payments/settlement_allocation_intent_create_params.rb', line 13

def 
  @financial_account
end

#metadataObject

Metadata associated with the SettlementAllocationIntent.



15
16
17
# File 'lib/stripe/params/v2/payments/settlement_allocation_intent_create_params.rb', line 15

def 
  @metadata
end

#referenceObject

Reference for the SettlementAllocationIntent. This should be same as the transaction reference used by payments processor to send funds to Stripe. Must have length between 5 and 255 characters and it must be unique among existing SettlementAllocationIntents that have a non-terminal status (‘pending`, `submitted`, `matched`, `errored`).



17
18
19
# File 'lib/stripe/params/v2/payments/settlement_allocation_intent_create_params.rb', line 17

def reference
  @reference
end