Class: Stripe::V2::Payments::SettlementAllocationIntentListParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/payments/settlement_allocation_intent_list_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(created_gt: nil, created_gte: nil, created_lt: nil, created_lte: nil, financial_account: nil, limit: nil, status: nil) ⇒ SettlementAllocationIntentListParams

Returns a new instance of SettlementAllocationIntentListParams.



27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
# File 'lib/stripe/params/v2/payments/settlement_allocation_intent_list_params.rb', line 27

def initialize(
  created_gt: nil,
  created_gte: nil,
  created_lt: nil,
  created_lte: nil,
  financial_account: nil,
  limit: nil,
  status: nil
)
  @created_gt = created_gt
  @created_gte = created_gte
  @created_lt = created_lt
  @created_lte = created_lte
  @financial_account = 
  @limit = limit
  @status = status
end

Instance Attribute Details

#created_gtObject

Filter for objects created after the specified timestamp. Must be an RFC 3339 date & time value, for example: 2025-10-17T13:22::00Z.



10
11
12
# File 'lib/stripe/params/v2/payments/settlement_allocation_intent_list_params.rb', line 10

def created_gt
  @created_gt
end

#created_gteObject

Filter for objects created on or after the specified timestamp. Must be an RFC 3339 date & time value, for example: 2025-10-17T13:22::00Z.



13
14
15
# File 'lib/stripe/params/v2/payments/settlement_allocation_intent_list_params.rb', line 13

def created_gte
  @created_gte
end

#created_ltObject

Filter for objects created before the specified timestamp. Must be an RFC 3339 date & time value, for example: 2025-10-17T13:22::00Z.



16
17
18
# File 'lib/stripe/params/v2/payments/settlement_allocation_intent_list_params.rb', line 16

def created_lt
  @created_lt
end

#created_lteObject

Filter for objects created on or before the specified timestamp. Must be an RFC 3339 date & time value, for example: 2025-10-17T13:22::00Z.



19
20
21
# File 'lib/stripe/params/v2/payments/settlement_allocation_intent_list_params.rb', line 19

def created_lte
  @created_lte
end

#financial_accountObject

Filter the SettlementAllocationIntents by FinancialAccount.



21
22
23
# File 'lib/stripe/params/v2/payments/settlement_allocation_intent_list_params.rb', line 21

def 
  @financial_account
end

#limitObject

The page size.



23
24
25
# File 'lib/stripe/params/v2/payments/settlement_allocation_intent_list_params.rb', line 23

def limit
  @limit
end

#statusObject

Filter the SettlementAllocationIntents by status.



25
26
27
# File 'lib/stripe/params/v2/payments/settlement_allocation_intent_list_params.rb', line 25

def status
  @status
end