Class: Stripe::V2::Payments::SettlementAllocationIntentSplit
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Payments::SettlementAllocationIntentSplit
- Defined in:
- lib/stripe/resources/v2/payments/settlement_allocation_intent_split.rb
Overview
SettlementAllocationIntentSplit resource.
Defined Under Namespace
Classes: Flow
Constant Summary collapse
- OBJECT_NAME =
"v2.payments.settlement_allocation_intent_split"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account ⇒ Object
readonly
The account id against which the SettlementAllocationIntentSplit should be settled.
-
#amount ⇒ Object
readonly
The amount and currency of the SettlementAllocationIntentSplit.
-
#created ⇒ Object
readonly
Timestamp at which SettlementAllocationIntentSplit was created.
-
#flow ⇒ Object
readonly
Details about the Flow object that settled the split.
-
#id ⇒ Object
readonly
Unique identifier for the SettlementAllocationIntentSplit.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#metadata ⇒ Object
readonly
Metadata associated with the SettlementAllocationIntentSplit.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#settlement_allocation_intent ⇒ Object
readonly
The ID of the SettlementAllocationIntent that this split belongs to.
-
#status ⇒ Object
readonly
The status of the SettlementAllocationIntentSplit.
-
#type ⇒ Object
readonly
The type of the SettlementAllocationIntentSplit.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account ⇒ Object (readonly)
The account id against which the SettlementAllocationIntentSplit should be settled.
33 34 35 |
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent_split.rb', line 33 def account @account end |
#amount ⇒ Object (readonly)
The amount and currency of the SettlementAllocationIntentSplit.
35 36 37 |
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent_split.rb', line 35 def amount @amount end |
#created ⇒ Object (readonly)
Timestamp at which SettlementAllocationIntentSplit was created.
37 38 39 |
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent_split.rb', line 37 def created @created end |
#flow ⇒ Object (readonly)
Details about the Flow object that settled the split.
39 40 41 |
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent_split.rb', line 39 def flow @flow end |
#id ⇒ Object (readonly)
Unique identifier for the SettlementAllocationIntentSplit.
41 42 43 |
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent_split.rb', line 41 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
43 44 45 |
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent_split.rb', line 43 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Metadata associated with the SettlementAllocationIntentSplit.
45 46 47 |
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent_split.rb', line 45 def @metadata end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
47 48 49 |
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent_split.rb', line 47 def object @object end |
#settlement_allocation_intent ⇒ Object (readonly)
The ID of the SettlementAllocationIntent that this split belongs to.
49 50 51 |
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent_split.rb', line 49 def settlement_allocation_intent @settlement_allocation_intent end |
#status ⇒ Object (readonly)
The status of the SettlementAllocationIntentSplit.
51 52 53 |
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent_split.rb', line 51 def status @status end |
#type ⇒ Object (readonly)
The type of the SettlementAllocationIntentSplit.
53 54 55 |
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent_split.rb', line 53 def type @type end |
Class Method Details
.field_remappings ⇒ Object
59 60 61 |
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent_split.rb', line 59 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
55 56 57 |
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent_split.rb', line 55 def self.inner_class_types @inner_class_types = { flow: Flow } end |
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent_split.rb', line 10 def self.object_name "v2.payments.settlement_allocation_intent_split" end |