Class: Stripe::V2::Payments::SettlementAllocationIntentSplit::Flow
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Payments::SettlementAllocationIntentSplit::Flow
- Defined in:
- lib/stripe/resources/v2/payments/settlement_allocation_intent_split.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#outbound_payment ⇒ Object
readonly
If applicable, the ID of the OutboundPayment that created this transaction.
-
#outbound_transfer ⇒ Object
readonly
If applicable, the ID of the OutboundTransfer that created this transaction.
-
#received_credit ⇒ Object
readonly
If applicable, the ID of the ReceivedCredit that created this transaction.
-
#type ⇒ Object
readonly
Type of the flow linked to the transaction which settled the SettlementAllocationIntentSplit.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#outbound_payment ⇒ Object (readonly)
If applicable, the ID of the OutboundPayment that created this transaction.
16 17 18 |
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent_split.rb', line 16 def outbound_payment @outbound_payment end |
#outbound_transfer ⇒ Object (readonly)
If applicable, the ID of the OutboundTransfer that created this transaction.
18 19 20 |
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent_split.rb', line 18 def outbound_transfer @outbound_transfer end |
#received_credit ⇒ Object (readonly)
If applicable, the ID of the ReceivedCredit that created this transaction.
20 21 22 |
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent_split.rb', line 20 def received_credit @received_credit end |
#type ⇒ Object (readonly)
Type of the flow linked to the transaction which settled the SettlementAllocationIntentSplit. The field matching this value will contain the ID of the flow.
22 23 24 |
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent_split.rb', line 22 def type @type end |
Class Method Details
.field_remappings ⇒ Object
28 29 30 |
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent_split.rb', line 28 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
24 25 26 |
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent_split.rb', line 24 def self.inner_class_types @inner_class_types = {} end |