Class: Stripe::V2::Reporting::Report
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Reporting::Report
- Defined in:
- lib/stripe/resources/v2/reporting/report.rb
Overview
The Report resource represents a customizable report template that provides insights into various aspects of your Stripe integration.
Defined Under Namespace
Classes: Parameters
Constant Summary collapse
- OBJECT_NAME =
"v2.reporting.report"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#id ⇒ Object
readonly
The unique identifier of the ‘Report` object.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#name ⇒ Object
readonly
The human-readable name of the ‘Report`.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#parameters ⇒ Object
readonly
Specification of the parameters that the ‘Report` accepts.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#id ⇒ Object (readonly)
The unique identifier of the ‘Report` object.
95 96 97 |
# File 'lib/stripe/resources/v2/reporting/report.rb', line 95 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
104 105 106 |
# File 'lib/stripe/resources/v2/reporting/report.rb', line 104 def livemode @livemode end |
#name ⇒ Object (readonly)
The human-readable name of the ‘Report`.
97 98 99 |
# File 'lib/stripe/resources/v2/reporting/report.rb', line 97 def name @name end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
99 100 101 |
# File 'lib/stripe/resources/v2/reporting/report.rb', line 99 def object @object end |
#parameters ⇒ Object (readonly)
Specification of the parameters that the ‘Report` accepts. It details each parameter’s name, description, whether it is required, and any validations performed.
102 103 104 |
# File 'lib/stripe/resources/v2/reporting/report.rb', line 102 def parameters @parameters end |
Class Method Details
.field_remappings ⇒ Object
110 111 112 |
# File 'lib/stripe/resources/v2/reporting/report.rb', line 110 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
106 107 108 |
# File 'lib/stripe/resources/v2/reporting/report.rb', line 106 def self.inner_class_types @inner_class_types = { parameters: Parameters } end |
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/v2/reporting/report.rb', line 10 def self.object_name "v2.reporting.report" end |