Class: Stripe::V2::Reporting::Report::Parameters
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Reporting::Report::Parameters
- Defined in:
- lib/stripe/resources/v2/reporting/report.rb
Defined Under Namespace
Classes: ArrayDetails, EnumDetails, TimestampDetails
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#array_details ⇒ Object
readonly
For array parameters, provides details about the array elements.
-
#description ⇒ Object
readonly
Explains the purpose and usage of the parameter.
-
#enum_details ⇒ Object
readonly
For enum parameters, provides the list of allowed values.
-
#required ⇒ Object
readonly
Indicates whether the parameter must be provided.
-
#timestamp_details ⇒ Object
readonly
For timestamp parameters, specifies the allowed date range.
-
#type ⇒ Object
readonly
The data type of the parameter.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#array_details ⇒ Object (readonly)
For array parameters, provides details about the array elements.
70 71 72 |
# File 'lib/stripe/resources/v2/reporting/report.rb', line 70 def array_details @array_details end |
#description ⇒ Object (readonly)
Explains the purpose and usage of the parameter.
72 73 74 |
# File 'lib/stripe/resources/v2/reporting/report.rb', line 72 def description @description end |
#enum_details ⇒ Object (readonly)
For enum parameters, provides the list of allowed values.
74 75 76 |
# File 'lib/stripe/resources/v2/reporting/report.rb', line 74 def enum_details @enum_details end |
#required ⇒ Object (readonly)
Indicates whether the parameter must be provided.
76 77 78 |
# File 'lib/stripe/resources/v2/reporting/report.rb', line 76 def required @required end |
#timestamp_details ⇒ Object (readonly)
For timestamp parameters, specifies the allowed date range.
78 79 80 |
# File 'lib/stripe/resources/v2/reporting/report.rb', line 78 def @timestamp_details end |
#type ⇒ Object (readonly)
The data type of the parameter.
80 81 82 |
# File 'lib/stripe/resources/v2/reporting/report.rb', line 80 def type @type end |
Class Method Details
.field_remappings ⇒ Object
90 91 92 |
# File 'lib/stripe/resources/v2/reporting/report.rb', line 90 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
82 83 84 85 86 87 88 |
# File 'lib/stripe/resources/v2/reporting/report.rb', line 82 def self.inner_class_types @inner_class_types = { array_details: ArrayDetails, enum_details: EnumDetails, timestamp_details: TimestampDetails, } end |