Class: Stripe::V2::Reporting::ReportRun
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Reporting::ReportRun
- Defined in:
- lib/stripe/resources/v2/reporting/report_run.rb
Overview
The ‘ReportRun` object represents an instance of a `Report` generated with specific run parameters. Once the object is created, Stripe begins processing the report. When the report has finished running, it will give you a reference to the results.
Defined Under Namespace
Classes: Result, ResultOptions, StatusDetails
Constant Summary collapse
- OBJECT_NAME =
"v2.reporting.report_run"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#id ⇒ Object
readonly
The unique identifier of the ‘ReportRun` object.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#report ⇒ Object
readonly
The unique identifier of the ‘Report` object which was run.
-
#report_name ⇒ Object
readonly
The human-readable name of the ‘Report` which was run.
-
#report_parameters ⇒ Object
readonly
The parameters used to customize the generation of the report.
-
#result ⇒ Object
readonly
Details how to retrieve the results of a successfully completed ‘ReportRun`.
-
#result_options ⇒ Object
readonly
The options specified for customizing the output file of the ‘ReportRun`.
-
#status ⇒ Object
readonly
The current status of the ‘ReportRun`.
-
#status_details ⇒ Object
readonly
Additional details about the current state of the ‘ReportRun`.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
- .field_encodings ⇒ Object
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
- .object_name ⇒ Object
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#created ⇒ Object (readonly)
Time at which the object was created.
99 100 101 |
# File 'lib/stripe/resources/v2/reporting/report_run.rb', line 99 def created @created end |
#id ⇒ Object (readonly)
The unique identifier of the ‘ReportRun` object.
101 102 103 |
# File 'lib/stripe/resources/v2/reporting/report_run.rb', line 101 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
103 104 105 |
# File 'lib/stripe/resources/v2/reporting/report_run.rb', line 103 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
105 106 107 |
# File 'lib/stripe/resources/v2/reporting/report_run.rb', line 105 def object @object end |
#report ⇒ Object (readonly)
The unique identifier of the ‘Report` object which was run.
107 108 109 |
# File 'lib/stripe/resources/v2/reporting/report_run.rb', line 107 def report @report end |
#report_name ⇒ Object (readonly)
The human-readable name of the ‘Report` which was run.
109 110 111 |
# File 'lib/stripe/resources/v2/reporting/report_run.rb', line 109 def report_name @report_name end |
#report_parameters ⇒ Object (readonly)
The parameters used to customize the generation of the report.
111 112 113 |
# File 'lib/stripe/resources/v2/reporting/report_run.rb', line 111 def report_parameters @report_parameters end |
#result ⇒ Object (readonly)
Details how to retrieve the results of a successfully completed ‘ReportRun`.
113 114 115 |
# File 'lib/stripe/resources/v2/reporting/report_run.rb', line 113 def result @result end |
#result_options ⇒ Object (readonly)
The options specified for customizing the output file of the ‘ReportRun`.
115 116 117 |
# File 'lib/stripe/resources/v2/reporting/report_run.rb', line 115 def @result_options end |
#status ⇒ Object (readonly)
The current status of the ‘ReportRun`.
117 118 119 |
# File 'lib/stripe/resources/v2/reporting/report_run.rb', line 117 def status @status end |
#status_details ⇒ Object (readonly)
Additional details about the current state of the ‘ReportRun`. The field is currently only populated when a `ReportRun` is in the `failed` state, providing more information about why the report failed to generate successfully.
120 121 122 |
# File 'lib/stripe/resources/v2/reporting/report_run.rb', line 120 def status_details @status_details end |
Class Method Details
.field_encodings ⇒ Object
134 135 136 137 138 |
# File 'lib/stripe/resources/v2/reporting/report_run.rb', line 134 def self.field_encodings @field_encodings = { result: { kind: :object, fields: { file: { kind: :object, fields: { size: :int64_string } } } }, } end |
.field_remappings ⇒ Object
130 131 132 |
# File 'lib/stripe/resources/v2/reporting/report_run.rb', line 130 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
122 123 124 125 126 127 128 |
# File 'lib/stripe/resources/v2/reporting/report_run.rb', line 122 def self.inner_class_types @inner_class_types = { result: Result, result_options: ResultOptions, status_details: StatusDetails, } end |
.object_name ⇒ Object
12 13 14 |
# File 'lib/stripe/resources/v2/reporting/report_run.rb', line 12 def self.object_name "v2.reporting.report_run" end |