Class: Stripe::V2::Reporting::ReportRun::Result
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Reporting::ReportRun::Result
- Defined in:
- lib/stripe/resources/v2/reporting/report_run.rb
Defined Under Namespace
Classes: File
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#file ⇒ Object
readonly
Contains metadata about the file produced by the ‘ReportRun`, including its content type, size, and a URL to download its contents.
-
#type ⇒ Object
readonly
The type of the ‘ReportRun` result.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#file ⇒ Object (readonly)
Contains metadata about the file produced by the ‘ReportRun`, including its content type, size, and a URL to download its contents.
49 50 51 |
# File 'lib/stripe/resources/v2/reporting/report_run.rb', line 49 def file @file end |
#type ⇒ Object (readonly)
The type of the ‘ReportRun` result.
51 52 53 |
# File 'lib/stripe/resources/v2/reporting/report_run.rb', line 51 def type @type end |
Class Method Details
.field_remappings ⇒ Object
57 58 59 |
# File 'lib/stripe/resources/v2/reporting/report_run.rb', line 57 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
53 54 55 |
# File 'lib/stripe/resources/v2/reporting/report_run.rb', line 53 def self.inner_class_types @inner_class_types = { file: File } end |