Class: Stripe::V2::Reporting::ReportRunService::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/reporting/report_run_service.rb

Defined Under Namespace

Classes: ReportParameters, ResultOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(report: nil, report_parameters: nil, result_options: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



49
50
51
52
53
# File 'lib/stripe/services/v2/reporting/report_run_service.rb', line 49

def initialize(report: nil, report_parameters: nil, result_options: nil)
  @report = report
  @report_parameters = report_parameters
  @result_options = result_options
end

Instance Attribute Details

#reportObject

The unique identifier of the ‘Report` being requested.



42
43
44
# File 'lib/stripe/services/v2/reporting/report_run_service.rb', line 42

def report
  @report
end

#report_parametersObject

A map of parameter names to values, specifying how the report should be customized. The accepted parameters depend on the specific ‘Report` being run.



45
46
47
# File 'lib/stripe/services/v2/reporting/report_run_service.rb', line 45

def report_parameters
  @report_parameters
end

#result_optionsObject

Optional settings to customize the results of the ‘ReportRun`.



47
48
49
# File 'lib/stripe/services/v2/reporting/report_run_service.rb', line 47

def result_options
  @result_options
end