Class: Stripe::V2::Reporting::ReportRunService::CreateParams::ResultOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/reporting/report_run_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(compress_file: nil) ⇒ ResultOptions

Returns a new instance of ResultOptions.



37
38
39
# File 'lib/stripe/services/v2/reporting/report_run_service.rb', line 37

def initialize(compress_file: nil)
  @compress_file = compress_file
end

Instance Attribute Details

#compress_fileObject

If set, the generated report file will be compressed into a ZIP folder. This is useful for reducing file size and download time for large reports.



35
36
37
# File 'lib/stripe/services/v2/reporting/report_run_service.rb', line 35

def compress_file
  @compress_file
end