Class: Stripe::V2::Reporting::ReportService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::V2::Reporting::ReportService
- Defined in:
- lib/stripe/services/v2/reporting/report_service.rb
Instance Method Summary collapse
-
#retrieve(id, params = {}, opts = {}) ⇒ Object
Retrieves metadata about a specific ‘Report` template, including its name, description, and the parameters it accepts.
Methods inherited from StripeService
#initialize, #request, #request_stream
Constructor Details
This class inherits a constructor from Stripe::StripeService
Instance Method Details
#retrieve(id, params = {}, opts = {}) ⇒ Object
Retrieves metadata about a specific ‘Report` template, including its name, description, and the parameters it accepts. It’s useful for understanding the capabilities and requirements of a particular ‘Report` before requesting a `ReportRun`.
11 12 13 14 15 16 17 18 19 |
# File 'lib/stripe/services/v2/reporting/report_service.rb', line 11 def retrieve(id, params = {}, opts = {}) request( method: :get, path: format("/v2/reporting/reports/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |