Class: Stripe::V2::Risk::Inquiry

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/risk/inquiry.rb

Overview

A risk inquiry represents a request from Stripe for information about a connected account.

Defined Under Namespace

Classes: Appeal, AuthorizationDocuments, ProductRemoval

Constant Summary collapse

OBJECT_NAME =
"v2.risk.inquiry"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#appealObject (readonly)

Data for appeal inquiries. Only present when type is appeal.



53
54
55
# File 'lib/stripe/resources/v2/risk/inquiry.rb', line 53

def appeal
  @appeal
end

#authorization_documentsObject (readonly)

Data for authorization_documents inquiries. Only present when type is authorization_documents.



55
56
57
# File 'lib/stripe/resources/v2/risk/inquiry.rb', line 55

def authorization_documents
  @authorization_documents
end

#closed_atObject (readonly)

Time at which the inquiry was closed.



57
58
59
# File 'lib/stripe/resources/v2/risk/inquiry.rb', line 57

def closed_at
  @closed_at
end

#createdObject (readonly)

Time at which the inquiry was created.



59
60
61
# File 'lib/stripe/resources/v2/risk/inquiry.rb', line 59

def created
  @created
end

#idObject (readonly)

Unique identifier for the inquiry.



61
62
63
# File 'lib/stripe/resources/v2/risk/inquiry.rb', line 61

def id
  @id
end

#livemodeObject (readonly)

Has the value true if the object exists in live mode or the value false if the object exists in test mode.



63
64
65
# File 'lib/stripe/resources/v2/risk/inquiry.rb', line 63

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object's type. Objects of the same type share the same value of the object field.



65
66
67
# File 'lib/stripe/resources/v2/risk/inquiry.rb', line 65

def object
  @object
end

#opened_atObject (readonly)

Time at which the inquiry was opened.



67
68
69
# File 'lib/stripe/resources/v2/risk/inquiry.rb', line 67

def opened_at
  @opened_at
end

#product_removalObject (readonly)

Data for product_removal inquiries. Only present when type is product_removal.



69
70
71
# File 'lib/stripe/resources/v2/risk/inquiry.rb', line 69

def product_removal
  @product_removal
end

#statusObject (readonly)

The current status of the inquiry.



71
72
73
# File 'lib/stripe/resources/v2/risk/inquiry.rb', line 71

def status
  @status
end

#typeObject (readonly)

The type of inquiry.



73
74
75
# File 'lib/stripe/resources/v2/risk/inquiry.rb', line 73

def type
  @type
end

Class Method Details

.field_remappingsObject



83
84
85
# File 'lib/stripe/resources/v2/risk/inquiry.rb', line 83

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



75
76
77
78
79
80
81
# File 'lib/stripe/resources/v2/risk/inquiry.rb', line 75

def self.inner_class_types
  @inner_class_types = {
    appeal: Appeal,
    authorization_documents: AuthorizationDocuments,
    product_removal: ProductRemoval,
  }
end

.object_nameObject



10
11
12
# File 'lib/stripe/resources/v2/risk/inquiry.rb', line 10

def self.object_name
  "v2.risk.inquiry"
end