Class: Stripe::V2::Signals::AccountActivity

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/signals/account_activity.rb

Overview

Account Activity resource for the Signals API.

Defined Under Namespace

Classes: AccountDetails, LoginAttempt, LoginDecision, RegistrationAttempt, RegistrationDecision

Constant Summary collapse

OBJECT_NAME =
"v2.signals.account_activity"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_detailsObject (readonly)

The account, customer, or inline account data associated with the activity.



183
184
185
# File 'lib/stripe/resources/v2/signals/account_activity.rb', line 183

def 
  @account_details
end

#account_evaluationObject (readonly)

The account evaluation this activity is associated with, when applicable.



185
186
187
# File 'lib/stripe/resources/v2/signals/account_activity.rb', line 185

def 
  @account_evaluation
end

#createdObject (readonly)

Timestamp at which the account activity was created.



187
188
189
# File 'lib/stripe/resources/v2/signals/account_activity.rb', line 187

def created
  @created
end

#idObject (readonly)

Unique identifier for the account activity.



189
190
191
# File 'lib/stripe/resources/v2/signals/account_activity.rb', line 189

def id
  @id
end

#livemodeObject (readonly)

Has the value true if the object exists in live mode or the value false if the object exists in test mode.



191
192
193
# File 'lib/stripe/resources/v2/signals/account_activity.rb', line 191

def livemode
  @livemode
end

#login_attemptObject (readonly)

Details for the login attempt. Present only when type is login_attempt.



193
194
195
# File 'lib/stripe/resources/v2/signals/account_activity.rb', line 193

def 
  @login_attempt
end

#login_decisionObject (readonly)

Details for the login decision. Present only when type is login_decision.



195
196
197
# File 'lib/stripe/resources/v2/signals/account_activity.rb', line 195

def 
  @login_decision
end

#objectObject (readonly)

String representing the object's type. Objects of the same type share the same value of the object field.



197
198
199
# File 'lib/stripe/resources/v2/signals/account_activity.rb', line 197

def object
  @object
end

#occurred_atObject (readonly)

Timestamp at which the activity occurred. Defaults to the created time if not provided.



199
200
201
# File 'lib/stripe/resources/v2/signals/account_activity.rb', line 199

def occurred_at
  @occurred_at
end

#registration_attemptObject (readonly)

Details for the registration attempt. Present only when type is registration_attempt.



201
202
203
# File 'lib/stripe/resources/v2/signals/account_activity.rb', line 201

def registration_attempt
  @registration_attempt
end

#registration_decisionObject (readonly)

Details for the registration decision. Present only when type is registration_decision.



203
204
205
# File 'lib/stripe/resources/v2/signals/account_activity.rb', line 203

def registration_decision
  @registration_decision
end

#typeObject (readonly)

The type of activity.



205
206
207
# File 'lib/stripe/resources/v2/signals/account_activity.rb', line 205

def type
  @type
end

Class Method Details

.field_remappingsObject



217
218
219
# File 'lib/stripe/resources/v2/signals/account_activity.rb', line 217

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



207
208
209
210
211
212
213
214
215
# File 'lib/stripe/resources/v2/signals/account_activity.rb', line 207

def self.inner_class_types
  @inner_class_types = {
    account_details: AccountDetails,
    login_attempt: LoginAttempt,
    login_decision: LoginDecision,
    registration_attempt: RegistrationAttempt,
    registration_decision: RegistrationDecision,
  }
end

.object_nameObject



10
11
12
# File 'lib/stripe/resources/v2/signals/account_activity.rb', line 10

def self.object_name
  "v2.signals.account_activity"
end