Class: Stripe::V2::Signals::AccountActivity::AccountDetails

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/signals/account_activity.rb

Defined Under Namespace

Classes: Data

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#accountObject (readonly)

The v2 account ID of the account.



56
57
58
# File 'lib/stripe/resources/v2/signals/account_activity.rb', line 56

def 
  @account
end

#customerObject (readonly)

The v1 customer ID of the account, for users not yet migrated to v2/accounts.



58
59
60
# File 'lib/stripe/resources/v2/signals/account_activity.rb', line 58

def customer
  @customer
end

#dataObject (readonly)

Inline account data to evaluate without creating a v2 account.



60
61
62
# File 'lib/stripe/resources/v2/signals/account_activity.rb', line 60

def data
  @data
end

Class Method Details

.field_remappingsObject



66
67
68
# File 'lib/stripe/resources/v2/signals/account_activity.rb', line 66

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



62
63
64
# File 'lib/stripe/resources/v2/signals/account_activity.rb', line 62

def self.inner_class_types
  @inner_class_types = { data: Data }
end