Class: Stripe::V2::Signals::AccountActivityCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Signals::AccountActivityCreateParams
- Defined in:
- lib/stripe/params/v2/signals/account_activity_create_params.rb
Defined Under Namespace
Classes: AccountDetails, LoginAttempt, LoginDecision, RegistrationAttempt, RegistrationDecision
Instance Attribute Summary collapse
-
#account_details ⇒ Object
The account, customer, or inline account data associated with the activity.
-
#account_evaluation ⇒ Object
The account evaluation this activity is associated with, when applicable.
-
#login_attempt ⇒ Object
Details for the login attempt.
-
#login_decision ⇒ Object
Details for the login decision.
-
#occurred_at ⇒ Object
Timestamp at which the activity occurred.
-
#registration_attempt ⇒ Object
Details for the registration attempt.
-
#registration_decision ⇒ Object
Details for the registration decision.
-
#type ⇒ Object
The type of activity.
Instance Method Summary collapse
-
#initialize(account_details: nil, account_evaluation: nil, login_attempt: nil, login_decision: nil, occurred_at: nil, registration_attempt: nil, registration_decision: nil, type: nil) ⇒ AccountActivityCreateParams
constructor
A new instance of AccountActivityCreateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(account_details: nil, account_evaluation: nil, login_attempt: nil, login_decision: nil, occurred_at: nil, registration_attempt: nil, registration_decision: nil, type: nil) ⇒ AccountActivityCreateParams
Returns a new instance of AccountActivityCreateParams.
155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/stripe/params/v2/signals/account_activity_create_params.rb', line 155 def initialize( account_details: nil, account_evaluation: nil, login_attempt: nil, login_decision: nil, occurred_at: nil, registration_attempt: nil, registration_decision: nil, type: nil ) @account_details = account_details @account_evaluation = account_evaluation @login_attempt = login_attempt @login_decision = login_decision @occurred_at = occurred_at @registration_attempt = registration_attempt @registration_decision = registration_decision @type = type end |
Instance Attribute Details
#account_details ⇒ Object
The account, customer, or inline account data associated with the activity.
139 140 141 |
# File 'lib/stripe/params/v2/signals/account_activity_create_params.rb', line 139 def account_details @account_details end |
#account_evaluation ⇒ Object
The account evaluation this activity is associated with, when applicable.
141 142 143 |
# File 'lib/stripe/params/v2/signals/account_activity_create_params.rb', line 141 def account_evaluation @account_evaluation end |
#login_attempt ⇒ Object
Details for the login attempt. Provide only when type is login_attempt.
143 144 145 |
# File 'lib/stripe/params/v2/signals/account_activity_create_params.rb', line 143 def login_attempt @login_attempt end |
#login_decision ⇒ Object
Details for the login decision. Provide only when type is login_decision.
145 146 147 |
# File 'lib/stripe/params/v2/signals/account_activity_create_params.rb', line 145 def login_decision @login_decision end |
#occurred_at ⇒ Object
Timestamp at which the activity occurred. Defaults to the created time if not provided.
147 148 149 |
# File 'lib/stripe/params/v2/signals/account_activity_create_params.rb', line 147 def occurred_at @occurred_at end |
#registration_attempt ⇒ Object
Details for the registration attempt. Provide only when type is registration_attempt.
149 150 151 |
# File 'lib/stripe/params/v2/signals/account_activity_create_params.rb', line 149 def registration_attempt @registration_attempt end |
#registration_decision ⇒ Object
Details for the registration decision. Provide only when type is registration_decision.
151 152 153 |
# File 'lib/stripe/params/v2/signals/account_activity_create_params.rb', line 151 def registration_decision @registration_decision end |
#type ⇒ Object
The type of activity.
153 154 155 |
# File 'lib/stripe/params/v2/signals/account_activity_create_params.rb', line 153 def type @type end |