Class: Stripe::V2::Signals::AccountActivityCreateParams::AccountDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Signals::AccountActivityCreateParams::AccountDetails
- Defined in:
- lib/stripe/params/v2/signals/account_activity_create_params.rb
Defined Under Namespace
Classes: Data
Instance Attribute Summary collapse
-
#account ⇒ Object
The v2 account ID of the account.
-
#customer ⇒ Object
The v1 customer ID of the account, for users not yet migrated to v2/accounts.
-
#data ⇒ Object
Inline account data to evaluate without creating a v2 account.
Instance Method Summary collapse
-
#initialize(account: nil, customer: nil, data: nil) ⇒ AccountDetails
constructor
A new instance of AccountDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(account: nil, customer: nil, data: nil) ⇒ AccountDetails
Returns a new instance of AccountDetails.
66 67 68 69 70 |
# File 'lib/stripe/params/v2/signals/account_activity_create_params.rb', line 66 def initialize(account: nil, customer: nil, data: nil) @account = account @customer = customer @data = data end |
Instance Attribute Details
#account ⇒ Object
The v2 account ID of the account.
60 61 62 |
# File 'lib/stripe/params/v2/signals/account_activity_create_params.rb', line 60 def account @account end |
#customer ⇒ Object
The v1 customer ID of the account, for users not yet migrated to v2/accounts.
62 63 64 |
# File 'lib/stripe/params/v2/signals/account_activity_create_params.rb', line 62 def customer @customer end |
#data ⇒ Object
Inline account data to evaluate without creating a v2 account.
64 65 66 |
# File 'lib/stripe/params/v2/signals/account_activity_create_params.rb', line 64 def data @data end |