Class: Stripe::V2::Signals::AccountEvaluationCreateParams::AccountDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Signals::AccountEvaluationCreateParams::AccountDetails
- Defined in:
- lib/stripe/params/v2/signals/account_evaluation_create_params.rb
Defined Under Namespace
Classes: Data
Instance Attribute Summary collapse
-
#account ⇒ Object
The v2 account ID of the account.
-
#customer ⇒ Object
The v1 customer ID of the account, for users not yet migrated to v2/accounts.
-
#data ⇒ Object
Inline account data to evaluate without creating a v2 account.
Instance Method Summary collapse
-
#initialize(account: nil, customer: nil, data: nil) ⇒ AccountDetails
constructor
A new instance of AccountDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(account: nil, customer: nil, data: nil) ⇒ AccountDetails
Returns a new instance of AccountDetails.
167 168 169 170 171 |
# File 'lib/stripe/params/v2/signals/account_evaluation_create_params.rb', line 167 def initialize(account: nil, customer: nil, data: nil) @account = account @customer = customer @data = data end |
Instance Attribute Details
#account ⇒ Object
The v2 account ID of the account.
161 162 163 |
# File 'lib/stripe/params/v2/signals/account_evaluation_create_params.rb', line 161 def account @account end |
#customer ⇒ Object
The v1 customer ID of the account, for users not yet migrated to v2/accounts.
163 164 165 |
# File 'lib/stripe/params/v2/signals/account_evaluation_create_params.rb', line 163 def customer @customer end |
#data ⇒ Object
Inline account data to evaluate without creating a v2 account.
165 166 167 |
# File 'lib/stripe/params/v2/signals/account_evaluation_create_params.rb', line 165 def data @data end |