Class: Stripe::V2::Signals::AccountSignal::FraudulentMerchant

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/signals/account_signal.rb

Defined Under Namespace

Classes: Indicator

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#indicatorsObject (readonly)

Array of objects representing individual factors that contributed to the calculated probability. Absent when risk level is not_assessed or unknown, or when the user is not on a product tier that includes indicators.



48
49
50
# File 'lib/stripe/resources/v2/signals/account_signal.rb', line 48

def indicators
  @indicators
end

#probabilityObject (readonly)

The probability of the merchant being fraudulent. Can be between 0.00 and 100.00. Absent when risk level is not_assessed or unknown, or when the user is not on a product tier that includes numeric scores.



51
52
53
# File 'lib/stripe/resources/v2/signals/account_signal.rb', line 51

def probability
  @probability
end

#risk_levelObject (readonly)

Categorical assessment of the fraudulent merchant risk based on probability.



53
54
55
# File 'lib/stripe/resources/v2/signals/account_signal.rb', line 53

def risk_level
  @risk_level
end

Class Method Details

.field_encodingsObject



63
64
65
# File 'lib/stripe/resources/v2/signals/account_signal.rb', line 63

def self.field_encodings
  @field_encodings = { probability: :decimal_string }
end

.field_remappingsObject



59
60
61
# File 'lib/stripe/resources/v2/signals/account_signal.rb', line 59

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



55
56
57
# File 'lib/stripe/resources/v2/signals/account_signal.rb', line 55

def self.inner_class_types
  @inner_class_types = { indicators: Indicator }
end