Class: Stripe::V2::Signals::AccountSignal::MerchantDelinquency
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Signals::AccountSignal::MerchantDelinquency
- Defined in:
- lib/stripe/resources/v2/signals/account_signal.rb
Defined Under Namespace
Classes: Indicator
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#indicators ⇒ Object
readonly
Array of objects representing individual factors that contributed to the calculated probability of delinquency.
-
#probability ⇒ Object
readonly
The probability of delinquency.
-
#risk_level ⇒ Object
readonly
Categorical assessment of the delinquency risk based on probability.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#indicators ⇒ Object (readonly)
Array of objects representing individual factors that contributed to the calculated probability of delinquency. Absent when risk level is not_assessed or unknown, or when the user is not on a product tier that includes indicators.
87 88 89 |
# File 'lib/stripe/resources/v2/signals/account_signal.rb', line 87 def indicators @indicators end |
#probability ⇒ Object (readonly)
The probability of delinquency. Can be between 0.00 and 100.00. Absent when risk level is not_assessed or unknown, or when the user is not on a product tier that includes numeric scores.
90 91 92 |
# File 'lib/stripe/resources/v2/signals/account_signal.rb', line 90 def probability @probability end |
#risk_level ⇒ Object (readonly)
Categorical assessment of the delinquency risk based on probability.
92 93 94 |
# File 'lib/stripe/resources/v2/signals/account_signal.rb', line 92 def risk_level @risk_level end |
Class Method Details
.field_encodings ⇒ Object
102 103 104 |
# File 'lib/stripe/resources/v2/signals/account_signal.rb', line 102 def self.field_encodings @field_encodings = { probability: :decimal_string } end |
.field_remappings ⇒ Object
98 99 100 |
# File 'lib/stripe/resources/v2/signals/account_signal.rb', line 98 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
94 95 96 |
# File 'lib/stripe/resources/v2/signals/account_signal.rb', line 94 def self.inner_class_types @inner_class_types = { indicators: Indicator } end |