Class: Stripe::V2::Signals::AccountSignal::UserAccountSharing
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Signals::AccountSignal::UserAccountSharing
- Defined in:
- lib/stripe/resources/v2/signals/account_signal.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#risk_level ⇒ Object
readonly
Categorical assessment of the account-sharing risk.
-
#score ⇒ Object
readonly
The specific risk score for the account, between 0.00 and 100.00.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#risk_level ⇒ Object (readonly)
Categorical assessment of the account-sharing risk.
34 35 36 |
# File 'lib/stripe/resources/v2/signals/account_signal.rb', line 34 def risk_level @risk_level end |
#score ⇒ Object (readonly)
The specific risk score for the account, between 0.00 and 100.00. Absent when risk level is not_assessed or unknown, or when the user is not on a product tier that includes numeric scores.
37 38 39 |
# File 'lib/stripe/resources/v2/signals/account_signal.rb', line 37 def score @score end |
Class Method Details
.field_encodings ⇒ Object
47 48 49 |
# File 'lib/stripe/resources/v2/signals/account_signal.rb', line 47 def self.field_encodings @field_encodings = { score: :decimal_string } end |
.field_remappings ⇒ Object
43 44 45 |
# File 'lib/stripe/resources/v2/signals/account_signal.rb', line 43 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
39 40 41 |
# File 'lib/stripe/resources/v2/signals/account_signal.rb', line 39 def self.inner_class_types @inner_class_types = {} end |