Class: Stripe::V2::Signals::AccountSignal::UserMultiAccounting
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Signals::AccountSignal::UserMultiAccounting
- Defined in:
- lib/stripe/resources/v2/signals/account_signal.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#risk_level ⇒ Object
readonly
Categorical assessment of the multi-accounting risk.
-
#score ⇒ Object
readonly
The specific risk score for the account, between 0.00 and 100.00.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#risk_level ⇒ Object (readonly)
Categorical assessment of the multi-accounting risk.
54 55 56 |
# File 'lib/stripe/resources/v2/signals/account_signal.rb', line 54 def risk_level @risk_level end |
#score ⇒ Object (readonly)
The specific risk score for the account, between 0.00 and 100.00. Absent when risk level is not_assessed or unknown, or when the user is not on a product tier that includes numeric scores.
57 58 59 |
# File 'lib/stripe/resources/v2/signals/account_signal.rb', line 57 def score @score end |
Class Method Details
.field_encodings ⇒ Object
67 68 69 |
# File 'lib/stripe/resources/v2/signals/account_signal.rb', line 67 def self.field_encodings @field_encodings = { score: :decimal_string } end |
.field_remappings ⇒ Object
63 64 65 |
# File 'lib/stripe/resources/v2/signals/account_signal.rb', line 63 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
59 60 61 |
# File 'lib/stripe/resources/v2/signals/account_signal.rb', line 59 def self.inner_class_types @inner_class_types = {} end |