Class: Stripe::V2::Signals::AccountSignalListParams::AccountDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Signals::AccountSignalListParams::AccountDetails
- Defined in:
- lib/stripe/params/v2/signals/account_signal_list_params.rb
Instance Attribute Summary collapse
-
#account ⇒ Object
The v2 account ID of the account.
-
#customer ⇒ Object
The v1 customer ID of the account, for users not yet migrated to v2/accounts.
Instance Method Summary collapse
-
#initialize(account: nil, customer: nil) ⇒ AccountDetails
constructor
A new instance of AccountDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(account: nil, customer: nil) ⇒ AccountDetails
Returns a new instance of AccountDetails.
14 15 16 17 |
# File 'lib/stripe/params/v2/signals/account_signal_list_params.rb', line 14 def initialize(account: nil, customer: nil) @account = account @customer = customer end |
Instance Attribute Details
#account ⇒ Object
The v2 account ID of the account.
10 11 12 |
# File 'lib/stripe/params/v2/signals/account_signal_list_params.rb', line 10 def account @account end |
#customer ⇒ Object
The v1 customer ID of the account, for users not yet migrated to v2/accounts.
12 13 14 |
# File 'lib/stripe/params/v2/signals/account_signal_list_params.rb', line 12 def customer @customer end |