Class: Stripe::V2::Tax::AutomaticRuleCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Tax::AutomaticRuleCreateParams
- Defined in:
- lib/stripe/params/v2/tax/automatic_rule_create_params.rb
Instance Attribute Summary collapse
-
#billable_item ⇒ Object
The BillableItem ID to set automatic Tax configuration for.
-
#tax_code ⇒ Object
The TaxCode object to be used for automatic tax calculations.
Instance Method Summary collapse
-
#initialize(billable_item: nil, tax_code: nil) ⇒ AutomaticRuleCreateParams
constructor
A new instance of AutomaticRuleCreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(billable_item: nil, tax_code: nil) ⇒ AutomaticRuleCreateParams
Returns a new instance of AutomaticRuleCreateParams.
13 14 15 16 |
# File 'lib/stripe/params/v2/tax/automatic_rule_create_params.rb', line 13 def initialize(billable_item: nil, tax_code: nil) @billable_item = billable_item @tax_code = tax_code end |
Instance Attribute Details
#billable_item ⇒ Object
The BillableItem ID to set automatic Tax configuration for.
9 10 11 |
# File 'lib/stripe/params/v2/tax/automatic_rule_create_params.rb', line 9 def billable_item @billable_item end |
#tax_code ⇒ Object
The TaxCode object to be used for automatic tax calculations.
11 12 13 |
# File 'lib/stripe/params/v2/tax/automatic_rule_create_params.rb', line 11 def tax_code @tax_code end |