Class: Stripe::V2::Tax::AutomaticRuleService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Tax::AutomaticRuleService::CreateParams
- Defined in:
- lib/stripe/services/v2/tax/automatic_rule_service.rb
Instance Attribute Summary collapse
-
#billable_item ⇒ Object
The BillableItem ID to set automatic Tax configuration for.
-
#tax_code ⇒ Object
The TaxCode object to be used for automatic tax calculations.
Instance Method Summary collapse
-
#initialize(billable_item: nil, tax_code: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(billable_item: nil, tax_code: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
14 15 16 17 |
# File 'lib/stripe/services/v2/tax/automatic_rule_service.rb', line 14 def initialize(billable_item: nil, tax_code: nil) @billable_item = billable_item @tax_code = tax_code end |
Instance Attribute Details
#billable_item ⇒ Object
The BillableItem ID to set automatic Tax configuration for.
10 11 12 |
# File 'lib/stripe/services/v2/tax/automatic_rule_service.rb', line 10 def billable_item @billable_item end |
#tax_code ⇒ Object
The TaxCode object to be used for automatic tax calculations.
12 13 14 |
# File 'lib/stripe/services/v2/tax/automatic_rule_service.rb', line 12 def tax_code @tax_code end |