Class: Stripe::V2::Tax::AutomaticRuleService::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Tax::AutomaticRuleService::UpdateParams
- Defined in:
- lib/stripe/services/v2/tax/automatic_rule_service.rb
Instance Attribute Summary collapse
-
#tax_code ⇒ Object
The TaxCode object to be used for automatic tax calculations.
Instance Method Summary collapse
-
#initialize(tax_code: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(tax_code: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
35 36 37 |
# File 'lib/stripe/services/v2/tax/automatic_rule_service.rb', line 35 def initialize(tax_code: nil) @tax_code = tax_code end |
Instance Attribute Details
#tax_code ⇒ Object
The TaxCode object to be used for automatic tax calculations.
33 34 35 |
# File 'lib/stripe/services/v2/tax/automatic_rule_service.rb', line 33 def tax_code @tax_code end |