Class: Stripe::V2::Tax::AutomaticRuleUpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Tax::AutomaticRuleUpdateParams
- Defined in:
- lib/stripe/params/v2/tax/automatic_rule_update_params.rb
Instance Attribute Summary collapse
-
#tax_code ⇒ Object
The TaxCode object to be used for automatic tax calculations.
Instance Method Summary collapse
-
#initialize(tax_code: nil) ⇒ AutomaticRuleUpdateParams
constructor
A new instance of AutomaticRuleUpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(tax_code: nil) ⇒ AutomaticRuleUpdateParams
Returns a new instance of AutomaticRuleUpdateParams.
11 12 13 |
# File 'lib/stripe/params/v2/tax/automatic_rule_update_params.rb', line 11 def initialize(tax_code: nil) @tax_code = tax_code end |
Instance Attribute Details
#tax_code ⇒ Object
The TaxCode object to be used for automatic tax calculations.
9 10 11 |
# File 'lib/stripe/params/v2/tax/automatic_rule_update_params.rb', line 9 def tax_code @tax_code end |