Class: Stripe::V2::Tax::ManualRule

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/tax/manual_rule.rb

Overview

A ManualRule holds tax rates for a BillableItem. It can hold at most 5 distinct tax rates.

Defined Under Namespace

Classes: Location, Product, ScheduledTaxRate

Constant Summary collapse

OBJECT_NAME =
"v2.tax.manual_rule"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#createdObject (readonly)

The time at which the ManualRule object was created.



98
99
100
# File 'lib/stripe/resources/v2/tax/manual_rule.rb', line 98

def created
  @created
end

#idObject (readonly)

The ID of the ManualRule object.



100
101
102
# File 'lib/stripe/resources/v2/tax/manual_rule.rb', line 100

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



102
103
104
# File 'lib/stripe/resources/v2/tax/manual_rule.rb', line 102

def livemode
  @livemode
end

#locationObject (readonly)

Location where the rule applies.



104
105
106
# File 'lib/stripe/resources/v2/tax/manual_rule.rb', line 104

def location
  @location
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



106
107
108
# File 'lib/stripe/resources/v2/tax/manual_rule.rb', line 106

def object
  @object
end

#productsObject (readonly)

Products associated with the rule.



108
109
110
# File 'lib/stripe/resources/v2/tax/manual_rule.rb', line 108

def products
  @products
end

#scheduled_tax_ratesObject (readonly)

Tax rates to be applied.



110
111
112
# File 'lib/stripe/resources/v2/tax/manual_rule.rb', line 110

def scheduled_tax_rates
  @scheduled_tax_rates
end

#statusObject (readonly)

The status of the ManualRule object.



112
113
114
# File 'lib/stripe/resources/v2/tax/manual_rule.rb', line 112

def status
  @status
end

Class Method Details

.field_encodingsObject



126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
# File 'lib/stripe/resources/v2/tax/manual_rule.rb', line 126

def self.field_encodings
  @field_encodings = {
    scheduled_tax_rates: {
      kind: :array,
      element: {
        kind: :object,
        fields: {
          rates: {
            kind: :array,
            element: { kind: :object, fields: { percentage: :decimal_string } },
          },
        },
      },
    },
  }
end

.field_remappingsObject



122
123
124
# File 'lib/stripe/resources/v2/tax/manual_rule.rb', line 122

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



114
115
116
117
118
119
120
# File 'lib/stripe/resources/v2/tax/manual_rule.rb', line 114

def self.inner_class_types
  @inner_class_types = {
    location: Location,
    products: Product,
    scheduled_tax_rates: ScheduledTaxRate,
  }
end

.object_nameObject



10
11
12
# File 'lib/stripe/resources/v2/tax/manual_rule.rb', line 10

def self.object_name
  "v2.tax.manual_rule"
end