Class: Stripe::V2::Tax::ManualRule::ScheduledTaxRate::Rate

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/tax/manual_rule.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#countryObject (readonly)

Country of the tax rate.



51
52
53
# File 'lib/stripe/resources/v2/tax/manual_rule.rb', line 51

def country
  @country
end

#descriptionObject (readonly)

Description of the tax rate.



53
54
55
# File 'lib/stripe/resources/v2/tax/manual_rule.rb', line 53

def description
  @description
end

#display_nameObject (readonly)

Display name of the tax rate as it will be shown on the invoice.



55
56
57
# File 'lib/stripe/resources/v2/tax/manual_rule.rb', line 55

def display_name
  @display_name
end

#jurisdictionObject (readonly)

Jurisdiction of the tax rate should apply as it will be shown on the invoice.



57
58
59
# File 'lib/stripe/resources/v2/tax/manual_rule.rb', line 57

def jurisdiction
  @jurisdiction
end

#percentageObject (readonly)

Percentage of the tax rate. Must be positive and maximum of 4 decimal points.



59
60
61
# File 'lib/stripe/resources/v2/tax/manual_rule.rb', line 59

def percentage
  @percentage
end

#stateObject (readonly)

State of the tax rate.



61
62
63
# File 'lib/stripe/resources/v2/tax/manual_rule.rb', line 61

def state
  @state
end

Class Method Details

.field_encodingsObject



71
72
73
# File 'lib/stripe/resources/v2/tax/manual_rule.rb', line 71

def self.field_encodings
  @field_encodings = { percentage: :decimal_string }
end

.field_remappingsObject



67
68
69
# File 'lib/stripe/resources/v2/tax/manual_rule.rb', line 67

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



63
64
65
# File 'lib/stripe/resources/v2/tax/manual_rule.rb', line 63

def self.inner_class_types
  @inner_class_types = {}
end