Class: Stripe::V2::Tax::ManualRuleCreateParams::ScheduledTaxRate::Rate

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/tax/manual_rule_create_params.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(country: nil, description: nil, display_name: nil, jurisdiction: nil, percentage: nil, state: nil) ⇒ Rate

Returns a new instance of Rate.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/stripe/params/v2/tax/manual_rule_create_params.rb', line 53

def initialize(
  country: nil,
  description: nil,
  display_name: nil,
  jurisdiction: nil,
  percentage: nil,
  state: nil
)
  @country = country
  @description = description
  @display_name = display_name
  @jurisdiction = jurisdiction
  @percentage = percentage
  @state = state
end

Instance Attribute Details

#countryObject

Country of the tax rate.



41
42
43
# File 'lib/stripe/params/v2/tax/manual_rule_create_params.rb', line 41

def country
  @country
end

#descriptionObject

Description of the tax rate.



43
44
45
# File 'lib/stripe/params/v2/tax/manual_rule_create_params.rb', line 43

def description
  @description
end

#display_nameObject

Display name of the tax rate as it will be shown on the invoice.



45
46
47
# File 'lib/stripe/params/v2/tax/manual_rule_create_params.rb', line 45

def display_name
  @display_name
end

#jurisdictionObject

Jurisdiction of the tax rate should apply as it will be shown on the invoice.



47
48
49
# File 'lib/stripe/params/v2/tax/manual_rule_create_params.rb', line 47

def jurisdiction
  @jurisdiction
end

#percentageObject

Percentage of the tax rate. Must be positive and maximum of 4 decimal points.



49
50
51
# File 'lib/stripe/params/v2/tax/manual_rule_create_params.rb', line 49

def percentage
  @percentage
end

#stateObject

State of the tax rate.



51
52
53
# File 'lib/stripe/params/v2/tax/manual_rule_create_params.rb', line 51

def state
  @state
end

Class Method Details

.field_encodingsObject



69
70
71
# File 'lib/stripe/params/v2/tax/manual_rule_create_params.rb', line 69

def self.field_encodings
  @field_encodings = { percentage: :decimal_string }
end