Class: Stripe::V2::TestHelpers::FinancialAddressCreditParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/test_helpers/financial_address_credit_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, network: nil, statement_descriptor: nil) ⇒ FinancialAddressCreditParams

Returns a new instance of FinancialAddressCreditParams.



15
16
17
18
19
# File 'lib/stripe/params/v2/test_helpers/financial_address_credit_params.rb', line 15

def initialize(amount: nil, network: nil, statement_descriptor: nil)
  @amount = amount
  @network = network
  @statement_descriptor = statement_descriptor
end

Instance Attribute Details

#amountObject

Object containing the amount value and currency to credit.



9
10
11
# File 'lib/stripe/params/v2/test_helpers/financial_address_credit_params.rb', line 9

def amount
  @amount
end

#networkObject

Open Enum. The network to use in simulating the funds flow. This will be the reflected in the resulting ReceivedCredit.



11
12
13
# File 'lib/stripe/params/v2/test_helpers/financial_address_credit_params.rb', line 11

def network
  @network
end

#statement_descriptorObject

String explaining funds flow. Use this field to populate the statement descriptor of the ReceivedCredit created as an eventual result of this simulation.



13
14
15
# File 'lib/stripe/params/v2/test_helpers/financial_address_credit_params.rb', line 13

def statement_descriptor
  @statement_descriptor
end