Class: Stripe::V2::TestHelpers::FinancialAddressService::CreditParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/test_helpers/financial_address_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, network: nil, statement_descriptor: nil) ⇒ CreditParams

Returns a new instance of CreditParams.



16
17
18
19
20
# File 'lib/stripe/services/v2/test_helpers/financial_address_service.rb', line 16

def initialize(amount: nil, network: nil, statement_descriptor: nil)
  @amount = amount
  @network = network
  @statement_descriptor = statement_descriptor
end

Instance Attribute Details

#amountObject

Object containing the amount value and currency to credit.



10
11
12
# File 'lib/stripe/services/v2/test_helpers/financial_address_service.rb', line 10

def amount
  @amount
end

#networkObject

Open Enum. The network to use in simulating the funds flow. This will be the reflected in the resulting ReceivedCredit.



12
13
14
# File 'lib/stripe/services/v2/test_helpers/financial_address_service.rb', line 12

def network
  @network
end

#statement_descriptorObject

String explaining funds flow. Use this field to populate the statement descriptor of the ReceivedCredit created as an eventual result of this simulation.



14
15
16
# File 'lib/stripe/services/v2/test_helpers/financial_address_service.rb', line 14

def statement_descriptor
  @statement_descriptor
end