Class: Stripe::V2::TestHelpers::MoneyManagementService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::V2::TestHelpers::MoneyManagementService
- Defined in:
- lib/stripe/services/v2/test_helpers/money_management_service.rb
Instance Method Summary collapse
-
#recipient_verifications(params = {}, opts = {}) ⇒ Object
Creates a RecipientVerification with a specified match result for testing purposes in a Sandbox environment.
Methods inherited from StripeService
#initialize, #request, #request_stream
Constructor Details
This class inherits a constructor from Stripe::StripeService
Instance Method Details
#recipient_verifications(params = {}, opts = {}) ⇒ Object
Creates a RecipientVerification with a specified match result for testing purposes in a Sandbox environment.
9 10 11 12 13 14 15 16 17 |
# File 'lib/stripe/services/v2/test_helpers/money_management_service.rb', line 9 def recipient_verifications(params = {}, opts = {}) request( method: :post, path: "/v2/test_helpers/money_management/recipient_verifications", params: params, opts: opts, base_address: :api ) end |