Class: Stripe::WebhookEndpoint::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::WebhookEndpoint::CreateParams
- Defined in:
- lib/stripe/resources/webhook_endpoint.rb
Instance Attribute Summary collapse
-
#api_version ⇒ Object
Events sent to this endpoint will be generated with this Stripe Version instead of your account’s default Stripe Version.
-
#connect ⇒ Object
Whether this endpoint should receive events from connected accounts (‘true`), or from your account (`false`).
-
#description ⇒ Object
An optional description of what the webhook is used for.
-
#enabled_events ⇒ Object
The list of events to enable for this endpoint.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#url ⇒ Object
The URL of the webhook endpoint.
Instance Method Summary collapse
-
#initialize(api_version: nil, connect: nil, description: nil, enabled_events: nil, expand: nil, metadata: nil, url: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(api_version: nil, connect: nil, description: nil, enabled_events: nil, expand: nil, metadata: nil, url: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/stripe/resources/webhook_endpoint.rb', line 91 def initialize( api_version: nil, connect: nil, description: nil, enabled_events: nil, expand: nil, metadata: nil, url: nil ) @api_version = api_version @connect = connect @description = description @enabled_events = enabled_events @expand = @metadata = @url = url end |
Instance Attribute Details
#api_version ⇒ Object
Events sent to this endpoint will be generated with this Stripe Version instead of your account’s default Stripe Version.
77 78 79 |
# File 'lib/stripe/resources/webhook_endpoint.rb', line 77 def api_version @api_version end |
#connect ⇒ Object
Whether this endpoint should receive events from connected accounts (‘true`), or from your account (`false`). Defaults to `false`.
79 80 81 |
# File 'lib/stripe/resources/webhook_endpoint.rb', line 79 def connect @connect end |
#description ⇒ Object
An optional description of what the webhook is used for.
81 82 83 |
# File 'lib/stripe/resources/webhook_endpoint.rb', line 81 def description @description end |
#enabled_events ⇒ Object
The list of events to enable for this endpoint. You may specify ‘[’*‘]` to enable all events, except those that require explicit selection.
83 84 85 |
# File 'lib/stripe/resources/webhook_endpoint.rb', line 83 def enabled_events @enabled_events end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
85 86 87 |
# File 'lib/stripe/resources/webhook_endpoint.rb', line 85 def @expand end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
87 88 89 |
# File 'lib/stripe/resources/webhook_endpoint.rb', line 87 def @metadata end |
#url ⇒ Object
The URL of the webhook endpoint.
89 90 91 |
# File 'lib/stripe/resources/webhook_endpoint.rb', line 89 def url @url end |