Class: Stripe::WebhookEndpointService

Inherits:
StripeService show all
Defined in:
lib/stripe/services/webhook_endpoint_service.rb

Defined Under Namespace

Classes: CreateParams, DeleteParams, ListParams, RetrieveParams, UpdateParams

Instance Method Summary collapse

Methods inherited from StripeService

#initialize, #request, #request_stream

Constructor Details

This class inherits a constructor from Stripe::StripeService

Instance Method Details

#create(params = {}, opts = {}) ⇒ Object

A webhook endpoint must have a url and a list of enabled_events. You may optionally specify the Boolean connect parameter. If set to true, then a Connect webhook endpoint that notifies the specified url about events from all connected accounts is created; otherwise an account webhook endpoint that notifies the specified url only about events from your account is created. You can also create webhook endpoints in the [webhooks settings](dashboard.stripe.com/account/webhooks) section of the Dashboard.



117
118
119
120
121
122
123
124
125
# File 'lib/stripe/services/webhook_endpoint_service.rb', line 117

def create(params = {}, opts = {})
  request(
    method: :post,
    path: "/v1/webhook_endpoints",
    params: params,
    opts: opts,
    base_address: :api
  )
end

#delete(webhook_endpoint, params = {}, opts = {}) ⇒ Object

You can also delete webhook endpoints via the [webhook endpoint management](dashboard.stripe.com/account/webhooks) page of the Stripe dashboard.



128
129
130
131
132
133
134
135
136
# File 'lib/stripe/services/webhook_endpoint_service.rb', line 128

def delete(webhook_endpoint, params = {}, opts = {})
  request(
    method: :delete,
    path: format("/v1/webhook_endpoints/%<webhook_endpoint>s", { webhook_endpoint: CGI.escape(webhook_endpoint) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end

#list(params = {}, opts = {}) ⇒ Object

Returns a list of your webhook endpoints.



139
140
141
142
143
144
145
146
147
# File 'lib/stripe/services/webhook_endpoint_service.rb', line 139

def list(params = {}, opts = {})
  request(
    method: :get,
    path: "/v1/webhook_endpoints",
    params: params,
    opts: opts,
    base_address: :api
  )
end

#retrieve(webhook_endpoint, params = {}, opts = {}) ⇒ Object

Retrieves the webhook endpoint with the given ID.



150
151
152
153
154
155
156
157
158
# File 'lib/stripe/services/webhook_endpoint_service.rb', line 150

def retrieve(webhook_endpoint, params = {}, opts = {})
  request(
    method: :get,
    path: format("/v1/webhook_endpoints/%<webhook_endpoint>s", { webhook_endpoint: CGI.escape(webhook_endpoint) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end

#update(webhook_endpoint, params = {}, opts = {}) ⇒ Object

Updates the webhook endpoint. You may edit the url, the list of enabled_events, and the status of your endpoint.



161
162
163
164
165
166
167
168
169
# File 'lib/stripe/services/webhook_endpoint_service.rb', line 161

def update(webhook_endpoint, params = {}, opts = {})
  request(
    method: :post,
    path: format("/v1/webhook_endpoints/%<webhook_endpoint>s", { webhook_endpoint: CGI.escape(webhook_endpoint) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end