Class: Stripe::WebhookEndpointService::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::WebhookEndpointService::UpdateParams
- Defined in:
- lib/stripe/services/webhook_endpoint_service.rb
Instance Attribute Summary collapse
-
#description ⇒ Object
An optional description of what the webhook is used for.
-
#disabled ⇒ Object
Disable the webhook endpoint if set to true.
-
#enabled_events ⇒ Object
The list of events to enable for this endpoint.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#url ⇒ Object
The URL of the webhook endpoint.
Instance Method Summary collapse
-
#initialize(description: nil, disabled: nil, enabled_events: nil, expand: nil, metadata: nil, url: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(description: nil, disabled: nil, enabled_events: nil, expand: nil, metadata: nil, url: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 |
# File 'lib/stripe/services/webhook_endpoint_service.rb', line 31 def initialize( description: nil, disabled: nil, enabled_events: nil, expand: nil, metadata: nil, url: nil ) @description = description @disabled = disabled @enabled_events = enabled_events @expand = @metadata = @url = url end |
Instance Attribute Details
#description ⇒ Object
An optional description of what the webhook is used for.
19 20 21 |
# File 'lib/stripe/services/webhook_endpoint_service.rb', line 19 def description @description end |
#disabled ⇒ Object
Disable the webhook endpoint if set to true.
21 22 23 |
# File 'lib/stripe/services/webhook_endpoint_service.rb', line 21 def disabled @disabled end |
#enabled_events ⇒ Object
The list of events to enable for this endpoint. You may specify ‘[’*‘]` to enable all events, except those that require explicit selection.
23 24 25 |
# File 'lib/stripe/services/webhook_endpoint_service.rb', line 23 def enabled_events @enabled_events end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
25 26 27 |
# File 'lib/stripe/services/webhook_endpoint_service.rb', line 25 def @expand end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
27 28 29 |
# File 'lib/stripe/services/webhook_endpoint_service.rb', line 27 def @metadata end |
#url ⇒ Object
The URL of the webhook endpoint.
29 30 31 |
# File 'lib/stripe/services/webhook_endpoint_service.rb', line 29 def url @url end |