Class: Stripe::APIRequestor::RequestLogContext

Inherits:
Object
  • Object
show all
Defined in:
lib/stripe/api_requestor.rb

Overview

RequestLogContext stores information about a request that’s begin made so that we can log certain information. It’s useful because it means that we don’t have to pass around as many parameters.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#accountObject

Returns the value of attribute account.



1075
1076
1077
# File 'lib/stripe/api_requestor.rb', line 1075

def 
  @account
end

#api_keyObject

Returns the value of attribute api_key.



1075
1076
1077
# File 'lib/stripe/api_requestor.rb', line 1075

def api_key
  @api_key
end

#api_versionObject

Returns the value of attribute api_version.



1075
1076
1077
# File 'lib/stripe/api_requestor.rb', line 1075

def api_version
  @api_version
end

#bodyObject

Returns the value of attribute body.



1075
1076
1077
# File 'lib/stripe/api_requestor.rb', line 1075

def body
  @body
end

#idempotency_keyObject

Returns the value of attribute idempotency_key.



1075
1076
1077
# File 'lib/stripe/api_requestor.rb', line 1075

def idempotency_key
  @idempotency_key
end

#methodObject

Returns the value of attribute method.



1075
1076
1077
# File 'lib/stripe/api_requestor.rb', line 1075

def method
  @method
end

#pathObject

Returns the value of attribute path.



1075
1076
1077
# File 'lib/stripe/api_requestor.rb', line 1075

def path
  @path
end

#queryObject

Returns the value of attribute query.



1075
1076
1077
# File 'lib/stripe/api_requestor.rb', line 1075

def query
  @query
end

#request_idObject

Returns the value of attribute request_id.



1075
1076
1077
# File 'lib/stripe/api_requestor.rb', line 1075

def request_id
  @request_id
end

Instance Method Details

#dup_from_response_headers(headers) ⇒ Object

The idea with this method is that we might want to update some of context information because a response that we’ve received from the API contains information that’s more authoritative than what we started with for a request. For example, we should trust whatever came back in a ‘Stripe-Version` header beyond what configuration information that we might have had available.



1083
1084
1085
1086
1087
1088
1089
1090
# File 'lib/stripe/api_requestor.rb', line 1083

def dup_from_response_headers(headers)
  context = dup
  context. = headers["Stripe-Account"]
  context.api_version = headers["Stripe-Version"]
  context.idempotency_key = headers["Idempotency-Key"]
  context.request_id = headers["Request-Id"]
  context
end