Class: Stripe::Account
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Account
- Extended by:
- Stripe::APIOperations::Create, Stripe::APIOperations::List, Stripe::APIOperations::NestedResource
- Defined in:
- lib/stripe/resources/account.rb
Overview
For new integrations, we recommend using the Accounts v2 API, in place of /v1/accounts and /v1/customers to represent a user.
This is an object representing a Stripe account. You can retrieve it to see properties on the account like its current requirements or if the account is enabled to make live charges or receive payouts.
For accounts where controller.requirement_collection
is application, which includes Custom accounts, the properties below are always
returned.
For accounts where controller.requirement_collection
is stripe, which includes Standard and Express accounts, some properties are only returned
until you create an Account Link or Account Session
to start Connect Onboarding. Learn about the differences between accounts.
Defined Under Namespace
Classes: BusinessProfile, Capabilities, Company, Controller, FutureRequirements, Groups, Requirements, RiskControls, Settings, TosAcceptance
Constant Summary collapse
- OBJECT_NAME =
"account"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#business_profile ⇒ Object
readonly
Business information about the account.
-
#business_type ⇒ Object
readonly
The business type.
-
#capabilities ⇒ Object
readonly
Attribute for field capabilities.
-
#charges_enabled ⇒ Object
readonly
Whether the account can process charges.
-
#company ⇒ Object
readonly
Attribute for field company.
-
#controller ⇒ Object
readonly
Attribute for field controller.
-
#country ⇒ Object
readonly
The account's country.
-
#created ⇒ Object
readonly
Time at which the account was connected.
-
#default_currency ⇒ Object
readonly
Three-letter ISO currency code representing the default currency for the account.
-
#deleted ⇒ Object
readonly
Always true for a deleted object.
-
#details_submitted ⇒ Object
readonly
Whether account details have been submitted.
-
#email ⇒ Object
readonly
An email address associated with the account.
-
#external_accounts ⇒ Object
readonly
External accounts (bank accounts and debit cards) currently attached to this account.
-
#future_requirements ⇒ Object
readonly
Attribute for field future_requirements.
-
#groups ⇒ Object
readonly
The groups associated with the account.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#individual ⇒ Object
readonly
This is an object representing a person associated with a Stripe account.
-
#metadata ⇒ Object
readonly
Set of key-value pairs that you can attach to an object.
-
#object ⇒ Object
readonly
String representing the object's type.
-
#payouts_enabled ⇒ Object
readonly
Whether the funds in this account can be paid out.
-
#requirements ⇒ Object
readonly
Attribute for field requirements.
-
#risk_controls ⇒ Object
readonly
Attribute for field risk_controls.
-
#settings ⇒ Object
readonly
Options for customizing how the account functions within Stripe.
-
#tos_acceptance ⇒ Object
readonly
Attribute for field tos_acceptance.
-
#type ⇒ Object
readonly
The Stripe account type.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.create(params = {}, opts = {}) ⇒ Object
With Connect, you can create Stripe accounts for your users.
-
.delete(account, params = {}, opts = {}) ⇒ Object
With Connect, you can delete accounts you manage.
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
-
.list(params = {}, opts = {}) ⇒ Object
Returns a list of accounts connected to your platform via Connect.
- .object_name ⇒ Object
-
.persons(account, params = {}, opts = {}) ⇒ Object
Returns a list of people associated with the account's legal entity.
- .protected_fields ⇒ Object
-
.reject(account, params = {}, opts = {}) ⇒ Object
With Connect, you can reject accounts that you have flagged as suspicious.
- .retrieve(id = nil, opts = {}) ⇒ Object
-
.unreject(account, params = {}, opts = {}) ⇒ Object
With Connect, you can unreject accounts that you have previously rejected.
-
.update(account, params = {}, opts = {}) ⇒ Object
Updates a connected account by setting the values of the parameters passed.
Instance Method Summary collapse
- #deauthorize(client_id = nil, opts = {}) ⇒ Object
-
#delete(params = {}, opts = {}) ⇒ Object
With Connect, you can delete accounts you manage.
- #legal_entity ⇒ Object
- #legal_entity=(_legal_entity) ⇒ Object
-
#persons(params = {}, opts = {}) ⇒ Object
Returns a list of people associated with the account's legal entity.
-
#reject(params = {}, opts = {}) ⇒ Object
With Connect, you can reject accounts that you have flagged as suspicious.
- #resource_url ⇒ Object
-
#serialize_params(options = {}) ⇒ Object
Somewhat unfortunately, we attempt to do a special encoding trick when serializing
additional_ownersunder an account: when updating a value, we actually send the update parameters up as an integer-indexed hash rather than an array. - #serialize_params_account(_obj, update_hash, options = {}) ⇒ Object
-
#unreject(params = {}, opts = {}) ⇒ Object
With Connect, you can unreject accounts that you have previously rejected.
Methods included from Stripe::APIOperations::Create
Methods included from Stripe::APIOperations::List
Methods included from Stripe::APIOperations::NestedResource
Methods included from Stripe::APIOperations::Save
Methods included from Stripe::APIOperations::Delete
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, save_nested_resource
Methods included from Stripe::APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#business_profile ⇒ Object (readonly)
Business information about the account.
1295 1296 1297 |
# File 'lib/stripe/resources/account.rb', line 1295 def business_profile @business_profile end |
#business_type ⇒ Object (readonly)
The business type.
1297 1298 1299 |
# File 'lib/stripe/resources/account.rb', line 1297 def business_type @business_type end |
#capabilities ⇒ Object (readonly)
Attribute for field capabilities
1299 1300 1301 |
# File 'lib/stripe/resources/account.rb', line 1299 def capabilities @capabilities end |
#charges_enabled ⇒ Object (readonly)
Whether the account can process charges.
1301 1302 1303 |
# File 'lib/stripe/resources/account.rb', line 1301 def charges_enabled @charges_enabled end |
#company ⇒ Object (readonly)
Attribute for field company
1303 1304 1305 |
# File 'lib/stripe/resources/account.rb', line 1303 def company @company end |
#controller ⇒ Object (readonly)
Attribute for field controller
1305 1306 1307 |
# File 'lib/stripe/resources/account.rb', line 1305 def controller @controller end |
#country ⇒ Object (readonly)
The account's country.
1307 1308 1309 |
# File 'lib/stripe/resources/account.rb', line 1307 def country @country end |
#created ⇒ Object (readonly)
Time at which the account was connected. Measured in seconds since the Unix epoch.
1309 1310 1311 |
# File 'lib/stripe/resources/account.rb', line 1309 def created @created end |
#default_currency ⇒ Object (readonly)
Three-letter ISO currency code representing the default currency for the account. This must be a currency that Stripe supports in the account's country.
1311 1312 1313 |
# File 'lib/stripe/resources/account.rb', line 1311 def default_currency @default_currency end |
#deleted ⇒ Object (readonly)
Always true for a deleted object
1313 1314 1315 |
# File 'lib/stripe/resources/account.rb', line 1313 def deleted @deleted end |
#details_submitted ⇒ Object (readonly)
Whether account details have been submitted. Accounts with Stripe Dashboard access, which includes Standard accounts, cannot receive payouts before this is true. Accounts where this is false should be directed to an onboarding flow to finish submitting account details.
1315 1316 1317 |
# File 'lib/stripe/resources/account.rb', line 1315 def details_submitted @details_submitted end |
#email ⇒ Object (readonly)
An email address associated with the account. It's not used for authentication and Stripe doesn't market to this field without explicit approval from the platform.
1317 1318 1319 |
# File 'lib/stripe/resources/account.rb', line 1317 def email @email end |
#external_accounts ⇒ Object (readonly)
External accounts (bank accounts and debit cards) currently attached to this account. External accounts are only returned for requests where controller[is_controller] is true.
1319 1320 1321 |
# File 'lib/stripe/resources/account.rb', line 1319 def external_accounts @external_accounts end |
#future_requirements ⇒ Object (readonly)
Attribute for field future_requirements
1321 1322 1323 |
# File 'lib/stripe/resources/account.rb', line 1321 def future_requirements @future_requirements end |
#groups ⇒ Object (readonly)
The groups associated with the account.
1323 1324 1325 |
# File 'lib/stripe/resources/account.rb', line 1323 def groups @groups end |
#id ⇒ Object (readonly)
Unique identifier for the object.
1325 1326 1327 |
# File 'lib/stripe/resources/account.rb', line 1325 def id @id end |
#individual ⇒ Object (readonly)
This is an object representing a person associated with a Stripe account.
A platform can only access a subset of data in a person for an account where account.controller.requirement_collection is stripe, which includes Standard and Express accounts, after creating an Account Link or Account Session to start Connect onboarding.
See the Standard onboarding or Express onboarding documentation for information about prefilling information and account onboarding steps. Learn more about handling identity verification with the API.
1331 1332 1333 |
# File 'lib/stripe/resources/account.rb', line 1331 def individual @individual end |
#metadata ⇒ Object (readonly)
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
1333 1334 1335 |
# File 'lib/stripe/resources/account.rb', line 1333 def @metadata end |
#object ⇒ Object (readonly)
String representing the object's type. Objects of the same type share the same value.
1335 1336 1337 |
# File 'lib/stripe/resources/account.rb', line 1335 def object @object end |
#payouts_enabled ⇒ Object (readonly)
Whether the funds in this account can be paid out.
1337 1338 1339 |
# File 'lib/stripe/resources/account.rb', line 1337 def payouts_enabled @payouts_enabled end |
#requirements ⇒ Object (readonly)
Attribute for field requirements
1339 1340 1341 |
# File 'lib/stripe/resources/account.rb', line 1339 def requirements @requirements end |
#risk_controls ⇒ Object (readonly)
Attribute for field risk_controls
1341 1342 1343 |
# File 'lib/stripe/resources/account.rb', line 1341 def risk_controls @risk_controls end |
#settings ⇒ Object (readonly)
Options for customizing how the account functions within Stripe.
1343 1344 1345 |
# File 'lib/stripe/resources/account.rb', line 1343 def settings @settings end |
#tos_acceptance ⇒ Object (readonly)
Attribute for field tos_acceptance
1345 1346 1347 |
# File 'lib/stripe/resources/account.rb', line 1345 def tos_acceptance @tos_acceptance end |
#type ⇒ Object (readonly)
The Stripe account type. Can be standard, express, custom, or none.
1347 1348 1349 |
# File 'lib/stripe/resources/account.rb', line 1347 def type @type end |
Class Method Details
.create(params = {}, opts = {}) ⇒ Object
With Connect, you can create Stripe accounts for your users. To do this, you'll first need to register your platform.
If you've already collected information for your connected accounts, you can prefill that information when creating the account. Connect Onboarding won't ask for the prefilled information during account onboarding. You can prefill any information on the account.
1355 1356 1357 |
# File 'lib/stripe/resources/account.rb', line 1355 def self.create(params = {}, opts = {}) request_stripe_object(method: :post, path: "/v1/accounts", params: params, opts: opts) end |
.delete(account, params = {}, opts = {}) ⇒ Object
With Connect, you can delete accounts you manage.
Test-mode accounts can be deleted at any time.
Live-mode accounts that have access to the standard dashboard and Stripe is responsible for negative account balances cannot be deleted, which includes Standard accounts. All other Live-mode accounts, can be deleted when all balances are zero.
If you want to delete your own account, use the account information tab in your account settings instead.
1366 1367 1368 1369 1370 1371 1372 1373 |
# File 'lib/stripe/resources/account.rb', line 1366 def self.delete(account, params = {}, opts = {}) request_stripe_object( method: :delete, path: format("/v1/accounts/%<account>s", { account: CGI.escape(account) }), params: params, opts: opts ) end |
.field_remappings ⇒ Object
1629 1630 1631 |
# File 'lib/stripe/resources/account.rb', line 1629 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1614 1615 1616 1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 |
# File 'lib/stripe/resources/account.rb', line 1614 def self.inner_class_types @inner_class_types = { business_profile: BusinessProfile, capabilities: Capabilities, company: Company, controller: Controller, future_requirements: FutureRequirements, groups: Groups, requirements: Requirements, risk_controls: RiskControls, settings: Settings, tos_acceptance: TosAcceptance, } end |
.list(params = {}, opts = {}) ⇒ Object
Returns a list of accounts connected to your platform via Connect. If you're not a platform, the list is empty.
1392 1393 1394 |
# File 'lib/stripe/resources/account.rb', line 1392 def self.list(params = {}, opts = {}) request_stripe_object(method: :get, path: "/v1/accounts", params: params, opts: opts) end |
.object_name ⇒ Object
27 28 29 |
# File 'lib/stripe/resources/account.rb', line 27 def self.object_name "account" end |
.persons(account, params = {}, opts = {}) ⇒ Object
Returns a list of people associated with the account's legal entity. The people are returned sorted by creation date, with the most recent people appearing first.
1407 1408 1409 1410 1411 1412 1413 1414 |
# File 'lib/stripe/resources/account.rb', line 1407 def self.persons(account, params = {}, opts = {}) request_stripe_object( method: :get, path: format("/v1/accounts/%<account>s/persons", { account: CGI.escape(account) }), params: params, opts: opts ) end |
.protected_fields ⇒ Object
1559 1560 1561 |
# File 'lib/stripe/resources/account.rb', line 1559 def self.protected_fields [:legal_entity] end |
.reject(account, params = {}, opts = {}) ⇒ Object
With Connect, you can reject accounts that you have flagged as suspicious.
Only accounts where your platform is liable for negative account balances, which includes Custom and Express accounts, can be rejected.
1431 1432 1433 1434 1435 1436 1437 1438 |
# File 'lib/stripe/resources/account.rb', line 1431 def self.reject(account, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/accounts/%<account>s/reject", { account: CGI.escape(account) }), params: params, opts: opts ) end |
.retrieve(id = nil, opts = {}) ⇒ Object
1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 1511 1512 1513 1514 |
# File 'lib/stripe/resources/account.rb', line 1501 def self.retrieve(id = nil, opts = {}) Util.check_string_argument!(id) if id # Account used to be a singleton, where this method's signature was # `(opts={})`. For the sake of not breaking folks who pass in an OAuth # key in opts, let's lurkily string match for it. if opts == {} && id.is_a?(String) && id.start_with?("sk_") # `super` properly assumes a String opts is the apiKey and normalizes # as expected. opts = id id = nil end super end |
.unreject(account, params = {}, opts = {}) ⇒ Object
With Connect, you can unreject accounts that you have previously rejected.
Only accounts that were rejected by your platform can be unrejected. This API cannot be used to unreject accounts that were rejected by Stripe.
Unreject will only enable charges and/or payouts if there are no other restrictions other than those placed by a previous rejection. If you have separately paused charges and/or payouts outside of rejection, those pauses will remain in place after unrejection.
1459 1460 1461 1462 1463 1464 1465 1466 |
# File 'lib/stripe/resources/account.rb', line 1459 def self.unreject(account, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/accounts/%<account>s/unreject", { account: CGI.escape(account) }), params: params, opts: opts ) end |
.update(account, params = {}, opts = {}) ⇒ Object
Updates a connected account by setting the values of the parameters passed. Any parameters not provided are left unchanged.
For accounts where controller.requirement_collection is application, which includes Custom accounts, you can update any information on the account.
For accounts where controller.requirement_collection is stripe, which includes Standard and Express accounts, you can update all information until you create an [Account Link or Account Session](https://docs.stripe.com/api/account_links) to start Connect onboarding, after which some properties can no longer be updated.
To update your own account, use the Dashboard. Refer to our Connect documentation to learn more about updating accounts.
1481 1482 1483 1484 1485 1486 1487 1488 |
# File 'lib/stripe/resources/account.rb', line 1481 def self.update(account, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/accounts/%<account>s", { account: CGI.escape(account) }), params: params, opts: opts ) end |
Instance Method Details
#deauthorize(client_id = nil, opts = {}) ⇒ Object
1574 1575 1576 1577 1578 1579 1580 1581 |
# File 'lib/stripe/resources/account.rb', line 1574 def (client_id = nil, opts = {}) params = { client_id: client_id, stripe_user_id: id, } opts = @opts.merge(Util.normalize_opts(opts)) OAuth.(params, opts) end |
#delete(params = {}, opts = {}) ⇒ Object
With Connect, you can delete accounts you manage.
Test-mode accounts can be deleted at any time.
Live-mode accounts that have access to the standard dashboard and Stripe is responsible for negative account balances cannot be deleted, which includes Standard accounts. All other Live-mode accounts, can be deleted when all balances are zero.
If you want to delete your own account, use the account information tab in your account settings instead.
1382 1383 1384 1385 1386 1387 1388 1389 |
# File 'lib/stripe/resources/account.rb', line 1382 def delete(params = {}, opts = {}) request_stripe_object( method: :delete, path: format("/v1/accounts/%<account>s", { account: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#legal_entity ⇒ Object
1563 1564 1565 |
# File 'lib/stripe/resources/account.rb', line 1563 def legal_entity self["legal_entity"] end |
#legal_entity=(_legal_entity) ⇒ Object
1567 1568 1569 1570 1571 1572 |
# File 'lib/stripe/resources/account.rb', line 1567 def legal_entity=(_legal_entity) raise NoMethodError, "Overriding legal_entity can cause serious issues. Instead, set " \ "the individual fields of legal_entity like " \ "`account.legal_entity.first_name = 'Blah'`" end |
#persons(params = {}, opts = {}) ⇒ Object
Returns a list of people associated with the account's legal entity. The people are returned sorted by creation date, with the most recent people appearing first.
1397 1398 1399 1400 1401 1402 1403 1404 |
# File 'lib/stripe/resources/account.rb', line 1397 def persons(params = {}, opts = {}) request_stripe_object( method: :get, path: format("/v1/accounts/%<account>s/persons", { account: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#reject(params = {}, opts = {}) ⇒ Object
With Connect, you can reject accounts that you have flagged as suspicious.
Only accounts where your platform is liable for negative account balances, which includes Custom and Express accounts, can be rejected.
1419 1420 1421 1422 1423 1424 1425 1426 |
# File 'lib/stripe/resources/account.rb', line 1419 def reject(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/accounts/%<account>s/reject", { account: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#resource_url ⇒ Object
1492 1493 1494 1495 1496 1497 1498 |
# File 'lib/stripe/resources/account.rb', line 1492 def resource_url if self["id"] super else "/v1/account" end end |
#serialize_params(options = {}) ⇒ Object
Somewhat unfortunately, we attempt to do a special encoding trick when
serializing additional_owners under an account: when updating a value,
we actually send the update parameters up as an integer-indexed hash
rather than an array. So instead of this:
field[]=item1&field[]=item2&field[]=item3
We send this:
field[0]=item1&field[1]=item2&field[2]=item3
There are two major problems with this technique:
* Entities are addressed by array index, which is not stable and can
easily result in unexpected results between two different requests.
* A replacement of the array's contents is ambiguous with setting a
subset of the array. Because of this, the only way to shorten an
array is to unset it completely by making sure it goes into the
server as an empty string, then setting its contents again.
We're trying to get this overturned on the server side, but for now, patch in a special allowance.
1543 1544 1545 |
# File 'lib/stripe/resources/account.rb', line 1543 def serialize_params( = {}) serialize_params_account(self, super, ) end |
#serialize_params_account(_obj, update_hash, options = {}) ⇒ Object
1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 1557 |
# File 'lib/stripe/resources/account.rb', line 1547 def serialize_params_account(_obj, update_hash, = {}) if (entity = @values[:legal_entity]) && (owners = entity[:additional_owners]) entity_update = update_hash[:legal_entity] ||= {} entity_update[:additional_owners] = serialize_additional_owners(entity, owners) end if (individual = @values[:individual]) && individual.is_a?(Person) && !update_hash.key?(:individual) update_hash[:individual] = individual.serialize_params() end update_hash end |
#unreject(params = {}, opts = {}) ⇒ Object
With Connect, you can unreject accounts that you have previously rejected.
Only accounts that were rejected by your platform can be unrejected. This API cannot be used to unreject accounts that were rejected by Stripe.
Unreject will only enable charges and/or payouts if there are no other restrictions other than those placed by a previous rejection. If you have separately paused charges and/or payouts outside of rejection, those pauses will remain in place after unrejection.
1445 1446 1447 1448 1449 1450 1451 1452 |
# File 'lib/stripe/resources/account.rb', line 1445 def unreject(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/accounts/%<account>s/unreject", { account: CGI.escape(self["id"]) }), params: params, opts: opts ) end |