Class: Stripe::Account

Overview

For new integrations, we recommend using the [Accounts v2 API](docs.stripe.com/api/v2/core/accounts), in place of /v1/accounts and /v1/customers to represent a user.

This is an object representing a Stripe account. You can retrieve it to see properties on the account like its current requirements or if the account is enabled to make live charges or receive payouts.

For accounts where [controller.requirement_collection](docs.stripe.com/api/accounts/object#account_object-controller-requirement_collection) is ‘application`, which includes Custom accounts, the properties below are always returned.

For accounts where [controller.requirement_collection](docs.stripe.com/api/accounts/object#account_object-controller-requirement_collection) is ‘stripe`, which includes Standard and Express accounts, some properties are only returned until you create an [Account Link](docs.stripe.com/api/account_links) or [Account Session](docs.stripe.com/api/account_sessions) to start Connect Onboarding. Learn about the [differences between accounts](docs.stripe.com/connect/accounts).

Defined Under Namespace

Classes: BusinessProfile, Capabilities, Company, Controller, FutureRequirements, Groups, Requirements, RiskControls, Settings, TosAcceptance

Constant Summary collapse

OBJECT_NAME =
"account"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Stripe::APIOperations::Create

create

Methods included from Stripe::APIOperations::List

list

Methods included from Stripe::APIOperations::NestedResource

nested_resource_class_methods

Methods included from Stripe::APIOperations::Save

included, #save

Methods included from Stripe::APIOperations::Delete

included

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, save_nested_resource

Methods included from Stripe::APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#business_profileObject (readonly)

Business information about the account.



1239
1240
1241
# File 'lib/stripe/resources/account.rb', line 1239

def business_profile
  @business_profile
end

#business_typeObject (readonly)

The business type.



1241
1242
1243
# File 'lib/stripe/resources/account.rb', line 1241

def business_type
  @business_type
end

#capabilitiesObject (readonly)

Attribute for field capabilities



1243
1244
1245
# File 'lib/stripe/resources/account.rb', line 1243

def capabilities
  @capabilities
end

#charges_enabledObject (readonly)

Whether the account can process charges.



1245
1246
1247
# File 'lib/stripe/resources/account.rb', line 1245

def charges_enabled
  @charges_enabled
end

#companyObject (readonly)

Attribute for field company



1247
1248
1249
# File 'lib/stripe/resources/account.rb', line 1247

def company
  @company
end

#controllerObject (readonly)

Attribute for field controller



1249
1250
1251
# File 'lib/stripe/resources/account.rb', line 1249

def controller
  @controller
end

#countryObject (readonly)

The account’s country.



1251
1252
1253
# File 'lib/stripe/resources/account.rb', line 1251

def country
  @country
end

#createdObject (readonly)

Time at which the account was connected. Measured in seconds since the Unix epoch.



1253
1254
1255
# File 'lib/stripe/resources/account.rb', line 1253

def created
  @created
end

#default_currencyObject (readonly)

Three-letter ISO currency code representing the default currency for the account. This must be a currency that [Stripe supports in the account’s country](stripe.com/docs/payouts).



1255
1256
1257
# File 'lib/stripe/resources/account.rb', line 1255

def default_currency
  @default_currency
end

#deletedObject (readonly)

Always true for a deleted object



1257
1258
1259
# File 'lib/stripe/resources/account.rb', line 1257

def deleted
  @deleted
end

#details_submittedObject (readonly)

Whether account details have been submitted. Accounts with Stripe Dashboard access, which includes Standard accounts, cannot receive payouts before this is true. Accounts where this is false should be directed to [an onboarding flow](/connect/onboarding) to finish submitting account details.



1259
1260
1261
# File 'lib/stripe/resources/account.rb', line 1259

def 
  @details_submitted
end

#emailObject (readonly)

An email address associated with the account. It’s not used for authentication and Stripe doesn’t market to this field without explicit approval from the platform.



1261
1262
1263
# File 'lib/stripe/resources/account.rb', line 1261

def email
  @email
end

#external_accountsObject (readonly)

External accounts (bank accounts and debit cards) currently attached to this account. External accounts are only returned for requests where ‘controller` is true.



1263
1264
1265
# File 'lib/stripe/resources/account.rb', line 1263

def external_accounts
  @external_accounts
end

#future_requirementsObject (readonly)

Attribute for field future_requirements



1265
1266
1267
# File 'lib/stripe/resources/account.rb', line 1265

def future_requirements
  @future_requirements
end

#groupsObject (readonly)

The groups associated with the account.



1267
1268
1269
# File 'lib/stripe/resources/account.rb', line 1267

def groups
  @groups
end

#idObject (readonly)

Unique identifier for the object.



1269
1270
1271
# File 'lib/stripe/resources/account.rb', line 1269

def id
  @id
end

#individualObject (readonly)

This is an object representing a person associated with a Stripe account.

A platform can only access a subset of data in a person for an account where [account.controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is ‘stripe`, which includes Standard and Express accounts, after creating an Account Link or Account Session to start Connect onboarding.

See the [Standard onboarding](/connect/standard-accounts) or [Express onboarding](/connect/express-accounts) documentation for information about prefilling information and account onboarding steps. Learn more about [handling identity verification with the API](/connect/handling-api-verification#person-information).



1275
1276
1277
# File 'lib/stripe/resources/account.rb', line 1275

def individual
  @individual
end

#metadataObject (readonly)

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



1277
1278
1279
# File 'lib/stripe/resources/account.rb', line 1277

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



1279
1280
1281
# File 'lib/stripe/resources/account.rb', line 1279

def object
  @object
end

#payouts_enabledObject (readonly)

Whether the funds in this account can be paid out.



1281
1282
1283
# File 'lib/stripe/resources/account.rb', line 1281

def payouts_enabled
  @payouts_enabled
end

#requirementsObject (readonly)

Attribute for field requirements



1283
1284
1285
# File 'lib/stripe/resources/account.rb', line 1283

def requirements
  @requirements
end

#risk_controlsObject (readonly)

Attribute for field risk_controls



1285
1286
1287
# File 'lib/stripe/resources/account.rb', line 1285

def risk_controls
  @risk_controls
end

#settingsObject (readonly)

Options for customizing how the account functions within Stripe.



1287
1288
1289
# File 'lib/stripe/resources/account.rb', line 1287

def settings
  @settings
end

#tos_acceptanceObject (readonly)

Attribute for field tos_acceptance



1289
1290
1291
# File 'lib/stripe/resources/account.rb', line 1289

def tos_acceptance
  @tos_acceptance
end

#typeObject (readonly)

The Stripe account type. Can be ‘standard`, `express`, `custom`, or `none`.



1291
1292
1293
# File 'lib/stripe/resources/account.rb', line 1291

def type
  @type
end

Class Method Details

.create(params = {}, opts = {}) ⇒ Object

With [Connect](docs.stripe.com/docs/connect), you can create Stripe accounts for your users. To do this, you’ll first need to [register your platform](dashboard.stripe.com/account/applications/settings).

If you’ve already collected information for your connected accounts, you [can prefill that information](docs.stripe.com/docs/connect/best-practices#onboarding) when creating the account. Connect Onboarding won’t ask for the prefilled information during account onboarding. You can prefill any information on the account.



1299
1300
1301
# File 'lib/stripe/resources/account.rb', line 1299

def self.create(params = {}, opts = {})
  request_stripe_object(method: :post, path: "/v1/accounts", params: params, opts: opts)
end

.delete(account, params = {}, opts = {}) ⇒ Object

With [Connect](docs.stripe.com/connect), you can delete accounts you manage.

Test-mode accounts can be deleted at any time.

Live-mode accounts that have access to the standard dashboard and Stripe is responsible for negative account balances cannot be deleted, which includes Standard accounts. All other Live-mode accounts, can be deleted when all [balances](docs.stripe.com/api/balance/balance_object) are zero.

If you want to delete your own account, use the [account information tab in your account settings](dashboard.stripe.com/settings/account) instead.



1310
1311
1312
1313
1314
1315
1316
1317
# File 'lib/stripe/resources/account.rb', line 1310

def self.delete(, params = {}, opts = {})
  request_stripe_object(
    method: :delete,
    path: format("/v1/accounts/%<account>s", { account: CGI.escape() }),
    params: params,
    opts: opts
  )
end

.field_remappingsObject



1545
1546
1547
# File 'lib/stripe/resources/account.rb', line 1545

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1530
1531
1532
1533
1534
1535
1536
1537
1538
1539
1540
1541
1542
1543
# File 'lib/stripe/resources/account.rb', line 1530

def self.inner_class_types
  @inner_class_types = {
    business_profile: BusinessProfile,
    capabilities: Capabilities,
    company: Company,
    controller: Controller,
    future_requirements: FutureRequirements,
    groups: Groups,
    requirements: Requirements,
    risk_controls: RiskControls,
    settings: Settings,
    tos_acceptance: TosAcceptance,
  }
end

.list(params = {}, opts = {}) ⇒ Object

Returns a list of accounts connected to your platform via [Connect](docs.stripe.com/docs/connect). If you’re not a platform, the list is empty.



1336
1337
1338
# File 'lib/stripe/resources/account.rb', line 1336

def self.list(params = {}, opts = {})
  request_stripe_object(method: :get, path: "/v1/accounts", params: params, opts: opts)
end

.object_nameObject



27
28
29
# File 'lib/stripe/resources/account.rb', line 27

def self.object_name
  "account"
end

.persons(account, params = {}, opts = {}) ⇒ Object

Returns a list of people associated with the account’s legal entity. The people are returned sorted by creation date, with the most recent people appearing first.



1351
1352
1353
1354
1355
1356
1357
1358
# File 'lib/stripe/resources/account.rb', line 1351

def self.persons(, params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: format("/v1/accounts/%<account>s/persons", { account: CGI.escape() }),
    params: params,
    opts: opts
  )
end

.protected_fieldsObject



1475
1476
1477
# File 'lib/stripe/resources/account.rb', line 1475

def self.protected_fields
  [:legal_entity]
end

.reject(account, params = {}, opts = {}) ⇒ Object

With [Connect](docs.stripe.com/connect), you can reject accounts that you have flagged as suspicious.

Only accounts where your platform is liable for negative account balances, which includes Custom and Express accounts, can be rejected. Test-mode accounts can be rejected at any time. Live-mode accounts can only be rejected after all balances are zero.



1375
1376
1377
1378
1379
1380
1381
1382
# File 'lib/stripe/resources/account.rb', line 1375

def self.reject(, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/accounts/%<account>s/reject", { account: CGI.escape() }),
    params: params,
    opts: opts
  )
end

.retrieve(id = nil, opts = {}) ⇒ Object



1417
1418
1419
1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
# File 'lib/stripe/resources/account.rb', line 1417

def self.retrieve(id = nil, opts = {})
  Util.check_string_argument!(id) if id

  # Account used to be a singleton, where this method's signature was
  # `(opts={})`. For the sake of not breaking folks who pass in an OAuth
  # key in opts, let's lurkily string match for it.
  if opts == {} && id.is_a?(String) && id.start_with?("sk_")
    # `super` properly assumes a String opts is the apiKey and normalizes
    # as expected.
    opts = id
    id = nil
  end
  super
end

.update(account, params = {}, opts = {}) ⇒ Object

Updates a [connected account](docs.stripe.com/connect/accounts) by setting the values of the parameters passed. Any parameters not provided are left unchanged.

For accounts where [controller.requirement_collection](docs.stripe.com/api/accounts/object#account_object-controller-requirement_collection) is application, which includes Custom accounts, you can update any information on the account.

For accounts where [controller.requirement_collection](docs.stripe.com/api/accounts/object#account_object-controller-requirement_collection) is stripe, which includes Standard and Express accounts, you can update all information until you create an [Account Link or <a href=“/api/account_sessions”>Account Session](docs.stripe.com/api/account_links) to start Connect onboarding, after which some properties can no longer be updated.

To update your own account, use the [Dashboard](dashboard.stripe.com/settings/account). Refer to our [Connect](docs.stripe.com/docs/connect/updating-accounts) documentation to learn more about updating accounts.



1397
1398
1399
1400
1401
1402
1403
1404
# File 'lib/stripe/resources/account.rb', line 1397

def self.update(, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/accounts/%<account>s", { account: CGI.escape() }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#deauthorize(client_id = nil, opts = {}) ⇒ Object



1490
1491
1492
1493
1494
1495
1496
1497
# File 'lib/stripe/resources/account.rb', line 1490

def deauthorize(client_id = nil, opts = {})
  params = {
    client_id: client_id,
    stripe_user_id: id,
  }
  opts = @opts.merge(Util.normalize_opts(opts))
  OAuth.deauthorize(params, opts)
end

#delete(params = {}, opts = {}) ⇒ Object

With [Connect](docs.stripe.com/connect), you can delete accounts you manage.

Test-mode accounts can be deleted at any time.

Live-mode accounts that have access to the standard dashboard and Stripe is responsible for negative account balances cannot be deleted, which includes Standard accounts. All other Live-mode accounts, can be deleted when all [balances](docs.stripe.com/api/balance/balance_object) are zero.

If you want to delete your own account, use the [account information tab in your account settings](dashboard.stripe.com/settings/account) instead.



1326
1327
1328
1329
1330
1331
1332
1333
# File 'lib/stripe/resources/account.rb', line 1326

def delete(params = {}, opts = {})
  request_stripe_object(
    method: :delete,
    path: format("/v1/accounts/%<account>s", { account: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end


1479
1480
1481
# File 'lib/stripe/resources/account.rb', line 1479

def legal_entity
  self["legal_entity"]
end

Raises:

  • (NoMethodError)


1483
1484
1485
1486
1487
1488
# File 'lib/stripe/resources/account.rb', line 1483

def legal_entity=(_legal_entity)
  raise NoMethodError,
        "Overriding legal_entity can cause serious issues. Instead, set " \
        "the individual fields of legal_entity like " \
        "`account.legal_entity.first_name = 'Blah'`"
end

#persons(params = {}, opts = {}) ⇒ Object

Returns a list of people associated with the account’s legal entity. The people are returned sorted by creation date, with the most recent people appearing first.



1341
1342
1343
1344
1345
1346
1347
1348
# File 'lib/stripe/resources/account.rb', line 1341

def persons(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: format("/v1/accounts/%<account>s/persons", { account: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#reject(params = {}, opts = {}) ⇒ Object

With [Connect](docs.stripe.com/connect), you can reject accounts that you have flagged as suspicious.

Only accounts where your platform is liable for negative account balances, which includes Custom and Express accounts, can be rejected. Test-mode accounts can be rejected at any time. Live-mode accounts can only be rejected after all balances are zero.



1363
1364
1365
1366
1367
1368
1369
1370
# File 'lib/stripe/resources/account.rb', line 1363

def reject(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/accounts/%<account>s/reject", { account: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#resource_urlObject



1408
1409
1410
1411
1412
1413
1414
# File 'lib/stripe/resources/account.rb', line 1408

def resource_url
  if self["id"]
    super
  else
    "/v1/account"
  end
end

#serialize_params(options = {}) ⇒ Object

Somewhat unfortunately, we attempt to do a special encoding trick when serializing ‘additional_owners` under an account: when updating a value, we actually send the update parameters up as an integer-indexed hash rather than an array. So instead of this:

field[]=item1&field[]=item2&field[]=item3

We send this:

field[0]=item1&field[1]=item2&field[2]=item3

There are two major problems with this technique:

* Entities are addressed by array index, which is not stable and can
  easily result in unexpected results between two different requests.

* A replacement of the array's contents is ambiguous with setting a
  subset of the array. Because of this, the only way to shorten an
  array is to unset it completely by making sure it goes into the
  server as an empty string, then setting its contents again.

We’re trying to get this overturned on the server side, but for now, patch in a special allowance.



1459
1460
1461
# File 'lib/stripe/resources/account.rb', line 1459

def serialize_params(options = {})
  (self, super, options)
end

#serialize_params_account(_obj, update_hash, options = {}) ⇒ Object



1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
# File 'lib/stripe/resources/account.rb', line 1463

def (_obj, update_hash, options = {})
  if (entity = @values[:legal_entity]) && (owners = entity[:additional_owners])
    entity_update = update_hash[:legal_entity] ||= {}
    entity_update[:additional_owners] =
      serialize_additional_owners(entity, owners)
  end
  if (individual = @values[:individual]) && individual.is_a?(Person) && !update_hash.key?(:individual)
    update_hash[:individual] = individual.serialize_params(options)
  end
  update_hash
end