Class: Stripe::Account
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Account
- Extended by:
- Stripe::APIOperations::Create, Stripe::APIOperations::List, Stripe::APIOperations::NestedResource
- Defined in:
- lib/stripe/resources/account.rb
Overview
This is an object representing a Stripe account. You can retrieve it to see properties on the account like its current requirements or if the account is enabled to make live charges or receive payouts.
For accounts where [controller.requirement_collection](stripe.com/api/accounts/object#account_object-controller-requirement_collection) is ‘application`, which includes Custom accounts, the properties below are always returned.
For accounts where [controller.requirement_collection](stripe.com/api/accounts/object#account_object-controller-requirement_collection) is ‘stripe`, which includes Standard and Express accounts, some properties are only returned until you create an [Account Link](stripe.com/api/account_links) or [Account Session](stripe.com/api/account_sessions) to start Connect Onboarding. Learn about the [differences between accounts](stripe.com/connect/accounts).
Defined Under Namespace
Classes: BusinessProfile, Capabilities, Company, Controller, CreateParams, DeleteParams, FutureRequirements, Groups, ListParams, PersonsParams, RejectParams, Requirements, Settings, TosAcceptance, UpdateParams
Constant Summary collapse
- OBJECT_NAME =
"account"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#business_profile ⇒ Object
readonly
Business information about the account.
-
#business_type ⇒ Object
readonly
The business type.
-
#capabilities ⇒ Object
readonly
Attribute for field capabilities.
-
#charges_enabled ⇒ Object
readonly
Whether the account can process charges.
-
#company ⇒ Object
readonly
Attribute for field company.
-
#controller ⇒ Object
readonly
Attribute for field controller.
-
#country ⇒ Object
readonly
The account’s country.
-
#created ⇒ Object
readonly
Time at which the account was connected.
-
#default_currency ⇒ Object
readonly
Three-letter ISO currency code representing the default currency for the account.
-
#deleted ⇒ Object
readonly
Always true for a deleted object.
-
#details_submitted ⇒ Object
readonly
Whether account details have been submitted.
-
#email ⇒ Object
readonly
An email address associated with the account.
-
#external_accounts ⇒ Object
readonly
External accounts (bank accounts and debit cards) currently attached to this account.
-
#future_requirements ⇒ Object
readonly
Attribute for field future_requirements.
-
#groups ⇒ Object
readonly
The groups associated with the account.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#individual ⇒ Object
readonly
This is an object representing a person associated with a Stripe account.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#payouts_enabled ⇒ Object
readonly
Whether the funds in this account can be paid out.
-
#requirements ⇒ Object
readonly
Attribute for field requirements.
-
#settings ⇒ Object
readonly
Options for customizing how the account functions within Stripe.
-
#tos_acceptance ⇒ Object
readonly
Attribute for field tos_acceptance.
-
#type ⇒ Object
readonly
The Stripe account type.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.create(params = {}, opts = {}) ⇒ Object
With [Connect](stripe.com/docs/connect), you can create Stripe accounts for your users.
-
.delete(account, params = {}, opts = {}) ⇒ Object
With [Connect](stripe.com/connect), you can delete accounts you manage.
-
.list(params = {}, opts = {}) ⇒ Object
Returns a list of accounts connected to your platform via [Connect](stripe.com/docs/connect).
- .object_name ⇒ Object
-
.persons(account, params = {}, opts = {}) ⇒ Object
Returns a list of people associated with the account’s legal entity.
- .protected_fields ⇒ Object
-
.reject(account, params = {}, opts = {}) ⇒ Object
With [Connect](stripe.com/connect), you can reject accounts that you have flagged as suspicious.
- .retrieve(id = nil, opts = {}) ⇒ Object
-
.update(account, params = {}, opts = {}) ⇒ Object
Updates a [connected account](stripe.com/connect/accounts) by setting the values of the parameters passed.
Instance Method Summary collapse
- #deauthorize(client_id = nil, opts = {}) ⇒ Object
-
#delete(params = {}, opts = {}) ⇒ Object
With [Connect](stripe.com/connect), you can delete accounts you manage.
- #legal_entity ⇒ Object
- #legal_entity=(_legal_entity) ⇒ Object
-
#persons(params = {}, opts = {}) ⇒ Object
Returns a list of people associated with the account’s legal entity.
-
#reject(params = {}, opts = {}) ⇒ Object
With [Connect](stripe.com/connect), you can reject accounts that you have flagged as suspicious.
- #resource_url ⇒ Object
-
#serialize_params(options = {}) ⇒ Object
Somewhat unfortunately, we attempt to do a special encoding trick when serializing ‘additional_owners` under an account: when updating a value, we actually send the update parameters up as an integer-indexed hash rather than an array.
- #serialize_params_account(_obj, update_hash, options = {}) ⇒ Object
Methods included from Stripe::APIOperations::Create
Methods included from Stripe::APIOperations::List
Methods included from Stripe::APIOperations::NestedResource
Methods included from Stripe::APIOperations::Save
Methods included from Stripe::APIOperations::Delete
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, save_nested_resource
Methods included from Stripe::APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#business_profile ⇒ Object (readonly)
Business information about the account.
4678 4679 4680 |
# File 'lib/stripe/resources/account.rb', line 4678 def business_profile @business_profile end |
#business_type ⇒ Object (readonly)
The business type.
4680 4681 4682 |
# File 'lib/stripe/resources/account.rb', line 4680 def business_type @business_type end |
#capabilities ⇒ Object (readonly)
Attribute for field capabilities
4682 4683 4684 |
# File 'lib/stripe/resources/account.rb', line 4682 def capabilities @capabilities end |
#charges_enabled ⇒ Object (readonly)
Whether the account can process charges.
4684 4685 4686 |
# File 'lib/stripe/resources/account.rb', line 4684 def charges_enabled @charges_enabled end |
#company ⇒ Object (readonly)
Attribute for field company
4686 4687 4688 |
# File 'lib/stripe/resources/account.rb', line 4686 def company @company end |
#controller ⇒ Object (readonly)
Attribute for field controller
4688 4689 4690 |
# File 'lib/stripe/resources/account.rb', line 4688 def controller @controller end |
#country ⇒ Object (readonly)
The account’s country.
4690 4691 4692 |
# File 'lib/stripe/resources/account.rb', line 4690 def country @country end |
#created ⇒ Object (readonly)
Time at which the account was connected. Measured in seconds since the Unix epoch.
4692 4693 4694 |
# File 'lib/stripe/resources/account.rb', line 4692 def created @created end |
#default_currency ⇒ Object (readonly)
Three-letter ISO currency code representing the default currency for the account. This must be a currency that [Stripe supports in the account’s country](stripe.com/docs/payouts).
4694 4695 4696 |
# File 'lib/stripe/resources/account.rb', line 4694 def default_currency @default_currency end |
#deleted ⇒ Object (readonly)
Always true for a deleted object
4728 4729 4730 |
# File 'lib/stripe/resources/account.rb', line 4728 def deleted @deleted end |
#details_submitted ⇒ Object (readonly)
Whether account details have been submitted. Accounts with Stripe Dashboard access, which includes Standard accounts, cannot receive payouts before this is true. Accounts where this is false should be directed to [an onboarding flow](/connect/onboarding) to finish submitting account details.
4696 4697 4698 |
# File 'lib/stripe/resources/account.rb', line 4696 def details_submitted @details_submitted end |
#email ⇒ Object (readonly)
An email address associated with the account. It’s not used for authentication and Stripe doesn’t market to this field without explicit approval from the platform.
4698 4699 4700 |
# File 'lib/stripe/resources/account.rb', line 4698 def email @email end |
#external_accounts ⇒ Object (readonly)
External accounts (bank accounts and debit cards) currently attached to this account. External accounts are only returned for requests where ‘controller` is true.
4700 4701 4702 |
# File 'lib/stripe/resources/account.rb', line 4700 def external_accounts @external_accounts end |
#future_requirements ⇒ Object (readonly)
Attribute for field future_requirements
4702 4703 4704 |
# File 'lib/stripe/resources/account.rb', line 4702 def future_requirements @future_requirements end |
#groups ⇒ Object (readonly)
The groups associated with the account.
4704 4705 4706 |
# File 'lib/stripe/resources/account.rb', line 4704 def groups @groups end |
#id ⇒ Object (readonly)
Unique identifier for the object.
4706 4707 4708 |
# File 'lib/stripe/resources/account.rb', line 4706 def id @id end |
#individual ⇒ Object (readonly)
This is an object representing a person associated with a Stripe account.
A platform can only access a subset of data in a person for an account where [account.controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is ‘stripe`, which includes Standard and Express accounts, after creating an Account Link or Account Session to start Connect onboarding.
See the [Standard onboarding](/connect/standard-accounts) or [Express onboarding](/connect/express-accounts) documentation for information about prefilling information and account onboarding steps. Learn more about [handling identity verification with the API](/connect/handling-api-verification#person-information).
4712 4713 4714 |
# File 'lib/stripe/resources/account.rb', line 4712 def individual @individual end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
4714 4715 4716 |
# File 'lib/stripe/resources/account.rb', line 4714 def @metadata end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
4716 4717 4718 |
# File 'lib/stripe/resources/account.rb', line 4716 def object @object end |
#payouts_enabled ⇒ Object (readonly)
Whether the funds in this account can be paid out.
4718 4719 4720 |
# File 'lib/stripe/resources/account.rb', line 4718 def payouts_enabled @payouts_enabled end |
#requirements ⇒ Object (readonly)
Attribute for field requirements
4720 4721 4722 |
# File 'lib/stripe/resources/account.rb', line 4720 def requirements @requirements end |
#settings ⇒ Object (readonly)
Options for customizing how the account functions within Stripe.
4722 4723 4724 |
# File 'lib/stripe/resources/account.rb', line 4722 def settings @settings end |
#tos_acceptance ⇒ Object (readonly)
Attribute for field tos_acceptance
4724 4725 4726 |
# File 'lib/stripe/resources/account.rb', line 4724 def tos_acceptance @tos_acceptance end |
#type ⇒ Object (readonly)
The Stripe account type. Can be ‘standard`, `express`, `custom`, or `none`.
4726 4727 4728 |
# File 'lib/stripe/resources/account.rb', line 4726 def type @type end |
Class Method Details
.create(params = {}, opts = {}) ⇒ Object
With [Connect](stripe.com/docs/connect), you can create Stripe accounts for your users. To do this, you’ll first need to [register your platform](dashboard.stripe.com/account/applications/settings).
If you’ve already collected information for your connected accounts, you [can prefill that information](stripe.com/docs/connect/best-practices#onboarding) when creating the account. Connect Onboarding won’t ask for the prefilled information during account onboarding. You can prefill any information on the account.
4736 4737 4738 |
# File 'lib/stripe/resources/account.rb', line 4736 def self.create(params = {}, opts = {}) request_stripe_object(method: :post, path: "/v1/accounts", params: params, opts: opts) end |
.delete(account, params = {}, opts = {}) ⇒ Object
With [Connect](stripe.com/connect), you can delete accounts you manage.
Test-mode accounts can be deleted at any time.
Live-mode accounts where Stripe is responsible for negative account balances cannot be deleted, which includes Standard accounts. Live-mode accounts where your platform is liable for negative account balances, which includes Custom and Express accounts, can be deleted when all [balances](stripe.com/api/balance/balance_object) are zero.
If you want to delete your own account, use the [account information tab in your account settings](dashboard.stripe.com/settings/account) instead.
4747 4748 4749 4750 4751 4752 4753 4754 |
# File 'lib/stripe/resources/account.rb', line 4747 def self.delete(account, params = {}, opts = {}) request_stripe_object( method: :delete, path: format("/v1/accounts/%<account>s", { account: CGI.escape(account) }), params: params, opts: opts ) end |
.list(params = {}, opts = {}) ⇒ Object
Returns a list of accounts connected to your platform via [Connect](stripe.com/docs/connect). If you’re not a platform, the list is empty.
4773 4774 4775 |
# File 'lib/stripe/resources/account.rb', line 4773 def self.list(params = {}, opts = {}) request_stripe_object(method: :get, path: "/v1/accounts", params: params, opts: opts) end |
.object_name ⇒ Object
25 26 27 |
# File 'lib/stripe/resources/account.rb', line 25 def self.object_name "account" end |
.persons(account, params = {}, opts = {}) ⇒ Object
Returns a list of people associated with the account’s legal entity. The people are returned sorted by creation date, with the most recent people appearing first.
4788 4789 4790 4791 4792 4793 4794 4795 |
# File 'lib/stripe/resources/account.rb', line 4788 def self.persons(account, params = {}, opts = {}) request_stripe_object( method: :get, path: format("/v1/accounts/%<account>s/persons", { account: CGI.escape(account) }), params: params, opts: opts ) end |
.protected_fields ⇒ Object
4912 4913 4914 |
# File 'lib/stripe/resources/account.rb', line 4912 def self.protected_fields [:legal_entity] end |
.reject(account, params = {}, opts = {}) ⇒ Object
With [Connect](stripe.com/connect), you can reject accounts that you have flagged as suspicious.
Only accounts where your platform is liable for negative account balances, which includes Custom and Express accounts, can be rejected. Test-mode accounts can be rejected at any time. Live-mode accounts can only be rejected after all balances are zero.
4812 4813 4814 4815 4816 4817 4818 4819 |
# File 'lib/stripe/resources/account.rb', line 4812 def self.reject(account, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/accounts/%<account>s/reject", { account: CGI.escape(account) }), params: params, opts: opts ) end |
.retrieve(id = nil, opts = {}) ⇒ Object
4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 4867 |
# File 'lib/stripe/resources/account.rb', line 4854 def self.retrieve(id = nil, opts = {}) Util.check_string_argument!(id) if id # Account used to be a singleton, where this method's signature was # `(opts={})`. For the sake of not breaking folks who pass in an OAuth # key in opts, let's lurkily string match for it. if opts == {} && id.is_a?(String) && id.start_with?("sk_") # `super` properly assumes a String opts is the apiKey and normalizes # as expected. opts = id id = nil end super end |
.update(account, params = {}, opts = {}) ⇒ Object
Updates a [connected account](stripe.com/connect/accounts) by setting the values of the parameters passed. Any parameters not provided are left unchanged.
For accounts where [controller.requirement_collection](stripe.com/api/accounts/object#account_object-controller-requirement_collection) is application, which includes Custom accounts, you can update any information on the account.
For accounts where [controller.requirement_collection](stripe.com/api/accounts/object#account_object-controller-requirement_collection) is stripe, which includes Standard and Express accounts, you can update all information until you create an [Account Link or <a href=“/api/account_sessions”>Account Session](stripe.com/api/account_links) to start Connect onboarding, after which some properties can no longer be updated.
To update your own account, use the [Dashboard](dashboard.stripe.com/settings/account). Refer to our [Connect](stripe.com/docs/connect/updating-accounts) documentation to learn more about updating accounts.
4834 4835 4836 4837 4838 4839 4840 4841 |
# File 'lib/stripe/resources/account.rb', line 4834 def self.update(account, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/accounts/%<account>s", { account: CGI.escape(account) }), params: params, opts: opts ) end |
Instance Method Details
#deauthorize(client_id = nil, opts = {}) ⇒ Object
4927 4928 4929 4930 4931 4932 4933 4934 |
# File 'lib/stripe/resources/account.rb', line 4927 def (client_id = nil, opts = {}) params = { client_id: client_id, stripe_user_id: id, } opts = @opts.merge(Util.normalize_opts(opts)) OAuth.(params, opts) end |
#delete(params = {}, opts = {}) ⇒ Object
With [Connect](stripe.com/connect), you can delete accounts you manage.
Test-mode accounts can be deleted at any time.
Live-mode accounts where Stripe is responsible for negative account balances cannot be deleted, which includes Standard accounts. Live-mode accounts where your platform is liable for negative account balances, which includes Custom and Express accounts, can be deleted when all [balances](stripe.com/api/balance/balance_object) are zero.
If you want to delete your own account, use the [account information tab in your account settings](dashboard.stripe.com/settings/account) instead.
4763 4764 4765 4766 4767 4768 4769 4770 |
# File 'lib/stripe/resources/account.rb', line 4763 def delete(params = {}, opts = {}) request_stripe_object( method: :delete, path: format("/v1/accounts/%<account>s", { account: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#legal_entity ⇒ Object
4916 4917 4918 |
# File 'lib/stripe/resources/account.rb', line 4916 def legal_entity self["legal_entity"] end |
#legal_entity=(_legal_entity) ⇒ Object
4920 4921 4922 4923 4924 4925 |
# File 'lib/stripe/resources/account.rb', line 4920 def legal_entity=(_legal_entity) raise NoMethodError, "Overriding legal_entity can cause serious issues. Instead, set " \ "the individual fields of legal_entity like " \ "`account.legal_entity.first_name = 'Blah'`" end |
#persons(params = {}, opts = {}) ⇒ Object
Returns a list of people associated with the account’s legal entity. The people are returned sorted by creation date, with the most recent people appearing first.
4778 4779 4780 4781 4782 4783 4784 4785 |
# File 'lib/stripe/resources/account.rb', line 4778 def persons(params = {}, opts = {}) request_stripe_object( method: :get, path: format("/v1/accounts/%<account>s/persons", { account: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#reject(params = {}, opts = {}) ⇒ Object
With [Connect](stripe.com/connect), you can reject accounts that you have flagged as suspicious.
Only accounts where your platform is liable for negative account balances, which includes Custom and Express accounts, can be rejected. Test-mode accounts can be rejected at any time. Live-mode accounts can only be rejected after all balances are zero.
4800 4801 4802 4803 4804 4805 4806 4807 |
# File 'lib/stripe/resources/account.rb', line 4800 def reject(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/accounts/%<account>s/reject", { account: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#resource_url ⇒ Object
4845 4846 4847 4848 4849 4850 4851 |
# File 'lib/stripe/resources/account.rb', line 4845 def resource_url if self["id"] super else "/v1/account" end end |
#serialize_params(options = {}) ⇒ Object
Somewhat unfortunately, we attempt to do a special encoding trick when serializing ‘additional_owners` under an account: when updating a value, we actually send the update parameters up as an integer-indexed hash rather than an array. So instead of this:
field[]=item1&field[]=item2&field[]=item3
We send this:
field[0]=item1&field[1]=item2&field[2]=item3
There are two major problems with this technique:
* Entities are addressed by array index, which is not stable and can
easily result in unexpected results between two different requests.
* A replacement of the array's contents is ambiguous with setting a
subset of the array. Because of this, the only way to shorten an
array is to unset it completely by making sure it goes into the
server as an empty string, then setting its contents again.
We’re trying to get this overturned on the server side, but for now, patch in a special allowance.
4896 4897 4898 |
# File 'lib/stripe/resources/account.rb', line 4896 def serialize_params( = {}) serialize_params_account(self, super, ) end |
#serialize_params_account(_obj, update_hash, options = {}) ⇒ Object
4900 4901 4902 4903 4904 4905 4906 4907 4908 4909 4910 |
# File 'lib/stripe/resources/account.rb', line 4900 def serialize_params_account(_obj, update_hash, = {}) if (entity = @values[:legal_entity]) && (owners = entity[:additional_owners]) entity_update = update_hash[:legal_entity] ||= {} entity_update[:additional_owners] = serialize_additional_owners(entity, owners) end if (individual = @values[:individual]) && individual.is_a?(Person) && !update_hash.key?(:individual) update_hash[:individual] = individual.serialize_params() end update_hash end |