Class: Stripe::Account::BusinessProfile
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Account::BusinessProfile
- Defined in:
- lib/stripe/resources/account.rb
Defined Under Namespace
Classes: AnnualRevenue, MonthlyEstimatedRevenue, SupportAddress
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#annual_revenue ⇒ Object
readonly
The applicant’s gross annual revenue for its preceding fiscal year.
-
#estimated_worker_count ⇒ Object
readonly
An estimated upper bound of employees, contractors, vendors, etc.
-
#mcc ⇒ Object
readonly
[The merchant category code for the account](/connect/setting-mcc).
-
#monthly_estimated_revenue ⇒ Object
readonly
Attribute for field monthly_estimated_revenue.
-
#name ⇒ Object
readonly
The customer-facing business name.
-
#product_description ⇒ Object
readonly
Internal-only description of the product sold or service provided by the business.
-
#support_address ⇒ Object
readonly
A publicly available mailing address for sending support issues to.
-
#support_email ⇒ Object
readonly
A publicly available email address for sending support issues to.
-
#support_phone ⇒ Object
readonly
A publicly available phone number to call with support issues.
-
#support_url ⇒ Object
readonly
A publicly available website for handling support issues.
-
#url ⇒ Object
readonly
The business’s publicly available website.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#annual_revenue ⇒ Object (readonly)
The applicant’s gross annual revenue for its preceding fiscal year.
77 78 79 |
# File 'lib/stripe/resources/account.rb', line 77 def annual_revenue @annual_revenue end |
#estimated_worker_count ⇒ Object (readonly)
An estimated upper bound of employees, contractors, vendors, etc. currently working for the business.
80 81 82 |
# File 'lib/stripe/resources/account.rb', line 80 def estimated_worker_count @estimated_worker_count end |
#mcc ⇒ Object (readonly)
[The merchant category code for the account](/connect/setting-mcc). MCCs are used to classify businesses based on the goods or services they provide.
83 84 85 |
# File 'lib/stripe/resources/account.rb', line 83 def mcc @mcc end |
#monthly_estimated_revenue ⇒ Object (readonly)
Attribute for field monthly_estimated_revenue
86 87 88 |
# File 'lib/stripe/resources/account.rb', line 86 def monthly_estimated_revenue @monthly_estimated_revenue end |
#name ⇒ Object (readonly)
The customer-facing business name.
89 90 91 |
# File 'lib/stripe/resources/account.rb', line 89 def name @name end |
#product_description ⇒ Object (readonly)
Internal-only description of the product sold or service provided by the business. It’s used by Stripe for risk and underwriting purposes.
92 93 94 |
# File 'lib/stripe/resources/account.rb', line 92 def product_description @product_description end |
#support_address ⇒ Object (readonly)
A publicly available mailing address for sending support issues to.
95 96 97 |
# File 'lib/stripe/resources/account.rb', line 95 def support_address @support_address end |
#support_email ⇒ Object (readonly)
A publicly available email address for sending support issues to.
98 99 100 |
# File 'lib/stripe/resources/account.rb', line 98 def support_email @support_email end |
#support_phone ⇒ Object (readonly)
A publicly available phone number to call with support issues.
101 102 103 |
# File 'lib/stripe/resources/account.rb', line 101 def support_phone @support_phone end |
#support_url ⇒ Object (readonly)
A publicly available website for handling support issues.
104 105 106 |
# File 'lib/stripe/resources/account.rb', line 104 def support_url @support_url end |
#url ⇒ Object (readonly)
The business’s publicly available website.
107 108 109 |
# File 'lib/stripe/resources/account.rb', line 107 def url @url end |