Class: Stripe::Account::Capabilities
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Account::Capabilities
- Defined in:
- lib/stripe/resources/account.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#acss_debit_payments ⇒ Object
readonly
The status of the Canadian pre-authorized debits payments capability of the account, or whether the account can directly process Canadian pre-authorized debits charges.
-
#affirm_payments ⇒ Object
readonly
The status of the Affirm capability of the account, or whether the account can directly process Affirm charges.
-
#afterpay_clearpay_payments ⇒ Object
readonly
The status of the Afterpay Clearpay capability of the account, or whether the account can directly process Afterpay Clearpay charges.
-
#alma_payments ⇒ Object
readonly
The status of the Alma capability of the account, or whether the account can directly process Alma payments.
-
#amazon_pay_payments ⇒ Object
readonly
The status of the AmazonPay capability of the account, or whether the account can directly process AmazonPay payments.
-
#app_distribution ⇒ Object
readonly
The status of the ‘app_distribution` capability of the account, or whether the platform can distribute apps to other accounts.
-
#au_becs_debit_payments ⇒ Object
readonly
The status of the BECS Direct Debit (AU) payments capability of the account, or whether the account can directly process BECS Direct Debit (AU) charges.
-
#automatic_indirect_tax ⇒ Object
readonly
The status of the automatic_indirect_tax capability of the account.
-
#bacs_debit_payments ⇒ Object
readonly
The status of the Bacs Direct Debits payments capability of the account, or whether the account can directly process Bacs Direct Debits charges.
-
#bancontact_payments ⇒ Object
readonly
The status of the Bancontact payments capability of the account, or whether the account can directly process Bancontact charges.
-
#bank_transfer_payments ⇒ Object
readonly
The status of the customer_balance payments capability of the account, or whether the account can directly process customer_balance charges.
-
#billie_payments ⇒ Object
readonly
The status of the Billie capability of the account, or whether the account can directly process Billie payments.
-
#blik_payments ⇒ Object
readonly
The status of the blik payments capability of the account, or whether the account can directly process blik charges.
-
#boleto_payments ⇒ Object
readonly
The status of the boleto payments capability of the account, or whether the account can directly process boleto charges.
-
#card_issuing ⇒ Object
readonly
The status of the card issuing capability of the account, or whether you can use Issuing to distribute funds on cards.
-
#card_payments ⇒ Object
readonly
The status of the card payments capability of the account, or whether the account can directly process credit and debit card charges.
-
#cartes_bancaires_payments ⇒ Object
readonly
The status of the Cartes Bancaires payments capability of the account, or whether the account can directly process Cartes Bancaires card charges in EUR currency.
-
#cashapp_payments ⇒ Object
readonly
The status of the Cash App Pay capability of the account, or whether the account can directly process Cash App Pay payments.
-
#crypto_payments ⇒ Object
readonly
The status of the Crypto capability of the account, or whether the account can directly process Crypto payments.
-
#eps_payments ⇒ Object
readonly
The status of the EPS payments capability of the account, or whether the account can directly process EPS charges.
-
#fpx_payments ⇒ Object
readonly
The status of the FPX payments capability of the account, or whether the account can directly process FPX charges.
-
#gb_bank_transfer_payments ⇒ Object
readonly
The status of the GB customer_balance payments (GBP currency) capability of the account, or whether the account can directly process GB customer_balance charges.
-
#giropay_payments ⇒ Object
readonly
The status of the giropay payments capability of the account, or whether the account can directly process giropay charges.
-
#gopay_payments ⇒ Object
readonly
The status of the Gopay capability of the account, or whether the account can directly process Gopay payments.
-
#grabpay_payments ⇒ Object
readonly
The status of the GrabPay payments capability of the account, or whether the account can directly process GrabPay charges.
-
#id_bank_transfer_payments ⇒ Object
readonly
The status of the Indonesia Bank Transfer payments capability of the account, or whether the account can directly process Indonesia Bank Transfer charges.
-
#id_bank_transfer_payments_bca ⇒ Object
readonly
The status of Bank BCA onboarding of the account.
-
#ideal_payments ⇒ Object
readonly
The status of the iDEAL payments capability of the account, or whether the account can directly process iDEAL charges.
-
#india_international_payments ⇒ Object
readonly
The status of the india_international_payments capability of the account, or whether the account can process international charges (non INR) in India.
-
#jcb_payments ⇒ Object
readonly
The status of the JCB payments capability of the account, or whether the account (Japan only) can directly process JCB credit card charges in JPY currency.
-
#jp_bank_transfer_payments ⇒ Object
readonly
The status of the Japanese customer_balance payments (JPY currency) capability of the account, or whether the account can directly process Japanese customer_balance charges.
-
#kakao_pay_payments ⇒ Object
readonly
The status of the KakaoPay capability of the account, or whether the account can directly process KakaoPay payments.
-
#klarna_payments ⇒ Object
readonly
The status of the Klarna payments capability of the account, or whether the account can directly process Klarna charges.
-
#konbini_payments ⇒ Object
readonly
The status of the konbini payments capability of the account, or whether the account can directly process konbini charges.
-
#kr_card_payments ⇒ Object
readonly
The status of the KrCard capability of the account, or whether the account can directly process KrCard payments.
-
#legacy_payments ⇒ Object
readonly
The status of the legacy payments capability of the account.
-
#link_payments ⇒ Object
readonly
The status of the link_payments capability of the account, or whether the account can directly process Link charges.
-
#mb_way_payments ⇒ Object
readonly
The status of the MB WAY payments capability of the account, or whether the account can directly process MB WAY charges.
-
#mobilepay_payments ⇒ Object
readonly
The status of the MobilePay capability of the account, or whether the account can directly process MobilePay charges.
-
#multibanco_payments ⇒ Object
readonly
The status of the Multibanco payments capability of the account, or whether the account can directly process Multibanco charges.
-
#mx_bank_transfer_payments ⇒ Object
readonly
The status of the Mexican customer_balance payments (MXN currency) capability of the account, or whether the account can directly process Mexican customer_balance charges.
-
#naver_pay_payments ⇒ Object
readonly
The status of the NaverPay capability of the account, or whether the account can directly process NaverPay payments.
-
#nz_bank_account_becs_debit_payments ⇒ Object
readonly
The status of the New Zealand BECS Direct Debit payments capability of the account, or whether the account can directly process New Zealand BECS Direct Debit charges.
-
#oxxo_payments ⇒ Object
readonly
The status of the OXXO payments capability of the account, or whether the account can directly process OXXO charges.
-
#p24_payments ⇒ Object
readonly
The status of the P24 payments capability of the account, or whether the account can directly process P24 charges.
-
#pay_by_bank_payments ⇒ Object
readonly
The status of the pay_by_bank payments capability of the account, or whether the account can directly process pay_by_bank charges.
-
#payco_payments ⇒ Object
readonly
The status of the Payco capability of the account, or whether the account can directly process Payco payments.
-
#paynow_payments ⇒ Object
readonly
The status of the paynow payments capability of the account, or whether the account can directly process paynow charges.
-
#paypal_payments ⇒ Object
readonly
The status of the PayPal payments capability of the account, or whether the account can directly process PayPal charges.
-
#paypay_payments ⇒ Object
readonly
The status of the Paypay capability of the account, or whether the account can directly process Paypay payments.
-
#payto_payments ⇒ Object
readonly
The status of the PayTo capability of the account, or whether the account can directly process PayTo charges.
-
#pix_payments ⇒ Object
readonly
The status of the pix payments capability of the account, or whether the account can directly process pix charges.
-
#promptpay_payments ⇒ Object
readonly
The status of the promptpay payments capability of the account, or whether the account can directly process promptpay charges.
-
#qris_payments ⇒ Object
readonly
The status of the Qris capability of the account, or whether the account can directly process Qris payments.
-
#rechnung_payments ⇒ Object
readonly
The status of the Rechnung capability of the account, or whether the account can directly process Rechnung payments.
-
#revolut_pay_payments ⇒ Object
readonly
The status of the RevolutPay capability of the account, or whether the account can directly process RevolutPay payments.
-
#samsung_pay_payments ⇒ Object
readonly
The status of the SamsungPay capability of the account, or whether the account can directly process SamsungPay payments.
-
#satispay_payments ⇒ Object
readonly
The status of the Satispay capability of the account, or whether the account can directly process Satispay payments.
-
#sepa_bank_transfer_payments ⇒ Object
readonly
The status of the SEPA customer_balance payments (EUR currency) capability of the account, or whether the account can directly process SEPA customer_balance charges.
-
#sepa_debit_payments ⇒ Object
readonly
The status of the SEPA Direct Debits payments capability of the account, or whether the account can directly process SEPA Direct Debits charges.
-
#shopeepay_payments ⇒ Object
readonly
The status of the ShopeePay capability of the account, or whether the account can directly process ShopeePay payments.
-
#sofort_payments ⇒ Object
readonly
The status of the Sofort payments capability of the account, or whether the account can directly process Sofort charges.
-
#stripe_balance_payments ⇒ Object
readonly
The status of the stripe_balance payments capability of the account, or whether the account can directly process stripe_balance charges.
-
#sunbit_payments ⇒ Object
readonly
The status of the Sunbit capability of the account, or whether the account can directly process Sunbit payments.
-
#swish_payments ⇒ Object
readonly
The status of the Swish capability of the account, or whether the account can directly process Swish payments.
-
#tax_reporting_us_1099_k ⇒ Object
readonly
The status of the tax reporting 1099-K (US) capability of the account.
-
#tax_reporting_us_1099_misc ⇒ Object
readonly
The status of the tax reporting 1099-MISC (US) capability of the account.
-
#transfers ⇒ Object
readonly
The status of the transfers capability of the account, or whether your platform can transfer funds to the account.
-
#treasury ⇒ Object
readonly
The status of the banking capability, or whether the account can have bank accounts.
-
#treasury_evolve ⇒ Object
readonly
The status of the treasury_evolve capability of the account.
-
#treasury_fifth_third ⇒ Object
readonly
The status of the treasury_fifth_third capability of the account.
-
#treasury_goldman_sachs ⇒ Object
readonly
The status of the treasury_goldman_sachs capability of the account.
-
#twint_payments ⇒ Object
readonly
The status of the TWINT capability of the account, or whether the account can directly process TWINT charges.
-
#upi_payments ⇒ Object
readonly
The status of the upi payments capability of the account, or whether the account can directly process upi charges.
-
#us_bank_account_ach_payments ⇒ Object
readonly
The status of the US bank account ACH payments capability of the account, or whether the account can directly process US bank account charges.
-
#us_bank_transfer_payments ⇒ Object
readonly
The status of the US customer_balance payments (USD currency) capability of the account, or whether the account can directly process US customer_balance charges.
-
#zip_payments ⇒ Object
readonly
The status of the Zip capability of the account, or whether the account can directly process Zip charges.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#acss_debit_payments ⇒ Object (readonly)
The status of the Canadian pre-authorized debits payments capability of the account, or whether the account can directly process Canadian pre-authorized debits charges.
136 137 138 |
# File 'lib/stripe/resources/account.rb', line 136 def acss_debit_payments @acss_debit_payments end |
#affirm_payments ⇒ Object (readonly)
The status of the Affirm capability of the account, or whether the account can directly process Affirm charges.
138 139 140 |
# File 'lib/stripe/resources/account.rb', line 138 def affirm_payments @affirm_payments end |
#afterpay_clearpay_payments ⇒ Object (readonly)
The status of the Afterpay Clearpay capability of the account, or whether the account can directly process Afterpay Clearpay charges.
140 141 142 |
# File 'lib/stripe/resources/account.rb', line 140 def afterpay_clearpay_payments @afterpay_clearpay_payments end |
#alma_payments ⇒ Object (readonly)
The status of the Alma capability of the account, or whether the account can directly process Alma payments.
142 143 144 |
# File 'lib/stripe/resources/account.rb', line 142 def alma_payments @alma_payments end |
#amazon_pay_payments ⇒ Object (readonly)
The status of the AmazonPay capability of the account, or whether the account can directly process AmazonPay payments.
144 145 146 |
# File 'lib/stripe/resources/account.rb', line 144 def amazon_pay_payments @amazon_pay_payments end |
#app_distribution ⇒ Object (readonly)
The status of the ‘app_distribution` capability of the account, or whether the platform can distribute apps to other accounts.
146 147 148 |
# File 'lib/stripe/resources/account.rb', line 146 def app_distribution @app_distribution end |
#au_becs_debit_payments ⇒ Object (readonly)
The status of the BECS Direct Debit (AU) payments capability of the account, or whether the account can directly process BECS Direct Debit (AU) charges.
148 149 150 |
# File 'lib/stripe/resources/account.rb', line 148 def au_becs_debit_payments @au_becs_debit_payments end |
#automatic_indirect_tax ⇒ Object (readonly)
The status of the automatic_indirect_tax capability of the account.
150 151 152 |
# File 'lib/stripe/resources/account.rb', line 150 def automatic_indirect_tax @automatic_indirect_tax end |
#bacs_debit_payments ⇒ Object (readonly)
The status of the Bacs Direct Debits payments capability of the account, or whether the account can directly process Bacs Direct Debits charges.
152 153 154 |
# File 'lib/stripe/resources/account.rb', line 152 def bacs_debit_payments @bacs_debit_payments end |
#bancontact_payments ⇒ Object (readonly)
The status of the Bancontact payments capability of the account, or whether the account can directly process Bancontact charges.
154 155 156 |
# File 'lib/stripe/resources/account.rb', line 154 def bancontact_payments @bancontact_payments end |
#bank_transfer_payments ⇒ Object (readonly)
The status of the customer_balance payments capability of the account, or whether the account can directly process customer_balance charges.
156 157 158 |
# File 'lib/stripe/resources/account.rb', line 156 def bank_transfer_payments @bank_transfer_payments end |
#billie_payments ⇒ Object (readonly)
The status of the Billie capability of the account, or whether the account can directly process Billie payments.
158 159 160 |
# File 'lib/stripe/resources/account.rb', line 158 def billie_payments @billie_payments end |
#blik_payments ⇒ Object (readonly)
The status of the blik payments capability of the account, or whether the account can directly process blik charges.
160 161 162 |
# File 'lib/stripe/resources/account.rb', line 160 def blik_payments @blik_payments end |
#boleto_payments ⇒ Object (readonly)
The status of the boleto payments capability of the account, or whether the account can directly process boleto charges.
162 163 164 |
# File 'lib/stripe/resources/account.rb', line 162 def boleto_payments @boleto_payments end |
#card_issuing ⇒ Object (readonly)
The status of the card issuing capability of the account, or whether you can use Issuing to distribute funds on cards
164 165 166 |
# File 'lib/stripe/resources/account.rb', line 164 def card_issuing @card_issuing end |
#card_payments ⇒ Object (readonly)
The status of the card payments capability of the account, or whether the account can directly process credit and debit card charges.
166 167 168 |
# File 'lib/stripe/resources/account.rb', line 166 def card_payments @card_payments end |
#cartes_bancaires_payments ⇒ Object (readonly)
The status of the Cartes Bancaires payments capability of the account, or whether the account can directly process Cartes Bancaires card charges in EUR currency.
168 169 170 |
# File 'lib/stripe/resources/account.rb', line 168 def cartes_bancaires_payments @cartes_bancaires_payments end |
#cashapp_payments ⇒ Object (readonly)
The status of the Cash App Pay capability of the account, or whether the account can directly process Cash App Pay payments.
170 171 172 |
# File 'lib/stripe/resources/account.rb', line 170 def cashapp_payments @cashapp_payments end |
#crypto_payments ⇒ Object (readonly)
The status of the Crypto capability of the account, or whether the account can directly process Crypto payments.
172 173 174 |
# File 'lib/stripe/resources/account.rb', line 172 def crypto_payments @crypto_payments end |
#eps_payments ⇒ Object (readonly)
The status of the EPS payments capability of the account, or whether the account can directly process EPS charges.
174 175 176 |
# File 'lib/stripe/resources/account.rb', line 174 def eps_payments @eps_payments end |
#fpx_payments ⇒ Object (readonly)
The status of the FPX payments capability of the account, or whether the account can directly process FPX charges.
176 177 178 |
# File 'lib/stripe/resources/account.rb', line 176 def fpx_payments @fpx_payments end |
#gb_bank_transfer_payments ⇒ Object (readonly)
The status of the GB customer_balance payments (GBP currency) capability of the account, or whether the account can directly process GB customer_balance charges.
178 179 180 |
# File 'lib/stripe/resources/account.rb', line 178 def gb_bank_transfer_payments @gb_bank_transfer_payments end |
#giropay_payments ⇒ Object (readonly)
The status of the giropay payments capability of the account, or whether the account can directly process giropay charges.
180 181 182 |
# File 'lib/stripe/resources/account.rb', line 180 def giropay_payments @giropay_payments end |
#gopay_payments ⇒ Object (readonly)
The status of the Gopay capability of the account, or whether the account can directly process Gopay payments.
182 183 184 |
# File 'lib/stripe/resources/account.rb', line 182 def gopay_payments @gopay_payments end |
#grabpay_payments ⇒ Object (readonly)
The status of the GrabPay payments capability of the account, or whether the account can directly process GrabPay charges.
184 185 186 |
# File 'lib/stripe/resources/account.rb', line 184 def grabpay_payments @grabpay_payments end |
#id_bank_transfer_payments ⇒ Object (readonly)
The status of the Indonesia Bank Transfer payments capability of the account, or whether the account can directly process Indonesia Bank Transfer charges.
186 187 188 |
# File 'lib/stripe/resources/account.rb', line 186 def id_bank_transfer_payments @id_bank_transfer_payments end |
#id_bank_transfer_payments_bca ⇒ Object (readonly)
The status of Bank BCA onboarding of the account.
188 189 190 |
# File 'lib/stripe/resources/account.rb', line 188 def id_bank_transfer_payments_bca @id_bank_transfer_payments_bca end |
#ideal_payments ⇒ Object (readonly)
The status of the iDEAL payments capability of the account, or whether the account can directly process iDEAL charges.
190 191 192 |
# File 'lib/stripe/resources/account.rb', line 190 def ideal_payments @ideal_payments end |
#india_international_payments ⇒ Object (readonly)
The status of the india_international_payments capability of the account, or whether the account can process international charges (non INR) in India.
192 193 194 |
# File 'lib/stripe/resources/account.rb', line 192 def india_international_payments @india_international_payments end |
#jcb_payments ⇒ Object (readonly)
The status of the JCB payments capability of the account, or whether the account (Japan only) can directly process JCB credit card charges in JPY currency.
194 195 196 |
# File 'lib/stripe/resources/account.rb', line 194 def jcb_payments @jcb_payments end |
#jp_bank_transfer_payments ⇒ Object (readonly)
The status of the Japanese customer_balance payments (JPY currency) capability of the account, or whether the account can directly process Japanese customer_balance charges.
196 197 198 |
# File 'lib/stripe/resources/account.rb', line 196 def jp_bank_transfer_payments @jp_bank_transfer_payments end |
#kakao_pay_payments ⇒ Object (readonly)
The status of the KakaoPay capability of the account, or whether the account can directly process KakaoPay payments.
198 199 200 |
# File 'lib/stripe/resources/account.rb', line 198 def kakao_pay_payments @kakao_pay_payments end |
#klarna_payments ⇒ Object (readonly)
The status of the Klarna payments capability of the account, or whether the account can directly process Klarna charges.
200 201 202 |
# File 'lib/stripe/resources/account.rb', line 200 def klarna_payments @klarna_payments end |
#konbini_payments ⇒ Object (readonly)
The status of the konbini payments capability of the account, or whether the account can directly process konbini charges.
202 203 204 |
# File 'lib/stripe/resources/account.rb', line 202 def konbini_payments @konbini_payments end |
#kr_card_payments ⇒ Object (readonly)
The status of the KrCard capability of the account, or whether the account can directly process KrCard payments.
204 205 206 |
# File 'lib/stripe/resources/account.rb', line 204 def kr_card_payments @kr_card_payments end |
#legacy_payments ⇒ Object (readonly)
The status of the legacy payments capability of the account.
206 207 208 |
# File 'lib/stripe/resources/account.rb', line 206 def legacy_payments @legacy_payments end |
#link_payments ⇒ Object (readonly)
The status of the link_payments capability of the account, or whether the account can directly process Link charges.
208 209 210 |
# File 'lib/stripe/resources/account.rb', line 208 def link_payments @link_payments end |
#mb_way_payments ⇒ Object (readonly)
The status of the MB WAY payments capability of the account, or whether the account can directly process MB WAY charges.
210 211 212 |
# File 'lib/stripe/resources/account.rb', line 210 def mb_way_payments @mb_way_payments end |
#mobilepay_payments ⇒ Object (readonly)
The status of the MobilePay capability of the account, or whether the account can directly process MobilePay charges.
212 213 214 |
# File 'lib/stripe/resources/account.rb', line 212 def mobilepay_payments @mobilepay_payments end |
#multibanco_payments ⇒ Object (readonly)
The status of the Multibanco payments capability of the account, or whether the account can directly process Multibanco charges.
214 215 216 |
# File 'lib/stripe/resources/account.rb', line 214 def multibanco_payments @multibanco_payments end |
#mx_bank_transfer_payments ⇒ Object (readonly)
The status of the Mexican customer_balance payments (MXN currency) capability of the account, or whether the account can directly process Mexican customer_balance charges.
216 217 218 |
# File 'lib/stripe/resources/account.rb', line 216 def mx_bank_transfer_payments @mx_bank_transfer_payments end |
#naver_pay_payments ⇒ Object (readonly)
The status of the NaverPay capability of the account, or whether the account can directly process NaverPay payments.
218 219 220 |
# File 'lib/stripe/resources/account.rb', line 218 def naver_pay_payments @naver_pay_payments end |
#nz_bank_account_becs_debit_payments ⇒ Object (readonly)
The status of the New Zealand BECS Direct Debit payments capability of the account, or whether the account can directly process New Zealand BECS Direct Debit charges.
220 221 222 |
# File 'lib/stripe/resources/account.rb', line 220 def nz_bank_account_becs_debit_payments @nz_bank_account_becs_debit_payments end |
#oxxo_payments ⇒ Object (readonly)
The status of the OXXO payments capability of the account, or whether the account can directly process OXXO charges.
222 223 224 |
# File 'lib/stripe/resources/account.rb', line 222 def oxxo_payments @oxxo_payments end |
#p24_payments ⇒ Object (readonly)
The status of the P24 payments capability of the account, or whether the account can directly process P24 charges.
224 225 226 |
# File 'lib/stripe/resources/account.rb', line 224 def p24_payments @p24_payments end |
#pay_by_bank_payments ⇒ Object (readonly)
The status of the pay_by_bank payments capability of the account, or whether the account can directly process pay_by_bank charges.
226 227 228 |
# File 'lib/stripe/resources/account.rb', line 226 def pay_by_bank_payments @pay_by_bank_payments end |
#payco_payments ⇒ Object (readonly)
The status of the Payco capability of the account, or whether the account can directly process Payco payments.
228 229 230 |
# File 'lib/stripe/resources/account.rb', line 228 def payco_payments @payco_payments end |
#paynow_payments ⇒ Object (readonly)
The status of the paynow payments capability of the account, or whether the account can directly process paynow charges.
230 231 232 |
# File 'lib/stripe/resources/account.rb', line 230 def paynow_payments @paynow_payments end |
#paypal_payments ⇒ Object (readonly)
The status of the PayPal payments capability of the account, or whether the account can directly process PayPal charges.
232 233 234 |
# File 'lib/stripe/resources/account.rb', line 232 def paypal_payments @paypal_payments end |
#paypay_payments ⇒ Object (readonly)
The status of the Paypay capability of the account, or whether the account can directly process Paypay payments.
234 235 236 |
# File 'lib/stripe/resources/account.rb', line 234 def paypay_payments @paypay_payments end |
#payto_payments ⇒ Object (readonly)
The status of the PayTo capability of the account, or whether the account can directly process PayTo charges.
236 237 238 |
# File 'lib/stripe/resources/account.rb', line 236 def payto_payments @payto_payments end |
#pix_payments ⇒ Object (readonly)
The status of the pix payments capability of the account, or whether the account can directly process pix charges.
238 239 240 |
# File 'lib/stripe/resources/account.rb', line 238 def pix_payments @pix_payments end |
#promptpay_payments ⇒ Object (readonly)
The status of the promptpay payments capability of the account, or whether the account can directly process promptpay charges.
240 241 242 |
# File 'lib/stripe/resources/account.rb', line 240 def promptpay_payments @promptpay_payments end |
#qris_payments ⇒ Object (readonly)
The status of the Qris capability of the account, or whether the account can directly process Qris payments.
242 243 244 |
# File 'lib/stripe/resources/account.rb', line 242 def qris_payments @qris_payments end |
#rechnung_payments ⇒ Object (readonly)
The status of the Rechnung capability of the account, or whether the account can directly process Rechnung payments.
244 245 246 |
# File 'lib/stripe/resources/account.rb', line 244 def rechnung_payments @rechnung_payments end |
#revolut_pay_payments ⇒ Object (readonly)
The status of the RevolutPay capability of the account, or whether the account can directly process RevolutPay payments.
246 247 248 |
# File 'lib/stripe/resources/account.rb', line 246 def revolut_pay_payments @revolut_pay_payments end |
#samsung_pay_payments ⇒ Object (readonly)
The status of the SamsungPay capability of the account, or whether the account can directly process SamsungPay payments.
248 249 250 |
# File 'lib/stripe/resources/account.rb', line 248 def samsung_pay_payments @samsung_pay_payments end |
#satispay_payments ⇒ Object (readonly)
The status of the Satispay capability of the account, or whether the account can directly process Satispay payments.
250 251 252 |
# File 'lib/stripe/resources/account.rb', line 250 def satispay_payments @satispay_payments end |
#sepa_bank_transfer_payments ⇒ Object (readonly)
The status of the SEPA customer_balance payments (EUR currency) capability of the account, or whether the account can directly process SEPA customer_balance charges.
252 253 254 |
# File 'lib/stripe/resources/account.rb', line 252 def sepa_bank_transfer_payments @sepa_bank_transfer_payments end |
#sepa_debit_payments ⇒ Object (readonly)
The status of the SEPA Direct Debits payments capability of the account, or whether the account can directly process SEPA Direct Debits charges.
254 255 256 |
# File 'lib/stripe/resources/account.rb', line 254 def sepa_debit_payments @sepa_debit_payments end |
#shopeepay_payments ⇒ Object (readonly)
The status of the ShopeePay capability of the account, or whether the account can directly process ShopeePay payments.
256 257 258 |
# File 'lib/stripe/resources/account.rb', line 256 def shopeepay_payments @shopeepay_payments end |
#sofort_payments ⇒ Object (readonly)
The status of the Sofort payments capability of the account, or whether the account can directly process Sofort charges.
258 259 260 |
# File 'lib/stripe/resources/account.rb', line 258 def sofort_payments @sofort_payments end |
#stripe_balance_payments ⇒ Object (readonly)
The status of the stripe_balance payments capability of the account, or whether the account can directly process stripe_balance charges.
260 261 262 |
# File 'lib/stripe/resources/account.rb', line 260 def stripe_balance_payments @stripe_balance_payments end |
#sunbit_payments ⇒ Object (readonly)
The status of the Sunbit capability of the account, or whether the account can directly process Sunbit payments.
262 263 264 |
# File 'lib/stripe/resources/account.rb', line 262 def sunbit_payments @sunbit_payments end |
#swish_payments ⇒ Object (readonly)
The status of the Swish capability of the account, or whether the account can directly process Swish payments.
264 265 266 |
# File 'lib/stripe/resources/account.rb', line 264 def swish_payments @swish_payments end |
#tax_reporting_us_1099_k ⇒ Object (readonly)
The status of the tax reporting 1099-K (US) capability of the account.
266 267 268 |
# File 'lib/stripe/resources/account.rb', line 266 def tax_reporting_us_1099_k @tax_reporting_us_1099_k end |
#tax_reporting_us_1099_misc ⇒ Object (readonly)
The status of the tax reporting 1099-MISC (US) capability of the account.
268 269 270 |
# File 'lib/stripe/resources/account.rb', line 268 def tax_reporting_us_1099_misc @tax_reporting_us_1099_misc end |
#transfers ⇒ Object (readonly)
The status of the transfers capability of the account, or whether your platform can transfer funds to the account.
270 271 272 |
# File 'lib/stripe/resources/account.rb', line 270 def transfers @transfers end |
#treasury ⇒ Object (readonly)
The status of the banking capability, or whether the account can have bank accounts.
272 273 274 |
# File 'lib/stripe/resources/account.rb', line 272 def treasury @treasury end |
#treasury_evolve ⇒ Object (readonly)
The status of the treasury_evolve capability of the account.
274 275 276 |
# File 'lib/stripe/resources/account.rb', line 274 def treasury_evolve @treasury_evolve end |
#treasury_fifth_third ⇒ Object (readonly)
The status of the treasury_fifth_third capability of the account.
276 277 278 |
# File 'lib/stripe/resources/account.rb', line 276 def treasury_fifth_third @treasury_fifth_third end |
#treasury_goldman_sachs ⇒ Object (readonly)
The status of the treasury_goldman_sachs capability of the account.
278 279 280 |
# File 'lib/stripe/resources/account.rb', line 278 def treasury_goldman_sachs @treasury_goldman_sachs end |
#twint_payments ⇒ Object (readonly)
The status of the TWINT capability of the account, or whether the account can directly process TWINT charges.
280 281 282 |
# File 'lib/stripe/resources/account.rb', line 280 def twint_payments @twint_payments end |
#upi_payments ⇒ Object (readonly)
The status of the upi payments capability of the account, or whether the account can directly process upi charges.
282 283 284 |
# File 'lib/stripe/resources/account.rb', line 282 def upi_payments @upi_payments end |
#us_bank_account_ach_payments ⇒ Object (readonly)
The status of the US bank account ACH payments capability of the account, or whether the account can directly process US bank account charges.
284 285 286 |
# File 'lib/stripe/resources/account.rb', line 284 def us_bank_account_ach_payments @us_bank_account_ach_payments end |
#us_bank_transfer_payments ⇒ Object (readonly)
The status of the US customer_balance payments (USD currency) capability of the account, or whether the account can directly process US customer_balance charges.
286 287 288 |
# File 'lib/stripe/resources/account.rb', line 286 def us_bank_transfer_payments @us_bank_transfer_payments end |
#zip_payments ⇒ Object (readonly)
The status of the Zip capability of the account, or whether the account can directly process Zip charges.
288 289 290 |
# File 'lib/stripe/resources/account.rb', line 288 def zip_payments @zip_payments end |
Class Method Details
.field_remappings ⇒ Object
294 295 296 |
# File 'lib/stripe/resources/account.rb', line 294 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
290 291 292 |
# File 'lib/stripe/resources/account.rb', line 290 def self.inner_class_types @inner_class_types = {} end |