Class: Stripe::Account::Capabilities
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Account::Capabilities
- Defined in:
- lib/stripe/resources/account.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#acss_debit_payments ⇒ Object
readonly
The status of the Canadian pre-authorized debits payments capability of the account, or whether the account can directly process Canadian pre-authorized debits charges.
-
#affirm_payments ⇒ Object
readonly
The status of the Affirm capability of the account, or whether the account can directly process Affirm charges.
-
#afterpay_clearpay_payments ⇒ Object
readonly
The status of the Afterpay Clearpay capability of the account, or whether the account can directly process Afterpay Clearpay charges.
-
#alma_payments ⇒ Object
readonly
The status of the Alma capability of the account, or whether the account can directly process Alma payments.
-
#amazon_pay_payments ⇒ Object
readonly
The status of the AmazonPay capability of the account, or whether the account can directly process AmazonPay payments.
-
#au_becs_debit_payments ⇒ Object
readonly
The status of the BECS Direct Debit (AU) payments capability of the account, or whether the account can directly process BECS Direct Debit (AU) charges.
-
#automatic_indirect_tax ⇒ Object
readonly
The status of the automatic_indirect_tax capability of the account.
-
#bacs_debit_payments ⇒ Object
readonly
The status of the Bacs Direct Debits payments capability of the account, or whether the account can directly process Bacs Direct Debits charges.
-
#bancontact_payments ⇒ Object
readonly
The status of the Bancontact payments capability of the account, or whether the account can directly process Bancontact charges.
-
#bank_transfer_payments ⇒ Object
readonly
The status of the customer_balance payments capability of the account, or whether the account can directly process customer_balance charges.
-
#blik_payments ⇒ Object
readonly
The status of the blik payments capability of the account, or whether the account can directly process blik charges.
-
#boleto_payments ⇒ Object
readonly
The status of the boleto payments capability of the account, or whether the account can directly process boleto charges.
-
#card_issuing ⇒ Object
readonly
The status of the card issuing capability of the account, or whether you can use Issuing to distribute funds on cards.
-
#card_payments ⇒ Object
readonly
The status of the card payments capability of the account, or whether the account can directly process credit and debit card charges.
-
#cartes_bancaires_payments ⇒ Object
readonly
The status of the Cartes Bancaires payments capability of the account, or whether the account can directly process Cartes Bancaires card charges in EUR currency.
-
#cashapp_payments ⇒ Object
readonly
The status of the Cash App Pay capability of the account, or whether the account can directly process Cash App Pay payments.
-
#eps_payments ⇒ Object
readonly
The status of the EPS payments capability of the account, or whether the account can directly process EPS charges.
-
#fpx_payments ⇒ Object
readonly
The status of the FPX payments capability of the account, or whether the account can directly process FPX charges.
-
#gb_bank_transfer_payments ⇒ Object
readonly
The status of the GB customer_balance payments (GBP currency) capability of the account, or whether the account can directly process GB customer_balance charges.
-
#giropay_payments ⇒ Object
readonly
The status of the giropay payments capability of the account, or whether the account can directly process giropay charges.
-
#gopay_payments ⇒ Object
readonly
The status of the Gopay capability of the account, or whether the account can directly process Gopay payments.
-
#grabpay_payments ⇒ Object
readonly
The status of the GrabPay payments capability of the account, or whether the account can directly process GrabPay charges.
-
#id_bank_transfer_payments ⇒ Object
readonly
The status of the Indonesia Bank Transfer payments capability of the account, or whether the account can directly process Indonesia Bank Transfer charges.
-
#id_bank_transfer_payments_bca ⇒ Object
readonly
The status of Bank BCA onboarding of the account.
-
#ideal_payments ⇒ Object
readonly
The status of the iDEAL payments capability of the account, or whether the account can directly process iDEAL charges.
-
#india_international_payments ⇒ Object
readonly
The status of the india_international_payments capability of the account, or whether the account can process international charges (non INR) in India.
-
#jcb_payments ⇒ Object
readonly
The status of the JCB payments capability of the account, or whether the account (Japan only) can directly process JCB credit card charges in JPY currency.
-
#jp_bank_transfer_payments ⇒ Object
readonly
The status of the Japanese customer_balance payments (JPY currency) capability of the account, or whether the account can directly process Japanese customer_balance charges.
-
#kakao_pay_payments ⇒ Object
readonly
The status of the KakaoPay capability of the account, or whether the account can directly process KakaoPay payments.
-
#klarna_payments ⇒ Object
readonly
The status of the Klarna payments capability of the account, or whether the account can directly process Klarna charges.
-
#konbini_payments ⇒ Object
readonly
The status of the konbini payments capability of the account, or whether the account can directly process konbini charges.
-
#kr_card_payments ⇒ Object
readonly
The status of the KrCard capability of the account, or whether the account can directly process KrCard payments.
-
#legacy_payments ⇒ Object
readonly
The status of the legacy payments capability of the account.
-
#link_payments ⇒ Object
readonly
The status of the link_payments capability of the account, or whether the account can directly process Link charges.
-
#mb_way_payments ⇒ Object
readonly
The status of the MB WAY payments capability of the account, or whether the account can directly process MB WAY charges.
-
#mobilepay_payments ⇒ Object
readonly
The status of the MobilePay capability of the account, or whether the account can directly process MobilePay charges.
-
#multibanco_payments ⇒ Object
readonly
The status of the Multibanco payments capability of the account, or whether the account can directly process Multibanco charges.
-
#mx_bank_transfer_payments ⇒ Object
readonly
The status of the Mexican customer_balance payments (MXN currency) capability of the account, or whether the account can directly process Mexican customer_balance charges.
-
#naver_pay_payments ⇒ Object
readonly
The status of the NaverPay capability of the account, or whether the account can directly process NaverPay payments.
-
#oxxo_payments ⇒ Object
readonly
The status of the OXXO payments capability of the account, or whether the account can directly process OXXO charges.
-
#p24_payments ⇒ Object
readonly
The status of the P24 payments capability of the account, or whether the account can directly process P24 charges.
-
#payco_payments ⇒ Object
readonly
The status of the Payco capability of the account, or whether the account can directly process Payco payments.
-
#paynow_payments ⇒ Object
readonly
The status of the paynow payments capability of the account, or whether the account can directly process paynow charges.
-
#paypal_payments ⇒ Object
readonly
The status of the PayPal payments capability of the account, or whether the account can directly process PayPal charges.
-
#payto_payments ⇒ Object
readonly
The status of the PayTo capability of the account, or whether the account can directly process PayTo charges.
-
#promptpay_payments ⇒ Object
readonly
The status of the promptpay payments capability of the account, or whether the account can directly process promptpay charges.
-
#qris_payments ⇒ Object
readonly
The status of the Qris capability of the account, or whether the account can directly process Qris payments.
-
#rechnung_payments ⇒ Object
readonly
The status of the Rechnung capability of the account, or whether the account can directly process Rechnung payments.
-
#revolut_pay_payments ⇒ Object
readonly
The status of the RevolutPay capability of the account, or whether the account can directly process RevolutPay payments.
-
#samsung_pay_payments ⇒ Object
readonly
The status of the SamsungPay capability of the account, or whether the account can directly process SamsungPay payments.
-
#sepa_bank_transfer_payments ⇒ Object
readonly
The status of the SEPA customer_balance payments (EUR currency) capability of the account, or whether the account can directly process SEPA customer_balance charges.
-
#sepa_debit_payments ⇒ Object
readonly
The status of the SEPA Direct Debits payments capability of the account, or whether the account can directly process SEPA Direct Debits charges.
-
#shopeepay_payments ⇒ Object
readonly
The status of the ShopeePay capability of the account, or whether the account can directly process ShopeePay payments.
-
#sofort_payments ⇒ Object
readonly
The status of the Sofort payments capability of the account, or whether the account can directly process Sofort charges.
-
#swish_payments ⇒ Object
readonly
The status of the Swish capability of the account, or whether the account can directly process Swish payments.
-
#tax_reporting_us_1099_k ⇒ Object
readonly
The status of the tax reporting 1099-K (US) capability of the account.
-
#tax_reporting_us_1099_misc ⇒ Object
readonly
The status of the tax reporting 1099-MISC (US) capability of the account.
-
#transfers ⇒ Object
readonly
The status of the transfers capability of the account, or whether your platform can transfer funds to the account.
-
#treasury ⇒ Object
readonly
The status of the banking capability, or whether the account can have bank accounts.
-
#treasury_evolve ⇒ Object
readonly
The status of the treasury_evolve capability of the account.
-
#treasury_fifth_third ⇒ Object
readonly
The status of the treasury_fifth_third capability of the account.
-
#treasury_goldman_sachs ⇒ Object
readonly
The status of the treasury_goldman_sachs capability of the account.
-
#twint_payments ⇒ Object
readonly
The status of the TWINT capability of the account, or whether the account can directly process TWINT charges.
-
#us_bank_account_ach_payments ⇒ Object
readonly
The status of the US bank account ACH payments capability of the account, or whether the account can directly process US bank account charges.
-
#us_bank_transfer_payments ⇒ Object
readonly
The status of the US customer_balance payments (USD currency) capability of the account, or whether the account can directly process US customer_balance charges.
-
#zip_payments ⇒ Object
readonly
The status of the Zip capability of the account, or whether the account can directly process Zip charges.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#acss_debit_payments ⇒ Object (readonly)
The status of the Canadian pre-authorized debits payments capability of the account, or whether the account can directly process Canadian pre-authorized debits charges.
112 113 114 |
# File 'lib/stripe/resources/account.rb', line 112 def acss_debit_payments @acss_debit_payments end |
#affirm_payments ⇒ Object (readonly)
The status of the Affirm capability of the account, or whether the account can directly process Affirm charges.
115 116 117 |
# File 'lib/stripe/resources/account.rb', line 115 def affirm_payments @affirm_payments end |
#afterpay_clearpay_payments ⇒ Object (readonly)
The status of the Afterpay Clearpay capability of the account, or whether the account can directly process Afterpay Clearpay charges.
118 119 120 |
# File 'lib/stripe/resources/account.rb', line 118 def afterpay_clearpay_payments @afterpay_clearpay_payments end |
#alma_payments ⇒ Object (readonly)
The status of the Alma capability of the account, or whether the account can directly process Alma payments.
121 122 123 |
# File 'lib/stripe/resources/account.rb', line 121 def alma_payments @alma_payments end |
#amazon_pay_payments ⇒ Object (readonly)
The status of the AmazonPay capability of the account, or whether the account can directly process AmazonPay payments.
124 125 126 |
# File 'lib/stripe/resources/account.rb', line 124 def amazon_pay_payments @amazon_pay_payments end |
#au_becs_debit_payments ⇒ Object (readonly)
The status of the BECS Direct Debit (AU) payments capability of the account, or whether the account can directly process BECS Direct Debit (AU) charges.
127 128 129 |
# File 'lib/stripe/resources/account.rb', line 127 def au_becs_debit_payments @au_becs_debit_payments end |
#automatic_indirect_tax ⇒ Object (readonly)
The status of the automatic_indirect_tax capability of the account.
130 131 132 |
# File 'lib/stripe/resources/account.rb', line 130 def automatic_indirect_tax @automatic_indirect_tax end |
#bacs_debit_payments ⇒ Object (readonly)
The status of the Bacs Direct Debits payments capability of the account, or whether the account can directly process Bacs Direct Debits charges.
133 134 135 |
# File 'lib/stripe/resources/account.rb', line 133 def bacs_debit_payments @bacs_debit_payments end |
#bancontact_payments ⇒ Object (readonly)
The status of the Bancontact payments capability of the account, or whether the account can directly process Bancontact charges.
136 137 138 |
# File 'lib/stripe/resources/account.rb', line 136 def bancontact_payments @bancontact_payments end |
#bank_transfer_payments ⇒ Object (readonly)
The status of the customer_balance payments capability of the account, or whether the account can directly process customer_balance charges.
139 140 141 |
# File 'lib/stripe/resources/account.rb', line 139 def bank_transfer_payments @bank_transfer_payments end |
#blik_payments ⇒ Object (readonly)
The status of the blik payments capability of the account, or whether the account can directly process blik charges.
142 143 144 |
# File 'lib/stripe/resources/account.rb', line 142 def blik_payments @blik_payments end |
#boleto_payments ⇒ Object (readonly)
The status of the boleto payments capability of the account, or whether the account can directly process boleto charges.
145 146 147 |
# File 'lib/stripe/resources/account.rb', line 145 def boleto_payments @boleto_payments end |
#card_issuing ⇒ Object (readonly)
The status of the card issuing capability of the account, or whether you can use Issuing to distribute funds on cards
148 149 150 |
# File 'lib/stripe/resources/account.rb', line 148 def card_issuing @card_issuing end |
#card_payments ⇒ Object (readonly)
The status of the card payments capability of the account, or whether the account can directly process credit and debit card charges.
151 152 153 |
# File 'lib/stripe/resources/account.rb', line 151 def card_payments @card_payments end |
#cartes_bancaires_payments ⇒ Object (readonly)
The status of the Cartes Bancaires payments capability of the account, or whether the account can directly process Cartes Bancaires card charges in EUR currency.
154 155 156 |
# File 'lib/stripe/resources/account.rb', line 154 def cartes_bancaires_payments @cartes_bancaires_payments end |
#cashapp_payments ⇒ Object (readonly)
The status of the Cash App Pay capability of the account, or whether the account can directly process Cash App Pay payments.
157 158 159 |
# File 'lib/stripe/resources/account.rb', line 157 def cashapp_payments @cashapp_payments end |
#eps_payments ⇒ Object (readonly)
The status of the EPS payments capability of the account, or whether the account can directly process EPS charges.
160 161 162 |
# File 'lib/stripe/resources/account.rb', line 160 def eps_payments @eps_payments end |
#fpx_payments ⇒ Object (readonly)
The status of the FPX payments capability of the account, or whether the account can directly process FPX charges.
163 164 165 |
# File 'lib/stripe/resources/account.rb', line 163 def fpx_payments @fpx_payments end |
#gb_bank_transfer_payments ⇒ Object (readonly)
The status of the GB customer_balance payments (GBP currency) capability of the account, or whether the account can directly process GB customer_balance charges.
166 167 168 |
# File 'lib/stripe/resources/account.rb', line 166 def gb_bank_transfer_payments @gb_bank_transfer_payments end |
#giropay_payments ⇒ Object (readonly)
The status of the giropay payments capability of the account, or whether the account can directly process giropay charges.
169 170 171 |
# File 'lib/stripe/resources/account.rb', line 169 def giropay_payments @giropay_payments end |
#gopay_payments ⇒ Object (readonly)
The status of the Gopay capability of the account, or whether the account can directly process Gopay payments.
172 173 174 |
# File 'lib/stripe/resources/account.rb', line 172 def gopay_payments @gopay_payments end |
#grabpay_payments ⇒ Object (readonly)
The status of the GrabPay payments capability of the account, or whether the account can directly process GrabPay charges.
175 176 177 |
# File 'lib/stripe/resources/account.rb', line 175 def grabpay_payments @grabpay_payments end |
#id_bank_transfer_payments ⇒ Object (readonly)
The status of the Indonesia Bank Transfer payments capability of the account, or whether the account can directly process Indonesia Bank Transfer charges.
178 179 180 |
# File 'lib/stripe/resources/account.rb', line 178 def id_bank_transfer_payments @id_bank_transfer_payments end |
#id_bank_transfer_payments_bca ⇒ Object (readonly)
The status of Bank BCA onboarding of the account.
181 182 183 |
# File 'lib/stripe/resources/account.rb', line 181 def id_bank_transfer_payments_bca @id_bank_transfer_payments_bca end |
#ideal_payments ⇒ Object (readonly)
The status of the iDEAL payments capability of the account, or whether the account can directly process iDEAL charges.
184 185 186 |
# File 'lib/stripe/resources/account.rb', line 184 def ideal_payments @ideal_payments end |
#india_international_payments ⇒ Object (readonly)
The status of the india_international_payments capability of the account, or whether the account can process international charges (non INR) in India.
187 188 189 |
# File 'lib/stripe/resources/account.rb', line 187 def india_international_payments @india_international_payments end |
#jcb_payments ⇒ Object (readonly)
The status of the JCB payments capability of the account, or whether the account (Japan only) can directly process JCB credit card charges in JPY currency.
190 191 192 |
# File 'lib/stripe/resources/account.rb', line 190 def jcb_payments @jcb_payments end |
#jp_bank_transfer_payments ⇒ Object (readonly)
The status of the Japanese customer_balance payments (JPY currency) capability of the account, or whether the account can directly process Japanese customer_balance charges.
193 194 195 |
# File 'lib/stripe/resources/account.rb', line 193 def jp_bank_transfer_payments @jp_bank_transfer_payments end |
#kakao_pay_payments ⇒ Object (readonly)
The status of the KakaoPay capability of the account, or whether the account can directly process KakaoPay payments.
196 197 198 |
# File 'lib/stripe/resources/account.rb', line 196 def kakao_pay_payments @kakao_pay_payments end |
#klarna_payments ⇒ Object (readonly)
The status of the Klarna payments capability of the account, or whether the account can directly process Klarna charges.
199 200 201 |
# File 'lib/stripe/resources/account.rb', line 199 def klarna_payments @klarna_payments end |
#konbini_payments ⇒ Object (readonly)
The status of the konbini payments capability of the account, or whether the account can directly process konbini charges.
202 203 204 |
# File 'lib/stripe/resources/account.rb', line 202 def konbini_payments @konbini_payments end |
#kr_card_payments ⇒ Object (readonly)
The status of the KrCard capability of the account, or whether the account can directly process KrCard payments.
205 206 207 |
# File 'lib/stripe/resources/account.rb', line 205 def kr_card_payments @kr_card_payments end |
#legacy_payments ⇒ Object (readonly)
The status of the legacy payments capability of the account.
208 209 210 |
# File 'lib/stripe/resources/account.rb', line 208 def legacy_payments @legacy_payments end |
#link_payments ⇒ Object (readonly)
The status of the link_payments capability of the account, or whether the account can directly process Link charges.
211 212 213 |
# File 'lib/stripe/resources/account.rb', line 211 def link_payments @link_payments end |
#mb_way_payments ⇒ Object (readonly)
The status of the MB WAY payments capability of the account, or whether the account can directly process MB WAY charges.
214 215 216 |
# File 'lib/stripe/resources/account.rb', line 214 def mb_way_payments @mb_way_payments end |
#mobilepay_payments ⇒ Object (readonly)
The status of the MobilePay capability of the account, or whether the account can directly process MobilePay charges.
217 218 219 |
# File 'lib/stripe/resources/account.rb', line 217 def mobilepay_payments @mobilepay_payments end |
#multibanco_payments ⇒ Object (readonly)
The status of the Multibanco payments capability of the account, or whether the account can directly process Multibanco charges.
220 221 222 |
# File 'lib/stripe/resources/account.rb', line 220 def multibanco_payments @multibanco_payments end |
#mx_bank_transfer_payments ⇒ Object (readonly)
The status of the Mexican customer_balance payments (MXN currency) capability of the account, or whether the account can directly process Mexican customer_balance charges.
223 224 225 |
# File 'lib/stripe/resources/account.rb', line 223 def mx_bank_transfer_payments @mx_bank_transfer_payments end |
#naver_pay_payments ⇒ Object (readonly)
The status of the NaverPay capability of the account, or whether the account can directly process NaverPay payments.
226 227 228 |
# File 'lib/stripe/resources/account.rb', line 226 def naver_pay_payments @naver_pay_payments end |
#oxxo_payments ⇒ Object (readonly)
The status of the OXXO payments capability of the account, or whether the account can directly process OXXO charges.
229 230 231 |
# File 'lib/stripe/resources/account.rb', line 229 def oxxo_payments @oxxo_payments end |
#p24_payments ⇒ Object (readonly)
The status of the P24 payments capability of the account, or whether the account can directly process P24 charges.
232 233 234 |
# File 'lib/stripe/resources/account.rb', line 232 def p24_payments @p24_payments end |
#payco_payments ⇒ Object (readonly)
The status of the Payco capability of the account, or whether the account can directly process Payco payments.
235 236 237 |
# File 'lib/stripe/resources/account.rb', line 235 def payco_payments @payco_payments end |
#paynow_payments ⇒ Object (readonly)
The status of the paynow payments capability of the account, or whether the account can directly process paynow charges.
238 239 240 |
# File 'lib/stripe/resources/account.rb', line 238 def paynow_payments @paynow_payments end |
#paypal_payments ⇒ Object (readonly)
The status of the PayPal payments capability of the account, or whether the account can directly process PayPal charges.
241 242 243 |
# File 'lib/stripe/resources/account.rb', line 241 def paypal_payments @paypal_payments end |
#payto_payments ⇒ Object (readonly)
The status of the PayTo capability of the account, or whether the account can directly process PayTo charges.
244 245 246 |
# File 'lib/stripe/resources/account.rb', line 244 def payto_payments @payto_payments end |
#promptpay_payments ⇒ Object (readonly)
The status of the promptpay payments capability of the account, or whether the account can directly process promptpay charges.
247 248 249 |
# File 'lib/stripe/resources/account.rb', line 247 def promptpay_payments @promptpay_payments end |
#qris_payments ⇒ Object (readonly)
The status of the Qris capability of the account, or whether the account can directly process Qris payments.
250 251 252 |
# File 'lib/stripe/resources/account.rb', line 250 def qris_payments @qris_payments end |
#rechnung_payments ⇒ Object (readonly)
The status of the Rechnung capability of the account, or whether the account can directly process Rechnung payments.
253 254 255 |
# File 'lib/stripe/resources/account.rb', line 253 def rechnung_payments @rechnung_payments end |
#revolut_pay_payments ⇒ Object (readonly)
The status of the RevolutPay capability of the account, or whether the account can directly process RevolutPay payments.
256 257 258 |
# File 'lib/stripe/resources/account.rb', line 256 def revolut_pay_payments @revolut_pay_payments end |
#samsung_pay_payments ⇒ Object (readonly)
The status of the SamsungPay capability of the account, or whether the account can directly process SamsungPay payments.
259 260 261 |
# File 'lib/stripe/resources/account.rb', line 259 def samsung_pay_payments @samsung_pay_payments end |
#sepa_bank_transfer_payments ⇒ Object (readonly)
The status of the SEPA customer_balance payments (EUR currency) capability of the account, or whether the account can directly process SEPA customer_balance charges.
262 263 264 |
# File 'lib/stripe/resources/account.rb', line 262 def sepa_bank_transfer_payments @sepa_bank_transfer_payments end |
#sepa_debit_payments ⇒ Object (readonly)
The status of the SEPA Direct Debits payments capability of the account, or whether the account can directly process SEPA Direct Debits charges.
265 266 267 |
# File 'lib/stripe/resources/account.rb', line 265 def sepa_debit_payments @sepa_debit_payments end |
#shopeepay_payments ⇒ Object (readonly)
The status of the ShopeePay capability of the account, or whether the account can directly process ShopeePay payments.
268 269 270 |
# File 'lib/stripe/resources/account.rb', line 268 def shopeepay_payments @shopeepay_payments end |
#sofort_payments ⇒ Object (readonly)
The status of the Sofort payments capability of the account, or whether the account can directly process Sofort charges.
271 272 273 |
# File 'lib/stripe/resources/account.rb', line 271 def sofort_payments @sofort_payments end |
#swish_payments ⇒ Object (readonly)
The status of the Swish capability of the account, or whether the account can directly process Swish payments.
274 275 276 |
# File 'lib/stripe/resources/account.rb', line 274 def swish_payments @swish_payments end |
#tax_reporting_us_1099_k ⇒ Object (readonly)
The status of the tax reporting 1099-K (US) capability of the account.
277 278 279 |
# File 'lib/stripe/resources/account.rb', line 277 def tax_reporting_us_1099_k @tax_reporting_us_1099_k end |
#tax_reporting_us_1099_misc ⇒ Object (readonly)
The status of the tax reporting 1099-MISC (US) capability of the account.
280 281 282 |
# File 'lib/stripe/resources/account.rb', line 280 def tax_reporting_us_1099_misc @tax_reporting_us_1099_misc end |
#transfers ⇒ Object (readonly)
The status of the transfers capability of the account, or whether your platform can transfer funds to the account.
283 284 285 |
# File 'lib/stripe/resources/account.rb', line 283 def transfers @transfers end |
#treasury ⇒ Object (readonly)
The status of the banking capability, or whether the account can have bank accounts.
286 287 288 |
# File 'lib/stripe/resources/account.rb', line 286 def treasury @treasury end |
#treasury_evolve ⇒ Object (readonly)
The status of the treasury_evolve capability of the account.
289 290 291 |
# File 'lib/stripe/resources/account.rb', line 289 def treasury_evolve @treasury_evolve end |
#treasury_fifth_third ⇒ Object (readonly)
The status of the treasury_fifth_third capability of the account.
292 293 294 |
# File 'lib/stripe/resources/account.rb', line 292 def treasury_fifth_third @treasury_fifth_third end |
#treasury_goldman_sachs ⇒ Object (readonly)
The status of the treasury_goldman_sachs capability of the account.
295 296 297 |
# File 'lib/stripe/resources/account.rb', line 295 def treasury_goldman_sachs @treasury_goldman_sachs end |
#twint_payments ⇒ Object (readonly)
The status of the TWINT capability of the account, or whether the account can directly process TWINT charges.
298 299 300 |
# File 'lib/stripe/resources/account.rb', line 298 def twint_payments @twint_payments end |
#us_bank_account_ach_payments ⇒ Object (readonly)
The status of the US bank account ACH payments capability of the account, or whether the account can directly process US bank account charges.
301 302 303 |
# File 'lib/stripe/resources/account.rb', line 301 def us_bank_account_ach_payments @us_bank_account_ach_payments end |
#us_bank_transfer_payments ⇒ Object (readonly)
The status of the US customer_balance payments (USD currency) capability of the account, or whether the account can directly process US customer_balance charges.
304 305 306 |
# File 'lib/stripe/resources/account.rb', line 304 def us_bank_transfer_payments @us_bank_transfer_payments end |
#zip_payments ⇒ Object (readonly)
The status of the Zip capability of the account, or whether the account can directly process Zip charges.
307 308 309 |
# File 'lib/stripe/resources/account.rb', line 307 def zip_payments @zip_payments end |