Class: Stripe::Account::Company
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Account::Company
- Defined in:
- lib/stripe/resources/account.rb
Defined Under Namespace
Classes: Address, AddressKana, AddressKanji, AdministrativeAddress, DirectorshipDeclaration, OwnershipDeclaration, PrincipalPlaceOfBusiness, RegistrationDate, RepresentativeDeclaration, Verification
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#address ⇒ Object
readonly
Attribute for field address.
-
#address_kana ⇒ Object
readonly
The Kana variation of the company's primary address (Japan only).
-
#address_kanji ⇒ Object
readonly
The Kanji variation of the company's primary address (Japan only).
-
#administrative_address ⇒ Object
readonly
Attribute for field administrative_address.
-
#directors_provided ⇒ Object
readonly
Whether the company's directors have been provided.
-
#directorship_declaration ⇒ Object
readonly
This hash is used to attest that the director information provided to Stripe is both current and correct.
-
#executives_provided ⇒ Object
readonly
Whether the company's executives have been provided.
-
#export_license_id ⇒ Object
readonly
The export license ID number of the company, also referred as Import Export Code (India only).
-
#export_purpose_code ⇒ Object
readonly
The purpose code to use for export transactions (India only).
-
#name ⇒ Object
readonly
The company's legal name.
-
#name_kana ⇒ Object
readonly
The Kana variation of the company's legal name (Japan only).
-
#name_kanji ⇒ Object
readonly
The Kanji variation of the company's legal name (Japan only).
-
#owners_provided ⇒ Object
readonly
Whether the company's owners have been provided.
-
#ownership_declaration ⇒ Object
readonly
This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.
-
#ownership_exemption_reason ⇒ Object
readonly
This value is used to determine if a business is exempt from providing ultimate beneficial owners.
-
#phone ⇒ Object
readonly
The company's phone number (used for verification).
-
#principal_place_of_business ⇒ Object
readonly
Attribute for field principal_place_of_business.
-
#registration_date ⇒ Object
readonly
Attribute for field registration_date.
-
#representative_declaration ⇒ Object
readonly
This hash is used to attest that the representative is authorized to act as the representative of their legal entity.
-
#structure ⇒ Object
readonly
The category identifying the legal structure of the company or legal entity.
-
#tax_id_provided ⇒ Object
readonly
Whether the company's business ID number was provided.
-
#tax_id_registrar ⇒ Object
readonly
The jurisdiction in which the
tax_idis registered (Germany-based companies only). -
#vat_id_provided ⇒ Object
readonly
Whether the company's business VAT number was provided.
-
#verification ⇒ Object
readonly
Information on the verification state of the company.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#address ⇒ Object (readonly)
Attribute for field address
494 495 496 |
# File 'lib/stripe/resources/account.rb', line 494 def address @address end |
#address_kana ⇒ Object (readonly)
The Kana variation of the company's primary address (Japan only).
496 497 498 |
# File 'lib/stripe/resources/account.rb', line 496 def address_kana @address_kana end |
#address_kanji ⇒ Object (readonly)
The Kanji variation of the company's primary address (Japan only).
498 499 500 |
# File 'lib/stripe/resources/account.rb', line 498 def address_kanji @address_kanji end |
#administrative_address ⇒ Object (readonly)
Attribute for field administrative_address
500 501 502 |
# File 'lib/stripe/resources/account.rb', line 500 def administrative_address @administrative_address end |
#directors_provided ⇒ Object (readonly)
Whether the company's directors have been provided. This Boolean will be true if you've manually indicated that all directors are provided via the directors_provided parameter.
502 503 504 |
# File 'lib/stripe/resources/account.rb', line 502 def directors_provided @directors_provided end |
#directorship_declaration ⇒ Object (readonly)
This hash is used to attest that the director information provided to Stripe is both current and correct.
504 505 506 |
# File 'lib/stripe/resources/account.rb', line 504 def directorship_declaration @directorship_declaration end |
#executives_provided ⇒ Object (readonly)
Whether the company's executives have been provided. This Boolean will be true if you've manually indicated that all executives are provided via the executives_provided parameter, or if Stripe determined that sufficient executives were provided.
506 507 508 |
# File 'lib/stripe/resources/account.rb', line 506 def executives_provided @executives_provided end |
#export_license_id ⇒ Object (readonly)
The export license ID number of the company, also referred as Import Export Code (India only).
508 509 510 |
# File 'lib/stripe/resources/account.rb', line 508 def export_license_id @export_license_id end |
#export_purpose_code ⇒ Object (readonly)
The purpose code to use for export transactions (India only).
510 511 512 |
# File 'lib/stripe/resources/account.rb', line 510 def export_purpose_code @export_purpose_code end |
#name ⇒ Object (readonly)
The company's legal name. Also available for accounts where controller.requirement_collection is stripe.
512 513 514 |
# File 'lib/stripe/resources/account.rb', line 512 def name @name end |
#name_kana ⇒ Object (readonly)
The Kana variation of the company's legal name (Japan only). Also available for accounts where controller.requirement_collection is stripe.
514 515 516 |
# File 'lib/stripe/resources/account.rb', line 514 def name_kana @name_kana end |
#name_kanji ⇒ Object (readonly)
The Kanji variation of the company's legal name (Japan only). Also available for accounts where controller.requirement_collection is stripe.
516 517 518 |
# File 'lib/stripe/resources/account.rb', line 516 def name_kanji @name_kanji end |
#owners_provided ⇒ Object (readonly)
Whether the company's owners have been provided. This Boolean will be true if you've manually indicated that all owners are provided via the owners_provided parameter, or if Stripe determined that sufficient owners were provided. Stripe determines ownership requirements using both the number of owners provided and their total percent ownership (calculated by adding the percent_ownership of each owner together).
518 519 520 |
# File 'lib/stripe/resources/account.rb', line 518 def owners_provided @owners_provided end |
#ownership_declaration ⇒ Object (readonly)
This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.
520 521 522 |
# File 'lib/stripe/resources/account.rb', line 520 def ownership_declaration @ownership_declaration end |
#ownership_exemption_reason ⇒ Object (readonly)
This value is used to determine if a business is exempt from providing ultimate beneficial owners. See this support article and changelog for more details.
522 523 524 |
# File 'lib/stripe/resources/account.rb', line 522 def ownership_exemption_reason @ownership_exemption_reason end |
#phone ⇒ Object (readonly)
The company's phone number (used for verification).
524 525 526 |
# File 'lib/stripe/resources/account.rb', line 524 def phone @phone end |
#principal_place_of_business ⇒ Object (readonly)
Attribute for field principal_place_of_business
526 527 528 |
# File 'lib/stripe/resources/account.rb', line 526 def principal_place_of_business @principal_place_of_business end |
#registration_date ⇒ Object (readonly)
Attribute for field registration_date
528 529 530 |
# File 'lib/stripe/resources/account.rb', line 528 def registration_date @registration_date end |
#representative_declaration ⇒ Object (readonly)
This hash is used to attest that the representative is authorized to act as the representative of their legal entity.
530 531 532 |
# File 'lib/stripe/resources/account.rb', line 530 def representative_declaration @representative_declaration end |
#structure ⇒ Object (readonly)
The category identifying the legal structure of the company or legal entity. Also available for accounts where controller.requirement_collection is stripe. See Business structure for more details.
532 533 534 |
# File 'lib/stripe/resources/account.rb', line 532 def structure @structure end |
#tax_id_provided ⇒ Object (readonly)
Whether the company's business ID number was provided.
534 535 536 |
# File 'lib/stripe/resources/account.rb', line 534 def tax_id_provided @tax_id_provided end |
#tax_id_registrar ⇒ Object (readonly)
The jurisdiction in which the tax_id is registered (Germany-based companies only).
536 537 538 |
# File 'lib/stripe/resources/account.rb', line 536 def tax_id_registrar @tax_id_registrar end |
#vat_id_provided ⇒ Object (readonly)
Whether the company's business VAT number was provided.
538 539 540 |
# File 'lib/stripe/resources/account.rb', line 538 def vat_id_provided @vat_id_provided end |
#verification ⇒ Object (readonly)
Information on the verification state of the company.
540 541 542 |
# File 'lib/stripe/resources/account.rb', line 540 def verification @verification end |
Class Method Details
.field_remappings ⇒ Object
557 558 559 |
# File 'lib/stripe/resources/account.rb', line 557 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
542 543 544 545 546 547 548 549 550 551 552 553 554 555 |
# File 'lib/stripe/resources/account.rb', line 542 def self.inner_class_types @inner_class_types = { address: Address, address_kana: AddressKana, address_kanji: AddressKanji, administrative_address: AdministrativeAddress, directorship_declaration: DirectorshipDeclaration, ownership_declaration: OwnershipDeclaration, principal_place_of_business: PrincipalPlaceOfBusiness, registration_date: RegistrationDate, representative_declaration: RepresentativeDeclaration, verification: Verification, } end |