Class: Stripe::Account::Company

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: Address, AddressKana, AddressKanji, DirectorshipDeclaration, OwnershipDeclaration, RegistrationDate, RepresentativeDeclaration, Verification

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#addressObject (readonly)

Attribute for field address



472
473
474
# File 'lib/stripe/resources/account.rb', line 472

def address
  @address
end

#address_kanaObject (readonly)

The Kana variation of the company’s primary address (Japan only).



474
475
476
# File 'lib/stripe/resources/account.rb', line 474

def address_kana
  @address_kana
end

#address_kanjiObject (readonly)

The Kanji variation of the company’s primary address (Japan only).



476
477
478
# File 'lib/stripe/resources/account.rb', line 476

def address_kanji
  @address_kanji
end

#directors_providedObject (readonly)

Whether the company’s directors have been provided. This Boolean will be ‘true` if you’ve manually indicated that all directors are provided via [the ‘directors_provided` parameter](docs.stripe.com/api/accounts/update#update_account-company-directors_provided).



478
479
480
# File 'lib/stripe/resources/account.rb', line 478

def directors_provided
  @directors_provided
end

#directorship_declarationObject (readonly)

This hash is used to attest that the director information provided to Stripe is both current and correct.



480
481
482
# File 'lib/stripe/resources/account.rb', line 480

def directorship_declaration
  @directorship_declaration
end

#executives_providedObject (readonly)

Whether the company’s executives have been provided. This Boolean will be ‘true` if you’ve manually indicated that all executives are provided via [the ‘executives_provided` parameter](docs.stripe.com/api/accounts/update#update_account-company-executives_provided), or if Stripe determined that sufficient executives were provided.



482
483
484
# File 'lib/stripe/resources/account.rb', line 482

def executives_provided
  @executives_provided
end

#export_license_idObject (readonly)

The export license ID number of the company, also referred as Import Export Code (India only).



484
485
486
# File 'lib/stripe/resources/account.rb', line 484

def export_license_id
  @export_license_id
end

#export_purpose_codeObject (readonly)

The purpose code to use for export transactions (India only).



486
487
488
# File 'lib/stripe/resources/account.rb', line 486

def export_purpose_code
  @export_purpose_code
end

#nameObject (readonly)

The company’s legal name. Also available for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is ‘stripe`.



488
489
490
# File 'lib/stripe/resources/account.rb', line 488

def name
  @name
end

#name_kanaObject (readonly)

The Kana variation of the company’s legal name (Japan only). Also available for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is ‘stripe`.



490
491
492
# File 'lib/stripe/resources/account.rb', line 490

def name_kana
  @name_kana
end

#name_kanjiObject (readonly)

The Kanji variation of the company’s legal name (Japan only). Also available for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is ‘stripe`.



492
493
494
# File 'lib/stripe/resources/account.rb', line 492

def name_kanji
  @name_kanji
end

#owners_providedObject (readonly)

Whether the company’s owners have been provided. This Boolean will be ‘true` if you’ve manually indicated that all owners are provided via [the ‘owners_provided` parameter](docs.stripe.com/api/accounts/update#update_account-company-owners_provided), or if Stripe determined that sufficient owners were provided. Stripe determines ownership requirements using both the number of owners provided and their total percent ownership (calculated by adding the `percent_ownership` of each owner together).



494
495
496
# File 'lib/stripe/resources/account.rb', line 494

def owners_provided
  @owners_provided
end

#ownership_declarationObject (readonly)

This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.



496
497
498
# File 'lib/stripe/resources/account.rb', line 496

def ownership_declaration
  @ownership_declaration
end

#ownership_exemption_reasonObject (readonly)

This value is used to determine if a business is exempt from providing ultimate beneficial owners. See [this support article](support.stripe.com/questions/exemption-from-providing-ownership-details) and [changelog](docs.stripe.com/changelog/acacia/2025-01-27/ownership-exemption-reason-accounts-api) for more details.



498
499
500
# File 'lib/stripe/resources/account.rb', line 498

def ownership_exemption_reason
  @ownership_exemption_reason
end

#phoneObject (readonly)

The company’s phone number (used for verification).



500
501
502
# File 'lib/stripe/resources/account.rb', line 500

def phone
  @phone
end

#registration_dateObject (readonly)

Attribute for field registration_date



502
503
504
# File 'lib/stripe/resources/account.rb', line 502

def registration_date
  @registration_date
end

#representative_declarationObject (readonly)

This hash is used to attest that the representative is authorized to act as the representative of their legal entity.



504
505
506
# File 'lib/stripe/resources/account.rb', line 504

def representative_declaration
  @representative_declaration
end

#structureObject (readonly)

The category identifying the legal structure of the company or legal entity. Also available for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is ‘stripe`. See [Business structure](docs.stripe.com/connect/identity-verification#business-structure) for more details.



506
507
508
# File 'lib/stripe/resources/account.rb', line 506

def structure
  @structure
end

#tax_id_providedObject (readonly)

Whether the company’s business ID number was provided.



508
509
510
# File 'lib/stripe/resources/account.rb', line 508

def tax_id_provided
  @tax_id_provided
end

#tax_id_registrarObject (readonly)

The jurisdiction in which the ‘tax_id` is registered (Germany-based companies only).



510
511
512
# File 'lib/stripe/resources/account.rb', line 510

def tax_id_registrar
  @tax_id_registrar
end

#vat_id_providedObject (readonly)

Whether the company’s business VAT number was provided.



512
513
514
# File 'lib/stripe/resources/account.rb', line 512

def vat_id_provided
  @vat_id_provided
end

#verificationObject (readonly)

Information on the verification state of the company.



514
515
516
# File 'lib/stripe/resources/account.rb', line 514

def verification
  @verification
end

Class Method Details

.field_remappingsObject



529
530
531
# File 'lib/stripe/resources/account.rb', line 529

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



516
517
518
519
520
521
522
523
524
525
526
527
# File 'lib/stripe/resources/account.rb', line 516

def self.inner_class_types
  @inner_class_types = {
    address: Address,
    address_kana: AddressKana,
    address_kanji: AddressKanji,
    directorship_declaration: DirectorshipDeclaration,
    ownership_declaration: OwnershipDeclaration,
    registration_date: RegistrationDate,
    representative_declaration: RepresentativeDeclaration,
    verification: Verification,
  }
end