Class: Stripe::Account::Company
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Account::Company
- Defined in:
- lib/stripe/resources/account.rb
Defined Under Namespace
Classes: Address, AddressKana, AddressKanji, DirectorshipDeclaration, OwnershipDeclaration, RegistrationDate, Verification
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#address ⇒ Object
readonly
Attribute for field address.
-
#address_kana ⇒ Object
readonly
The Kana variation of the company’s primary address (Japan only).
-
#address_kanji ⇒ Object
readonly
The Kanji variation of the company’s primary address (Japan only).
-
#directors_provided ⇒ Object
readonly
Whether the company’s directors have been provided.
-
#directorship_declaration ⇒ Object
readonly
This hash is used to attest that the director information provided to Stripe is both current and correct.
-
#executives_provided ⇒ Object
readonly
Whether the company’s executives have been provided.
-
#export_license_id ⇒ Object
readonly
The export license ID number of the company, also referred as Import Export Code (India only).
-
#export_purpose_code ⇒ Object
readonly
The purpose code to use for export transactions (India only).
-
#name ⇒ Object
readonly
The company’s legal name.
-
#name_kana ⇒ Object
readonly
The Kana variation of the company’s legal name (Japan only).
-
#name_kanji ⇒ Object
readonly
The Kanji variation of the company’s legal name (Japan only).
-
#owners_provided ⇒ Object
readonly
Whether the company’s owners have been provided.
-
#ownership_declaration ⇒ Object
readonly
This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.
-
#ownership_exemption_reason ⇒ Object
readonly
This value is used to determine if a business is exempt from providing ultimate beneficial owners.
-
#phone ⇒ Object
readonly
The company’s phone number (used for verification).
-
#registration_date ⇒ Object
readonly
Attribute for field registration_date.
-
#structure ⇒ Object
readonly
The category identifying the legal structure of the company or legal entity.
-
#tax_id_provided ⇒ Object
readonly
Whether the company’s business ID number was provided.
-
#tax_id_registrar ⇒ Object
readonly
The jurisdiction in which the ‘tax_id` is registered (Germany-based companies only).
-
#vat_id_provided ⇒ Object
readonly
Whether the company’s business VAT number was provided.
-
#verification ⇒ Object
readonly
Information on the verification state of the company.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#address ⇒ Object (readonly)
Attribute for field address
305 306 307 |
# File 'lib/stripe/resources/account.rb', line 305 def address @address end |
#address_kana ⇒ Object (readonly)
The Kana variation of the company’s primary address (Japan only).
307 308 309 |
# File 'lib/stripe/resources/account.rb', line 307 def address_kana @address_kana end |
#address_kanji ⇒ Object (readonly)
The Kanji variation of the company’s primary address (Japan only).
309 310 311 |
# File 'lib/stripe/resources/account.rb', line 309 def address_kanji @address_kanji end |
#directors_provided ⇒ Object (readonly)
Whether the company’s directors have been provided. This Boolean will be ‘true` if you’ve manually indicated that all directors are provided via [the ‘directors_provided` parameter](stripe.com/docs/api/accounts/update#update_account-company-directors_provided).
311 312 313 |
# File 'lib/stripe/resources/account.rb', line 311 def directors_provided @directors_provided end |
#directorship_declaration ⇒ Object (readonly)
This hash is used to attest that the director information provided to Stripe is both current and correct.
313 314 315 |
# File 'lib/stripe/resources/account.rb', line 313 def directorship_declaration @directorship_declaration end |
#executives_provided ⇒ Object (readonly)
Whether the company’s executives have been provided. This Boolean will be ‘true` if you’ve manually indicated that all executives are provided via [the ‘executives_provided` parameter](stripe.com/docs/api/accounts/update#update_account-company-executives_provided), or if Stripe determined that sufficient executives were provided.
315 316 317 |
# File 'lib/stripe/resources/account.rb', line 315 def executives_provided @executives_provided end |
#export_license_id ⇒ Object (readonly)
The export license ID number of the company, also referred as Import Export Code (India only).
317 318 319 |
# File 'lib/stripe/resources/account.rb', line 317 def export_license_id @export_license_id end |
#export_purpose_code ⇒ Object (readonly)
The purpose code to use for export transactions (India only).
319 320 321 |
# File 'lib/stripe/resources/account.rb', line 319 def export_purpose_code @export_purpose_code end |
#name ⇒ Object (readonly)
The company’s legal name. Also available for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is ‘stripe`.
321 322 323 |
# File 'lib/stripe/resources/account.rb', line 321 def name @name end |
#name_kana ⇒ Object (readonly)
The Kana variation of the company’s legal name (Japan only). Also available for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is ‘stripe`.
323 324 325 |
# File 'lib/stripe/resources/account.rb', line 323 def name_kana @name_kana end |
#name_kanji ⇒ Object (readonly)
The Kanji variation of the company’s legal name (Japan only). Also available for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is ‘stripe`.
325 326 327 |
# File 'lib/stripe/resources/account.rb', line 325 def name_kanji @name_kanji end |
#owners_provided ⇒ Object (readonly)
Whether the company’s owners have been provided. This Boolean will be ‘true` if you’ve manually indicated that all owners are provided via [the ‘owners_provided` parameter](stripe.com/docs/api/accounts/update#update_account-company-owners_provided), or if Stripe determined that sufficient owners were provided. Stripe determines ownership requirements using both the number of owners provided and their total percent ownership (calculated by adding the `percent_ownership` of each owner together).
327 328 329 |
# File 'lib/stripe/resources/account.rb', line 327 def owners_provided @owners_provided end |
#ownership_declaration ⇒ Object (readonly)
This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.
329 330 331 |
# File 'lib/stripe/resources/account.rb', line 329 def ownership_declaration @ownership_declaration end |
#ownership_exemption_reason ⇒ Object (readonly)
This value is used to determine if a business is exempt from providing ultimate beneficial owners. See [this support article](support.stripe.com/questions/exemption-from-providing-ownership-details) and [changelog](docs.stripe.com/changelog/acacia/2025-01-27/ownership-exemption-reason-accounts-api) for more details.
331 332 333 |
# File 'lib/stripe/resources/account.rb', line 331 def ownership_exemption_reason @ownership_exemption_reason end |
#phone ⇒ Object (readonly)
The company’s phone number (used for verification).
333 334 335 |
# File 'lib/stripe/resources/account.rb', line 333 def phone @phone end |
#registration_date ⇒ Object (readonly)
Attribute for field registration_date
335 336 337 |
# File 'lib/stripe/resources/account.rb', line 335 def registration_date @registration_date end |
#structure ⇒ Object (readonly)
The category identifying the legal structure of the company or legal entity. Also available for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is ‘stripe`. See [Business structure](stripe.com/docs/connect/identity-verification#business-structure) for more details.
337 338 339 |
# File 'lib/stripe/resources/account.rb', line 337 def structure @structure end |
#tax_id_provided ⇒ Object (readonly)
Whether the company’s business ID number was provided.
339 340 341 |
# File 'lib/stripe/resources/account.rb', line 339 def tax_id_provided @tax_id_provided end |
#tax_id_registrar ⇒ Object (readonly)
The jurisdiction in which the ‘tax_id` is registered (Germany-based companies only).
341 342 343 |
# File 'lib/stripe/resources/account.rb', line 341 def tax_id_registrar @tax_id_registrar end |
#vat_id_provided ⇒ Object (readonly)
Whether the company’s business VAT number was provided.
343 344 345 |
# File 'lib/stripe/resources/account.rb', line 343 def vat_id_provided @vat_id_provided end |
#verification ⇒ Object (readonly)
Information on the verification state of the company.
345 346 347 |
# File 'lib/stripe/resources/account.rb', line 345 def verification @verification end |