Class: Stripe::Account::Company::Verification::Document

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#backObject (readonly)

The back of a document returned by a [file upload](api.stripe.com#create_file) with a ‘purpose` value of `additional_verification`. Note that `additional_verification` files are [not downloadable](/file-upload#uploading-a-file).



444
445
446
# File 'lib/stripe/resources/account.rb', line 444

def back
  @back
end

#detailsObject (readonly)

A user-displayable string describing the verification state of this document.



446
447
448
# File 'lib/stripe/resources/account.rb', line 446

def details
  @details
end

#details_codeObject (readonly)

One of ‘document_corrupt`, `document_expired`, `document_failed_copy`, `document_failed_greyscale`, `document_failed_other`, `document_failed_test_mode`, `document_fraudulent`, `document_incomplete`, `document_invalid`, `document_manipulated`, `document_not_readable`, `document_not_uploaded`, `document_type_not_supported`, or `document_too_large`. A machine-readable code specifying the verification state for this document.



448
449
450
# File 'lib/stripe/resources/account.rb', line 448

def details_code
  @details_code
end

#frontObject (readonly)

The front of a document returned by a [file upload](api.stripe.com#create_file) with a ‘purpose` value of `additional_verification`. Note that `additional_verification` files are [not downloadable](/file-upload#uploading-a-file).



450
451
452
# File 'lib/stripe/resources/account.rb', line 450

def front
  @front
end

Class Method Details

.field_remappingsObject



456
457
458
# File 'lib/stripe/resources/account.rb', line 456

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



452
453
454
# File 'lib/stripe/resources/account.rb', line 452

def self.inner_class_types
  @inner_class_types = {}
end