Class: Stripe::Account::Company::Verification::Document
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Account::Company::Verification::Document
- Defined in:
- lib/stripe/resources/account.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#back ⇒ Object
readonly
The back of a document returned by a [file upload](stripe.com/docs/api#create_file) with a ‘purpose` value of `additional_verification`.
-
#details ⇒ Object
readonly
A user-displayable string describing the verification state of this document.
-
#details_code ⇒ Object
readonly
One of ‘document_corrupt`, `document_expired`, `document_failed_copy`, `document_failed_greyscale`, `document_failed_other`, `document_failed_test_mode`, `document_fraudulent`, `document_incomplete`, `document_invalid`, `document_manipulated`, `document_not_readable`, `document_not_uploaded`, `document_type_not_supported`, or `document_too_large`.
-
#front ⇒ Object
readonly
The front of a document returned by a [file upload](stripe.com/docs/api#create_file) with a ‘purpose` value of `additional_verification`.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#back ⇒ Object (readonly)
The back of a document returned by a [file upload](stripe.com/docs/api#create_file) with a ‘purpose` value of `additional_verification`. Note that `additional_verification` files are [not downloadable](/file-upload#uploading-a-file).
417 418 419 |
# File 'lib/stripe/resources/account.rb', line 417 def back @back end |
#details ⇒ Object (readonly)
A user-displayable string describing the verification state of this document.
419 420 421 |
# File 'lib/stripe/resources/account.rb', line 419 def details @details end |
#details_code ⇒ Object (readonly)
One of ‘document_corrupt`, `document_expired`, `document_failed_copy`, `document_failed_greyscale`, `document_failed_other`, `document_failed_test_mode`, `document_fraudulent`, `document_incomplete`, `document_invalid`, `document_manipulated`, `document_not_readable`, `document_not_uploaded`, `document_type_not_supported`, or `document_too_large`. A machine-readable code specifying the verification state for this document.
421 422 423 |
# File 'lib/stripe/resources/account.rb', line 421 def details_code @details_code end |
#front ⇒ Object (readonly)
The front of a document returned by a [file upload](stripe.com/docs/api#create_file) with a ‘purpose` value of `additional_verification`. Note that `additional_verification` files are [not downloadable](/file-upload#uploading-a-file).
423 424 425 |
# File 'lib/stripe/resources/account.rb', line 423 def front @front end |
Class Method Details
.field_remappings ⇒ Object
429 430 431 |
# File 'lib/stripe/resources/account.rb', line 429 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
425 426 427 |
# File 'lib/stripe/resources/account.rb', line 425 def self.inner_class_types @inner_class_types = {} end |