Class: Stripe::Account::Controller
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Account::Controller
- Defined in:
- lib/stripe/resources/account.rb
Defined Under Namespace
Classes: Application, Dashboard, Fees, Losses, StripeDashboard
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#application ⇒ Object
readonly
Attribute for field application.
-
#dashboard ⇒ Object
readonly
Attribute for field dashboard.
-
#fees ⇒ Object
readonly
Attribute for field fees.
-
#is_controller ⇒ Object
readonly
‘true` if the Connect application retrieving the resource controls the account and can therefore exercise [platform controls](stripe.com/docs/connect/platform-controls-for-standard-accounts).
-
#losses ⇒ Object
readonly
Attribute for field losses.
-
#requirement_collection ⇒ Object
readonly
A value indicating responsibility for collecting requirements on this account.
-
#stripe_dashboard ⇒ Object
readonly
Attribute for field stripe_dashboard.
-
#type ⇒ Object
readonly
The controller type.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#application ⇒ Object (readonly)
Attribute for field application
596 597 598 |
# File 'lib/stripe/resources/account.rb', line 596 def application @application end |
#dashboard ⇒ Object (readonly)
Attribute for field dashboard
598 599 600 |
# File 'lib/stripe/resources/account.rb', line 598 def dashboard @dashboard end |
#fees ⇒ Object (readonly)
Attribute for field fees
600 601 602 |
# File 'lib/stripe/resources/account.rb', line 600 def fees @fees end |
#is_controller ⇒ Object (readonly)
‘true` if the Connect application retrieving the resource controls the account and can therefore exercise [platform controls](stripe.com/docs/connect/platform-controls-for-standard-accounts). Otherwise, this field is null.
602 603 604 |
# File 'lib/stripe/resources/account.rb', line 602 def is_controller @is_controller end |
#losses ⇒ Object (readonly)
Attribute for field losses
604 605 606 |
# File 'lib/stripe/resources/account.rb', line 604 def losses @losses end |
#requirement_collection ⇒ Object (readonly)
A value indicating responsibility for collecting requirements on this account. Only returned when the Connect application retrieving the resource controls the account.
606 607 608 |
# File 'lib/stripe/resources/account.rb', line 606 def requirement_collection @requirement_collection end |
#stripe_dashboard ⇒ Object (readonly)
Attribute for field stripe_dashboard
608 609 610 |
# File 'lib/stripe/resources/account.rb', line 608 def stripe_dashboard @stripe_dashboard end |
#type ⇒ Object (readonly)
The controller type. Can be ‘application`, if a Connect application controls the account, or `account`, if the account controls itself.
610 611 612 |
# File 'lib/stripe/resources/account.rb', line 610 def type @type end |
Class Method Details
.field_remappings ⇒ Object
622 623 624 |
# File 'lib/stripe/resources/account.rb', line 622 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
612 613 614 615 616 617 618 619 620 |
# File 'lib/stripe/resources/account.rb', line 612 def self.inner_class_types @inner_class_types = { application: Application, dashboard: Dashboard, fees: Fees, losses: Losses, stripe_dashboard: StripeDashboard, } end |