Class: Stripe::Account::Controller

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: Application, Dashboard, Fees, Losses, StripeDashboard

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#applicationObject (readonly)

Attribute for field application



574
575
576
# File 'lib/stripe/resources/account.rb', line 574

def application
  @application
end

#dashboardObject (readonly)

Attribute for field dashboard



576
577
578
# File 'lib/stripe/resources/account.rb', line 576

def dashboard
  @dashboard
end

#feesObject (readonly)

Attribute for field fees



578
579
580
# File 'lib/stripe/resources/account.rb', line 578

def fees
  @fees
end

#is_controllerObject (readonly)

‘true` if the Connect application retrieving the resource controls the account and can therefore exercise [platform controls](stripe.com/docs/connect/platform-controls-for-standard-accounts). Otherwise, this field is null.



580
581
582
# File 'lib/stripe/resources/account.rb', line 580

def is_controller
  @is_controller
end

#lossesObject (readonly)

Attribute for field losses



582
583
584
# File 'lib/stripe/resources/account.rb', line 582

def losses
  @losses
end

#requirement_collectionObject (readonly)

A value indicating responsibility for collecting requirements on this account. Only returned when the Connect application retrieving the resource controls the account.



584
585
586
# File 'lib/stripe/resources/account.rb', line 584

def requirement_collection
  @requirement_collection
end

#stripe_dashboardObject (readonly)

Attribute for field stripe_dashboard



586
587
588
# File 'lib/stripe/resources/account.rb', line 586

def stripe_dashboard
  @stripe_dashboard
end

#typeObject (readonly)

The controller type. Can be ‘application`, if a Connect application controls the account, or `account`, if the account controls itself.



588
589
590
# File 'lib/stripe/resources/account.rb', line 588

def type
  @type
end

Class Method Details

.field_remappingsObject



600
601
602
# File 'lib/stripe/resources/account.rb', line 600

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



590
591
592
593
594
595
596
597
598
# File 'lib/stripe/resources/account.rb', line 590

def self.inner_class_types
  @inner_class_types = {
    application: Application,
    dashboard: Dashboard,
    fees: Fees,
    losses: Losses,
    stripe_dashboard: StripeDashboard,
  }
end