Class: Stripe::Account::Controller
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Account::Controller
- Defined in:
- lib/stripe/resources/account.rb
Defined Under Namespace
Classes: Application, Dashboard, Fees, Losses, StripeDashboard
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#application ⇒ Object
readonly
Attribute for field application.
-
#dashboard ⇒ Object
readonly
Attribute for field dashboard.
-
#fees ⇒ Object
readonly
Attribute for field fees.
-
#is_controller ⇒ Object
readonly
‘true` if the Connect application retrieving the resource controls the account and can therefore exercise [platform controls](stripe.com/docs/connect/platform-controls-for-standard-accounts).
-
#losses ⇒ Object
readonly
Attribute for field losses.
-
#requirement_collection ⇒ Object
readonly
A value indicating responsibility for collecting requirements on this account.
-
#stripe_dashboard ⇒ Object
readonly
Attribute for field stripe_dashboard.
-
#type ⇒ Object
readonly
The controller type.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#application ⇒ Object (readonly)
Attribute for field application
572 573 574 |
# File 'lib/stripe/resources/account.rb', line 572 def application @application end |
#dashboard ⇒ Object (readonly)
Attribute for field dashboard
574 575 576 |
# File 'lib/stripe/resources/account.rb', line 574 def dashboard @dashboard end |
#fees ⇒ Object (readonly)
Attribute for field fees
576 577 578 |
# File 'lib/stripe/resources/account.rb', line 576 def fees @fees end |
#is_controller ⇒ Object (readonly)
‘true` if the Connect application retrieving the resource controls the account and can therefore exercise [platform controls](stripe.com/docs/connect/platform-controls-for-standard-accounts). Otherwise, this field is null.
578 579 580 |
# File 'lib/stripe/resources/account.rb', line 578 def is_controller @is_controller end |
#losses ⇒ Object (readonly)
Attribute for field losses
580 581 582 |
# File 'lib/stripe/resources/account.rb', line 580 def losses @losses end |
#requirement_collection ⇒ Object (readonly)
A value indicating responsibility for collecting requirements on this account. Only returned when the Connect application retrieving the resource controls the account.
582 583 584 |
# File 'lib/stripe/resources/account.rb', line 582 def requirement_collection @requirement_collection end |
#stripe_dashboard ⇒ Object (readonly)
Attribute for field stripe_dashboard
584 585 586 |
# File 'lib/stripe/resources/account.rb', line 584 def stripe_dashboard @stripe_dashboard end |
#type ⇒ Object (readonly)
The controller type. Can be ‘application`, if a Connect application controls the account, or `account`, if the account controls itself.
586 587 588 |
# File 'lib/stripe/resources/account.rb', line 586 def type @type end |
Class Method Details
.field_remappings ⇒ Object
598 599 600 |
# File 'lib/stripe/resources/account.rb', line 598 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
588 589 590 591 592 593 594 595 596 |
# File 'lib/stripe/resources/account.rb', line 588 def self.inner_class_types @inner_class_types = { application: Application, dashboard: Dashboard, fees: Fees, losses: Losses, stripe_dashboard: StripeDashboard, } end |