Class: Stripe::Account::Controller
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Account::Controller
- Defined in:
- lib/stripe/resources/account.rb
Defined Under Namespace
Classes: Fees, Losses, StripeDashboard
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#fees ⇒ Object
readonly
Attribute for field fees.
-
#is_controller ⇒ Object
readonly
‘true` if the Connect application retrieving the resource controls the account and can therefore exercise [platform controls](stripe.com/docs/connect/platform-controls-for-standard-accounts).
-
#losses ⇒ Object
readonly
Attribute for field losses.
-
#requirement_collection ⇒ Object
readonly
A value indicating responsibility for collecting requirements on this account.
-
#stripe_dashboard ⇒ Object
readonly
Attribute for field stripe_dashboard.
-
#type ⇒ Object
readonly
The controller type.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#fees ⇒ Object (readonly)
Attribute for field fees
364 365 366 |
# File 'lib/stripe/resources/account.rb', line 364 def fees @fees end |
#is_controller ⇒ Object (readonly)
‘true` if the Connect application retrieving the resource controls the account and can therefore exercise [platform controls](stripe.com/docs/connect/platform-controls-for-standard-accounts). Otherwise, this field is null.
366 367 368 |
# File 'lib/stripe/resources/account.rb', line 366 def is_controller @is_controller end |
#losses ⇒ Object (readonly)
Attribute for field losses
368 369 370 |
# File 'lib/stripe/resources/account.rb', line 368 def losses @losses end |
#requirement_collection ⇒ Object (readonly)
A value indicating responsibility for collecting requirements on this account. Only returned when the Connect application retrieving the resource controls the account.
370 371 372 |
# File 'lib/stripe/resources/account.rb', line 370 def requirement_collection @requirement_collection end |
#stripe_dashboard ⇒ Object (readonly)
Attribute for field stripe_dashboard
372 373 374 |
# File 'lib/stripe/resources/account.rb', line 372 def stripe_dashboard @stripe_dashboard end |
#type ⇒ Object (readonly)
The controller type. Can be ‘application`, if a Connect application controls the account, or `account`, if the account controls itself.
374 375 376 |
# File 'lib/stripe/resources/account.rb', line 374 def type @type end |