Class: Stripe::Account::Controller::Application
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Account::Controller::Application
- Defined in:
- lib/stripe/resources/account.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#loss_liable ⇒ Object
readonly
‘true` if the Connect application is responsible for negative balances and should manage credit and fraud risk on the account.
-
#onboarding_owner ⇒ Object
readonly
‘true` if the Connect application is responsible for onboarding the account.
-
#pricing_controls ⇒ Object
readonly
‘true` if the Connect application is responsible for paying Stripe fees on pricing-control eligible products.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#loss_liable ⇒ Object (readonly)
‘true` if the Connect application is responsible for negative balances and should manage credit and fraud risk on the account.
505 506 507 |
# File 'lib/stripe/resources/account.rb', line 505 def loss_liable @loss_liable end |
#onboarding_owner ⇒ Object (readonly)
‘true` if the Connect application is responsible for onboarding the account.
507 508 509 |
# File 'lib/stripe/resources/account.rb', line 507 def onboarding_owner @onboarding_owner end |
#pricing_controls ⇒ Object (readonly)
‘true` if the Connect application is responsible for paying Stripe fees on pricing-control eligible products.
509 510 511 |
# File 'lib/stripe/resources/account.rb', line 509 def pricing_controls @pricing_controls end |
Class Method Details
.field_remappings ⇒ Object
515 516 517 |
# File 'lib/stripe/resources/account.rb', line 515 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
511 512 513 |
# File 'lib/stripe/resources/account.rb', line 511 def self.inner_class_types @inner_class_types = {} end |