Class: Stripe::Account::Controller::Application

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#loss_liableObject (readonly)

‘true` if the Connect application is responsible for negative balances and should manage credit and fraud risk on the account.



366
367
368
# File 'lib/stripe/resources/account.rb', line 366

def loss_liable
  @loss_liable
end

#onboarding_ownerObject (readonly)

‘true` if the Connect application is responsible for onboarding the account.



368
369
370
# File 'lib/stripe/resources/account.rb', line 368

def onboarding_owner
  @onboarding_owner
end

#pricing_controlsObject (readonly)

‘true` if the Connect application is responsible for paying Stripe fees on pricing-control eligible products.



370
371
372
# File 'lib/stripe/resources/account.rb', line 370

def pricing_controls
  @pricing_controls
end