Class: Stripe::Account::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: BankAccount, BusinessProfile, Capabilities, Card, CardToken, Company, Controller, Documents, Groups, Individual, RiskControls, Settings, TosAcceptance

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_token: nil, business_profile: nil, business_type: nil, capabilities: nil, company: nil, controller: nil, country: nil, default_currency: nil, documents: nil, email: nil, expand: nil, external_account: nil, groups: nil, individual: nil, metadata: nil, risk_controls: nil, settings: nil, tos_acceptance: nil, type: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



5216
5217
5218
5219
5220
5221
5222
5223
5224
5225
5226
5227
5228
5229
5230
5231
5232
5233
5234
5235
5236
5237
5238
5239
5240
5241
5242
5243
5244
5245
5246
5247
5248
5249
5250
5251
5252
5253
5254
5255
5256
# File 'lib/stripe/resources/account.rb', line 5216

def initialize(
  account_token: nil,
  business_profile: nil,
  business_type: nil,
  capabilities: nil,
  company: nil,
  controller: nil,
  country: nil,
  default_currency: nil,
  documents: nil,
  email: nil,
  expand: nil,
  external_account: nil,
  groups: nil,
  individual: nil,
  metadata: nil,
  risk_controls: nil,
  settings: nil,
  tos_acceptance: nil,
  type: nil
)
  @account_token = 
  @business_profile = business_profile
  @business_type = business_type
  @capabilities = capabilities
  @company = company
  @controller = controller
  @country = country
  @default_currency = default_currency
  @documents = documents
  @email = email
  @expand = expand
  @external_account = 
  @groups = groups
  @individual = individual
  @metadata = 
  @risk_controls = risk_controls
  @settings = settings
  @tos_acceptance = tos_acceptance
  @type = type
end

Instance Attribute Details

#account_tokenObject

An [account token](stripe.com/docs/api#create_account_token), used to securely provide details to the account.



5171
5172
5173
# File 'lib/stripe/resources/account.rb', line 5171

def 
  @account_token
end

#business_profileObject

Business information about the account.



5173
5174
5175
# File 'lib/stripe/resources/account.rb', line 5173

def business_profile
  @business_profile
end

#business_typeObject

The business type. Once you create an [Account Link](/api/account_links) or [Account Session](/api/account_sessions), this property can only be updated for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is ‘application`, which includes Custom accounts.



5175
5176
5177
# File 'lib/stripe/resources/account.rb', line 5175

def business_type
  @business_type
end

#capabilitiesObject

Each key of the dictionary represents a capability, and each capability maps to its settings (for example, whether it has been requested or not). Each capability is inactive until you have provided its specific requirements and Stripe has verified them. An account might have some of its requested capabilities be active and some be inactive.

Required when [account.controller.stripe_dashboard.type](/api/accounts/create#create_account-controller-dashboard-type) is ‘none`, which includes Custom accounts.



5184
5185
5186
# File 'lib/stripe/resources/account.rb', line 5184

def capabilities
  @capabilities
end

#companyObject

Information about the company or business. This field is available for any ‘business_type`. Once you create an [Account Link](/api/account_links) or [Account Session](/api/account_sessions), this property can only be updated for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is `application`, which includes Custom accounts.



5186
5187
5188
# File 'lib/stripe/resources/account.rb', line 5186

def company
  @company
end

#controllerObject

A hash of configuration describing the account controller’s attributes.



5188
5189
5190
# File 'lib/stripe/resources/account.rb', line 5188

def controller
  @controller
end

#countryObject

The country in which the account holder resides, or in which the business is legally established. This should be an ISO 3166-1 alpha-2 country code. For example, if you are in the United States and the business for which you’re creating an account is legally represented in Canada, you would use ‘CA` as the country for the account being created. Available countries include [Stripe’s global markets](stripe.com/global) as well as countries where [cross-border payouts](stripe.com/docs/connect/cross-border-payouts) are supported.



5190
5191
5192
# File 'lib/stripe/resources/account.rb', line 5190

def country
  @country
end

#default_currencyObject

Three-letter ISO currency code representing the default currency for the account. This must be a currency that [Stripe supports in the account’s country](docs.stripe.com/payouts).



5192
5193
5194
# File 'lib/stripe/resources/account.rb', line 5192

def default_currency
  @default_currency
end

#documentsObject

Documents that may be submitted to satisfy various informational requests.



5194
5195
5196
# File 'lib/stripe/resources/account.rb', line 5194

def documents
  @documents
end

#emailObject

The email address of the account holder. This is only to make the account easier to identify to you. If [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is ‘application`, which includes Custom accounts, Stripe doesn’t email the account without your consent.



5196
5197
5198
# File 'lib/stripe/resources/account.rb', line 5196

def email
  @email
end

#expandObject

Specifies which fields in the response should be expanded.



5198
5199
5200
# File 'lib/stripe/resources/account.rb', line 5198

def expand
  @expand
end

#external_accountObject

A card or bank account to attach to the account for receiving [payouts](/connect/bank-debit-card-payouts) (you won’t be able to use it for top-ups). You can provide either a token, like the ones returned by [Stripe.js](/js), or a dictionary, as documented in the ‘external_account` parameter for [bank account](/api#account_create_bank_account) creation.
By default, providing an external account sets it as the new default external account for its currency, and deletes the old default if one exists. To add additional external accounts without replacing the existing default for the currency, use the [bank account](/api#account_create_bank_account) or [card creation](/api#account_create_card) APIs. After you create an [Account Link](/api/account_links) or [Account Session](/api/account_sessions), this property can only be updated for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is `application`, which includes Custom accounts.



5200
5201
5202
# File 'lib/stripe/resources/account.rb', line 5200

def 
  @external_account
end

#groupsObject

A hash of account group type to tokens. These are account groups this account should be added to.



5202
5203
5204
# File 'lib/stripe/resources/account.rb', line 5202

def groups
  @groups
end

#individualObject

Information about the person represented by the account. This field is null unless ‘business_type` is set to `individual`. Once you create an [Account Link](/api/account_links) or [Account Session](/api/account_sessions), this property can only be updated for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is `application`, which includes Custom accounts.



5204
5205
5206
# File 'lib/stripe/resources/account.rb', line 5204

def individual
  @individual
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



5206
5207
5208
# File 'lib/stripe/resources/account.rb', line 5206

def 
  @metadata
end

#risk_controlsObject

A hash to configure risk controls on the account. Please see [this page for more details](/connect/pausing-payments-or-payouts-on-connected-accounts).



5208
5209
5210
# File 'lib/stripe/resources/account.rb', line 5208

def risk_controls
  @risk_controls
end

#settingsObject

Options for customizing how the account functions within Stripe.



5210
5211
5212
# File 'lib/stripe/resources/account.rb', line 5210

def settings
  @settings
end

#tos_acceptanceObject

Details on the account’s acceptance of the [Stripe Services Agreement](/connect/updating-accounts#tos-acceptance). This property can only be updated for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is ‘application`, which includes Custom accounts. This property defaults to a `full` service agreement when empty.



5212
5213
5214
# File 'lib/stripe/resources/account.rb', line 5212

def tos_acceptance
  @tos_acceptance
end

#typeObject

The type of Stripe account to create. May be one of ‘custom`, `express` or `standard`.



5214
5215
5216
# File 'lib/stripe/resources/account.rb', line 5214

def type
  @type
end