Class: Stripe::Account::CreateParams::BankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(object: nil, account_holder_name: nil, account_holder_type: nil, account_number: nil, country: nil, currency: nil, routing_number: nil) ⇒ BankAccount

Returns a new instance of BankAccount.



3022
3023
3024
3025
3026
3027
3028
3029
3030
3031
3032
3033
3034
3035
3036
3037
3038
# File 'lib/stripe/resources/account.rb', line 3022

def initialize(
  object: nil,
  account_holder_name: nil,
  account_holder_type: nil,
  account_number: nil,
  country: nil,
  currency: nil,
  routing_number: nil
)
  @object = object
  @account_holder_name = 
  @account_holder_type = 
  @account_number = 
  @country = country
  @currency = currency
  @routing_number = routing_number
end

Instance Attribute Details

#account_holder_nameObject

The name of the person or business that owns the bank account.This field is required when attaching the bank account to a ‘Customer` object.



3010
3011
3012
# File 'lib/stripe/resources/account.rb', line 3010

def 
  @account_holder_name
end

#account_holder_typeObject

The type of entity that holds the account. It can be ‘company` or `individual`. This field is required when attaching the bank account to a `Customer` object.



3012
3013
3014
# File 'lib/stripe/resources/account.rb', line 3012

def 
  @account_holder_type
end

#account_numberObject

The account number for the bank account, in string form. Must be a checking account.



3014
3015
3016
# File 'lib/stripe/resources/account.rb', line 3014

def 
  @account_number
end

#countryObject

The country in which the bank account is located.



3016
3017
3018
# File 'lib/stripe/resources/account.rb', line 3016

def country
  @country
end

#currencyObject

The currency the bank account is in. This must be a country/currency pairing that [Stripe supports.](docs/payouts)



3018
3019
3020
# File 'lib/stripe/resources/account.rb', line 3018

def currency
  @currency
end

#objectObject

Attribute for param field object



3008
3009
3010
# File 'lib/stripe/resources/account.rb', line 3008

def object
  @object
end

#routing_numberObject

The routing number, sort code, or other country-appropriate institution number for the bank account. For US bank accounts, this is required and should be the ACH routing number, not the wire routing number. If you are providing an IBAN for ‘account_number`, this field is not required.



3020
3021
3022
# File 'lib/stripe/resources/account.rb', line 3020

def routing_number
  @routing_number
end