Class: Stripe::Account::CreateParams::BankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(object: nil, account_holder_name: nil, account_holder_type: nil, account_number: nil, country: nil, currency: nil, routing_number: nil) ⇒ BankAccount

Returns a new instance of BankAccount.



2977
2978
2979
2980
2981
2982
2983
2984
2985
2986
2987
2988
2989
2990
2991
2992
2993
# File 'lib/stripe/resources/account.rb', line 2977

def initialize(
  object: nil,
  account_holder_name: nil,
  account_holder_type: nil,
  account_number: nil,
  country: nil,
  currency: nil,
  routing_number: nil
)
  @object = object
  @account_holder_name = 
  @account_holder_type = 
  @account_number = 
  @country = country
  @currency = currency
  @routing_number = routing_number
end

Instance Attribute Details

#account_holder_nameObject

The name of the person or business that owns the bank account.This field is required when attaching the bank account to a ‘Customer` object.



2965
2966
2967
# File 'lib/stripe/resources/account.rb', line 2965

def 
  @account_holder_name
end

#account_holder_typeObject

The type of entity that holds the account. It can be ‘company` or `individual`. This field is required when attaching the bank account to a `Customer` object.



2967
2968
2969
# File 'lib/stripe/resources/account.rb', line 2967

def 
  @account_holder_type
end

#account_numberObject

The account number for the bank account, in string form. Must be a checking account.



2969
2970
2971
# File 'lib/stripe/resources/account.rb', line 2969

def 
  @account_number
end

#countryObject

The country in which the bank account is located.



2971
2972
2973
# File 'lib/stripe/resources/account.rb', line 2971

def country
  @country
end

#currencyObject

The currency the bank account is in. This must be a country/currency pairing that [Stripe supports.](docs/payouts)



2973
2974
2975
# File 'lib/stripe/resources/account.rb', line 2973

def currency
  @currency
end

#objectObject

Attribute for param field object



2963
2964
2965
# File 'lib/stripe/resources/account.rb', line 2963

def object
  @object
end

#routing_numberObject

The routing number, sort code, or other country-appropriate institution number for the bank account. For US bank accounts, this is required and should be the ACH routing number, not the wire routing number. If you are providing an IBAN for ‘account_number`, this field is not required.



2975
2976
2977
# File 'lib/stripe/resources/account.rb', line 2975

def routing_number
  @routing_number
end