Class: Stripe::Account::CreateParams::BankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(object: nil, account_holder_name: nil, account_holder_type: nil, account_number: nil, country: nil, currency: nil, routing_number: nil) ⇒ BankAccount

Returns a new instance of BankAccount.



2626
2627
2628
2629
2630
2631
2632
2633
2634
2635
2636
2637
2638
2639
2640
2641
2642
# File 'lib/stripe/resources/account.rb', line 2626

def initialize(
  object: nil,
  account_holder_name: nil,
  account_holder_type: nil,
  account_number: nil,
  country: nil,
  currency: nil,
  routing_number: nil
)
  @object = object
  @account_holder_name = 
  @account_holder_type = 
  @account_number = 
  @country = country
  @currency = currency
  @routing_number = routing_number
end

Instance Attribute Details

#account_holder_nameObject

The name of the person or business that owns the bank account.This field is required when attaching the bank account to a ‘Customer` object.



2614
2615
2616
# File 'lib/stripe/resources/account.rb', line 2614

def 
  @account_holder_name
end

#account_holder_typeObject

The type of entity that holds the account. It can be ‘company` or `individual`. This field is required when attaching the bank account to a `Customer` object.



2616
2617
2618
# File 'lib/stripe/resources/account.rb', line 2616

def 
  @account_holder_type
end

#account_numberObject

The account number for the bank account, in string form. Must be a checking account.



2618
2619
2620
# File 'lib/stripe/resources/account.rb', line 2618

def 
  @account_number
end

#countryObject

The country in which the bank account is located.



2620
2621
2622
# File 'lib/stripe/resources/account.rb', line 2620

def country
  @country
end

#currencyObject

The currency the bank account is in. This must be a country/currency pairing that [Stripe supports.](docs/payouts)



2622
2623
2624
# File 'lib/stripe/resources/account.rb', line 2622

def currency
  @currency
end

#objectObject

Attribute for param field object



2612
2613
2614
# File 'lib/stripe/resources/account.rb', line 2612

def object
  @object
end

#routing_numberObject

The routing number, sort code, or other country-appropriate institution number for the bank account. For US bank accounts, this is required and should be the ACH routing number, not the wire routing number. If you are providing an IBAN for ‘account_number`, this field is not required.



2624
2625
2626
# File 'lib/stripe/resources/account.rb', line 2624

def routing_number
  @routing_number
end