Class: Stripe::Account::CreateParams::BankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(object: nil, account_holder_name: nil, account_holder_type: nil, account_number: nil, country: nil, currency: nil, routing_number: nil) ⇒ BankAccount

Returns a new instance of BankAccount.



2963
2964
2965
2966
2967
2968
2969
2970
2971
2972
2973
2974
2975
2976
2977
2978
2979
# File 'lib/stripe/resources/account.rb', line 2963

def initialize(
  object: nil,
  account_holder_name: nil,
  account_holder_type: nil,
  account_number: nil,
  country: nil,
  currency: nil,
  routing_number: nil
)
  @object = object
  @account_holder_name = 
  @account_holder_type = 
  @account_number = 
  @country = country
  @currency = currency
  @routing_number = routing_number
end

Instance Attribute Details

#account_holder_nameObject

The name of the person or business that owns the bank account.This field is required when attaching the bank account to a ‘Customer` object.



2951
2952
2953
# File 'lib/stripe/resources/account.rb', line 2951

def 
  @account_holder_name
end

#account_holder_typeObject

The type of entity that holds the account. It can be ‘company` or `individual`. This field is required when attaching the bank account to a `Customer` object.



2953
2954
2955
# File 'lib/stripe/resources/account.rb', line 2953

def 
  @account_holder_type
end

#account_numberObject

The account number for the bank account, in string form. Must be a checking account.



2955
2956
2957
# File 'lib/stripe/resources/account.rb', line 2955

def 
  @account_number
end

#countryObject

The country in which the bank account is located.



2957
2958
2959
# File 'lib/stripe/resources/account.rb', line 2957

def country
  @country
end

#currencyObject

The currency the bank account is in. This must be a country/currency pairing that [Stripe supports.](docs/payouts)



2959
2960
2961
# File 'lib/stripe/resources/account.rb', line 2959

def currency
  @currency
end

#objectObject

Attribute for param field object



2949
2950
2951
# File 'lib/stripe/resources/account.rb', line 2949

def object
  @object
end

#routing_numberObject

The routing number, sort code, or other country-appropriateinstitution number for the bank account. For US bank accounts, this is required and should bethe ACH routing number, not the wire routing number. If you are providing an IBAN for`account_number`, this field is not required.



2961
2962
2963
# File 'lib/stripe/resources/account.rb', line 2961

def routing_number
  @routing_number
end