Class: Stripe::Account::CreateParams::BankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::CreateParams::BankAccount
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name of the person or business that owns the bank account.This field is required when attaching the bank account to a ‘Customer` object.
-
#account_holder_type ⇒ Object
The type of entity that holds the account.
-
#account_number ⇒ Object
The account number for the bank account, in string form.
-
#country ⇒ Object
The country in which the bank account is located.
-
#currency ⇒ Object
The currency the bank account is in.
-
#object ⇒ Object
Attribute for param field object.
-
#routing_number ⇒ Object
The routing number, sort code, or other country-appropriateinstitution number for the bank account.
Instance Method Summary collapse
-
#initialize(object: nil, account_holder_name: nil, account_holder_type: nil, account_number: nil, country: nil, currency: nil, routing_number: nil) ⇒ BankAccount
constructor
A new instance of BankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(object: nil, account_holder_name: nil, account_holder_type: nil, account_number: nil, country: nil, currency: nil, routing_number: nil) ⇒ BankAccount
Returns a new instance of BankAccount.
2871 2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 |
# File 'lib/stripe/resources/account.rb', line 2871 def initialize( object: nil, account_holder_name: nil, account_holder_type: nil, account_number: nil, country: nil, currency: nil, routing_number: nil ) @object = object @account_holder_name = account_holder_name @account_holder_type = account_holder_type @account_number = account_number @country = country @currency = currency @routing_number = routing_number end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name of the person or business that owns the bank account.This field is required when attaching the bank account to a ‘Customer` object.
2859 2860 2861 |
# File 'lib/stripe/resources/account.rb', line 2859 def account_holder_name @account_holder_name end |
#account_holder_type ⇒ Object
The type of entity that holds the account. It can be ‘company` or `individual`. This field is required when attaching the bank account to a `Customer` object.
2861 2862 2863 |
# File 'lib/stripe/resources/account.rb', line 2861 def account_holder_type @account_holder_type end |
#account_number ⇒ Object
The account number for the bank account, in string form. Must be a checking account.
2863 2864 2865 |
# File 'lib/stripe/resources/account.rb', line 2863 def account_number @account_number end |
#country ⇒ Object
The country in which the bank account is located.
2865 2866 2867 |
# File 'lib/stripe/resources/account.rb', line 2865 def country @country end |
#currency ⇒ Object
The currency the bank account is in. This must be a country/currency pairing that [Stripe supports.](docs/payouts)
2867 2868 2869 |
# File 'lib/stripe/resources/account.rb', line 2867 def currency @currency end |
#object ⇒ Object
Attribute for param field object
2857 2858 2859 |
# File 'lib/stripe/resources/account.rb', line 2857 def object @object end |
#routing_number ⇒ Object
The routing number, sort code, or other country-appropriateinstitution number for the bank account. For US bank accounts, this is required and should bethe ACH routing number, not the wire routing number. If you are providing an IBAN for`account_number`, this field is not required.
2869 2870 2871 |
# File 'lib/stripe/resources/account.rb', line 2869 def routing_number @routing_number end |