Class: Stripe::Account::CreateParams::BankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(object: nil, account_holder_name: nil, account_holder_type: nil, account_number: nil, country: nil, currency: nil, routing_number: nil) ⇒ BankAccount

Returns a new instance of BankAccount.



3260
3261
3262
3263
3264
3265
3266
3267
3268
3269
3270
3271
3272
3273
3274
3275
3276
# File 'lib/stripe/resources/account.rb', line 3260

def initialize(
  object: nil,
  account_holder_name: nil,
  account_holder_type: nil,
  account_number: nil,
  country: nil,
  currency: nil,
  routing_number: nil
)
  @object = object
  @account_holder_name = 
  @account_holder_type = 
  @account_number = 
  @country = country
  @currency = currency
  @routing_number = routing_number
end

Instance Attribute Details

#account_holder_nameObject

The name of the person or business that owns the bank account.This field is required when attaching the bank account to a ‘Customer` object.



3243
3244
3245
# File 'lib/stripe/resources/account.rb', line 3243

def 
  @account_holder_name
end

#account_holder_typeObject

The type of entity that holds the account. It can be ‘company` or `individual`. This field is required when attaching the bank account to a `Customer` object.



3246
3247
3248
# File 'lib/stripe/resources/account.rb', line 3246

def 
  @account_holder_type
end

#account_numberObject

The account number for the bank account, in string form. Must be a checking account.



3249
3250
3251
# File 'lib/stripe/resources/account.rb', line 3249

def 
  @account_number
end

#countryObject

The country in which the bank account is located.



3252
3253
3254
# File 'lib/stripe/resources/account.rb', line 3252

def country
  @country
end

#currencyObject

The currency the bank account is in. This must be a country/currency pairing that [Stripe supports.](docs/payouts)



3255
3256
3257
# File 'lib/stripe/resources/account.rb', line 3255

def currency
  @currency
end

#objectObject

Attribute for param field object



3240
3241
3242
# File 'lib/stripe/resources/account.rb', line 3240

def object
  @object
end

#routing_numberObject

The routing number, sort code, or other country-appropriateinstitution number for the bank account. For US bank accounts, this is required and should bethe ACH routing number, not the wire routing number. If you are providing an IBAN for`account_number`, this field is not required.



3258
3259
3260
# File 'lib/stripe/resources/account.rb', line 3258

def routing_number
  @routing_number
end