Class: Stripe::Account::CreateParams::BusinessProfile

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: AnnualRevenue, MonthlyEstimatedRevenue, SupportAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(annual_revenue: nil, estimated_worker_count: nil, mcc: nil, minority_owned_business_designation: nil, monthly_estimated_revenue: nil, name: nil, product_description: nil, support_address: nil, support_email: nil, support_phone: nil, support_url: nil, url: nil) ⇒ BusinessProfile

Returns a new instance of BusinessProfile.



3124
3125
3126
3127
3128
3129
3130
3131
3132
3133
3134
3135
3136
3137
3138
3139
3140
3141
3142
3143
3144
3145
3146
3147
3148
3149
3150
# File 'lib/stripe/resources/account.rb', line 3124

def initialize(
  annual_revenue: nil,
  estimated_worker_count: nil,
  mcc: nil,
  minority_owned_business_designation: nil,
  monthly_estimated_revenue: nil,
  name: nil,
  product_description: nil,
  support_address: nil,
  support_email: nil,
  support_phone: nil,
  support_url: nil,
  url: nil
)
  @annual_revenue = annual_revenue
  @estimated_worker_count = estimated_worker_count
  @mcc = mcc
  @minority_owned_business_designation = minority_owned_business_designation
  @monthly_estimated_revenue = monthly_estimated_revenue
  @name = name
  @product_description = product_description
  @support_address = support_address
  @support_email = support_email
  @support_phone = support_phone
  @support_url = support_url
  @url = url
end

Instance Attribute Details

#annual_revenueObject

The applicant’s gross annual revenue for its preceding fiscal year.



3100
3101
3102
# File 'lib/stripe/resources/account.rb', line 3100

def annual_revenue
  @annual_revenue
end

#estimated_worker_countObject

An estimated upper bound of employees, contractors, vendors, etc. currently working for the business.



3102
3103
3104
# File 'lib/stripe/resources/account.rb', line 3102

def estimated_worker_count
  @estimated_worker_count
end

#mccObject

[The merchant category code for the account](/connect/setting-mcc). MCCs are used to classify businesses based on the goods or services they provide.



3104
3105
3106
# File 'lib/stripe/resources/account.rb', line 3104

def mcc
  @mcc
end

#minority_owned_business_designationObject

Whether the business is a minority-owned, women-owned, and/or LGBTQI+-owned business.



3106
3107
3108
# File 'lib/stripe/resources/account.rb', line 3106

def minority_owned_business_designation
  @minority_owned_business_designation
end

#monthly_estimated_revenueObject

An estimate of the monthly revenue of the business. Only accepted for accounts in Brazil and India.



3108
3109
3110
# File 'lib/stripe/resources/account.rb', line 3108

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#nameObject

The customer-facing business name.



3110
3111
3112
# File 'lib/stripe/resources/account.rb', line 3110

def name
  @name
end

#product_descriptionObject

Internal-only description of the product sold by, or service provided by, the business. Used by Stripe for risk and underwriting purposes.



3112
3113
3114
# File 'lib/stripe/resources/account.rb', line 3112

def product_description
  @product_description
end

#support_addressObject

A publicly available mailing address for sending support issues to.



3114
3115
3116
# File 'lib/stripe/resources/account.rb', line 3114

def support_address
  @support_address
end

#support_emailObject

A publicly available email address for sending support issues to.



3116
3117
3118
# File 'lib/stripe/resources/account.rb', line 3116

def support_email
  @support_email
end

#support_phoneObject

A publicly available phone number to call with support issues.



3118
3119
3120
# File 'lib/stripe/resources/account.rb', line 3118

def support_phone
  @support_phone
end

#support_urlObject

A publicly available website for handling support issues.



3120
3121
3122
# File 'lib/stripe/resources/account.rb', line 3120

def support_url
  @support_url
end

#urlObject

The business’s publicly available website.



3122
3123
3124
# File 'lib/stripe/resources/account.rb', line 3122

def url
  @url
end