Class: Stripe::Account::CreateParams::BusinessProfile

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: AnnualRevenue, MonthlyEstimatedRevenue, SupportAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(annual_revenue: nil, estimated_worker_count: nil, mcc: nil, minority_owned_business_designation: nil, monthly_estimated_revenue: nil, name: nil, product_description: nil, support_address: nil, support_email: nil, support_phone: nil, support_url: nil, url: nil) ⇒ BusinessProfile

Returns a new instance of BusinessProfile.



2773
2774
2775
2776
2777
2778
2779
2780
2781
2782
2783
2784
2785
2786
2787
2788
2789
2790
2791
2792
2793
2794
2795
2796
2797
2798
2799
# File 'lib/stripe/resources/account.rb', line 2773

def initialize(
  annual_revenue: nil,
  estimated_worker_count: nil,
  mcc: nil,
  minority_owned_business_designation: nil,
  monthly_estimated_revenue: nil,
  name: nil,
  product_description: nil,
  support_address: nil,
  support_email: nil,
  support_phone: nil,
  support_url: nil,
  url: nil
)
  @annual_revenue = annual_revenue
  @estimated_worker_count = estimated_worker_count
  @mcc = mcc
  @minority_owned_business_designation = minority_owned_business_designation
  @monthly_estimated_revenue = monthly_estimated_revenue
  @name = name
  @product_description = product_description
  @support_address = support_address
  @support_email = support_email
  @support_phone = support_phone
  @support_url = support_url
  @url = url
end

Instance Attribute Details

#annual_revenueObject

The applicant’s gross annual revenue for its preceding fiscal year.



2749
2750
2751
# File 'lib/stripe/resources/account.rb', line 2749

def annual_revenue
  @annual_revenue
end

#estimated_worker_countObject

An estimated upper bound of employees, contractors, vendors, etc. currently working for the business.



2751
2752
2753
# File 'lib/stripe/resources/account.rb', line 2751

def estimated_worker_count
  @estimated_worker_count
end

#mccObject

[The merchant category code for the account](/connect/setting-mcc). MCCs are used to classify businesses based on the goods or services they provide.



2753
2754
2755
# File 'lib/stripe/resources/account.rb', line 2753

def mcc
  @mcc
end

#minority_owned_business_designationObject

Whether the business is a minority-owned, women-owned, and/or LGBTQI+-owned business.



2755
2756
2757
# File 'lib/stripe/resources/account.rb', line 2755

def minority_owned_business_designation
  @minority_owned_business_designation
end

#monthly_estimated_revenueObject

An estimate of the monthly revenue of the business. Only accepted for accounts in Brazil and India.



2757
2758
2759
# File 'lib/stripe/resources/account.rb', line 2757

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#nameObject

The customer-facing business name.



2759
2760
2761
# File 'lib/stripe/resources/account.rb', line 2759

def name
  @name
end

#product_descriptionObject

Internal-only description of the product sold by, or service provided by, the business. Used by Stripe for risk and underwriting purposes.



2761
2762
2763
# File 'lib/stripe/resources/account.rb', line 2761

def product_description
  @product_description
end

#support_addressObject

A publicly available mailing address for sending support issues to.



2763
2764
2765
# File 'lib/stripe/resources/account.rb', line 2763

def support_address
  @support_address
end

#support_emailObject

A publicly available email address for sending support issues to.



2765
2766
2767
# File 'lib/stripe/resources/account.rb', line 2765

def support_email
  @support_email
end

#support_phoneObject

A publicly available phone number to call with support issues.



2767
2768
2769
# File 'lib/stripe/resources/account.rb', line 2767

def support_phone
  @support_phone
end

#support_urlObject

A publicly available website for handling support issues.



2769
2770
2771
# File 'lib/stripe/resources/account.rb', line 2769

def support_url
  @support_url
end

#urlObject

The business’s publicly available website.



2771
2772
2773
# File 'lib/stripe/resources/account.rb', line 2771

def url
  @url
end