Class: Stripe::Account::CreateParams::BusinessProfile

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: AnnualRevenue, MonthlyEstimatedRevenue, SupportAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(annual_revenue: nil, estimated_worker_count: nil, mcc: nil, minority_owned_business_designation: nil, monthly_estimated_revenue: nil, name: nil, product_description: nil, support_address: nil, support_email: nil, support_phone: nil, support_url: nil, url: nil) ⇒ BusinessProfile

Returns a new instance of BusinessProfile.



2728
2729
2730
2731
2732
2733
2734
2735
2736
2737
2738
2739
2740
2741
2742
2743
2744
2745
2746
2747
2748
2749
2750
2751
2752
2753
2754
# File 'lib/stripe/resources/account.rb', line 2728

def initialize(
  annual_revenue: nil,
  estimated_worker_count: nil,
  mcc: nil,
  minority_owned_business_designation: nil,
  monthly_estimated_revenue: nil,
  name: nil,
  product_description: nil,
  support_address: nil,
  support_email: nil,
  support_phone: nil,
  support_url: nil,
  url: nil
)
  @annual_revenue = annual_revenue
  @estimated_worker_count = estimated_worker_count
  @mcc = mcc
  @minority_owned_business_designation = minority_owned_business_designation
  @monthly_estimated_revenue = monthly_estimated_revenue
  @name = name
  @product_description = product_description
  @support_address = support_address
  @support_email = support_email
  @support_phone = support_phone
  @support_url = support_url
  @url = url
end

Instance Attribute Details

#annual_revenueObject

The applicant’s gross annual revenue for its preceding fiscal year.



2704
2705
2706
# File 'lib/stripe/resources/account.rb', line 2704

def annual_revenue
  @annual_revenue
end

#estimated_worker_countObject

An estimated upper bound of employees, contractors, vendors, etc. currently working for the business.



2706
2707
2708
# File 'lib/stripe/resources/account.rb', line 2706

def estimated_worker_count
  @estimated_worker_count
end

#mccObject

[The merchant category code for the account](/connect/setting-mcc). MCCs are used to classify businesses based on the goods or services they provide.



2708
2709
2710
# File 'lib/stripe/resources/account.rb', line 2708

def mcc
  @mcc
end

#minority_owned_business_designationObject

Whether the business is a minority-owned, women-owned, and/or LGBTQI+-owned business.



2710
2711
2712
# File 'lib/stripe/resources/account.rb', line 2710

def minority_owned_business_designation
  @minority_owned_business_designation
end

#monthly_estimated_revenueObject

An estimate of the monthly revenue of the business. Only accepted for accounts in Brazil and India.



2712
2713
2714
# File 'lib/stripe/resources/account.rb', line 2712

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#nameObject

The customer-facing business name.



2714
2715
2716
# File 'lib/stripe/resources/account.rb', line 2714

def name
  @name
end

#product_descriptionObject

Internal-only description of the product sold by, or service provided by, the business. Used by Stripe for risk and underwriting purposes.



2716
2717
2718
# File 'lib/stripe/resources/account.rb', line 2716

def product_description
  @product_description
end

#support_addressObject

A publicly available mailing address for sending support issues to.



2718
2719
2720
# File 'lib/stripe/resources/account.rb', line 2718

def support_address
  @support_address
end

#support_emailObject

A publicly available email address for sending support issues to.



2720
2721
2722
# File 'lib/stripe/resources/account.rb', line 2720

def support_email
  @support_email
end

#support_phoneObject

A publicly available phone number to call with support issues.



2722
2723
2724
# File 'lib/stripe/resources/account.rb', line 2722

def support_phone
  @support_phone
end

#support_urlObject

A publicly available website for handling support issues.



2724
2725
2726
# File 'lib/stripe/resources/account.rb', line 2724

def support_url
  @support_url
end

#urlObject

The business’s publicly available website.



2726
2727
2728
# File 'lib/stripe/resources/account.rb', line 2726

def url
  @url
end