Class: Stripe::Account::CreateParams::BusinessProfile
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::CreateParams::BusinessProfile
- Defined in:
- lib/stripe/resources/account.rb
Defined Under Namespace
Classes: AnnualRevenue, MonthlyEstimatedRevenue, SupportAddress
Instance Attribute Summary collapse
-
#annual_revenue ⇒ Object
The applicant’s gross annual revenue for its preceding fiscal year.
-
#estimated_worker_count ⇒ Object
An estimated upper bound of employees, contractors, vendors, etc.
-
#mcc ⇒ Object
[The merchant category code for the account](/connect/setting-mcc).
-
#minority_owned_business_designation ⇒ Object
Whether the business is a minority-owned, women-owned, and/or LGBTQI+-owned business.
-
#monthly_estimated_revenue ⇒ Object
An estimate of the monthly revenue of the business.
-
#name ⇒ Object
The customer-facing business name.
-
#product_description ⇒ Object
Internal-only description of the product sold by, or service provided by, the business.
-
#support_address ⇒ Object
A publicly available mailing address for sending support issues to.
-
#support_email ⇒ Object
A publicly available email address for sending support issues to.
-
#support_phone ⇒ Object
A publicly available phone number to call with support issues.
-
#support_url ⇒ Object
A publicly available website for handling support issues.
-
#url ⇒ Object
The business’s publicly available website.
Instance Method Summary collapse
-
#initialize(annual_revenue: nil, estimated_worker_count: nil, mcc: nil, minority_owned_business_designation: nil, monthly_estimated_revenue: nil, name: nil, product_description: nil, support_address: nil, support_email: nil, support_phone: nil, support_url: nil, url: nil) ⇒ BusinessProfile
constructor
A new instance of BusinessProfile.
Methods inherited from RequestParams
Constructor Details
#initialize(annual_revenue: nil, estimated_worker_count: nil, mcc: nil, minority_owned_business_designation: nil, monthly_estimated_revenue: nil, name: nil, product_description: nil, support_address: nil, support_email: nil, support_phone: nil, support_url: nil, url: nil) ⇒ BusinessProfile
Returns a new instance of BusinessProfile.
2714 2715 2716 2717 2718 2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 2730 2731 2732 2733 2734 2735 2736 2737 2738 2739 2740 |
# File 'lib/stripe/resources/account.rb', line 2714 def initialize( annual_revenue: nil, estimated_worker_count: nil, mcc: nil, minority_owned_business_designation: nil, monthly_estimated_revenue: nil, name: nil, product_description: nil, support_address: nil, support_email: nil, support_phone: nil, support_url: nil, url: nil ) @annual_revenue = annual_revenue @estimated_worker_count = estimated_worker_count @mcc = mcc @minority_owned_business_designation = minority_owned_business_designation @monthly_estimated_revenue = monthly_estimated_revenue @name = name @product_description = product_description @support_address = support_address @support_email = support_email @support_phone = support_phone @support_url = support_url @url = url end |
Instance Attribute Details
#annual_revenue ⇒ Object
The applicant’s gross annual revenue for its preceding fiscal year.
2690 2691 2692 |
# File 'lib/stripe/resources/account.rb', line 2690 def annual_revenue @annual_revenue end |
#estimated_worker_count ⇒ Object
An estimated upper bound of employees, contractors, vendors, etc. currently working for the business.
2692 2693 2694 |
# File 'lib/stripe/resources/account.rb', line 2692 def estimated_worker_count @estimated_worker_count end |
#mcc ⇒ Object
[The merchant category code for the account](/connect/setting-mcc). MCCs are used to classify businesses based on the goods or services they provide.
2694 2695 2696 |
# File 'lib/stripe/resources/account.rb', line 2694 def mcc @mcc end |
#minority_owned_business_designation ⇒ Object
Whether the business is a minority-owned, women-owned, and/or LGBTQI+-owned business.
2696 2697 2698 |
# File 'lib/stripe/resources/account.rb', line 2696 def minority_owned_business_designation @minority_owned_business_designation end |
#monthly_estimated_revenue ⇒ Object
An estimate of the monthly revenue of the business. Only accepted for accounts in Brazil and India.
2698 2699 2700 |
# File 'lib/stripe/resources/account.rb', line 2698 def monthly_estimated_revenue @monthly_estimated_revenue end |
#name ⇒ Object
The customer-facing business name.
2700 2701 2702 |
# File 'lib/stripe/resources/account.rb', line 2700 def name @name end |
#product_description ⇒ Object
Internal-only description of the product sold by, or service provided by, the business. Used by Stripe for risk and underwriting purposes.
2702 2703 2704 |
# File 'lib/stripe/resources/account.rb', line 2702 def product_description @product_description end |
#support_address ⇒ Object
A publicly available mailing address for sending support issues to.
2704 2705 2706 |
# File 'lib/stripe/resources/account.rb', line 2704 def support_address @support_address end |
#support_email ⇒ Object
A publicly available email address for sending support issues to.
2706 2707 2708 |
# File 'lib/stripe/resources/account.rb', line 2706 def support_email @support_email end |
#support_phone ⇒ Object
A publicly available phone number to call with support issues.
2708 2709 2710 |
# File 'lib/stripe/resources/account.rb', line 2708 def support_phone @support_phone end |
#support_url ⇒ Object
A publicly available website for handling support issues.
2710 2711 2712 |
# File 'lib/stripe/resources/account.rb', line 2710 def support_url @support_url end |
#url ⇒ Object
The business’s publicly available website.
2712 2713 2714 |
# File 'lib/stripe/resources/account.rb', line 2712 def url @url end |