Class: Stripe::Account::CreateParams::BusinessProfile

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: AnnualRevenue, MonthlyEstimatedRevenue, SupportAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(annual_revenue: nil, estimated_worker_count: nil, mcc: nil, minority_owned_business_designation: nil, monthly_estimated_revenue: nil, name: nil, product_description: nil, support_address: nil, support_email: nil, support_phone: nil, support_url: nil, url: nil) ⇒ BusinessProfile

Returns a new instance of BusinessProfile.



3035
3036
3037
3038
3039
3040
3041
3042
3043
3044
3045
3046
3047
3048
3049
3050
3051
3052
3053
3054
3055
3056
3057
3058
3059
3060
3061
# File 'lib/stripe/resources/account.rb', line 3035

def initialize(
  annual_revenue: nil,
  estimated_worker_count: nil,
  mcc: nil,
  minority_owned_business_designation: nil,
  monthly_estimated_revenue: nil,
  name: nil,
  product_description: nil,
  support_address: nil,
  support_email: nil,
  support_phone: nil,
  support_url: nil,
  url: nil
)
  @annual_revenue = annual_revenue
  @estimated_worker_count = estimated_worker_count
  @mcc = mcc
  @minority_owned_business_designation = minority_owned_business_designation
  @monthly_estimated_revenue = monthly_estimated_revenue
  @name = name
  @product_description = product_description
  @support_address = support_address
  @support_email = support_email
  @support_phone = support_phone
  @support_url = support_url
  @url = url
end

Instance Attribute Details

#annual_revenueObject

The applicant’s gross annual revenue for its preceding fiscal year.



3011
3012
3013
# File 'lib/stripe/resources/account.rb', line 3011

def annual_revenue
  @annual_revenue
end

#estimated_worker_countObject

An estimated upper bound of employees, contractors, vendors, etc. currently working for the business.



3013
3014
3015
# File 'lib/stripe/resources/account.rb', line 3013

def estimated_worker_count
  @estimated_worker_count
end

#mccObject

[The merchant category code for the account](/connect/setting-mcc). MCCs are used to classify businesses based on the goods or services they provide.



3015
3016
3017
# File 'lib/stripe/resources/account.rb', line 3015

def mcc
  @mcc
end

#minority_owned_business_designationObject

Whether the business is a minority-owned, women-owned, and/or LGBTQI+-owned business.



3017
3018
3019
# File 'lib/stripe/resources/account.rb', line 3017

def minority_owned_business_designation
  @minority_owned_business_designation
end

#monthly_estimated_revenueObject

An estimate of the monthly revenue of the business. Only accepted for accounts in Brazil and India.



3019
3020
3021
# File 'lib/stripe/resources/account.rb', line 3019

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#nameObject

The customer-facing business name.



3021
3022
3023
# File 'lib/stripe/resources/account.rb', line 3021

def name
  @name
end

#product_descriptionObject

Internal-only description of the product sold by, or service provided by, the business. Used by Stripe for risk and underwriting purposes.



3023
3024
3025
# File 'lib/stripe/resources/account.rb', line 3023

def product_description
  @product_description
end

#support_addressObject

A publicly available mailing address for sending support issues to.



3025
3026
3027
# File 'lib/stripe/resources/account.rb', line 3025

def support_address
  @support_address
end

#support_emailObject

A publicly available email address for sending support issues to.



3027
3028
3029
# File 'lib/stripe/resources/account.rb', line 3027

def support_email
  @support_email
end

#support_phoneObject

A publicly available phone number to call with support issues.



3029
3030
3031
# File 'lib/stripe/resources/account.rb', line 3029

def support_phone
  @support_phone
end

#support_urlObject

A publicly available website for handling support issues.



3031
3032
3033
# File 'lib/stripe/resources/account.rb', line 3031

def support_url
  @support_url
end

#urlObject

The business’s publicly available website.



3033
3034
3035
# File 'lib/stripe/resources/account.rb', line 3033

def url
  @url
end