Class: Stripe::Account::CreateParams::BusinessProfile

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: AnnualRevenue, MonthlyEstimatedRevenue, SupportAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(annual_revenue: nil, estimated_worker_count: nil, mcc: nil, minority_owned_business_designation: nil, monthly_estimated_revenue: nil, name: nil, product_description: nil, support_address: nil, support_email: nil, support_phone: nil, support_url: nil, url: nil) ⇒ BusinessProfile

Returns a new instance of BusinessProfile.



3065
3066
3067
3068
3069
3070
3071
3072
3073
3074
3075
3076
3077
3078
3079
3080
3081
3082
3083
3084
3085
3086
3087
3088
3089
3090
3091
# File 'lib/stripe/resources/account.rb', line 3065

def initialize(
  annual_revenue: nil,
  estimated_worker_count: nil,
  mcc: nil,
  minority_owned_business_designation: nil,
  monthly_estimated_revenue: nil,
  name: nil,
  product_description: nil,
  support_address: nil,
  support_email: nil,
  support_phone: nil,
  support_url: nil,
  url: nil
)
  @annual_revenue = annual_revenue
  @estimated_worker_count = estimated_worker_count
  @mcc = mcc
  @minority_owned_business_designation = minority_owned_business_designation
  @monthly_estimated_revenue = monthly_estimated_revenue
  @name = name
  @product_description = product_description
  @support_address = support_address
  @support_email = support_email
  @support_phone = support_phone
  @support_url = support_url
  @url = url
end

Instance Attribute Details

#annual_revenueObject

The applicant’s gross annual revenue for its preceding fiscal year.



3041
3042
3043
# File 'lib/stripe/resources/account.rb', line 3041

def annual_revenue
  @annual_revenue
end

#estimated_worker_countObject

An estimated upper bound of employees, contractors, vendors, etc. currently working for the business.



3043
3044
3045
# File 'lib/stripe/resources/account.rb', line 3043

def estimated_worker_count
  @estimated_worker_count
end

#mccObject

[The merchant category code for the account](/connect/setting-mcc). MCCs are used to classify businesses based on the goods or services they provide.



3045
3046
3047
# File 'lib/stripe/resources/account.rb', line 3045

def mcc
  @mcc
end

#minority_owned_business_designationObject

Whether the business is a minority-owned, women-owned, and/or LGBTQI+-owned business.



3047
3048
3049
# File 'lib/stripe/resources/account.rb', line 3047

def minority_owned_business_designation
  @minority_owned_business_designation
end

#monthly_estimated_revenueObject

An estimate of the monthly revenue of the business. Only accepted for accounts in Brazil and India.



3049
3050
3051
# File 'lib/stripe/resources/account.rb', line 3049

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#nameObject

The customer-facing business name.



3051
3052
3053
# File 'lib/stripe/resources/account.rb', line 3051

def name
  @name
end

#product_descriptionObject

Internal-only description of the product sold by, or service provided by, the business. Used by Stripe for risk and underwriting purposes.



3053
3054
3055
# File 'lib/stripe/resources/account.rb', line 3053

def product_description
  @product_description
end

#support_addressObject

A publicly available mailing address for sending support issues to.



3055
3056
3057
# File 'lib/stripe/resources/account.rb', line 3055

def support_address
  @support_address
end

#support_emailObject

A publicly available email address for sending support issues to.



3057
3058
3059
# File 'lib/stripe/resources/account.rb', line 3057

def support_email
  @support_email
end

#support_phoneObject

A publicly available phone number to call with support issues.



3059
3060
3061
# File 'lib/stripe/resources/account.rb', line 3059

def support_phone
  @support_phone
end

#support_urlObject

A publicly available website for handling support issues.



3061
3062
3063
# File 'lib/stripe/resources/account.rb', line 3061

def support_url
  @support_url
end

#urlObject

The business’s publicly available website.



3063
3064
3065
# File 'lib/stripe/resources/account.rb', line 3063

def url
  @url
end