Class: Stripe::Account::CreateParams::BusinessProfile

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: AnnualRevenue, MonthlyEstimatedRevenue, SupportAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(annual_revenue: nil, estimated_worker_count: nil, mcc: nil, monthly_estimated_revenue: nil, name: nil, product_description: nil, support_address: nil, support_email: nil, support_phone: nil, support_url: nil, url: nil) ⇒ BusinessProfile

Returns a new instance of BusinessProfile.



2676
2677
2678
2679
2680
2681
2682
2683
2684
2685
2686
2687
2688
2689
2690
2691
2692
2693
2694
2695
2696
2697
2698
2699
2700
# File 'lib/stripe/resources/account.rb', line 2676

def initialize(
  annual_revenue: nil,
  estimated_worker_count: nil,
  mcc: nil,
  monthly_estimated_revenue: nil,
  name: nil,
  product_description: nil,
  support_address: nil,
  support_email: nil,
  support_phone: nil,
  support_url: nil,
  url: nil
)
  @annual_revenue = annual_revenue
  @estimated_worker_count = estimated_worker_count
  @mcc = mcc
  @monthly_estimated_revenue = monthly_estimated_revenue
  @name = name
  @product_description = product_description
  @support_address = support_address
  @support_email = support_email
  @support_phone = support_phone
  @support_url = support_url
  @url = url
end

Instance Attribute Details

#annual_revenueObject

The applicant’s gross annual revenue for its preceding fiscal year.



2654
2655
2656
# File 'lib/stripe/resources/account.rb', line 2654

def annual_revenue
  @annual_revenue
end

#estimated_worker_countObject

An estimated upper bound of employees, contractors, vendors, etc. currently working for the business.



2656
2657
2658
# File 'lib/stripe/resources/account.rb', line 2656

def estimated_worker_count
  @estimated_worker_count
end

#mccObject

[The merchant category code for the account](/connect/setting-mcc). MCCs are used to classify businesses based on the goods or services they provide.



2658
2659
2660
# File 'lib/stripe/resources/account.rb', line 2658

def mcc
  @mcc
end

#monthly_estimated_revenueObject

An estimate of the monthly revenue of the business. Only accepted for accounts in Brazil and India.



2660
2661
2662
# File 'lib/stripe/resources/account.rb', line 2660

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#nameObject

The customer-facing business name.



2662
2663
2664
# File 'lib/stripe/resources/account.rb', line 2662

def name
  @name
end

#product_descriptionObject

Internal-only description of the product sold by, or service provided by, the business. Used by Stripe for risk and underwriting purposes.



2664
2665
2666
# File 'lib/stripe/resources/account.rb', line 2664

def product_description
  @product_description
end

#support_addressObject

A publicly available mailing address for sending support issues to.



2666
2667
2668
# File 'lib/stripe/resources/account.rb', line 2666

def support_address
  @support_address
end

#support_emailObject

A publicly available email address for sending support issues to.



2668
2669
2670
# File 'lib/stripe/resources/account.rb', line 2668

def support_email
  @support_email
end

#support_phoneObject

A publicly available phone number to call with support issues.



2670
2671
2672
# File 'lib/stripe/resources/account.rb', line 2670

def support_phone
  @support_phone
end

#support_urlObject

A publicly available website for handling support issues.



2672
2673
2674
# File 'lib/stripe/resources/account.rb', line 2672

def support_url
  @support_url
end

#urlObject

The business’s publicly available website.



2674
2675
2676
# File 'lib/stripe/resources/account.rb', line 2674

def url
  @url
end