Class: Stripe::Account::CreateParams::BusinessProfile

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: AnnualRevenue, MonthlyEstimatedRevenue, SupportAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(annual_revenue: nil, estimated_worker_count: nil, mcc: nil, monthly_estimated_revenue: nil, name: nil, product_description: nil, support_address: nil, support_email: nil, support_phone: nil, support_url: nil, url: nil) ⇒ BusinessProfile

Returns a new instance of BusinessProfile.



3027
3028
3029
3030
3031
3032
3033
3034
3035
3036
3037
3038
3039
3040
3041
3042
3043
3044
3045
3046
3047
3048
3049
3050
3051
# File 'lib/stripe/resources/account.rb', line 3027

def initialize(
  annual_revenue: nil,
  estimated_worker_count: nil,
  mcc: nil,
  monthly_estimated_revenue: nil,
  name: nil,
  product_description: nil,
  support_address: nil,
  support_email: nil,
  support_phone: nil,
  support_url: nil,
  url: nil
)
  @annual_revenue = annual_revenue
  @estimated_worker_count = estimated_worker_count
  @mcc = mcc
  @monthly_estimated_revenue = monthly_estimated_revenue
  @name = name
  @product_description = product_description
  @support_address = support_address
  @support_email = support_email
  @support_phone = support_phone
  @support_url = support_url
  @url = url
end

Instance Attribute Details

#annual_revenueObject

The applicant’s gross annual revenue for its preceding fiscal year.



3005
3006
3007
# File 'lib/stripe/resources/account.rb', line 3005

def annual_revenue
  @annual_revenue
end

#estimated_worker_countObject

An estimated upper bound of employees, contractors, vendors, etc. currently working for the business.



3007
3008
3009
# File 'lib/stripe/resources/account.rb', line 3007

def estimated_worker_count
  @estimated_worker_count
end

#mccObject

[The merchant category code for the account](/connect/setting-mcc). MCCs are used to classify businesses based on the goods or services they provide.



3009
3010
3011
# File 'lib/stripe/resources/account.rb', line 3009

def mcc
  @mcc
end

#monthly_estimated_revenueObject

An estimate of the monthly revenue of the business. Only accepted for accounts in Brazil and India.



3011
3012
3013
# File 'lib/stripe/resources/account.rb', line 3011

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#nameObject

The customer-facing business name.



3013
3014
3015
# File 'lib/stripe/resources/account.rb', line 3013

def name
  @name
end

#product_descriptionObject

Internal-only description of the product sold by, or service provided by, the business. Used by Stripe for risk and underwriting purposes.



3015
3016
3017
# File 'lib/stripe/resources/account.rb', line 3015

def product_description
  @product_description
end

#support_addressObject

A publicly available mailing address for sending support issues to.



3017
3018
3019
# File 'lib/stripe/resources/account.rb', line 3017

def support_address
  @support_address
end

#support_emailObject

A publicly available email address for sending support issues to.



3019
3020
3021
# File 'lib/stripe/resources/account.rb', line 3019

def support_email
  @support_email
end

#support_phoneObject

A publicly available phone number to call with support issues.



3021
3022
3023
# File 'lib/stripe/resources/account.rb', line 3021

def support_phone
  @support_phone
end

#support_urlObject

A publicly available website for handling support issues.



3023
3024
3025
# File 'lib/stripe/resources/account.rb', line 3023

def support_url
  @support_url
end

#urlObject

The business’s publicly available website.



3025
3026
3027
# File 'lib/stripe/resources/account.rb', line 3025

def url
  @url
end