Class: Stripe::Account::CreateParams::BusinessProfile

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: AnnualRevenue, MonthlyEstimatedRevenue, SupportAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(annual_revenue: nil, estimated_worker_count: nil, mcc: nil, monthly_estimated_revenue: nil, name: nil, product_description: nil, support_address: nil, support_email: nil, support_phone: nil, support_url: nil, url: nil) ⇒ BusinessProfile

Returns a new instance of BusinessProfile.



2971
2972
2973
2974
2975
2976
2977
2978
2979
2980
2981
2982
2983
2984
2985
2986
2987
2988
2989
2990
2991
2992
2993
2994
2995
# File 'lib/stripe/resources/account.rb', line 2971

def initialize(
  annual_revenue: nil,
  estimated_worker_count: nil,
  mcc: nil,
  monthly_estimated_revenue: nil,
  name: nil,
  product_description: nil,
  support_address: nil,
  support_email: nil,
  support_phone: nil,
  support_url: nil,
  url: nil
)
  @annual_revenue = annual_revenue
  @estimated_worker_count = estimated_worker_count
  @mcc = mcc
  @monthly_estimated_revenue = monthly_estimated_revenue
  @name = name
  @product_description = product_description
  @support_address = support_address
  @support_email = support_email
  @support_phone = support_phone
  @support_url = support_url
  @url = url
end

Instance Attribute Details

#annual_revenueObject

The applicant’s gross annual revenue for its preceding fiscal year.



2949
2950
2951
# File 'lib/stripe/resources/account.rb', line 2949

def annual_revenue
  @annual_revenue
end

#estimated_worker_countObject

An estimated upper bound of employees, contractors, vendors, etc. currently working for the business.



2951
2952
2953
# File 'lib/stripe/resources/account.rb', line 2951

def estimated_worker_count
  @estimated_worker_count
end

#mccObject

[The merchant category code for the account](/connect/setting-mcc). MCCs are used to classify businesses based on the goods or services they provide.



2953
2954
2955
# File 'lib/stripe/resources/account.rb', line 2953

def mcc
  @mcc
end

#monthly_estimated_revenueObject

An estimate of the monthly revenue of the business. Only accepted for accounts in Brazil and India.



2955
2956
2957
# File 'lib/stripe/resources/account.rb', line 2955

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#nameObject

The customer-facing business name.



2957
2958
2959
# File 'lib/stripe/resources/account.rb', line 2957

def name
  @name
end

#product_descriptionObject

Internal-only description of the product sold by, or service provided by, the business. Used by Stripe for risk and underwriting purposes.



2959
2960
2961
# File 'lib/stripe/resources/account.rb', line 2959

def product_description
  @product_description
end

#support_addressObject

A publicly available mailing address for sending support issues to.



2961
2962
2963
# File 'lib/stripe/resources/account.rb', line 2961

def support_address
  @support_address
end

#support_emailObject

A publicly available email address for sending support issues to.



2963
2964
2965
# File 'lib/stripe/resources/account.rb', line 2963

def support_email
  @support_email
end

#support_phoneObject

A publicly available phone number to call with support issues.



2965
2966
2967
# File 'lib/stripe/resources/account.rb', line 2965

def support_phone
  @support_phone
end

#support_urlObject

A publicly available website for handling support issues.



2967
2968
2969
# File 'lib/stripe/resources/account.rb', line 2967

def support_url
  @support_url
end

#urlObject

The business’s publicly available website.



2969
2970
2971
# File 'lib/stripe/resources/account.rb', line 2969

def url
  @url
end