Class: Stripe::Account::CreateParams::BusinessProfile

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: AnnualRevenue, MonthlyEstimatedRevenue, SupportAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(annual_revenue: nil, estimated_worker_count: nil, mcc: nil, monthly_estimated_revenue: nil, name: nil, product_description: nil, support_address: nil, support_email: nil, support_phone: nil, support_url: nil, url: nil) ⇒ BusinessProfile

Returns a new instance of BusinessProfile.



3378
3379
3380
3381
3382
3383
3384
3385
3386
3387
3388
3389
3390
3391
3392
3393
3394
3395
3396
3397
3398
3399
3400
3401
3402
# File 'lib/stripe/resources/account.rb', line 3378

def initialize(
  annual_revenue: nil,
  estimated_worker_count: nil,
  mcc: nil,
  monthly_estimated_revenue: nil,
  name: nil,
  product_description: nil,
  support_address: nil,
  support_email: nil,
  support_phone: nil,
  support_url: nil,
  url: nil
)
  @annual_revenue = annual_revenue
  @estimated_worker_count = estimated_worker_count
  @mcc = mcc
  @monthly_estimated_revenue = monthly_estimated_revenue
  @name = name
  @product_description = product_description
  @support_address = support_address
  @support_email = support_email
  @support_phone = support_phone
  @support_url = support_url
  @url = url
end

Instance Attribute Details

#annual_revenueObject

The applicant’s gross annual revenue for its preceding fiscal year.



3346
3347
3348
# File 'lib/stripe/resources/account.rb', line 3346

def annual_revenue
  @annual_revenue
end

#estimated_worker_countObject

An estimated upper bound of employees, contractors, vendors, etc. currently working for the business.



3349
3350
3351
# File 'lib/stripe/resources/account.rb', line 3349

def estimated_worker_count
  @estimated_worker_count
end

#mccObject

[The merchant category code for the account](/connect/setting-mcc). MCCs are used to classify businesses based on the goods or services they provide.



3352
3353
3354
# File 'lib/stripe/resources/account.rb', line 3352

def mcc
  @mcc
end

#monthly_estimated_revenueObject

An estimate of the monthly revenue of the business. Only accepted for accounts in Brazil and India.



3355
3356
3357
# File 'lib/stripe/resources/account.rb', line 3355

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#nameObject

The customer-facing business name.



3358
3359
3360
# File 'lib/stripe/resources/account.rb', line 3358

def name
  @name
end

#product_descriptionObject

Internal-only description of the product sold by, or service provided by, the business. Used by Stripe for risk and underwriting purposes.



3361
3362
3363
# File 'lib/stripe/resources/account.rb', line 3361

def product_description
  @product_description
end

#support_addressObject

A publicly available mailing address for sending support issues to.



3364
3365
3366
# File 'lib/stripe/resources/account.rb', line 3364

def support_address
  @support_address
end

#support_emailObject

A publicly available email address for sending support issues to.



3367
3368
3369
# File 'lib/stripe/resources/account.rb', line 3367

def support_email
  @support_email
end

#support_phoneObject

A publicly available phone number to call with support issues.



3370
3371
3372
# File 'lib/stripe/resources/account.rb', line 3370

def support_phone
  @support_phone
end

#support_urlObject

A publicly available website for handling support issues.



3373
3374
3375
# File 'lib/stripe/resources/account.rb', line 3373

def support_url
  @support_url
end

#urlObject

The business’s publicly available website.



3376
3377
3378
# File 'lib/stripe/resources/account.rb', line 3376

def url
  @url
end