Class: Stripe::Account::CreateParams::BusinessProfile

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: AnnualRevenue, MonthlyEstimatedRevenue, SupportAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(annual_revenue: nil, estimated_worker_count: nil, mcc: nil, monthly_estimated_revenue: nil, name: nil, product_description: nil, support_address: nil, support_email: nil, support_phone: nil, support_url: nil, url: nil) ⇒ BusinessProfile

Returns a new instance of BusinessProfile.



2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
2933
2934
2935
2936
2937
2938
2939
2940
2941
2942
2943
2944
2945
2946
# File 'lib/stripe/resources/account.rb', line 2922

def initialize(
  annual_revenue: nil,
  estimated_worker_count: nil,
  mcc: nil,
  monthly_estimated_revenue: nil,
  name: nil,
  product_description: nil,
  support_address: nil,
  support_email: nil,
  support_phone: nil,
  support_url: nil,
  url: nil
)
  @annual_revenue = annual_revenue
  @estimated_worker_count = estimated_worker_count
  @mcc = mcc
  @monthly_estimated_revenue = monthly_estimated_revenue
  @name = name
  @product_description = product_description
  @support_address = support_address
  @support_email = support_email
  @support_phone = support_phone
  @support_url = support_url
  @url = url
end

Instance Attribute Details

#annual_revenueObject

The applicant’s gross annual revenue for its preceding fiscal year.



2900
2901
2902
# File 'lib/stripe/resources/account.rb', line 2900

def annual_revenue
  @annual_revenue
end

#estimated_worker_countObject

An estimated upper bound of employees, contractors, vendors, etc. currently working for the business.



2902
2903
2904
# File 'lib/stripe/resources/account.rb', line 2902

def estimated_worker_count
  @estimated_worker_count
end

#mccObject

[The merchant category code for the account](/connect/setting-mcc). MCCs are used to classify businesses based on the goods or services they provide.



2904
2905
2906
# File 'lib/stripe/resources/account.rb', line 2904

def mcc
  @mcc
end

#monthly_estimated_revenueObject

An estimate of the monthly revenue of the business. Only accepted for accounts in Brazil and India.



2906
2907
2908
# File 'lib/stripe/resources/account.rb', line 2906

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#nameObject

The customer-facing business name.



2908
2909
2910
# File 'lib/stripe/resources/account.rb', line 2908

def name
  @name
end

#product_descriptionObject

Internal-only description of the product sold by, or service provided by, the business. Used by Stripe for risk and underwriting purposes.



2910
2911
2912
# File 'lib/stripe/resources/account.rb', line 2910

def product_description
  @product_description
end

#support_addressObject

A publicly available mailing address for sending support issues to.



2912
2913
2914
# File 'lib/stripe/resources/account.rb', line 2912

def support_address
  @support_address
end

#support_emailObject

A publicly available email address for sending support issues to.



2914
2915
2916
# File 'lib/stripe/resources/account.rb', line 2914

def support_email
  @support_email
end

#support_phoneObject

A publicly available phone number to call with support issues.



2916
2917
2918
# File 'lib/stripe/resources/account.rb', line 2916

def support_phone
  @support_phone
end

#support_urlObject

A publicly available website for handling support issues.



2918
2919
2920
# File 'lib/stripe/resources/account.rb', line 2918

def support_url
  @support_url
end

#urlObject

The business’s publicly available website.



2920
2921
2922
# File 'lib/stripe/resources/account.rb', line 2920

def url
  @url
end