Class: Stripe::Account::CreateParams::BusinessProfile::MonthlyEstimatedRevenue
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::CreateParams::BusinessProfile::MonthlyEstimatedRevenue
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
A non-negative integer representing how much to charge in the [smallest currency unit](/currencies#zero-decimal).
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
Instance Method Summary collapse
-
#initialize(amount: nil, currency: nil) ⇒ MonthlyEstimatedRevenue
constructor
A new instance of MonthlyEstimatedRevenue.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, currency: nil) ⇒ MonthlyEstimatedRevenue
Returns a new instance of MonthlyEstimatedRevenue.
3004 3005 3006 3007 |
# File 'lib/stripe/resources/account.rb', line 3004 def initialize(amount: nil, currency: nil) @amount = amount @currency = currency end |
Instance Attribute Details
#amount ⇒ Object
A non-negative integer representing how much to charge in the [smallest currency unit](/currencies#zero-decimal).
3000 3001 3002 |
# File 'lib/stripe/resources/account.rb', line 3000 def amount @amount end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
3002 3003 3004 |
# File 'lib/stripe/resources/account.rb', line 3002 def currency @currency end |