Class: Stripe::Account::CreateParams::BusinessProfile::MonthlyEstimatedRevenue
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::CreateParams::BusinessProfile::MonthlyEstimatedRevenue
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
A non-negative integer representing how much to charge in the [smallest currency unit](/currencies#zero-decimal).
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
Instance Method Summary collapse
-
#initialize(amount: nil, currency: nil) ⇒ MonthlyEstimatedRevenue
constructor
A new instance of MonthlyEstimatedRevenue.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, currency: nil) ⇒ MonthlyEstimatedRevenue
Returns a new instance of MonthlyEstimatedRevenue.
3304 3305 3306 3307 |
# File 'lib/stripe/resources/account.rb', line 3304 def initialize(amount: nil, currency: nil) @amount = amount @currency = currency end |
Instance Attribute Details
#amount ⇒ Object
A non-negative integer representing how much to charge in the [smallest currency unit](/currencies#zero-decimal).
3299 3300 3301 |
# File 'lib/stripe/resources/account.rb', line 3299 def amount @amount end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
3302 3303 3304 |
# File 'lib/stripe/resources/account.rb', line 3302 def currency @currency end |