Class: Stripe::Account::CreateParams::Capabilities::CryptoPayments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::CreateParams::Capabilities::CryptoPayments
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#requested ⇒ Object
Passing true requests the capability for the account, if it is not already requested.
Instance Method Summary collapse
-
#initialize(requested: nil) ⇒ CryptoPayments
constructor
A new instance of CryptoPayments.
Methods inherited from RequestParams
Constructor Details
#initialize(requested: nil) ⇒ CryptoPayments
Returns a new instance of CryptoPayments.
3735 3736 3737 |
# File 'lib/stripe/resources/account.rb', line 3735 def initialize(requested: nil) @requested = requested end |
Instance Attribute Details
#requested ⇒ Object
Passing true requests the capability for the account, if it is not already requested. A requested capability may not immediately become active. Any requirements to activate the capability are returned in the ‘requirements` arrays.
3733 3734 3735 |
# File 'lib/stripe/resources/account.rb', line 3733 def requested @requested end |