Class: Stripe::Account::CreateParams::Capabilities::GopayPayments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(requested: nil) ⇒ GopayPayments

Returns a new instance of GopayPayments.



3590
3591
3592
# File 'lib/stripe/resources/account.rb', line 3590

def initialize(requested: nil)
  @requested = requested
end

Instance Attribute Details

#requestedObject

Passing true requests the capability for the account, if it is not already requested. A requested capability may not immediately become active. Any requirements to activate the capability are returned in the ‘requirements` arrays.



3588
3589
3590
# File 'lib/stripe/resources/account.rb', line 3588

def requested
  @requested
end