Class: Stripe::Account::CreateParams::Capabilities::KrCardPayments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::CreateParams::Capabilities::KrCardPayments
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#requested ⇒ Object
Passing true requests the capability for the account, if it is not already requested.
Instance Method Summary collapse
-
#initialize(requested: nil) ⇒ KrCardPayments
constructor
A new instance of KrCardPayments.
Methods inherited from RequestParams
Constructor Details
#initialize(requested: nil) ⇒ KrCardPayments
Returns a new instance of KrCardPayments.
3387 3388 3389 |
# File 'lib/stripe/resources/account.rb', line 3387 def initialize(requested: nil) @requested = requested end |
Instance Attribute Details
#requested ⇒ Object
Passing true requests the capability for the account, if it is not already requested. A requested capability may not immediately become active. Any requirements to activate the capability are returned in the ‘requirements` arrays.
3385 3386 3387 |
# File 'lib/stripe/resources/account.rb', line 3385 def requested @requested end |