Class: Stripe::Account::CreateParams::Capabilities::PaynowPayments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(requested: nil) ⇒ PaynowPayments

Returns a new instance of PaynowPayments.



3390
3391
3392
# File 'lib/stripe/resources/account.rb', line 3390

def initialize(requested: nil)
  @requested = requested
end

Instance Attribute Details

#requestedObject

Passing true requests the capability for the account, if it is not already requested. A requested capability may not immediately become active. Any requirements to activate the capability are returned in the ‘requirements` arrays.



3388
3389
3390
# File 'lib/stripe/resources/account.rb', line 3388

def requested
  @requested
end