Class: Stripe::Account::CreateParams::Company

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: Address, AddressKana, AddressKanji, DirectorshipDeclaration, OwnershipDeclaration, RegistrationDate, Verification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, address_kana: nil, address_kanji: nil, directors_provided: nil, directorship_declaration: nil, executives_provided: nil, export_license_id: nil, export_purpose_code: nil, name: nil, name_kana: nil, name_kanji: nil, owners_provided: nil, ownership_declaration: nil, ownership_exemption_reason: nil, phone: nil, registration_date: nil, registration_number: nil, structure: nil, tax_id: nil, tax_id_registrar: nil, vat_id: nil, verification: nil) ⇒ Company

Returns a new instance of Company.



3868
3869
3870
3871
3872
3873
3874
3875
3876
3877
3878
3879
3880
3881
3882
3883
3884
3885
3886
3887
3888
3889
3890
3891
3892
3893
3894
3895
3896
3897
3898
3899
3900
3901
3902
3903
3904
3905
3906
3907
3908
3909
3910
3911
3912
3913
3914
# File 'lib/stripe/resources/account.rb', line 3868

def initialize(
  address: nil,
  address_kana: nil,
  address_kanji: nil,
  directors_provided: nil,
  directorship_declaration: nil,
  executives_provided: nil,
  export_license_id: nil,
  export_purpose_code: nil,
  name: nil,
  name_kana: nil,
  name_kanji: nil,
  owners_provided: nil,
  ownership_declaration: nil,
  ownership_exemption_reason: nil,
  phone: nil,
  registration_date: nil,
  registration_number: nil,
  structure: nil,
  tax_id: nil,
  tax_id_registrar: nil,
  vat_id: nil,
  verification: nil
)
  @address = address
  @address_kana = address_kana
  @address_kanji = address_kanji
  @directors_provided = directors_provided
  @directorship_declaration = directorship_declaration
  @executives_provided = executives_provided
  @export_license_id = export_license_id
  @export_purpose_code = export_purpose_code
  @name = name
  @name_kana = name_kana
  @name_kanji = name_kanji
  @owners_provided = owners_provided
  @ownership_declaration = ownership_declaration
  @ownership_exemption_reason = ownership_exemption_reason
  @phone = phone
  @registration_date = registration_date
  @registration_number = registration_number
  @structure = structure
  @tax_id = tax_id
  @tax_id_registrar = tax_id_registrar
  @vat_id = vat_id
  @verification = verification
end

Instance Attribute Details

#addressObject

The company’s primary address.



3824
3825
3826
# File 'lib/stripe/resources/account.rb', line 3824

def address
  @address
end

#address_kanaObject

The Kana variation of the company’s primary address (Japan only).



3826
3827
3828
# File 'lib/stripe/resources/account.rb', line 3826

def address_kana
  @address_kana
end

#address_kanjiObject

The Kanji variation of the company’s primary address (Japan only).



3828
3829
3830
# File 'lib/stripe/resources/account.rb', line 3828

def address_kanji
  @address_kanji
end

#directors_providedObject

Whether the company’s directors have been provided. Set this Boolean to ‘true` after creating all the company’s directors with [the Persons API](/api/persons) for accounts with a ‘relationship.director` requirement. This value is not automatically set to `true` after creating directors, so it needs to be updated to indicate all directors have been provided.



3830
3831
3832
# File 'lib/stripe/resources/account.rb', line 3830

def directors_provided
  @directors_provided
end

#directorship_declarationObject

This hash is used to attest that the directors information provided to Stripe is both current and correct.



3832
3833
3834
# File 'lib/stripe/resources/account.rb', line 3832

def directorship_declaration
  @directorship_declaration
end

#executives_providedObject

Whether the company’s executives have been provided. Set this Boolean to ‘true` after creating all the company’s executives with [the Persons API](/api/persons) for accounts with a ‘relationship.executive` requirement.



3834
3835
3836
# File 'lib/stripe/resources/account.rb', line 3834

def executives_provided
  @executives_provided
end

#export_license_idObject

The export license ID number of the company, also referred as Import Export Code (India only).



3836
3837
3838
# File 'lib/stripe/resources/account.rb', line 3836

def export_license_id
  @export_license_id
end

#export_purpose_codeObject

The purpose code to use for export transactions (India only).



3838
3839
3840
# File 'lib/stripe/resources/account.rb', line 3838

def export_purpose_code
  @export_purpose_code
end

#nameObject

The company’s legal name.



3840
3841
3842
# File 'lib/stripe/resources/account.rb', line 3840

def name
  @name
end

#name_kanaObject

The Kana variation of the company’s legal name (Japan only).



3842
3843
3844
# File 'lib/stripe/resources/account.rb', line 3842

def name_kana
  @name_kana
end

#name_kanjiObject

The Kanji variation of the company’s legal name (Japan only).



3844
3845
3846
# File 'lib/stripe/resources/account.rb', line 3844

def name_kanji
  @name_kanji
end

#owners_providedObject

Whether the company’s owners have been provided. Set this Boolean to ‘true` after creating all the company’s owners with [the Persons API](/api/persons) for accounts with a ‘relationship.owner` requirement.



3846
3847
3848
# File 'lib/stripe/resources/account.rb', line 3846

def owners_provided
  @owners_provided
end

#ownership_declarationObject

This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.



3848
3849
3850
# File 'lib/stripe/resources/account.rb', line 3848

def ownership_declaration
  @ownership_declaration
end

#ownership_exemption_reasonObject

This value is used to determine if a business is exempt from providing ultimate beneficial owners. See [this support article](support.stripe.com/questions/exemption-from-providing-ownership-details) and [changelog](docs.stripe.com/changelog/acacia/2025-01-27/ownership-exemption-reason-accounts-api) for more details.



3850
3851
3852
# File 'lib/stripe/resources/account.rb', line 3850

def ownership_exemption_reason
  @ownership_exemption_reason
end

#phoneObject

The company’s phone number (used for verification).



3852
3853
3854
# File 'lib/stripe/resources/account.rb', line 3852

def phone
  @phone
end

#registration_dateObject

When the business was incorporated or registered.



3854
3855
3856
# File 'lib/stripe/resources/account.rb', line 3854

def registration_date
  @registration_date
end

#registration_numberObject

The identification number given to a company when it is registered or incorporated, if distinct from the identification number used for filing taxes. (Examples are the CIN for companies and LLP IN for partnerships in India, and the Company Registration Number in Hong Kong).



3856
3857
3858
# File 'lib/stripe/resources/account.rb', line 3856

def registration_number
  @registration_number
end

#structureObject

The category identifying the legal structure of the company or legal entity. See [Business structure](/connect/identity-verification#business-structure) for more details. Pass an empty string to unset this value.



3858
3859
3860
# File 'lib/stripe/resources/account.rb', line 3858

def structure
  @structure
end

#tax_idObject

The business ID number of the company, as appropriate for the company’s country. (Examples are an Employer ID Number in the U.S., a Business Number in Canada, or a Company Number in the UK.)



3860
3861
3862
# File 'lib/stripe/resources/account.rb', line 3860

def tax_id
  @tax_id
end

#tax_id_registrarObject

The jurisdiction in which the ‘tax_id` is registered (Germany-based companies only).



3862
3863
3864
# File 'lib/stripe/resources/account.rb', line 3862

def tax_id_registrar
  @tax_id_registrar
end

#vat_idObject

The VAT number of the company.



3864
3865
3866
# File 'lib/stripe/resources/account.rb', line 3864

def vat_id
  @vat_id
end

#verificationObject

Information on the verification state of the company.



3866
3867
3868
# File 'lib/stripe/resources/account.rb', line 3866

def verification
  @verification
end