Class: Stripe::Account::CreateParams::Company

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: Address, AddressKana, AddressKanji, DirectorshipDeclaration, OwnershipDeclaration, RegistrationDate, Verification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, address_kana: nil, address_kanji: nil, directors_provided: nil, directorship_declaration: nil, executives_provided: nil, export_license_id: nil, export_purpose_code: nil, name: nil, name_kana: nil, name_kanji: nil, owners_provided: nil, ownership_declaration: nil, ownership_exemption_reason: nil, phone: nil, registration_date: nil, registration_number: nil, structure: nil, tax_id: nil, tax_id_registrar: nil, vat_id: nil, verification: nil) ⇒ Company

Returns a new instance of Company.



4401
4402
4403
4404
4405
4406
4407
4408
4409
4410
4411
4412
4413
4414
4415
4416
4417
4418
4419
4420
4421
4422
4423
4424
4425
4426
4427
4428
4429
4430
4431
4432
4433
4434
4435
4436
4437
4438
4439
4440
4441
4442
4443
4444
4445
4446
4447
# File 'lib/stripe/resources/account.rb', line 4401

def initialize(
  address: nil,
  address_kana: nil,
  address_kanji: nil,
  directors_provided: nil,
  directorship_declaration: nil,
  executives_provided: nil,
  export_license_id: nil,
  export_purpose_code: nil,
  name: nil,
  name_kana: nil,
  name_kanji: nil,
  owners_provided: nil,
  ownership_declaration: nil,
  ownership_exemption_reason: nil,
  phone: nil,
  registration_date: nil,
  registration_number: nil,
  structure: nil,
  tax_id: nil,
  tax_id_registrar: nil,
  vat_id: nil,
  verification: nil
)
  @address = address
  @address_kana = address_kana
  @address_kanji = address_kanji
  @directors_provided = directors_provided
  @directorship_declaration = directorship_declaration
  @executives_provided = executives_provided
  @export_license_id = export_license_id
  @export_purpose_code = export_purpose_code
  @name = name
  @name_kana = name_kana
  @name_kanji = name_kanji
  @owners_provided = owners_provided
  @ownership_declaration = ownership_declaration
  @ownership_exemption_reason = ownership_exemption_reason
  @phone = phone
  @registration_date = registration_date
  @registration_number = registration_number
  @structure = structure
  @tax_id = tax_id
  @tax_id_registrar = tax_id_registrar
  @vat_id = vat_id
  @verification = verification
end

Instance Attribute Details

#addressObject

The company’s primary address.



4357
4358
4359
# File 'lib/stripe/resources/account.rb', line 4357

def address
  @address
end

#address_kanaObject

The Kana variation of the company’s primary address (Japan only).



4359
4360
4361
# File 'lib/stripe/resources/account.rb', line 4359

def address_kana
  @address_kana
end

#address_kanjiObject

The Kanji variation of the company’s primary address (Japan only).



4361
4362
4363
# File 'lib/stripe/resources/account.rb', line 4361

def address_kanji
  @address_kanji
end

#directors_providedObject

Whether the company’s directors have been provided. Set this Boolean to ‘true` after creating all the company’s directors with [the Persons API](/api/persons) for accounts with a ‘relationship.director` requirement. This value is not automatically set to `true` after creating directors, so it needs to be updated to indicate all directors have been provided.



4363
4364
4365
# File 'lib/stripe/resources/account.rb', line 4363

def directors_provided
  @directors_provided
end

#directorship_declarationObject

This hash is used to attest that the directors information provided to Stripe is both current and correct.



4365
4366
4367
# File 'lib/stripe/resources/account.rb', line 4365

def directorship_declaration
  @directorship_declaration
end

#executives_providedObject

Whether the company’s executives have been provided. Set this Boolean to ‘true` after creating all the company’s executives with [the Persons API](/api/persons) for accounts with a ‘relationship.executive` requirement.



4367
4368
4369
# File 'lib/stripe/resources/account.rb', line 4367

def executives_provided
  @executives_provided
end

#export_license_idObject

The export license ID number of the company, also referred as Import Export Code (India only).



4369
4370
4371
# File 'lib/stripe/resources/account.rb', line 4369

def export_license_id
  @export_license_id
end

#export_purpose_codeObject

The purpose code to use for export transactions (India only).



4371
4372
4373
# File 'lib/stripe/resources/account.rb', line 4371

def export_purpose_code
  @export_purpose_code
end

#nameObject

The company’s legal name.



4373
4374
4375
# File 'lib/stripe/resources/account.rb', line 4373

def name
  @name
end

#name_kanaObject

The Kana variation of the company’s legal name (Japan only).



4375
4376
4377
# File 'lib/stripe/resources/account.rb', line 4375

def name_kana
  @name_kana
end

#name_kanjiObject

The Kanji variation of the company’s legal name (Japan only).



4377
4378
4379
# File 'lib/stripe/resources/account.rb', line 4377

def name_kanji
  @name_kanji
end

#owners_providedObject

Whether the company’s owners have been provided. Set this Boolean to ‘true` after creating all the company’s owners with [the Persons API](/api/persons) for accounts with a ‘relationship.owner` requirement.



4379
4380
4381
# File 'lib/stripe/resources/account.rb', line 4379

def owners_provided
  @owners_provided
end

#ownership_declarationObject

This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.



4381
4382
4383
# File 'lib/stripe/resources/account.rb', line 4381

def ownership_declaration
  @ownership_declaration
end

#ownership_exemption_reasonObject

This value is used to determine if a business is exempt from providing ultimate beneficial owners. See [this support article](support.stripe.com/questions/exemption-from-providing-ownership-details) and [changelog](docs.stripe.com/changelog/acacia/2025-01-27/ownership-exemption-reason-accounts-api) for more details.



4383
4384
4385
# File 'lib/stripe/resources/account.rb', line 4383

def ownership_exemption_reason
  @ownership_exemption_reason
end

#phoneObject

The company’s phone number (used for verification).



4385
4386
4387
# File 'lib/stripe/resources/account.rb', line 4385

def phone
  @phone
end

#registration_dateObject

When the business was incorporated or registered.



4387
4388
4389
# File 'lib/stripe/resources/account.rb', line 4387

def registration_date
  @registration_date
end

#registration_numberObject

The identification number given to a company when it is registered or incorporated, if distinct from the identification number used for filing taxes. (Examples are the CIN for companies and LLP IN for partnerships in India, and the Company Registration Number in Hong Kong).



4389
4390
4391
# File 'lib/stripe/resources/account.rb', line 4389

def registration_number
  @registration_number
end

#structureObject

The category identifying the legal structure of the company or legal entity. See [Business structure](/connect/identity-verification#business-structure) for more details. Pass an empty string to unset this value.



4391
4392
4393
# File 'lib/stripe/resources/account.rb', line 4391

def structure
  @structure
end

#tax_idObject

The business ID number of the company, as appropriate for the company’s country. (Examples are an Employer ID Number in the U.S., a Business Number in Canada, or a Company Number in the UK.)



4393
4394
4395
# File 'lib/stripe/resources/account.rb', line 4393

def tax_id
  @tax_id
end

#tax_id_registrarObject

The jurisdiction in which the ‘tax_id` is registered (Germany-based companies only).



4395
4396
4397
# File 'lib/stripe/resources/account.rb', line 4395

def tax_id_registrar
  @tax_id_registrar
end

#vat_idObject

The VAT number of the company.



4397
4398
4399
# File 'lib/stripe/resources/account.rb', line 4397

def vat_id
  @vat_id
end

#verificationObject

Information on the verification state of the company.



4399
4400
4401
# File 'lib/stripe/resources/account.rb', line 4399

def verification
  @verification
end