Class: Stripe::Account::CreateParams::Company

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: Address, AddressKana, AddressKanji, OwnershipDeclaration, Verification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, address_kana: nil, address_kanji: nil, directors_provided: nil, executives_provided: nil, export_license_id: nil, export_purpose_code: nil, name: nil, name_kana: nil, name_kanji: nil, owners_provided: nil, ownership_declaration: nil, phone: nil, registration_number: nil, structure: nil, tax_id: nil, tax_id_registrar: nil, vat_id: nil, verification: nil) ⇒ Company

Returns a new instance of Company.



4645
4646
4647
4648
4649
4650
4651
4652
4653
4654
4655
4656
4657
4658
4659
4660
4661
4662
4663
4664
4665
4666
4667
4668
4669
4670
4671
4672
4673
4674
4675
4676
4677
4678
4679
4680
4681
4682
4683
4684
4685
# File 'lib/stripe/resources/account.rb', line 4645

def initialize(
  address: nil,
  address_kana: nil,
  address_kanji: nil,
  directors_provided: nil,
  executives_provided: nil,
  export_license_id: nil,
  export_purpose_code: nil,
  name: nil,
  name_kana: nil,
  name_kanji: nil,
  owners_provided: nil,
  ownership_declaration: nil,
  phone: nil,
  registration_number: nil,
  structure: nil,
  tax_id: nil,
  tax_id_registrar: nil,
  vat_id: nil,
  verification: nil
)
  @address = address
  @address_kana = address_kana
  @address_kanji = address_kanji
  @directors_provided = directors_provided
  @executives_provided = executives_provided
  @export_license_id = export_license_id
  @export_purpose_code = export_purpose_code
  @name = name
  @name_kana = name_kana
  @name_kanji = name_kanji
  @owners_provided = owners_provided
  @ownership_declaration = ownership_declaration
  @phone = phone
  @registration_number = registration_number
  @structure = structure
  @tax_id = tax_id
  @tax_id_registrar = tax_id_registrar
  @vat_id = vat_id
  @verification = verification
end

Instance Attribute Details

#addressObject

The company’s primary address.



4589
4590
4591
# File 'lib/stripe/resources/account.rb', line 4589

def address
  @address
end

#address_kanaObject

The Kana variation of the company’s primary address (Japan only).



4592
4593
4594
# File 'lib/stripe/resources/account.rb', line 4592

def address_kana
  @address_kana
end

#address_kanjiObject

The Kanji variation of the company’s primary address (Japan only).



4595
4596
4597
# File 'lib/stripe/resources/account.rb', line 4595

def address_kanji
  @address_kanji
end

#directors_providedObject

Whether the company’s directors have been provided. Set this Boolean to ‘true` after creating all the company’s directors with [the Persons API](/api/persons) for accounts with a ‘relationship.director` requirement. This value is not automatically set to `true` after creating directors, so it needs to be updated to indicate all directors have been provided.



4598
4599
4600
# File 'lib/stripe/resources/account.rb', line 4598

def directors_provided
  @directors_provided
end

#executives_providedObject

Whether the company’s executives have been provided. Set this Boolean to ‘true` after creating all the company’s executives with [the Persons API](/api/persons) for accounts with a ‘relationship.executive` requirement.



4601
4602
4603
# File 'lib/stripe/resources/account.rb', line 4601

def executives_provided
  @executives_provided
end

#export_license_idObject

The export license ID number of the company, also referred as Import Export Code (India only).



4604
4605
4606
# File 'lib/stripe/resources/account.rb', line 4604

def export_license_id
  @export_license_id
end

#export_purpose_codeObject

The purpose code to use for export transactions (India only).



4607
4608
4609
# File 'lib/stripe/resources/account.rb', line 4607

def export_purpose_code
  @export_purpose_code
end

#nameObject

The company’s legal name.



4610
4611
4612
# File 'lib/stripe/resources/account.rb', line 4610

def name
  @name
end

#name_kanaObject

The Kana variation of the company’s legal name (Japan only).



4613
4614
4615
# File 'lib/stripe/resources/account.rb', line 4613

def name_kana
  @name_kana
end

#name_kanjiObject

The Kanji variation of the company’s legal name (Japan only).



4616
4617
4618
# File 'lib/stripe/resources/account.rb', line 4616

def name_kanji
  @name_kanji
end

#owners_providedObject

Whether the company’s owners have been provided. Set this Boolean to ‘true` after creating all the company’s owners with [the Persons API](/api/persons) for accounts with a ‘relationship.owner` requirement.



4619
4620
4621
# File 'lib/stripe/resources/account.rb', line 4619

def owners_provided
  @owners_provided
end

#ownership_declarationObject

This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.



4622
4623
4624
# File 'lib/stripe/resources/account.rb', line 4622

def ownership_declaration
  @ownership_declaration
end

#phoneObject

The company’s phone number (used for verification).



4625
4626
4627
# File 'lib/stripe/resources/account.rb', line 4625

def phone
  @phone
end

#registration_numberObject

The identification number given to a company when it is registered or incorporated, if distinct from the identification number used for filing taxes. (Examples are the CIN for companies and LLP IN for partnerships in India, and the Company Registration Number in Hong Kong).



4628
4629
4630
# File 'lib/stripe/resources/account.rb', line 4628

def registration_number
  @registration_number
end

#structureObject

The category identifying the legal structure of the company or legal entity. See [Business structure](/connect/identity-verification#business-structure) for more details. Pass an empty string to unset this value.



4631
4632
4633
# File 'lib/stripe/resources/account.rb', line 4631

def structure
  @structure
end

#tax_idObject

The business ID number of the company, as appropriate for the company’s country. (Examples are an Employer ID Number in the U.S., a Business Number in Canada, or a Company Number in the UK.)



4634
4635
4636
# File 'lib/stripe/resources/account.rb', line 4634

def tax_id
  @tax_id
end

#tax_id_registrarObject

The jurisdiction in which the ‘tax_id` is registered (Germany-based companies only).



4637
4638
4639
# File 'lib/stripe/resources/account.rb', line 4637

def tax_id_registrar
  @tax_id_registrar
end

#vat_idObject

The VAT number of the company.



4640
4641
4642
# File 'lib/stripe/resources/account.rb', line 4640

def vat_id
  @vat_id
end

#verificationObject

Information on the verification state of the company.



4643
4644
4645
# File 'lib/stripe/resources/account.rb', line 4643

def verification
  @verification
end