Class: Stripe::Account::CreateParams::Company
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::CreateParams::Company
- Defined in:
- lib/stripe/resources/account.rb
Defined Under Namespace
Classes: Address, AddressKana, AddressKanji, DirectorshipDeclaration, OwnershipDeclaration, Verification
Instance Attribute Summary collapse
-
#address ⇒ Object
The company’s primary address.
-
#address_kana ⇒ Object
The Kana variation of the company’s primary address (Japan only).
-
#address_kanji ⇒ Object
The Kanji variation of the company’s primary address (Japan only).
-
#directors_provided ⇒ Object
Whether the company’s directors have been provided.
-
#directorship_declaration ⇒ Object
This hash is used to attest that the directors information provided to Stripe is both current and correct.
-
#executives_provided ⇒ Object
Whether the company’s executives have been provided.
-
#export_license_id ⇒ Object
The export license ID number of the company, also referred as Import Export Code (India only).
-
#export_purpose_code ⇒ Object
The purpose code to use for export transactions (India only).
-
#name ⇒ Object
The company’s legal name.
-
#name_kana ⇒ Object
The Kana variation of the company’s legal name (Japan only).
-
#name_kanji ⇒ Object
The Kanji variation of the company’s legal name (Japan only).
-
#owners_provided ⇒ Object
Whether the company’s owners have been provided.
-
#ownership_declaration ⇒ Object
This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.
-
#ownership_exemption_reason ⇒ Object
Attribute for param field ownership_exemption_reason.
-
#phone ⇒ Object
The company’s phone number (used for verification).
-
#registration_number ⇒ Object
The identification number given to a company when it is registered or incorporated, if distinct from the identification number used for filing taxes.
-
#structure ⇒ Object
The category identifying the legal structure of the company or legal entity.
-
#tax_id ⇒ Object
The business ID number of the company, as appropriate for the company’s country.
-
#tax_id_registrar ⇒ Object
The jurisdiction in which the ‘tax_id` is registered (Germany-based companies only).
-
#vat_id ⇒ Object
The VAT number of the company.
-
#verification ⇒ Object
Information on the verification state of the company.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, address_kana: nil, address_kanji: nil, directors_provided: nil, directorship_declaration: nil, executives_provided: nil, export_license_id: nil, export_purpose_code: nil, name: nil, name_kana: nil, name_kanji: nil, owners_provided: nil, ownership_declaration: nil, ownership_exemption_reason: nil, phone: nil, registration_number: nil, structure: nil, tax_id: nil, tax_id_registrar: nil, vat_id: nil, verification: nil) ⇒ Company
Returns a new instance of Company.
4149 4150 4151 4152 4153 4154 4155 4156 4157 4158 4159 4160 4161 4162 4163 4164 4165 4166 4167 4168 4169 4170 4171 4172 4173 4174 4175 4176 4177 4178 4179 4180 4181 4182 4183 4184 4185 4186 4187 4188 4189 4190 4191 4192 4193 |
# File 'lib/stripe/resources/account.rb', line 4149 def initialize( address: nil, address_kana: nil, address_kanji: nil, directors_provided: nil, directorship_declaration: nil, executives_provided: nil, export_license_id: nil, export_purpose_code: nil, name: nil, name_kana: nil, name_kanji: nil, owners_provided: nil, ownership_declaration: nil, ownership_exemption_reason: nil, phone: nil, registration_number: nil, structure: nil, tax_id: nil, tax_id_registrar: nil, vat_id: nil, verification: nil ) @address = address @address_kana = address_kana @address_kanji = address_kanji @directors_provided = directors_provided @directorship_declaration = directorship_declaration @executives_provided = executives_provided @export_license_id = export_license_id @export_purpose_code = export_purpose_code @name = name @name_kana = name_kana @name_kanji = name_kanji @owners_provided = owners_provided @ownership_declaration = ownership_declaration @ownership_exemption_reason = ownership_exemption_reason @phone = phone @registration_number = registration_number @structure = structure @tax_id = tax_id @tax_id_registrar = tax_id_registrar @vat_id = vat_id @verification = verification end |
Instance Attribute Details
#address ⇒ Object
The company’s primary address.
4107 4108 4109 |
# File 'lib/stripe/resources/account.rb', line 4107 def address @address end |
#address_kana ⇒ Object
The Kana variation of the company’s primary address (Japan only).
4109 4110 4111 |
# File 'lib/stripe/resources/account.rb', line 4109 def address_kana @address_kana end |
#address_kanji ⇒ Object
The Kanji variation of the company’s primary address (Japan only).
4111 4112 4113 |
# File 'lib/stripe/resources/account.rb', line 4111 def address_kanji @address_kanji end |
#directors_provided ⇒ Object
Whether the company’s directors have been provided. Set this Boolean to ‘true` after creating all the company’s directors with [the Persons API](/api/persons) for accounts with a ‘relationship.director` requirement. This value is not automatically set to `true` after creating directors, so it needs to be updated to indicate all directors have been provided.
4113 4114 4115 |
# File 'lib/stripe/resources/account.rb', line 4113 def directors_provided @directors_provided end |
#directorship_declaration ⇒ Object
This hash is used to attest that the directors information provided to Stripe is both current and correct.
4115 4116 4117 |
# File 'lib/stripe/resources/account.rb', line 4115 def directorship_declaration @directorship_declaration end |
#executives_provided ⇒ Object
Whether the company’s executives have been provided. Set this Boolean to ‘true` after creating all the company’s executives with [the Persons API](/api/persons) for accounts with a ‘relationship.executive` requirement.
4117 4118 4119 |
# File 'lib/stripe/resources/account.rb', line 4117 def executives_provided @executives_provided end |
#export_license_id ⇒ Object
The export license ID number of the company, also referred as Import Export Code (India only).
4119 4120 4121 |
# File 'lib/stripe/resources/account.rb', line 4119 def export_license_id @export_license_id end |
#export_purpose_code ⇒ Object
The purpose code to use for export transactions (India only).
4121 4122 4123 |
# File 'lib/stripe/resources/account.rb', line 4121 def export_purpose_code @export_purpose_code end |
#name ⇒ Object
The company’s legal name.
4123 4124 4125 |
# File 'lib/stripe/resources/account.rb', line 4123 def name @name end |
#name_kana ⇒ Object
The Kana variation of the company’s legal name (Japan only).
4125 4126 4127 |
# File 'lib/stripe/resources/account.rb', line 4125 def name_kana @name_kana end |
#name_kanji ⇒ Object
The Kanji variation of the company’s legal name (Japan only).
4127 4128 4129 |
# File 'lib/stripe/resources/account.rb', line 4127 def name_kanji @name_kanji end |
#owners_provided ⇒ Object
Whether the company’s owners have been provided. Set this Boolean to ‘true` after creating all the company’s owners with [the Persons API](/api/persons) for accounts with a ‘relationship.owner` requirement.
4129 4130 4131 |
# File 'lib/stripe/resources/account.rb', line 4129 def owners_provided @owners_provided end |
#ownership_declaration ⇒ Object
This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.
4131 4132 4133 |
# File 'lib/stripe/resources/account.rb', line 4131 def ownership_declaration @ownership_declaration end |
#ownership_exemption_reason ⇒ Object
Attribute for param field ownership_exemption_reason
4133 4134 4135 |
# File 'lib/stripe/resources/account.rb', line 4133 def ownership_exemption_reason @ownership_exemption_reason end |
#phone ⇒ Object
The company’s phone number (used for verification).
4135 4136 4137 |
# File 'lib/stripe/resources/account.rb', line 4135 def phone @phone end |
#registration_number ⇒ Object
The identification number given to a company when it is registered or incorporated, if distinct from the identification number used for filing taxes. (Examples are the CIN for companies and LLP IN for partnerships in India, and the Company Registration Number in Hong Kong).
4137 4138 4139 |
# File 'lib/stripe/resources/account.rb', line 4137 def registration_number @registration_number end |
#structure ⇒ Object
The category identifying the legal structure of the company or legal entity. See [Business structure](/connect/identity-verification#business-structure) for more details. Pass an empty string to unset this value.
4139 4140 4141 |
# File 'lib/stripe/resources/account.rb', line 4139 def structure @structure end |
#tax_id ⇒ Object
The business ID number of the company, as appropriate for the company’s country. (Examples are an Employer ID Number in the U.S., a Business Number in Canada, or a Company Number in the UK.)
4141 4142 4143 |
# File 'lib/stripe/resources/account.rb', line 4141 def tax_id @tax_id end |
#tax_id_registrar ⇒ Object
The jurisdiction in which the ‘tax_id` is registered (Germany-based companies only).
4143 4144 4145 |
# File 'lib/stripe/resources/account.rb', line 4143 def tax_id_registrar @tax_id_registrar end |
#vat_id ⇒ Object
The VAT number of the company.
4145 4146 4147 |
# File 'lib/stripe/resources/account.rb', line 4145 def vat_id @vat_id end |
#verification ⇒ Object
Information on the verification state of the company.
4147 4148 4149 |
# File 'lib/stripe/resources/account.rb', line 4147 def verification @verification end |