Class: Stripe::Account::CreateParams::Company::DirectorshipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ DirectorshipDeclaration

Returns a new instance of DirectorshipDeclaration.



3767
3768
3769
3770
3771
# File 'lib/stripe/resources/account.rb', line 3767

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the directorship declaration attestation was made.



3761
3762
3763
# File 'lib/stripe/resources/account.rb', line 3761

def date
  @date
end

#ipObject

The IP address from which the directorship declaration attestation was made.



3763
3764
3765
# File 'lib/stripe/resources/account.rb', line 3763

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the directorship declaration attestation was made.



3765
3766
3767
# File 'lib/stripe/resources/account.rb', line 3765

def user_agent
  @user_agent
end