Class: Stripe::Account::CreateParams::Company::DirectorshipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ DirectorshipDeclaration

Returns a new instance of DirectorshipDeclaration.



4300
4301
4302
4303
4304
# File 'lib/stripe/resources/account.rb', line 4300

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the directorship declaration attestation was made.



4294
4295
4296
# File 'lib/stripe/resources/account.rb', line 4294

def date
  @date
end

#ipObject

The IP address from which the directorship declaration attestation was made.



4296
4297
4298
# File 'lib/stripe/resources/account.rb', line 4296

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the directorship declaration attestation was made.



4298
4299
4300
# File 'lib/stripe/resources/account.rb', line 4298

def user_agent
  @user_agent
end