Class: Stripe::Account::CreateParams::Company::DirectorshipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ DirectorshipDeclaration

Returns a new instance of DirectorshipDeclaration.



4242
4243
4244
4245
4246
# File 'lib/stripe/resources/account.rb', line 4242

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the directorship declaration attestation was made.



4236
4237
4238
# File 'lib/stripe/resources/account.rb', line 4236

def date
  @date
end

#ipObject

The IP address from which the directorship declaration attestation was made.



4238
4239
4240
# File 'lib/stripe/resources/account.rb', line 4238

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the directorship declaration attestation was made.



4240
4241
4242
# File 'lib/stripe/resources/account.rb', line 4240

def user_agent
  @user_agent
end