Class: Stripe::Account::CreateParams::Company::DirectorshipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ DirectorshipDeclaration

Returns a new instance of DirectorshipDeclaration.



3682
3683
3684
3685
3686
# File 'lib/stripe/resources/account.rb', line 3682

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the directorship declaration attestation was made.



3676
3677
3678
# File 'lib/stripe/resources/account.rb', line 3676

def date
  @date
end

#ipObject

The IP address from which the directorship declaration attestation was made.



3678
3679
3680
# File 'lib/stripe/resources/account.rb', line 3678

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the directorship declaration attestation was made.



3680
3681
3682
# File 'lib/stripe/resources/account.rb', line 3680

def user_agent
  @user_agent
end