Class: Stripe::Account::CreateParams::Company::DirectorshipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ DirectorshipDeclaration

Returns a new instance of DirectorshipDeclaration.



4185
4186
4187
4188
4189
# File 'lib/stripe/resources/account.rb', line 4185

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the directorship declaration attestation was made.



4179
4180
4181
# File 'lib/stripe/resources/account.rb', line 4179

def date
  @date
end

#ipObject

The IP address from which the directorship declaration attestation was made.



4181
4182
4183
# File 'lib/stripe/resources/account.rb', line 4181

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the directorship declaration attestation was made.



4183
4184
4185
# File 'lib/stripe/resources/account.rb', line 4183

def user_agent
  @user_agent
end