Class: Stripe::Account::CreateParams::Company::DirectorshipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ DirectorshipDeclaration

Returns a new instance of DirectorshipDeclaration.



4215
4216
4217
4218
4219
# File 'lib/stripe/resources/account.rb', line 4215

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the directorship declaration attestation was made.



4209
4210
4211
# File 'lib/stripe/resources/account.rb', line 4209

def date
  @date
end

#ipObject

The IP address from which the directorship declaration attestation was made.



4211
4212
4213
# File 'lib/stripe/resources/account.rb', line 4211

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the directorship declaration attestation was made.



4213
4214
4215
# File 'lib/stripe/resources/account.rb', line 4213

def user_agent
  @user_agent
end