Class: Stripe::Account::CreateParams::Company::DirectorshipDeclaration
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::CreateParams::Company::DirectorshipDeclaration
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the directorship declaration attestation was made.
-
#ip ⇒ Object
The IP address from which the directorship declaration attestation was made.
-
#user_agent ⇒ Object
The user agent of the browser from which the directorship declaration attestation was made.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ DirectorshipDeclaration
constructor
A new instance of DirectorshipDeclaration.
Methods inherited from RequestParams
Constructor Details
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ DirectorshipDeclaration
Returns a new instance of DirectorshipDeclaration.
4215 4216 4217 4218 4219 |
# File 'lib/stripe/resources/account.rb', line 4215 def initialize(date: nil, ip: nil, user_agent: nil) @date = date @ip = ip @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the directorship declaration attestation was made.
4209 4210 4211 |
# File 'lib/stripe/resources/account.rb', line 4209 def date @date end |
#ip ⇒ Object
The IP address from which the directorship declaration attestation was made.
4211 4212 4213 |
# File 'lib/stripe/resources/account.rb', line 4211 def ip @ip end |
#user_agent ⇒ Object
The user agent of the browser from which the directorship declaration attestation was made.
4213 4214 4215 |
# File 'lib/stripe/resources/account.rb', line 4213 def user_agent @user_agent end |