Class: Stripe::Account::CreateParams::Company::DirectorshipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ DirectorshipDeclaration

Returns a new instance of DirectorshipDeclaration.



4175
4176
4177
4178
4179
# File 'lib/stripe/resources/account.rb', line 4175

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the directorship declaration attestation was made.



4169
4170
4171
# File 'lib/stripe/resources/account.rb', line 4169

def date
  @date
end

#ipObject

The IP address from which the directorship declaration attestation was made.



4171
4172
4173
# File 'lib/stripe/resources/account.rb', line 4171

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the directorship declaration attestation was made.



4173
4174
4175
# File 'lib/stripe/resources/account.rb', line 4173

def user_agent
  @user_agent
end