Class: Stripe::Account::CreateParams::Company::DirectorshipDeclaration
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::CreateParams::Company::DirectorshipDeclaration
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the directorship declaration attestation was made.
-
#ip ⇒ Object
The IP address from which the directorship declaration attestation was made.
-
#user_agent ⇒ Object
The user agent of the browser from which the directorship declaration attestation was made.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ DirectorshipDeclaration
constructor
A new instance of DirectorshipDeclaration.
Methods inherited from RequestParams
Constructor Details
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ DirectorshipDeclaration
Returns a new instance of DirectorshipDeclaration.
4175 4176 4177 4178 4179 |
# File 'lib/stripe/resources/account.rb', line 4175 def initialize(date: nil, ip: nil, user_agent: nil) @date = date @ip = ip @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the directorship declaration attestation was made.
4169 4170 4171 |
# File 'lib/stripe/resources/account.rb', line 4169 def date @date end |
#ip ⇒ Object
The IP address from which the directorship declaration attestation was made.
4171 4172 4173 |
# File 'lib/stripe/resources/account.rb', line 4171 def ip @ip end |
#user_agent ⇒ Object
The user agent of the browser from which the directorship declaration attestation was made.
4173 4174 4175 |
# File 'lib/stripe/resources/account.rb', line 4173 def user_agent @user_agent end |