Class: Stripe::Account::CreateParams::Company::DirectorshipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ DirectorshipDeclaration

Returns a new instance of DirectorshipDeclaration.



4067
4068
4069
4070
4071
# File 'lib/stripe/resources/account.rb', line 4067

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the directorship declaration attestation was made.



4061
4062
4063
# File 'lib/stripe/resources/account.rb', line 4061

def date
  @date
end

#ipObject

The IP address from which the directorship declaration attestation was made.



4063
4064
4065
# File 'lib/stripe/resources/account.rb', line 4063

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the directorship declaration attestation was made.



4065
4066
4067
# File 'lib/stripe/resources/account.rb', line 4065

def user_agent
  @user_agent
end