Class: Stripe::Account::CreateParams::Company::OwnershipDeclaration
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::CreateParams::Company::OwnershipDeclaration
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the beneficial owner attestation was made.
-
#ip ⇒ Object
The IP address from which the beneficial owner attestation was made.
-
#user_agent ⇒ Object
The user agent of the browser from which the beneficial owner attestation was made.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ OwnershipDeclaration
constructor
A new instance of OwnershipDeclaration.
Methods inherited from RequestParams
Constructor Details
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ OwnershipDeclaration
Returns a new instance of OwnershipDeclaration.
4739 4740 4741 4742 4743 |
# File 'lib/stripe/resources/account.rb', line 4739 def initialize(date: nil, ip: nil, user_agent: nil) @date = date @ip = ip @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the beneficial owner attestation was made.
4733 4734 4735 |
# File 'lib/stripe/resources/account.rb', line 4733 def date @date end |
#ip ⇒ Object
The IP address from which the beneficial owner attestation was made.
4735 4736 4737 |
# File 'lib/stripe/resources/account.rb', line 4735 def ip @ip end |
#user_agent ⇒ Object
The user agent of the browser from which the beneficial owner attestation was made.
4737 4738 4739 |
# File 'lib/stripe/resources/account.rb', line 4737 def user_agent @user_agent end |