Class: Stripe::Account::CreateParams::Company::OwnershipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ OwnershipDeclaration

Returns a new instance of OwnershipDeclaration.



3782
3783
3784
3785
3786
# File 'lib/stripe/resources/account.rb', line 3782

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the beneficial owner attestation was made.



3776
3777
3778
# File 'lib/stripe/resources/account.rb', line 3776

def date
  @date
end

#ipObject

The IP address from which the beneficial owner attestation was made.



3778
3779
3780
# File 'lib/stripe/resources/account.rb', line 3778

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the beneficial owner attestation was made.



3780
3781
3782
# File 'lib/stripe/resources/account.rb', line 3780

def user_agent
  @user_agent
end