Class: Stripe::Account::CreateParams::Company::OwnershipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ OwnershipDeclaration

Returns a new instance of OwnershipDeclaration.



4315
4316
4317
4318
4319
# File 'lib/stripe/resources/account.rb', line 4315

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the beneficial owner attestation was made.



4309
4310
4311
# File 'lib/stripe/resources/account.rb', line 4309

def date
  @date
end

#ipObject

The IP address from which the beneficial owner attestation was made.



4311
4312
4313
# File 'lib/stripe/resources/account.rb', line 4311

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the beneficial owner attestation was made.



4313
4314
4315
# File 'lib/stripe/resources/account.rb', line 4313

def user_agent
  @user_agent
end