Class: Stripe::Account::CreateParams::Company::OwnershipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ OwnershipDeclaration

Returns a new instance of OwnershipDeclaration.



3724
3725
3726
3727
3728
# File 'lib/stripe/resources/account.rb', line 3724

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the beneficial owner attestation was made.



3718
3719
3720
# File 'lib/stripe/resources/account.rb', line 3718

def date
  @date
end

#ipObject

The IP address from which the beneficial owner attestation was made.



3720
3721
3722
# File 'lib/stripe/resources/account.rb', line 3720

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the beneficial owner attestation was made.



3722
3723
3724
# File 'lib/stripe/resources/account.rb', line 3722

def user_agent
  @user_agent
end