Class: Stripe::Account::CreateParams::Company::OwnershipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ OwnershipDeclaration

Returns a new instance of OwnershipDeclaration.



3697
3698
3699
3700
3701
# File 'lib/stripe/resources/account.rb', line 3697

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the beneficial owner attestation was made.



3691
3692
3693
# File 'lib/stripe/resources/account.rb', line 3691

def date
  @date
end

#ipObject

The IP address from which the beneficial owner attestation was made.



3693
3694
3695
# File 'lib/stripe/resources/account.rb', line 3693

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the beneficial owner attestation was made.



3695
3696
3697
# File 'lib/stripe/resources/account.rb', line 3695

def user_agent
  @user_agent
end