Class: Stripe::Account::CreateParams::Company::OwnershipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ OwnershipDeclaration

Returns a new instance of OwnershipDeclaration.



4200
4201
4202
4203
4204
# File 'lib/stripe/resources/account.rb', line 4200

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the beneficial owner attestation was made.



4194
4195
4196
# File 'lib/stripe/resources/account.rb', line 4194

def date
  @date
end

#ipObject

The IP address from which the beneficial owner attestation was made.



4196
4197
4198
# File 'lib/stripe/resources/account.rb', line 4196

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the beneficial owner attestation was made.



4198
4199
4200
# File 'lib/stripe/resources/account.rb', line 4198

def user_agent
  @user_agent
end