Class: Stripe::Account::CreateParams::Company::OwnershipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ OwnershipDeclaration

Returns a new instance of OwnershipDeclaration.



4190
4191
4192
4193
4194
# File 'lib/stripe/resources/account.rb', line 4190

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the beneficial owner attestation was made.



4184
4185
4186
# File 'lib/stripe/resources/account.rb', line 4184

def date
  @date
end

#ipObject

The IP address from which the beneficial owner attestation was made.



4186
4187
4188
# File 'lib/stripe/resources/account.rb', line 4186

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the beneficial owner attestation was made.



4188
4189
4190
# File 'lib/stripe/resources/account.rb', line 4188

def user_agent
  @user_agent
end