Class: Stripe::Account::CreateParams::Company::OwnershipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ OwnershipDeclaration

Returns a new instance of OwnershipDeclaration.



4082
4083
4084
4085
4086
# File 'lib/stripe/resources/account.rb', line 4082

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the beneficial owner attestation was made.



4076
4077
4078
# File 'lib/stripe/resources/account.rb', line 4076

def date
  @date
end

#ipObject

The IP address from which the beneficial owner attestation was made.



4078
4079
4080
# File 'lib/stripe/resources/account.rb', line 4078

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the beneficial owner attestation was made.



4080
4081
4082
# File 'lib/stripe/resources/account.rb', line 4080

def user_agent
  @user_agent
end