Class: Stripe::Account::CreateParams::Company::OwnershipDeclaration
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::CreateParams::Company::OwnershipDeclaration
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the beneficial owner attestation was made.
-
#ip ⇒ Object
The IP address from which the beneficial owner attestation was made.
-
#user_agent ⇒ Object
The user agent of the browser from which the beneficial owner attestation was made.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ OwnershipDeclaration
constructor
A new instance of OwnershipDeclaration.
Methods inherited from RequestParams
Constructor Details
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ OwnershipDeclaration
Returns a new instance of OwnershipDeclaration.
4561 4562 4563 4564 4565 |
# File 'lib/stripe/resources/account.rb', line 4561 def initialize(date: nil, ip: nil, user_agent: nil) @date = date @ip = ip @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the beneficial owner attestation was made.
4553 4554 4555 |
# File 'lib/stripe/resources/account.rb', line 4553 def date @date end |
#ip ⇒ Object
The IP address from which the beneficial owner attestation was made.
4556 4557 4558 |
# File 'lib/stripe/resources/account.rb', line 4556 def ip @ip end |
#user_agent ⇒ Object
The user agent of the browser from which the beneficial owner attestation was made.
4559 4560 4561 |
# File 'lib/stripe/resources/account.rb', line 4559 def user_agent @user_agent end |