Class: Stripe::Account::CreateParams::Controller
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::CreateParams::Controller
- Defined in:
- lib/stripe/resources/account.rb
Defined Under Namespace
Classes: Application, Dashboard, Fees, Losses, StripeDashboard
Instance Attribute Summary collapse
-
#application ⇒ Object
A hash of configuration describing the Connect application that controls the account.
-
#dashboard ⇒ Object
Properties of the account’s dashboard.
-
#fees ⇒ Object
A hash of configuration for who pays Stripe fees for product usage on this account.
-
#losses ⇒ Object
A hash of configuration for products that have negative balance liability, and whether Stripe or a Connect application is responsible for them.
-
#requirement_collection ⇒ Object
A value indicating responsibility for collecting updated information when requirements on the account are due or change.
-
#stripe_dashboard ⇒ Object
A hash of configuration for Stripe-hosted dashboards.
Instance Method Summary collapse
-
#initialize(application: nil, dashboard: nil, fees: nil, losses: nil, requirement_collection: nil, stripe_dashboard: nil) ⇒ Controller
constructor
A new instance of Controller.
Methods inherited from RequestParams
Constructor Details
#initialize(application: nil, dashboard: nil, fees: nil, losses: nil, requirement_collection: nil, stripe_dashboard: nil) ⇒ Controller
Returns a new instance of Controller.
4456 4457 4458 4459 4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 |
# File 'lib/stripe/resources/account.rb', line 4456 def initialize( application: nil, dashboard: nil, fees: nil, losses: nil, requirement_collection: nil, stripe_dashboard: nil ) @application = application @dashboard = dashboard @fees = fees @losses = losses @requirement_collection = requirement_collection @stripe_dashboard = stripe_dashboard end |
Instance Attribute Details
#application ⇒ Object
A hash of configuration describing the Connect application that controls the account.
4444 4445 4446 |
# File 'lib/stripe/resources/account.rb', line 4444 def application @application end |
#dashboard ⇒ Object
Properties of the account’s dashboard.
4446 4447 4448 |
# File 'lib/stripe/resources/account.rb', line 4446 def dashboard @dashboard end |
#fees ⇒ Object
A hash of configuration for who pays Stripe fees for product usage on this account.
4448 4449 4450 |
# File 'lib/stripe/resources/account.rb', line 4448 def fees @fees end |
#losses ⇒ Object
A hash of configuration for products that have negative balance liability, and whether Stripe or a Connect application is responsible for them.
4450 4451 4452 |
# File 'lib/stripe/resources/account.rb', line 4450 def losses @losses end |
#requirement_collection ⇒ Object
A value indicating responsibility for collecting updated information when requirements on the account are due or change. Defaults to ‘stripe`.
4452 4453 4454 |
# File 'lib/stripe/resources/account.rb', line 4452 def requirement_collection @requirement_collection end |
#stripe_dashboard ⇒ Object
A hash of configuration for Stripe-hosted dashboards.
4454 4455 4456 |
# File 'lib/stripe/resources/account.rb', line 4454 def stripe_dashboard @stripe_dashboard end |