Class: Stripe::Account::CreateParams::Controller
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::CreateParams::Controller
- Defined in:
- lib/stripe/resources/account.rb
Defined Under Namespace
Classes: Fees, Losses, StripeDashboard
Instance Attribute Summary collapse
-
#fees ⇒ Object
A hash of configuration for who pays Stripe fees for product usage on this account.
-
#losses ⇒ Object
A hash of configuration for products that have negative balance liability, and whether Stripe or a Connect application is responsible for them.
-
#requirement_collection ⇒ Object
A value indicating responsibility for collecting updated information when requirements on the account are due or change.
-
#stripe_dashboard ⇒ Object
A hash of configuration for Stripe-hosted dashboards.
Instance Method Summary collapse
-
#initialize(fees: nil, losses: nil, requirement_collection: nil, stripe_dashboard: nil) ⇒ Controller
constructor
A new instance of Controller.
Methods inherited from RequestParams
Constructor Details
#initialize(fees: nil, losses: nil, requirement_collection: nil, stripe_dashboard: nil) ⇒ Controller
Returns a new instance of Controller.
3895 3896 3897 3898 3899 3900 |
# File 'lib/stripe/resources/account.rb', line 3895 def initialize(fees: nil, losses: nil, requirement_collection: nil, stripe_dashboard: nil) @fees = fees @losses = losses @requirement_collection = requirement_collection @stripe_dashboard = stripe_dashboard end |
Instance Attribute Details
#fees ⇒ Object
A hash of configuration for who pays Stripe fees for product usage on this account.
3887 3888 3889 |
# File 'lib/stripe/resources/account.rb', line 3887 def fees @fees end |
#losses ⇒ Object
A hash of configuration for products that have negative balance liability, and whether Stripe or a Connect application is responsible for them.
3889 3890 3891 |
# File 'lib/stripe/resources/account.rb', line 3889 def losses @losses end |
#requirement_collection ⇒ Object
A value indicating responsibility for collecting updated information when requirements on the account are due or change. Defaults to ‘stripe`.
3891 3892 3893 |
# File 'lib/stripe/resources/account.rb', line 3891 def requirement_collection @requirement_collection end |
#stripe_dashboard ⇒ Object
A hash of configuration for Stripe-hosted dashboards.
3893 3894 3895 |
# File 'lib/stripe/resources/account.rb', line 3893 def stripe_dashboard @stripe_dashboard end |