Class: Stripe::Account::CreateParams::Controller
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::CreateParams::Controller
- Defined in:
- lib/stripe/resources/account.rb
Defined Under Namespace
Classes: Fees, Losses, StripeDashboard
Instance Attribute Summary collapse
-
#fees ⇒ Object
A hash of configuration for who pays Stripe fees for product usage on this account.
-
#losses ⇒ Object
A hash of configuration for products that have negative balance liability, and whether Stripe or a Connect application is responsible for them.
-
#requirement_collection ⇒ Object
A value indicating responsibility for collecting updated information when requirements on the account are due or change.
-
#stripe_dashboard ⇒ Object
A hash of configuration for Stripe-hosted dashboards.
Instance Method Summary collapse
-
#initialize(fees: nil, losses: nil, requirement_collection: nil, stripe_dashboard: nil) ⇒ Controller
constructor
A new instance of Controller.
Methods inherited from RequestParams
Constructor Details
#initialize(fees: nil, losses: nil, requirement_collection: nil, stripe_dashboard: nil) ⇒ Controller
Returns a new instance of Controller.
3868 3869 3870 3871 3872 3873 |
# File 'lib/stripe/resources/account.rb', line 3868 def initialize(fees: nil, losses: nil, requirement_collection: nil, stripe_dashboard: nil) @fees = fees @losses = losses @requirement_collection = requirement_collection @stripe_dashboard = stripe_dashboard end |
Instance Attribute Details
#fees ⇒ Object
A hash of configuration for who pays Stripe fees for product usage on this account.
3860 3861 3862 |
# File 'lib/stripe/resources/account.rb', line 3860 def fees @fees end |
#losses ⇒ Object
A hash of configuration for products that have negative balance liability, and whether Stripe or a Connect application is responsible for them.
3862 3863 3864 |
# File 'lib/stripe/resources/account.rb', line 3862 def losses @losses end |
#requirement_collection ⇒ Object
A value indicating responsibility for collecting updated information when requirements on the account are due or change. Defaults to ‘stripe`.
3864 3865 3866 |
# File 'lib/stripe/resources/account.rb', line 3864 def requirement_collection @requirement_collection end |
#stripe_dashboard ⇒ Object
A hash of configuration for Stripe-hosted dashboards.
3866 3867 3868 |
# File 'lib/stripe/resources/account.rb', line 3866 def stripe_dashboard @stripe_dashboard end |