Class: Stripe::Account::CreateParams::Controller

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: Application, Dashboard, Fees, Losses, StripeDashboard

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(application: nil, dashboard: nil, fees: nil, losses: nil, requirement_collection: nil, stripe_dashboard: nil) ⇒ Controller

Returns a new instance of Controller.



4370
4371
4372
4373
4374
4375
4376
4377
4378
4379
4380
4381
4382
4383
4384
# File 'lib/stripe/resources/account.rb', line 4370

def initialize(
  application: nil,
  dashboard: nil,
  fees: nil,
  losses: nil,
  requirement_collection: nil,
  stripe_dashboard: nil
)
  @application = application
  @dashboard = dashboard
  @fees = fees
  @losses = losses
  @requirement_collection = requirement_collection
  @stripe_dashboard = stripe_dashboard
end

Instance Attribute Details

#applicationObject

A hash of configuration describing the Connect application that controls the account.



4358
4359
4360
# File 'lib/stripe/resources/account.rb', line 4358

def application
  @application
end

#dashboardObject

Properties of the account’s dashboard.



4360
4361
4362
# File 'lib/stripe/resources/account.rb', line 4360

def dashboard
  @dashboard
end

#feesObject

A hash of configuration for who pays Stripe fees for product usage on this account.



4362
4363
4364
# File 'lib/stripe/resources/account.rb', line 4362

def fees
  @fees
end

#lossesObject

A hash of configuration for products that have negative balance liability, and whether Stripe or a Connect application is responsible for them.



4364
4365
4366
# File 'lib/stripe/resources/account.rb', line 4364

def losses
  @losses
end

#requirement_collectionObject

A value indicating responsibility for collecting updated information when requirements on the account are due or change. Defaults to ‘stripe`.



4366
4367
4368
# File 'lib/stripe/resources/account.rb', line 4366

def requirement_collection
  @requirement_collection
end

#stripe_dashboardObject

A hash of configuration for Stripe-hosted dashboards.



4368
4369
4370
# File 'lib/stripe/resources/account.rb', line 4368

def stripe_dashboard
  @stripe_dashboard
end