Class: Stripe::Account::CreateParams::Controller
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::CreateParams::Controller
- Defined in:
- lib/stripe/resources/account.rb
Defined Under Namespace
Classes: Fees, Losses, StripeDashboard
Instance Attribute Summary collapse
-
#fees ⇒ Object
A hash of configuration for who pays Stripe fees for product usage on this account.
-
#losses ⇒ Object
A hash of configuration for products that have negative balance liability, and whether Stripe or a Connect application is responsible for them.
-
#requirement_collection ⇒ Object
A value indicating responsibility for collecting updated information when requirements on the account are due or change.
-
#stripe_dashboard ⇒ Object
A hash of configuration for Stripe-hosted dashboards.
Instance Method Summary collapse
-
#initialize(fees: nil, losses: nil, requirement_collection: nil, stripe_dashboard: nil) ⇒ Controller
constructor
A new instance of Controller.
Methods inherited from RequestParams
Constructor Details
#initialize(fees: nil, losses: nil, requirement_collection: nil, stripe_dashboard: nil) ⇒ Controller
Returns a new instance of Controller.
3809 3810 3811 3812 3813 3814 |
# File 'lib/stripe/resources/account.rb', line 3809 def initialize(fees: nil, losses: nil, requirement_collection: nil, stripe_dashboard: nil) @fees = fees @losses = losses @requirement_collection = requirement_collection @stripe_dashboard = stripe_dashboard end |
Instance Attribute Details
#fees ⇒ Object
A hash of configuration for who pays Stripe fees for product usage on this account.
3801 3802 3803 |
# File 'lib/stripe/resources/account.rb', line 3801 def fees @fees end |
#losses ⇒ Object
A hash of configuration for products that have negative balance liability, and whether Stripe or a Connect application is responsible for them.
3803 3804 3805 |
# File 'lib/stripe/resources/account.rb', line 3803 def losses @losses end |
#requirement_collection ⇒ Object
A value indicating responsibility for collecting updated information when requirements on the account are due or change. Defaults to ‘stripe`.
3805 3806 3807 |
# File 'lib/stripe/resources/account.rb', line 3805 def requirement_collection @requirement_collection end |
#stripe_dashboard ⇒ Object
A hash of configuration for Stripe-hosted dashboards.
3807 3808 3809 |
# File 'lib/stripe/resources/account.rb', line 3807 def stripe_dashboard @stripe_dashboard end |