Class: Stripe::Account::CreateParams::Controller

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: Application, Dashboard, Fees, Losses, StripeDashboard

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(application: nil, dashboard: nil, fees: nil, losses: nil, requirement_collection: nil, stripe_dashboard: nil) ⇒ Controller

Returns a new instance of Controller.



4262
4263
4264
4265
4266
4267
4268
4269
4270
4271
4272
4273
4274
4275
4276
# File 'lib/stripe/resources/account.rb', line 4262

def initialize(
  application: nil,
  dashboard: nil,
  fees: nil,
  losses: nil,
  requirement_collection: nil,
  stripe_dashboard: nil
)
  @application = application
  @dashboard = dashboard
  @fees = fees
  @losses = losses
  @requirement_collection = requirement_collection
  @stripe_dashboard = stripe_dashboard
end

Instance Attribute Details

#applicationObject

A hash of configuration describing the Connect application that controls the account.



4250
4251
4252
# File 'lib/stripe/resources/account.rb', line 4250

def application
  @application
end

#dashboardObject

Properties of the account’s dashboard.



4252
4253
4254
# File 'lib/stripe/resources/account.rb', line 4252

def dashboard
  @dashboard
end

#feesObject

A hash of configuration for who pays Stripe fees for product usage on this account.



4254
4255
4256
# File 'lib/stripe/resources/account.rb', line 4254

def fees
  @fees
end

#lossesObject

A hash of configuration for products that have negative balance liability, and whether Stripe or a Connect application is responsible for them.



4256
4257
4258
# File 'lib/stripe/resources/account.rb', line 4256

def losses
  @losses
end

#requirement_collectionObject

A value indicating responsibility for collecting updated information when requirements on the account are due or change. Defaults to ‘stripe`.



4258
4259
4260
# File 'lib/stripe/resources/account.rb', line 4258

def requirement_collection
  @requirement_collection
end

#stripe_dashboardObject

A hash of configuration for Stripe-hosted dashboards.



4260
4261
4262
# File 'lib/stripe/resources/account.rb', line 4260

def stripe_dashboard
  @stripe_dashboard
end