Class: Stripe::Account::CreateParams::Controller

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: Application, Dashboard, Fees, Losses, StripeDashboard

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(application: nil, dashboard: nil, fees: nil, losses: nil, requirement_collection: nil, stripe_dashboard: nil) ⇒ Controller

Returns a new instance of Controller.



4181
4182
4183
4184
4185
4186
4187
4188
4189
4190
4191
4192
4193
4194
4195
# File 'lib/stripe/resources/account.rb', line 4181

def initialize(
  application: nil,
  dashboard: nil,
  fees: nil,
  losses: nil,
  requirement_collection: nil,
  stripe_dashboard: nil
)
  @application = application
  @dashboard = dashboard
  @fees = fees
  @losses = losses
  @requirement_collection = requirement_collection
  @stripe_dashboard = stripe_dashboard
end

Instance Attribute Details

#applicationObject

A hash of configuration describing the Connect application that controls the account.



4169
4170
4171
# File 'lib/stripe/resources/account.rb', line 4169

def application
  @application
end

#dashboardObject

Properties of the account’s dashboard.



4171
4172
4173
# File 'lib/stripe/resources/account.rb', line 4171

def dashboard
  @dashboard
end

#feesObject

A hash of configuration for who pays Stripe fees for product usage on this account.



4173
4174
4175
# File 'lib/stripe/resources/account.rb', line 4173

def fees
  @fees
end

#lossesObject

A hash of configuration for products that have negative balance liability, and whether Stripe or a Connect application is responsible for them.



4175
4176
4177
# File 'lib/stripe/resources/account.rb', line 4175

def losses
  @losses
end

#requirement_collectionObject

A value indicating responsibility for collecting updated information when requirements on the account are due or change. Defaults to ‘stripe`.



4177
4178
4179
# File 'lib/stripe/resources/account.rb', line 4177

def requirement_collection
  @requirement_collection
end

#stripe_dashboardObject

A hash of configuration for Stripe-hosted dashboards.



4179
4180
4181
# File 'lib/stripe/resources/account.rb', line 4179

def stripe_dashboard
  @stripe_dashboard
end