Class: Stripe::Account::CreateParams::Controller

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: Application, Dashboard, Fees, Losses, StripeDashboard

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(application: nil, dashboard: nil, fees: nil, losses: nil, requirement_collection: nil, stripe_dashboard: nil) ⇒ Controller

Returns a new instance of Controller.



4759
4760
4761
4762
4763
4764
4765
4766
4767
4768
4769
4770
4771
4772
4773
# File 'lib/stripe/resources/account.rb', line 4759

def initialize(
  application: nil,
  dashboard: nil,
  fees: nil,
  losses: nil,
  requirement_collection: nil,
  stripe_dashboard: nil
)
  @application = application
  @dashboard = dashboard
  @fees = fees
  @losses = losses
  @requirement_collection = requirement_collection
  @stripe_dashboard = stripe_dashboard
end

Instance Attribute Details

#applicationObject

A hash of configuration describing the Connect application that controls the account.



4742
4743
4744
# File 'lib/stripe/resources/account.rb', line 4742

def application
  @application
end

#dashboardObject

Properties of the account’s dashboard.



4745
4746
4747
# File 'lib/stripe/resources/account.rb', line 4745

def dashboard
  @dashboard
end

#feesObject

A hash of configuration for who pays Stripe fees for product usage on this account.



4748
4749
4750
# File 'lib/stripe/resources/account.rb', line 4748

def fees
  @fees
end

#lossesObject

A hash of configuration for products that have negative balance liability, and whether Stripe or a Connect application is responsible for them.



4751
4752
4753
# File 'lib/stripe/resources/account.rb', line 4751

def losses
  @losses
end

#requirement_collectionObject

A value indicating responsibility for collecting updated information when requirements on the account are due or change. Defaults to ‘stripe`.



4754
4755
4756
# File 'lib/stripe/resources/account.rb', line 4754

def requirement_collection
  @requirement_collection
end

#stripe_dashboardObject

A hash of configuration for Stripe-hosted dashboards.



4757
4758
4759
# File 'lib/stripe/resources/account.rb', line 4757

def stripe_dashboard
  @stripe_dashboard
end