Class: Stripe::Account::CreateParams::Documents
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::CreateParams::Documents
- Defined in:
- lib/stripe/resources/account.rb
Defined Under Namespace
Classes: BankAccountOwnershipVerification, CompanyLicense, CompanyMemorandumOfAssociation, CompanyMinisterialDecree, CompanyRegistrationVerification, CompanyTaxIdVerification, ProofOfAddress, ProofOfRegistration, ProofOfUltimateBeneficialOwnership
Instance Attribute Summary collapse
-
#bank_account_ownership_verification ⇒ Object
One or more documents that support the [Bank account ownership verification](support.stripe.com/questions/bank-account-ownership-verification) requirement.
-
#company_license ⇒ Object
One or more documents that demonstrate proof of a company’s license to operate.
-
#company_memorandum_of_association ⇒ Object
One or more documents showing the company’s Memorandum of Association.
-
#company_ministerial_decree ⇒ Object
(Certain countries only) One or more documents showing the ministerial decree legalizing the company’s establishment.
-
#company_registration_verification ⇒ Object
One or more documents that demonstrate proof of a company’s registration with the appropriate local authorities.
-
#company_tax_id_verification ⇒ Object
One or more documents that demonstrate proof of a company’s tax ID.
-
#proof_of_address ⇒ Object
One or more documents that demonstrate proof of address.
-
#proof_of_registration ⇒ Object
One or more documents showing the company’s proof of registration with the national business registry.
-
#proof_of_ultimate_beneficial_ownership ⇒ Object
One or more documents that demonstrate proof of ultimate beneficial ownership.
Instance Method Summary collapse
-
#initialize(bank_account_ownership_verification: nil, company_license: nil, company_memorandum_of_association: nil, company_ministerial_decree: nil, company_registration_verification: nil, company_tax_id_verification: nil, proof_of_address: nil, proof_of_registration: nil, proof_of_ultimate_beneficial_ownership: nil) ⇒ Documents
constructor
A new instance of Documents.
Methods inherited from RequestParams
Constructor Details
#initialize(bank_account_ownership_verification: nil, company_license: nil, company_memorandum_of_association: nil, company_ministerial_decree: nil, company_registration_verification: nil, company_tax_id_verification: nil, proof_of_address: nil, proof_of_registration: nil, proof_of_ultimate_beneficial_ownership: nil) ⇒ Documents
Returns a new instance of Documents.
4061 4062 4063 4064 4065 4066 4067 4068 4069 4070 4071 4072 4073 4074 4075 4076 4077 4078 4079 4080 4081 |
# File 'lib/stripe/resources/account.rb', line 4061 def initialize( bank_account_ownership_verification: nil, company_license: nil, company_memorandum_of_association: nil, company_ministerial_decree: nil, company_registration_verification: nil, company_tax_id_verification: nil, proof_of_address: nil, proof_of_registration: nil, proof_of_ultimate_beneficial_ownership: nil ) @bank_account_ownership_verification = bank_account_ownership_verification @company_license = company_license @company_memorandum_of_association = company_memorandum_of_association @company_ministerial_decree = company_ministerial_decree @company_registration_verification = company_registration_verification @company_tax_id_verification = company_tax_id_verification @proof_of_address = proof_of_address @proof_of_registration = proof_of_registration @proof_of_ultimate_beneficial_ownership = proof_of_ultimate_beneficial_ownership end |
Instance Attribute Details
#bank_account_ownership_verification ⇒ Object
One or more documents that support the [Bank account ownership verification](support.stripe.com/questions/bank-account-ownership-verification) requirement. Must be a document associated with the account’s primary active bank account that displays the last 4 digits of the account number, either a statement or a check.
4043 4044 4045 |
# File 'lib/stripe/resources/account.rb', line 4043 def bank_account_ownership_verification @bank_account_ownership_verification end |
#company_license ⇒ Object
One or more documents that demonstrate proof of a company’s license to operate.
4045 4046 4047 |
# File 'lib/stripe/resources/account.rb', line 4045 def company_license @company_license end |
#company_memorandum_of_association ⇒ Object
One or more documents showing the company’s Memorandum of Association.
4047 4048 4049 |
# File 'lib/stripe/resources/account.rb', line 4047 def company_memorandum_of_association @company_memorandum_of_association end |
#company_ministerial_decree ⇒ Object
(Certain countries only) One or more documents showing the ministerial decree legalizing the company’s establishment.
4049 4050 4051 |
# File 'lib/stripe/resources/account.rb', line 4049 def company_ministerial_decree @company_ministerial_decree end |
#company_registration_verification ⇒ Object
One or more documents that demonstrate proof of a company’s registration with the appropriate local authorities.
4051 4052 4053 |
# File 'lib/stripe/resources/account.rb', line 4051 def company_registration_verification @company_registration_verification end |
#company_tax_id_verification ⇒ Object
One or more documents that demonstrate proof of a company’s tax ID.
4053 4054 4055 |
# File 'lib/stripe/resources/account.rb', line 4053 def company_tax_id_verification @company_tax_id_verification end |
#proof_of_address ⇒ Object
One or more documents that demonstrate proof of address.
4055 4056 4057 |
# File 'lib/stripe/resources/account.rb', line 4055 def proof_of_address @proof_of_address end |
#proof_of_registration ⇒ Object
One or more documents showing the company’s proof of registration with the national business registry.
4057 4058 4059 |
# File 'lib/stripe/resources/account.rb', line 4057 def proof_of_registration @proof_of_registration end |
#proof_of_ultimate_beneficial_ownership ⇒ Object
One or more documents that demonstrate proof of ultimate beneficial ownership.
4059 4060 4061 |
# File 'lib/stripe/resources/account.rb', line 4059 def proof_of_ultimate_beneficial_ownership @proof_of_ultimate_beneficial_ownership end |