Class: Stripe::Account::CreateParams::Documents

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: BankAccountOwnershipVerification, CompanyLicense, CompanyMemorandumOfAssociation, CompanyMinisterialDecree, CompanyRegistrationVerification, CompanyTaxIdVerification, ProofOfRegistration, ProofOfUltimateBeneficialOwnership

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bank_account_ownership_verification: nil, company_license: nil, company_memorandum_of_association: nil, company_ministerial_decree: nil, company_registration_verification: nil, company_tax_id_verification: nil, proof_of_registration: nil, proof_of_ultimate_beneficial_ownership: nil) ⇒ Documents

Returns a new instance of Documents.



3965
3966
3967
3968
3969
3970
3971
3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
# File 'lib/stripe/resources/account.rb', line 3965

def initialize(
  bank_account_ownership_verification: nil,
  company_license: nil,
  company_memorandum_of_association: nil,
  company_ministerial_decree: nil,
  company_registration_verification: nil,
  company_tax_id_verification: nil,
  proof_of_registration: nil,
  proof_of_ultimate_beneficial_ownership: nil
)
  @bank_account_ownership_verification = 
  @company_license = company_license
  @company_memorandum_of_association = company_memorandum_of_association
  @company_ministerial_decree = company_ministerial_decree
  @company_registration_verification = company_registration_verification
  @company_tax_id_verification = company_tax_id_verification
  @proof_of_registration = proof_of_registration
  @proof_of_ultimate_beneficial_ownership = proof_of_ultimate_beneficial_ownership
end

Instance Attribute Details

#bank_account_ownership_verificationObject

One or more documents that support the [Bank account ownership verification](support.stripe.com/questions/bank-account-ownership-verification) requirement. Must be a document associated with the account’s primary active bank account that displays the last 4 digits of the account number, either a statement or a check.



3949
3950
3951
# File 'lib/stripe/resources/account.rb', line 3949

def 
  @bank_account_ownership_verification
end

#company_licenseObject

One or more documents that demonstrate proof of a company’s license to operate.



3951
3952
3953
# File 'lib/stripe/resources/account.rb', line 3951

def company_license
  @company_license
end

#company_memorandum_of_associationObject

One or more documents showing the company’s Memorandum of Association.



3953
3954
3955
# File 'lib/stripe/resources/account.rb', line 3953

def company_memorandum_of_association
  @company_memorandum_of_association
end

#company_ministerial_decreeObject

(Certain countries only) One or more documents showing the ministerial decree legalizing the company’s establishment.



3955
3956
3957
# File 'lib/stripe/resources/account.rb', line 3955

def company_ministerial_decree
  @company_ministerial_decree
end

#company_registration_verificationObject

One or more documents that demonstrate proof of a company’s registration with the appropriate local authorities.



3957
3958
3959
# File 'lib/stripe/resources/account.rb', line 3957

def company_registration_verification
  @company_registration_verification
end

#company_tax_id_verificationObject

One or more documents that demonstrate proof of a company’s tax ID.



3959
3960
3961
# File 'lib/stripe/resources/account.rb', line 3959

def company_tax_id_verification
  @company_tax_id_verification
end

#proof_of_registrationObject

One or more documents showing the company’s proof of registration with the national business registry.



3961
3962
3963
# File 'lib/stripe/resources/account.rb', line 3961

def proof_of_registration
  @proof_of_registration
end

#proof_of_ultimate_beneficial_ownershipObject

One or more documents that demonstrate proof of ultimate beneficial ownership.



3963
3964
3965
# File 'lib/stripe/resources/account.rb', line 3963

def proof_of_ultimate_beneficial_ownership
  @proof_of_ultimate_beneficial_ownership
end