Class: Stripe::Account::CreateParams::Documents

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: BankAccountOwnershipVerification, CompanyLicense, CompanyMemorandumOfAssociation, CompanyMinisterialDecree, CompanyRegistrationVerification, CompanyTaxIdVerification, ProofOfRegistration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bank_account_ownership_verification: nil, company_license: nil, company_memorandum_of_association: nil, company_ministerial_decree: nil, company_registration_verification: nil, company_tax_id_verification: nil, proof_of_registration: nil) ⇒ Documents

Returns a new instance of Documents.



4860
4861
4862
4863
4864
4865
4866
4867
4868
4869
4870
4871
4872
4873
4874
4875
4876
# File 'lib/stripe/resources/account.rb', line 4860

def initialize(
  bank_account_ownership_verification: nil,
  company_license: nil,
  company_memorandum_of_association: nil,
  company_ministerial_decree: nil,
  company_registration_verification: nil,
  company_tax_id_verification: nil,
  proof_of_registration: nil
)
  @bank_account_ownership_verification = 
  @company_license = company_license
  @company_memorandum_of_association = company_memorandum_of_association
  @company_ministerial_decree = company_ministerial_decree
  @company_registration_verification = company_registration_verification
  @company_tax_id_verification = company_tax_id_verification
  @proof_of_registration = proof_of_registration
end

Instance Attribute Details

#bank_account_ownership_verificationObject

One or more documents that support the [Bank account ownership verification](support.stripe.com/questions/bank-account-ownership-verification) requirement. Must be a document associated with the account’s primary active bank account that displays the last 4 digits of the account number, either a statement or a check.



4840
4841
4842
# File 'lib/stripe/resources/account.rb', line 4840

def 
  @bank_account_ownership_verification
end

#company_licenseObject

One or more documents that demonstrate proof of a company’s license to operate.



4843
4844
4845
# File 'lib/stripe/resources/account.rb', line 4843

def company_license
  @company_license
end

#company_memorandum_of_associationObject

One or more documents showing the company’s Memorandum of Association.



4846
4847
4848
# File 'lib/stripe/resources/account.rb', line 4846

def company_memorandum_of_association
  @company_memorandum_of_association
end

#company_ministerial_decreeObject

(Certain countries only) One or more documents showing the ministerial decree legalizing the company’s establishment.



4849
4850
4851
# File 'lib/stripe/resources/account.rb', line 4849

def company_ministerial_decree
  @company_ministerial_decree
end

#company_registration_verificationObject

One or more documents that demonstrate proof of a company’s registration with the appropriate local authorities.



4852
4853
4854
# File 'lib/stripe/resources/account.rb', line 4852

def company_registration_verification
  @company_registration_verification
end

#company_tax_id_verificationObject

One or more documents that demonstrate proof of a company’s tax ID.



4855
4856
4857
# File 'lib/stripe/resources/account.rb', line 4855

def company_tax_id_verification
  @company_tax_id_verification
end

#proof_of_registrationObject

One or more documents showing the company’s proof of registration with the national business registry.



4858
4859
4860
# File 'lib/stripe/resources/account.rb', line 4858

def proof_of_registration
  @proof_of_registration
end