Class: Stripe::Account::CreateParams::Groups
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::CreateParams::Groups
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#payments_pricing ⇒ Object
The group the account is in to determine their payments pricing, and null if the account is on customized pricing.
Instance Method Summary collapse
-
#initialize(payments_pricing: nil) ⇒ Groups
constructor
A new instance of Groups.
Methods inherited from RequestParams
Constructor Details
#initialize(payments_pricing: nil) ⇒ Groups
Returns a new instance of Groups.
4391 4392 4393 |
# File 'lib/stripe/resources/account.rb', line 4391 def initialize(payments_pricing: nil) @payments_pricing = payments_pricing end |
Instance Attribute Details
#payments_pricing ⇒ Object
The group the account is in to determine their payments pricing, and null if the account is on customized pricing. [See the Platform pricing tool documentation](stripe.com/docs/connect/platform-pricing-tools) for details.
4389 4390 4391 |
# File 'lib/stripe/resources/account.rb', line 4389 def payments_pricing @payments_pricing end |