Class: Stripe::Account::CreateParams::Individual
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::CreateParams::Individual
- Defined in:
- lib/stripe/resources/account.rb
Defined Under Namespace
Classes: Address, AddressKana, AddressKanji, Dob, RegisteredAddress, Relationship, Verification
Instance Attribute Summary collapse
-
#address ⇒ Object
The individual’s primary address.
-
#address_kana ⇒ Object
The Kana variation of the individual’s primary address (Japan only).
-
#address_kanji ⇒ Object
The Kanji variation of the individual’s primary address (Japan only).
-
#dob ⇒ Object
The individual’s date of birth.
-
#email ⇒ Object
The individual’s email address.
-
#first_name ⇒ Object
The individual’s first name.
-
#first_name_kana ⇒ Object
The Kana variation of the individual’s first name (Japan only).
-
#first_name_kanji ⇒ Object
The Kanji variation of the individual’s first name (Japan only).
-
#full_name_aliases ⇒ Object
A list of alternate names or aliases that the individual is known by.
-
#gender ⇒ Object
The individual’s gender.
-
#id_number ⇒ Object
The government-issued ID number of the individual, as appropriate for the representative’s country.
-
#id_number_secondary ⇒ Object
The government-issued secondary ID number of the individual, as appropriate for the representative’s country, will be used for enhanced verification checks.
-
#last_name ⇒ Object
The individual’s last name.
-
#last_name_kana ⇒ Object
The Kana variation of the individual’s last name (Japan only).
-
#last_name_kanji ⇒ Object
The Kanji variation of the individual’s last name (Japan only).
-
#maiden_name ⇒ Object
The individual’s maiden name.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#phone ⇒ Object
The individual’s phone number.
-
#political_exposure ⇒ Object
Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
-
#registered_address ⇒ Object
The individual’s registered address.
-
#relationship ⇒ Object
Describes the person’s relationship to the account.
-
#ssn_last_4 ⇒ Object
The last four digits of the individual’s Social Security Number (U.S. only).
-
#verification ⇒ Object
The individual’s verification document information.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, address_kana: nil, address_kanji: nil, dob: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil) ⇒ Individual
Returns a new instance of Individual.
4919 4920 4921 4922 4923 4924 4925 4926 4927 4928 4929 4930 4931 4932 4933 4934 4935 4936 4937 4938 4939 4940 4941 4942 4943 4944 4945 4946 4947 4948 4949 4950 4951 4952 4953 4954 4955 4956 4957 4958 4959 4960 4961 4962 4963 4964 4965 4966 4967 |
# File 'lib/stripe/resources/account.rb', line 4919 def initialize( address: nil, address_kana: nil, address_kanji: nil, dob: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil ) @address = address @address_kana = address_kana @address_kanji = address_kanji @dob = dob @email = email @first_name = first_name @first_name_kana = first_name_kana @first_name_kanji = first_name_kanji @full_name_aliases = full_name_aliases @gender = gender @id_number = id_number @id_number_secondary = id_number_secondary @last_name = last_name @last_name_kana = last_name_kana @last_name_kanji = last_name_kanji @maiden_name = maiden_name @metadata = @phone = phone @political_exposure = political_exposure @registered_address = registered_address @relationship = relationship @ssn_last_4 = ssn_last_4 @verification = verification end |
Instance Attribute Details
#address ⇒ Object
The individual’s primary address.
4873 4874 4875 |
# File 'lib/stripe/resources/account.rb', line 4873 def address @address end |
#address_kana ⇒ Object
The Kana variation of the individual’s primary address (Japan only).
4875 4876 4877 |
# File 'lib/stripe/resources/account.rb', line 4875 def address_kana @address_kana end |
#address_kanji ⇒ Object
The Kanji variation of the individual’s primary address (Japan only).
4877 4878 4879 |
# File 'lib/stripe/resources/account.rb', line 4877 def address_kanji @address_kanji end |
#dob ⇒ Object
The individual’s date of birth.
4879 4880 4881 |
# File 'lib/stripe/resources/account.rb', line 4879 def dob @dob end |
#email ⇒ Object
The individual’s email address.
4881 4882 4883 |
# File 'lib/stripe/resources/account.rb', line 4881 def email @email end |
#first_name ⇒ Object
The individual’s first name.
4883 4884 4885 |
# File 'lib/stripe/resources/account.rb', line 4883 def first_name @first_name end |
#first_name_kana ⇒ Object
The Kana variation of the individual’s first name (Japan only).
4885 4886 4887 |
# File 'lib/stripe/resources/account.rb', line 4885 def first_name_kana @first_name_kana end |
#first_name_kanji ⇒ Object
The Kanji variation of the individual’s first name (Japan only).
4887 4888 4889 |
# File 'lib/stripe/resources/account.rb', line 4887 def first_name_kanji @first_name_kanji end |
#full_name_aliases ⇒ Object
A list of alternate names or aliases that the individual is known by.
4889 4890 4891 |
# File 'lib/stripe/resources/account.rb', line 4889 def full_name_aliases @full_name_aliases end |
#gender ⇒ Object
The individual’s gender
4891 4892 4893 |
# File 'lib/stripe/resources/account.rb', line 4891 def gender @gender end |
#id_number ⇒ Object
The government-issued ID number of the individual, as appropriate for the representative’s country. (Examples are a Social Security Number in the U.S., or a Social Insurance Number in Canada). Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).
4893 4894 4895 |
# File 'lib/stripe/resources/account.rb', line 4893 def id_number @id_number end |
#id_number_secondary ⇒ Object
The government-issued secondary ID number of the individual, as appropriate for the representative’s country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).
4895 4896 4897 |
# File 'lib/stripe/resources/account.rb', line 4895 def id_number_secondary @id_number_secondary end |
#last_name ⇒ Object
The individual’s last name.
4897 4898 4899 |
# File 'lib/stripe/resources/account.rb', line 4897 def last_name @last_name end |
#last_name_kana ⇒ Object
The Kana variation of the individual’s last name (Japan only).
4899 4900 4901 |
# File 'lib/stripe/resources/account.rb', line 4899 def last_name_kana @last_name_kana end |
#last_name_kanji ⇒ Object
The Kanji variation of the individual’s last name (Japan only).
4901 4902 4903 |
# File 'lib/stripe/resources/account.rb', line 4901 def last_name_kanji @last_name_kanji end |
#maiden_name ⇒ Object
The individual’s maiden name.
4903 4904 4905 |
# File 'lib/stripe/resources/account.rb', line 4903 def maiden_name @maiden_name end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
4905 4906 4907 |
# File 'lib/stripe/resources/account.rb', line 4905 def @metadata end |
#phone ⇒ Object
The individual’s phone number.
4907 4908 4909 |
# File 'lib/stripe/resources/account.rb', line 4907 def phone @phone end |
#political_exposure ⇒ Object
Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
4909 4910 4911 |
# File 'lib/stripe/resources/account.rb', line 4909 def political_exposure @political_exposure end |
#registered_address ⇒ Object
The individual’s registered address.
4911 4912 4913 |
# File 'lib/stripe/resources/account.rb', line 4911 def registered_address @registered_address end |
#relationship ⇒ Object
Describes the person’s relationship to the account.
4913 4914 4915 |
# File 'lib/stripe/resources/account.rb', line 4913 def relationship @relationship end |
#ssn_last_4 ⇒ Object
The last four digits of the individual’s Social Security Number (U.S. only).
4915 4916 4917 |
# File 'lib/stripe/resources/account.rb', line 4915 def ssn_last_4 @ssn_last_4 end |
#verification ⇒ Object
The individual’s verification document information.
4917 4918 4919 |
# File 'lib/stripe/resources/account.rb', line 4917 def verification @verification end |