Class: Stripe::Account::CreateParams::Individual
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::CreateParams::Individual
- Defined in:
- lib/stripe/resources/account.rb
Defined Under Namespace
Classes: Address, AddressKana, AddressKanji, Dob, RegisteredAddress, Relationship, Verification
Instance Attribute Summary collapse
-
#address ⇒ Object
The individual’s primary address.
-
#address_kana ⇒ Object
The Kana variation of the individual’s primary address (Japan only).
-
#address_kanji ⇒ Object
The Kanji variation of the individual’s primary address (Japan only).
-
#dob ⇒ Object
The individual’s date of birth.
-
#email ⇒ Object
The individual’s email address.
-
#first_name ⇒ Object
The individual’s first name.
-
#first_name_kana ⇒ Object
The Kana variation of the individual’s first name (Japan only).
-
#first_name_kanji ⇒ Object
The Kanji variation of the individual’s first name (Japan only).
-
#full_name_aliases ⇒ Object
A list of alternate names or aliases that the individual is known by.
-
#gender ⇒ Object
The individual’s gender.
-
#id_number ⇒ Object
The government-issued ID number of the individual, as appropriate for the representative’s country.
-
#id_number_secondary ⇒ Object
The government-issued secondary ID number of the individual, as appropriate for the representative’s country, will be used for enhanced verification checks.
-
#last_name ⇒ Object
The individual’s last name.
-
#last_name_kana ⇒ Object
The Kana variation of the individual’s last name (Japan only).
-
#last_name_kanji ⇒ Object
The Kanji variation of the individual’s last name (Japan only).
-
#maiden_name ⇒ Object
The individual’s maiden name.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#phone ⇒ Object
The individual’s phone number.
-
#political_exposure ⇒ Object
Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
-
#registered_address ⇒ Object
The individual’s registered address.
-
#relationship ⇒ Object
Describes the person’s relationship to the account.
-
#ssn_last_4 ⇒ Object
The last four digits of the individual’s Social Security Number (U.S. only).
-
#verification ⇒ Object
The individual’s verification document information.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, address_kana: nil, address_kanji: nil, dob: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil) ⇒ Individual
Returns a new instance of Individual.
5343 5344 5345 5346 5347 5348 5349 5350 5351 5352 5353 5354 5355 5356 5357 5358 5359 5360 5361 5362 5363 5364 5365 5366 5367 5368 5369 5370 5371 5372 5373 5374 5375 5376 5377 5378 5379 5380 5381 5382 5383 5384 5385 5386 5387 5388 5389 5390 5391 |
# File 'lib/stripe/resources/account.rb', line 5343 def initialize( address: nil, address_kana: nil, address_kanji: nil, dob: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil ) @address = address @address_kana = address_kana @address_kanji = address_kanji @dob = dob @email = email @first_name = first_name @first_name_kana = first_name_kana @first_name_kanji = first_name_kanji @full_name_aliases = full_name_aliases @gender = gender @id_number = id_number @id_number_secondary = id_number_secondary @last_name = last_name @last_name_kana = last_name_kana @last_name_kanji = last_name_kanji @maiden_name = maiden_name @metadata = @phone = phone @political_exposure = political_exposure @registered_address = registered_address @relationship = relationship @ssn_last_4 = ssn_last_4 @verification = verification end |
Instance Attribute Details
#address ⇒ Object
The individual’s primary address.
5297 5298 5299 |
# File 'lib/stripe/resources/account.rb', line 5297 def address @address end |
#address_kana ⇒ Object
The Kana variation of the individual’s primary address (Japan only).
5299 5300 5301 |
# File 'lib/stripe/resources/account.rb', line 5299 def address_kana @address_kana end |
#address_kanji ⇒ Object
The Kanji variation of the individual’s primary address (Japan only).
5301 5302 5303 |
# File 'lib/stripe/resources/account.rb', line 5301 def address_kanji @address_kanji end |
#dob ⇒ Object
The individual’s date of birth.
5303 5304 5305 |
# File 'lib/stripe/resources/account.rb', line 5303 def dob @dob end |
#email ⇒ Object
The individual’s email address.
5305 5306 5307 |
# File 'lib/stripe/resources/account.rb', line 5305 def email @email end |
#first_name ⇒ Object
The individual’s first name.
5307 5308 5309 |
# File 'lib/stripe/resources/account.rb', line 5307 def first_name @first_name end |
#first_name_kana ⇒ Object
The Kana variation of the individual’s first name (Japan only).
5309 5310 5311 |
# File 'lib/stripe/resources/account.rb', line 5309 def first_name_kana @first_name_kana end |
#first_name_kanji ⇒ Object
The Kanji variation of the individual’s first name (Japan only).
5311 5312 5313 |
# File 'lib/stripe/resources/account.rb', line 5311 def first_name_kanji @first_name_kanji end |
#full_name_aliases ⇒ Object
A list of alternate names or aliases that the individual is known by.
5313 5314 5315 |
# File 'lib/stripe/resources/account.rb', line 5313 def full_name_aliases @full_name_aliases end |
#gender ⇒ Object
The individual’s gender
5315 5316 5317 |
# File 'lib/stripe/resources/account.rb', line 5315 def gender @gender end |
#id_number ⇒ Object
The government-issued ID number of the individual, as appropriate for the representative’s country. (Examples are a Social Security Number in the U.S., or a Social Insurance Number in Canada). Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).
5317 5318 5319 |
# File 'lib/stripe/resources/account.rb', line 5317 def id_number @id_number end |
#id_number_secondary ⇒ Object
The government-issued secondary ID number of the individual, as appropriate for the representative’s country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).
5319 5320 5321 |
# File 'lib/stripe/resources/account.rb', line 5319 def id_number_secondary @id_number_secondary end |
#last_name ⇒ Object
The individual’s last name.
5321 5322 5323 |
# File 'lib/stripe/resources/account.rb', line 5321 def last_name @last_name end |
#last_name_kana ⇒ Object
The Kana variation of the individual’s last name (Japan only).
5323 5324 5325 |
# File 'lib/stripe/resources/account.rb', line 5323 def last_name_kana @last_name_kana end |
#last_name_kanji ⇒ Object
The Kanji variation of the individual’s last name (Japan only).
5325 5326 5327 |
# File 'lib/stripe/resources/account.rb', line 5325 def last_name_kanji @last_name_kanji end |
#maiden_name ⇒ Object
The individual’s maiden name.
5327 5328 5329 |
# File 'lib/stripe/resources/account.rb', line 5327 def maiden_name @maiden_name end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
5329 5330 5331 |
# File 'lib/stripe/resources/account.rb', line 5329 def @metadata end |
#phone ⇒ Object
The individual’s phone number.
5331 5332 5333 |
# File 'lib/stripe/resources/account.rb', line 5331 def phone @phone end |
#political_exposure ⇒ Object
Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
5333 5334 5335 |
# File 'lib/stripe/resources/account.rb', line 5333 def political_exposure @political_exposure end |
#registered_address ⇒ Object
The individual’s registered address.
5335 5336 5337 |
# File 'lib/stripe/resources/account.rb', line 5335 def registered_address @registered_address end |
#relationship ⇒ Object
Describes the person’s relationship to the account.
5337 5338 5339 |
# File 'lib/stripe/resources/account.rb', line 5337 def relationship @relationship end |
#ssn_last_4 ⇒ Object
The last four digits of the individual’s Social Security Number (U.S. only).
5339 5340 5341 |
# File 'lib/stripe/resources/account.rb', line 5339 def ssn_last_4 @ssn_last_4 end |
#verification ⇒ Object
The individual’s verification document information.
5341 5342 5343 |
# File 'lib/stripe/resources/account.rb', line 5341 def verification @verification end |