Class: Stripe::Account::CreateParams::Individual

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: Address, AddressKana, AddressKanji, Dob, RegisteredAddress, Relationship, Verification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, address_kana: nil, address_kanji: nil, dob: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil) ⇒ Individual

Returns a new instance of Individual.



4349
4350
4351
4352
4353
4354
4355
4356
4357
4358
4359
4360
4361
4362
4363
4364
4365
4366
4367
4368
4369
4370
4371
4372
4373
4374
4375
4376
4377
4378
4379
4380
4381
4382
4383
4384
4385
4386
4387
4388
4389
4390
4391
4392
4393
4394
4395
4396
4397
# File 'lib/stripe/resources/account.rb', line 4349

def initialize(
  address: nil,
  address_kana: nil,
  address_kanji: nil,
  dob: nil,
  email: nil,
  first_name: nil,
  first_name_kana: nil,
  first_name_kanji: nil,
  full_name_aliases: nil,
  gender: nil,
  id_number: nil,
  id_number_secondary: nil,
  last_name: nil,
  last_name_kana: nil,
  last_name_kanji: nil,
  maiden_name: nil,
  metadata: nil,
  phone: nil,
  political_exposure: nil,
  registered_address: nil,
  relationship: nil,
  ssn_last_4: nil,
  verification: nil
)
  @address = address
  @address_kana = address_kana
  @address_kanji = address_kanji
  @dob = dob
  @email = email
  @first_name = first_name
  @first_name_kana = first_name_kana
  @first_name_kanji = first_name_kanji
  @full_name_aliases = full_name_aliases
  @gender = gender
  @id_number = id_number
  @id_number_secondary = id_number_secondary
  @last_name = last_name
  @last_name_kana = last_name_kana
  @last_name_kanji = last_name_kanji
  @maiden_name = maiden_name
  @metadata = 
  @phone = phone
  @political_exposure = political_exposure
  @registered_address = registered_address
  @relationship = relationship
  @ssn_last_4 = ssn_last_4
  @verification = verification
end

Instance Attribute Details

#addressObject

The individual’s primary address.



4303
4304
4305
# File 'lib/stripe/resources/account.rb', line 4303

def address
  @address
end

#address_kanaObject

The Kana variation of the individual’s primary address (Japan only).



4305
4306
4307
# File 'lib/stripe/resources/account.rb', line 4305

def address_kana
  @address_kana
end

#address_kanjiObject

The Kanji variation of the individual’s primary address (Japan only).



4307
4308
4309
# File 'lib/stripe/resources/account.rb', line 4307

def address_kanji
  @address_kanji
end

#dobObject

The individual’s date of birth.



4309
4310
4311
# File 'lib/stripe/resources/account.rb', line 4309

def dob
  @dob
end

#emailObject

The individual’s email address.



4311
4312
4313
# File 'lib/stripe/resources/account.rb', line 4311

def email
  @email
end

#first_nameObject

The individual’s first name.



4313
4314
4315
# File 'lib/stripe/resources/account.rb', line 4313

def first_name
  @first_name
end

#first_name_kanaObject

The Kana variation of the individual’s first name (Japan only).



4315
4316
4317
# File 'lib/stripe/resources/account.rb', line 4315

def first_name_kana
  @first_name_kana
end

#first_name_kanjiObject

The Kanji variation of the individual’s first name (Japan only).



4317
4318
4319
# File 'lib/stripe/resources/account.rb', line 4317

def first_name_kanji
  @first_name_kanji
end

#full_name_aliasesObject

A list of alternate names or aliases that the individual is known by.



4319
4320
4321
# File 'lib/stripe/resources/account.rb', line 4319

def full_name_aliases
  @full_name_aliases
end

#genderObject

The individual’s gender



4321
4322
4323
# File 'lib/stripe/resources/account.rb', line 4321

def gender
  @gender
end

#id_numberObject

The government-issued ID number of the individual, as appropriate for the representative’s country. (Examples are a Social Security Number in the U.S., or a Social Insurance Number in Canada). Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).



4323
4324
4325
# File 'lib/stripe/resources/account.rb', line 4323

def id_number
  @id_number
end

#id_number_secondaryObject

The government-issued secondary ID number of the individual, as appropriate for the representative’s country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).



4325
4326
4327
# File 'lib/stripe/resources/account.rb', line 4325

def id_number_secondary
  @id_number_secondary
end

#last_nameObject

The individual’s last name.



4327
4328
4329
# File 'lib/stripe/resources/account.rb', line 4327

def last_name
  @last_name
end

#last_name_kanaObject

The Kana variation of the individual’s last name (Japan only).



4329
4330
4331
# File 'lib/stripe/resources/account.rb', line 4329

def last_name_kana
  @last_name_kana
end

#last_name_kanjiObject

The Kanji variation of the individual’s last name (Japan only).



4331
4332
4333
# File 'lib/stripe/resources/account.rb', line 4331

def last_name_kanji
  @last_name_kanji
end

#maiden_nameObject

The individual’s maiden name.



4333
4334
4335
# File 'lib/stripe/resources/account.rb', line 4333

def maiden_name
  @maiden_name
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



4335
4336
4337
# File 'lib/stripe/resources/account.rb', line 4335

def 
  @metadata
end

#phoneObject

The individual’s phone number.



4337
4338
4339
# File 'lib/stripe/resources/account.rb', line 4337

def phone
  @phone
end

#political_exposureObject

Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.



4339
4340
4341
# File 'lib/stripe/resources/account.rb', line 4339

def political_exposure
  @political_exposure
end

#registered_addressObject

The individual’s registered address.



4341
4342
4343
# File 'lib/stripe/resources/account.rb', line 4341

def registered_address
  @registered_address
end

#relationshipObject

Describes the person’s relationship to the account.



4343
4344
4345
# File 'lib/stripe/resources/account.rb', line 4343

def relationship
  @relationship
end

#ssn_last_4Object

The last four digits of the individual’s Social Security Number (U.S. only).



4345
4346
4347
# File 'lib/stripe/resources/account.rb', line 4345

def ssn_last_4
  @ssn_last_4
end

#verificationObject

The individual’s verification document information.



4347
4348
4349
# File 'lib/stripe/resources/account.rb', line 4347

def verification
  @verification
end