Class: Stripe::Account::CreateParams::Individual

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: Address, AddressKana, AddressKanji, Dob, RegisteredAddress, Relationship, Verification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, address_kana: nil, address_kanji: nil, dob: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil) ⇒ Individual

Returns a new instance of Individual.



4848
4849
4850
4851
4852
4853
4854
4855
4856
4857
4858
4859
4860
4861
4862
4863
4864
4865
4866
4867
4868
4869
4870
4871
4872
4873
4874
4875
4876
4877
4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
4893
4894
4895
4896
# File 'lib/stripe/resources/account.rb', line 4848

def initialize(
  address: nil,
  address_kana: nil,
  address_kanji: nil,
  dob: nil,
  email: nil,
  first_name: nil,
  first_name_kana: nil,
  first_name_kanji: nil,
  full_name_aliases: nil,
  gender: nil,
  id_number: nil,
  id_number_secondary: nil,
  last_name: nil,
  last_name_kana: nil,
  last_name_kanji: nil,
  maiden_name: nil,
  metadata: nil,
  phone: nil,
  political_exposure: nil,
  registered_address: nil,
  relationship: nil,
  ssn_last_4: nil,
  verification: nil
)
  @address = address
  @address_kana = address_kana
  @address_kanji = address_kanji
  @dob = dob
  @email = email
  @first_name = first_name
  @first_name_kana = first_name_kana
  @first_name_kanji = first_name_kanji
  @full_name_aliases = full_name_aliases
  @gender = gender
  @id_number = id_number
  @id_number_secondary = id_number_secondary
  @last_name = last_name
  @last_name_kana = last_name_kana
  @last_name_kanji = last_name_kanji
  @maiden_name = maiden_name
  @metadata = 
  @phone = phone
  @political_exposure = political_exposure
  @registered_address = registered_address
  @relationship = relationship
  @ssn_last_4 = ssn_last_4
  @verification = verification
end

Instance Attribute Details

#addressObject

The individual’s primary address.



4802
4803
4804
# File 'lib/stripe/resources/account.rb', line 4802

def address
  @address
end

#address_kanaObject

The Kana variation of the individual’s primary address (Japan only).



4804
4805
4806
# File 'lib/stripe/resources/account.rb', line 4804

def address_kana
  @address_kana
end

#address_kanjiObject

The Kanji variation of the individual’s primary address (Japan only).



4806
4807
4808
# File 'lib/stripe/resources/account.rb', line 4806

def address_kanji
  @address_kanji
end

#dobObject

The individual’s date of birth.



4808
4809
4810
# File 'lib/stripe/resources/account.rb', line 4808

def dob
  @dob
end

#emailObject

The individual’s email address.



4810
4811
4812
# File 'lib/stripe/resources/account.rb', line 4810

def email
  @email
end

#first_nameObject

The individual’s first name.



4812
4813
4814
# File 'lib/stripe/resources/account.rb', line 4812

def first_name
  @first_name
end

#first_name_kanaObject

The Kana variation of the individual’s first name (Japan only).



4814
4815
4816
# File 'lib/stripe/resources/account.rb', line 4814

def first_name_kana
  @first_name_kana
end

#first_name_kanjiObject

The Kanji variation of the individual’s first name (Japan only).



4816
4817
4818
# File 'lib/stripe/resources/account.rb', line 4816

def first_name_kanji
  @first_name_kanji
end

#full_name_aliasesObject

A list of alternate names or aliases that the individual is known by.



4818
4819
4820
# File 'lib/stripe/resources/account.rb', line 4818

def full_name_aliases
  @full_name_aliases
end

#genderObject

The individual’s gender



4820
4821
4822
# File 'lib/stripe/resources/account.rb', line 4820

def gender
  @gender
end

#id_numberObject

The government-issued ID number of the individual, as appropriate for the representative’s country. (Examples are a Social Security Number in the U.S., or a Social Insurance Number in Canada). Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).



4822
4823
4824
# File 'lib/stripe/resources/account.rb', line 4822

def id_number
  @id_number
end

#id_number_secondaryObject

The government-issued secondary ID number of the individual, as appropriate for the representative’s country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).



4824
4825
4826
# File 'lib/stripe/resources/account.rb', line 4824

def id_number_secondary
  @id_number_secondary
end

#last_nameObject

The individual’s last name.



4826
4827
4828
# File 'lib/stripe/resources/account.rb', line 4826

def last_name
  @last_name
end

#last_name_kanaObject

The Kana variation of the individual’s last name (Japan only).



4828
4829
4830
# File 'lib/stripe/resources/account.rb', line 4828

def last_name_kana
  @last_name_kana
end

#last_name_kanjiObject

The Kanji variation of the individual’s last name (Japan only).



4830
4831
4832
# File 'lib/stripe/resources/account.rb', line 4830

def last_name_kanji
  @last_name_kanji
end

#maiden_nameObject

The individual’s maiden name.



4832
4833
4834
# File 'lib/stripe/resources/account.rb', line 4832

def maiden_name
  @maiden_name
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



4834
4835
4836
# File 'lib/stripe/resources/account.rb', line 4834

def 
  @metadata
end

#phoneObject

The individual’s phone number.



4836
4837
4838
# File 'lib/stripe/resources/account.rb', line 4836

def phone
  @phone
end

#political_exposureObject

Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.



4838
4839
4840
# File 'lib/stripe/resources/account.rb', line 4838

def political_exposure
  @political_exposure
end

#registered_addressObject

The individual’s registered address.



4840
4841
4842
# File 'lib/stripe/resources/account.rb', line 4840

def registered_address
  @registered_address
end

#relationshipObject

Describes the person’s relationship to the account.



4842
4843
4844
# File 'lib/stripe/resources/account.rb', line 4842

def relationship
  @relationship
end

#ssn_last_4Object

The last four digits of the individual’s Social Security Number (U.S. only).



4844
4845
4846
# File 'lib/stripe/resources/account.rb', line 4844

def ssn_last_4
  @ssn_last_4
end

#verificationObject

The individual’s verification document information.



4846
4847
4848
# File 'lib/stripe/resources/account.rb', line 4846

def verification
  @verification
end