Class: Stripe::Account::CreateParams::Individual
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::CreateParams::Individual
- Defined in:
- lib/stripe/resources/account.rb
Defined Under Namespace
Classes: Address, AddressKana, AddressKanji, Dob, RegisteredAddress, Relationship, Verification
Instance Attribute Summary collapse
-
#address ⇒ Object
The individual’s primary address.
-
#address_kana ⇒ Object
The Kana variation of the individual’s primary address (Japan only).
-
#address_kanji ⇒ Object
The Kanji variation of the individual’s primary address (Japan only).
-
#dob ⇒ Object
The individual’s date of birth.
-
#email ⇒ Object
The individual’s email address.
-
#first_name ⇒ Object
The individual’s first name.
-
#first_name_kana ⇒ Object
The Kana variation of the individual’s first name (Japan only).
-
#first_name_kanji ⇒ Object
The Kanji variation of the individual’s first name (Japan only).
-
#full_name_aliases ⇒ Object
A list of alternate names or aliases that the individual is known by.
-
#gender ⇒ Object
The individual’s gender.
-
#id_number ⇒ Object
The government-issued ID number of the individual, as appropriate for the representative’s country.
-
#id_number_secondary ⇒ Object
The government-issued secondary ID number of the individual, as appropriate for the representative’s country, will be used for enhanced verification checks.
-
#last_name ⇒ Object
The individual’s last name.
-
#last_name_kana ⇒ Object
The Kana variation of the individual’s last name (Japan only).
-
#last_name_kanji ⇒ Object
The Kanji variation of the individual’s last name (Japan only).
-
#maiden_name ⇒ Object
The individual’s maiden name.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#phone ⇒ Object
The individual’s phone number.
-
#political_exposure ⇒ Object
Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
-
#registered_address ⇒ Object
The individual’s registered address.
-
#relationship ⇒ Object
Describes the person’s relationship to the account.
-
#ssn_last_4 ⇒ Object
The last four digits of the individual’s Social Security Number (U.S. only).
-
#verification ⇒ Object
The individual’s verification document information.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, address_kana: nil, address_kanji: nil, dob: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil) ⇒ Individual
Returns a new instance of Individual.
4251 4252 4253 4254 4255 4256 4257 4258 4259 4260 4261 4262 4263 4264 4265 4266 4267 4268 4269 4270 4271 4272 4273 4274 4275 4276 4277 4278 4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 4289 4290 4291 4292 4293 4294 4295 4296 4297 4298 4299 |
# File 'lib/stripe/resources/account.rb', line 4251 def initialize( address: nil, address_kana: nil, address_kanji: nil, dob: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil ) @address = address @address_kana = address_kana @address_kanji = address_kanji @dob = dob @email = email @first_name = first_name @first_name_kana = first_name_kana @first_name_kanji = first_name_kanji @full_name_aliases = full_name_aliases @gender = gender @id_number = id_number @id_number_secondary = id_number_secondary @last_name = last_name @last_name_kana = last_name_kana @last_name_kanji = last_name_kanji @maiden_name = maiden_name @metadata = @phone = phone @political_exposure = political_exposure @registered_address = registered_address @relationship = relationship @ssn_last_4 = ssn_last_4 @verification = verification end |
Instance Attribute Details
#address ⇒ Object
The individual’s primary address.
4205 4206 4207 |
# File 'lib/stripe/resources/account.rb', line 4205 def address @address end |
#address_kana ⇒ Object
The Kana variation of the individual’s primary address (Japan only).
4207 4208 4209 |
# File 'lib/stripe/resources/account.rb', line 4207 def address_kana @address_kana end |
#address_kanji ⇒ Object
The Kanji variation of the individual’s primary address (Japan only).
4209 4210 4211 |
# File 'lib/stripe/resources/account.rb', line 4209 def address_kanji @address_kanji end |
#dob ⇒ Object
The individual’s date of birth.
4211 4212 4213 |
# File 'lib/stripe/resources/account.rb', line 4211 def dob @dob end |
#email ⇒ Object
The individual’s email address.
4213 4214 4215 |
# File 'lib/stripe/resources/account.rb', line 4213 def email @email end |
#first_name ⇒ Object
The individual’s first name.
4215 4216 4217 |
# File 'lib/stripe/resources/account.rb', line 4215 def first_name @first_name end |
#first_name_kana ⇒ Object
The Kana variation of the individual’s first name (Japan only).
4217 4218 4219 |
# File 'lib/stripe/resources/account.rb', line 4217 def first_name_kana @first_name_kana end |
#first_name_kanji ⇒ Object
The Kanji variation of the individual’s first name (Japan only).
4219 4220 4221 |
# File 'lib/stripe/resources/account.rb', line 4219 def first_name_kanji @first_name_kanji end |
#full_name_aliases ⇒ Object
A list of alternate names or aliases that the individual is known by.
4221 4222 4223 |
# File 'lib/stripe/resources/account.rb', line 4221 def full_name_aliases @full_name_aliases end |
#gender ⇒ Object
The individual’s gender
4223 4224 4225 |
# File 'lib/stripe/resources/account.rb', line 4223 def gender @gender end |
#id_number ⇒ Object
The government-issued ID number of the individual, as appropriate for the representative’s country. (Examples are a Social Security Number in the U.S., or a Social Insurance Number in Canada). Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).
4225 4226 4227 |
# File 'lib/stripe/resources/account.rb', line 4225 def id_number @id_number end |
#id_number_secondary ⇒ Object
The government-issued secondary ID number of the individual, as appropriate for the representative’s country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).
4227 4228 4229 |
# File 'lib/stripe/resources/account.rb', line 4227 def id_number_secondary @id_number_secondary end |
#last_name ⇒ Object
The individual’s last name.
4229 4230 4231 |
# File 'lib/stripe/resources/account.rb', line 4229 def last_name @last_name end |
#last_name_kana ⇒ Object
The Kana variation of the individual’s last name (Japan only).
4231 4232 4233 |
# File 'lib/stripe/resources/account.rb', line 4231 def last_name_kana @last_name_kana end |
#last_name_kanji ⇒ Object
The Kanji variation of the individual’s last name (Japan only).
4233 4234 4235 |
# File 'lib/stripe/resources/account.rb', line 4233 def last_name_kanji @last_name_kanji end |
#maiden_name ⇒ Object
The individual’s maiden name.
4235 4236 4237 |
# File 'lib/stripe/resources/account.rb', line 4235 def maiden_name @maiden_name end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
4237 4238 4239 |
# File 'lib/stripe/resources/account.rb', line 4237 def @metadata end |
#phone ⇒ Object
The individual’s phone number.
4239 4240 4241 |
# File 'lib/stripe/resources/account.rb', line 4239 def phone @phone end |
#political_exposure ⇒ Object
Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
4241 4242 4243 |
# File 'lib/stripe/resources/account.rb', line 4241 def political_exposure @political_exposure end |
#registered_address ⇒ Object
The individual’s registered address.
4243 4244 4245 |
# File 'lib/stripe/resources/account.rb', line 4243 def registered_address @registered_address end |
#relationship ⇒ Object
Describes the person’s relationship to the account.
4245 4246 4247 |
# File 'lib/stripe/resources/account.rb', line 4245 def relationship @relationship end |
#ssn_last_4 ⇒ Object
The last four digits of the individual’s Social Security Number (U.S. only).
4247 4248 4249 |
# File 'lib/stripe/resources/account.rb', line 4247 def ssn_last_4 @ssn_last_4 end |
#verification ⇒ Object
The individual’s verification document information.
4249 4250 4251 |
# File 'lib/stripe/resources/account.rb', line 4249 def verification @verification end |