Class: Stripe::Account::CreateParams::Individual

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: Address, AddressKana, AddressKanji, Dob, RegisteredAddress, Relationship, Verification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, address_kana: nil, address_kanji: nil, dob: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil) ⇒ Individual

Returns a new instance of Individual.



4762
4763
4764
4765
4766
4767
4768
4769
4770
4771
4772
4773
4774
4775
4776
4777
4778
4779
4780
4781
4782
4783
4784
4785
4786
4787
4788
4789
4790
4791
4792
4793
4794
4795
4796
4797
4798
4799
4800
4801
4802
4803
4804
4805
4806
4807
4808
4809
4810
# File 'lib/stripe/resources/account.rb', line 4762

def initialize(
  address: nil,
  address_kana: nil,
  address_kanji: nil,
  dob: nil,
  email: nil,
  first_name: nil,
  first_name_kana: nil,
  first_name_kanji: nil,
  full_name_aliases: nil,
  gender: nil,
  id_number: nil,
  id_number_secondary: nil,
  last_name: nil,
  last_name_kana: nil,
  last_name_kanji: nil,
  maiden_name: nil,
  metadata: nil,
  phone: nil,
  political_exposure: nil,
  registered_address: nil,
  relationship: nil,
  ssn_last_4: nil,
  verification: nil
)
  @address = address
  @address_kana = address_kana
  @address_kanji = address_kanji
  @dob = dob
  @email = email
  @first_name = first_name
  @first_name_kana = first_name_kana
  @first_name_kanji = first_name_kanji
  @full_name_aliases = full_name_aliases
  @gender = gender
  @id_number = id_number
  @id_number_secondary = id_number_secondary
  @last_name = last_name
  @last_name_kana = last_name_kana
  @last_name_kanji = last_name_kanji
  @maiden_name = maiden_name
  @metadata = 
  @phone = phone
  @political_exposure = political_exposure
  @registered_address = registered_address
  @relationship = relationship
  @ssn_last_4 = ssn_last_4
  @verification = verification
end

Instance Attribute Details

#addressObject

The individual’s primary address.



4716
4717
4718
# File 'lib/stripe/resources/account.rb', line 4716

def address
  @address
end

#address_kanaObject

The Kana variation of the individual’s primary address (Japan only).



4718
4719
4720
# File 'lib/stripe/resources/account.rb', line 4718

def address_kana
  @address_kana
end

#address_kanjiObject

The Kanji variation of the individual’s primary address (Japan only).



4720
4721
4722
# File 'lib/stripe/resources/account.rb', line 4720

def address_kanji
  @address_kanji
end

#dobObject

The individual’s date of birth.



4722
4723
4724
# File 'lib/stripe/resources/account.rb', line 4722

def dob
  @dob
end

#emailObject

The individual’s email address.



4724
4725
4726
# File 'lib/stripe/resources/account.rb', line 4724

def email
  @email
end

#first_nameObject

The individual’s first name.



4726
4727
4728
# File 'lib/stripe/resources/account.rb', line 4726

def first_name
  @first_name
end

#first_name_kanaObject

The Kana variation of the individual’s first name (Japan only).



4728
4729
4730
# File 'lib/stripe/resources/account.rb', line 4728

def first_name_kana
  @first_name_kana
end

#first_name_kanjiObject

The Kanji variation of the individual’s first name (Japan only).



4730
4731
4732
# File 'lib/stripe/resources/account.rb', line 4730

def first_name_kanji
  @first_name_kanji
end

#full_name_aliasesObject

A list of alternate names or aliases that the individual is known by.



4732
4733
4734
# File 'lib/stripe/resources/account.rb', line 4732

def full_name_aliases
  @full_name_aliases
end

#genderObject

The individual’s gender



4734
4735
4736
# File 'lib/stripe/resources/account.rb', line 4734

def gender
  @gender
end

#id_numberObject

The government-issued ID number of the individual, as appropriate for the representative’s country. (Examples are a Social Security Number in the U.S., or a Social Insurance Number in Canada). Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).



4736
4737
4738
# File 'lib/stripe/resources/account.rb', line 4736

def id_number
  @id_number
end

#id_number_secondaryObject

The government-issued secondary ID number of the individual, as appropriate for the representative’s country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).



4738
4739
4740
# File 'lib/stripe/resources/account.rb', line 4738

def id_number_secondary
  @id_number_secondary
end

#last_nameObject

The individual’s last name.



4740
4741
4742
# File 'lib/stripe/resources/account.rb', line 4740

def last_name
  @last_name
end

#last_name_kanaObject

The Kana variation of the individual’s last name (Japan only).



4742
4743
4744
# File 'lib/stripe/resources/account.rb', line 4742

def last_name_kana
  @last_name_kana
end

#last_name_kanjiObject

The Kanji variation of the individual’s last name (Japan only).



4744
4745
4746
# File 'lib/stripe/resources/account.rb', line 4744

def last_name_kanji
  @last_name_kanji
end

#maiden_nameObject

The individual’s maiden name.



4746
4747
4748
# File 'lib/stripe/resources/account.rb', line 4746

def maiden_name
  @maiden_name
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



4748
4749
4750
# File 'lib/stripe/resources/account.rb', line 4748

def 
  @metadata
end

#phoneObject

The individual’s phone number.



4750
4751
4752
# File 'lib/stripe/resources/account.rb', line 4750

def phone
  @phone
end

#political_exposureObject

Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.



4752
4753
4754
# File 'lib/stripe/resources/account.rb', line 4752

def political_exposure
  @political_exposure
end

#registered_addressObject

The individual’s registered address.



4754
4755
4756
# File 'lib/stripe/resources/account.rb', line 4754

def registered_address
  @registered_address
end

#relationshipObject

Describes the person’s relationship to the account.



4756
4757
4758
# File 'lib/stripe/resources/account.rb', line 4756

def relationship
  @relationship
end

#ssn_last_4Object

The last four digits of the individual’s Social Security Number (U.S. only).



4758
4759
4760
# File 'lib/stripe/resources/account.rb', line 4758

def ssn_last_4
  @ssn_last_4
end

#verificationObject

The individual’s verification document information.



4760
4761
4762
# File 'lib/stripe/resources/account.rb', line 4760

def verification
  @verification
end