Class: Stripe::Account::CreateParams::Individual

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: Address, AddressKana, AddressKanji, Dob, RegisteredAddress, Relationship, Verification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, address_kana: nil, address_kanji: nil, dob: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil) ⇒ Individual

Returns a new instance of Individual.



4654
4655
4656
4657
4658
4659
4660
4661
4662
4663
4664
4665
4666
4667
4668
4669
4670
4671
4672
4673
4674
4675
4676
4677
4678
4679
4680
4681
4682
4683
4684
4685
4686
4687
4688
4689
4690
4691
4692
4693
4694
4695
4696
4697
4698
4699
4700
4701
4702
# File 'lib/stripe/resources/account.rb', line 4654

def initialize(
  address: nil,
  address_kana: nil,
  address_kanji: nil,
  dob: nil,
  email: nil,
  first_name: nil,
  first_name_kana: nil,
  first_name_kanji: nil,
  full_name_aliases: nil,
  gender: nil,
  id_number: nil,
  id_number_secondary: nil,
  last_name: nil,
  last_name_kana: nil,
  last_name_kanji: nil,
  maiden_name: nil,
  metadata: nil,
  phone: nil,
  political_exposure: nil,
  registered_address: nil,
  relationship: nil,
  ssn_last_4: nil,
  verification: nil
)
  @address = address
  @address_kana = address_kana
  @address_kanji = address_kanji
  @dob = dob
  @email = email
  @first_name = first_name
  @first_name_kana = first_name_kana
  @first_name_kanji = first_name_kanji
  @full_name_aliases = full_name_aliases
  @gender = gender
  @id_number = id_number
  @id_number_secondary = id_number_secondary
  @last_name = last_name
  @last_name_kana = last_name_kana
  @last_name_kanji = last_name_kanji
  @maiden_name = maiden_name
  @metadata = 
  @phone = phone
  @political_exposure = political_exposure
  @registered_address = registered_address
  @relationship = relationship
  @ssn_last_4 = ssn_last_4
  @verification = verification
end

Instance Attribute Details

#addressObject

The individual’s primary address.



4608
4609
4610
# File 'lib/stripe/resources/account.rb', line 4608

def address
  @address
end

#address_kanaObject

The Kana variation of the individual’s primary address (Japan only).



4610
4611
4612
# File 'lib/stripe/resources/account.rb', line 4610

def address_kana
  @address_kana
end

#address_kanjiObject

The Kanji variation of the individual’s primary address (Japan only).



4612
4613
4614
# File 'lib/stripe/resources/account.rb', line 4612

def address_kanji
  @address_kanji
end

#dobObject

The individual’s date of birth.



4614
4615
4616
# File 'lib/stripe/resources/account.rb', line 4614

def dob
  @dob
end

#emailObject

The individual’s email address.



4616
4617
4618
# File 'lib/stripe/resources/account.rb', line 4616

def email
  @email
end

#first_nameObject

The individual’s first name.



4618
4619
4620
# File 'lib/stripe/resources/account.rb', line 4618

def first_name
  @first_name
end

#first_name_kanaObject

The Kana variation of the individual’s first name (Japan only).



4620
4621
4622
# File 'lib/stripe/resources/account.rb', line 4620

def first_name_kana
  @first_name_kana
end

#first_name_kanjiObject

The Kanji variation of the individual’s first name (Japan only).



4622
4623
4624
# File 'lib/stripe/resources/account.rb', line 4622

def first_name_kanji
  @first_name_kanji
end

#full_name_aliasesObject

A list of alternate names or aliases that the individual is known by.



4624
4625
4626
# File 'lib/stripe/resources/account.rb', line 4624

def full_name_aliases
  @full_name_aliases
end

#genderObject

The individual’s gender



4626
4627
4628
# File 'lib/stripe/resources/account.rb', line 4626

def gender
  @gender
end

#id_numberObject

The government-issued ID number of the individual, as appropriate for the representative’s country. (Examples are a Social Security Number in the U.S., or a Social Insurance Number in Canada). Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).



4628
4629
4630
# File 'lib/stripe/resources/account.rb', line 4628

def id_number
  @id_number
end

#id_number_secondaryObject

The government-issued secondary ID number of the individual, as appropriate for the representative’s country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).



4630
4631
4632
# File 'lib/stripe/resources/account.rb', line 4630

def id_number_secondary
  @id_number_secondary
end

#last_nameObject

The individual’s last name.



4632
4633
4634
# File 'lib/stripe/resources/account.rb', line 4632

def last_name
  @last_name
end

#last_name_kanaObject

The Kana variation of the individual’s last name (Japan only).



4634
4635
4636
# File 'lib/stripe/resources/account.rb', line 4634

def last_name_kana
  @last_name_kana
end

#last_name_kanjiObject

The Kanji variation of the individual’s last name (Japan only).



4636
4637
4638
# File 'lib/stripe/resources/account.rb', line 4636

def last_name_kanji
  @last_name_kanji
end

#maiden_nameObject

The individual’s maiden name.



4638
4639
4640
# File 'lib/stripe/resources/account.rb', line 4638

def maiden_name
  @maiden_name
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



4640
4641
4642
# File 'lib/stripe/resources/account.rb', line 4640

def 
  @metadata
end

#phoneObject

The individual’s phone number.



4642
4643
4644
# File 'lib/stripe/resources/account.rb', line 4642

def phone
  @phone
end

#political_exposureObject

Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.



4644
4645
4646
# File 'lib/stripe/resources/account.rb', line 4644

def political_exposure
  @political_exposure
end

#registered_addressObject

The individual’s registered address.



4646
4647
4648
# File 'lib/stripe/resources/account.rb', line 4646

def registered_address
  @registered_address
end

#relationshipObject

Describes the person’s relationship to the account.



4648
4649
4650
# File 'lib/stripe/resources/account.rb', line 4648

def relationship
  @relationship
end

#ssn_last_4Object

The last four digits of the individual’s Social Security Number (U.S. only).



4650
4651
4652
# File 'lib/stripe/resources/account.rb', line 4650

def ssn_last_4
  @ssn_last_4
end

#verificationObject

The individual’s verification document information.



4652
4653
4654
# File 'lib/stripe/resources/account.rb', line 4652

def verification
  @verification
end