Class: Stripe::Account::CreateParams::Individual

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: Address, AddressKana, AddressKanji, Dob, RegisteredAddress, Relationship, Verification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, address_kana: nil, address_kanji: nil, dob: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil) ⇒ Individual

Returns a new instance of Individual.



5197
5198
5199
5200
5201
5202
5203
5204
5205
5206
5207
5208
5209
5210
5211
5212
5213
5214
5215
5216
5217
5218
5219
5220
5221
5222
5223
5224
5225
5226
5227
5228
5229
5230
5231
5232
5233
5234
5235
5236
5237
5238
5239
5240
5241
5242
5243
5244
5245
# File 'lib/stripe/resources/account.rb', line 5197

def initialize(
  address: nil,
  address_kana: nil,
  address_kanji: nil,
  dob: nil,
  email: nil,
  first_name: nil,
  first_name_kana: nil,
  first_name_kanji: nil,
  full_name_aliases: nil,
  gender: nil,
  id_number: nil,
  id_number_secondary: nil,
  last_name: nil,
  last_name_kana: nil,
  last_name_kanji: nil,
  maiden_name: nil,
  metadata: nil,
  phone: nil,
  political_exposure: nil,
  registered_address: nil,
  relationship: nil,
  ssn_last_4: nil,
  verification: nil
)
  @address = address
  @address_kana = address_kana
  @address_kanji = address_kanji
  @dob = dob
  @email = email
  @first_name = first_name
  @first_name_kana = first_name_kana
  @first_name_kanji = first_name_kanji
  @full_name_aliases = full_name_aliases
  @gender = gender
  @id_number = id_number
  @id_number_secondary = id_number_secondary
  @last_name = last_name
  @last_name_kana = last_name_kana
  @last_name_kanji = last_name_kanji
  @maiden_name = maiden_name
  @metadata = 
  @phone = phone
  @political_exposure = political_exposure
  @registered_address = registered_address
  @relationship = relationship
  @ssn_last_4 = ssn_last_4
  @verification = verification
end

Instance Attribute Details

#addressObject

The individual’s primary address.



5129
5130
5131
# File 'lib/stripe/resources/account.rb', line 5129

def address
  @address
end

#address_kanaObject

The Kana variation of the individual’s primary address (Japan only).



5132
5133
5134
# File 'lib/stripe/resources/account.rb', line 5132

def address_kana
  @address_kana
end

#address_kanjiObject

The Kanji variation of the individual’s primary address (Japan only).



5135
5136
5137
# File 'lib/stripe/resources/account.rb', line 5135

def address_kanji
  @address_kanji
end

#dobObject

The individual’s date of birth.



5138
5139
5140
# File 'lib/stripe/resources/account.rb', line 5138

def dob
  @dob
end

#emailObject

The individual’s email address.



5141
5142
5143
# File 'lib/stripe/resources/account.rb', line 5141

def email
  @email
end

#first_nameObject

The individual’s first name.



5144
5145
5146
# File 'lib/stripe/resources/account.rb', line 5144

def first_name
  @first_name
end

#first_name_kanaObject

The Kana variation of the individual’s first name (Japan only).



5147
5148
5149
# File 'lib/stripe/resources/account.rb', line 5147

def first_name_kana
  @first_name_kana
end

#first_name_kanjiObject

The Kanji variation of the individual’s first name (Japan only).



5150
5151
5152
# File 'lib/stripe/resources/account.rb', line 5150

def first_name_kanji
  @first_name_kanji
end

#full_name_aliasesObject

A list of alternate names or aliases that the individual is known by.



5153
5154
5155
# File 'lib/stripe/resources/account.rb', line 5153

def full_name_aliases
  @full_name_aliases
end

#genderObject

The individual’s gender



5156
5157
5158
# File 'lib/stripe/resources/account.rb', line 5156

def gender
  @gender
end

#id_numberObject

The government-issued ID number of the individual, as appropriate for the representative’s country. (Examples are a Social Security Number in the U.S., or a Social Insurance Number in Canada). Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).



5159
5160
5161
# File 'lib/stripe/resources/account.rb', line 5159

def id_number
  @id_number
end

#id_number_secondaryObject

The government-issued secondary ID number of the individual, as appropriate for the representative’s country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).



5162
5163
5164
# File 'lib/stripe/resources/account.rb', line 5162

def id_number_secondary
  @id_number_secondary
end

#last_nameObject

The individual’s last name.



5165
5166
5167
# File 'lib/stripe/resources/account.rb', line 5165

def last_name
  @last_name
end

#last_name_kanaObject

The Kana variation of the individual’s last name (Japan only).



5168
5169
5170
# File 'lib/stripe/resources/account.rb', line 5168

def last_name_kana
  @last_name_kana
end

#last_name_kanjiObject

The Kanji variation of the individual’s last name (Japan only).



5171
5172
5173
# File 'lib/stripe/resources/account.rb', line 5171

def last_name_kanji
  @last_name_kanji
end

#maiden_nameObject

The individual’s maiden name.



5174
5175
5176
# File 'lib/stripe/resources/account.rb', line 5174

def maiden_name
  @maiden_name
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



5177
5178
5179
# File 'lib/stripe/resources/account.rb', line 5177

def 
  @metadata
end

#phoneObject

The individual’s phone number.



5180
5181
5182
# File 'lib/stripe/resources/account.rb', line 5180

def phone
  @phone
end

#political_exposureObject

Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.



5183
5184
5185
# File 'lib/stripe/resources/account.rb', line 5183

def political_exposure
  @political_exposure
end

#registered_addressObject

The individual’s registered address.



5186
5187
5188
# File 'lib/stripe/resources/account.rb', line 5186

def registered_address
  @registered_address
end

#relationshipObject

Describes the person’s relationship to the account.



5189
5190
5191
# File 'lib/stripe/resources/account.rb', line 5189

def relationship
  @relationship
end

#ssn_last_4Object

The last four digits of the individual’s Social Security Number (U.S. only).



5192
5193
5194
# File 'lib/stripe/resources/account.rb', line 5192

def ssn_last_4
  @ssn_last_4
end

#verificationObject

The individual’s verification document information.



5195
5196
5197
# File 'lib/stripe/resources/account.rb', line 5195

def verification
  @verification
end