Class: Stripe::Account::CreateParams::Individual
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::CreateParams::Individual
- Defined in:
- lib/stripe/resources/account.rb
Defined Under Namespace
Classes: Address, AddressKana, AddressKanji, Dob, RegisteredAddress, Relationship, Verification
Instance Attribute Summary collapse
-
#address ⇒ Object
The individual’s primary address.
-
#address_kana ⇒ Object
The Kana variation of the individual’s primary address (Japan only).
-
#address_kanji ⇒ Object
The Kanji variation of the individual’s primary address (Japan only).
-
#dob ⇒ Object
The individual’s date of birth.
-
#email ⇒ Object
The individual’s email address.
-
#first_name ⇒ Object
The individual’s first name.
-
#first_name_kana ⇒ Object
The Kana variation of the individual’s first name (Japan only).
-
#first_name_kanji ⇒ Object
The Kanji variation of the individual’s first name (Japan only).
-
#full_name_aliases ⇒ Object
A list of alternate names or aliases that the individual is known by.
-
#gender ⇒ Object
The individual’s gender.
-
#id_number ⇒ Object
The government-issued ID number of the individual, as appropriate for the representative’s country.
-
#id_number_secondary ⇒ Object
The government-issued secondary ID number of the individual, as appropriate for the representative’s country, will be used for enhanced verification checks.
-
#last_name ⇒ Object
The individual’s last name.
-
#last_name_kana ⇒ Object
The Kana variation of the individual’s last name (Japan only).
-
#last_name_kanji ⇒ Object
The Kanji variation of the individual’s last name (Japan only).
-
#maiden_name ⇒ Object
The individual’s maiden name.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#phone ⇒ Object
The individual’s phone number.
-
#political_exposure ⇒ Object
Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
-
#registered_address ⇒ Object
The individual’s registered address.
-
#relationship ⇒ Object
Describes the person’s relationship to the account.
-
#ssn_last_4 ⇒ Object
The last four digits of the individual’s Social Security Number (U.S. only).
-
#verification ⇒ Object
The individual’s verification document information.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, address_kana: nil, address_kanji: nil, dob: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil) ⇒ Individual
Returns a new instance of Individual.
4560 4561 4562 4563 4564 4565 4566 4567 4568 4569 4570 4571 4572 4573 4574 4575 4576 4577 4578 4579 4580 4581 4582 4583 4584 4585 4586 4587 4588 4589 4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 4600 4601 4602 4603 4604 4605 4606 4607 4608 |
# File 'lib/stripe/resources/account.rb', line 4560 def initialize( address: nil, address_kana: nil, address_kanji: nil, dob: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil ) @address = address @address_kana = address_kana @address_kanji = address_kanji @dob = dob @email = email @first_name = first_name @first_name_kana = first_name_kana @first_name_kanji = first_name_kanji @full_name_aliases = full_name_aliases @gender = gender @id_number = id_number @id_number_secondary = id_number_secondary @last_name = last_name @last_name_kana = last_name_kana @last_name_kanji = last_name_kanji @maiden_name = maiden_name @metadata = @phone = phone @political_exposure = political_exposure @registered_address = registered_address @relationship = relationship @ssn_last_4 = ssn_last_4 @verification = verification end |
Instance Attribute Details
#address ⇒ Object
The individual’s primary address.
4514 4515 4516 |
# File 'lib/stripe/resources/account.rb', line 4514 def address @address end |
#address_kana ⇒ Object
The Kana variation of the individual’s primary address (Japan only).
4516 4517 4518 |
# File 'lib/stripe/resources/account.rb', line 4516 def address_kana @address_kana end |
#address_kanji ⇒ Object
The Kanji variation of the individual’s primary address (Japan only).
4518 4519 4520 |
# File 'lib/stripe/resources/account.rb', line 4518 def address_kanji @address_kanji end |
#dob ⇒ Object
The individual’s date of birth.
4520 4521 4522 |
# File 'lib/stripe/resources/account.rb', line 4520 def dob @dob end |
#email ⇒ Object
The individual’s email address.
4522 4523 4524 |
# File 'lib/stripe/resources/account.rb', line 4522 def email @email end |
#first_name ⇒ Object
The individual’s first name.
4524 4525 4526 |
# File 'lib/stripe/resources/account.rb', line 4524 def first_name @first_name end |
#first_name_kana ⇒ Object
The Kana variation of the individual’s first name (Japan only).
4526 4527 4528 |
# File 'lib/stripe/resources/account.rb', line 4526 def first_name_kana @first_name_kana end |
#first_name_kanji ⇒ Object
The Kanji variation of the individual’s first name (Japan only).
4528 4529 4530 |
# File 'lib/stripe/resources/account.rb', line 4528 def first_name_kanji @first_name_kanji end |
#full_name_aliases ⇒ Object
A list of alternate names or aliases that the individual is known by.
4530 4531 4532 |
# File 'lib/stripe/resources/account.rb', line 4530 def full_name_aliases @full_name_aliases end |
#gender ⇒ Object
The individual’s gender
4532 4533 4534 |
# File 'lib/stripe/resources/account.rb', line 4532 def gender @gender end |
#id_number ⇒ Object
The government-issued ID number of the individual, as appropriate for the representative’s country. (Examples are a Social Security Number in the U.S., or a Social Insurance Number in Canada). Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).
4534 4535 4536 |
# File 'lib/stripe/resources/account.rb', line 4534 def id_number @id_number end |
#id_number_secondary ⇒ Object
The government-issued secondary ID number of the individual, as appropriate for the representative’s country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).
4536 4537 4538 |
# File 'lib/stripe/resources/account.rb', line 4536 def id_number_secondary @id_number_secondary end |
#last_name ⇒ Object
The individual’s last name.
4538 4539 4540 |
# File 'lib/stripe/resources/account.rb', line 4538 def last_name @last_name end |
#last_name_kana ⇒ Object
The Kana variation of the individual’s last name (Japan only).
4540 4541 4542 |
# File 'lib/stripe/resources/account.rb', line 4540 def last_name_kana @last_name_kana end |
#last_name_kanji ⇒ Object
The Kanji variation of the individual’s last name (Japan only).
4542 4543 4544 |
# File 'lib/stripe/resources/account.rb', line 4542 def last_name_kanji @last_name_kanji end |
#maiden_name ⇒ Object
The individual’s maiden name.
4544 4545 4546 |
# File 'lib/stripe/resources/account.rb', line 4544 def maiden_name @maiden_name end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
4546 4547 4548 |
# File 'lib/stripe/resources/account.rb', line 4546 def @metadata end |
#phone ⇒ Object
The individual’s phone number.
4548 4549 4550 |
# File 'lib/stripe/resources/account.rb', line 4548 def phone @phone end |
#political_exposure ⇒ Object
Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
4550 4551 4552 |
# File 'lib/stripe/resources/account.rb', line 4550 def political_exposure @political_exposure end |
#registered_address ⇒ Object
The individual’s registered address.
4552 4553 4554 |
# File 'lib/stripe/resources/account.rb', line 4552 def registered_address @registered_address end |
#relationship ⇒ Object
Describes the person’s relationship to the account.
4554 4555 4556 |
# File 'lib/stripe/resources/account.rb', line 4554 def relationship @relationship end |
#ssn_last_4 ⇒ Object
The last four digits of the individual’s Social Security Number (U.S. only).
4556 4557 4558 |
# File 'lib/stripe/resources/account.rb', line 4556 def ssn_last_4 @ssn_last_4 end |
#verification ⇒ Object
The individual’s verification document information.
4558 4559 4560 |
# File 'lib/stripe/resources/account.rb', line 4558 def verification @verification end |