Class: Stripe::Account::CreateParams::Individual::Relationship
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::CreateParams::Individual::Relationship
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#director ⇒ Object
Whether the person is a director of the account’s legal entity.
-
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
-
#owner ⇒ Object
Whether the person is an owner of the account’s legal entity.
-
#percent_ownership ⇒ Object
The percent owned by the person of the account’s legal entity.
-
#title ⇒ Object
The person’s title (e.g., CEO, Support Engineer).
Instance Method Summary collapse
-
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
constructor
A new instance of Relationship.
Methods inherited from RequestParams
Constructor Details
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
Returns a new instance of Relationship.
5247 5248 5249 5250 5251 5252 5253 5254 5255 5256 5257 5258 5259 |
# File 'lib/stripe/resources/account.rb', line 5247 def initialize( director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil ) @director = director @executive = executive @owner = owner @percent_ownership = percent_ownership @title = title end |
Instance Attribute Details
#director ⇒ Object
Whether the person is a director of the account’s legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.
5237 5238 5239 |
# File 'lib/stripe/resources/account.rb', line 5237 def director @director end |
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
5239 5240 5241 |
# File 'lib/stripe/resources/account.rb', line 5239 def executive @executive end |
#owner ⇒ Object
Whether the person is an owner of the account’s legal entity.
5241 5242 5243 |
# File 'lib/stripe/resources/account.rb', line 5241 def owner @owner end |
#percent_ownership ⇒ Object
The percent owned by the person of the account’s legal entity.
5243 5244 5245 |
# File 'lib/stripe/resources/account.rb', line 5243 def percent_ownership @percent_ownership end |
#title ⇒ Object
The person’s title (e.g., CEO, Support Engineer).
5245 5246 5247 |
# File 'lib/stripe/resources/account.rb', line 5245 def title @title end |