Class: Stripe::Account::CreateParams::Individual::Relationship
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::CreateParams::Individual::Relationship
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#director ⇒ Object
Whether the person is a director of the account’s legal entity.
-
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
-
#owner ⇒ Object
Whether the person is an owner of the account’s legal entity.
-
#percent_ownership ⇒ Object
The percent owned by the person of the account’s legal entity.
-
#title ⇒ Object
The person’s title (e.g., CEO, Support Engineer).
Instance Method Summary collapse
-
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
constructor
A new instance of Relationship.
Methods inherited from RequestParams
Constructor Details
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
Returns a new instance of Relationship.
4182 4183 4184 4185 4186 4187 4188 4189 4190 4191 4192 4193 4194 |
# File 'lib/stripe/resources/account.rb', line 4182 def initialize( director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil ) @director = director @executive = executive @owner = owner @percent_ownership = percent_ownership @title = title end |
Instance Attribute Details
#director ⇒ Object
Whether the person is a director of the account’s legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.
4172 4173 4174 |
# File 'lib/stripe/resources/account.rb', line 4172 def director @director end |
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
4174 4175 4176 |
# File 'lib/stripe/resources/account.rb', line 4174 def executive @executive end |
#owner ⇒ Object
Whether the person is an owner of the account’s legal entity.
4176 4177 4178 |
# File 'lib/stripe/resources/account.rb', line 4176 def owner @owner end |
#percent_ownership ⇒ Object
The percent owned by the person of the account’s legal entity.
4178 4179 4180 |
# File 'lib/stripe/resources/account.rb', line 4178 def percent_ownership @percent_ownership end |
#title ⇒ Object
The person’s title (e.g., CEO, Support Engineer).
4180 4181 4182 |
# File 'lib/stripe/resources/account.rb', line 4180 def title @title end |