Class: Stripe::Account::CreateParams::Individual::Relationship
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::CreateParams::Individual::Relationship
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#director ⇒ Object
Whether the person is a director of the account’s legal entity.
-
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
-
#owner ⇒ Object
Whether the person is an owner of the account’s legal entity.
-
#percent_ownership ⇒ Object
The percent owned by the person of the account’s legal entity.
-
#title ⇒ Object
The person’s title (e.g., CEO, Support Engineer).
Instance Method Summary collapse
-
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
constructor
A new instance of Relationship.
Methods inherited from RequestParams
Constructor Details
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
Returns a new instance of Relationship.
4725 4726 4727 4728 4729 4730 4731 4732 4733 4734 4735 4736 4737 |
# File 'lib/stripe/resources/account.rb', line 4725 def initialize( director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil ) @director = director @executive = executive @owner = owner @percent_ownership = percent_ownership @title = title end |
Instance Attribute Details
#director ⇒ Object
Whether the person is a director of the account’s legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.
4715 4716 4717 |
# File 'lib/stripe/resources/account.rb', line 4715 def director @director end |
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
4717 4718 4719 |
# File 'lib/stripe/resources/account.rb', line 4717 def executive @executive end |
#owner ⇒ Object
Whether the person is an owner of the account’s legal entity.
4719 4720 4721 |
# File 'lib/stripe/resources/account.rb', line 4719 def owner @owner end |
#percent_ownership ⇒ Object
The percent owned by the person of the account’s legal entity.
4721 4722 4723 |
# File 'lib/stripe/resources/account.rb', line 4721 def percent_ownership @percent_ownership end |
#title ⇒ Object
The person’s title (e.g., CEO, Support Engineer).
4723 4724 4725 |
# File 'lib/stripe/resources/account.rb', line 4723 def title @title end |