Class: Stripe::Account::CreateParams::Individual::Relationship
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::CreateParams::Individual::Relationship
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#director ⇒ Object
Whether the person is a director of the account’s legal entity.
-
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
-
#owner ⇒ Object
Whether the person is an owner of the account’s legal entity.
-
#percent_ownership ⇒ Object
The percent owned by the person of the account’s legal entity.
-
#title ⇒ Object
The person’s title (e.g., CEO, Support Engineer).
Instance Method Summary collapse
-
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
constructor
A new instance of Relationship.
Methods inherited from RequestParams
Constructor Details
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
Returns a new instance of Relationship.
4676 4677 4678 4679 4680 4681 4682 4683 4684 4685 4686 4687 4688 |
# File 'lib/stripe/resources/account.rb', line 4676 def initialize( director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil ) @director = director @executive = executive @owner = owner @percent_ownership = percent_ownership @title = title end |
Instance Attribute Details
#director ⇒ Object
Whether the person is a director of the account’s legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.
4666 4667 4668 |
# File 'lib/stripe/resources/account.rb', line 4666 def director @director end |
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
4668 4669 4670 |
# File 'lib/stripe/resources/account.rb', line 4668 def executive @executive end |
#owner ⇒ Object
Whether the person is an owner of the account’s legal entity.
4670 4671 4672 |
# File 'lib/stripe/resources/account.rb', line 4670 def owner @owner end |
#percent_ownership ⇒ Object
The percent owned by the person of the account’s legal entity.
4672 4673 4674 |
# File 'lib/stripe/resources/account.rb', line 4672 def percent_ownership @percent_ownership end |
#title ⇒ Object
The person’s title (e.g., CEO, Support Engineer).
4674 4675 4676 |
# File 'lib/stripe/resources/account.rb', line 4674 def title @title end |