Class: Stripe::Account::CreateParams::Individual::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship

Returns a new instance of Relationship.



4666
4667
4668
4669
4670
4671
4672
4673
4674
4675
4676
4677
4678
# File 'lib/stripe/resources/account.rb', line 4666

def initialize(
  director: nil,
  executive: nil,
  owner: nil,
  percent_ownership: nil,
  title: nil
)
  @director = director
  @executive = executive
  @owner = owner
  @percent_ownership = percent_ownership
  @title = title
end

Instance Attribute Details

#directorObject

Whether the person is a director of the account’s legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



4656
4657
4658
# File 'lib/stripe/resources/account.rb', line 4656

def director
  @director
end

#executiveObject

Whether the person has significant responsibility to control, manage, or direct the organization.



4658
4659
4660
# File 'lib/stripe/resources/account.rb', line 4658

def executive
  @executive
end

#ownerObject

Whether the person is an owner of the account’s legal entity.



4660
4661
4662
# File 'lib/stripe/resources/account.rb', line 4660

def owner
  @owner
end

#percent_ownershipObject

The percent owned by the person of the account’s legal entity.



4662
4663
4664
# File 'lib/stripe/resources/account.rb', line 4662

def percent_ownership
  @percent_ownership
end

#titleObject

The person’s title (e.g., CEO, Support Engineer).



4664
4665
4666
# File 'lib/stripe/resources/account.rb', line 4664

def title
  @title
end