Class: Stripe::Account::CreateParams::Individual::Relationship
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::CreateParams::Individual::Relationship
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#director ⇒ Object
Whether the person is a director of the account’s legal entity.
-
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
-
#owner ⇒ Object
Whether the person is an owner of the account’s legal entity.
-
#percent_ownership ⇒ Object
The percent owned by the person of the account’s legal entity.
-
#title ⇒ Object
The person’s title (e.g., CEO, Support Engineer).
Instance Method Summary collapse
-
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
constructor
A new instance of Relationship.
Methods inherited from RequestParams
Constructor Details
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
Returns a new instance of Relationship.
4558 4559 4560 4561 4562 4563 4564 4565 4566 4567 4568 4569 4570 |
# File 'lib/stripe/resources/account.rb', line 4558 def initialize( director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil ) @director = director @executive = executive @owner = owner @percent_ownership = percent_ownership @title = title end |
Instance Attribute Details
#director ⇒ Object
Whether the person is a director of the account’s legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.
4548 4549 4550 |
# File 'lib/stripe/resources/account.rb', line 4548 def director @director end |
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
4550 4551 4552 |
# File 'lib/stripe/resources/account.rb', line 4550 def executive @executive end |
#owner ⇒ Object
Whether the person is an owner of the account’s legal entity.
4552 4553 4554 |
# File 'lib/stripe/resources/account.rb', line 4552 def owner @owner end |
#percent_ownership ⇒ Object
The percent owned by the person of the account’s legal entity.
4554 4555 4556 |
# File 'lib/stripe/resources/account.rb', line 4554 def percent_ownership @percent_ownership end |
#title ⇒ Object
The person’s title (e.g., CEO, Support Engineer).
4556 4557 4558 |
# File 'lib/stripe/resources/account.rb', line 4556 def title @title end |