Class: Stripe::Account::CreateParams::Individual::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship

Returns a new instance of Relationship.



4464
4465
4466
4467
4468
4469
4470
4471
4472
4473
4474
4475
4476
# File 'lib/stripe/resources/account.rb', line 4464

def initialize(
  director: nil,
  executive: nil,
  owner: nil,
  percent_ownership: nil,
  title: nil
)
  @director = director
  @executive = executive
  @owner = owner
  @percent_ownership = percent_ownership
  @title = title
end

Instance Attribute Details

#directorObject

Whether the person is a director of the account’s legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



4454
4455
4456
# File 'lib/stripe/resources/account.rb', line 4454

def director
  @director
end

#executiveObject

Whether the person has significant responsibility to control, manage, or direct the organization.



4456
4457
4458
# File 'lib/stripe/resources/account.rb', line 4456

def executive
  @executive
end

#ownerObject

Whether the person is an owner of the account’s legal entity.



4458
4459
4460
# File 'lib/stripe/resources/account.rb', line 4458

def owner
  @owner
end

#percent_ownershipObject

The percent owned by the person of the account’s legal entity.



4460
4461
4462
# File 'lib/stripe/resources/account.rb', line 4460

def percent_ownership
  @percent_ownership
end

#titleObject

The person’s title (e.g., CEO, Support Engineer).



4462
4463
4464
# File 'lib/stripe/resources/account.rb', line 4462

def title
  @title
end