Class: Stripe::Account::CreateParams::Individual::Relationship
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::CreateParams::Individual::Relationship
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#director ⇒ Object
Whether the person is a director of the account’s legal entity.
-
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
-
#owner ⇒ Object
Whether the person is an owner of the account’s legal entity.
-
#percent_ownership ⇒ Object
The percent owned by the person of the account’s legal entity.
-
#title ⇒ Object
The person’s title (e.g., CEO, Support Engineer).
Instance Method Summary collapse
-
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
constructor
A new instance of Relationship.
Methods inherited from RequestParams
Constructor Details
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
Returns a new instance of Relationship.
5076 5077 5078 5079 5080 5081 5082 5083 5084 5085 5086 5087 5088 |
# File 'lib/stripe/resources/account.rb', line 5076 def initialize( director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil ) @director = director @executive = executive @owner = owner @percent_ownership = percent_ownership @title = title end |
Instance Attribute Details
#director ⇒ Object
Whether the person is a director of the account’s legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.
5062 5063 5064 |
# File 'lib/stripe/resources/account.rb', line 5062 def director @director end |
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
5065 5066 5067 |
# File 'lib/stripe/resources/account.rb', line 5065 def executive @executive end |
#owner ⇒ Object
Whether the person is an owner of the account’s legal entity.
5068 5069 5070 |
# File 'lib/stripe/resources/account.rb', line 5068 def owner @owner end |
#percent_ownership ⇒ Object
The percent owned by the person of the account’s legal entity.
5071 5072 5073 |
# File 'lib/stripe/resources/account.rb', line 5071 def percent_ownership @percent_ownership end |
#title ⇒ Object
The person’s title (e.g., CEO, Support Engineer).
5074 5075 5076 |
# File 'lib/stripe/resources/account.rb', line 5074 def title @title end |