Class: Stripe::Account::CreateParams::Individual::Verification::Document
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::CreateParams::Individual::Verification::Document
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#back ⇒ Object
The back of an ID returned by a [file upload](stripe.com/docs/api#create_file) with a ‘purpose` value of `identity_document`.
-
#front ⇒ Object
The front of an ID returned by a [file upload](stripe.com/docs/api#create_file) with a ‘purpose` value of `identity_document`.
Instance Method Summary collapse
-
#initialize(back: nil, front: nil) ⇒ Document
constructor
A new instance of Document.
Methods inherited from RequestParams
Constructor Details
#initialize(back: nil, front: nil) ⇒ Document
Returns a new instance of Document.
5112 5113 5114 5115 |
# File 'lib/stripe/resources/account.rb', line 5112 def initialize(back: nil, front: nil) @back = back @front = front end |
Instance Attribute Details
#back ⇒ Object
The back of an ID returned by a [file upload](stripe.com/docs/api#create_file) with a ‘purpose` value of `identity_document`. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.
5107 5108 5109 |
# File 'lib/stripe/resources/account.rb', line 5107 def back @back end |
#front ⇒ Object
The front of an ID returned by a [file upload](stripe.com/docs/api#create_file) with a ‘purpose` value of `identity_document`. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.
5110 5111 5112 |
# File 'lib/stripe/resources/account.rb', line 5110 def front @front end |