Class: Stripe::Account::CreateParams::Settings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::CreateParams::Settings
- Defined in:
- lib/stripe/resources/account.rb
Defined Under Namespace
Classes: BacsDebitPayments, BankBcaOnboarding, Branding, Capital, CardIssuing, CardPayments, Invoices, Payments, Payouts, TaxForms, Treasury
Instance Attribute Summary collapse
-
#bacs_debit_payments ⇒ Object
Settings specific to Bacs Direct Debit.
-
#bank_bca_onboarding ⇒ Object
Settings specific to bank BCA onboarding for Indonesia bank transfers payments method.
-
#branding ⇒ Object
Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.
-
#capital ⇒ Object
Settings specific to the account’s use of the Capital product.
-
#card_issuing ⇒ Object
Settings specific to the account’s use of the Card Issuing product.
-
#card_payments ⇒ Object
Settings specific to card charging on the account.
-
#invoices ⇒ Object
Settings specific to the account’s use of Invoices.
-
#payments ⇒ Object
Settings that apply across payment methods for charging on the account.
-
#payouts ⇒ Object
Settings specific to the account’s payouts.
-
#tax_forms ⇒ Object
Settings specific to the account’s tax forms.
-
#treasury ⇒ Object
Settings specific to the account’s Treasury FinancialAccounts.
Instance Method Summary collapse
-
#initialize(bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, tax_forms: nil, treasury: nil) ⇒ Settings
constructor
A new instance of Settings.
Methods inherited from RequestParams
Constructor Details
#initialize(bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, tax_forms: nil, treasury: nil) ⇒ Settings
Returns a new instance of Settings.
5661 5662 5663 5664 5665 5666 5667 5668 5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 5683 5684 5685 |
# File 'lib/stripe/resources/account.rb', line 5661 def initialize( bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, tax_forms: nil, treasury: nil ) @bacs_debit_payments = bacs_debit_payments @bank_bca_onboarding = bank_bca_onboarding @branding = branding @capital = capital @card_issuing = card_issuing @card_payments = card_payments @invoices = invoices @payments = payments @payouts = payouts @tax_forms = tax_forms @treasury = treasury end |
Instance Attribute Details
#bacs_debit_payments ⇒ Object
Settings specific to Bacs Direct Debit.
5639 5640 5641 |
# File 'lib/stripe/resources/account.rb', line 5639 def bacs_debit_payments @bacs_debit_payments end |
#bank_bca_onboarding ⇒ Object
Settings specific to bank BCA onboarding for Indonesia bank transfers payments method.
5641 5642 5643 |
# File 'lib/stripe/resources/account.rb', line 5641 def bank_bca_onboarding @bank_bca_onboarding end |
#branding ⇒ Object
Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.
5643 5644 5645 |
# File 'lib/stripe/resources/account.rb', line 5643 def branding @branding end |
#capital ⇒ Object
Settings specific to the account’s use of the Capital product.
5645 5646 5647 |
# File 'lib/stripe/resources/account.rb', line 5645 def capital @capital end |
#card_issuing ⇒ Object
Settings specific to the account’s use of the Card Issuing product.
5647 5648 5649 |
# File 'lib/stripe/resources/account.rb', line 5647 def card_issuing @card_issuing end |
#card_payments ⇒ Object
Settings specific to card charging on the account.
5649 5650 5651 |
# File 'lib/stripe/resources/account.rb', line 5649 def card_payments @card_payments end |
#invoices ⇒ Object
Settings specific to the account’s use of Invoices.
5651 5652 5653 |
# File 'lib/stripe/resources/account.rb', line 5651 def invoices @invoices end |
#payments ⇒ Object
Settings that apply across payment methods for charging on the account.
5653 5654 5655 |
# File 'lib/stripe/resources/account.rb', line 5653 def payments @payments end |
#payouts ⇒ Object
Settings specific to the account’s payouts.
5655 5656 5657 |
# File 'lib/stripe/resources/account.rb', line 5655 def payouts @payouts end |
#tax_forms ⇒ Object
Settings specific to the account’s tax forms.
5657 5658 5659 |
# File 'lib/stripe/resources/account.rb', line 5657 def tax_forms @tax_forms end |
#treasury ⇒ Object
Settings specific to the account’s Treasury FinancialAccounts.
5659 5660 5661 |
# File 'lib/stripe/resources/account.rb', line 5659 def treasury @treasury end |