Class: Stripe::Account::CreateParams::Settings

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: BacsDebitPayments, BankBcaOnboarding, Branding, Capital, CardIssuing, CardPayments, Invoices, Payments, Payouts, TaxForms, Treasury

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, tax_forms: nil, treasury: nil) ⇒ Settings

Returns a new instance of Settings.



5237
5238
5239
5240
5241
5242
5243
5244
5245
5246
5247
5248
5249
5250
5251
5252
5253
5254
5255
5256
5257
5258
5259
5260
5261
# File 'lib/stripe/resources/account.rb', line 5237

def initialize(
  bacs_debit_payments: nil,
  bank_bca_onboarding: nil,
  branding: nil,
  capital: nil,
  card_issuing: nil,
  card_payments: nil,
  invoices: nil,
  payments: nil,
  payouts: nil,
  tax_forms: nil,
  treasury: nil
)
  @bacs_debit_payments = bacs_debit_payments
  @bank_bca_onboarding = bank_bca_onboarding
  @branding = branding
  @capital = capital
  @card_issuing = card_issuing
  @card_payments = card_payments
  @invoices = invoices
  @payments = payments
  @payouts = payouts
  @tax_forms = tax_forms
  @treasury = treasury
end

Instance Attribute Details

#bacs_debit_paymentsObject

Settings specific to Bacs Direct Debit.



5215
5216
5217
# File 'lib/stripe/resources/account.rb', line 5215

def bacs_debit_payments
  @bacs_debit_payments
end

#bank_bca_onboardingObject

Settings specific to bank BCA onboarding for Indonesia bank transfers payments method.



5217
5218
5219
# File 'lib/stripe/resources/account.rb', line 5217

def bank_bca_onboarding
  @bank_bca_onboarding
end

#brandingObject

Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.



5219
5220
5221
# File 'lib/stripe/resources/account.rb', line 5219

def branding
  @branding
end

#capitalObject

Settings specific to the account’s use of the Capital product.



5221
5222
5223
# File 'lib/stripe/resources/account.rb', line 5221

def capital
  @capital
end

#card_issuingObject

Settings specific to the account’s use of the Card Issuing product.



5223
5224
5225
# File 'lib/stripe/resources/account.rb', line 5223

def card_issuing
  @card_issuing
end

#card_paymentsObject

Settings specific to card charging on the account.



5225
5226
5227
# File 'lib/stripe/resources/account.rb', line 5225

def card_payments
  @card_payments
end

#invoicesObject

Settings specific to the account’s use of Invoices.



5227
5228
5229
# File 'lib/stripe/resources/account.rb', line 5227

def invoices
  @invoices
end

#paymentsObject

Settings that apply across payment methods for charging on the account.



5229
5230
5231
# File 'lib/stripe/resources/account.rb', line 5229

def payments
  @payments
end

#payoutsObject

Settings specific to the account’s payouts.



5231
5232
5233
# File 'lib/stripe/resources/account.rb', line 5231

def payouts
  @payouts
end

#tax_formsObject

Settings specific to the account’s tax forms.



5233
5234
5235
# File 'lib/stripe/resources/account.rb', line 5233

def tax_forms
  @tax_forms
end

#treasuryObject

Settings specific to the account’s Treasury FinancialAccounts.



5235
5236
5237
# File 'lib/stripe/resources/account.rb', line 5235

def treasury
  @treasury
end