Class: Stripe::Account::CreateParams::Settings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::CreateParams::Settings
- Defined in:
- lib/stripe/resources/account.rb
Defined Under Namespace
Classes: BacsDebitPayments, BankBcaOnboarding, Branding, Capital, CardIssuing, CardPayments, Invoices, Payments, Payouts, TaxForms, Treasury
Instance Attribute Summary collapse
-
#bacs_debit_payments ⇒ Object
Settings specific to Bacs Direct Debit.
-
#bank_bca_onboarding ⇒ Object
Settings specific to bank BCA onboarding for Indonesia bank transfers payments method.
-
#branding ⇒ Object
Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.
-
#capital ⇒ Object
Settings specific to the account’s use of the Capital product.
-
#card_issuing ⇒ Object
Settings specific to the account’s use of the Card Issuing product.
-
#card_payments ⇒ Object
Settings specific to card charging on the account.
-
#invoices ⇒ Object
Settings specific to the account’s use of Invoices.
-
#payments ⇒ Object
Settings that apply across payment methods for charging on the account.
-
#payouts ⇒ Object
Settings specific to the account’s payouts.
-
#tax_forms ⇒ Object
Settings specific to the account’s tax forms.
-
#treasury ⇒ Object
Settings specific to the account’s Treasury FinancialAccounts.
Instance Method Summary collapse
-
#initialize(bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, tax_forms: nil, treasury: nil) ⇒ Settings
constructor
A new instance of Settings.
Methods inherited from RequestParams
Constructor Details
#initialize(bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, tax_forms: nil, treasury: nil) ⇒ Settings
Returns a new instance of Settings.
5153 5154 5155 5156 5157 5158 5159 5160 5161 5162 5163 5164 5165 5166 5167 5168 5169 5170 5171 5172 5173 5174 5175 5176 5177 |
# File 'lib/stripe/resources/account.rb', line 5153 def initialize( bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, tax_forms: nil, treasury: nil ) @bacs_debit_payments = bacs_debit_payments @bank_bca_onboarding = bank_bca_onboarding @branding = branding @capital = capital @card_issuing = card_issuing @card_payments = card_payments @invoices = invoices @payments = payments @payouts = payouts @tax_forms = tax_forms @treasury = treasury end |
Instance Attribute Details
#bacs_debit_payments ⇒ Object
Settings specific to Bacs Direct Debit.
5131 5132 5133 |
# File 'lib/stripe/resources/account.rb', line 5131 def bacs_debit_payments @bacs_debit_payments end |
#bank_bca_onboarding ⇒ Object
Settings specific to bank BCA onboarding for Indonesia bank transfers payments method.
5133 5134 5135 |
# File 'lib/stripe/resources/account.rb', line 5133 def bank_bca_onboarding @bank_bca_onboarding end |
#branding ⇒ Object
Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.
5135 5136 5137 |
# File 'lib/stripe/resources/account.rb', line 5135 def branding @branding end |
#capital ⇒ Object
Settings specific to the account’s use of the Capital product.
5137 5138 5139 |
# File 'lib/stripe/resources/account.rb', line 5137 def capital @capital end |
#card_issuing ⇒ Object
Settings specific to the account’s use of the Card Issuing product.
5139 5140 5141 |
# File 'lib/stripe/resources/account.rb', line 5139 def card_issuing @card_issuing end |
#card_payments ⇒ Object
Settings specific to card charging on the account.
5141 5142 5143 |
# File 'lib/stripe/resources/account.rb', line 5141 def card_payments @card_payments end |
#invoices ⇒ Object
Settings specific to the account’s use of Invoices.
5143 5144 5145 |
# File 'lib/stripe/resources/account.rb', line 5143 def invoices @invoices end |
#payments ⇒ Object
Settings that apply across payment methods for charging on the account.
5145 5146 5147 |
# File 'lib/stripe/resources/account.rb', line 5145 def payments @payments end |
#payouts ⇒ Object
Settings specific to the account’s payouts.
5147 5148 5149 |
# File 'lib/stripe/resources/account.rb', line 5147 def payouts @payouts end |
#tax_forms ⇒ Object
Settings specific to the account’s tax forms.
5149 5150 5151 |
# File 'lib/stripe/resources/account.rb', line 5149 def tax_forms @tax_forms end |
#treasury ⇒ Object
Settings specific to the account’s Treasury FinancialAccounts.
5151 5152 5153 |
# File 'lib/stripe/resources/account.rb', line 5151 def treasury @treasury end |