Class: Stripe::Account::CreateParams::Settings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::CreateParams::Settings
- Defined in:
- lib/stripe/resources/account.rb
Defined Under Namespace
Classes: BacsDebitPayments, Branding, CardIssuing, CardPayments, Invoices, Payments, Payouts, Treasury
Instance Attribute Summary collapse
-
#bacs_debit_payments ⇒ Object
Settings specific to Bacs Direct Debit.
-
#branding ⇒ Object
Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.
-
#card_issuing ⇒ Object
Settings specific to the account’s use of the Card Issuing product.
-
#card_payments ⇒ Object
Settings specific to card charging on the account.
-
#invoices ⇒ Object
Settings specific to the account’s use of Invoices.
-
#payments ⇒ Object
Settings that apply across payment methods for charging on the account.
-
#payouts ⇒ Object
Settings specific to the account’s payouts.
-
#treasury ⇒ Object
Settings specific to the account’s Treasury FinancialAccounts.
Instance Method Summary collapse
-
#initialize(bacs_debit_payments: nil, branding: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, treasury: nil) ⇒ Settings
constructor
A new instance of Settings.
Methods inherited from RequestParams
Constructor Details
#initialize(bacs_debit_payments: nil, branding: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, treasury: nil) ⇒ Settings
Returns a new instance of Settings.
4486 4487 4488 4489 4490 4491 4492 4493 4494 4495 4496 4497 4498 4499 4500 4501 4502 4503 4504 |
# File 'lib/stripe/resources/account.rb', line 4486 def initialize( bacs_debit_payments: nil, branding: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, treasury: nil ) @bacs_debit_payments = bacs_debit_payments @branding = branding @card_issuing = card_issuing @card_payments = card_payments @invoices = invoices @payments = payments @payouts = payouts @treasury = treasury end |
Instance Attribute Details
#bacs_debit_payments ⇒ Object
Settings specific to Bacs Direct Debit.
4470 4471 4472 |
# File 'lib/stripe/resources/account.rb', line 4470 def bacs_debit_payments @bacs_debit_payments end |
#branding ⇒ Object
Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.
4472 4473 4474 |
# File 'lib/stripe/resources/account.rb', line 4472 def branding @branding end |
#card_issuing ⇒ Object
Settings specific to the account’s use of the Card Issuing product.
4474 4475 4476 |
# File 'lib/stripe/resources/account.rb', line 4474 def card_issuing @card_issuing end |
#card_payments ⇒ Object
Settings specific to card charging on the account.
4476 4477 4478 |
# File 'lib/stripe/resources/account.rb', line 4476 def card_payments @card_payments end |
#invoices ⇒ Object
Settings specific to the account’s use of Invoices.
4478 4479 4480 |
# File 'lib/stripe/resources/account.rb', line 4478 def invoices @invoices end |
#payments ⇒ Object
Settings that apply across payment methods for charging on the account.
4480 4481 4482 |
# File 'lib/stripe/resources/account.rb', line 4480 def payments @payments end |
#payouts ⇒ Object
Settings specific to the account’s payouts.
4482 4483 4484 |
# File 'lib/stripe/resources/account.rb', line 4482 def payouts @payouts end |
#treasury ⇒ Object
Settings specific to the account’s Treasury FinancialAccounts.
4484 4485 4486 |
# File 'lib/stripe/resources/account.rb', line 4484 def treasury @treasury end |