Class: Stripe::Account::CreateParams::Settings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::CreateParams::Settings
- Defined in:
- lib/stripe/resources/account.rb
Defined Under Namespace
Classes: BacsDebitPayments, BankBcaOnboarding, Branding, Capital, CardIssuing, CardPayments, Invoices, Payments, Payouts, TaxForms, Treasury
Instance Attribute Summary collapse
-
#bacs_debit_payments ⇒ Object
Settings specific to Bacs Direct Debit.
-
#bank_bca_onboarding ⇒ Object
Settings specific to bank BCA onboarding for Indonesia bank transfers payments method.
-
#branding ⇒ Object
Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.
-
#capital ⇒ Object
Settings specific to the account’s use of the Capital product.
-
#card_issuing ⇒ Object
Settings specific to the account’s use of the Card Issuing product.
-
#card_payments ⇒ Object
Settings specific to card charging on the account.
-
#invoices ⇒ Object
Settings specific to the account’s use of Invoices.
-
#payments ⇒ Object
Settings that apply across payment methods for charging on the account.
-
#payouts ⇒ Object
Settings specific to the account’s payouts.
-
#tax_forms ⇒ Object
Settings specific to the account’s tax forms.
-
#treasury ⇒ Object
Settings specific to the account’s Treasury FinancialAccounts.
Instance Method Summary collapse
-
#initialize(bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, tax_forms: nil, treasury: nil) ⇒ Settings
constructor
A new instance of Settings.
Methods inherited from RequestParams
Constructor Details
#initialize(bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, tax_forms: nil, treasury: nil) ⇒ Settings
Returns a new instance of Settings.
5126 5127 5128 5129 5130 5131 5132 5133 5134 5135 5136 5137 5138 5139 5140 5141 5142 5143 5144 5145 5146 5147 5148 5149 5150 |
# File 'lib/stripe/resources/account.rb', line 5126 def initialize( bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, tax_forms: nil, treasury: nil ) @bacs_debit_payments = bacs_debit_payments @bank_bca_onboarding = bank_bca_onboarding @branding = branding @capital = capital @card_issuing = card_issuing @card_payments = card_payments @invoices = invoices @payments = payments @payouts = payouts @tax_forms = tax_forms @treasury = treasury end |
Instance Attribute Details
#bacs_debit_payments ⇒ Object
Settings specific to Bacs Direct Debit.
5104 5105 5106 |
# File 'lib/stripe/resources/account.rb', line 5104 def bacs_debit_payments @bacs_debit_payments end |
#bank_bca_onboarding ⇒ Object
Settings specific to bank BCA onboarding for Indonesia bank transfers payments method.
5106 5107 5108 |
# File 'lib/stripe/resources/account.rb', line 5106 def bank_bca_onboarding @bank_bca_onboarding end |
#branding ⇒ Object
Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.
5108 5109 5110 |
# File 'lib/stripe/resources/account.rb', line 5108 def branding @branding end |
#capital ⇒ Object
Settings specific to the account’s use of the Capital product.
5110 5111 5112 |
# File 'lib/stripe/resources/account.rb', line 5110 def capital @capital end |
#card_issuing ⇒ Object
Settings specific to the account’s use of the Card Issuing product.
5112 5113 5114 |
# File 'lib/stripe/resources/account.rb', line 5112 def card_issuing @card_issuing end |
#card_payments ⇒ Object
Settings specific to card charging on the account.
5114 5115 5116 |
# File 'lib/stripe/resources/account.rb', line 5114 def card_payments @card_payments end |
#invoices ⇒ Object
Settings specific to the account’s use of Invoices.
5116 5117 5118 |
# File 'lib/stripe/resources/account.rb', line 5116 def invoices @invoices end |
#payments ⇒ Object
Settings that apply across payment methods for charging on the account.
5118 5119 5120 |
# File 'lib/stripe/resources/account.rb', line 5118 def payments @payments end |
#payouts ⇒ Object
Settings specific to the account’s payouts.
5120 5121 5122 |
# File 'lib/stripe/resources/account.rb', line 5120 def payouts @payouts end |
#tax_forms ⇒ Object
Settings specific to the account’s tax forms.
5122 5123 5124 |
# File 'lib/stripe/resources/account.rb', line 5122 def tax_forms @tax_forms end |
#treasury ⇒ Object
Settings specific to the account’s Treasury FinancialAccounts.
5124 5125 5126 |
# File 'lib/stripe/resources/account.rb', line 5124 def treasury @treasury end |