Class: Stripe::Account::CreateParams::Settings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::CreateParams::Settings
- Defined in:
- lib/stripe/resources/account.rb
Defined Under Namespace
Classes: BacsDebitPayments, BankBcaOnboarding, Branding, Capital, CardIssuing, CardPayments, Invoices, Payments, Payouts, TaxForms, Treasury
Instance Attribute Summary collapse
-
#bacs_debit_payments ⇒ Object
Settings specific to Bacs Direct Debit.
-
#bank_bca_onboarding ⇒ Object
Settings specific to bank BCA onboarding for Indonesia bank transfers payments method.
-
#branding ⇒ Object
Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.
-
#capital ⇒ Object
Settings specific to the account’s use of the Capital product.
-
#card_issuing ⇒ Object
Settings specific to the account’s use of the Card Issuing product.
-
#card_payments ⇒ Object
Settings specific to card charging on the account.
-
#invoices ⇒ Object
Settings specific to the account’s use of Invoices.
-
#payments ⇒ Object
Settings that apply across payment methods for charging on the account.
-
#payouts ⇒ Object
Settings specific to the account’s payouts.
-
#tax_forms ⇒ Object
Settings specific to the account’s tax forms.
-
#treasury ⇒ Object
Settings specific to the account’s Treasury FinancialAccounts.
Instance Method Summary collapse
-
#initialize(bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, tax_forms: nil, treasury: nil) ⇒ Settings
constructor
A new instance of Settings.
Methods inherited from RequestParams
Constructor Details
#initialize(bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, tax_forms: nil, treasury: nil) ⇒ Settings
Returns a new instance of Settings.
5077 5078 5079 5080 5081 5082 5083 5084 5085 5086 5087 5088 5089 5090 5091 5092 5093 5094 5095 5096 5097 5098 5099 5100 5101 |
# File 'lib/stripe/resources/account.rb', line 5077 def initialize( bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, tax_forms: nil, treasury: nil ) @bacs_debit_payments = bacs_debit_payments @bank_bca_onboarding = bank_bca_onboarding @branding = branding @capital = capital @card_issuing = card_issuing @card_payments = card_payments @invoices = invoices @payments = payments @payouts = payouts @tax_forms = tax_forms @treasury = treasury end |
Instance Attribute Details
#bacs_debit_payments ⇒ Object
Settings specific to Bacs Direct Debit.
5055 5056 5057 |
# File 'lib/stripe/resources/account.rb', line 5055 def bacs_debit_payments @bacs_debit_payments end |
#bank_bca_onboarding ⇒ Object
Settings specific to bank BCA onboarding for Indonesia bank transfers payments method.
5057 5058 5059 |
# File 'lib/stripe/resources/account.rb', line 5057 def bank_bca_onboarding @bank_bca_onboarding end |
#branding ⇒ Object
Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.
5059 5060 5061 |
# File 'lib/stripe/resources/account.rb', line 5059 def branding @branding end |
#capital ⇒ Object
Settings specific to the account’s use of the Capital product.
5061 5062 5063 |
# File 'lib/stripe/resources/account.rb', line 5061 def capital @capital end |
#card_issuing ⇒ Object
Settings specific to the account’s use of the Card Issuing product.
5063 5064 5065 |
# File 'lib/stripe/resources/account.rb', line 5063 def card_issuing @card_issuing end |
#card_payments ⇒ Object
Settings specific to card charging on the account.
5065 5066 5067 |
# File 'lib/stripe/resources/account.rb', line 5065 def card_payments @card_payments end |
#invoices ⇒ Object
Settings specific to the account’s use of Invoices.
5067 5068 5069 |
# File 'lib/stripe/resources/account.rb', line 5067 def invoices @invoices end |
#payments ⇒ Object
Settings that apply across payment methods for charging on the account.
5069 5070 5071 |
# File 'lib/stripe/resources/account.rb', line 5069 def payments @payments end |
#payouts ⇒ Object
Settings specific to the account’s payouts.
5071 5072 5073 |
# File 'lib/stripe/resources/account.rb', line 5071 def payouts @payouts end |
#tax_forms ⇒ Object
Settings specific to the account’s tax forms.
5073 5074 5075 |
# File 'lib/stripe/resources/account.rb', line 5073 def tax_forms @tax_forms end |
#treasury ⇒ Object
Settings specific to the account’s Treasury FinancialAccounts.
5075 5076 5077 |
# File 'lib/stripe/resources/account.rb', line 5075 def treasury @treasury end |