Class: Stripe::Account::CreateParams::Settings

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: BacsDebitPayments, BankBcaOnboarding, Branding, Capital, CardIssuing, CardPayments, Invoices, Payments, Payouts, TaxForms, Treasury

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, tax_forms: nil, treasury: nil) ⇒ Settings

Returns a new instance of Settings.



5067
5068
5069
5070
5071
5072
5073
5074
5075
5076
5077
5078
5079
5080
5081
5082
5083
5084
5085
5086
5087
5088
5089
5090
5091
# File 'lib/stripe/resources/account.rb', line 5067

def initialize(
  bacs_debit_payments: nil,
  bank_bca_onboarding: nil,
  branding: nil,
  capital: nil,
  card_issuing: nil,
  card_payments: nil,
  invoices: nil,
  payments: nil,
  payouts: nil,
  tax_forms: nil,
  treasury: nil
)
  @bacs_debit_payments = bacs_debit_payments
  @bank_bca_onboarding = bank_bca_onboarding
  @branding = branding
  @capital = capital
  @card_issuing = card_issuing
  @card_payments = card_payments
  @invoices = invoices
  @payments = payments
  @payouts = payouts
  @tax_forms = tax_forms
  @treasury = treasury
end

Instance Attribute Details

#bacs_debit_paymentsObject

Settings specific to Bacs Direct Debit.



5045
5046
5047
# File 'lib/stripe/resources/account.rb', line 5045

def bacs_debit_payments
  @bacs_debit_payments
end

#bank_bca_onboardingObject

Settings specific to bank BCA onboarding for Indonesia bank transfers payments method.



5047
5048
5049
# File 'lib/stripe/resources/account.rb', line 5047

def bank_bca_onboarding
  @bank_bca_onboarding
end

#brandingObject

Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.



5049
5050
5051
# File 'lib/stripe/resources/account.rb', line 5049

def branding
  @branding
end

#capitalObject

Settings specific to the account’s use of the Capital product.



5051
5052
5053
# File 'lib/stripe/resources/account.rb', line 5051

def capital
  @capital
end

#card_issuingObject

Settings specific to the account’s use of the Card Issuing product.



5053
5054
5055
# File 'lib/stripe/resources/account.rb', line 5053

def card_issuing
  @card_issuing
end

#card_paymentsObject

Settings specific to card charging on the account.



5055
5056
5057
# File 'lib/stripe/resources/account.rb', line 5055

def card_payments
  @card_payments
end

#invoicesObject

Settings specific to the account’s use of Invoices.



5057
5058
5059
# File 'lib/stripe/resources/account.rb', line 5057

def invoices
  @invoices
end

#paymentsObject

Settings that apply across payment methods for charging on the account.



5059
5060
5061
# File 'lib/stripe/resources/account.rb', line 5059

def payments
  @payments
end

#payoutsObject

Settings specific to the account’s payouts.



5061
5062
5063
# File 'lib/stripe/resources/account.rb', line 5061

def payouts
  @payouts
end

#tax_formsObject

Settings specific to the account’s tax forms.



5063
5064
5065
# File 'lib/stripe/resources/account.rb', line 5063

def tax_forms
  @tax_forms
end

#treasuryObject

Settings specific to the account’s Treasury FinancialAccounts.



5065
5066
5067
# File 'lib/stripe/resources/account.rb', line 5065

def treasury
  @treasury
end