Class: Stripe::Account::CreateParams::Settings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::CreateParams::Settings
- Defined in:
- lib/stripe/resources/account.rb
Defined Under Namespace
Classes: BacsDebitPayments, BankBcaOnboarding, Branding, Capital, CardIssuing, CardPayments, Payments, Payouts, TaxForms, Treasury
Instance Attribute Summary collapse
-
#bacs_debit_payments ⇒ Object
Settings specific to Bacs Direct Debit.
-
#bank_bca_onboarding ⇒ Object
Settings specific to bank BCA onboarding for Indonesia bank transfers payments method.
-
#branding ⇒ Object
Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.
-
#capital ⇒ Object
Settings specific to the account’s use of the Capital product.
-
#card_issuing ⇒ Object
Settings specific to the account’s use of the Card Issuing product.
-
#card_payments ⇒ Object
Settings specific to card charging on the account.
-
#payments ⇒ Object
Settings that apply across payment methods for charging on the account.
-
#payouts ⇒ Object
Settings specific to the account’s payouts.
-
#tax_forms ⇒ Object
Settings specific to the account’s tax forms.
-
#treasury ⇒ Object
Settings specific to the account’s Treasury FinancialAccounts.
Instance Method Summary collapse
-
#initialize(bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, payments: nil, payouts: nil, tax_forms: nil, treasury: nil) ⇒ Settings
constructor
A new instance of Settings.
Methods inherited from RequestParams
Constructor Details
#initialize(bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, payments: nil, payouts: nil, tax_forms: nil, treasury: nil) ⇒ Settings
Returns a new instance of Settings.
4948 4949 4950 4951 4952 4953 4954 4955 4956 4957 4958 4959 4960 4961 4962 4963 4964 4965 4966 4967 4968 4969 4970 |
# File 'lib/stripe/resources/account.rb', line 4948 def initialize( bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, payments: nil, payouts: nil, tax_forms: nil, treasury: nil ) @bacs_debit_payments = bacs_debit_payments @bank_bca_onboarding = bank_bca_onboarding @branding = branding @capital = capital @card_issuing = card_issuing @card_payments = card_payments @payments = payments @payouts = payouts @tax_forms = tax_forms @treasury = treasury end |
Instance Attribute Details
#bacs_debit_payments ⇒ Object
Settings specific to Bacs Direct Debit.
4928 4929 4930 |
# File 'lib/stripe/resources/account.rb', line 4928 def bacs_debit_payments @bacs_debit_payments end |
#bank_bca_onboarding ⇒ Object
Settings specific to bank BCA onboarding for Indonesia bank transfers payments method.
4930 4931 4932 |
# File 'lib/stripe/resources/account.rb', line 4930 def bank_bca_onboarding @bank_bca_onboarding end |
#branding ⇒ Object
Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.
4932 4933 4934 |
# File 'lib/stripe/resources/account.rb', line 4932 def branding @branding end |
#capital ⇒ Object
Settings specific to the account’s use of the Capital product.
4934 4935 4936 |
# File 'lib/stripe/resources/account.rb', line 4934 def capital @capital end |
#card_issuing ⇒ Object
Settings specific to the account’s use of the Card Issuing product.
4936 4937 4938 |
# File 'lib/stripe/resources/account.rb', line 4936 def card_issuing @card_issuing end |
#card_payments ⇒ Object
Settings specific to card charging on the account.
4938 4939 4940 |
# File 'lib/stripe/resources/account.rb', line 4938 def card_payments @card_payments end |
#payments ⇒ Object
Settings that apply across payment methods for charging on the account.
4940 4941 4942 |
# File 'lib/stripe/resources/account.rb', line 4940 def payments @payments end |
#payouts ⇒ Object
Settings specific to the account’s payouts.
4942 4943 4944 |
# File 'lib/stripe/resources/account.rb', line 4942 def payouts @payouts end |
#tax_forms ⇒ Object
Settings specific to the account’s tax forms.
4944 4945 4946 |
# File 'lib/stripe/resources/account.rb', line 4944 def tax_forms @tax_forms end |
#treasury ⇒ Object
Settings specific to the account’s Treasury FinancialAccounts.
4946 4947 4948 |
# File 'lib/stripe/resources/account.rb', line 4946 def treasury @treasury end |