Class: Stripe::Account::CreateParams::Settings

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: BacsDebitPayments, BankBcaOnboarding, Branding, Capital, CardIssuing, CardPayments, Payments, Payouts, TaxForms, Treasury

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, payments: nil, payouts: nil, tax_forms: nil, treasury: nil) ⇒ Settings

Returns a new instance of Settings.



5521
5522
5523
5524
5525
5526
5527
5528
5529
5530
5531
5532
5533
5534
5535
5536
5537
5538
5539
5540
5541
5542
5543
# File 'lib/stripe/resources/account.rb', line 5521

def initialize(
  bacs_debit_payments: nil,
  bank_bca_onboarding: nil,
  branding: nil,
  capital: nil,
  card_issuing: nil,
  card_payments: nil,
  payments: nil,
  payouts: nil,
  tax_forms: nil,
  treasury: nil
)
  @bacs_debit_payments = bacs_debit_payments
  @bank_bca_onboarding = bank_bca_onboarding
  @branding = branding
  @capital = capital
  @card_issuing = card_issuing
  @card_payments = card_payments
  @payments = payments
  @payouts = payouts
  @tax_forms = tax_forms
  @treasury = treasury
end

Instance Attribute Details

#bacs_debit_paymentsObject

Settings specific to Bacs Direct Debit.



5492
5493
5494
# File 'lib/stripe/resources/account.rb', line 5492

def bacs_debit_payments
  @bacs_debit_payments
end

#bank_bca_onboardingObject

Settings specific to bank BCA onboarding for Indonesia bank transfers payments method.



5495
5496
5497
# File 'lib/stripe/resources/account.rb', line 5495

def bank_bca_onboarding
  @bank_bca_onboarding
end

#brandingObject

Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.



5498
5499
5500
# File 'lib/stripe/resources/account.rb', line 5498

def branding
  @branding
end

#capitalObject

Settings specific to the account’s use of the Capital product.



5501
5502
5503
# File 'lib/stripe/resources/account.rb', line 5501

def capital
  @capital
end

#card_issuingObject

Settings specific to the account’s use of the Card Issuing product.



5504
5505
5506
# File 'lib/stripe/resources/account.rb', line 5504

def card_issuing
  @card_issuing
end

#card_paymentsObject

Settings specific to card charging on the account.



5507
5508
5509
# File 'lib/stripe/resources/account.rb', line 5507

def card_payments
  @card_payments
end

#paymentsObject

Settings that apply across payment methods for charging on the account.



5510
5511
5512
# File 'lib/stripe/resources/account.rb', line 5510

def payments
  @payments
end

#payoutsObject

Settings specific to the account’s payouts.



5513
5514
5515
# File 'lib/stripe/resources/account.rb', line 5513

def payouts
  @payouts
end

#tax_formsObject

Settings specific to the account’s tax forms.



5516
5517
5518
# File 'lib/stripe/resources/account.rb', line 5516

def tax_forms
  @tax_forms
end

#treasuryObject

Settings specific to the account’s Treasury FinancialAccounts.



5519
5520
5521
# File 'lib/stripe/resources/account.rb', line 5519

def treasury
  @treasury
end