Class: Stripe::Account::CreateParams::Settings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::CreateParams::Settings
- Defined in:
- lib/stripe/resources/account.rb
Defined Under Namespace
Classes: BacsDebitPayments, BankBcaOnboarding, Branding, Capital, CardIssuing, CardPayments, Payments, Payouts, TaxForms, Treasury
Instance Attribute Summary collapse
-
#bacs_debit_payments ⇒ Object
Settings specific to Bacs Direct Debit.
-
#bank_bca_onboarding ⇒ Object
Settings specific to bank BCA onboarding for Indonesia bank transfers payments method.
-
#branding ⇒ Object
Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.
-
#capital ⇒ Object
Settings specific to the account’s use of the Capital product.
-
#card_issuing ⇒ Object
Settings specific to the account’s use of the Card Issuing product.
-
#card_payments ⇒ Object
Settings specific to card charging on the account.
-
#payments ⇒ Object
Settings that apply across payment methods for charging on the account.
-
#payouts ⇒ Object
Settings specific to the account’s payouts.
-
#tax_forms ⇒ Object
Settings specific to the account’s tax forms.
-
#treasury ⇒ Object
Settings specific to the account’s Treasury FinancialAccounts.
Instance Method Summary collapse
-
#initialize(bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, payments: nil, payouts: nil, tax_forms: nil, treasury: nil) ⇒ Settings
constructor
A new instance of Settings.
Methods inherited from RequestParams
Constructor Details
#initialize(bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, payments: nil, payouts: nil, tax_forms: nil, treasury: nil) ⇒ Settings
Returns a new instance of Settings.
4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 4867 4868 4869 4870 4871 4872 4873 4874 4875 4876 |
# File 'lib/stripe/resources/account.rb', line 4854 def initialize( bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, payments: nil, payouts: nil, tax_forms: nil, treasury: nil ) @bacs_debit_payments = bacs_debit_payments @bank_bca_onboarding = bank_bca_onboarding @branding = branding @capital = capital @card_issuing = card_issuing @card_payments = card_payments @payments = payments @payouts = payouts @tax_forms = tax_forms @treasury = treasury end |
Instance Attribute Details
#bacs_debit_payments ⇒ Object
Settings specific to Bacs Direct Debit.
4834 4835 4836 |
# File 'lib/stripe/resources/account.rb', line 4834 def bacs_debit_payments @bacs_debit_payments end |
#bank_bca_onboarding ⇒ Object
Settings specific to bank BCA onboarding for Indonesia bank transfers payments method.
4836 4837 4838 |
# File 'lib/stripe/resources/account.rb', line 4836 def bank_bca_onboarding @bank_bca_onboarding end |
#branding ⇒ Object
Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.
4838 4839 4840 |
# File 'lib/stripe/resources/account.rb', line 4838 def branding @branding end |
#capital ⇒ Object
Settings specific to the account’s use of the Capital product.
4840 4841 4842 |
# File 'lib/stripe/resources/account.rb', line 4840 def capital @capital end |
#card_issuing ⇒ Object
Settings specific to the account’s use of the Card Issuing product.
4842 4843 4844 |
# File 'lib/stripe/resources/account.rb', line 4842 def card_issuing @card_issuing end |
#card_payments ⇒ Object
Settings specific to card charging on the account.
4844 4845 4846 |
# File 'lib/stripe/resources/account.rb', line 4844 def card_payments @card_payments end |
#payments ⇒ Object
Settings that apply across payment methods for charging on the account.
4846 4847 4848 |
# File 'lib/stripe/resources/account.rb', line 4846 def payments @payments end |
#payouts ⇒ Object
Settings specific to the account’s payouts.
4848 4849 4850 |
# File 'lib/stripe/resources/account.rb', line 4848 def payouts @payouts end |
#tax_forms ⇒ Object
Settings specific to the account’s tax forms.
4850 4851 4852 |
# File 'lib/stripe/resources/account.rb', line 4850 def tax_forms @tax_forms end |
#treasury ⇒ Object
Settings specific to the account’s Treasury FinancialAccounts.
4852 4853 4854 |
# File 'lib/stripe/resources/account.rb', line 4852 def treasury @treasury end |