Class: Stripe::Account::CreateParams::Settings::Branding

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil) ⇒ Branding

Returns a new instance of Branding.



4962
4963
4964
4965
4966
4967
# File 'lib/stripe/resources/account.rb', line 4962

def initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil)
  @icon = icon
  @logo = 
  @primary_color = primary_color
  @secondary_color = secondary_color
end

Instance Attribute Details

#iconObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) An icon for the account. Must be square and at least 128px x 128px.



4954
4955
4956
# File 'lib/stripe/resources/account.rb', line 4954

def icon
  @icon
end

#logoObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) A logo for the account that will be used in Checkout instead of the icon and without the account’s name next to it if provided. Must be at least 128px x 128px.



4956
4957
4958
# File 'lib/stripe/resources/account.rb', line 4956

def 
  @logo
end

#primary_colorObject

A CSS hex color value representing the primary branding color for this account.



4958
4959
4960
# File 'lib/stripe/resources/account.rb', line 4958

def primary_color
  @primary_color
end

#secondary_colorObject

A CSS hex color value representing the secondary branding color for this account.



4960
4961
4962
# File 'lib/stripe/resources/account.rb', line 4960

def secondary_color
  @secondary_color
end