Class: Stripe::Account::CreateParams::Settings::Branding

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil) ⇒ Branding

Returns a new instance of Branding.



4349
4350
4351
4352
4353
4354
# File 'lib/stripe/resources/account.rb', line 4349

def initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil)
  @icon = icon
  @logo = 
  @primary_color = primary_color
  @secondary_color = secondary_color
end

Instance Attribute Details

#iconObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) An icon for the account. Must be square and at least 128px x 128px.



4341
4342
4343
# File 'lib/stripe/resources/account.rb', line 4341

def icon
  @icon
end

#logoObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) A logo for the account that will be used in Checkout instead of the icon and without the account’s name next to it if provided. Must be at least 128px x 128px.



4343
4344
4345
# File 'lib/stripe/resources/account.rb', line 4343

def 
  @logo
end

#primary_colorObject

A CSS hex color value representing the primary branding color for this account.



4345
4346
4347
# File 'lib/stripe/resources/account.rb', line 4345

def primary_color
  @primary_color
end

#secondary_colorObject

A CSS hex color value representing the secondary branding color for this account.



4347
4348
4349
# File 'lib/stripe/resources/account.rb', line 4347

def secondary_color
  @secondary_color
end