Class: Stripe::Account::CreateParams::Settings::Branding

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil) ⇒ Branding

Returns a new instance of Branding.



4322
4323
4324
4325
4326
4327
# File 'lib/stripe/resources/account.rb', line 4322

def initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil)
  @icon = icon
  @logo = 
  @primary_color = primary_color
  @secondary_color = secondary_color
end

Instance Attribute Details

#iconObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) An icon for the account. Must be square and at least 128px x 128px.



4314
4315
4316
# File 'lib/stripe/resources/account.rb', line 4314

def icon
  @icon
end

#logoObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) A logo for the account that will be used in Checkout instead of the icon and without the account’s name next to it if provided. Must be at least 128px x 128px.



4316
4317
4318
# File 'lib/stripe/resources/account.rb', line 4316

def 
  @logo
end

#primary_colorObject

A CSS hex color value representing the primary branding color for this account.



4318
4319
4320
# File 'lib/stripe/resources/account.rb', line 4318

def primary_color
  @primary_color
end

#secondary_colorObject

A CSS hex color value representing the secondary branding color for this account.



4320
4321
4322
# File 'lib/stripe/resources/account.rb', line 4320

def secondary_color
  @secondary_color
end