Class: Stripe::Account::CreateParams::Settings::Branding

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil) ⇒ Branding

Returns a new instance of Branding.



4886
4887
4888
4889
4890
4891
# File 'lib/stripe/resources/account.rb', line 4886

def initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil)
  @icon = icon
  @logo = 
  @primary_color = primary_color
  @secondary_color = secondary_color
end

Instance Attribute Details

#iconObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) An icon for the account. Must be square and at least 128px x 128px.



4878
4879
4880
# File 'lib/stripe/resources/account.rb', line 4878

def icon
  @icon
end

#logoObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) A logo for the account that will be used in Checkout instead of the icon and without the account’s name next to it if provided. Must be at least 128px x 128px.



4880
4881
4882
# File 'lib/stripe/resources/account.rb', line 4880

def 
  @logo
end

#primary_colorObject

A CSS hex color value representing the primary branding color for this account.



4882
4883
4884
# File 'lib/stripe/resources/account.rb', line 4882

def primary_color
  @primary_color
end

#secondary_colorObject

A CSS hex color value representing the secondary branding color for this account.



4884
4885
4886
# File 'lib/stripe/resources/account.rb', line 4884

def secondary_color
  @secondary_color
end