Class: Stripe::Account::CreateParams::Settings::Branding

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil) ⇒ Branding

Returns a new instance of Branding.



4768
4769
4770
4771
4772
4773
# File 'lib/stripe/resources/account.rb', line 4768

def initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil)
  @icon = icon
  @logo = 
  @primary_color = primary_color
  @secondary_color = secondary_color
end

Instance Attribute Details

#iconObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) An icon for the account. Must be square and at least 128px x 128px.



4760
4761
4762
# File 'lib/stripe/resources/account.rb', line 4760

def icon
  @icon
end

#logoObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) A logo for the account that will be used in Checkout instead of the icon and without the account’s name next to it if provided. Must be at least 128px x 128px.



4762
4763
4764
# File 'lib/stripe/resources/account.rb', line 4762

def 
  @logo
end

#primary_colorObject

A CSS hex color value representing the primary branding color for this account.



4764
4765
4766
# File 'lib/stripe/resources/account.rb', line 4764

def primary_color
  @primary_color
end

#secondary_colorObject

A CSS hex color value representing the secondary branding color for this account.



4766
4767
4768
# File 'lib/stripe/resources/account.rb', line 4766

def secondary_color
  @secondary_color
end