Class: Stripe::Account::CreateParams::Settings::Branding

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil) ⇒ Branding

Returns a new instance of Branding.



5316
5317
5318
5319
5320
5321
# File 'lib/stripe/resources/account.rb', line 5316

def initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil)
  @icon = icon
  @logo = 
  @primary_color = primary_color
  @secondary_color = secondary_color
end

Instance Attribute Details

#iconObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) An icon for the account. Must be square and at least 128px x 128px.



5305
5306
5307
# File 'lib/stripe/resources/account.rb', line 5305

def icon
  @icon
end

#logoObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) A logo for the account that will be used in Checkout instead of the icon and without the account’s name next to it if provided. Must be at least 128px x 128px.



5308
5309
5310
# File 'lib/stripe/resources/account.rb', line 5308

def 
  @logo
end

#primary_colorObject

A CSS hex color value representing the primary branding color for this account.



5311
5312
5313
# File 'lib/stripe/resources/account.rb', line 5311

def primary_color
  @primary_color
end

#secondary_colorObject

A CSS hex color value representing the secondary branding color for this account.



5314
5315
5316
# File 'lib/stripe/resources/account.rb', line 5314

def secondary_color
  @secondary_color
end