Class: Stripe::Account::CreateParams::Settings::CardIssuing::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



5062
5063
5064
5065
5066
# File 'lib/stripe/resources/account.rb', line 5062

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



5056
5057
5058
# File 'lib/stripe/resources/account.rb', line 5056

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



5058
5059
5060
# File 'lib/stripe/resources/account.rb', line 5058

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



5060
5061
5062
# File 'lib/stripe/resources/account.rb', line 5060

def user_agent
  @user_agent
end