Class: Stripe::Account::CreateParams::Settings::CardIssuing::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



4991
4992
4993
4994
4995
# File 'lib/stripe/resources/account.rb', line 4991

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



4985
4986
4987
# File 'lib/stripe/resources/account.rb', line 4985

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



4987
4988
4989
# File 'lib/stripe/resources/account.rb', line 4987

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



4989
4990
4991
# File 'lib/stripe/resources/account.rb', line 4989

def user_agent
  @user_agent
end