Class: Stripe::Account::CreateParams::Settings::CardIssuing::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



4339
4340
4341
4342
4343
# File 'lib/stripe/resources/account.rb', line 4339

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



4333
4334
4335
# File 'lib/stripe/resources/account.rb', line 4333

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



4335
4336
4337
# File 'lib/stripe/resources/account.rb', line 4335

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



4337
4338
4339
# File 'lib/stripe/resources/account.rb', line 4337

def user_agent
  @user_agent
end