Class: Stripe::Account::CreateParams::Settings::CardIssuing::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



5348
5349
5350
5351
5352
# File 'lib/stripe/resources/account.rb', line 5348

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



5340
5341
5342
# File 'lib/stripe/resources/account.rb', line 5340

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



5343
5344
5345
# File 'lib/stripe/resources/account.rb', line 5343

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



5346
5347
5348
# File 'lib/stripe/resources/account.rb', line 5346

def user_agent
  @user_agent
end