Class: Stripe::Account::CreateParams::Settings::CardIssuing::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



4703
4704
4705
4706
4707
# File 'lib/stripe/resources/account.rb', line 4703

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



4697
4698
4699
# File 'lib/stripe/resources/account.rb', line 4697

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



4699
4700
4701
# File 'lib/stripe/resources/account.rb', line 4699

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



4701
4702
4703
# File 'lib/stripe/resources/account.rb', line 4701

def user_agent
  @user_agent
end