Class: Stripe::Account::CreateParams::Settings::CardIssuing::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



4795
4796
4797
4798
4799
# File 'lib/stripe/resources/account.rb', line 4795

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



4789
4790
4791
# File 'lib/stripe/resources/account.rb', line 4789

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



4791
4792
4793
# File 'lib/stripe/resources/account.rb', line 4791

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



4793
4794
4795
# File 'lib/stripe/resources/account.rb', line 4793

def user_agent
  @user_agent
end