Class: Stripe::Account::CreateParams::Settings::CardPayments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::CreateParams::Settings::CardPayments
- Defined in:
- lib/stripe/resources/account.rb
Defined Under Namespace
Classes: DeclineOn
Instance Attribute Summary collapse
-
#decline_on ⇒ Object
Automatically declines certain charge types regardless of whether the card issuer accepted or declined the charge.
-
#statement_descriptor_prefix ⇒ Object
The default text that appears on credit card statements when a charge is made.
-
#statement_descriptor_prefix_kana ⇒ Object
The Kana variation of the default text that appears on credit card statements when a charge is made (Japan only).
-
#statement_descriptor_prefix_kanji ⇒ Object
The Kanji variation of the default text that appears on credit card statements when a charge is made (Japan only).
Instance Method Summary collapse
-
#initialize(decline_on: nil, statement_descriptor_prefix: nil, statement_descriptor_prefix_kana: nil, statement_descriptor_prefix_kanji: nil) ⇒ CardPayments
constructor
A new instance of CardPayments.
Methods inherited from RequestParams
Constructor Details
#initialize(decline_on: nil, statement_descriptor_prefix: nil, statement_descriptor_prefix_kana: nil, statement_descriptor_prefix_kanji: nil) ⇒ CardPayments
Returns a new instance of CardPayments.
5026 5027 5028 5029 5030 5031 5032 5033 5034 5035 5036 |
# File 'lib/stripe/resources/account.rb', line 5026 def initialize( decline_on: nil, statement_descriptor_prefix: nil, statement_descriptor_prefix_kana: nil, statement_descriptor_prefix_kanji: nil ) @decline_on = decline_on @statement_descriptor_prefix = statement_descriptor_prefix @statement_descriptor_prefix_kana = statement_descriptor_prefix_kana @statement_descriptor_prefix_kanji = statement_descriptor_prefix_kanji end |
Instance Attribute Details
#decline_on ⇒ Object
Automatically declines certain charge types regardless of whether the card issuer accepted or declined the charge.
5018 5019 5020 |
# File 'lib/stripe/resources/account.rb', line 5018 def decline_on @decline_on end |
#statement_descriptor_prefix ⇒ Object
The default text that appears on credit card statements when a charge is made. This field prefixes any dynamic ‘statement_descriptor` specified on the charge. `statement_descriptor_prefix` is useful for maximizing descriptor space for the dynamic portion.
5020 5021 5022 |
# File 'lib/stripe/resources/account.rb', line 5020 def statement_descriptor_prefix @statement_descriptor_prefix end |
#statement_descriptor_prefix_kana ⇒ Object
The Kana variation of the default text that appears on credit card statements when a charge is made (Japan only). This field prefixes any dynamic ‘statement_descriptor_suffix_kana` specified on the charge. `statement_descriptor_prefix_kana` is useful for maximizing descriptor space for the dynamic portion.
5022 5023 5024 |
# File 'lib/stripe/resources/account.rb', line 5022 def statement_descriptor_prefix_kana @statement_descriptor_prefix_kana end |
#statement_descriptor_prefix_kanji ⇒ Object
The Kanji variation of the default text that appears on credit card statements when a charge is made (Japan only). This field prefixes any dynamic ‘statement_descriptor_suffix_kanji` specified on the charge. `statement_descriptor_prefix_kanji` is useful for maximizing descriptor space for the dynamic portion.
5024 5025 5026 |
# File 'lib/stripe/resources/account.rb', line 5024 def statement_descriptor_prefix_kanji @statement_descriptor_prefix_kanji end |