Class: Stripe::Account::CreateParams::Settings::CardPayments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::CreateParams::Settings::CardPayments
- Defined in:
- lib/stripe/resources/account.rb
Defined Under Namespace
Classes: DeclineOn
Instance Attribute Summary collapse
-
#decline_on ⇒ Object
Automatically declines certain charge types regardless of whether the card issuer accepted or declined the charge.
-
#statement_descriptor_prefix ⇒ Object
The default text that appears on credit card statements when a charge is made.
-
#statement_descriptor_prefix_kana ⇒ Object
The Kana variation of the default text that appears on credit card statements when a charge is made (Japan only).
-
#statement_descriptor_prefix_kanji ⇒ Object
The Kanji variation of the default text that appears on credit card statements when a charge is made (Japan only).
Instance Method Summary collapse
-
#initialize(decline_on: nil, statement_descriptor_prefix: nil, statement_descriptor_prefix_kana: nil, statement_descriptor_prefix_kanji: nil) ⇒ CardPayments
constructor
A new instance of CardPayments.
Methods inherited from RequestParams
Constructor Details
#initialize(decline_on: nil, statement_descriptor_prefix: nil, statement_descriptor_prefix_kana: nil, statement_descriptor_prefix_kanji: nil) ⇒ CardPayments
Returns a new instance of CardPayments.
4999 5000 5001 5002 5003 5004 5005 5006 5007 5008 5009 |
# File 'lib/stripe/resources/account.rb', line 4999 def initialize( decline_on: nil, statement_descriptor_prefix: nil, statement_descriptor_prefix_kana: nil, statement_descriptor_prefix_kanji: nil ) @decline_on = decline_on @statement_descriptor_prefix = statement_descriptor_prefix @statement_descriptor_prefix_kana = statement_descriptor_prefix_kana @statement_descriptor_prefix_kanji = statement_descriptor_prefix_kanji end |
Instance Attribute Details
#decline_on ⇒ Object
Automatically declines certain charge types regardless of whether the card issuer accepted or declined the charge.
4991 4992 4993 |
# File 'lib/stripe/resources/account.rb', line 4991 def decline_on @decline_on end |
#statement_descriptor_prefix ⇒ Object
The default text that appears on credit card statements when a charge is made. This field prefixes any dynamic ‘statement_descriptor` specified on the charge. `statement_descriptor_prefix` is useful for maximizing descriptor space for the dynamic portion.
4993 4994 4995 |
# File 'lib/stripe/resources/account.rb', line 4993 def statement_descriptor_prefix @statement_descriptor_prefix end |
#statement_descriptor_prefix_kana ⇒ Object
The Kana variation of the default text that appears on credit card statements when a charge is made (Japan only). This field prefixes any dynamic ‘statement_descriptor_suffix_kana` specified on the charge. `statement_descriptor_prefix_kana` is useful for maximizing descriptor space for the dynamic portion.
4995 4996 4997 |
# File 'lib/stripe/resources/account.rb', line 4995 def statement_descriptor_prefix_kana @statement_descriptor_prefix_kana end |
#statement_descriptor_prefix_kanji ⇒ Object
The Kanji variation of the default text that appears on credit card statements when a charge is made (Japan only). This field prefixes any dynamic ‘statement_descriptor_suffix_kanji` specified on the charge. `statement_descriptor_prefix_kanji` is useful for maximizing descriptor space for the dynamic portion.
4997 4998 4999 |
# File 'lib/stripe/resources/account.rb', line 4997 def statement_descriptor_prefix_kanji @statement_descriptor_prefix_kanji end |