Class: Stripe::Account::CreateParams::Settings::CardPayments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: DeclineOn

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(decline_on: nil, statement_descriptor_prefix: nil, statement_descriptor_prefix_kana: nil, statement_descriptor_prefix_kanji: nil) ⇒ CardPayments

Returns a new instance of CardPayments.



4830
4831
4832
4833
4834
4835
4836
4837
4838
4839
4840
# File 'lib/stripe/resources/account.rb', line 4830

def initialize(
  decline_on: nil,
  statement_descriptor_prefix: nil,
  statement_descriptor_prefix_kana: nil,
  statement_descriptor_prefix_kanji: nil
)
  @decline_on = decline_on
  @statement_descriptor_prefix = statement_descriptor_prefix
  @statement_descriptor_prefix_kana = statement_descriptor_prefix_kana
  @statement_descriptor_prefix_kanji = statement_descriptor_prefix_kanji
end

Instance Attribute Details

#decline_onObject

Automatically declines certain charge types regardless of whether the card issuer accepted or declined the charge.



4822
4823
4824
# File 'lib/stripe/resources/account.rb', line 4822

def decline_on
  @decline_on
end

#statement_descriptor_prefixObject

The default text that appears on credit card statements when a charge is made. This field prefixes any dynamic ‘statement_descriptor` specified on the charge. `statement_descriptor_prefix` is useful for maximizing descriptor space for the dynamic portion.



4824
4825
4826
# File 'lib/stripe/resources/account.rb', line 4824

def statement_descriptor_prefix
  @statement_descriptor_prefix
end

#statement_descriptor_prefix_kanaObject

The Kana variation of the default text that appears on credit card statements when a charge is made (Japan only). This field prefixes any dynamic ‘statement_descriptor_suffix_kana` specified on the charge. `statement_descriptor_prefix_kana` is useful for maximizing descriptor space for the dynamic portion.



4826
4827
4828
# File 'lib/stripe/resources/account.rb', line 4826

def statement_descriptor_prefix_kana
  @statement_descriptor_prefix_kana
end

#statement_descriptor_prefix_kanjiObject

The Kanji variation of the default text that appears on credit card statements when a charge is made (Japan only). This field prefixes any dynamic ‘statement_descriptor_suffix_kanji` specified on the charge. `statement_descriptor_prefix_kanji` is useful for maximizing descriptor space for the dynamic portion.



4828
4829
4830
# File 'lib/stripe/resources/account.rb', line 4828

def statement_descriptor_prefix_kanji
  @statement_descriptor_prefix_kanji
end