Class: Stripe::Account::CreateParams::Settings::CardPayments::DeclineOn
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::CreateParams::Settings::CardPayments::DeclineOn
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#avs_failure ⇒ Object
Whether Stripe automatically declines charges with an incorrect ZIP or postal code.
-
#cvc_failure ⇒ Object
Whether Stripe automatically declines charges with an incorrect CVC.
Instance Method Summary collapse
-
#initialize(avs_failure: nil, cvc_failure: nil) ⇒ DeclineOn
constructor
A new instance of DeclineOn.
Methods inherited from RequestParams
Constructor Details
#initialize(avs_failure: nil, cvc_failure: nil) ⇒ DeclineOn
Returns a new instance of DeclineOn.
4985 4986 4987 4988 |
# File 'lib/stripe/resources/account.rb', line 4985 def initialize(avs_failure: nil, cvc_failure: nil) @avs_failure = avs_failure @cvc_failure = cvc_failure end |
Instance Attribute Details
#avs_failure ⇒ Object
Whether Stripe automatically declines charges with an incorrect ZIP or postal code. This setting only applies when a ZIP or postal code is provided and they fail bank verification.
4981 4982 4983 |
# File 'lib/stripe/resources/account.rb', line 4981 def avs_failure @avs_failure end |
#cvc_failure ⇒ Object
Whether Stripe automatically declines charges with an incorrect CVC. This setting only applies when a CVC is provided and it fails bank verification.
4983 4984 4985 |
# File 'lib/stripe/resources/account.rb', line 4983 def cvc_failure @cvc_failure end |