Class: Stripe::Account::CreateParams::Settings::CardPayments::DeclineOn

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(avs_failure: nil, cvc_failure: nil) ⇒ DeclineOn

Returns a new instance of DeclineOn.



5370
5371
5372
5373
# File 'lib/stripe/resources/account.rb', line 5370

def initialize(avs_failure: nil, cvc_failure: nil)
  @avs_failure = avs_failure
  @cvc_failure = cvc_failure
end

Instance Attribute Details

#avs_failureObject

Whether Stripe automatically declines charges with an incorrect ZIP or postal code. This setting only applies when a ZIP or postal code is provided and they fail bank verification.



5365
5366
5367
# File 'lib/stripe/resources/account.rb', line 5365

def avs_failure
  @avs_failure
end

#cvc_failureObject

Whether Stripe automatically declines charges with an incorrect CVC. This setting only applies when a CVC is provided and it fails bank verification.



5368
5369
5370
# File 'lib/stripe/resources/account.rb', line 5368

def cvc_failure
  @cvc_failure
end