Class: Stripe::Account::CreateParams::Settings::Payments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::CreateParams::Settings::Payments
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#statement_descriptor ⇒ Object
The default text that appears on statements for non-card charges outside of Japan.
-
#statement_descriptor_kana ⇒ Object
The Kana variation of ‘statement_descriptor` used for charges in Japan.
-
#statement_descriptor_kanji ⇒ Object
The Kanji variation of ‘statement_descriptor` used for charges in Japan.
Instance Method Summary collapse
-
#initialize(statement_descriptor: nil, statement_descriptor_kana: nil, statement_descriptor_kanji: nil) ⇒ Payments
constructor
A new instance of Payments.
Methods inherited from RequestParams
Constructor Details
#initialize(statement_descriptor: nil, statement_descriptor_kana: nil, statement_descriptor_kanji: nil) ⇒ Payments
Returns a new instance of Payments.
5410 5411 5412 5413 5414 5415 5416 5417 5418 |
# File 'lib/stripe/resources/account.rb', line 5410 def initialize( statement_descriptor: nil, statement_descriptor_kana: nil, statement_descriptor_kanji: nil ) @statement_descriptor = statement_descriptor @statement_descriptor_kana = statement_descriptor_kana @statement_descriptor_kanji = statement_descriptor_kanji end |
Instance Attribute Details
#statement_descriptor ⇒ Object
The default text that appears on statements for non-card charges outside of Japan. For card charges, if you don’t set a ‘statement_descriptor_prefix`, this text is also used as the statement descriptor prefix. In that case, if concatenating the statement descriptor suffix causes the combined statement descriptor to exceed 22 characters, we truncate the `statement_descriptor` text to limit the full descriptor to 22 characters. For more information about statement descriptors and their requirements, see the [account settings documentation](docs.stripe.com/get-started/account/statement-descriptors).
5402 5403 5404 |
# File 'lib/stripe/resources/account.rb', line 5402 def statement_descriptor @statement_descriptor end |
#statement_descriptor_kana ⇒ Object
The Kana variation of ‘statement_descriptor` used for charges in Japan. Japanese statement descriptors have [special requirements](docs.stripe.com/get-started/account/statement-descriptors#set-japanese-statement-descriptors).
5405 5406 5407 |
# File 'lib/stripe/resources/account.rb', line 5405 def statement_descriptor_kana @statement_descriptor_kana end |
#statement_descriptor_kanji ⇒ Object
The Kanji variation of ‘statement_descriptor` used for charges in Japan. Japanese statement descriptors have [special requirements](docs.stripe.com/get-started/account/statement-descriptors#set-japanese-statement-descriptors).
5408 5409 5410 |
# File 'lib/stripe/resources/account.rb', line 5408 def statement_descriptor_kanji @statement_descriptor_kanji end |