Class: Stripe::Account::CreateParams::Settings::Payouts::Schedule
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::CreateParams::Settings::Payouts::Schedule
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#delay_days ⇒ Object
The number of days charge funds are held before being paid out.
-
#interval ⇒ Object
How frequently available funds are paid out.
-
#monthly_anchor ⇒ Object
The day of the month when available funds are paid out, specified as a number between 1–31.
-
#weekly_anchor ⇒ Object
The day of the week when available funds are paid out, specified as ‘monday`, `tuesday`, etc.
Instance Method Summary collapse
-
#initialize(delay_days: nil, interval: nil, monthly_anchor: nil, weekly_anchor: nil) ⇒ Schedule
constructor
A new instance of Schedule.
Methods inherited from RequestParams
Constructor Details
#initialize(delay_days: nil, interval: nil, monthly_anchor: nil, weekly_anchor: nil) ⇒ Schedule
Returns a new instance of Schedule.
5435 5436 5437 5438 5439 5440 |
# File 'lib/stripe/resources/account.rb', line 5435 def initialize(delay_days: nil, interval: nil, monthly_anchor: nil, weekly_anchor: nil) @delay_days = delay_days @interval = interval @monthly_anchor = monthly_anchor @weekly_anchor = weekly_anchor end |
Instance Attribute Details
#delay_days ⇒ Object
The number of days charge funds are held before being paid out. May also be set to ‘minimum`, representing the lowest available value for the account country. Default is `minimum`. The `delay_days` parameter remains at the last configured value if `interval` is `manual`. [Learn more about controlling payout delay days](/connect/manage-payout-schedule).
5424 5425 5426 |
# File 'lib/stripe/resources/account.rb', line 5424 def delay_days @delay_days end |
#interval ⇒ Object
How frequently available funds are paid out. One of: ‘daily`, `manual`, `weekly`, or `monthly`. Default is `daily`.
5427 5428 5429 |
# File 'lib/stripe/resources/account.rb', line 5427 def interval @interval end |
#monthly_anchor ⇒ Object
The day of the month when available funds are paid out, specified as a number between 1–31. Payouts nominally scheduled between the 29th and 31st of the month are instead sent on the last day of a shorter month. Required and applicable only if ‘interval` is `monthly`.
5430 5431 5432 |
# File 'lib/stripe/resources/account.rb', line 5430 def monthly_anchor @monthly_anchor end |
#weekly_anchor ⇒ Object
The day of the week when available funds are paid out, specified as ‘monday`, `tuesday`, etc. (required and applicable only if `interval` is `weekly`.)
5433 5434 5435 |
# File 'lib/stripe/resources/account.rb', line 5433 def weekly_anchor @weekly_anchor end |