Class: Stripe::Account::CreateParams::Settings::Treasury::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



4567
4568
4569
4570
4571
# File 'lib/stripe/resources/account.rb', line 4567

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



4561
4562
4563
# File 'lib/stripe/resources/account.rb', line 4561

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



4563
4564
4565
# File 'lib/stripe/resources/account.rb', line 4563

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



4565
4566
4567
# File 'lib/stripe/resources/account.rb', line 4565

def user_agent
  @user_agent
end