Class: Stripe::Account::CreateParams::Settings::Treasury::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



5201
5202
5203
5204
5205
# File 'lib/stripe/resources/account.rb', line 5201

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



5195
5196
5197
# File 'lib/stripe/resources/account.rb', line 5195

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



5197
5198
5199
# File 'lib/stripe/resources/account.rb', line 5197

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



5199
5200
5201
# File 'lib/stripe/resources/account.rb', line 5199

def user_agent
  @user_agent
end