Class: Stripe::Account::CreateParams::Settings::Treasury::TosAcceptance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::CreateParams::Settings::Treasury::TosAcceptance
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the account representative accepted the service agreement.
-
#ip ⇒ Object
The IP address from which the account representative accepted the service agreement.
-
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted the service agreement.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance
constructor
A new instance of TosAcceptance.
Methods inherited from RequestParams
Constructor Details
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance
Returns a new instance of TosAcceptance.
5117 5118 5119 5120 5121 |
# File 'lib/stripe/resources/account.rb', line 5117 def initialize(date: nil, ip: nil, user_agent: nil) @date = date @ip = ip @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the account representative accepted the service agreement.
5111 5112 5113 |
# File 'lib/stripe/resources/account.rb', line 5111 def date @date end |
#ip ⇒ Object
The IP address from which the account representative accepted the service agreement.
5113 5114 5115 |
# File 'lib/stripe/resources/account.rb', line 5113 def ip @ip end |
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted the service agreement.
5115 5116 5117 |
# File 'lib/stripe/resources/account.rb', line 5115 def user_agent @user_agent end |