Class: Stripe::Account::CreateParams::Settings::Treasury::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



5090
5091
5092
5093
5094
# File 'lib/stripe/resources/account.rb', line 5090

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



5084
5085
5086
# File 'lib/stripe/resources/account.rb', line 5084

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



5086
5087
5088
# File 'lib/stripe/resources/account.rb', line 5086

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



5088
5089
5090
# File 'lib/stripe/resources/account.rb', line 5088

def user_agent
  @user_agent
end