Class: Stripe::Account::CreateParams::Settings::Treasury::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



4397
4398
4399
4400
4401
# File 'lib/stripe/resources/account.rb', line 4397

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



4391
4392
4393
# File 'lib/stripe/resources/account.rb', line 4391

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



4393
4394
4395
# File 'lib/stripe/resources/account.rb', line 4393

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



4395
4396
4397
# File 'lib/stripe/resources/account.rb', line 4395

def user_agent
  @user_agent
end