Class: Stripe::Account::CreateParams::Settings::Treasury::TosAcceptance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::CreateParams::Settings::Treasury::TosAcceptance
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the account representative accepted the service agreement.
-
#ip ⇒ Object
The IP address from which the account representative accepted the service agreement.
-
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted the service agreement.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance
constructor
A new instance of TosAcceptance.
Methods inherited from RequestParams
Constructor Details
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance
Returns a new instance of TosAcceptance.
4397 4398 4399 4400 4401 |
# File 'lib/stripe/resources/account.rb', line 4397 def initialize(date: nil, ip: nil, user_agent: nil) @date = date @ip = ip @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the account representative accepted the service agreement.
4391 4392 4393 |
# File 'lib/stripe/resources/account.rb', line 4391 def date @date end |
#ip ⇒ Object
The IP address from which the account representative accepted the service agreement.
4393 4394 4395 |
# File 'lib/stripe/resources/account.rb', line 4393 def ip @ip end |
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted the service agreement.
4395 4396 4397 |
# File 'lib/stripe/resources/account.rb', line 4395 def user_agent @user_agent end |