Class: Stripe::Account::CreateParams::Settings::Treasury::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



4820
4821
4822
4823
4824
# File 'lib/stripe/resources/account.rb', line 4820

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



4814
4815
4816
# File 'lib/stripe/resources/account.rb', line 4814

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



4816
4817
4818
# File 'lib/stripe/resources/account.rb', line 4816

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



4818
4819
4820
# File 'lib/stripe/resources/account.rb', line 4818

def user_agent
  @user_agent
end