Class: Stripe::Account::CreateParams::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



5274
5275
5276
5277
5278
5279
# File 'lib/stripe/resources/account.rb', line 5274

def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil)
  @date = date
  @ip = ip
  @service_agreement = service_agreement
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted their service agreement.



5266
5267
5268
# File 'lib/stripe/resources/account.rb', line 5266

def date
  @date
end

#ipObject

The IP address from which the account representative accepted their service agreement.



5268
5269
5270
# File 'lib/stripe/resources/account.rb', line 5268

def ip
  @ip
end

#service_agreementObject

The user’s service agreement type.



5270
5271
5272
# File 'lib/stripe/resources/account.rb', line 5270

def service_agreement
  @service_agreement
end

#user_agentObject

The user agent of the browser from which the account representative accepted their service agreement.



5272
5273
5274
# File 'lib/stripe/resources/account.rb', line 5272

def user_agent
  @user_agent
end