Class: Stripe::Account::CreateParams::TosAcceptance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::CreateParams::TosAcceptance
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the account representative accepted their service agreement.
-
#ip ⇒ Object
The IP address from which the account representative accepted their service agreement.
-
#service_agreement ⇒ Object
The user’s service agreement type.
-
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted their service agreement.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance
constructor
A new instance of TosAcceptance.
Methods inherited from RequestParams
Constructor Details
#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance
Returns a new instance of TosAcceptance.
4544 4545 4546 4547 4548 4549 |
# File 'lib/stripe/resources/account.rb', line 4544 def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) @date = date @ip = ip @service_agreement = service_agreement @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the account representative accepted their service agreement.
4536 4537 4538 |
# File 'lib/stripe/resources/account.rb', line 4536 def date @date end |
#ip ⇒ Object
The IP address from which the account representative accepted their service agreement.
4538 4539 4540 |
# File 'lib/stripe/resources/account.rb', line 4538 def ip @ip end |
#service_agreement ⇒ Object
The user’s service agreement type.
4540 4541 4542 |
# File 'lib/stripe/resources/account.rb', line 4540 def service_agreement @service_agreement end |
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted their service agreement.
4542 4543 4544 |
# File 'lib/stripe/resources/account.rb', line 4542 def user_agent @user_agent end |