Class: Stripe::Account::CreateParams::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



5114
5115
5116
5117
5118
5119
# File 'lib/stripe/resources/account.rb', line 5114

def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil)
  @date = date
  @ip = ip
  @service_agreement = service_agreement
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted their service agreement.



5106
5107
5108
# File 'lib/stripe/resources/account.rb', line 5106

def date
  @date
end

#ipObject

The IP address from which the account representative accepted their service agreement.



5108
5109
5110
# File 'lib/stripe/resources/account.rb', line 5108

def ip
  @ip
end

#service_agreementObject

The user’s service agreement type.



5110
5111
5112
# File 'lib/stripe/resources/account.rb', line 5110

def service_agreement
  @service_agreement
end

#user_agentObject

The user agent of the browser from which the account representative accepted their service agreement.



5112
5113
5114
# File 'lib/stripe/resources/account.rb', line 5112

def user_agent
  @user_agent
end