Class: Stripe::Account::CreateParams::TosAcceptance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::CreateParams::TosAcceptance
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the account representative accepted their service agreement.
-
#ip ⇒ Object
The IP address from which the account representative accepted their service agreement.
-
#service_agreement ⇒ Object
The user’s service agreement type.
-
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted their service agreement.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance
constructor
A new instance of TosAcceptance.
Methods inherited from RequestParams
Constructor Details
#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance
Returns a new instance of TosAcceptance.
5114 5115 5116 5117 5118 5119 |
# File 'lib/stripe/resources/account.rb', line 5114 def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) @date = date @ip = ip @service_agreement = service_agreement @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the account representative accepted their service agreement.
5106 5107 5108 |
# File 'lib/stripe/resources/account.rb', line 5106 def date @date end |
#ip ⇒ Object
The IP address from which the account representative accepted their service agreement.
5108 5109 5110 |
# File 'lib/stripe/resources/account.rb', line 5108 def ip @ip end |
#service_agreement ⇒ Object
The user’s service agreement type.
5110 5111 5112 |
# File 'lib/stripe/resources/account.rb', line 5110 def service_agreement @service_agreement end |
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted their service agreement.
5112 5113 5114 |
# File 'lib/stripe/resources/account.rb', line 5112 def user_agent @user_agent end |