Class: Stripe::Account::CreateParams::TosAcceptance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::CreateParams::TosAcceptance
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the account representative accepted their service agreement.
-
#ip ⇒ Object
The IP address from which the account representative accepted their service agreement.
-
#service_agreement ⇒ Object
The user’s service agreement type.
-
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted their service agreement.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance
constructor
A new instance of TosAcceptance.
Methods inherited from RequestParams
Constructor Details
#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance
Returns a new instance of TosAcceptance.
5163 5164 5165 5166 5167 5168 |
# File 'lib/stripe/resources/account.rb', line 5163 def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) @date = date @ip = ip @service_agreement = service_agreement @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the account representative accepted their service agreement.
5155 5156 5157 |
# File 'lib/stripe/resources/account.rb', line 5155 def date @date end |
#ip ⇒ Object
The IP address from which the account representative accepted their service agreement.
5157 5158 5159 |
# File 'lib/stripe/resources/account.rb', line 5157 def ip @ip end |
#service_agreement ⇒ Object
The user’s service agreement type.
5159 5160 5161 |
# File 'lib/stripe/resources/account.rb', line 5159 def service_agreement @service_agreement end |
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted their service agreement.
5161 5162 5163 |
# File 'lib/stripe/resources/account.rb', line 5161 def user_agent @user_agent end |