Class: Stripe::Account::CreateParams::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



5104
5105
5106
5107
5108
5109
# File 'lib/stripe/resources/account.rb', line 5104

def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil)
  @date = date
  @ip = ip
  @service_agreement = service_agreement
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted their service agreement.



5096
5097
5098
# File 'lib/stripe/resources/account.rb', line 5096

def date
  @date
end

#ipObject

The IP address from which the account representative accepted their service agreement.



5098
5099
5100
# File 'lib/stripe/resources/account.rb', line 5098

def ip
  @ip
end

#service_agreementObject

The user’s service agreement type.



5100
5101
5102
# File 'lib/stripe/resources/account.rb', line 5100

def service_agreement
  @service_agreement
end

#user_agentObject

The user agent of the browser from which the account representative accepted their service agreement.



5102
5103
5104
# File 'lib/stripe/resources/account.rb', line 5102

def user_agent
  @user_agent
end