Class: Stripe::Account::CreateParams::TosAcceptance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::CreateParams::TosAcceptance
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the account representative accepted their service agreement.
-
#ip ⇒ Object
The IP address from which the account representative accepted their service agreement.
-
#service_agreement ⇒ Object
The user’s service agreement type.
-
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted their service agreement.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance
constructor
A new instance of TosAcceptance.
Methods inherited from RequestParams
Constructor Details
#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance
Returns a new instance of TosAcceptance.
4458 4459 4460 4461 4462 4463 |
# File 'lib/stripe/resources/account.rb', line 4458 def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) @date = date @ip = ip @service_agreement = service_agreement @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the account representative accepted their service agreement.
4450 4451 4452 |
# File 'lib/stripe/resources/account.rb', line 4450 def date @date end |
#ip ⇒ Object
The IP address from which the account representative accepted their service agreement.
4452 4453 4454 |
# File 'lib/stripe/resources/account.rb', line 4452 def ip @ip end |
#service_agreement ⇒ Object
The user’s service agreement type.
4454 4455 4456 |
# File 'lib/stripe/resources/account.rb', line 4454 def service_agreement @service_agreement end |
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted their service agreement.
4456 4457 4458 |
# File 'lib/stripe/resources/account.rb', line 4456 def user_agent @user_agent end |