Class: Stripe::Account::CreateParams::TosAcceptance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::CreateParams::TosAcceptance
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the account representative accepted their service agreement.
-
#ip ⇒ Object
The IP address from which the account representative accepted their service agreement.
-
#service_agreement ⇒ Object
The user’s service agreement type.
-
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted their service agreement.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance
constructor
A new instance of TosAcceptance.
Methods inherited from RequestParams
Constructor Details
#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance
Returns a new instance of TosAcceptance.
4983 4984 4985 4986 4987 4988 |
# File 'lib/stripe/resources/account.rb', line 4983 def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) @date = date @ip = ip @service_agreement = service_agreement @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the account representative accepted their service agreement.
4975 4976 4977 |
# File 'lib/stripe/resources/account.rb', line 4975 def date @date end |
#ip ⇒ Object
The IP address from which the account representative accepted their service agreement.
4977 4978 4979 |
# File 'lib/stripe/resources/account.rb', line 4977 def ip @ip end |
#service_agreement ⇒ Object
The user’s service agreement type.
4979 4980 4981 |
# File 'lib/stripe/resources/account.rb', line 4979 def service_agreement @service_agreement end |
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted their service agreement.
4981 4982 4983 |
# File 'lib/stripe/resources/account.rb', line 4981 def user_agent @user_agent end |