Class: Stripe::Account::CreateParams::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



4889
4890
4891
4892
4893
4894
# File 'lib/stripe/resources/account.rb', line 4889

def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil)
  @date = date
  @ip = ip
  @service_agreement = service_agreement
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted their service agreement.



4881
4882
4883
# File 'lib/stripe/resources/account.rb', line 4881

def date
  @date
end

#ipObject

The IP address from which the account representative accepted their service agreement.



4883
4884
4885
# File 'lib/stripe/resources/account.rb', line 4883

def ip
  @ip
end

#service_agreementObject

The user’s service agreement type.



4885
4886
4887
# File 'lib/stripe/resources/account.rb', line 4885

def service_agreement
  @service_agreement
end

#user_agentObject

The user agent of the browser from which the account representative accepted their service agreement.



4887
4888
4889
# File 'lib/stripe/resources/account.rb', line 4887

def user_agent
  @user_agent
end