Class: Stripe::Account::CreateParams::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



4981
4982
4983
4984
4985
4986
# File 'lib/stripe/resources/account.rb', line 4981

def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil)
  @date = date
  @ip = ip
  @service_agreement = service_agreement
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted their service agreement.



4973
4974
4975
# File 'lib/stripe/resources/account.rb', line 4973

def date
  @date
end

#ipObject

The IP address from which the account representative accepted their service agreement.



4975
4976
4977
# File 'lib/stripe/resources/account.rb', line 4975

def ip
  @ip
end

#service_agreementObject

The user’s service agreement type.



4977
4978
4979
# File 'lib/stripe/resources/account.rb', line 4977

def service_agreement
  @service_agreement
end

#user_agentObject

The user agent of the browser from which the account representative accepted their service agreement.



4979
4980
4981
# File 'lib/stripe/resources/account.rb', line 4979

def user_agent
  @user_agent
end