Class: Stripe::Account::CreateParams::TosAcceptance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::CreateParams::TosAcceptance
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the account representative accepted their service agreement.
-
#ip ⇒ Object
The IP address from which the account representative accepted their service agreement.
-
#service_agreement ⇒ Object
The user’s service agreement type.
-
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted their service agreement.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance
constructor
A new instance of TosAcceptance.
Methods inherited from RequestParams
Constructor Details
#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance
Returns a new instance of TosAcceptance.
5559 5560 5561 5562 5563 5564 |
# File 'lib/stripe/resources/account.rb', line 5559 def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) @date = date @ip = ip @service_agreement = service_agreement @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the account representative accepted their service agreement.
5548 5549 5550 |
# File 'lib/stripe/resources/account.rb', line 5548 def date @date end |
#ip ⇒ Object
The IP address from which the account representative accepted their service agreement.
5551 5552 5553 |
# File 'lib/stripe/resources/account.rb', line 5551 def ip @ip end |
#service_agreement ⇒ Object
The user’s service agreement type.
5554 5555 5556 |
# File 'lib/stripe/resources/account.rb', line 5554 def service_agreement @service_agreement end |
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted their service agreement.
5557 5558 5559 |
# File 'lib/stripe/resources/account.rb', line 5557 def user_agent @user_agent end |