Class: Stripe::Account::FutureRequirements

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: Alternative, Error

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#alternativesObject (readonly)

Fields that are due and can be resolved by providing the corresponding alternative fields instead. Many alternatives can list the same ‘original_fields_due`, and any of these alternatives can serve as a pathway for attempting to resolve the fields again. Re-providing `original_fields_due` also serves as a pathway for attempting to resolve the fields again.



668
669
670
# File 'lib/stripe/resources/account.rb', line 668

def alternatives
  @alternatives
end

#current_deadlineObject (readonly)

Date on which ‘future_requirements` becomes the main `requirements` hash and `future_requirements` becomes empty. After the transition, `currently_due` requirements may immediately become `past_due`, but the account may also be given a grace period depending on its enablement state prior to transitioning.



670
671
672
# File 'lib/stripe/resources/account.rb', line 670

def current_deadline
  @current_deadline
end

#currently_dueObject (readonly)

Fields that need to be resolved to keep the account enabled. If not resolved by ‘future_requirements`, these fields will transition to the main `requirements` hash.



672
673
674
# File 'lib/stripe/resources/account.rb', line 672

def currently_due
  @currently_due
end

#disabled_reasonObject (readonly)

This is typed as an enum for consistency with ‘requirements.disabled_reason`.



674
675
676
# File 'lib/stripe/resources/account.rb', line 674

def disabled_reason
  @disabled_reason
end

#errorsObject (readonly)

Details about validation and verification failures for ‘due` requirements that must be resolved.



676
677
678
# File 'lib/stripe/resources/account.rb', line 676

def errors
  @errors
end

#eventually_dueObject (readonly)

Fields you must collect when all thresholds are reached. As they become required, they appear in ‘currently_due` as well.



678
679
680
# File 'lib/stripe/resources/account.rb', line 678

def eventually_due
  @eventually_due
end

#past_dueObject (readonly)

Fields that haven’t been resolved by ‘requirements.current_deadline`. These fields need to be resolved to enable the capability on the account. `future_requirements.past_due` is a subset of `requirements.past_due`.



680
681
682
# File 'lib/stripe/resources/account.rb', line 680

def past_due
  @past_due
end

#pending_verificationObject (readonly)

Fields that are being reviewed, or might become required depending on the results of a review. If the review fails, these fields can move to ‘eventually_due`, `currently_due`, `past_due` or `alternatives`. Fields might appear in `eventually_due`, `currently_due`, `past_due` or `alternatives` and in `pending_verification` if one verification fails but another is still pending.



682
683
684
# File 'lib/stripe/resources/account.rb', line 682

def pending_verification
  @pending_verification
end

Class Method Details

.field_remappingsObject



688
689
690
# File 'lib/stripe/resources/account.rb', line 688

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



684
685
686
# File 'lib/stripe/resources/account.rb', line 684

def self.inner_class_types
  @inner_class_types = { alternatives: Alternative, errors: Error }
end