Class: Stripe::Account::FutureRequirements

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: Alternative, Error

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#alternativesObject (readonly)

Fields that are due and can be satisfied by providing the corresponding alternative fields instead.



660
661
662
# File 'lib/stripe/resources/account.rb', line 660

def alternatives
  @alternatives
end

#current_deadlineObject (readonly)

Date on which ‘future_requirements` becomes the main `requirements` hash and `future_requirements` becomes empty. After the transition, `currently_due` requirements may immediately become `past_due`, but the account may also be given a grace period depending on its enablement state prior to transitioning.



662
663
664
# File 'lib/stripe/resources/account.rb', line 662

def current_deadline
  @current_deadline
end

#currently_dueObject (readonly)

Fields that need to be collected to keep the account enabled. If not collected by ‘future_requirements`, these fields will transition to the main `requirements` hash.



664
665
666
# File 'lib/stripe/resources/account.rb', line 664

def currently_due
  @currently_due
end

#disabled_reasonObject (readonly)

This is typed as an enum for consistency with ‘requirements.disabled_reason`.



666
667
668
# File 'lib/stripe/resources/account.rb', line 666

def disabled_reason
  @disabled_reason
end

#errorsObject (readonly)

Fields that are ‘currently_due` and need to be collected again because validation or verification failed.



668
669
670
# File 'lib/stripe/resources/account.rb', line 668

def errors
  @errors
end

#eventually_dueObject (readonly)

Fields you must collect when all thresholds are reached. As they become required, they appear in ‘currently_due` as well.



670
671
672
# File 'lib/stripe/resources/account.rb', line 670

def eventually_due
  @eventually_due
end

#past_dueObject (readonly)

Fields that weren’t collected by ‘requirements.current_deadline`. These fields need to be collected to enable the capability on the account. New fields will never appear here; `future_requirements.past_due` will always be a subset of `requirements.past_due`.



672
673
674
# File 'lib/stripe/resources/account.rb', line 672

def past_due
  @past_due
end

#pending_verificationObject (readonly)

Fields that might become required depending on the results of verification or review. It’s an empty array unless an asynchronous verification is pending. If verification fails, these fields move to ‘eventually_due` or `currently_due`. Fields might appear in `eventually_due` or `currently_due` and in `pending_verification` if verification fails but another verification is still pending.



674
675
676
# File 'lib/stripe/resources/account.rb', line 674

def pending_verification
  @pending_verification
end

Class Method Details

.field_remappingsObject



680
681
682
# File 'lib/stripe/resources/account.rb', line 680

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



676
677
678
# File 'lib/stripe/resources/account.rb', line 676

def self.inner_class_types
  @inner_class_types = { alternatives: Alternative, errors: Error }
end