Class: Stripe::Account::FutureRequirements
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Account::FutureRequirements
- Defined in:
- lib/stripe/resources/account.rb
Defined Under Namespace
Classes: Alternative, Error
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#alternatives ⇒ Object
readonly
Fields that are due and can be satisfied by providing the corresponding alternative fields instead.
-
#current_deadline ⇒ Object
readonly
Date on which ‘future_requirements` becomes the main `requirements` hash and `future_requirements` becomes empty.
-
#currently_due ⇒ Object
readonly
Fields that need to be collected to keep the account enabled.
-
#disabled_reason ⇒ Object
readonly
This is typed as an enum for consistency with ‘requirements.disabled_reason`.
-
#errors ⇒ Object
readonly
Fields that are ‘currently_due` and need to be collected again because validation or verification failed.
-
#eventually_due ⇒ Object
readonly
Fields you must collect when all thresholds are reached.
-
#past_due ⇒ Object
readonly
Fields that weren’t collected by ‘requirements.current_deadline`.
-
#pending_verification ⇒ Object
readonly
Fields that might become required depending on the results of verification or review.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#alternatives ⇒ Object (readonly)
Fields that are due and can be satisfied by providing the corresponding alternative fields instead.
440 441 442 |
# File 'lib/stripe/resources/account.rb', line 440 def alternatives @alternatives end |
#current_deadline ⇒ Object (readonly)
Date on which ‘future_requirements` becomes the main `requirements` hash and `future_requirements` becomes empty. After the transition, `currently_due` requirements may immediately become `past_due`, but the account may also be given a grace period depending on its enablement state prior to transitioning.
442 443 444 |
# File 'lib/stripe/resources/account.rb', line 442 def current_deadline @current_deadline end |
#currently_due ⇒ Object (readonly)
Fields that need to be collected to keep the account enabled. If not collected by ‘future_requirements`, these fields will transition to the main `requirements` hash.
444 445 446 |
# File 'lib/stripe/resources/account.rb', line 444 def currently_due @currently_due end |
#disabled_reason ⇒ Object (readonly)
This is typed as an enum for consistency with ‘requirements.disabled_reason`.
446 447 448 |
# File 'lib/stripe/resources/account.rb', line 446 def disabled_reason @disabled_reason end |
#errors ⇒ Object (readonly)
Fields that are ‘currently_due` and need to be collected again because validation or verification failed.
448 449 450 |
# File 'lib/stripe/resources/account.rb', line 448 def errors @errors end |
#eventually_due ⇒ Object (readonly)
Fields you must collect when all thresholds are reached. As they become required, they appear in ‘currently_due` as well.
450 451 452 |
# File 'lib/stripe/resources/account.rb', line 450 def eventually_due @eventually_due end |
#past_due ⇒ Object (readonly)
Fields that weren’t collected by ‘requirements.current_deadline`. These fields need to be collected to enable the capability on the account. New fields will never appear here; `future_requirements.past_due` will always be a subset of `requirements.past_due`.
452 453 454 |
# File 'lib/stripe/resources/account.rb', line 452 def past_due @past_due end |
#pending_verification ⇒ Object (readonly)
Fields that might become required depending on the results of verification or review. It’s an empty array unless an asynchronous verification is pending. If verification fails, these fields move to ‘eventually_due` or `currently_due`. Fields might appear in `eventually_due` or `currently_due` and in `pending_verification` if verification fails but another verification is still pending.
454 455 456 |
# File 'lib/stripe/resources/account.rb', line 454 def pending_verification @pending_verification end |