Class: Stripe::Account::Groups

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/account.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#payments_pricingObject (readonly)

The group the account is in to determine their payments pricing, and null if the account is on customized pricing. See the Platform pricing tool documentation for details.



751
752
753
# File 'lib/stripe/resources/account.rb', line 751

def payments_pricing
  @payments_pricing
end

Class Method Details

.field_remappingsObject



757
758
759
# File 'lib/stripe/resources/account.rb', line 757

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



753
754
755
# File 'lib/stripe/resources/account.rb', line 753

def self.inner_class_types
  @inner_class_types = {}
end