Class: Stripe::Account::Groups
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Account::Groups
- Defined in:
- lib/stripe/resources/account.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#payments_pricing ⇒ Object
readonly
The group the account is in to determine their payments pricing, and null if the account is on customized pricing.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#payments_pricing ⇒ Object (readonly)
The group the account is in to determine their payments pricing, and null if the account is on customized pricing. [See the Platform pricing tool documentation](docs.stripe.com/connect/platform-pricing-tools) for details.
695 696 697 |
# File 'lib/stripe/resources/account.rb', line 695 def payments_pricing @payments_pricing end |
Class Method Details
.field_remappings ⇒ Object
701 702 703 |
# File 'lib/stripe/resources/account.rb', line 701 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
697 698 699 |
# File 'lib/stripe/resources/account.rb', line 697 def self.inner_class_types @inner_class_types = {} end |