Class: Stripe::Account::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



2901
2902
2903
2904
2905
2906
2907
# File 'lib/stripe/resources/account.rb', line 2901

def initialize(created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil)
  @created = created
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
end

Instance Attribute Details

#createdObject

Only return connected accounts that were created during the given date interval.



2891
2892
2893
# File 'lib/stripe/resources/account.rb', line 2891

def created
  @created
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



2893
2894
2895
# File 'lib/stripe/resources/account.rb', line 2893

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



2895
2896
2897
# File 'lib/stripe/resources/account.rb', line 2895

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



2897
2898
2899
# File 'lib/stripe/resources/account.rb', line 2897

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



2899
2900
2901
# File 'lib/stripe/resources/account.rb', line 2899

def starting_after
  @starting_after
end