Class: Stripe::Account::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::ListParams
- Defined in:
- lib/stripe/resources/account.rb
Defined Under Namespace
Classes: Created
Instance Attribute Summary collapse
-
#created ⇒ Object
Only return connected accounts that were created during the given date interval.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#starting_after ⇒ Object
A cursor for use in pagination.
Instance Method Summary collapse
-
#initialize(created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams
Returns a new instance of ListParams.
2796 2797 2798 2799 2800 2801 2802 |
# File 'lib/stripe/resources/account.rb', line 2796 def initialize(created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) @created = created @ending_before = ending_before @expand = @limit = limit @starting_after = starting_after end |
Instance Attribute Details
#created ⇒ Object
Only return connected accounts that were created during the given date interval.
2786 2787 2788 |
# File 'lib/stripe/resources/account.rb', line 2786 def created @created end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
2788 2789 2790 |
# File 'lib/stripe/resources/account.rb', line 2788 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2790 2791 2792 |
# File 'lib/stripe/resources/account.rb', line 2790 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
2792 2793 2794 |
# File 'lib/stripe/resources/account.rb', line 2792 def limit @limit end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
2794 2795 2796 |
# File 'lib/stripe/resources/account.rb', line 2794 def starting_after @starting_after end |