Class: Stripe::Account::PersonsParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::PersonsParams
- Defined in:
- lib/stripe/resources/account.rb
Defined Under Namespace
Classes: Relationship
Instance Attribute Summary collapse
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#relationship ⇒ Object
Filters on the list of people returned based on the person’s relationship to the account’s company.
-
#starting_after ⇒ Object
A cursor for use in pagination.
Instance Method Summary collapse
-
#initialize(ending_before: nil, expand: nil, limit: nil, relationship: nil, starting_after: nil) ⇒ PersonsParams
constructor
A new instance of PersonsParams.
Methods inherited from RequestParams
Constructor Details
#initialize(ending_before: nil, expand: nil, limit: nil, relationship: nil, starting_after: nil) ⇒ PersonsParams
Returns a new instance of PersonsParams.
5836 5837 5838 5839 5840 5841 5842 5843 5844 5845 5846 5847 5848 |
# File 'lib/stripe/resources/account.rb', line 5836 def initialize( ending_before: nil, expand: nil, limit: nil, relationship: nil, starting_after: nil ) @ending_before = ending_before @expand = @limit = limit @relationship = relationship @starting_after = starting_after end |
Instance Attribute Details
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
5826 5827 5828 |
# File 'lib/stripe/resources/account.rb', line 5826 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
5828 5829 5830 |
# File 'lib/stripe/resources/account.rb', line 5828 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
5830 5831 5832 |
# File 'lib/stripe/resources/account.rb', line 5830 def limit @limit end |
#relationship ⇒ Object
Filters on the list of people returned based on the person’s relationship to the account’s company.
5832 5833 5834 |
# File 'lib/stripe/resources/account.rb', line 5832 def relationship @relationship end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
5834 5835 5836 |
# File 'lib/stripe/resources/account.rb', line 5834 def starting_after @starting_after end |