Class: Stripe::Account::PersonsParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::PersonsParams
- Defined in:
- lib/stripe/resources/account.rb
Defined Under Namespace
Classes: Relationship
Instance Attribute Summary collapse
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#relationship ⇒ Object
Filters on the list of people returned based on the person’s relationship to the account’s company.
-
#starting_after ⇒ Object
A cursor for use in pagination.
Instance Method Summary collapse
-
#initialize(ending_before: nil, expand: nil, limit: nil, relationship: nil, starting_after: nil) ⇒ PersonsParams
constructor
A new instance of PersonsParams.
Methods inherited from RequestParams
Constructor Details
#initialize(ending_before: nil, expand: nil, limit: nil, relationship: nil, starting_after: nil) ⇒ PersonsParams
Returns a new instance of PersonsParams.
5301 5302 5303 5304 5305 5306 5307 5308 5309 5310 5311 5312 5313 |
# File 'lib/stripe/resources/account.rb', line 5301 def initialize( ending_before: nil, expand: nil, limit: nil, relationship: nil, starting_after: nil ) @ending_before = ending_before @expand = @limit = limit @relationship = relationship @starting_after = starting_after end |
Instance Attribute Details
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
5291 5292 5293 |
# File 'lib/stripe/resources/account.rb', line 5291 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
5293 5294 5295 |
# File 'lib/stripe/resources/account.rb', line 5293 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
5295 5296 5297 |
# File 'lib/stripe/resources/account.rb', line 5295 def limit @limit end |
#relationship ⇒ Object
Filters on the list of people returned based on the person’s relationship to the account’s company.
5297 5298 5299 |
# File 'lib/stripe/resources/account.rb', line 5297 def relationship @relationship end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
5299 5300 5301 |
# File 'lib/stripe/resources/account.rb', line 5299 def starting_after @starting_after end |