Class: Stripe::Account::PersonsParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: Relationship

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(ending_before: nil, expand: nil, limit: nil, relationship: nil, starting_after: nil) ⇒ PersonsParams

Returns a new instance of PersonsParams.



5242
5243
5244
5245
5246
5247
5248
5249
5250
5251
5252
5253
5254
# File 'lib/stripe/resources/account.rb', line 5242

def initialize(
  ending_before: nil,
  expand: nil,
  limit: nil,
  relationship: nil,
  starting_after: nil
)
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @relationship = relationship
  @starting_after = starting_after
end

Instance Attribute Details

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



5232
5233
5234
# File 'lib/stripe/resources/account.rb', line 5232

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



5234
5235
5236
# File 'lib/stripe/resources/account.rb', line 5234

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



5236
5237
5238
# File 'lib/stripe/resources/account.rb', line 5236

def limit
  @limit
end

#relationshipObject

Filters on the list of people returned based on the person’s relationship to the account’s company.



5238
5239
5240
# File 'lib/stripe/resources/account.rb', line 5238

def relationship
  @relationship
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



5240
5241
5242
# File 'lib/stripe/resources/account.rb', line 5240

def starting_after
  @starting_after
end