Class: Stripe::Account::PersonsParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: Relationship

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(ending_before: nil, expand: nil, limit: nil, relationship: nil, starting_after: nil) ⇒ PersonsParams

Returns a new instance of PersonsParams.



5119
5120
5121
5122
5123
5124
5125
5126
5127
5128
5129
5130
5131
# File 'lib/stripe/resources/account.rb', line 5119

def initialize(
  ending_before: nil,
  expand: nil,
  limit: nil,
  relationship: nil,
  starting_after: nil
)
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @relationship = relationship
  @starting_after = starting_after
end

Instance Attribute Details

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



5109
5110
5111
# File 'lib/stripe/resources/account.rb', line 5109

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



5111
5112
5113
# File 'lib/stripe/resources/account.rb', line 5111

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



5113
5114
5115
# File 'lib/stripe/resources/account.rb', line 5113

def limit
  @limit
end

#relationshipObject

Filters on the list of people returned based on the person’s relationship to the account’s company.



5115
5116
5117
# File 'lib/stripe/resources/account.rb', line 5115

def relationship
  @relationship
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



5117
5118
5119
# File 'lib/stripe/resources/account.rb', line 5117

def starting_after
  @starting_after
end