Class: Stripe::Account::PersonsParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: Relationship

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(ending_before: nil, expand: nil, limit: nil, relationship: nil, starting_after: nil) ⇒ PersonsParams

Returns a new instance of PersonsParams.



5724
5725
5726
5727
5728
5729
5730
5731
5732
5733
5734
5735
5736
# File 'lib/stripe/resources/account.rb', line 5724

def initialize(
  ending_before: nil,
  expand: nil,
  limit: nil,
  relationship: nil,
  starting_after: nil
)
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @relationship = relationship
  @starting_after = starting_after
end

Instance Attribute Details

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



5710
5711
5712
# File 'lib/stripe/resources/account.rb', line 5710

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



5713
5714
5715
# File 'lib/stripe/resources/account.rb', line 5713

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



5716
5717
5718
# File 'lib/stripe/resources/account.rb', line 5716

def limit
  @limit
end

#relationshipObject

Filters on the list of people returned based on the person’s relationship to the account’s company.



5719
5720
5721
# File 'lib/stripe/resources/account.rb', line 5719

def relationship
  @relationship
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



5722
5723
5724
# File 'lib/stripe/resources/account.rb', line 5722

def starting_after
  @starting_after
end