Class: Stripe::Account::PersonsParams::Relationship
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::PersonsParams::Relationship
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#authorizer ⇒ Object
A filter on the list of people returned based on whether these people are authorizers of the account’s representative.
-
#director ⇒ Object
A filter on the list of people returned based on whether these people are directors of the account’s company.
-
#executive ⇒ Object
A filter on the list of people returned based on whether these people are executives of the account’s company.
-
#legal_guardian ⇒ Object
A filter on the list of people returned based on whether these people are legal guardians of the account’s representative.
-
#owner ⇒ Object
A filter on the list of people returned based on whether these people are owners of the account’s company.
-
#representative ⇒ Object
A filter on the list of people returned based on whether these people are the representative of the account’s company.
Instance Method Summary collapse
-
#initialize(authorizer: nil, director: nil, executive: nil, legal_guardian: nil, owner: nil, representative: nil) ⇒ Relationship
constructor
A new instance of Relationship.
Methods inherited from RequestParams
Constructor Details
#initialize(authorizer: nil, director: nil, executive: nil, legal_guardian: nil, owner: nil, representative: nil) ⇒ Relationship
Returns a new instance of Relationship.
5385 5386 5387 5388 5389 5390 5391 5392 5393 5394 5395 5396 5397 5398 5399 |
# File 'lib/stripe/resources/account.rb', line 5385 def initialize( authorizer: nil, director: nil, executive: nil, legal_guardian: nil, owner: nil, representative: nil ) @authorizer = @director = director @executive = executive @legal_guardian = legal_guardian @owner = owner @representative = representative end |
Instance Attribute Details
#authorizer ⇒ Object
A filter on the list of people returned based on whether these people are authorizers of the account’s representative.
5373 5374 5375 |
# File 'lib/stripe/resources/account.rb', line 5373 def @authorizer end |
#director ⇒ Object
A filter on the list of people returned based on whether these people are directors of the account’s company.
5375 5376 5377 |
# File 'lib/stripe/resources/account.rb', line 5375 def director @director end |
#executive ⇒ Object
A filter on the list of people returned based on whether these people are executives of the account’s company.
5377 5378 5379 |
# File 'lib/stripe/resources/account.rb', line 5377 def executive @executive end |
#legal_guardian ⇒ Object
A filter on the list of people returned based on whether these people are legal guardians of the account’s representative.
5379 5380 5381 |
# File 'lib/stripe/resources/account.rb', line 5379 def legal_guardian @legal_guardian end |
#owner ⇒ Object
A filter on the list of people returned based on whether these people are owners of the account’s company.
5381 5382 5383 |
# File 'lib/stripe/resources/account.rb', line 5381 def owner @owner end |
#representative ⇒ Object
A filter on the list of people returned based on whether these people are the representative of the account’s company.
5383 5384 5385 |
# File 'lib/stripe/resources/account.rb', line 5383 def representative @representative end |