Class: Stripe::Account::PersonsParams::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(authorizer: nil, director: nil, executive: nil, legal_guardian: nil, owner: nil, representative: nil) ⇒ Relationship

Returns a new instance of Relationship.



4735
4736
4737
4738
4739
4740
4741
4742
4743
4744
4745
4746
4747
4748
4749
# File 'lib/stripe/resources/account.rb', line 4735

def initialize(
  authorizer: nil,
  director: nil,
  executive: nil,
  legal_guardian: nil,
  owner: nil,
  representative: nil
)
  @authorizer = authorizer
  @director = director
  @executive = executive
  @legal_guardian = legal_guardian
  @owner = owner
  @representative = representative
end

Instance Attribute Details

#authorizerObject

A filter on the list of people returned based on whether these people are authorizers of the account’s representative.



4723
4724
4725
# File 'lib/stripe/resources/account.rb', line 4723

def authorizer
  @authorizer
end

#directorObject

A filter on the list of people returned based on whether these people are directors of the account’s company.



4725
4726
4727
# File 'lib/stripe/resources/account.rb', line 4725

def director
  @director
end

#executiveObject

A filter on the list of people returned based on whether these people are executives of the account’s company.



4727
4728
4729
# File 'lib/stripe/resources/account.rb', line 4727

def executive
  @executive
end

A filter on the list of people returned based on whether these people are legal guardians of the account’s representative.



4729
4730
4731
# File 'lib/stripe/resources/account.rb', line 4729

def legal_guardian
  @legal_guardian
end

#ownerObject

A filter on the list of people returned based on whether these people are owners of the account’s company.



4731
4732
4733
# File 'lib/stripe/resources/account.rb', line 4731

def owner
  @owner
end

#representativeObject

A filter on the list of people returned based on whether these people are the representative of the account’s company.



4733
4734
4735
# File 'lib/stripe/resources/account.rb', line 4733

def representative
  @representative
end