Class: Stripe::Account::PersonsParams::Relationship
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::PersonsParams::Relationship
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#authorizer ⇒ Object
A filter on the list of people returned based on whether these people are authorizers of the account’s representative.
-
#director ⇒ Object
A filter on the list of people returned based on whether these people are directors of the account’s company.
-
#executive ⇒ Object
A filter on the list of people returned based on whether these people are executives of the account’s company.
-
#legal_guardian ⇒ Object
A filter on the list of people returned based on whether these people are legal guardians of the account’s representative.
-
#owner ⇒ Object
A filter on the list of people returned based on whether these people are owners of the account’s company.
-
#representative ⇒ Object
A filter on the list of people returned based on whether these people are the representative of the account’s company.
Instance Method Summary collapse
-
#initialize(authorizer: nil, director: nil, executive: nil, legal_guardian: nil, owner: nil, representative: nil) ⇒ Relationship
constructor
A new instance of Relationship.
Methods inherited from RequestParams
Constructor Details
#initialize(authorizer: nil, director: nil, executive: nil, legal_guardian: nil, owner: nil, representative: nil) ⇒ Relationship
Returns a new instance of Relationship.
5301 5302 5303 5304 5305 5306 5307 5308 5309 5310 5311 5312 5313 5314 5315 |
# File 'lib/stripe/resources/account.rb', line 5301 def initialize( authorizer: nil, director: nil, executive: nil, legal_guardian: nil, owner: nil, representative: nil ) @authorizer = @director = director @executive = executive @legal_guardian = legal_guardian @owner = owner @representative = representative end |
Instance Attribute Details
#authorizer ⇒ Object
A filter on the list of people returned based on whether these people are authorizers of the account’s representative.
5289 5290 5291 |
# File 'lib/stripe/resources/account.rb', line 5289 def @authorizer end |
#director ⇒ Object
A filter on the list of people returned based on whether these people are directors of the account’s company.
5291 5292 5293 |
# File 'lib/stripe/resources/account.rb', line 5291 def director @director end |
#executive ⇒ Object
A filter on the list of people returned based on whether these people are executives of the account’s company.
5293 5294 5295 |
# File 'lib/stripe/resources/account.rb', line 5293 def executive @executive end |
#legal_guardian ⇒ Object
A filter on the list of people returned based on whether these people are legal guardians of the account’s representative.
5295 5296 5297 |
# File 'lib/stripe/resources/account.rb', line 5295 def legal_guardian @legal_guardian end |
#owner ⇒ Object
A filter on the list of people returned based on whether these people are owners of the account’s company.
5297 5298 5299 |
# File 'lib/stripe/resources/account.rb', line 5297 def owner @owner end |
#representative ⇒ Object
A filter on the list of people returned based on whether these people are the representative of the account’s company.
5299 5300 5301 |
# File 'lib/stripe/resources/account.rb', line 5299 def representative @representative end |