Class: Stripe::Account::PersonsParams::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(authorizer: nil, director: nil, executive: nil, legal_guardian: nil, owner: nil, representative: nil) ⇒ Relationship

Returns a new instance of Relationship.



4651
4652
4653
4654
4655
4656
4657
4658
4659
4660
4661
4662
4663
4664
4665
# File 'lib/stripe/resources/account.rb', line 4651

def initialize(
  authorizer: nil,
  director: nil,
  executive: nil,
  legal_guardian: nil,
  owner: nil,
  representative: nil
)
  @authorizer = authorizer
  @director = director
  @executive = executive
  @legal_guardian = legal_guardian
  @owner = owner
  @representative = representative
end

Instance Attribute Details

#authorizerObject

A filter on the list of people returned based on whether these people are authorizers of the account’s representative.



4639
4640
4641
# File 'lib/stripe/resources/account.rb', line 4639

def authorizer
  @authorizer
end

#directorObject

A filter on the list of people returned based on whether these people are directors of the account’s company.



4641
4642
4643
# File 'lib/stripe/resources/account.rb', line 4641

def director
  @director
end

#executiveObject

A filter on the list of people returned based on whether these people are executives of the account’s company.



4643
4644
4645
# File 'lib/stripe/resources/account.rb', line 4643

def executive
  @executive
end

A filter on the list of people returned based on whether these people are legal guardians of the account’s representative.



4645
4646
4647
# File 'lib/stripe/resources/account.rb', line 4645

def legal_guardian
  @legal_guardian
end

#ownerObject

A filter on the list of people returned based on whether these people are owners of the account’s company.



4647
4648
4649
# File 'lib/stripe/resources/account.rb', line 4647

def owner
  @owner
end

#representativeObject

A filter on the list of people returned based on whether these people are the representative of the account’s company.



4649
4650
4651
# File 'lib/stripe/resources/account.rb', line 4649

def representative
  @representative
end