Class: Stripe::Account::PersonsParams::Relationship
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::PersonsParams::Relationship
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#authorizer ⇒ Object
A filter on the list of people returned based on whether these people are authorizers of the account’s representative.
-
#director ⇒ Object
A filter on the list of people returned based on whether these people are directors of the account’s company.
-
#executive ⇒ Object
A filter on the list of people returned based on whether these people are executives of the account’s company.
-
#legal_guardian ⇒ Object
A filter on the list of people returned based on whether these people are legal guardians of the account’s representative.
-
#owner ⇒ Object
A filter on the list of people returned based on whether these people are owners of the account’s company.
-
#representative ⇒ Object
A filter on the list of people returned based on whether these people are the representative of the account’s company.
Instance Method Summary collapse
-
#initialize(authorizer: nil, director: nil, executive: nil, legal_guardian: nil, owner: nil, representative: nil) ⇒ Relationship
constructor
A new instance of Relationship.
Methods inherited from RequestParams
Constructor Details
#initialize(authorizer: nil, director: nil, executive: nil, legal_guardian: nil, owner: nil, representative: nil) ⇒ Relationship
Returns a new instance of Relationship.
4651 4652 4653 4654 4655 4656 4657 4658 4659 4660 4661 4662 4663 4664 4665 |
# File 'lib/stripe/resources/account.rb', line 4651 def initialize( authorizer: nil, director: nil, executive: nil, legal_guardian: nil, owner: nil, representative: nil ) @authorizer = @director = director @executive = executive @legal_guardian = legal_guardian @owner = owner @representative = representative end |
Instance Attribute Details
#authorizer ⇒ Object
A filter on the list of people returned based on whether these people are authorizers of the account’s representative.
4639 4640 4641 |
# File 'lib/stripe/resources/account.rb', line 4639 def @authorizer end |
#director ⇒ Object
A filter on the list of people returned based on whether these people are directors of the account’s company.
4641 4642 4643 |
# File 'lib/stripe/resources/account.rb', line 4641 def director @director end |
#executive ⇒ Object
A filter on the list of people returned based on whether these people are executives of the account’s company.
4643 4644 4645 |
# File 'lib/stripe/resources/account.rb', line 4643 def executive @executive end |
#legal_guardian ⇒ Object
A filter on the list of people returned based on whether these people are legal guardians of the account’s representative.
4645 4646 4647 |
# File 'lib/stripe/resources/account.rb', line 4645 def legal_guardian @legal_guardian end |
#owner ⇒ Object
A filter on the list of people returned based on whether these people are owners of the account’s company.
4647 4648 4649 |
# File 'lib/stripe/resources/account.rb', line 4647 def owner @owner end |
#representative ⇒ Object
A filter on the list of people returned based on whether these people are the representative of the account’s company.
4649 4650 4651 |
# File 'lib/stripe/resources/account.rb', line 4649 def representative @representative end |