Class: Stripe::Account::PersonsParams::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(authorizer: nil, director: nil, executive: nil, legal_guardian: nil, owner: nil, representative: nil) ⇒ Relationship

Returns a new instance of Relationship.



4624
4625
4626
4627
4628
4629
4630
4631
4632
4633
4634
4635
4636
4637
4638
# File 'lib/stripe/resources/account.rb', line 4624

def initialize(
  authorizer: nil,
  director: nil,
  executive: nil,
  legal_guardian: nil,
  owner: nil,
  representative: nil
)
  @authorizer = authorizer
  @director = director
  @executive = executive
  @legal_guardian = legal_guardian
  @owner = owner
  @representative = representative
end

Instance Attribute Details

#authorizerObject

A filter on the list of people returned based on whether these people are authorizers of the account’s representative.



4612
4613
4614
# File 'lib/stripe/resources/account.rb', line 4612

def authorizer
  @authorizer
end

#directorObject

A filter on the list of people returned based on whether these people are directors of the account’s company.



4614
4615
4616
# File 'lib/stripe/resources/account.rb', line 4614

def director
  @director
end

#executiveObject

A filter on the list of people returned based on whether these people are executives of the account’s company.



4616
4617
4618
# File 'lib/stripe/resources/account.rb', line 4616

def executive
  @executive
end

A filter on the list of people returned based on whether these people are legal guardians of the account’s representative.



4618
4619
4620
# File 'lib/stripe/resources/account.rb', line 4618

def legal_guardian
  @legal_guardian
end

#ownerObject

A filter on the list of people returned based on whether these people are owners of the account’s company.



4620
4621
4622
# File 'lib/stripe/resources/account.rb', line 4620

def owner
  @owner
end

#representativeObject

A filter on the list of people returned based on whether these people are the representative of the account’s company.



4622
4623
4624
# File 'lib/stripe/resources/account.rb', line 4622

def representative
  @representative
end