Class: Stripe::Account::PersonsParams::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(authorizer: nil, director: nil, executive: nil, legal_guardian: nil, owner: nil, representative: nil) ⇒ Relationship

Returns a new instance of Relationship.



5274
5275
5276
5277
5278
5279
5280
5281
5282
5283
5284
5285
5286
5287
5288
# File 'lib/stripe/resources/account.rb', line 5274

def initialize(
  authorizer: nil,
  director: nil,
  executive: nil,
  legal_guardian: nil,
  owner: nil,
  representative: nil
)
  @authorizer = authorizer
  @director = director
  @executive = executive
  @legal_guardian = legal_guardian
  @owner = owner
  @representative = representative
end

Instance Attribute Details

#authorizerObject

A filter on the list of people returned based on whether these people are authorizers of the account’s representative.



5262
5263
5264
# File 'lib/stripe/resources/account.rb', line 5262

def authorizer
  @authorizer
end

#directorObject

A filter on the list of people returned based on whether these people are directors of the account’s company.



5264
5265
5266
# File 'lib/stripe/resources/account.rb', line 5264

def director
  @director
end

#executiveObject

A filter on the list of people returned based on whether these people are executives of the account’s company.



5266
5267
5268
# File 'lib/stripe/resources/account.rb', line 5266

def executive
  @executive
end

A filter on the list of people returned based on whether these people are legal guardians of the account’s representative.



5268
5269
5270
# File 'lib/stripe/resources/account.rb', line 5268

def legal_guardian
  @legal_guardian
end

#ownerObject

A filter on the list of people returned based on whether these people are owners of the account’s company.



5270
5271
5272
# File 'lib/stripe/resources/account.rb', line 5270

def owner
  @owner
end

#representativeObject

A filter on the list of people returned based on whether these people are the representative of the account’s company.



5272
5273
5274
# File 'lib/stripe/resources/account.rb', line 5272

def representative
  @representative
end