Class: Stripe::Account::PersonsParams::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(authorizer: nil, director: nil, executive: nil, legal_guardian: nil, owner: nil, representative: nil) ⇒ Relationship

Returns a new instance of Relationship.



5225
5226
5227
5228
5229
5230
5231
5232
5233
5234
5235
5236
5237
5238
5239
# File 'lib/stripe/resources/account.rb', line 5225

def initialize(
  authorizer: nil,
  director: nil,
  executive: nil,
  legal_guardian: nil,
  owner: nil,
  representative: nil
)
  @authorizer = authorizer
  @director = director
  @executive = executive
  @legal_guardian = legal_guardian
  @owner = owner
  @representative = representative
end

Instance Attribute Details

#authorizerObject

A filter on the list of people returned based on whether these people are authorizers of the account’s representative.



5213
5214
5215
# File 'lib/stripe/resources/account.rb', line 5213

def authorizer
  @authorizer
end

#directorObject

A filter on the list of people returned based on whether these people are directors of the account’s company.



5215
5216
5217
# File 'lib/stripe/resources/account.rb', line 5215

def director
  @director
end

#executiveObject

A filter on the list of people returned based on whether these people are executives of the account’s company.



5217
5218
5219
# File 'lib/stripe/resources/account.rb', line 5217

def executive
  @executive
end

A filter on the list of people returned based on whether these people are legal guardians of the account’s representative.



5219
5220
5221
# File 'lib/stripe/resources/account.rb', line 5219

def legal_guardian
  @legal_guardian
end

#ownerObject

A filter on the list of people returned based on whether these people are owners of the account’s company.



5221
5222
5223
# File 'lib/stripe/resources/account.rb', line 5221

def owner
  @owner
end

#representativeObject

A filter on the list of people returned based on whether these people are the representative of the account’s company.



5223
5224
5225
# File 'lib/stripe/resources/account.rb', line 5223

def representative
  @representative
end