Class: Stripe::Account::PersonsParams::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(authorizer: nil, director: nil, executive: nil, legal_guardian: nil, owner: nil, representative: nil) ⇒ Relationship

Returns a new instance of Relationship.



5215
5216
5217
5218
5219
5220
5221
5222
5223
5224
5225
5226
5227
5228
5229
# File 'lib/stripe/resources/account.rb', line 5215

def initialize(
  authorizer: nil,
  director: nil,
  executive: nil,
  legal_guardian: nil,
  owner: nil,
  representative: nil
)
  @authorizer = authorizer
  @director = director
  @executive = executive
  @legal_guardian = legal_guardian
  @owner = owner
  @representative = representative
end

Instance Attribute Details

#authorizerObject

A filter on the list of people returned based on whether these people are authorizers of the account’s representative.



5203
5204
5205
# File 'lib/stripe/resources/account.rb', line 5203

def authorizer
  @authorizer
end

#directorObject

A filter on the list of people returned based on whether these people are directors of the account’s company.



5205
5206
5207
# File 'lib/stripe/resources/account.rb', line 5205

def director
  @director
end

#executiveObject

A filter on the list of people returned based on whether these people are executives of the account’s company.



5207
5208
5209
# File 'lib/stripe/resources/account.rb', line 5207

def executive
  @executive
end

A filter on the list of people returned based on whether these people are legal guardians of the account’s representative.



5209
5210
5211
# File 'lib/stripe/resources/account.rb', line 5209

def legal_guardian
  @legal_guardian
end

#ownerObject

A filter on the list of people returned based on whether these people are owners of the account’s company.



5211
5212
5213
# File 'lib/stripe/resources/account.rb', line 5211

def owner
  @owner
end

#representativeObject

A filter on the list of people returned based on whether these people are the representative of the account’s company.



5213
5214
5215
# File 'lib/stripe/resources/account.rb', line 5213

def representative
  @representative
end