Class: Stripe::Account::PersonsParams::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(authorizer: nil, director: nil, executive: nil, legal_guardian: nil, owner: nil, representative: nil) ⇒ Relationship

Returns a new instance of Relationship.



5693
5694
5695
5696
5697
5698
5699
5700
5701
5702
5703
5704
5705
5706
5707
# File 'lib/stripe/resources/account.rb', line 5693

def initialize(
  authorizer: nil,
  director: nil,
  executive: nil,
  legal_guardian: nil,
  owner: nil,
  representative: nil
)
  @authorizer = authorizer
  @director = director
  @executive = executive
  @legal_guardian = legal_guardian
  @owner = owner
  @representative = representative
end

Instance Attribute Details

#authorizerObject

A filter on the list of people returned based on whether these people are authorizers of the account’s representative.



5676
5677
5678
# File 'lib/stripe/resources/account.rb', line 5676

def authorizer
  @authorizer
end

#directorObject

A filter on the list of people returned based on whether these people are directors of the account’s company.



5679
5680
5681
# File 'lib/stripe/resources/account.rb', line 5679

def director
  @director
end

#executiveObject

A filter on the list of people returned based on whether these people are executives of the account’s company.



5682
5683
5684
# File 'lib/stripe/resources/account.rb', line 5682

def executive
  @executive
end

A filter on the list of people returned based on whether these people are legal guardians of the account’s representative.



5685
5686
5687
# File 'lib/stripe/resources/account.rb', line 5685

def legal_guardian
  @legal_guardian
end

#ownerObject

A filter on the list of people returned based on whether these people are owners of the account’s company.



5688
5689
5690
# File 'lib/stripe/resources/account.rb', line 5688

def owner
  @owner
end

#representativeObject

A filter on the list of people returned based on whether these people are the representative of the account’s company.



5691
5692
5693
# File 'lib/stripe/resources/account.rb', line 5691

def representative
  @representative
end