Class: Stripe::Account::PersonsParams::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(authorizer: nil, director: nil, executive: nil, legal_guardian: nil, owner: nil, representative: nil) ⇒ Relationship

Returns a new instance of Relationship.



5000
5001
5002
5003
5004
5005
5006
5007
5008
5009
5010
5011
5012
5013
5014
# File 'lib/stripe/resources/account.rb', line 5000

def initialize(
  authorizer: nil,
  director: nil,
  executive: nil,
  legal_guardian: nil,
  owner: nil,
  representative: nil
)
  @authorizer = authorizer
  @director = director
  @executive = executive
  @legal_guardian = legal_guardian
  @owner = owner
  @representative = representative
end

Instance Attribute Details

#authorizerObject

A filter on the list of people returned based on whether these people are authorizers of the account’s representative.



4988
4989
4990
# File 'lib/stripe/resources/account.rb', line 4988

def authorizer
  @authorizer
end

#directorObject

A filter on the list of people returned based on whether these people are directors of the account’s company.



4990
4991
4992
# File 'lib/stripe/resources/account.rb', line 4990

def director
  @director
end

#executiveObject

A filter on the list of people returned based on whether these people are executives of the account’s company.



4992
4993
4994
# File 'lib/stripe/resources/account.rb', line 4992

def executive
  @executive
end

A filter on the list of people returned based on whether these people are legal guardians of the account’s representative.



4994
4995
4996
# File 'lib/stripe/resources/account.rb', line 4994

def legal_guardian
  @legal_guardian
end

#ownerObject

A filter on the list of people returned based on whether these people are owners of the account’s company.



4996
4997
4998
# File 'lib/stripe/resources/account.rb', line 4996

def owner
  @owner
end

#representativeObject

A filter on the list of people returned based on whether these people are the representative of the account’s company.



4998
4999
5000
# File 'lib/stripe/resources/account.rb', line 4998

def representative
  @representative
end