Class: Stripe::Account::PersonsParams::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(authorizer: nil, director: nil, executive: nil, legal_guardian: nil, owner: nil, representative: nil) ⇒ Relationship

Returns a new instance of Relationship.



5092
5093
5094
5095
5096
5097
5098
5099
5100
5101
5102
5103
5104
5105
5106
# File 'lib/stripe/resources/account.rb', line 5092

def initialize(
  authorizer: nil,
  director: nil,
  executive: nil,
  legal_guardian: nil,
  owner: nil,
  representative: nil
)
  @authorizer = authorizer
  @director = director
  @executive = executive
  @legal_guardian = legal_guardian
  @owner = owner
  @representative = representative
end

Instance Attribute Details

#authorizerObject

A filter on the list of people returned based on whether these people are authorizers of the account’s representative.



5080
5081
5082
# File 'lib/stripe/resources/account.rb', line 5080

def authorizer
  @authorizer
end

#directorObject

A filter on the list of people returned based on whether these people are directors of the account’s company.



5082
5083
5084
# File 'lib/stripe/resources/account.rb', line 5082

def director
  @director
end

#executiveObject

A filter on the list of people returned based on whether these people are executives of the account’s company.



5084
5085
5086
# File 'lib/stripe/resources/account.rb', line 5084

def executive
  @executive
end

A filter on the list of people returned based on whether these people are legal guardians of the account’s representative.



5086
5087
5088
# File 'lib/stripe/resources/account.rb', line 5086

def legal_guardian
  @legal_guardian
end

#ownerObject

A filter on the list of people returned based on whether these people are owners of the account’s company.



5088
5089
5090
# File 'lib/stripe/resources/account.rb', line 5088

def owner
  @owner
end

#representativeObject

A filter on the list of people returned based on whether these people are the representative of the account’s company.



5090
5091
5092
# File 'lib/stripe/resources/account.rb', line 5090

def representative
  @representative
end