Class: Stripe::Account::Requirements

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: Alternative, Error

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#alternativesObject (readonly)

Fields that are due and can be resolved by providing the corresponding alternative fields instead. Many alternatives can list the same original_fields_due, and any of these alternatives can serve as a pathway for attempting to resolve the fields again. Re-providing original_fields_due also serves as a pathway for attempting to resolve the fields again.



795
796
797
# File 'lib/stripe/resources/account.rb', line 795

def alternatives
  @alternatives
end

#current_deadlineObject (readonly)

Date by which the fields in currently_due must be collected to keep the account enabled. These fields may disable the account sooner if the next threshold is reached before they are collected.



797
798
799
# File 'lib/stripe/resources/account.rb', line 797

def current_deadline
  @current_deadline
end

#currently_dueObject (readonly)

Fields that need to be resolved to keep the account enabled. If not resolved by current_deadline, these fields will appear in past_due as well, and the account will be disabled.



799
800
801
# File 'lib/stripe/resources/account.rb', line 799

def currently_due
  @currently_due
end

#disabled_reasonObject (readonly)

If the account is disabled, this enum describes why. Learn more about handling verification issues.



801
802
803
# File 'lib/stripe/resources/account.rb', line 801

def disabled_reason
  @disabled_reason
end

#errorsObject (readonly)

Fields that are currently_due and need to be collected again because validation or verification failed.



803
804
805
# File 'lib/stripe/resources/account.rb', line 803

def errors
  @errors
end

#eventually_dueObject (readonly)

Fields you must collect when all thresholds are reached. As they become required, they appear in currently_due as well, and current_deadline becomes set.



805
806
807
# File 'lib/stripe/resources/account.rb', line 805

def eventually_due
  @eventually_due
end

#past_dueObject (readonly)

Fields that haven't been resolved by current_deadline. These fields need to be resolved to enable the account.



807
808
809
# File 'lib/stripe/resources/account.rb', line 807

def past_due
  @past_due
end

#pending_verificationObject (readonly)

Fields that are being reviewed, or might become required depending on the results of a review. If the review fails, these fields can move to eventually_due, currently_due, past_due or alternatives. Fields might appear in eventually_due, currently_due, past_due or alternatives and in pending_verification if one verification fails but another is still pending.



809
810
811
# File 'lib/stripe/resources/account.rb', line 809

def pending_verification
  @pending_verification
end

Class Method Details

.field_remappingsObject



815
816
817
# File 'lib/stripe/resources/account.rb', line 815

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



811
812
813
# File 'lib/stripe/resources/account.rb', line 811

def self.inner_class_types
  @inner_class_types = { alternatives: Alternative, errors: Error }
end