Class: Stripe::Account::Requirements
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Account::Requirements
- Defined in:
- lib/stripe/resources/account.rb
Defined Under Namespace
Classes: Alternative, Error
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#alternatives ⇒ Object
readonly
Fields that are due and can be satisfied by providing the corresponding alternative fields instead.
-
#current_deadline ⇒ Object
readonly
Date by which the fields in ‘currently_due` must be collected to keep the account enabled.
-
#currently_due ⇒ Object
readonly
Fields that need to be collected to keep the account enabled.
-
#disabled_reason ⇒ Object
readonly
If the account is disabled, this enum describes why.
-
#errors ⇒ Object
readonly
Fields that are ‘currently_due` and need to be collected again because validation or verification failed.
-
#eventually_due ⇒ Object
readonly
Fields you must collect when all thresholds are reached.
-
#past_due ⇒ Object
readonly
Fields that weren’t collected by ‘current_deadline`.
-
#pending_verification ⇒ Object
readonly
Fields that might become required depending on the results of verification or review.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#alternatives ⇒ Object (readonly)
Fields that are due and can be satisfied by providing the corresponding alternative fields instead.
709 710 711 |
# File 'lib/stripe/resources/account.rb', line 709 def alternatives @alternatives end |
#current_deadline ⇒ Object (readonly)
Date by which the fields in ‘currently_due` must be collected to keep the account enabled. These fields may disable the account sooner if the next threshold is reached before they are collected.
711 712 713 |
# File 'lib/stripe/resources/account.rb', line 711 def current_deadline @current_deadline end |
#currently_due ⇒ Object (readonly)
Fields that need to be collected to keep the account enabled. If not collected by ‘current_deadline`, these fields appear in `past_due` as well, and the account is disabled.
713 714 715 |
# File 'lib/stripe/resources/account.rb', line 713 def currently_due @currently_due end |
#disabled_reason ⇒ Object (readonly)
If the account is disabled, this enum describes why. [Learn more about handling verification issues](stripe.com/docs/connect/handling-api-verification).
715 716 717 |
# File 'lib/stripe/resources/account.rb', line 715 def disabled_reason @disabled_reason end |
#errors ⇒ Object (readonly)
Fields that are ‘currently_due` and need to be collected again because validation or verification failed.
717 718 719 |
# File 'lib/stripe/resources/account.rb', line 717 def errors @errors end |
#eventually_due ⇒ Object (readonly)
Fields you must collect when all thresholds are reached. As they become required, they appear in ‘currently_due` as well, and `current_deadline` becomes set.
719 720 721 |
# File 'lib/stripe/resources/account.rb', line 719 def eventually_due @eventually_due end |
#past_due ⇒ Object (readonly)
Fields that weren’t collected by ‘current_deadline`. These fields need to be collected to enable the account.
721 722 723 |
# File 'lib/stripe/resources/account.rb', line 721 def past_due @past_due end |
#pending_verification ⇒ Object (readonly)
Fields that might become required depending on the results of verification or review. It’s an empty array unless an asynchronous verification is pending. If verification fails, these fields move to ‘eventually_due`, `currently_due`, or `past_due`. Fields might appear in `eventually_due`, `currently_due`, or `past_due` and in `pending_verification` if verification fails but another verification is still pending.
723 724 725 |
# File 'lib/stripe/resources/account.rb', line 723 def pending_verification @pending_verification end |
Class Method Details
.field_remappings ⇒ Object
729 730 731 |
# File 'lib/stripe/resources/account.rb', line 729 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
725 726 727 |
# File 'lib/stripe/resources/account.rb', line 725 def self.inner_class_types @inner_class_types = { alternatives: Alternative, errors: Error } end |