Class: Stripe::Account::Requirements

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: Alternative, Error

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#alternativesObject (readonly)

Fields that are due and can be satisfied by providing the corresponding alternative fields instead.



431
432
433
# File 'lib/stripe/resources/account.rb', line 431

def alternatives
  @alternatives
end

#current_deadlineObject (readonly)

Date by which the fields in ‘currently_due` must be collected to keep the account enabled. These fields may disable the account sooner if the next threshold is reached before they are collected.



433
434
435
# File 'lib/stripe/resources/account.rb', line 433

def current_deadline
  @current_deadline
end

#currently_dueObject (readonly)

Fields that need to be collected to keep the account enabled. If not collected by ‘current_deadline`, these fields appear in `past_due` as well, and the account is disabled.



435
436
437
# File 'lib/stripe/resources/account.rb', line 435

def currently_due
  @currently_due
end

#disabled_reasonObject (readonly)

If the account is disabled, this enum describes why. [Learn more about handling verification issues](stripe.com/docs/connect/handling-api-verification).



437
438
439
# File 'lib/stripe/resources/account.rb', line 437

def disabled_reason
  @disabled_reason
end

#errorsObject (readonly)

Fields that are ‘currently_due` and need to be collected again because validation or verification failed.



439
440
441
# File 'lib/stripe/resources/account.rb', line 439

def errors
  @errors
end

#eventually_dueObject (readonly)

Fields you must collect when all thresholds are reached. As they become required, they appear in ‘currently_due` as well, and `current_deadline` becomes set.



441
442
443
# File 'lib/stripe/resources/account.rb', line 441

def eventually_due
  @eventually_due
end

#past_dueObject (readonly)

Fields that weren’t collected by ‘current_deadline`. These fields need to be collected to enable the account.



443
444
445
# File 'lib/stripe/resources/account.rb', line 443

def past_due
  @past_due
end

#pending_verificationObject (readonly)

Fields that might become required depending on the results of verification or review. It’s an empty array unless an asynchronous verification is pending. If verification fails, these fields move to ‘eventually_due`, `currently_due`, or `past_due`. Fields might appear in `eventually_due`, `currently_due`, or `past_due` and in `pending_verification` if verification fails but another verification is still pending.



445
446
447
# File 'lib/stripe/resources/account.rb', line 445

def pending_verification
  @pending_verification
end