Class: Stripe::Account::Settings::CardPayments
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Account::Settings::CardPayments
- Defined in:
- lib/stripe/resources/account.rb
Defined Under Namespace
Classes: DeclineOn
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#decline_on ⇒ Object
readonly
Attribute for field decline_on.
-
#statement_descriptor_prefix ⇒ Object
readonly
The default text that appears on credit card statements when a charge is made.
-
#statement_descriptor_prefix_kana ⇒ Object
readonly
The Kana variation of the default text that appears on credit card statements when a charge is made (Japan only).
-
#statement_descriptor_prefix_kanji ⇒ Object
readonly
The Kanji variation of the default text that appears on credit card statements when a charge is made (Japan only).
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#decline_on ⇒ Object (readonly)
Attribute for field decline_on
901 902 903 |
# File 'lib/stripe/resources/account.rb', line 901 def decline_on @decline_on end |
#statement_descriptor_prefix ⇒ Object (readonly)
The default text that appears on credit card statements when a charge is made. This field prefixes any dynamic ‘statement_descriptor` specified on the charge. `statement_descriptor_prefix` is useful for maximizing descriptor space for the dynamic portion.
903 904 905 |
# File 'lib/stripe/resources/account.rb', line 903 def statement_descriptor_prefix @statement_descriptor_prefix end |
#statement_descriptor_prefix_kana ⇒ Object (readonly)
The Kana variation of the default text that appears on credit card statements when a charge is made (Japan only). This field prefixes any dynamic ‘statement_descriptor_suffix_kana` specified on the charge. `statement_descriptor_prefix_kana` is useful for maximizing descriptor space for the dynamic portion.
905 906 907 |
# File 'lib/stripe/resources/account.rb', line 905 def statement_descriptor_prefix_kana @statement_descriptor_prefix_kana end |
#statement_descriptor_prefix_kanji ⇒ Object (readonly)
The Kanji variation of the default text that appears on credit card statements when a charge is made (Japan only). This field prefixes any dynamic ‘statement_descriptor_suffix_kanji` specified on the charge. `statement_descriptor_prefix_kanji` is useful for maximizing descriptor space for the dynamic portion.
907 908 909 |
# File 'lib/stripe/resources/account.rb', line 907 def statement_descriptor_prefix_kanji @statement_descriptor_prefix_kanji end |
Class Method Details
.field_remappings ⇒ Object
913 914 915 |
# File 'lib/stripe/resources/account.rb', line 913 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
909 910 911 |
# File 'lib/stripe/resources/account.rb', line 909 def self.inner_class_types @inner_class_types = { decline_on: DeclineOn } end |