Class: Stripe::Account::Settings::CardPayments
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Account::Settings::CardPayments
- Defined in:
- lib/stripe/resources/account.rb
Defined Under Namespace
Classes: DeclineOn
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#decline_on ⇒ Object
readonly
Attribute for field decline_on.
-
#statement_descriptor_prefix ⇒ Object
readonly
The default text that appears on credit card statements when a charge is made.
-
#statement_descriptor_prefix_kana ⇒ Object
readonly
The Kana variation of the default text that appears on credit card statements when a charge is made (Japan only).
-
#statement_descriptor_prefix_kanji ⇒ Object
readonly
The Kanji variation of the default text that appears on credit card statements when a charge is made (Japan only).
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#decline_on ⇒ Object (readonly)
Attribute for field decline_on
906 907 908 |
# File 'lib/stripe/resources/account.rb', line 906 def decline_on @decline_on end |
#statement_descriptor_prefix ⇒ Object (readonly)
The default text that appears on credit card statements when a charge is made. This field prefixes any dynamic ‘statement_descriptor` specified on the charge. `statement_descriptor_prefix` is useful for maximizing descriptor space for the dynamic portion.
908 909 910 |
# File 'lib/stripe/resources/account.rb', line 908 def statement_descriptor_prefix @statement_descriptor_prefix end |
#statement_descriptor_prefix_kana ⇒ Object (readonly)
The Kana variation of the default text that appears on credit card statements when a charge is made (Japan only). This field prefixes any dynamic ‘statement_descriptor_suffix_kana` specified on the charge. `statement_descriptor_prefix_kana` is useful for maximizing descriptor space for the dynamic portion.
910 911 912 |
# File 'lib/stripe/resources/account.rb', line 910 def statement_descriptor_prefix_kana @statement_descriptor_prefix_kana end |
#statement_descriptor_prefix_kanji ⇒ Object (readonly)
The Kanji variation of the default text that appears on credit card statements when a charge is made (Japan only). This field prefixes any dynamic ‘statement_descriptor_suffix_kanji` specified on the charge. `statement_descriptor_prefix_kanji` is useful for maximizing descriptor space for the dynamic portion.
912 913 914 |
# File 'lib/stripe/resources/account.rb', line 912 def statement_descriptor_prefix_kanji @statement_descriptor_prefix_kanji end |
Class Method Details
.field_remappings ⇒ Object
918 919 920 |
# File 'lib/stripe/resources/account.rb', line 918 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
914 915 916 |
# File 'lib/stripe/resources/account.rb', line 914 def self.inner_class_types @inner_class_types = { decline_on: DeclineOn } end |