Class: Stripe::Account::Settings::Invoices
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Account::Settings::Invoices
- Defined in:
- lib/stripe/resources/account.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#default_account_tax_ids ⇒ Object
readonly
The list of default Account Tax IDs to automatically include on invoices.
-
#hosted_payment_method_save ⇒ Object
readonly
Whether payment methods should be saved when a payment is completed for a one-time invoices on a hosted invoice page.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#default_account_tax_ids ⇒ Object (readonly)
The list of default Account Tax IDs to automatically include on invoices. Account Tax IDs get added when an invoice is finalized.
506 507 508 |
# File 'lib/stripe/resources/account.rb', line 506 def default_account_tax_ids @default_account_tax_ids end |
#hosted_payment_method_save ⇒ Object (readonly)
Whether payment methods should be saved when a payment is completed for a one-time invoices on a hosted invoice page.
508 509 510 |
# File 'lib/stripe/resources/account.rb', line 508 def hosted_payment_method_save @hosted_payment_method_save end |