Class: Stripe::Account::Settings::Payments
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Account::Settings::Payments
- Defined in:
- lib/stripe/resources/account.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#email_customers_on_successful_payment ⇒ Object
readonly
When enabled, the customer of this Account will receive an email receipt when their payment is successful.
-
#statement_descriptor ⇒ Object
readonly
The default text that appears on credit card statements when a charge is made.
-
#statement_descriptor_kana ⇒ Object
readonly
The Kana variation of
statement_descriptorused for charges in Japan. -
#statement_descriptor_kanji ⇒ Object
readonly
The Kanji variation of
statement_descriptorused for charges in Japan. -
#statement_descriptor_prefix_kana ⇒ Object
readonly
The Kana variation of
statement_descriptor_prefixused for card charges in Japan. -
#statement_descriptor_prefix_kanji ⇒ Object
readonly
The Kanji variation of
statement_descriptor_prefixused for card charges in Japan.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#email_customers_on_successful_payment ⇒ Object (readonly)
When enabled, the customer of this Account will receive an email receipt when their payment is successful. If this parameter is not set, the default value is false.
1006 1007 1008 |
# File 'lib/stripe/resources/account.rb', line 1006 def email_customers_on_successful_payment @email_customers_on_successful_payment end |
#statement_descriptor ⇒ Object (readonly)
The default text that appears on credit card statements when a charge is made. This field prefixes any dynamic statement_descriptor specified on the charge.
1008 1009 1010 |
# File 'lib/stripe/resources/account.rb', line 1008 def statement_descriptor @statement_descriptor end |
#statement_descriptor_kana ⇒ Object (readonly)
The Kana variation of statement_descriptor used for charges in Japan. Japanese statement descriptors have special requirements.
1010 1011 1012 |
# File 'lib/stripe/resources/account.rb', line 1010 def statement_descriptor_kana @statement_descriptor_kana end |
#statement_descriptor_kanji ⇒ Object (readonly)
The Kanji variation of statement_descriptor used for charges in Japan. Japanese statement descriptors have special requirements.
1012 1013 1014 |
# File 'lib/stripe/resources/account.rb', line 1012 def statement_descriptor_kanji @statement_descriptor_kanji end |
#statement_descriptor_prefix_kana ⇒ Object (readonly)
The Kana variation of statement_descriptor_prefix used for card charges in Japan. Japanese statement descriptors have special requirements.
1014 1015 1016 |
# File 'lib/stripe/resources/account.rb', line 1014 def statement_descriptor_prefix_kana @statement_descriptor_prefix_kana end |
#statement_descriptor_prefix_kanji ⇒ Object (readonly)
The Kanji variation of statement_descriptor_prefix used for card charges in Japan. Japanese statement descriptors have special requirements.
1016 1017 1018 |
# File 'lib/stripe/resources/account.rb', line 1016 def statement_descriptor_prefix_kanji @statement_descriptor_prefix_kanji end |
Class Method Details
.field_remappings ⇒ Object
1022 1023 1024 |
# File 'lib/stripe/resources/account.rb', line 1022 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1018 1019 1020 |
# File 'lib/stripe/resources/account.rb', line 1018 def self.inner_class_types @inner_class_types = {} end |