Class: Stripe::Account::Settings::Payments
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Account::Settings::Payments
- Defined in:
- lib/stripe/resources/account.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#email_customers_on_successful_payment ⇒ Object
readonly
When enabled, the customer of this Account will receive an email receipt when their payment is successful.
-
#statement_descriptor ⇒ Object
readonly
The default text that appears on credit card statements when a charge is made.
-
#statement_descriptor_kana ⇒ Object
readonly
The Kana variation of ‘statement_descriptor` used for charges in Japan.
-
#statement_descriptor_kanji ⇒ Object
readonly
The Kanji variation of ‘statement_descriptor` used for charges in Japan.
-
#statement_descriptor_prefix_kana ⇒ Object
readonly
The Kana variation of ‘statement_descriptor_prefix` used for card charges in Japan.
-
#statement_descriptor_prefix_kanji ⇒ Object
readonly
The Kanji variation of ‘statement_descriptor_prefix` used for card charges in Japan.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#email_customers_on_successful_payment ⇒ Object (readonly)
When enabled, the customer of this Account will receive an email receipt when their payment is successful. If this parameter is not set, the default value is ‘false`.
950 951 952 |
# File 'lib/stripe/resources/account.rb', line 950 def email_customers_on_successful_payment @email_customers_on_successful_payment end |
#statement_descriptor ⇒ Object (readonly)
The default text that appears on credit card statements when a charge is made. This field prefixes any dynamic ‘statement_descriptor` specified on the charge.
952 953 954 |
# File 'lib/stripe/resources/account.rb', line 952 def statement_descriptor @statement_descriptor end |
#statement_descriptor_kana ⇒ Object (readonly)
The Kana variation of ‘statement_descriptor` used for charges in Japan. Japanese statement descriptors have [special requirements](docs.stripe.com/get-started/account/statement-descriptors#set-japanese-statement-descriptors).
954 955 956 |
# File 'lib/stripe/resources/account.rb', line 954 def statement_descriptor_kana @statement_descriptor_kana end |
#statement_descriptor_kanji ⇒ Object (readonly)
The Kanji variation of ‘statement_descriptor` used for charges in Japan. Japanese statement descriptors have [special requirements](docs.stripe.com/get-started/account/statement-descriptors#set-japanese-statement-descriptors).
956 957 958 |
# File 'lib/stripe/resources/account.rb', line 956 def statement_descriptor_kanji @statement_descriptor_kanji end |
#statement_descriptor_prefix_kana ⇒ Object (readonly)
The Kana variation of ‘statement_descriptor_prefix` used for card charges in Japan. Japanese statement descriptors have [special requirements](docs.stripe.com/get-started/account/statement-descriptors#set-japanese-statement-descriptors).
958 959 960 |
# File 'lib/stripe/resources/account.rb', line 958 def statement_descriptor_prefix_kana @statement_descriptor_prefix_kana end |
#statement_descriptor_prefix_kanji ⇒ Object (readonly)
The Kanji variation of ‘statement_descriptor_prefix` used for card charges in Japan. Japanese statement descriptors have [special requirements](docs.stripe.com/get-started/account/statement-descriptors#set-japanese-statement-descriptors).
960 961 962 |
# File 'lib/stripe/resources/account.rb', line 960 def statement_descriptor_prefix_kanji @statement_descriptor_prefix_kanji end |
Class Method Details
.field_remappings ⇒ Object
966 967 968 |
# File 'lib/stripe/resources/account.rb', line 966 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
962 963 964 |
# File 'lib/stripe/resources/account.rb', line 962 def self.inner_class_types @inner_class_types = {} end |