Class: Stripe::Account::Settings::Payments
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Account::Settings::Payments
- Defined in:
- lib/stripe/resources/account.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#statement_descriptor ⇒ Object
readonly
The default text that appears on credit card statements when a charge is made.
-
#statement_descriptor_kana ⇒ Object
readonly
The Kana variation of ‘statement_descriptor` used for charges in Japan.
-
#statement_descriptor_kanji ⇒ Object
readonly
The Kanji variation of ‘statement_descriptor` used for charges in Japan.
-
#statement_descriptor_prefix_kana ⇒ Object
readonly
The Kana variation of ‘statement_descriptor_prefix` used for card charges in Japan.
-
#statement_descriptor_prefix_kanji ⇒ Object
readonly
The Kanji variation of ‘statement_descriptor_prefix` used for card charges in Japan.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#statement_descriptor ⇒ Object (readonly)
The default text that appears on credit card statements when a charge is made. This field prefixes any dynamic ‘statement_descriptor` specified on the charge.
568 569 570 |
# File 'lib/stripe/resources/account.rb', line 568 def statement_descriptor @statement_descriptor end |
#statement_descriptor_kana ⇒ Object (readonly)
The Kana variation of ‘statement_descriptor` used for charges in Japan. Japanese statement descriptors have [special requirements](docs.stripe.com/get-started/account/statement-descriptors#set-japanese-statement-descriptors).
570 571 572 |
# File 'lib/stripe/resources/account.rb', line 570 def statement_descriptor_kana @statement_descriptor_kana end |
#statement_descriptor_kanji ⇒ Object (readonly)
The Kanji variation of ‘statement_descriptor` used for charges in Japan. Japanese statement descriptors have [special requirements](docs.stripe.com/get-started/account/statement-descriptors#set-japanese-statement-descriptors).
572 573 574 |
# File 'lib/stripe/resources/account.rb', line 572 def statement_descriptor_kanji @statement_descriptor_kanji end |
#statement_descriptor_prefix_kana ⇒ Object (readonly)
The Kana variation of ‘statement_descriptor_prefix` used for card charges in Japan. Japanese statement descriptors have [special requirements](docs.stripe.com/get-started/account/statement-descriptors#set-japanese-statement-descriptors).
574 575 576 |
# File 'lib/stripe/resources/account.rb', line 574 def statement_descriptor_prefix_kana @statement_descriptor_prefix_kana end |
#statement_descriptor_prefix_kanji ⇒ Object (readonly)
The Kanji variation of ‘statement_descriptor_prefix` used for card charges in Japan. Japanese statement descriptors have [special requirements](docs.stripe.com/get-started/account/statement-descriptors#set-japanese-statement-descriptors).
576 577 578 |
# File 'lib/stripe/resources/account.rb', line 576 def statement_descriptor_prefix_kanji @statement_descriptor_prefix_kanji end |