Class: Stripe::Account::Settings::Payouts

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: Schedule

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#debit_negative_balancesObject (readonly)

A Boolean indicating if Stripe should try to reclaim negative balances from an attached bank account. See Understanding Connect account balances for details. The default value is false when controller.requirement_collection is application, which includes Custom accounts, otherwise true.



1051
1052
1053
# File 'lib/stripe/resources/account.rb', line 1051

def debit_negative_balances
  @debit_negative_balances
end

#scheduleObject (readonly)

Attribute for field schedule



1053
1054
1055
# File 'lib/stripe/resources/account.rb', line 1053

def schedule
  @schedule
end

#statement_descriptorObject (readonly)

The text that appears on the bank account statement for payouts. If not set, this defaults to the platform's bank descriptor as set in the Dashboard.



1055
1056
1057
# File 'lib/stripe/resources/account.rb', line 1055

def statement_descriptor
  @statement_descriptor
end

Class Method Details

.field_remappingsObject



1061
1062
1063
# File 'lib/stripe/resources/account.rb', line 1061

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1057
1058
1059
# File 'lib/stripe/resources/account.rb', line 1057

def self.inner_class_types
  @inner_class_types = { schedule: Schedule }
end