Class: Stripe::Account::Settings::Payouts

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: Schedule

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#debit_negative_balancesObject (readonly)

A Boolean indicating if Stripe should try to reclaim negative balances from an attached bank account. See [Understanding Connect account balances](/connect/account-balances) for details. The default value is ‘false` when [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is `application`, which includes Custom accounts, otherwise `true`.



838
839
840
# File 'lib/stripe/resources/account.rb', line 838

def debit_negative_balances
  @debit_negative_balances
end

#scheduleObject (readonly)

Attribute for field schedule



840
841
842
# File 'lib/stripe/resources/account.rb', line 840

def schedule
  @schedule
end

#statement_descriptorObject (readonly)

The text that appears on the bank account statement for payouts. If not set, this defaults to the platform’s bank descriptor as set in the Dashboard.



842
843
844
# File 'lib/stripe/resources/account.rb', line 842

def statement_descriptor
  @statement_descriptor
end

Class Method Details

.field_remappingsObject



848
849
850
# File 'lib/stripe/resources/account.rb', line 848

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



844
845
846
# File 'lib/stripe/resources/account.rb', line 844

def self.inner_class_types
  @inner_class_types = { schedule: Schedule }
end