Class: Stripe::Account::Settings::Payouts
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Account::Settings::Payouts
- Defined in:
- lib/stripe/resources/account.rb
Defined Under Namespace
Classes: Schedule
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#debit_negative_balances ⇒ Object
readonly
A Boolean indicating if Stripe should try to reclaim negative balances from an attached bank account.
-
#schedule ⇒ Object
readonly
Attribute for field schedule.
-
#statement_descriptor ⇒ Object
readonly
The text that appears on the bank account statement for payouts.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#debit_negative_balances ⇒ Object (readonly)
A Boolean indicating if Stripe should try to reclaim negative balances from an attached bank account. See [Understanding Connect account balances](/connect/account-balances) for details. The default value is ‘false` when [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is `application`, which includes Custom accounts, otherwise `true`.
976 977 978 |
# File 'lib/stripe/resources/account.rb', line 976 def debit_negative_balances @debit_negative_balances end |
#schedule ⇒ Object (readonly)
Attribute for field schedule
978 979 980 |
# File 'lib/stripe/resources/account.rb', line 978 def schedule @schedule end |
#statement_descriptor ⇒ Object (readonly)
The text that appears on the bank account statement for payouts. If not set, this defaults to the platform’s bank descriptor as set in the Dashboard.
980 981 982 |
# File 'lib/stripe/resources/account.rb', line 980 def statement_descriptor @statement_descriptor end |
Class Method Details
.field_remappings ⇒ Object
986 987 988 |
# File 'lib/stripe/resources/account.rb', line 986 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
982 983 984 |
# File 'lib/stripe/resources/account.rb', line 982 def self.inner_class_types @inner_class_types = { schedule: Schedule } end |