Class: Stripe::Account::Settings::Payouts::Schedule
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Account::Settings::Payouts::Schedule
- Defined in:
- lib/stripe/resources/account.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#delay_days ⇒ Object
readonly
The number of days charges for the account will be held before being paid out.
-
#interval ⇒ Object
readonly
How frequently funds will be paid out.
-
#monthly_anchor ⇒ Object
readonly
The day of the month funds will be paid out.
-
#monthly_payout_days ⇒ Object
readonly
The days of the month funds will be paid out.
-
#weekly_anchor ⇒ Object
readonly
The day of the week funds will be paid out, of the style 'monday', 'tuesday', etc.
-
#weekly_payout_days ⇒ Object
readonly
The days of the week when available funds are paid out, specified as an array, for example, [
monday,tuesday].
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#delay_days ⇒ Object (readonly)
The number of days charges for the account will be held before being paid out.
903 904 905 |
# File 'lib/stripe/resources/account.rb', line 903 def delay_days @delay_days end |
#interval ⇒ Object (readonly)
How frequently funds will be paid out. One of manual (payouts only created via API call), daily, weekly, or monthly.
905 906 907 |
# File 'lib/stripe/resources/account.rb', line 905 def interval @interval end |
#monthly_anchor ⇒ Object (readonly)
The day of the month funds will be paid out. Only shown if interval is monthly. Payouts scheduled between the 29th and 31st of the month are sent on the last day of shorter months.
907 908 909 |
# File 'lib/stripe/resources/account.rb', line 907 def monthly_anchor @monthly_anchor end |
#monthly_payout_days ⇒ Object (readonly)
The days of the month funds will be paid out. Only shown if interval is monthly. Payouts scheduled between the 29th and 31st of the month are sent on the last day of shorter months.
909 910 911 |
# File 'lib/stripe/resources/account.rb', line 909 def monthly_payout_days @monthly_payout_days end |
#weekly_anchor ⇒ Object (readonly)
The day of the week funds will be paid out, of the style 'monday', 'tuesday', etc. Only shown if interval is weekly.
911 912 913 |
# File 'lib/stripe/resources/account.rb', line 911 def weekly_anchor @weekly_anchor end |
#weekly_payout_days ⇒ Object (readonly)
The days of the week when available funds are paid out, specified as an array, for example, [monday, tuesday]. Only shown if interval is weekly.
913 914 915 |
# File 'lib/stripe/resources/account.rb', line 913 def weekly_payout_days @weekly_payout_days end |
Class Method Details
.field_remappings ⇒ Object
919 920 921 |
# File 'lib/stripe/resources/account.rb', line 919 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
915 916 917 |
# File 'lib/stripe/resources/account.rb', line 915 def self.inner_class_types @inner_class_types = {} end |