Class: Stripe::Account::Settings::Payouts::Schedule

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#delay_daysObject (readonly)

The number of days charges for the account will be held before being paid out.



609
610
611
# File 'lib/stripe/resources/account.rb', line 609

def delay_days
  @delay_days
end

#intervalObject (readonly)

How frequently funds will be paid out. One of ‘manual` (payouts only created via API call), `daily`, `weekly`, or `monthly`.



611
612
613
# File 'lib/stripe/resources/account.rb', line 611

def interval
  @interval
end

#monthly_anchorObject (readonly)

The day of the month funds will be paid out. Only shown if ‘interval` is monthly. Payouts scheduled between the 29th and 31st of the month are sent on the last day of shorter months.



613
614
615
# File 'lib/stripe/resources/account.rb', line 613

def monthly_anchor
  @monthly_anchor
end

#monthly_payout_daysObject (readonly)

The days of the month funds will be paid out. Only shown if ‘interval` is monthly. Payouts scheduled between the 29th and 31st of the month are sent on the last day of shorter months.



615
616
617
# File 'lib/stripe/resources/account.rb', line 615

def monthly_payout_days
  @monthly_payout_days
end

#weekly_anchorObject (readonly)

The day of the week funds will be paid out, of the style ‘monday’, ‘tuesday’, etc. Only shown if ‘interval` is weekly.



617
618
619
# File 'lib/stripe/resources/account.rb', line 617

def weekly_anchor
  @weekly_anchor
end

#weekly_payout_daysObject (readonly)

The days of the week when available funds are paid out, specified as an array, for example, [‘monday`, `tuesday`]. Only shown if `interval` is weekly.



619
620
621
# File 'lib/stripe/resources/account.rb', line 619

def weekly_payout_days
  @weekly_payout_days
end