Class: Stripe::Account::Settings::Payouts::Schedule
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Account::Settings::Payouts::Schedule
- Defined in:
- lib/stripe/resources/account.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#delay_days ⇒ Object
readonly
The number of days charges for the account will be held before being paid out.
-
#interval ⇒ Object
readonly
How frequently funds will be paid out.
-
#monthly_anchor ⇒ Object
readonly
The day of the month funds will be paid out.
-
#weekly_anchor ⇒ Object
readonly
The day of the week funds will be paid out, of the style ‘monday’, ‘tuesday’, etc.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#delay_days ⇒ Object (readonly)
The number of days charges for the account will be held before being paid out.
580 581 582 |
# File 'lib/stripe/resources/account.rb', line 580 def delay_days @delay_days end |
#interval ⇒ Object (readonly)
How frequently funds will be paid out. One of ‘manual` (payouts only created via API call), `daily`, `weekly`, or `monthly`.
582 583 584 |
# File 'lib/stripe/resources/account.rb', line 582 def interval @interval end |
#monthly_anchor ⇒ Object (readonly)
The day of the month funds will be paid out. Only shown if ‘interval` is monthly. Payouts scheduled between the 29th and 31st of the month are sent on the last day of shorter months.
584 585 586 |
# File 'lib/stripe/resources/account.rb', line 584 def monthly_anchor @monthly_anchor end |
#weekly_anchor ⇒ Object (readonly)
The day of the week funds will be paid out, of the style ‘monday’, ‘tuesday’, etc. Only shown if ‘interval` is weekly.
586 587 588 |
# File 'lib/stripe/resources/account.rb', line 586 def weekly_anchor @weekly_anchor end |