Class: Stripe::Account::Settings::PaypayPayments
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Account::Settings::PaypayPayments
- Defined in:
- lib/stripe/resources/account.rb
Defined Under Namespace
Classes: Site
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#additional_files ⇒ Object
readonly
Additional files that are required to support the onboarding process of your business.
-
#goods_type ⇒ Object
readonly
The type of goods your business sells.
-
#site ⇒ Object
readonly
Attribute for field site.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#additional_files ⇒ Object (readonly)
Additional files that are required to support the onboarding process of your business.
1071 1072 1073 |
# File 'lib/stripe/resources/account.rb', line 1071 def additional_files @additional_files end |
#goods_type ⇒ Object (readonly)
The type of goods your business sells. Use ‘digital_content` if you sell digital content. Use `other` for all other types of goods or services.
1073 1074 1075 |
# File 'lib/stripe/resources/account.rb', line 1073 def goods_type @goods_type end |
#site ⇒ Object (readonly)
Attribute for field site
1075 1076 1077 |
# File 'lib/stripe/resources/account.rb', line 1075 def site @site end |
Class Method Details
.field_remappings ⇒ Object
1081 1082 1083 |
# File 'lib/stripe/resources/account.rb', line 1081 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1077 1078 1079 |
# File 'lib/stripe/resources/account.rb', line 1077 def self.inner_class_types @inner_class_types = { site: Site } end |