Class: Stripe::Account::TosAcceptance

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/account.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#dateObject (readonly)

The Unix timestamp marking when the account representative accepted their service agreement



1137
1138
1139
# File 'lib/stripe/resources/account.rb', line 1137

def date
  @date
end

#ipObject (readonly)

The IP address from which the account representative accepted their service agreement



1139
1140
1141
# File 'lib/stripe/resources/account.rb', line 1139

def ip
  @ip
end

#service_agreementObject (readonly)

The user’s service agreement type



1141
1142
1143
# File 'lib/stripe/resources/account.rb', line 1141

def service_agreement
  @service_agreement
end

#user_agentObject (readonly)

The user agent of the browser from which the account representative accepted their service agreement



1143
1144
1145
# File 'lib/stripe/resources/account.rb', line 1143

def user_agent
  @user_agent
end

Class Method Details

.field_remappingsObject



1149
1150
1151
# File 'lib/stripe/resources/account.rb', line 1149

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1145
1146
1147
# File 'lib/stripe/resources/account.rb', line 1145

def self.inner_class_types
  @inner_class_types = {}
end