Class: Stripe::Account::TosAcceptance
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Account::TosAcceptance
- Defined in:
- lib/stripe/resources/account.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#date ⇒ Object
readonly
The Unix timestamp marking when the account representative accepted their service agreement.
-
#ip ⇒ Object
readonly
The IP address from which the account representative accepted their service agreement.
-
#service_agreement ⇒ Object
readonly
The user’s service agreement type.
-
#user_agent ⇒ Object
readonly
The user agent of the browser from which the account representative accepted their service agreement.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#date ⇒ Object (readonly)
The Unix timestamp marking when the account representative accepted their service agreement
1099 1100 1101 |
# File 'lib/stripe/resources/account.rb', line 1099 def date @date end |
#ip ⇒ Object (readonly)
The IP address from which the account representative accepted their service agreement
1101 1102 1103 |
# File 'lib/stripe/resources/account.rb', line 1101 def ip @ip end |
#service_agreement ⇒ Object (readonly)
The user’s service agreement type
1103 1104 1105 |
# File 'lib/stripe/resources/account.rb', line 1103 def service_agreement @service_agreement end |
#user_agent ⇒ Object (readonly)
The user agent of the browser from which the account representative accepted their service agreement
1105 1106 1107 |
# File 'lib/stripe/resources/account.rb', line 1105 def user_agent @user_agent end |
Class Method Details
.field_remappings ⇒ Object
1111 1112 1113 |
# File 'lib/stripe/resources/account.rb', line 1111 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1107 1108 1109 |
# File 'lib/stripe/resources/account.rb', line 1107 def self.inner_class_types @inner_class_types = {} end |