Class: Stripe::Account::TosAcceptance
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Account::TosAcceptance
- Defined in:
- lib/stripe/resources/account.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#date ⇒ Object
readonly
The Unix timestamp marking when the account representative accepted their service agreement.
-
#ip ⇒ Object
readonly
The IP address from which the account representative accepted their service agreement.
-
#service_agreement ⇒ Object
readonly
The user’s service agreement type.
-
#user_agent ⇒ Object
readonly
The user agent of the browser from which the account representative accepted their service agreement.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#date ⇒ Object (readonly)
The Unix timestamp marking when the account representative accepted their service agreement
821 822 823 |
# File 'lib/stripe/resources/account.rb', line 821 def date @date end |
#ip ⇒ Object (readonly)
The IP address from which the account representative accepted their service agreement
824 825 826 |
# File 'lib/stripe/resources/account.rb', line 824 def ip @ip end |
#service_agreement ⇒ Object (readonly)
The user’s service agreement type
827 828 829 |
# File 'lib/stripe/resources/account.rb', line 827 def service_agreement @service_agreement end |
#user_agent ⇒ Object (readonly)
The user agent of the browser from which the account representative accepted their service agreement
830 831 832 |
# File 'lib/stripe/resources/account.rb', line 830 def user_agent @user_agent end |