Class: Stripe::Account::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::UpdateParams
- Defined in:
- lib/stripe/resources/account.rb
Defined Under Namespace
Classes: BankAccount, BusinessProfile, Capabilities, Card, CardToken, Company, Documents, Groups, Individual, RiskControls, Settings, TosAcceptance
Instance Attribute Summary collapse
-
#account_token ⇒ Object
An [account token](stripe.com/docs/api#create_account_token), used to securely provide details to the account.
-
#business_profile ⇒ Object
Business information about the account.
-
#business_type ⇒ Object
The business type.
-
#capabilities ⇒ Object
Each key of the dictionary represents a capability, and each capability maps to its settings (for example, whether it has been requested or not).
-
#company ⇒ Object
Information about the company or business.
-
#default_currency ⇒ Object
Three-letter ISO currency code representing the default currency for the account.
-
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
-
#email ⇒ Object
The email address of the account holder.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#external_account ⇒ Object
A card or bank account to attach to the account for receiving [payouts](/connect/bank-debit-card-payouts) (you won’t be able to use it for top-ups).
-
#groups ⇒ Object
A hash of account group type to tokens.
-
#individual ⇒ Object
Information about the person represented by the account.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#risk_controls ⇒ Object
A hash to configure risk controls on the account.
-
#settings ⇒ Object
Options for customizing how the account functions within Stripe.
-
#tos_acceptance ⇒ Object
Details on the account’s acceptance of the [Stripe Services Agreement](/connect/updating-accounts#tos-acceptance).
Instance Method Summary collapse
-
#initialize(account_token: nil, business_profile: nil, business_type: nil, capabilities: nil, company: nil, default_currency: nil, documents: nil, email: nil, expand: nil, external_account: nil, groups: nil, individual: nil, metadata: nil, risk_controls: nil, settings: nil, tos_acceptance: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(account_token: nil, business_profile: nil, business_type: nil, capabilities: nil, company: nil, default_currency: nil, documents: nil, email: nil, expand: nil, external_account: nil, groups: nil, individual: nil, metadata: nil, risk_controls: nil, settings: nil, tos_acceptance: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 2917 2918 2919 |
# File 'lib/stripe/resources/account.rb', line 2885 def initialize( account_token: nil, business_profile: nil, business_type: nil, capabilities: nil, company: nil, default_currency: nil, documents: nil, email: nil, expand: nil, external_account: nil, groups: nil, individual: nil, metadata: nil, risk_controls: nil, settings: nil, tos_acceptance: nil ) @account_token = account_token @business_profile = business_profile @business_type = business_type @capabilities = capabilities @company = company @default_currency = default_currency @documents = documents @email = email @expand = @external_account = external_account @groups = groups @individual = individual @metadata = @risk_controls = risk_controls @settings = settings @tos_acceptance = tos_acceptance end |
Instance Attribute Details
#account_token ⇒ Object
An [account token](stripe.com/docs/api#create_account_token), used to securely provide details to the account.
2846 2847 2848 |
# File 'lib/stripe/resources/account.rb', line 2846 def account_token @account_token end |
#business_profile ⇒ Object
Business information about the account.
2848 2849 2850 |
# File 'lib/stripe/resources/account.rb', line 2848 def business_profile @business_profile end |
#business_type ⇒ Object
The business type. Once you create an [Account Link](/api/account_links) or [Account Session](/api/account_sessions), this property can only be updated for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is ‘application`, which includes Custom accounts.
2850 2851 2852 |
# File 'lib/stripe/resources/account.rb', line 2850 def business_type @business_type end |
#capabilities ⇒ Object
Each key of the dictionary represents a capability, and each capability maps to its settings (for example, whether it has been requested or not). Each capability is inactive until you have provided its specific requirements and Stripe has verified them. An account might have some of its requested capabilities be active and some be inactive.
Required when [account.controller.stripe_dashboard.type](/api/accounts/create#create_account-controller-dashboard-type) is ‘none`, which includes Custom accounts.
2859 2860 2861 |
# File 'lib/stripe/resources/account.rb', line 2859 def capabilities @capabilities end |
#company ⇒ Object
Information about the company or business. This field is available for any ‘business_type`. Once you create an [Account Link](/api/account_links) or [Account Session](/api/account_sessions), this property can only be updated for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is `application`, which includes Custom accounts.
2861 2862 2863 |
# File 'lib/stripe/resources/account.rb', line 2861 def company @company end |
#default_currency ⇒ Object
Three-letter ISO currency code representing the default currency for the account. This must be a currency that [Stripe supports in the account’s country](docs.stripe.com/payouts).
2863 2864 2865 |
# File 'lib/stripe/resources/account.rb', line 2863 def default_currency @default_currency end |
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
2865 2866 2867 |
# File 'lib/stripe/resources/account.rb', line 2865 def documents @documents end |
#email ⇒ Object
The email address of the account holder. This is only to make the account easier to identify to you. If [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is ‘application`, which includes Custom accounts, Stripe doesn’t email the account without your consent.
2867 2868 2869 |
# File 'lib/stripe/resources/account.rb', line 2867 def email @email end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2869 2870 2871 |
# File 'lib/stripe/resources/account.rb', line 2869 def @expand end |
#external_account ⇒ Object
A card or bank account to attach to the account for receiving [payouts](/connect/bank-debit-card-payouts) (you won’t be able to use it for top-ups). You can provide either a token, like the ones returned by [Stripe.js](/js), or a dictionary, as documented in the ‘external_account` parameter for [bank account](/api#account_create_bank_account) creation.
By default, providing an external account sets it as the new default external account for its currency, and deletes the old default if one exists. To add additional external accounts without replacing the existing default for the currency, use the [bank account](/api#account_create_bank_account) or [card creation](/api#account_create_card) APIs. After you create an [Account Link](/api/account_links) or [Account Session](/api/account_sessions), this property can only be updated for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is `application`, which includes Custom accounts.
2871 2872 2873 |
# File 'lib/stripe/resources/account.rb', line 2871 def external_account @external_account end |
#groups ⇒ Object
A hash of account group type to tokens. These are account groups this account should be added to.
2873 2874 2875 |
# File 'lib/stripe/resources/account.rb', line 2873 def groups @groups end |
#individual ⇒ Object
Information about the person represented by the account. This field is null unless ‘business_type` is set to `individual`. Once you create an [Account Link](/api/account_links) or [Account Session](/api/account_sessions), this property can only be updated for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is `application`, which includes Custom accounts.
2875 2876 2877 |
# File 'lib/stripe/resources/account.rb', line 2875 def individual @individual end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
2877 2878 2879 |
# File 'lib/stripe/resources/account.rb', line 2877 def @metadata end |
#risk_controls ⇒ Object
A hash to configure risk controls on the account. Please see [this page for more details](/connect/pausing-payments-or-payouts-on-connected-accounts).
2879 2880 2881 |
# File 'lib/stripe/resources/account.rb', line 2879 def risk_controls @risk_controls end |
#settings ⇒ Object
Options for customizing how the account functions within Stripe.
2881 2882 2883 |
# File 'lib/stripe/resources/account.rb', line 2881 def settings @settings end |
#tos_acceptance ⇒ Object
Details on the account’s acceptance of the [Stripe Services Agreement](/connect/updating-accounts#tos-acceptance). This property can only be updated for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is ‘application`, which includes Custom accounts. This property defaults to a `full` service agreement when empty.
2883 2884 2885 |
# File 'lib/stripe/resources/account.rb', line 2883 def tos_acceptance @tos_acceptance end |