Class: Stripe::Account::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::UpdateParams
- Defined in:
- lib/stripe/resources/account.rb
Defined Under Namespace
Classes: BankAccount, BusinessProfile, Capabilities, Card, CardToken, Company, Documents, Groups, Individual, RiskControls, Settings, TosAcceptance
Instance Attribute Summary collapse
-
#account_token ⇒ Object
An [account token](stripe.com/docs/api#create_account_token), used to securely provide details to the account.
-
#business_profile ⇒ Object
Business information about the account.
-
#business_type ⇒ Object
The business type.
-
#capabilities ⇒ Object
Each key of the dictionary represents a capability, and each capability maps to its settings (for example, whether it has been requested or not).
-
#company ⇒ Object
Information about the company or business.
-
#default_currency ⇒ Object
Three-letter ISO currency code representing the default currency for the account.
-
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
-
#email ⇒ Object
The email address of the account holder.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#external_account ⇒ Object
A card or bank account to attach to the account for receiving [payouts](/connect/bank-debit-card-payouts) (you won’t be able to use it for top-ups).
-
#groups ⇒ Object
A hash of account group type to tokens.
-
#individual ⇒ Object
Information about the person represented by the account.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#risk_controls ⇒ Object
A hash to configure risk controls on the account.
-
#settings ⇒ Object
Options for customizing how the account functions within Stripe.
-
#tos_acceptance ⇒ Object
Details on the account’s acceptance of the [Stripe Services Agreement](/connect/updating-accounts#tos-acceptance).
Instance Method Summary collapse
-
#initialize(account_token: nil, business_profile: nil, business_type: nil, capabilities: nil, company: nil, default_currency: nil, documents: nil, email: nil, expand: nil, external_account: nil, groups: nil, individual: nil, metadata: nil, risk_controls: nil, settings: nil, tos_acceptance: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(account_token: nil, business_profile: nil, business_type: nil, capabilities: nil, company: nil, default_currency: nil, documents: nil, email: nil, expand: nil, external_account: nil, groups: nil, individual: nil, metadata: nil, risk_controls: nil, settings: nil, tos_acceptance: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
2730 2731 2732 2733 2734 2735 2736 2737 2738 2739 2740 2741 2742 2743 2744 2745 2746 2747 2748 2749 2750 2751 2752 2753 2754 2755 2756 2757 2758 2759 2760 2761 2762 2763 2764 |
# File 'lib/stripe/resources/account.rb', line 2730 def initialize( account_token: nil, business_profile: nil, business_type: nil, capabilities: nil, company: nil, default_currency: nil, documents: nil, email: nil, expand: nil, external_account: nil, groups: nil, individual: nil, metadata: nil, risk_controls: nil, settings: nil, tos_acceptance: nil ) @account_token = account_token @business_profile = business_profile @business_type = business_type @capabilities = capabilities @company = company @default_currency = default_currency @documents = documents @email = email @expand = @external_account = external_account @groups = groups @individual = individual @metadata = @risk_controls = risk_controls @settings = settings @tos_acceptance = tos_acceptance end |
Instance Attribute Details
#account_token ⇒ Object
An [account token](stripe.com/docs/api#create_account_token), used to securely provide details to the account.
2691 2692 2693 |
# File 'lib/stripe/resources/account.rb', line 2691 def account_token @account_token end |
#business_profile ⇒ Object
Business information about the account.
2693 2694 2695 |
# File 'lib/stripe/resources/account.rb', line 2693 def business_profile @business_profile end |
#business_type ⇒ Object
The business type. Once you create an [Account Link](/api/account_links) or [Account Session](/api/account_sessions), this property can only be updated for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is ‘application`, which includes Custom accounts.
2695 2696 2697 |
# File 'lib/stripe/resources/account.rb', line 2695 def business_type @business_type end |
#capabilities ⇒ Object
Each key of the dictionary represents a capability, and each capability maps to its settings (for example, whether it has been requested or not). Each capability is inactive until you have provided its specific requirements and Stripe has verified them. An account might have some of its requested capabilities be active and some be inactive.
Required when [account.controller.stripe_dashboard.type](/api/accounts/create#create_account-controller-dashboard-type) is ‘none`, which includes Custom accounts.
2704 2705 2706 |
# File 'lib/stripe/resources/account.rb', line 2704 def capabilities @capabilities end |
#company ⇒ Object
Information about the company or business. This field is available for any ‘business_type`. Once you create an [Account Link](/api/account_links) or [Account Session](/api/account_sessions), this property can only be updated for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is `application`, which includes Custom accounts.
2706 2707 2708 |
# File 'lib/stripe/resources/account.rb', line 2706 def company @company end |
#default_currency ⇒ Object
Three-letter ISO currency code representing the default currency for the account. This must be a currency that [Stripe supports in the account’s country](docs.stripe.com/payouts).
2708 2709 2710 |
# File 'lib/stripe/resources/account.rb', line 2708 def default_currency @default_currency end |
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
2710 2711 2712 |
# File 'lib/stripe/resources/account.rb', line 2710 def documents @documents end |
#email ⇒ Object
The email address of the account holder. This is only to make the account easier to identify to you. If [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is ‘application`, which includes Custom accounts, Stripe doesn’t email the account without your consent.
2712 2713 2714 |
# File 'lib/stripe/resources/account.rb', line 2712 def email @email end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2714 2715 2716 |
# File 'lib/stripe/resources/account.rb', line 2714 def @expand end |
#external_account ⇒ Object
A card or bank account to attach to the account for receiving [payouts](/connect/bank-debit-card-payouts) (you won’t be able to use it for top-ups). You can provide either a token, like the ones returned by [Stripe.js](/js), or a dictionary, as documented in the ‘external_account` parameter for [bank account](/api#account_create_bank_account) creation.
By default, providing an external account sets it as the new default external account for its currency, and deletes the old default if one exists. To add additional external accounts without replacing the existing default for the currency, use the [bank account](/api#account_create_bank_account) or [card creation](/api#account_create_card) APIs. After you create an [Account Link](/api/account_links) or [Account Session](/api/account_sessions), this property can only be updated for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is `application`, which includes Custom accounts.
2716 2717 2718 |
# File 'lib/stripe/resources/account.rb', line 2716 def external_account @external_account end |
#groups ⇒ Object
A hash of account group type to tokens. These are account groups this account should be added to.
2718 2719 2720 |
# File 'lib/stripe/resources/account.rb', line 2718 def groups @groups end |
#individual ⇒ Object
Information about the person represented by the account. This field is null unless ‘business_type` is set to `individual`. Once you create an [Account Link](/api/account_links) or [Account Session](/api/account_sessions), this property can only be updated for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is `application`, which includes Custom accounts.
2720 2721 2722 |
# File 'lib/stripe/resources/account.rb', line 2720 def individual @individual end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
2722 2723 2724 |
# File 'lib/stripe/resources/account.rb', line 2722 def @metadata end |
#risk_controls ⇒ Object
A hash to configure risk controls on the account. Please see [this page for more details](/connect/pausing-payments-or-payouts-on-connected-accounts).
2724 2725 2726 |
# File 'lib/stripe/resources/account.rb', line 2724 def risk_controls @risk_controls end |
#settings ⇒ Object
Options for customizing how the account functions within Stripe.
2726 2727 2728 |
# File 'lib/stripe/resources/account.rb', line 2726 def settings @settings end |
#tos_acceptance ⇒ Object
Details on the account’s acceptance of the [Stripe Services Agreement](/connect/updating-accounts#tos-acceptance). This property can only be updated for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is ‘application`, which includes Custom accounts. This property defaults to a `full` service agreement when empty.
2728 2729 2730 |
# File 'lib/stripe/resources/account.rb', line 2728 def tos_acceptance @tos_acceptance end |