Class: Stripe::Account::UpdateParams::BankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(object: nil, account_holder_name: nil, account_holder_type: nil, account_number: nil, country: nil, currency: nil, routing_number: nil) ⇒ BankAccount

Returns a new instance of BankAccount.



709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
# File 'lib/stripe/resources/account.rb', line 709

def initialize(
  object: nil,
  account_holder_name: nil,
  account_holder_type: nil,
  account_number: nil,
  country: nil,
  currency: nil,
  routing_number: nil
)
  @object = object
  @account_holder_name = 
  @account_holder_type = 
  @account_number = 
  @country = country
  @currency = currency
  @routing_number = routing_number
end

Instance Attribute Details

#account_holder_nameObject

The name of the person or business that owns the bank account.This field is required when attaching the bank account to a ‘Customer` object.



697
698
699
# File 'lib/stripe/resources/account.rb', line 697

def 
  @account_holder_name
end

#account_holder_typeObject

The type of entity that holds the account. It can be ‘company` or `individual`. This field is required when attaching the bank account to a `Customer` object.



699
700
701
# File 'lib/stripe/resources/account.rb', line 699

def 
  @account_holder_type
end

#account_numberObject

The account number for the bank account, in string form. Must be a checking account.



701
702
703
# File 'lib/stripe/resources/account.rb', line 701

def 
  @account_number
end

#countryObject

The country in which the bank account is located.



703
704
705
# File 'lib/stripe/resources/account.rb', line 703

def country
  @country
end

#currencyObject

The currency the bank account is in. This must be a country/currency pairing that [Stripe supports.](docs/payouts)



705
706
707
# File 'lib/stripe/resources/account.rb', line 705

def currency
  @currency
end

#objectObject

Attribute for param field object



695
696
697
# File 'lib/stripe/resources/account.rb', line 695

def object
  @object
end

#routing_numberObject

The routing number, sort code, or other country-appropriate institution number for the bank account. For US bank accounts, this is required and should be the ACH routing number, not the wire routing number. If you are providing an IBAN for ‘account_number`, this field is not required.



707
708
709
# File 'lib/stripe/resources/account.rb', line 707

def routing_number
  @routing_number
end