Class: Stripe::Account::UpdateParams::BankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(object: nil, account_holder_name: nil, account_holder_type: nil, account_number: nil, country: nil, currency: nil, routing_number: nil) ⇒ BankAccount

Returns a new instance of BankAccount.



614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
# File 'lib/stripe/resources/account.rb', line 614

def initialize(
  object: nil,
  account_holder_name: nil,
  account_holder_type: nil,
  account_number: nil,
  country: nil,
  currency: nil,
  routing_number: nil
)
  @object = object
  @account_holder_name = 
  @account_holder_type = 
  @account_number = 
  @country = country
  @currency = currency
  @routing_number = routing_number
end

Instance Attribute Details

#account_holder_nameObject

The name of the person or business that owns the bank account.This field is required when attaching the bank account to a ‘Customer` object.



602
603
604
# File 'lib/stripe/resources/account.rb', line 602

def 
  @account_holder_name
end

#account_holder_typeObject

The type of entity that holds the account. It can be ‘company` or `individual`. This field is required when attaching the bank account to a `Customer` object.



604
605
606
# File 'lib/stripe/resources/account.rb', line 604

def 
  @account_holder_type
end

#account_numberObject

The account number for the bank account, in string form. Must be a checking account.



606
607
608
# File 'lib/stripe/resources/account.rb', line 606

def 
  @account_number
end

#countryObject

The country in which the bank account is located.



608
609
610
# File 'lib/stripe/resources/account.rb', line 608

def country
  @country
end

#currencyObject

The currency the bank account is in. This must be a country/currency pairing that [Stripe supports.](docs/payouts)



610
611
612
# File 'lib/stripe/resources/account.rb', line 610

def currency
  @currency
end

#objectObject

Attribute for param field object



600
601
602
# File 'lib/stripe/resources/account.rb', line 600

def object
  @object
end

#routing_numberObject

The routing number, sort code, or other country-appropriate institution number for the bank account. For US bank accounts, this is required and should be the ACH routing number, not the wire routing number. If you are providing an IBAN for ‘account_number`, this field is not required.



612
613
614
# File 'lib/stripe/resources/account.rb', line 612

def routing_number
  @routing_number
end