Class: Stripe::Account::UpdateParams::BankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(object: nil, account_holder_name: nil, account_holder_type: nil, account_number: nil, country: nil, currency: nil, routing_number: nil) ⇒ BankAccount

Returns a new instance of BankAccount.



702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
# File 'lib/stripe/resources/account.rb', line 702

def initialize(
  object: nil,
  account_holder_name: nil,
  account_holder_type: nil,
  account_number: nil,
  country: nil,
  currency: nil,
  routing_number: nil
)
  @object = object
  @account_holder_name = 
  @account_holder_type = 
  @account_number = 
  @country = country
  @currency = currency
  @routing_number = routing_number
end

Instance Attribute Details

#account_holder_nameObject

The name of the person or business that owns the bank account.This field is required when attaching the bank account to a ‘Customer` object.



690
691
692
# File 'lib/stripe/resources/account.rb', line 690

def 
  @account_holder_name
end

#account_holder_typeObject

The type of entity that holds the account. It can be ‘company` or `individual`. This field is required when attaching the bank account to a `Customer` object.



692
693
694
# File 'lib/stripe/resources/account.rb', line 692

def 
  @account_holder_type
end

#account_numberObject

The account number for the bank account, in string form. Must be a checking account.



694
695
696
# File 'lib/stripe/resources/account.rb', line 694

def 
  @account_number
end

#countryObject

The country in which the bank account is located.



696
697
698
# File 'lib/stripe/resources/account.rb', line 696

def country
  @country
end

#currencyObject

The currency the bank account is in. This must be a country/currency pairing that [Stripe supports.](docs/payouts)



698
699
700
# File 'lib/stripe/resources/account.rb', line 698

def currency
  @currency
end

#objectObject

Attribute for param field object



688
689
690
# File 'lib/stripe/resources/account.rb', line 688

def object
  @object
end

#routing_numberObject

The routing number, sort code, or other country-appropriate institution number for the bank account. For US bank accounts, this is required and should be the ACH routing number, not the wire routing number. If you are providing an IBAN for ‘account_number`, this field is not required.



700
701
702
# File 'lib/stripe/resources/account.rb', line 700

def routing_number
  @routing_number
end