Class: Stripe::Account::UpdateParams::BankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(object: nil, account_holder_name: nil, account_holder_type: nil, account_number: nil, country: nil, currency: nil, routing_number: nil) ⇒ BankAccount

Returns a new instance of BankAccount.



613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
# File 'lib/stripe/resources/account.rb', line 613

def initialize(
  object: nil,
  account_holder_name: nil,
  account_holder_type: nil,
  account_number: nil,
  country: nil,
  currency: nil,
  routing_number: nil
)
  @object = object
  @account_holder_name = 
  @account_holder_type = 
  @account_number = 
  @country = country
  @currency = currency
  @routing_number = routing_number
end

Instance Attribute Details

#account_holder_nameObject

The name of the person or business that owns the bank account.This field is required when attaching the bank account to a ‘Customer` object.



601
602
603
# File 'lib/stripe/resources/account.rb', line 601

def 
  @account_holder_name
end

#account_holder_typeObject

The type of entity that holds the account. It can be ‘company` or `individual`. This field is required when attaching the bank account to a `Customer` object.



603
604
605
# File 'lib/stripe/resources/account.rb', line 603

def 
  @account_holder_type
end

#account_numberObject

The account number for the bank account, in string form. Must be a checking account.



605
606
607
# File 'lib/stripe/resources/account.rb', line 605

def 
  @account_number
end

#countryObject

The country in which the bank account is located.



607
608
609
# File 'lib/stripe/resources/account.rb', line 607

def country
  @country
end

#currencyObject

The currency the bank account is in. This must be a country/currency pairing that [Stripe supports.](docs/payouts)



609
610
611
# File 'lib/stripe/resources/account.rb', line 609

def currency
  @currency
end

#objectObject

Attribute for param field object



599
600
601
# File 'lib/stripe/resources/account.rb', line 599

def object
  @object
end

#routing_numberObject

The routing number, sort code, or other country-appropriate institution number for the bank account. For US bank accounts, this is required and should be the ACH routing number, not the wire routing number. If you are providing an IBAN for ‘account_number`, this field is not required.



611
612
613
# File 'lib/stripe/resources/account.rb', line 611

def routing_number
  @routing_number
end