Class: Stripe::Account::UpdateParams::BankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(object: nil, account_holder_name: nil, account_holder_type: nil, account_number: nil, country: nil, currency: nil, routing_number: nil) ⇒ BankAccount

Returns a new instance of BankAccount.



691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
# File 'lib/stripe/resources/account.rb', line 691

def initialize(
  object: nil,
  account_holder_name: nil,
  account_holder_type: nil,
  account_number: nil,
  country: nil,
  currency: nil,
  routing_number: nil
)
  @object = object
  @account_holder_name = 
  @account_holder_type = 
  @account_number = 
  @country = country
  @currency = currency
  @routing_number = routing_number
end

Instance Attribute Details

#account_holder_nameObject

The name of the person or business that owns the bank account.This field is required when attaching the bank account to a ‘Customer` object.



679
680
681
# File 'lib/stripe/resources/account.rb', line 679

def 
  @account_holder_name
end

#account_holder_typeObject

The type of entity that holds the account. It can be ‘company` or `individual`. This field is required when attaching the bank account to a `Customer` object.



681
682
683
# File 'lib/stripe/resources/account.rb', line 681

def 
  @account_holder_type
end

#account_numberObject

The account number for the bank account, in string form. Must be a checking account.



683
684
685
# File 'lib/stripe/resources/account.rb', line 683

def 
  @account_number
end

#countryObject

The country in which the bank account is located.



685
686
687
# File 'lib/stripe/resources/account.rb', line 685

def country
  @country
end

#currencyObject

The currency the bank account is in. This must be a country/currency pairing that [Stripe supports.](docs/payouts)



687
688
689
# File 'lib/stripe/resources/account.rb', line 687

def currency
  @currency
end

#objectObject

Attribute for param field object



677
678
679
# File 'lib/stripe/resources/account.rb', line 677

def object
  @object
end

#routing_numberObject

The routing number, sort code, or other country-appropriateinstitution number for the bank account. For US bank accounts, this is required and should bethe ACH routing number, not the wire routing number. If you are providing an IBAN for`account_number`, this field is not required.



689
690
691
# File 'lib/stripe/resources/account.rb', line 689

def routing_number
  @routing_number
end