Class: Stripe::Account::UpdateParams::BankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(object: nil, account_holder_name: nil, account_holder_type: nil, account_number: nil, country: nil, currency: nil, routing_number: nil) ⇒ BankAccount

Returns a new instance of BankAccount.



600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
# File 'lib/stripe/resources/account.rb', line 600

def initialize(
  object: nil,
  account_holder_name: nil,
  account_holder_type: nil,
  account_number: nil,
  country: nil,
  currency: nil,
  routing_number: nil
)
  @object = object
  @account_holder_name = 
  @account_holder_type = 
  @account_number = 
  @country = country
  @currency = currency
  @routing_number = routing_number
end

Instance Attribute Details

#account_holder_nameObject

The name of the person or business that owns the bank account.This field is required when attaching the bank account to a ‘Customer` object.



588
589
590
# File 'lib/stripe/resources/account.rb', line 588

def 
  @account_holder_name
end

#account_holder_typeObject

The type of entity that holds the account. It can be ‘company` or `individual`. This field is required when attaching the bank account to a `Customer` object.



590
591
592
# File 'lib/stripe/resources/account.rb', line 590

def 
  @account_holder_type
end

#account_numberObject

The account number for the bank account, in string form. Must be a checking account.



592
593
594
# File 'lib/stripe/resources/account.rb', line 592

def 
  @account_number
end

#countryObject

The country in which the bank account is located.



594
595
596
# File 'lib/stripe/resources/account.rb', line 594

def country
  @country
end

#currencyObject

The currency the bank account is in. This must be a country/currency pairing that [Stripe supports.](docs/payouts)



596
597
598
# File 'lib/stripe/resources/account.rb', line 596

def currency
  @currency
end

#objectObject

Attribute for param field object



586
587
588
# File 'lib/stripe/resources/account.rb', line 586

def object
  @object
end

#routing_numberObject

The routing number, sort code, or other country-appropriateinstitution number for the bank account. For US bank accounts, this is required and should bethe ACH routing number, not the wire routing number. If you are providing an IBAN for`account_number`, this field is not required.



598
599
600
# File 'lib/stripe/resources/account.rb', line 598

def routing_number
  @routing_number
end