Class: Stripe::Account::UpdateParams::BankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(object: nil, account_holder_name: nil, account_holder_type: nil, account_number: nil, country: nil, currency: nil, routing_number: nil) ⇒ BankAccount

Returns a new instance of BankAccount.



688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
# File 'lib/stripe/resources/account.rb', line 688

def initialize(
  object: nil,
  account_holder_name: nil,
  account_holder_type: nil,
  account_number: nil,
  country: nil,
  currency: nil,
  routing_number: nil
)
  @object = object
  @account_holder_name = 
  @account_holder_type = 
  @account_number = 
  @country = country
  @currency = currency
  @routing_number = routing_number
end

Instance Attribute Details

#account_holder_nameObject

The name of the person or business that owns the bank account.This field is required when attaching the bank account to a ‘Customer` object.



676
677
678
# File 'lib/stripe/resources/account.rb', line 676

def 
  @account_holder_name
end

#account_holder_typeObject

The type of entity that holds the account. It can be ‘company` or `individual`. This field is required when attaching the bank account to a `Customer` object.



678
679
680
# File 'lib/stripe/resources/account.rb', line 678

def 
  @account_holder_type
end

#account_numberObject

The account number for the bank account, in string form. Must be a checking account.



680
681
682
# File 'lib/stripe/resources/account.rb', line 680

def 
  @account_number
end

#countryObject

The country in which the bank account is located.



682
683
684
# File 'lib/stripe/resources/account.rb', line 682

def country
  @country
end

#currencyObject

The currency the bank account is in. This must be a country/currency pairing that [Stripe supports.](docs/payouts)



684
685
686
# File 'lib/stripe/resources/account.rb', line 684

def currency
  @currency
end

#objectObject

Attribute for param field object



674
675
676
# File 'lib/stripe/resources/account.rb', line 674

def object
  @object
end

#routing_numberObject

The routing number, sort code, or other country-appropriateinstitution number for the bank account. For US bank accounts, this is required and should bethe ACH routing number, not the wire routing number. If you are providing an IBAN for`account_number`, this field is not required.



686
687
688
# File 'lib/stripe/resources/account.rb', line 686

def routing_number
  @routing_number
end