Class: Stripe::Account::UpdateParams::BankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(object: nil, account_holder_name: nil, account_holder_type: nil, account_number: nil, country: nil, currency: nil, routing_number: nil) ⇒ BankAccount

Returns a new instance of BankAccount.



868
869
870
871
872
873
874
875
876
877
878
879
880
881
882
883
884
# File 'lib/stripe/resources/account.rb', line 868

def initialize(
  object: nil,
  account_holder_name: nil,
  account_holder_type: nil,
  account_number: nil,
  country: nil,
  currency: nil,
  routing_number: nil
)
  @object = object
  @account_holder_name = 
  @account_holder_type = 
  @account_number = 
  @country = country
  @currency = currency
  @routing_number = routing_number
end

Instance Attribute Details

#account_holder_nameObject

The name of the person or business that owns the bank account.This field is required when attaching the bank account to a ‘Customer` object.



851
852
853
# File 'lib/stripe/resources/account.rb', line 851

def 
  @account_holder_name
end

#account_holder_typeObject

The type of entity that holds the account. It can be ‘company` or `individual`. This field is required when attaching the bank account to a `Customer` object.



854
855
856
# File 'lib/stripe/resources/account.rb', line 854

def 
  @account_holder_type
end

#account_numberObject

The account number for the bank account, in string form. Must be a checking account.



857
858
859
# File 'lib/stripe/resources/account.rb', line 857

def 
  @account_number
end

#countryObject

The country in which the bank account is located.



860
861
862
# File 'lib/stripe/resources/account.rb', line 860

def country
  @country
end

#currencyObject

The currency the bank account is in. This must be a country/currency pairing that [Stripe supports.](docs/payouts)



863
864
865
# File 'lib/stripe/resources/account.rb', line 863

def currency
  @currency
end

#objectObject

Attribute for param field object



848
849
850
# File 'lib/stripe/resources/account.rb', line 848

def object
  @object
end

#routing_numberObject

The routing number, sort code, or other country-appropriateinstitution number for the bank account. For US bank accounts, this is required and should bethe ACH routing number, not the wire routing number. If you are providing an IBAN for`account_number`, this field is not required.



866
867
868
# File 'lib/stripe/resources/account.rb', line 866

def routing_number
  @routing_number
end