Class: Stripe::Account::UpdateParams::BusinessProfile

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: AnnualRevenue, MonthlyEstimatedRevenue, SupportAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(annual_revenue: nil, estimated_worker_count: nil, mcc: nil, minority_owned_business_designation: nil, monthly_estimated_revenue: nil, name: nil, product_description: nil, support_address: nil, support_email: nil, support_phone: nil, support_url: nil, url: nil) ⇒ BusinessProfile

Returns a new instance of BusinessProfile.



811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
# File 'lib/stripe/resources/account.rb', line 811

def initialize(
  annual_revenue: nil,
  estimated_worker_count: nil,
  mcc: nil,
  minority_owned_business_designation: nil,
  monthly_estimated_revenue: nil,
  name: nil,
  product_description: nil,
  support_address: nil,
  support_email: nil,
  support_phone: nil,
  support_url: nil,
  url: nil
)
  @annual_revenue = annual_revenue
  @estimated_worker_count = estimated_worker_count
  @mcc = mcc
  @minority_owned_business_designation = minority_owned_business_designation
  @monthly_estimated_revenue = monthly_estimated_revenue
  @name = name
  @product_description = product_description
  @support_address = support_address
  @support_email = support_email
  @support_phone = support_phone
  @support_url = support_url
  @url = url
end

Instance Attribute Details

#annual_revenueObject

The applicant’s gross annual revenue for its preceding fiscal year.



787
788
789
# File 'lib/stripe/resources/account.rb', line 787

def annual_revenue
  @annual_revenue
end

#estimated_worker_countObject

An estimated upper bound of employees, contractors, vendors, etc. currently working for the business.



789
790
791
# File 'lib/stripe/resources/account.rb', line 789

def estimated_worker_count
  @estimated_worker_count
end

#mccObject

[The merchant category code for the account](/connect/setting-mcc). MCCs are used to classify businesses based on the goods or services they provide.



791
792
793
# File 'lib/stripe/resources/account.rb', line 791

def mcc
  @mcc
end

#minority_owned_business_designationObject

Whether the business is a minority-owned, women-owned, and/or LGBTQI+ -owned business.



793
794
795
# File 'lib/stripe/resources/account.rb', line 793

def minority_owned_business_designation
  @minority_owned_business_designation
end

#monthly_estimated_revenueObject

An estimate of the monthly revenue of the business. Only accepted for accounts in Brazil and India.



795
796
797
# File 'lib/stripe/resources/account.rb', line 795

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#nameObject

The customer-facing business name.



797
798
799
# File 'lib/stripe/resources/account.rb', line 797

def name
  @name
end

#product_descriptionObject

Internal-only description of the product sold by, or service provided by, the business. Used by Stripe for risk and underwriting purposes.



799
800
801
# File 'lib/stripe/resources/account.rb', line 799

def product_description
  @product_description
end

#support_addressObject

A publicly available mailing address for sending support issues to.



801
802
803
# File 'lib/stripe/resources/account.rb', line 801

def support_address
  @support_address
end

#support_emailObject

A publicly available email address for sending support issues to.



803
804
805
# File 'lib/stripe/resources/account.rb', line 803

def support_email
  @support_email
end

#support_phoneObject

A publicly available phone number to call with support issues.



805
806
807
# File 'lib/stripe/resources/account.rb', line 805

def support_phone
  @support_phone
end

#support_urlObject

A publicly available website for handling support issues.



807
808
809
# File 'lib/stripe/resources/account.rb', line 807

def support_url
  @support_url
end

#urlObject

The business’s publicly available website.



809
810
811
# File 'lib/stripe/resources/account.rb', line 809

def url
  @url
end