Class: Stripe::Account::UpdateParams::BusinessProfile

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: AnnualRevenue, MonthlyEstimatedRevenue, SupportAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(annual_revenue: nil, estimated_worker_count: nil, mcc: nil, minority_owned_business_designation: nil, monthly_estimated_revenue: nil, name: nil, product_description: nil, support_address: nil, support_email: nil, support_phone: nil, support_url: nil, url: nil) ⇒ BusinessProfile

Returns a new instance of BusinessProfile.



715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
# File 'lib/stripe/resources/account.rb', line 715

def initialize(
  annual_revenue: nil,
  estimated_worker_count: nil,
  mcc: nil,
  minority_owned_business_designation: nil,
  monthly_estimated_revenue: nil,
  name: nil,
  product_description: nil,
  support_address: nil,
  support_email: nil,
  support_phone: nil,
  support_url: nil,
  url: nil
)
  @annual_revenue = annual_revenue
  @estimated_worker_count = estimated_worker_count
  @mcc = mcc
  @minority_owned_business_designation = minority_owned_business_designation
  @monthly_estimated_revenue = monthly_estimated_revenue
  @name = name
  @product_description = product_description
  @support_address = support_address
  @support_email = support_email
  @support_phone = support_phone
  @support_url = support_url
  @url = url
end

Instance Attribute Details

#annual_revenueObject

The applicant’s gross annual revenue for its preceding fiscal year.



691
692
693
# File 'lib/stripe/resources/account.rb', line 691

def annual_revenue
  @annual_revenue
end

#estimated_worker_countObject

An estimated upper bound of employees, contractors, vendors, etc. currently working for the business.



693
694
695
# File 'lib/stripe/resources/account.rb', line 693

def estimated_worker_count
  @estimated_worker_count
end

#mccObject

[The merchant category code for the account](/connect/setting-mcc). MCCs are used to classify businesses based on the goods or services they provide.



695
696
697
# File 'lib/stripe/resources/account.rb', line 695

def mcc
  @mcc
end

#minority_owned_business_designationObject

Whether the business is a minority-owned, women-owned, and/or LGBTQI+-owned business.



697
698
699
# File 'lib/stripe/resources/account.rb', line 697

def minority_owned_business_designation
  @minority_owned_business_designation
end

#monthly_estimated_revenueObject

An estimate of the monthly revenue of the business. Only accepted for accounts in Brazil and India.



699
700
701
# File 'lib/stripe/resources/account.rb', line 699

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#nameObject

The customer-facing business name.



701
702
703
# File 'lib/stripe/resources/account.rb', line 701

def name
  @name
end

#product_descriptionObject

Internal-only description of the product sold by, or service provided by, the business. Used by Stripe for risk and underwriting purposes.



703
704
705
# File 'lib/stripe/resources/account.rb', line 703

def product_description
  @product_description
end

#support_addressObject

A publicly available mailing address for sending support issues to.



705
706
707
# File 'lib/stripe/resources/account.rb', line 705

def support_address
  @support_address
end

#support_emailObject

A publicly available email address for sending support issues to.



707
708
709
# File 'lib/stripe/resources/account.rb', line 707

def support_email
  @support_email
end

#support_phoneObject

A publicly available phone number to call with support issues.



709
710
711
# File 'lib/stripe/resources/account.rb', line 709

def support_phone
  @support_phone
end

#support_urlObject

A publicly available website for handling support issues.



711
712
713
# File 'lib/stripe/resources/account.rb', line 711

def support_url
  @support_url
end

#urlObject

The business’s publicly available website.



713
714
715
# File 'lib/stripe/resources/account.rb', line 713

def url
  @url
end