Class: Stripe::Account::UpdateParams::BusinessProfile

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: AnnualRevenue, MonthlyEstimatedRevenue, SupportAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(annual_revenue: nil, estimated_worker_count: nil, mcc: nil, monthly_estimated_revenue: nil, name: nil, product_description: nil, support_address: nil, support_email: nil, support_phone: nil, support_url: nil, url: nil) ⇒ BusinessProfile

Returns a new instance of BusinessProfile.



700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
# File 'lib/stripe/resources/account.rb', line 700

def initialize(
  annual_revenue: nil,
  estimated_worker_count: nil,
  mcc: nil,
  monthly_estimated_revenue: nil,
  name: nil,
  product_description: nil,
  support_address: nil,
  support_email: nil,
  support_phone: nil,
  support_url: nil,
  url: nil
)
  @annual_revenue = annual_revenue
  @estimated_worker_count = estimated_worker_count
  @mcc = mcc
  @monthly_estimated_revenue = monthly_estimated_revenue
  @name = name
  @product_description = product_description
  @support_address = support_address
  @support_email = support_email
  @support_phone = support_phone
  @support_url = support_url
  @url = url
end

Instance Attribute Details

#annual_revenueObject

The applicant’s gross annual revenue for its preceding fiscal year.



678
679
680
# File 'lib/stripe/resources/account.rb', line 678

def annual_revenue
  @annual_revenue
end

#estimated_worker_countObject

An estimated upper bound of employees, contractors, vendors, etc. currently working for the business.



680
681
682
# File 'lib/stripe/resources/account.rb', line 680

def estimated_worker_count
  @estimated_worker_count
end

#mccObject

[The merchant category code for the account](/connect/setting-mcc). MCCs are used to classify businesses based on the goods or services they provide.



682
683
684
# File 'lib/stripe/resources/account.rb', line 682

def mcc
  @mcc
end

#monthly_estimated_revenueObject

An estimate of the monthly revenue of the business. Only accepted for accounts in Brazil and India.



684
685
686
# File 'lib/stripe/resources/account.rb', line 684

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#nameObject

The customer-facing business name.



686
687
688
# File 'lib/stripe/resources/account.rb', line 686

def name
  @name
end

#product_descriptionObject

Internal-only description of the product sold by, or service provided by, the business. Used by Stripe for risk and underwriting purposes.



688
689
690
# File 'lib/stripe/resources/account.rb', line 688

def product_description
  @product_description
end

#support_addressObject

A publicly available mailing address for sending support issues to.



690
691
692
# File 'lib/stripe/resources/account.rb', line 690

def support_address
  @support_address
end

#support_emailObject

A publicly available email address for sending support issues to.



692
693
694
# File 'lib/stripe/resources/account.rb', line 692

def support_email
  @support_email
end

#support_phoneObject

A publicly available phone number to call with support issues.



694
695
696
# File 'lib/stripe/resources/account.rb', line 694

def support_phone
  @support_phone
end

#support_urlObject

A publicly available website for handling support issues.



696
697
698
# File 'lib/stripe/resources/account.rb', line 696

def support_url
  @support_url
end

#urlObject

The business’s publicly available website.



698
699
700
# File 'lib/stripe/resources/account.rb', line 698

def url
  @url
end