Class: Stripe::Account::UpdateParams::BusinessProfile
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::UpdateParams::BusinessProfile
- Defined in:
- lib/stripe/resources/account.rb
Defined Under Namespace
Classes: AnnualRevenue, MonthlyEstimatedRevenue, SupportAddress
Instance Attribute Summary collapse
-
#annual_revenue ⇒ Object
The applicant’s gross annual revenue for its preceding fiscal year.
-
#estimated_worker_count ⇒ Object
An estimated upper bound of employees, contractors, vendors, etc.
-
#mcc ⇒ Object
[The merchant category code for the account](/connect/setting-mcc).
-
#monthly_estimated_revenue ⇒ Object
An estimate of the monthly revenue of the business.
-
#name ⇒ Object
The customer-facing business name.
-
#product_description ⇒ Object
Internal-only description of the product sold by, or service provided by, the business.
-
#support_address ⇒ Object
A publicly available mailing address for sending support issues to.
-
#support_email ⇒ Object
A publicly available email address for sending support issues to.
-
#support_phone ⇒ Object
A publicly available phone number to call with support issues.
-
#support_url ⇒ Object
A publicly available website for handling support issues.
-
#url ⇒ Object
The business’s publicly available website.
Instance Method Summary collapse
-
#initialize(annual_revenue: nil, estimated_worker_count: nil, mcc: nil, monthly_estimated_revenue: nil, name: nil, product_description: nil, support_address: nil, support_email: nil, support_phone: nil, support_url: nil, url: nil) ⇒ BusinessProfile
constructor
A new instance of BusinessProfile.
Methods inherited from RequestParams
Constructor Details
#initialize(annual_revenue: nil, estimated_worker_count: nil, mcc: nil, monthly_estimated_revenue: nil, name: nil, product_description: nil, support_address: nil, support_email: nil, support_phone: nil, support_url: nil, url: nil) ⇒ BusinessProfile
Returns a new instance of BusinessProfile.
986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 |
# File 'lib/stripe/resources/account.rb', line 986 def initialize( annual_revenue: nil, estimated_worker_count: nil, mcc: nil, monthly_estimated_revenue: nil, name: nil, product_description: nil, support_address: nil, support_email: nil, support_phone: nil, support_url: nil, url: nil ) @annual_revenue = annual_revenue @estimated_worker_count = estimated_worker_count @mcc = mcc @monthly_estimated_revenue = monthly_estimated_revenue @name = name @product_description = product_description @support_address = support_address @support_email = support_email @support_phone = support_phone @support_url = support_url @url = url end |
Instance Attribute Details
#annual_revenue ⇒ Object
The applicant’s gross annual revenue for its preceding fiscal year.
954 955 956 |
# File 'lib/stripe/resources/account.rb', line 954 def annual_revenue @annual_revenue end |
#estimated_worker_count ⇒ Object
An estimated upper bound of employees, contractors, vendors, etc. currently working for the business.
957 958 959 |
# File 'lib/stripe/resources/account.rb', line 957 def estimated_worker_count @estimated_worker_count end |
#mcc ⇒ Object
[The merchant category code for the account](/connect/setting-mcc). MCCs are used to classify businesses based on the goods or services they provide.
960 961 962 |
# File 'lib/stripe/resources/account.rb', line 960 def mcc @mcc end |
#monthly_estimated_revenue ⇒ Object
An estimate of the monthly revenue of the business. Only accepted for accounts in Brazil and India.
963 964 965 |
# File 'lib/stripe/resources/account.rb', line 963 def monthly_estimated_revenue @monthly_estimated_revenue end |
#name ⇒ Object
The customer-facing business name.
966 967 968 |
# File 'lib/stripe/resources/account.rb', line 966 def name @name end |
#product_description ⇒ Object
Internal-only description of the product sold by, or service provided by, the business. Used by Stripe for risk and underwriting purposes.
969 970 971 |
# File 'lib/stripe/resources/account.rb', line 969 def product_description @product_description end |
#support_address ⇒ Object
A publicly available mailing address for sending support issues to.
972 973 974 |
# File 'lib/stripe/resources/account.rb', line 972 def support_address @support_address end |
#support_email ⇒ Object
A publicly available email address for sending support issues to.
975 976 977 |
# File 'lib/stripe/resources/account.rb', line 975 def support_email @support_email end |
#support_phone ⇒ Object
A publicly available phone number to call with support issues.
978 979 980 |
# File 'lib/stripe/resources/account.rb', line 978 def support_phone @support_phone end |
#support_url ⇒ Object
A publicly available website for handling support issues.
981 982 983 |
# File 'lib/stripe/resources/account.rb', line 981 def support_url @support_url end |
#url ⇒ Object
The business’s publicly available website.
984 985 986 |
# File 'lib/stripe/resources/account.rb', line 984 def url @url end |