Class: Stripe::Account::UpdateParams::BusinessProfile
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::UpdateParams::BusinessProfile
- Defined in:
- lib/stripe/resources/account.rb
Defined Under Namespace
Classes: AnnualRevenue, MonthlyEstimatedRevenue, SupportAddress
Instance Attribute Summary collapse
-
#annual_revenue ⇒ Object
The applicant’s gross annual revenue for its preceding fiscal year.
-
#estimated_worker_count ⇒ Object
An estimated upper bound of employees, contractors, vendors, etc.
-
#mcc ⇒ Object
[The merchant category code for the account](/connect/setting-mcc).
-
#monthly_estimated_revenue ⇒ Object
An estimate of the monthly revenue of the business.
-
#name ⇒ Object
The customer-facing business name.
-
#product_description ⇒ Object
Internal-only description of the product sold by, or service provided by, the business.
-
#support_address ⇒ Object
A publicly available mailing address for sending support issues to.
-
#support_email ⇒ Object
A publicly available email address for sending support issues to.
-
#support_phone ⇒ Object
A publicly available phone number to call with support issues.
-
#support_url ⇒ Object
A publicly available website for handling support issues.
-
#url ⇒ Object
The business’s publicly available website.
Instance Method Summary collapse
-
#initialize(annual_revenue: nil, estimated_worker_count: nil, mcc: nil, monthly_estimated_revenue: nil, name: nil, product_description: nil, support_address: nil, support_email: nil, support_phone: nil, support_url: nil, url: nil) ⇒ BusinessProfile
constructor
A new instance of BusinessProfile.
Methods inherited from RequestParams
Constructor Details
#initialize(annual_revenue: nil, estimated_worker_count: nil, mcc: nil, monthly_estimated_revenue: nil, name: nil, product_description: nil, support_address: nil, support_email: nil, support_phone: nil, support_url: nil, url: nil) ⇒ BusinessProfile
Returns a new instance of BusinessProfile.
786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 |
# File 'lib/stripe/resources/account.rb', line 786 def initialize( annual_revenue: nil, estimated_worker_count: nil, mcc: nil, monthly_estimated_revenue: nil, name: nil, product_description: nil, support_address: nil, support_email: nil, support_phone: nil, support_url: nil, url: nil ) @annual_revenue = annual_revenue @estimated_worker_count = estimated_worker_count @mcc = mcc @monthly_estimated_revenue = monthly_estimated_revenue @name = name @product_description = product_description @support_address = support_address @support_email = support_email @support_phone = support_phone @support_url = support_url @url = url end |
Instance Attribute Details
#annual_revenue ⇒ Object
The applicant’s gross annual revenue for its preceding fiscal year.
764 765 766 |
# File 'lib/stripe/resources/account.rb', line 764 def annual_revenue @annual_revenue end |
#estimated_worker_count ⇒ Object
An estimated upper bound of employees, contractors, vendors, etc. currently working for the business.
766 767 768 |
# File 'lib/stripe/resources/account.rb', line 766 def estimated_worker_count @estimated_worker_count end |
#mcc ⇒ Object
[The merchant category code for the account](/connect/setting-mcc). MCCs are used to classify businesses based on the goods or services they provide.
768 769 770 |
# File 'lib/stripe/resources/account.rb', line 768 def mcc @mcc end |
#monthly_estimated_revenue ⇒ Object
An estimate of the monthly revenue of the business. Only accepted for accounts in Brazil and India.
770 771 772 |
# File 'lib/stripe/resources/account.rb', line 770 def monthly_estimated_revenue @monthly_estimated_revenue end |
#name ⇒ Object
The customer-facing business name.
772 773 774 |
# File 'lib/stripe/resources/account.rb', line 772 def name @name end |
#product_description ⇒ Object
Internal-only description of the product sold by, or service provided by, the business. Used by Stripe for risk and underwriting purposes.
774 775 776 |
# File 'lib/stripe/resources/account.rb', line 774 def product_description @product_description end |
#support_address ⇒ Object
A publicly available mailing address for sending support issues to.
776 777 778 |
# File 'lib/stripe/resources/account.rb', line 776 def support_address @support_address end |
#support_email ⇒ Object
A publicly available email address for sending support issues to.
778 779 780 |
# File 'lib/stripe/resources/account.rb', line 778 def support_email @support_email end |
#support_phone ⇒ Object
A publicly available phone number to call with support issues.
780 781 782 |
# File 'lib/stripe/resources/account.rb', line 780 def support_phone @support_phone end |
#support_url ⇒ Object
A publicly available website for handling support issues.
782 783 784 |
# File 'lib/stripe/resources/account.rb', line 782 def support_url @support_url end |
#url ⇒ Object
The business’s publicly available website.
784 785 786 |
# File 'lib/stripe/resources/account.rb', line 784 def url @url end |