Class: Stripe::Account::UpdateParams::BusinessProfile::AnnualRevenue
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::UpdateParams::BusinessProfile::AnnualRevenue
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
A non-negative integer representing the amount in the [smallest currency unit](/currencies#zero-decimal).
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#fiscal_year_end ⇒ Object
The close-out date of the preceding fiscal year in ISO 8601 format.
Instance Method Summary collapse
-
#initialize(amount: nil, currency: nil, fiscal_year_end: nil) ⇒ AnnualRevenue
constructor
A new instance of AnnualRevenue.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, currency: nil, fiscal_year_end: nil) ⇒ AnnualRevenue
Returns a new instance of AnnualRevenue.
714 715 716 717 718 |
# File 'lib/stripe/resources/account.rb', line 714 def initialize(amount: nil, currency: nil, fiscal_year_end: nil) @amount = amount @currency = currency @fiscal_year_end = fiscal_year_end end |
Instance Attribute Details
#amount ⇒ Object
A non-negative integer representing the amount in the [smallest currency unit](/currencies#zero-decimal).
708 709 710 |
# File 'lib/stripe/resources/account.rb', line 708 def amount @amount end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
710 711 712 |
# File 'lib/stripe/resources/account.rb', line 710 def currency @currency end |
#fiscal_year_end ⇒ Object
The close-out date of the preceding fiscal year in ISO 8601 format. E.g. 2023-12-31 for the 31st of December, 2023.
712 713 714 |
# File 'lib/stripe/resources/account.rb', line 712 def fiscal_year_end @fiscal_year_end end |