Class: Stripe::Account::UpdateParams::Company

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: Address, AddressKana, AddressKanji, DirectorshipDeclaration, OwnershipDeclaration, RegistrationDate, Verification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, address_kana: nil, address_kanji: nil, directors_provided: nil, directorship_declaration: nil, executives_provided: nil, export_license_id: nil, export_purpose_code: nil, name: nil, name_kana: nil, name_kanji: nil, owners_provided: nil, ownership_declaration: nil, ownership_exemption_reason: nil, phone: nil, registration_date: nil, registration_number: nil, structure: nil, tax_id: nil, tax_id_registrar: nil, vat_id: nil, verification: nil) ⇒ Company

Returns a new instance of Company.



2088
2089
2090
2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
2101
2102
2103
2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
2124
2125
2126
2127
2128
2129
2130
2131
2132
2133
2134
# File 'lib/stripe/resources/account.rb', line 2088

def initialize(
  address: nil,
  address_kana: nil,
  address_kanji: nil,
  directors_provided: nil,
  directorship_declaration: nil,
  executives_provided: nil,
  export_license_id: nil,
  export_purpose_code: nil,
  name: nil,
  name_kana: nil,
  name_kanji: nil,
  owners_provided: nil,
  ownership_declaration: nil,
  ownership_exemption_reason: nil,
  phone: nil,
  registration_date: nil,
  registration_number: nil,
  structure: nil,
  tax_id: nil,
  tax_id_registrar: nil,
  vat_id: nil,
  verification: nil
)
  @address = address
  @address_kana = address_kana
  @address_kanji = address_kanji
  @directors_provided = directors_provided
  @directorship_declaration = directorship_declaration
  @executives_provided = executives_provided
  @export_license_id = export_license_id
  @export_purpose_code = export_purpose_code
  @name = name
  @name_kana = name_kana
  @name_kanji = name_kanji
  @owners_provided = owners_provided
  @ownership_declaration = ownership_declaration
  @ownership_exemption_reason = ownership_exemption_reason
  @phone = phone
  @registration_date = registration_date
  @registration_number = registration_number
  @structure = structure
  @tax_id = tax_id
  @tax_id_registrar = tax_id_registrar
  @vat_id = vat_id
  @verification = verification
end

Instance Attribute Details

#addressObject

The company’s primary address.



2044
2045
2046
# File 'lib/stripe/resources/account.rb', line 2044

def address
  @address
end

#address_kanaObject

The Kana variation of the company’s primary address (Japan only).



2046
2047
2048
# File 'lib/stripe/resources/account.rb', line 2046

def address_kana
  @address_kana
end

#address_kanjiObject

The Kanji variation of the company’s primary address (Japan only).



2048
2049
2050
# File 'lib/stripe/resources/account.rb', line 2048

def address_kanji
  @address_kanji
end

#directors_providedObject

Whether the company’s directors have been provided. Set this Boolean to ‘true` after creating all the company’s directors with [the Persons API](/api/persons) for accounts with a ‘relationship.director` requirement. This value is not automatically set to `true` after creating directors, so it needs to be updated to indicate all directors have been provided.



2050
2051
2052
# File 'lib/stripe/resources/account.rb', line 2050

def directors_provided
  @directors_provided
end

#directorship_declarationObject

This hash is used to attest that the directors information provided to Stripe is both current and correct.



2052
2053
2054
# File 'lib/stripe/resources/account.rb', line 2052

def directorship_declaration
  @directorship_declaration
end

#executives_providedObject

Whether the company’s executives have been provided. Set this Boolean to ‘true` after creating all the company’s executives with [the Persons API](/api/persons) for accounts with a ‘relationship.executive` requirement.



2054
2055
2056
# File 'lib/stripe/resources/account.rb', line 2054

def executives_provided
  @executives_provided
end

#export_license_idObject

The export license ID number of the company, also referred as Import Export Code (India only).



2056
2057
2058
# File 'lib/stripe/resources/account.rb', line 2056

def export_license_id
  @export_license_id
end

#export_purpose_codeObject

The purpose code to use for export transactions (India only).



2058
2059
2060
# File 'lib/stripe/resources/account.rb', line 2058

def export_purpose_code
  @export_purpose_code
end

#nameObject

The company’s legal name.



2060
2061
2062
# File 'lib/stripe/resources/account.rb', line 2060

def name
  @name
end

#name_kanaObject

The Kana variation of the company’s legal name (Japan only).



2062
2063
2064
# File 'lib/stripe/resources/account.rb', line 2062

def name_kana
  @name_kana
end

#name_kanjiObject

The Kanji variation of the company’s legal name (Japan only).



2064
2065
2066
# File 'lib/stripe/resources/account.rb', line 2064

def name_kanji
  @name_kanji
end

#owners_providedObject

Whether the company’s owners have been provided. Set this Boolean to ‘true` after creating all the company’s owners with [the Persons API](/api/persons) for accounts with a ‘relationship.owner` requirement.



2066
2067
2068
# File 'lib/stripe/resources/account.rb', line 2066

def owners_provided
  @owners_provided
end

#ownership_declarationObject

This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.



2068
2069
2070
# File 'lib/stripe/resources/account.rb', line 2068

def ownership_declaration
  @ownership_declaration
end

#ownership_exemption_reasonObject

This value is used to determine if a business is exempt from providing ultimate beneficial owners. See [this support article](support.stripe.com/questions/exemption-from-providing-ownership-details) and [changelog](docs.stripe.com/changelog/acacia/2025-01-27/ownership-exemption-reason-accounts-api) for more details.



2070
2071
2072
# File 'lib/stripe/resources/account.rb', line 2070

def ownership_exemption_reason
  @ownership_exemption_reason
end

#phoneObject

The company’s phone number (used for verification).



2072
2073
2074
# File 'lib/stripe/resources/account.rb', line 2072

def phone
  @phone
end

#registration_dateObject

Attribute for param field registration_date



2074
2075
2076
# File 'lib/stripe/resources/account.rb', line 2074

def registration_date
  @registration_date
end

#registration_numberObject

The identification number given to a company when it is registered or incorporated, if distinct from the identification number used for filing taxes. (Examples are the CIN for companies and LLP IN for partnerships in India, and the Company Registration Number in Hong Kong).



2076
2077
2078
# File 'lib/stripe/resources/account.rb', line 2076

def registration_number
  @registration_number
end

#structureObject

The category identifying the legal structure of the company or legal entity. See [Business structure](/connect/identity-verification#business-structure) for more details. Pass an empty string to unset this value.



2078
2079
2080
# File 'lib/stripe/resources/account.rb', line 2078

def structure
  @structure
end

#tax_idObject

The business ID number of the company, as appropriate for the company’s country. (Examples are an Employer ID Number in the U.S., a Business Number in Canada, or a Company Number in the UK.)



2080
2081
2082
# File 'lib/stripe/resources/account.rb', line 2080

def tax_id
  @tax_id
end

#tax_id_registrarObject

The jurisdiction in which the ‘tax_id` is registered (Germany-based companies only).



2082
2083
2084
# File 'lib/stripe/resources/account.rb', line 2082

def tax_id_registrar
  @tax_id_registrar
end

#vat_idObject

The VAT number of the company.



2084
2085
2086
# File 'lib/stripe/resources/account.rb', line 2084

def vat_id
  @vat_id
end

#verificationObject

Information on the verification state of the company.



2086
2087
2088
# File 'lib/stripe/resources/account.rb', line 2086

def verification
  @verification
end