Class: Stripe::Account::UpdateParams::Company

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: Address, AddressKana, AddressKanji, DirectorshipDeclaration, OwnershipDeclaration, RegistrationDate, Verification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, address_kana: nil, address_kanji: nil, directors_provided: nil, directorship_declaration: nil, executives_provided: nil, export_license_id: nil, export_purpose_code: nil, name: nil, name_kana: nil, name_kanji: nil, owners_provided: nil, ownership_declaration: nil, ownership_exemption_reason: nil, phone: nil, registration_date: nil, registration_number: nil, structure: nil, tax_id: nil, tax_id_registrar: nil, vat_id: nil, verification: nil) ⇒ Company

Returns a new instance of Company.



1798
1799
1800
1801
1802
1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
1831
1832
1833
1834
1835
1836
1837
1838
1839
1840
1841
1842
1843
1844
# File 'lib/stripe/resources/account.rb', line 1798

def initialize(
  address: nil,
  address_kana: nil,
  address_kanji: nil,
  directors_provided: nil,
  directorship_declaration: nil,
  executives_provided: nil,
  export_license_id: nil,
  export_purpose_code: nil,
  name: nil,
  name_kana: nil,
  name_kanji: nil,
  owners_provided: nil,
  ownership_declaration: nil,
  ownership_exemption_reason: nil,
  phone: nil,
  registration_date: nil,
  registration_number: nil,
  structure: nil,
  tax_id: nil,
  tax_id_registrar: nil,
  vat_id: nil,
  verification: nil
)
  @address = address
  @address_kana = address_kana
  @address_kanji = address_kanji
  @directors_provided = directors_provided
  @directorship_declaration = directorship_declaration
  @executives_provided = executives_provided
  @export_license_id = export_license_id
  @export_purpose_code = export_purpose_code
  @name = name
  @name_kana = name_kana
  @name_kanji = name_kanji
  @owners_provided = owners_provided
  @ownership_declaration = ownership_declaration
  @ownership_exemption_reason = ownership_exemption_reason
  @phone = phone
  @registration_date = registration_date
  @registration_number = registration_number
  @structure = structure
  @tax_id = tax_id
  @tax_id_registrar = tax_id_registrar
  @vat_id = vat_id
  @verification = verification
end

Instance Attribute Details

#addressObject

The company’s primary address.



1754
1755
1756
# File 'lib/stripe/resources/account.rb', line 1754

def address
  @address
end

#address_kanaObject

The Kana variation of the company’s primary address (Japan only).



1756
1757
1758
# File 'lib/stripe/resources/account.rb', line 1756

def address_kana
  @address_kana
end

#address_kanjiObject

The Kanji variation of the company’s primary address (Japan only).



1758
1759
1760
# File 'lib/stripe/resources/account.rb', line 1758

def address_kanji
  @address_kanji
end

#directors_providedObject

Whether the company’s directors have been provided. Set this Boolean to ‘true` after creating all the company’s directors with [the Persons API](/api/persons) for accounts with a ‘relationship.director` requirement. This value is not automatically set to `true` after creating directors, so it needs to be updated to indicate all directors have been provided.



1760
1761
1762
# File 'lib/stripe/resources/account.rb', line 1760

def directors_provided
  @directors_provided
end

#directorship_declarationObject

This hash is used to attest that the directors information provided to Stripe is both current and correct.



1762
1763
1764
# File 'lib/stripe/resources/account.rb', line 1762

def directorship_declaration
  @directorship_declaration
end

#executives_providedObject

Whether the company’s executives have been provided. Set this Boolean to ‘true` after creating all the company’s executives with [the Persons API](/api/persons) for accounts with a ‘relationship.executive` requirement.



1764
1765
1766
# File 'lib/stripe/resources/account.rb', line 1764

def executives_provided
  @executives_provided
end

#export_license_idObject

The export license ID number of the company, also referred as Import Export Code (India only).



1766
1767
1768
# File 'lib/stripe/resources/account.rb', line 1766

def export_license_id
  @export_license_id
end

#export_purpose_codeObject

The purpose code to use for export transactions (India only).



1768
1769
1770
# File 'lib/stripe/resources/account.rb', line 1768

def export_purpose_code
  @export_purpose_code
end

#nameObject

The company’s legal name.



1770
1771
1772
# File 'lib/stripe/resources/account.rb', line 1770

def name
  @name
end

#name_kanaObject

The Kana variation of the company’s legal name (Japan only).



1772
1773
1774
# File 'lib/stripe/resources/account.rb', line 1772

def name_kana
  @name_kana
end

#name_kanjiObject

The Kanji variation of the company’s legal name (Japan only).



1774
1775
1776
# File 'lib/stripe/resources/account.rb', line 1774

def name_kanji
  @name_kanji
end

#owners_providedObject

Whether the company’s owners have been provided. Set this Boolean to ‘true` after creating all the company’s owners with [the Persons API](/api/persons) for accounts with a ‘relationship.owner` requirement.



1776
1777
1778
# File 'lib/stripe/resources/account.rb', line 1776

def owners_provided
  @owners_provided
end

#ownership_declarationObject

This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.



1778
1779
1780
# File 'lib/stripe/resources/account.rb', line 1778

def ownership_declaration
  @ownership_declaration
end

#ownership_exemption_reasonObject

This value is used to determine if a business is exempt from providing ultimate beneficial owners. See [this support article](support.stripe.com/questions/exemption-from-providing-ownership-details) and [changelog](docs.stripe.com/changelog/acacia/2025-01-27/ownership-exemption-reason-accounts-api) for more details.



1780
1781
1782
# File 'lib/stripe/resources/account.rb', line 1780

def ownership_exemption_reason
  @ownership_exemption_reason
end

#phoneObject

The company’s phone number (used for verification).



1782
1783
1784
# File 'lib/stripe/resources/account.rb', line 1782

def phone
  @phone
end

#registration_dateObject

Attribute for param field registration_date



1784
1785
1786
# File 'lib/stripe/resources/account.rb', line 1784

def registration_date
  @registration_date
end

#registration_numberObject

The identification number given to a company when it is registered or incorporated, if distinct from the identification number used for filing taxes. (Examples are the CIN for companies and LLP IN for partnerships in India, and the Company Registration Number in Hong Kong).



1786
1787
1788
# File 'lib/stripe/resources/account.rb', line 1786

def registration_number
  @registration_number
end

#structureObject

The category identifying the legal structure of the company or legal entity. See [Business structure](/connect/identity-verification#business-structure) for more details. Pass an empty string to unset this value.



1788
1789
1790
# File 'lib/stripe/resources/account.rb', line 1788

def structure
  @structure
end

#tax_idObject

The business ID number of the company, as appropriate for the company’s country. (Examples are an Employer ID Number in the U.S., a Business Number in Canada, or a Company Number in the UK.)



1790
1791
1792
# File 'lib/stripe/resources/account.rb', line 1790

def tax_id
  @tax_id
end

#tax_id_registrarObject

The jurisdiction in which the ‘tax_id` is registered (Germany-based companies only).



1792
1793
1794
# File 'lib/stripe/resources/account.rb', line 1792

def tax_id_registrar
  @tax_id_registrar
end

#vat_idObject

The VAT number of the company.



1794
1795
1796
# File 'lib/stripe/resources/account.rb', line 1794

def vat_id
  @vat_id
end

#verificationObject

Information on the verification state of the company.



1796
1797
1798
# File 'lib/stripe/resources/account.rb', line 1796

def verification
  @verification
end