Class: Stripe::Account::UpdateParams::Company
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::UpdateParams::Company
- Defined in:
- lib/stripe/resources/account.rb
Defined Under Namespace
Classes: Address, AddressKana, AddressKanji, DirectorshipDeclaration, OwnershipDeclaration, Verification
Instance Attribute Summary collapse
-
#address ⇒ Object
The company’s primary address.
-
#address_kana ⇒ Object
The Kana variation of the company’s primary address (Japan only).
-
#address_kanji ⇒ Object
The Kanji variation of the company’s primary address (Japan only).
-
#directors_provided ⇒ Object
Whether the company’s directors have been provided.
-
#directorship_declaration ⇒ Object
This hash is used to attest that the directors information provided to Stripe is both current and correct.
-
#executives_provided ⇒ Object
Whether the company’s executives have been provided.
-
#export_license_id ⇒ Object
The export license ID number of the company, also referred as Import Export Code (India only).
-
#export_purpose_code ⇒ Object
The purpose code to use for export transactions (India only).
-
#name ⇒ Object
The company’s legal name.
-
#name_kana ⇒ Object
The Kana variation of the company’s legal name (Japan only).
-
#name_kanji ⇒ Object
The Kanji variation of the company’s legal name (Japan only).
-
#owners_provided ⇒ Object
Whether the company’s owners have been provided.
-
#ownership_declaration ⇒ Object
This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.
-
#ownership_exemption_reason ⇒ Object
This value is used to determine if a business is exempt from providing ultimate beneficial owners.
-
#phone ⇒ Object
The company’s phone number (used for verification).
-
#registration_number ⇒ Object
The identification number given to a company when it is registered or incorporated, if distinct from the identification number used for filing taxes.
-
#structure ⇒ Object
The category identifying the legal structure of the company or legal entity.
-
#tax_id ⇒ Object
The business ID number of the company, as appropriate for the company’s country.
-
#tax_id_registrar ⇒ Object
The jurisdiction in which the ‘tax_id` is registered (Germany-based companies only).
-
#vat_id ⇒ Object
The VAT number of the company.
-
#verification ⇒ Object
Information on the verification state of the company.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, address_kana: nil, address_kanji: nil, directors_provided: nil, directorship_declaration: nil, executives_provided: nil, export_license_id: nil, export_purpose_code: nil, name: nil, name_kana: nil, name_kanji: nil, owners_provided: nil, ownership_declaration: nil, ownership_exemption_reason: nil, phone: nil, registration_number: nil, structure: nil, tax_id: nil, tax_id_registrar: nil, vat_id: nil, verification: nil) ⇒ Company
Returns a new instance of Company.
2021 2022 2023 2024 2025 2026 2027 2028 2029 2030 2031 2032 2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 2058 2059 2060 2061 2062 2063 2064 2065 |
# File 'lib/stripe/resources/account.rb', line 2021 def initialize( address: nil, address_kana: nil, address_kanji: nil, directors_provided: nil, directorship_declaration: nil, executives_provided: nil, export_license_id: nil, export_purpose_code: nil, name: nil, name_kana: nil, name_kanji: nil, owners_provided: nil, ownership_declaration: nil, ownership_exemption_reason: nil, phone: nil, registration_number: nil, structure: nil, tax_id: nil, tax_id_registrar: nil, vat_id: nil, verification: nil ) @address = address @address_kana = address_kana @address_kanji = address_kanji @directors_provided = directors_provided @directorship_declaration = directorship_declaration @executives_provided = executives_provided @export_license_id = export_license_id @export_purpose_code = export_purpose_code @name = name @name_kana = name_kana @name_kanji = name_kanji @owners_provided = owners_provided @ownership_declaration = ownership_declaration @ownership_exemption_reason = ownership_exemption_reason @phone = phone @registration_number = registration_number @structure = structure @tax_id = tax_id @tax_id_registrar = tax_id_registrar @vat_id = vat_id @verification = verification end |
Instance Attribute Details
#address ⇒ Object
The company’s primary address.
1979 1980 1981 |
# File 'lib/stripe/resources/account.rb', line 1979 def address @address end |
#address_kana ⇒ Object
The Kana variation of the company’s primary address (Japan only).
1981 1982 1983 |
# File 'lib/stripe/resources/account.rb', line 1981 def address_kana @address_kana end |
#address_kanji ⇒ Object
The Kanji variation of the company’s primary address (Japan only).
1983 1984 1985 |
# File 'lib/stripe/resources/account.rb', line 1983 def address_kanji @address_kanji end |
#directors_provided ⇒ Object
Whether the company’s directors have been provided. Set this Boolean to ‘true` after creating all the company’s directors with [the Persons API](/api/persons) for accounts with a ‘relationship.director` requirement. This value is not automatically set to `true` after creating directors, so it needs to be updated to indicate all directors have been provided.
1985 1986 1987 |
# File 'lib/stripe/resources/account.rb', line 1985 def directors_provided @directors_provided end |
#directorship_declaration ⇒ Object
This hash is used to attest that the directors information provided to Stripe is both current and correct.
1987 1988 1989 |
# File 'lib/stripe/resources/account.rb', line 1987 def directorship_declaration @directorship_declaration end |
#executives_provided ⇒ Object
Whether the company’s executives have been provided. Set this Boolean to ‘true` after creating all the company’s executives with [the Persons API](/api/persons) for accounts with a ‘relationship.executive` requirement.
1989 1990 1991 |
# File 'lib/stripe/resources/account.rb', line 1989 def executives_provided @executives_provided end |
#export_license_id ⇒ Object
The export license ID number of the company, also referred as Import Export Code (India only).
1991 1992 1993 |
# File 'lib/stripe/resources/account.rb', line 1991 def export_license_id @export_license_id end |
#export_purpose_code ⇒ Object
The purpose code to use for export transactions (India only).
1993 1994 1995 |
# File 'lib/stripe/resources/account.rb', line 1993 def export_purpose_code @export_purpose_code end |
#name ⇒ Object
The company’s legal name.
1995 1996 1997 |
# File 'lib/stripe/resources/account.rb', line 1995 def name @name end |
#name_kana ⇒ Object
The Kana variation of the company’s legal name (Japan only).
1997 1998 1999 |
# File 'lib/stripe/resources/account.rb', line 1997 def name_kana @name_kana end |
#name_kanji ⇒ Object
The Kanji variation of the company’s legal name (Japan only).
1999 2000 2001 |
# File 'lib/stripe/resources/account.rb', line 1999 def name_kanji @name_kanji end |
#owners_provided ⇒ Object
Whether the company’s owners have been provided. Set this Boolean to ‘true` after creating all the company’s owners with [the Persons API](/api/persons) for accounts with a ‘relationship.owner` requirement.
2001 2002 2003 |
# File 'lib/stripe/resources/account.rb', line 2001 def owners_provided @owners_provided end |
#ownership_declaration ⇒ Object
This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.
2003 2004 2005 |
# File 'lib/stripe/resources/account.rb', line 2003 def ownership_declaration @ownership_declaration end |
#ownership_exemption_reason ⇒ Object
This value is used to determine if a business is exempt from providing ultimate beneficial owners. See [this support article](support.stripe.com/questions/exemption-from-providing-ownership-details) and [changelog](docs.stripe.com/changelog/acacia/2025-01-27/ownership-exemption-reason-accounts-api) for more details.
2005 2006 2007 |
# File 'lib/stripe/resources/account.rb', line 2005 def ownership_exemption_reason @ownership_exemption_reason end |
#phone ⇒ Object
The company’s phone number (used for verification).
2007 2008 2009 |
# File 'lib/stripe/resources/account.rb', line 2007 def phone @phone end |
#registration_number ⇒ Object
The identification number given to a company when it is registered or incorporated, if distinct from the identification number used for filing taxes. (Examples are the CIN for companies and LLP IN for partnerships in India, and the Company Registration Number in Hong Kong).
2009 2010 2011 |
# File 'lib/stripe/resources/account.rb', line 2009 def registration_number @registration_number end |
#structure ⇒ Object
The category identifying the legal structure of the company or legal entity. See [Business structure](/connect/identity-verification#business-structure) for more details. Pass an empty string to unset this value.
2011 2012 2013 |
# File 'lib/stripe/resources/account.rb', line 2011 def structure @structure end |
#tax_id ⇒ Object
The business ID number of the company, as appropriate for the company’s country. (Examples are an Employer ID Number in the U.S., a Business Number in Canada, or a Company Number in the UK.)
2013 2014 2015 |
# File 'lib/stripe/resources/account.rb', line 2013 def tax_id @tax_id end |
#tax_id_registrar ⇒ Object
The jurisdiction in which the ‘tax_id` is registered (Germany-based companies only).
2015 2016 2017 |
# File 'lib/stripe/resources/account.rb', line 2015 def tax_id_registrar @tax_id_registrar end |
#vat_id ⇒ Object
The VAT number of the company.
2017 2018 2019 |
# File 'lib/stripe/resources/account.rb', line 2017 def vat_id @vat_id end |
#verification ⇒ Object
Information on the verification state of the company.
2019 2020 2021 |
# File 'lib/stripe/resources/account.rb', line 2019 def verification @verification end |