Class: Stripe::Account::UpdateParams::Company

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: Address, AddressKana, AddressKanji, OwnershipDeclaration, Verification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, address_kana: nil, address_kanji: nil, directors_provided: nil, executives_provided: nil, export_license_id: nil, export_purpose_code: nil, name: nil, name_kana: nil, name_kanji: nil, owners_provided: nil, ownership_declaration: nil, ownership_exemption_reason: nil, phone: nil, registration_number: nil, structure: nil, tax_id: nil, tax_id_registrar: nil, vat_id: nil, verification: nil) ⇒ Company

Returns a new instance of Company.



1934
1935
1936
1937
1938
1939
1940
1941
1942
1943
1944
1945
1946
1947
1948
1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
1967
1968
1969
1970
1971
1972
1973
1974
1975
1976
# File 'lib/stripe/resources/account.rb', line 1934

def initialize(
  address: nil,
  address_kana: nil,
  address_kanji: nil,
  directors_provided: nil,
  executives_provided: nil,
  export_license_id: nil,
  export_purpose_code: nil,
  name: nil,
  name_kana: nil,
  name_kanji: nil,
  owners_provided: nil,
  ownership_declaration: nil,
  ownership_exemption_reason: nil,
  phone: nil,
  registration_number: nil,
  structure: nil,
  tax_id: nil,
  tax_id_registrar: nil,
  vat_id: nil,
  verification: nil
)
  @address = address
  @address_kana = address_kana
  @address_kanji = address_kanji
  @directors_provided = directors_provided
  @executives_provided = executives_provided
  @export_license_id = export_license_id
  @export_purpose_code = export_purpose_code
  @name = name
  @name_kana = name_kana
  @name_kanji = name_kanji
  @owners_provided = owners_provided
  @ownership_declaration = ownership_declaration
  @ownership_exemption_reason = ownership_exemption_reason
  @phone = phone
  @registration_number = registration_number
  @structure = structure
  @tax_id = tax_id
  @tax_id_registrar = tax_id_registrar
  @vat_id = vat_id
  @verification = verification
end

Instance Attribute Details

#addressObject

The company’s primary address.



1894
1895
1896
# File 'lib/stripe/resources/account.rb', line 1894

def address
  @address
end

#address_kanaObject

The Kana variation of the company’s primary address (Japan only).



1896
1897
1898
# File 'lib/stripe/resources/account.rb', line 1896

def address_kana
  @address_kana
end

#address_kanjiObject

The Kanji variation of the company’s primary address (Japan only).



1898
1899
1900
# File 'lib/stripe/resources/account.rb', line 1898

def address_kanji
  @address_kanji
end

#directors_providedObject

Whether the company’s directors have been provided. Set this Boolean to ‘true` after creating all the company’s directors with [the Persons API](/api/persons) for accounts with a ‘relationship.director` requirement. This value is not automatically set to `true` after creating directors, so it needs to be updated to indicate all directors have been provided.



1900
1901
1902
# File 'lib/stripe/resources/account.rb', line 1900

def directors_provided
  @directors_provided
end

#executives_providedObject

Whether the company’s executives have been provided. Set this Boolean to ‘true` after creating all the company’s executives with [the Persons API](/api/persons) for accounts with a ‘relationship.executive` requirement.



1902
1903
1904
# File 'lib/stripe/resources/account.rb', line 1902

def executives_provided
  @executives_provided
end

#export_license_idObject

The export license ID number of the company, also referred as Import Export Code (India only).



1904
1905
1906
# File 'lib/stripe/resources/account.rb', line 1904

def export_license_id
  @export_license_id
end

#export_purpose_codeObject

The purpose code to use for export transactions (India only).



1906
1907
1908
# File 'lib/stripe/resources/account.rb', line 1906

def export_purpose_code
  @export_purpose_code
end

#nameObject

The company’s legal name.



1908
1909
1910
# File 'lib/stripe/resources/account.rb', line 1908

def name
  @name
end

#name_kanaObject

The Kana variation of the company’s legal name (Japan only).



1910
1911
1912
# File 'lib/stripe/resources/account.rb', line 1910

def name_kana
  @name_kana
end

#name_kanjiObject

The Kanji variation of the company’s legal name (Japan only).



1912
1913
1914
# File 'lib/stripe/resources/account.rb', line 1912

def name_kanji
  @name_kanji
end

#owners_providedObject

Whether the company’s owners have been provided. Set this Boolean to ‘true` after creating all the company’s owners with [the Persons API](/api/persons) for accounts with a ‘relationship.owner` requirement.



1914
1915
1916
# File 'lib/stripe/resources/account.rb', line 1914

def owners_provided
  @owners_provided
end

#ownership_declarationObject

This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.



1916
1917
1918
# File 'lib/stripe/resources/account.rb', line 1916

def ownership_declaration
  @ownership_declaration
end

#ownership_exemption_reasonObject

Attribute for param field ownership_exemption_reason



1918
1919
1920
# File 'lib/stripe/resources/account.rb', line 1918

def ownership_exemption_reason
  @ownership_exemption_reason
end

#phoneObject

The company’s phone number (used for verification).



1920
1921
1922
# File 'lib/stripe/resources/account.rb', line 1920

def phone
  @phone
end

#registration_numberObject

The identification number given to a company when it is registered or incorporated, if distinct from the identification number used for filing taxes. (Examples are the CIN for companies and LLP IN for partnerships in India, and the Company Registration Number in Hong Kong).



1922
1923
1924
# File 'lib/stripe/resources/account.rb', line 1922

def registration_number
  @registration_number
end

#structureObject

The category identifying the legal structure of the company or legal entity. See [Business structure](/connect/identity-verification#business-structure) for more details. Pass an empty string to unset this value.



1924
1925
1926
# File 'lib/stripe/resources/account.rb', line 1924

def structure
  @structure
end

#tax_idObject

The business ID number of the company, as appropriate for the company’s country. (Examples are an Employer ID Number in the U.S., a Business Number in Canada, or a Company Number in the UK.)



1926
1927
1928
# File 'lib/stripe/resources/account.rb', line 1926

def tax_id
  @tax_id
end

#tax_id_registrarObject

The jurisdiction in which the ‘tax_id` is registered (Germany-based companies only).



1928
1929
1930
# File 'lib/stripe/resources/account.rb', line 1928

def tax_id_registrar
  @tax_id_registrar
end

#vat_idObject

The VAT number of the company.



1930
1931
1932
# File 'lib/stripe/resources/account.rb', line 1930

def vat_id
  @vat_id
end

#verificationObject

Information on the verification state of the company.



1932
1933
1934
# File 'lib/stripe/resources/account.rb', line 1932

def verification
  @verification
end