Class: Stripe::Account::UpdateParams::Company
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::UpdateParams::Company
- Defined in:
- lib/stripe/resources/account.rb
Defined Under Namespace
Classes: Address, AddressKana, AddressKanji, OwnershipDeclaration, Verification
Instance Attribute Summary collapse
-
#address ⇒ Object
The company’s primary address.
-
#address_kana ⇒ Object
The Kana variation of the company’s primary address (Japan only).
-
#address_kanji ⇒ Object
The Kanji variation of the company’s primary address (Japan only).
-
#directors_provided ⇒ Object
Whether the company’s directors have been provided.
-
#executives_provided ⇒ Object
Whether the company’s executives have been provided.
-
#export_license_id ⇒ Object
The export license ID number of the company, also referred as Import Export Code (India only).
-
#export_purpose_code ⇒ Object
The purpose code to use for export transactions (India only).
-
#name ⇒ Object
The company’s legal name.
-
#name_kana ⇒ Object
The Kana variation of the company’s legal name (Japan only).
-
#name_kanji ⇒ Object
The Kanji variation of the company’s legal name (Japan only).
-
#owners_provided ⇒ Object
Whether the company’s owners have been provided.
-
#ownership_declaration ⇒ Object
This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.
-
#phone ⇒ Object
The company’s phone number (used for verification).
-
#registration_number ⇒ Object
The identification number given to a company when it is registered or incorporated, if distinct from the identification number used for filing taxes.
-
#structure ⇒ Object
The category identifying the legal structure of the company or legal entity.
-
#tax_id ⇒ Object
The business ID number of the company, as appropriate for the company’s country.
-
#tax_id_registrar ⇒ Object
The jurisdiction in which the ‘tax_id` is registered (Germany-based companies only).
-
#vat_id ⇒ Object
The VAT number of the company.
-
#verification ⇒ Object
Information on the verification state of the company.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, address_kana: nil, address_kanji: nil, directors_provided: nil, executives_provided: nil, export_license_id: nil, export_purpose_code: nil, name: nil, name_kana: nil, name_kanji: nil, owners_provided: nil, ownership_declaration: nil, phone: nil, registration_number: nil, structure: nil, tax_id: nil, tax_id_registrar: nil, vat_id: nil, verification: nil) ⇒ Company
Returns a new instance of Company.
2253 2254 2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 2271 2272 2273 2274 2275 2276 2277 2278 2279 2280 2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 |
# File 'lib/stripe/resources/account.rb', line 2253 def initialize( address: nil, address_kana: nil, address_kanji: nil, directors_provided: nil, executives_provided: nil, export_license_id: nil, export_purpose_code: nil, name: nil, name_kana: nil, name_kanji: nil, owners_provided: nil, ownership_declaration: nil, phone: nil, registration_number: nil, structure: nil, tax_id: nil, tax_id_registrar: nil, vat_id: nil, verification: nil ) @address = address @address_kana = address_kana @address_kanji = address_kanji @directors_provided = directors_provided @executives_provided = executives_provided @export_license_id = export_license_id @export_purpose_code = export_purpose_code @name = name @name_kana = name_kana @name_kanji = name_kanji @owners_provided = owners_provided @ownership_declaration = ownership_declaration @phone = phone @registration_number = registration_number @structure = structure @tax_id = tax_id @tax_id_registrar = tax_id_registrar @vat_id = vat_id @verification = verification end |
Instance Attribute Details
#address ⇒ Object
The company’s primary address.
2197 2198 2199 |
# File 'lib/stripe/resources/account.rb', line 2197 def address @address end |
#address_kana ⇒ Object
The Kana variation of the company’s primary address (Japan only).
2200 2201 2202 |
# File 'lib/stripe/resources/account.rb', line 2200 def address_kana @address_kana end |
#address_kanji ⇒ Object
The Kanji variation of the company’s primary address (Japan only).
2203 2204 2205 |
# File 'lib/stripe/resources/account.rb', line 2203 def address_kanji @address_kanji end |
#directors_provided ⇒ Object
Whether the company’s directors have been provided. Set this Boolean to ‘true` after creating all the company’s directors with [the Persons API](/api/persons) for accounts with a ‘relationship.director` requirement. This value is not automatically set to `true` after creating directors, so it needs to be updated to indicate all directors have been provided.
2206 2207 2208 |
# File 'lib/stripe/resources/account.rb', line 2206 def directors_provided @directors_provided end |
#executives_provided ⇒ Object
Whether the company’s executives have been provided. Set this Boolean to ‘true` after creating all the company’s executives with [the Persons API](/api/persons) for accounts with a ‘relationship.executive` requirement.
2209 2210 2211 |
# File 'lib/stripe/resources/account.rb', line 2209 def executives_provided @executives_provided end |
#export_license_id ⇒ Object
The export license ID number of the company, also referred as Import Export Code (India only).
2212 2213 2214 |
# File 'lib/stripe/resources/account.rb', line 2212 def export_license_id @export_license_id end |
#export_purpose_code ⇒ Object
The purpose code to use for export transactions (India only).
2215 2216 2217 |
# File 'lib/stripe/resources/account.rb', line 2215 def export_purpose_code @export_purpose_code end |
#name ⇒ Object
The company’s legal name.
2218 2219 2220 |
# File 'lib/stripe/resources/account.rb', line 2218 def name @name end |
#name_kana ⇒ Object
The Kana variation of the company’s legal name (Japan only).
2221 2222 2223 |
# File 'lib/stripe/resources/account.rb', line 2221 def name_kana @name_kana end |
#name_kanji ⇒ Object
The Kanji variation of the company’s legal name (Japan only).
2224 2225 2226 |
# File 'lib/stripe/resources/account.rb', line 2224 def name_kanji @name_kanji end |
#owners_provided ⇒ Object
Whether the company’s owners have been provided. Set this Boolean to ‘true` after creating all the company’s owners with [the Persons API](/api/persons) for accounts with a ‘relationship.owner` requirement.
2227 2228 2229 |
# File 'lib/stripe/resources/account.rb', line 2227 def owners_provided @owners_provided end |
#ownership_declaration ⇒ Object
This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.
2230 2231 2232 |
# File 'lib/stripe/resources/account.rb', line 2230 def ownership_declaration @ownership_declaration end |
#phone ⇒ Object
The company’s phone number (used for verification).
2233 2234 2235 |
# File 'lib/stripe/resources/account.rb', line 2233 def phone @phone end |
#registration_number ⇒ Object
The identification number given to a company when it is registered or incorporated, if distinct from the identification number used for filing taxes. (Examples are the CIN for companies and LLP IN for partnerships in India, and the Company Registration Number in Hong Kong).
2236 2237 2238 |
# File 'lib/stripe/resources/account.rb', line 2236 def registration_number @registration_number end |
#structure ⇒ Object
The category identifying the legal structure of the company or legal entity. See [Business structure](/connect/identity-verification#business-structure) for more details. Pass an empty string to unset this value.
2239 2240 2241 |
# File 'lib/stripe/resources/account.rb', line 2239 def structure @structure end |
#tax_id ⇒ Object
The business ID number of the company, as appropriate for the company’s country. (Examples are an Employer ID Number in the U.S., a Business Number in Canada, or a Company Number in the UK.)
2242 2243 2244 |
# File 'lib/stripe/resources/account.rb', line 2242 def tax_id @tax_id end |
#tax_id_registrar ⇒ Object
The jurisdiction in which the ‘tax_id` is registered (Germany-based companies only).
2245 2246 2247 |
# File 'lib/stripe/resources/account.rb', line 2245 def tax_id_registrar @tax_id_registrar end |
#vat_id ⇒ Object
The VAT number of the company.
2248 2249 2250 |
# File 'lib/stripe/resources/account.rb', line 2248 def vat_id @vat_id end |
#verification ⇒ Object
Information on the verification state of the company.
2251 2252 2253 |
# File 'lib/stripe/resources/account.rb', line 2251 def verification @verification end |