Class: Stripe::Account::UpdateParams::Company::DirectorshipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ DirectorshipDeclaration

Returns a new instance of DirectorshipDeclaration.



1716
1717
1718
1719
1720
# File 'lib/stripe/resources/account.rb', line 1716

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the directorship declaration attestation was made.



1710
1711
1712
# File 'lib/stripe/resources/account.rb', line 1710

def date
  @date
end

#ipObject

The IP address from which the directorship declaration attestation was made.



1712
1713
1714
# File 'lib/stripe/resources/account.rb', line 1712

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the directorship declaration attestation was made.



1714
1715
1716
# File 'lib/stripe/resources/account.rb', line 1714

def user_agent
  @user_agent
end