Class: Stripe::Account::UpdateParams::Company::DirectorshipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ DirectorshipDeclaration

Returns a new instance of DirectorshipDeclaration.



1987
1988
1989
1990
1991
# File 'lib/stripe/resources/account.rb', line 1987

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the directorship declaration attestation was made.



1981
1982
1983
# File 'lib/stripe/resources/account.rb', line 1981

def date
  @date
end

#ipObject

The IP address from which the directorship declaration attestation was made.



1983
1984
1985
# File 'lib/stripe/resources/account.rb', line 1983

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the directorship declaration attestation was made.



1985
1986
1987
# File 'lib/stripe/resources/account.rb', line 1985

def user_agent
  @user_agent
end