Class: Stripe::Account::UpdateParams::Company::DirectorshipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ DirectorshipDeclaration

Returns a new instance of DirectorshipDeclaration.



1968
1969
1970
1971
1972
# File 'lib/stripe/resources/account.rb', line 1968

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the directorship declaration attestation was made.



1962
1963
1964
# File 'lib/stripe/resources/account.rb', line 1962

def date
  @date
end

#ipObject

The IP address from which the directorship declaration attestation was made.



1964
1965
1966
# File 'lib/stripe/resources/account.rb', line 1964

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the directorship declaration attestation was made.



1966
1967
1968
# File 'lib/stripe/resources/account.rb', line 1966

def user_agent
  @user_agent
end