Class: Stripe::Account::UpdateParams::Company::DirectorshipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ DirectorshipDeclaration

Returns a new instance of DirectorshipDeclaration.



1683
1684
1685
1686
1687
# File 'lib/stripe/resources/account.rb', line 1683

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the directorship declaration attestation was made.



1677
1678
1679
# File 'lib/stripe/resources/account.rb', line 1677

def date
  @date
end

#ipObject

The IP address from which the directorship declaration attestation was made.



1679
1680
1681
# File 'lib/stripe/resources/account.rb', line 1679

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the directorship declaration attestation was made.



1681
1682
1683
# File 'lib/stripe/resources/account.rb', line 1681

def user_agent
  @user_agent
end