Class: Stripe::Account::UpdateParams::Company::DirectorshipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ DirectorshipDeclaration

Returns a new instance of DirectorshipDeclaration.



1937
1938
1939
1940
1941
# File 'lib/stripe/resources/account.rb', line 1937

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the directorship declaration attestation was made.



1931
1932
1933
# File 'lib/stripe/resources/account.rb', line 1931

def date
  @date
end

#ipObject

The IP address from which the directorship declaration attestation was made.



1933
1934
1935
# File 'lib/stripe/resources/account.rb', line 1933

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the directorship declaration attestation was made.



1935
1936
1937
# File 'lib/stripe/resources/account.rb', line 1935

def user_agent
  @user_agent
end