Class: Stripe::Account::UpdateParams::Company::DirectorshipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ DirectorshipDeclaration

Returns a new instance of DirectorshipDeclaration.



1666
1667
1668
1669
1670
# File 'lib/stripe/resources/account.rb', line 1666

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the directorship declaration attestation was made.



1660
1661
1662
# File 'lib/stripe/resources/account.rb', line 1660

def date
  @date
end

#ipObject

The IP address from which the directorship declaration attestation was made.



1662
1663
1664
# File 'lib/stripe/resources/account.rb', line 1662

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the directorship declaration attestation was made.



1664
1665
1666
# File 'lib/stripe/resources/account.rb', line 1664

def user_agent
  @user_agent
end