Class: Stripe::Account::UpdateParams::Company::OwnershipDeclaration
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::UpdateParams::Company::OwnershipDeclaration
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the beneficial owner attestation was made.
-
#ip ⇒ Object
The IP address from which the beneficial owner attestation was made.
-
#user_agent ⇒ Object
The user agent of the browser from which the beneficial owner attestation was made.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ OwnershipDeclaration
constructor
A new instance of OwnershipDeclaration.
Methods inherited from RequestParams
Constructor Details
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ OwnershipDeclaration
Returns a new instance of OwnershipDeclaration.
2002 2003 2004 2005 2006 |
# File 'lib/stripe/resources/account.rb', line 2002 def initialize(date: nil, ip: nil, user_agent: nil) @date = date @ip = ip @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the beneficial owner attestation was made.
1996 1997 1998 |
# File 'lib/stripe/resources/account.rb', line 1996 def date @date end |
#ip ⇒ Object
The IP address from which the beneficial owner attestation was made.
1998 1999 2000 |
# File 'lib/stripe/resources/account.rb', line 1998 def ip @ip end |
#user_agent ⇒ Object
The user agent of the browser from which the beneficial owner attestation was made.
2000 2001 2002 |
# File 'lib/stripe/resources/account.rb', line 2000 def user_agent @user_agent end |