Class: Stripe::Account::UpdateParams::Company::OwnershipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ OwnershipDeclaration

Returns a new instance of OwnershipDeclaration.



1731
1732
1733
1734
1735
# File 'lib/stripe/resources/account.rb', line 1731

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the beneficial owner attestation was made.



1725
1726
1727
# File 'lib/stripe/resources/account.rb', line 1725

def date
  @date
end

#ipObject

The IP address from which the beneficial owner attestation was made.



1727
1728
1729
# File 'lib/stripe/resources/account.rb', line 1727

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the beneficial owner attestation was made.



1729
1730
1731
# File 'lib/stripe/resources/account.rb', line 1729

def user_agent
  @user_agent
end