Class: Stripe::Account::UpdateParams::Company::OwnershipDeclaration
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::UpdateParams::Company::OwnershipDeclaration
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the beneficial owner attestation was made.
-
#ip ⇒ Object
The IP address from which the beneficial owner attestation was made.
-
#user_agent ⇒ Object
The user agent of the browser from which the beneficial owner attestation was made.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ OwnershipDeclaration
constructor
A new instance of OwnershipDeclaration.
Methods inherited from RequestParams
Constructor Details
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ OwnershipDeclaration
Returns a new instance of OwnershipDeclaration.
1969 1970 1971 1972 1973 |
# File 'lib/stripe/resources/account.rb', line 1969 def initialize(date: nil, ip: nil, user_agent: nil) @date = date @ip = ip @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the beneficial owner attestation was made.
1963 1964 1965 |
# File 'lib/stripe/resources/account.rb', line 1963 def date @date end |
#ip ⇒ Object
The IP address from which the beneficial owner attestation was made.
1965 1966 1967 |
# File 'lib/stripe/resources/account.rb', line 1965 def ip @ip end |
#user_agent ⇒ Object
The user agent of the browser from which the beneficial owner attestation was made.
1967 1968 1969 |
# File 'lib/stripe/resources/account.rb', line 1967 def user_agent @user_agent end |