Class: Stripe::Account::UpdateParams::Company::OwnershipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ OwnershipDeclaration

Returns a new instance of OwnershipDeclaration.



1698
1699
1700
1701
1702
# File 'lib/stripe/resources/account.rb', line 1698

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the beneficial owner attestation was made.



1692
1693
1694
# File 'lib/stripe/resources/account.rb', line 1692

def date
  @date
end

#ipObject

The IP address from which the beneficial owner attestation was made.



1694
1695
1696
# File 'lib/stripe/resources/account.rb', line 1694

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the beneficial owner attestation was made.



1696
1697
1698
# File 'lib/stripe/resources/account.rb', line 1696

def user_agent
  @user_agent
end