Class: Stripe::Account::UpdateParams::Company::OwnershipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ OwnershipDeclaration

Returns a new instance of OwnershipDeclaration.



1958
1959
1960
1961
1962
# File 'lib/stripe/resources/account.rb', line 1958

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the beneficial owner attestation was made.



1952
1953
1954
# File 'lib/stripe/resources/account.rb', line 1952

def date
  @date
end

#ipObject

The IP address from which the beneficial owner attestation was made.



1954
1955
1956
# File 'lib/stripe/resources/account.rb', line 1954

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the beneficial owner attestation was made.



1956
1957
1958
# File 'lib/stripe/resources/account.rb', line 1956

def user_agent
  @user_agent
end