Class: Stripe::Account::UpdateParams::Company::OwnershipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ OwnershipDeclaration

Returns a new instance of OwnershipDeclaration.



1867
1868
1869
1870
1871
# File 'lib/stripe/resources/account.rb', line 1867

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the beneficial owner attestation was made.



1861
1862
1863
# File 'lib/stripe/resources/account.rb', line 1861

def date
  @date
end

#ipObject

The IP address from which the beneficial owner attestation was made.



1863
1864
1865
# File 'lib/stripe/resources/account.rb', line 1863

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the beneficial owner attestation was made.



1865
1866
1867
# File 'lib/stripe/resources/account.rb', line 1865

def user_agent
  @user_agent
end