Class: Stripe::Account::UpdateParams::Company::OwnershipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ OwnershipDeclaration

Returns a new instance of OwnershipDeclaration.



2169
2170
2171
2172
2173
# File 'lib/stripe/resources/account.rb', line 2169

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the beneficial owner attestation was made.



2161
2162
2163
# File 'lib/stripe/resources/account.rb', line 2161

def date
  @date
end

#ipObject

The IP address from which the beneficial owner attestation was made.



2164
2165
2166
# File 'lib/stripe/resources/account.rb', line 2164

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the beneficial owner attestation was made.



2167
2168
2169
# File 'lib/stripe/resources/account.rb', line 2167

def user_agent
  @user_agent
end