Class: Stripe::Account::UpdateParams::Company::OwnershipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ OwnershipDeclaration

Returns a new instance of OwnershipDeclaration.



1897
1898
1899
1900
1901
# File 'lib/stripe/resources/account.rb', line 1897

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the beneficial owner attestation was made.



1891
1892
1893
# File 'lib/stripe/resources/account.rb', line 1891

def date
  @date
end

#ipObject

The IP address from which the beneficial owner attestation was made.



1893
1894
1895
# File 'lib/stripe/resources/account.rb', line 1893

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the beneficial owner attestation was made.



1895
1896
1897
# File 'lib/stripe/resources/account.rb', line 1895

def user_agent
  @user_agent
end