Class: Stripe::Account::UpdateParams::Documents

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: BankAccountOwnershipVerification, CompanyLicense, CompanyMemorandumOfAssociation, CompanyMinisterialDecree, CompanyRegistrationVerification, CompanyTaxIdVerification, ProofOfAddress, ProofOfRegistration, ProofOfUltimateBeneficialOwnership

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bank_account_ownership_verification: nil, company_license: nil, company_memorandum_of_association: nil, company_ministerial_decree: nil, company_registration_verification: nil, company_tax_id_verification: nil, proof_of_address: nil, proof_of_registration: nil, proof_of_ultimate_beneficial_ownership: nil) ⇒ Documents

Returns a new instance of Documents.



2237
2238
2239
2240
2241
2242
2243
2244
2245
2246
2247
2248
2249
2250
2251
2252
2253
2254
2255
2256
2257
# File 'lib/stripe/resources/account.rb', line 2237

def initialize(
  bank_account_ownership_verification: nil,
  company_license: nil,
  company_memorandum_of_association: nil,
  company_ministerial_decree: nil,
  company_registration_verification: nil,
  company_tax_id_verification: nil,
  proof_of_address: nil,
  proof_of_registration: nil,
  proof_of_ultimate_beneficial_ownership: nil
)
  @bank_account_ownership_verification = 
  @company_license = company_license
  @company_memorandum_of_association = company_memorandum_of_association
  @company_ministerial_decree = company_ministerial_decree
  @company_registration_verification = company_registration_verification
  @company_tax_id_verification = company_tax_id_verification
  @proof_of_address = proof_of_address
  @proof_of_registration = proof_of_registration
  @proof_of_ultimate_beneficial_ownership = proof_of_ultimate_beneficial_ownership
end

Instance Attribute Details

#bank_account_ownership_verificationObject

One or more documents that support the [Bank account ownership verification](support.stripe.com/questions/bank-account-ownership-verification) requirement. Must be a document associated with the account’s primary active bank account that displays the last 4 digits of the account number, either a statement or a check.



2219
2220
2221
# File 'lib/stripe/resources/account.rb', line 2219

def 
  @bank_account_ownership_verification
end

#company_licenseObject

One or more documents that demonstrate proof of a company’s license to operate.



2221
2222
2223
# File 'lib/stripe/resources/account.rb', line 2221

def company_license
  @company_license
end

#company_memorandum_of_associationObject

One or more documents showing the company’s Memorandum of Association.



2223
2224
2225
# File 'lib/stripe/resources/account.rb', line 2223

def company_memorandum_of_association
  @company_memorandum_of_association
end

#company_ministerial_decreeObject

(Certain countries only) One or more documents showing the ministerial decree legalizing the company’s establishment.



2225
2226
2227
# File 'lib/stripe/resources/account.rb', line 2225

def company_ministerial_decree
  @company_ministerial_decree
end

#company_registration_verificationObject

One or more documents that demonstrate proof of a company’s registration with the appropriate local authorities.



2227
2228
2229
# File 'lib/stripe/resources/account.rb', line 2227

def company_registration_verification
  @company_registration_verification
end

#company_tax_id_verificationObject

One or more documents that demonstrate proof of a company’s tax ID.



2229
2230
2231
# File 'lib/stripe/resources/account.rb', line 2229

def company_tax_id_verification
  @company_tax_id_verification
end

#proof_of_addressObject

One or more documents that demonstrate proof of address.



2231
2232
2233
# File 'lib/stripe/resources/account.rb', line 2231

def proof_of_address
  @proof_of_address
end

#proof_of_registrationObject

One or more documents showing the company’s proof of registration with the national business registry.



2233
2234
2235
# File 'lib/stripe/resources/account.rb', line 2233

def proof_of_registration
  @proof_of_registration
end

#proof_of_ultimate_beneficial_ownershipObject

One or more documents that demonstrate proof of ultimate beneficial ownership.



2235
2236
2237
# File 'lib/stripe/resources/account.rb', line 2235

def proof_of_ultimate_beneficial_ownership
  @proof_of_ultimate_beneficial_ownership
end