Class: Stripe::Account::UpdateParams::Documents

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: BankAccountOwnershipVerification, CompanyLicense, CompanyMemorandumOfAssociation, CompanyMinisterialDecree, CompanyRegistrationVerification, CompanyTaxIdVerification, ProofOfRegistration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bank_account_ownership_verification: nil, company_license: nil, company_memorandum_of_association: nil, company_ministerial_decree: nil, company_registration_verification: nil, company_tax_id_verification: nil, proof_of_registration: nil) ⇒ Documents

Returns a new instance of Documents.



2057
2058
2059
2060
2061
2062
2063
2064
2065
2066
2067
2068
2069
2070
2071
2072
2073
# File 'lib/stripe/resources/account.rb', line 2057

def initialize(
  bank_account_ownership_verification: nil,
  company_license: nil,
  company_memorandum_of_association: nil,
  company_ministerial_decree: nil,
  company_registration_verification: nil,
  company_tax_id_verification: nil,
  proof_of_registration: nil
)
  @bank_account_ownership_verification = 
  @company_license = company_license
  @company_memorandum_of_association = company_memorandum_of_association
  @company_ministerial_decree = company_ministerial_decree
  @company_registration_verification = company_registration_verification
  @company_tax_id_verification = company_tax_id_verification
  @proof_of_registration = proof_of_registration
end

Instance Attribute Details

#bank_account_ownership_verificationObject

One or more documents that support the [Bank account ownership verification](support.stripe.com/questions/bank-account-ownership-verification) requirement. Must be a document associated with the account’s primary active bank account that displays the last 4 digits of the account number, either a statement or a check.



2043
2044
2045
# File 'lib/stripe/resources/account.rb', line 2043

def 
  @bank_account_ownership_verification
end

#company_licenseObject

One or more documents that demonstrate proof of a company’s license to operate.



2045
2046
2047
# File 'lib/stripe/resources/account.rb', line 2045

def company_license
  @company_license
end

#company_memorandum_of_associationObject

One or more documents showing the company’s Memorandum of Association.



2047
2048
2049
# File 'lib/stripe/resources/account.rb', line 2047

def company_memorandum_of_association
  @company_memorandum_of_association
end

#company_ministerial_decreeObject

(Certain countries only) One or more documents showing the ministerial decree legalizing the company’s establishment.



2049
2050
2051
# File 'lib/stripe/resources/account.rb', line 2049

def company_ministerial_decree
  @company_ministerial_decree
end

#company_registration_verificationObject

One or more documents that demonstrate proof of a company’s registration with the appropriate local authorities.



2051
2052
2053
# File 'lib/stripe/resources/account.rb', line 2051

def company_registration_verification
  @company_registration_verification
end

#company_tax_id_verificationObject

One or more documents that demonstrate proof of a company’s tax ID.



2053
2054
2055
# File 'lib/stripe/resources/account.rb', line 2053

def company_tax_id_verification
  @company_tax_id_verification
end

#proof_of_registrationObject

One or more documents showing the company’s proof of registration with the national business registry.



2055
2056
2057
# File 'lib/stripe/resources/account.rb', line 2055

def proof_of_registration
  @proof_of_registration
end