Class: Stripe::Account::UpdateParams::Individual
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::UpdateParams::Individual
- Defined in:
- lib/stripe/resources/account.rb
Defined Under Namespace
Classes: Address, AddressKana, AddressKanji, Dob, RegisteredAddress, Relationship, Verification
Instance Attribute Summary collapse
-
#address ⇒ Object
The individual’s primary address.
-
#address_kana ⇒ Object
The Kana variation of the individual’s primary address (Japan only).
-
#address_kanji ⇒ Object
The Kanji variation of the individual’s primary address (Japan only).
-
#dob ⇒ Object
The individual’s date of birth.
-
#email ⇒ Object
The individual’s email address.
-
#first_name ⇒ Object
The individual’s first name.
-
#first_name_kana ⇒ Object
The Kana variation of the individual’s first name (Japan only).
-
#first_name_kanji ⇒ Object
The Kanji variation of the individual’s first name (Japan only).
-
#full_name_aliases ⇒ Object
A list of alternate names or aliases that the individual is known by.
-
#gender ⇒ Object
The individual’s gender.
-
#id_number ⇒ Object
The government-issued ID number of the individual, as appropriate for the representative’s country.
-
#id_number_secondary ⇒ Object
The government-issued secondary ID number of the individual, as appropriate for the representative’s country, will be used for enhanced verification checks.
-
#last_name ⇒ Object
The individual’s last name.
-
#last_name_kana ⇒ Object
The Kana variation of the individual’s last name (Japan only).
-
#last_name_kanji ⇒ Object
The Kanji variation of the individual’s last name (Japan only).
-
#maiden_name ⇒ Object
The individual’s maiden name.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#phone ⇒ Object
The individual’s phone number.
-
#political_exposure ⇒ Object
Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
-
#registered_address ⇒ Object
The individual’s registered address.
-
#relationship ⇒ Object
Describes the person’s relationship to the account.
-
#ssn_last_4 ⇒ Object
The last four digits of the individual’s Social Security Number (U.S. only).
-
#verification ⇒ Object
The individual’s verification document information.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, address_kana: nil, address_kanji: nil, dob: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil) ⇒ Individual
Returns a new instance of Individual.
2525 2526 2527 2528 2529 2530 2531 2532 2533 2534 2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 2548 2549 2550 2551 2552 2553 2554 2555 2556 2557 2558 2559 2560 2561 2562 2563 2564 2565 2566 2567 2568 2569 2570 2571 2572 2573 |
# File 'lib/stripe/resources/account.rb', line 2525 def initialize( address: nil, address_kana: nil, address_kanji: nil, dob: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil ) @address = address @address_kana = address_kana @address_kanji = address_kanji @dob = dob @email = email @first_name = first_name @first_name_kana = first_name_kana @first_name_kanji = first_name_kanji @full_name_aliases = full_name_aliases @gender = gender @id_number = id_number @id_number_secondary = id_number_secondary @last_name = last_name @last_name_kana = last_name_kana @last_name_kanji = last_name_kanji @maiden_name = maiden_name @metadata = @phone = phone @political_exposure = political_exposure @registered_address = registered_address @relationship = relationship @ssn_last_4 = ssn_last_4 @verification = verification end |
Instance Attribute Details
#address ⇒ Object
The individual’s primary address.
2479 2480 2481 |
# File 'lib/stripe/resources/account.rb', line 2479 def address @address end |
#address_kana ⇒ Object
The Kana variation of the individual’s primary address (Japan only).
2481 2482 2483 |
# File 'lib/stripe/resources/account.rb', line 2481 def address_kana @address_kana end |
#address_kanji ⇒ Object
The Kanji variation of the individual’s primary address (Japan only).
2483 2484 2485 |
# File 'lib/stripe/resources/account.rb', line 2483 def address_kanji @address_kanji end |
#dob ⇒ Object
The individual’s date of birth.
2485 2486 2487 |
# File 'lib/stripe/resources/account.rb', line 2485 def dob @dob end |
#email ⇒ Object
The individual’s email address.
2487 2488 2489 |
# File 'lib/stripe/resources/account.rb', line 2487 def email @email end |
#first_name ⇒ Object
The individual’s first name.
2489 2490 2491 |
# File 'lib/stripe/resources/account.rb', line 2489 def first_name @first_name end |
#first_name_kana ⇒ Object
The Kana variation of the individual’s first name (Japan only).
2491 2492 2493 |
# File 'lib/stripe/resources/account.rb', line 2491 def first_name_kana @first_name_kana end |
#first_name_kanji ⇒ Object
The Kanji variation of the individual’s first name (Japan only).
2493 2494 2495 |
# File 'lib/stripe/resources/account.rb', line 2493 def first_name_kanji @first_name_kanji end |
#full_name_aliases ⇒ Object
A list of alternate names or aliases that the individual is known by.
2495 2496 2497 |
# File 'lib/stripe/resources/account.rb', line 2495 def full_name_aliases @full_name_aliases end |
#gender ⇒ Object
The individual’s gender
2497 2498 2499 |
# File 'lib/stripe/resources/account.rb', line 2497 def gender @gender end |
#id_number ⇒ Object
The government-issued ID number of the individual, as appropriate for the representative’s country. (Examples are a Social Security Number in the U.S., or a Social Insurance Number in Canada). Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).
2499 2500 2501 |
# File 'lib/stripe/resources/account.rb', line 2499 def id_number @id_number end |
#id_number_secondary ⇒ Object
The government-issued secondary ID number of the individual, as appropriate for the representative’s country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).
2501 2502 2503 |
# File 'lib/stripe/resources/account.rb', line 2501 def id_number_secondary @id_number_secondary end |
#last_name ⇒ Object
The individual’s last name.
2503 2504 2505 |
# File 'lib/stripe/resources/account.rb', line 2503 def last_name @last_name end |
#last_name_kana ⇒ Object
The Kana variation of the individual’s last name (Japan only).
2505 2506 2507 |
# File 'lib/stripe/resources/account.rb', line 2505 def last_name_kana @last_name_kana end |
#last_name_kanji ⇒ Object
The Kanji variation of the individual’s last name (Japan only).
2507 2508 2509 |
# File 'lib/stripe/resources/account.rb', line 2507 def last_name_kanji @last_name_kanji end |
#maiden_name ⇒ Object
The individual’s maiden name.
2509 2510 2511 |
# File 'lib/stripe/resources/account.rb', line 2509 def maiden_name @maiden_name end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
2511 2512 2513 |
# File 'lib/stripe/resources/account.rb', line 2511 def @metadata end |
#phone ⇒ Object
The individual’s phone number.
2513 2514 2515 |
# File 'lib/stripe/resources/account.rb', line 2513 def phone @phone end |
#political_exposure ⇒ Object
Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
2515 2516 2517 |
# File 'lib/stripe/resources/account.rb', line 2515 def political_exposure @political_exposure end |
#registered_address ⇒ Object
The individual’s registered address.
2517 2518 2519 |
# File 'lib/stripe/resources/account.rb', line 2517 def registered_address @registered_address end |
#relationship ⇒ Object
Describes the person’s relationship to the account.
2519 2520 2521 |
# File 'lib/stripe/resources/account.rb', line 2519 def relationship @relationship end |
#ssn_last_4 ⇒ Object
The last four digits of the individual’s Social Security Number (U.S. only).
2521 2522 2523 |
# File 'lib/stripe/resources/account.rb', line 2521 def ssn_last_4 @ssn_last_4 end |
#verification ⇒ Object
The individual’s verification document information.
2523 2524 2525 |
# File 'lib/stripe/resources/account.rb', line 2523 def verification @verification end |