Class: Stripe::Account::UpdateParams::Individual

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: Address, AddressKana, AddressKanji, Dob, RegisteredAddress, Relationship, Verification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, address_kana: nil, address_kanji: nil, dob: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil) ⇒ Individual

Returns a new instance of Individual.



2254
2255
2256
2257
2258
2259
2260
2261
2262
2263
2264
2265
2266
2267
2268
2269
2270
2271
2272
2273
2274
2275
2276
2277
2278
2279
2280
2281
2282
2283
2284
2285
2286
2287
2288
2289
2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
2300
2301
2302
# File 'lib/stripe/resources/account.rb', line 2254

def initialize(
  address: nil,
  address_kana: nil,
  address_kanji: nil,
  dob: nil,
  email: nil,
  first_name: nil,
  first_name_kana: nil,
  first_name_kanji: nil,
  full_name_aliases: nil,
  gender: nil,
  id_number: nil,
  id_number_secondary: nil,
  last_name: nil,
  last_name_kana: nil,
  last_name_kanji: nil,
  maiden_name: nil,
  metadata: nil,
  phone: nil,
  political_exposure: nil,
  registered_address: nil,
  relationship: nil,
  ssn_last_4: nil,
  verification: nil
)
  @address = address
  @address_kana = address_kana
  @address_kanji = address_kanji
  @dob = dob
  @email = email
  @first_name = first_name
  @first_name_kana = first_name_kana
  @first_name_kanji = first_name_kanji
  @full_name_aliases = full_name_aliases
  @gender = gender
  @id_number = id_number
  @id_number_secondary = id_number_secondary
  @last_name = last_name
  @last_name_kana = last_name_kana
  @last_name_kanji = last_name_kanji
  @maiden_name = maiden_name
  @metadata = 
  @phone = phone
  @political_exposure = political_exposure
  @registered_address = registered_address
  @relationship = relationship
  @ssn_last_4 = ssn_last_4
  @verification = verification
end

Instance Attribute Details

#addressObject

The individual’s primary address.



2208
2209
2210
# File 'lib/stripe/resources/account.rb', line 2208

def address
  @address
end

#address_kanaObject

The Kana variation of the individual’s primary address (Japan only).



2210
2211
2212
# File 'lib/stripe/resources/account.rb', line 2210

def address_kana
  @address_kana
end

#address_kanjiObject

The Kanji variation of the individual’s primary address (Japan only).



2212
2213
2214
# File 'lib/stripe/resources/account.rb', line 2212

def address_kanji
  @address_kanji
end

#dobObject

The individual’s date of birth.



2214
2215
2216
# File 'lib/stripe/resources/account.rb', line 2214

def dob
  @dob
end

#emailObject

The individual’s email address.



2216
2217
2218
# File 'lib/stripe/resources/account.rb', line 2216

def email
  @email
end

#first_nameObject

The individual’s first name.



2218
2219
2220
# File 'lib/stripe/resources/account.rb', line 2218

def first_name
  @first_name
end

#first_name_kanaObject

The Kana variation of the individual’s first name (Japan only).



2220
2221
2222
# File 'lib/stripe/resources/account.rb', line 2220

def first_name_kana
  @first_name_kana
end

#first_name_kanjiObject

The Kanji variation of the individual’s first name (Japan only).



2222
2223
2224
# File 'lib/stripe/resources/account.rb', line 2222

def first_name_kanji
  @first_name_kanji
end

#full_name_aliasesObject

A list of alternate names or aliases that the individual is known by.



2224
2225
2226
# File 'lib/stripe/resources/account.rb', line 2224

def full_name_aliases
  @full_name_aliases
end

#genderObject

The individual’s gender



2226
2227
2228
# File 'lib/stripe/resources/account.rb', line 2226

def gender
  @gender
end

#id_numberObject

The government-issued ID number of the individual, as appropriate for the representative’s country. (Examples are a Social Security Number in the U.S., or a Social Insurance Number in Canada). Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).



2228
2229
2230
# File 'lib/stripe/resources/account.rb', line 2228

def id_number
  @id_number
end

#id_number_secondaryObject

The government-issued secondary ID number of the individual, as appropriate for the representative’s country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).



2230
2231
2232
# File 'lib/stripe/resources/account.rb', line 2230

def id_number_secondary
  @id_number_secondary
end

#last_nameObject

The individual’s last name.



2232
2233
2234
# File 'lib/stripe/resources/account.rb', line 2232

def last_name
  @last_name
end

#last_name_kanaObject

The Kana variation of the individual’s last name (Japan only).



2234
2235
2236
# File 'lib/stripe/resources/account.rb', line 2234

def last_name_kana
  @last_name_kana
end

#last_name_kanjiObject

The Kanji variation of the individual’s last name (Japan only).



2236
2237
2238
# File 'lib/stripe/resources/account.rb', line 2236

def last_name_kanji
  @last_name_kanji
end

#maiden_nameObject

The individual’s maiden name.



2238
2239
2240
# File 'lib/stripe/resources/account.rb', line 2238

def maiden_name
  @maiden_name
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2240
2241
2242
# File 'lib/stripe/resources/account.rb', line 2240

def 
  @metadata
end

#phoneObject

The individual’s phone number.



2242
2243
2244
# File 'lib/stripe/resources/account.rb', line 2242

def phone
  @phone
end

#political_exposureObject

Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.



2244
2245
2246
# File 'lib/stripe/resources/account.rb', line 2244

def political_exposure
  @political_exposure
end

#registered_addressObject

The individual’s registered address.



2246
2247
2248
# File 'lib/stripe/resources/account.rb', line 2246

def registered_address
  @registered_address
end

#relationshipObject

Describes the person’s relationship to the account.



2248
2249
2250
# File 'lib/stripe/resources/account.rb', line 2248

def relationship
  @relationship
end

#ssn_last_4Object

The last four digits of the individual’s Social Security Number (U.S. only).



2250
2251
2252
# File 'lib/stripe/resources/account.rb', line 2250

def ssn_last_4
  @ssn_last_4
end

#verificationObject

The individual’s verification document information.



2252
2253
2254
# File 'lib/stripe/resources/account.rb', line 2252

def verification
  @verification
end