Class: Stripe::Account::UpdateParams::Individual

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: Address, AddressKana, AddressKanji, Dob, RegisteredAddress, Relationship, Verification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, address_kana: nil, address_kanji: nil, dob: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil) ⇒ Individual

Returns a new instance of Individual.



2493
2494
2495
2496
2497
2498
2499
2500
2501
2502
2503
2504
2505
2506
2507
2508
2509
2510
2511
2512
2513
2514
2515
2516
2517
2518
2519
2520
2521
2522
2523
2524
2525
2526
2527
2528
2529
2530
2531
2532
2533
2534
2535
2536
2537
2538
2539
2540
2541
# File 'lib/stripe/resources/account.rb', line 2493

def initialize(
  address: nil,
  address_kana: nil,
  address_kanji: nil,
  dob: nil,
  email: nil,
  first_name: nil,
  first_name_kana: nil,
  first_name_kanji: nil,
  full_name_aliases: nil,
  gender: nil,
  id_number: nil,
  id_number_secondary: nil,
  last_name: nil,
  last_name_kana: nil,
  last_name_kanji: nil,
  maiden_name: nil,
  metadata: nil,
  phone: nil,
  political_exposure: nil,
  registered_address: nil,
  relationship: nil,
  ssn_last_4: nil,
  verification: nil
)
  @address = address
  @address_kana = address_kana
  @address_kanji = address_kanji
  @dob = dob
  @email = email
  @first_name = first_name
  @first_name_kana = first_name_kana
  @first_name_kanji = first_name_kanji
  @full_name_aliases = full_name_aliases
  @gender = gender
  @id_number = id_number
  @id_number_secondary = id_number_secondary
  @last_name = last_name
  @last_name_kana = last_name_kana
  @last_name_kanji = last_name_kanji
  @maiden_name = maiden_name
  @metadata = 
  @phone = phone
  @political_exposure = political_exposure
  @registered_address = registered_address
  @relationship = relationship
  @ssn_last_4 = ssn_last_4
  @verification = verification
end

Instance Attribute Details

#addressObject

The individual’s primary address.



2447
2448
2449
# File 'lib/stripe/resources/account.rb', line 2447

def address
  @address
end

#address_kanaObject

The Kana variation of the individual’s primary address (Japan only).



2449
2450
2451
# File 'lib/stripe/resources/account.rb', line 2449

def address_kana
  @address_kana
end

#address_kanjiObject

The Kanji variation of the individual’s primary address (Japan only).



2451
2452
2453
# File 'lib/stripe/resources/account.rb', line 2451

def address_kanji
  @address_kanji
end

#dobObject

The individual’s date of birth.



2453
2454
2455
# File 'lib/stripe/resources/account.rb', line 2453

def dob
  @dob
end

#emailObject

The individual’s email address.



2455
2456
2457
# File 'lib/stripe/resources/account.rb', line 2455

def email
  @email
end

#first_nameObject

The individual’s first name.



2457
2458
2459
# File 'lib/stripe/resources/account.rb', line 2457

def first_name
  @first_name
end

#first_name_kanaObject

The Kana variation of the individual’s first name (Japan only).



2459
2460
2461
# File 'lib/stripe/resources/account.rb', line 2459

def first_name_kana
  @first_name_kana
end

#first_name_kanjiObject

The Kanji variation of the individual’s first name (Japan only).



2461
2462
2463
# File 'lib/stripe/resources/account.rb', line 2461

def first_name_kanji
  @first_name_kanji
end

#full_name_aliasesObject

A list of alternate names or aliases that the individual is known by.



2463
2464
2465
# File 'lib/stripe/resources/account.rb', line 2463

def full_name_aliases
  @full_name_aliases
end

#genderObject

The individual’s gender



2465
2466
2467
# File 'lib/stripe/resources/account.rb', line 2465

def gender
  @gender
end

#id_numberObject

The government-issued ID number of the individual, as appropriate for the representative’s country. (Examples are a Social Security Number in the U.S., or a Social Insurance Number in Canada). Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).



2467
2468
2469
# File 'lib/stripe/resources/account.rb', line 2467

def id_number
  @id_number
end

#id_number_secondaryObject

The government-issued secondary ID number of the individual, as appropriate for the representative’s country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).



2469
2470
2471
# File 'lib/stripe/resources/account.rb', line 2469

def id_number_secondary
  @id_number_secondary
end

#last_nameObject

The individual’s last name.



2471
2472
2473
# File 'lib/stripe/resources/account.rb', line 2471

def last_name
  @last_name
end

#last_name_kanaObject

The Kana variation of the individual’s last name (Japan only).



2473
2474
2475
# File 'lib/stripe/resources/account.rb', line 2473

def last_name_kana
  @last_name_kana
end

#last_name_kanjiObject

The Kanji variation of the individual’s last name (Japan only).



2475
2476
2477
# File 'lib/stripe/resources/account.rb', line 2475

def last_name_kanji
  @last_name_kanji
end

#maiden_nameObject

The individual’s maiden name.



2477
2478
2479
# File 'lib/stripe/resources/account.rb', line 2477

def maiden_name
  @maiden_name
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2479
2480
2481
# File 'lib/stripe/resources/account.rb', line 2479

def 
  @metadata
end

#phoneObject

The individual’s phone number.



2481
2482
2483
# File 'lib/stripe/resources/account.rb', line 2481

def phone
  @phone
end

#political_exposureObject

Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.



2483
2484
2485
# File 'lib/stripe/resources/account.rb', line 2483

def political_exposure
  @political_exposure
end

#registered_addressObject

The individual’s registered address.



2485
2486
2487
# File 'lib/stripe/resources/account.rb', line 2485

def registered_address
  @registered_address
end

#relationshipObject

Describes the person’s relationship to the account.



2487
2488
2489
# File 'lib/stripe/resources/account.rb', line 2487

def relationship
  @relationship
end

#ssn_last_4Object

The last four digits of the individual’s Social Security Number (U.S. only).



2489
2490
2491
# File 'lib/stripe/resources/account.rb', line 2489

def ssn_last_4
  @ssn_last_4
end

#verificationObject

The individual’s verification document information.



2491
2492
2493
# File 'lib/stripe/resources/account.rb', line 2491

def verification
  @verification
end