Class: Stripe::Account::UpdateParams::Individual
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::UpdateParams::Individual
- Defined in:
- lib/stripe/resources/account.rb
Defined Under Namespace
Classes: Address, AddressKana, AddressKanji, Dob, RegisteredAddress, Relationship, Verification
Instance Attribute Summary collapse
-
#address ⇒ Object
The individual’s primary address.
-
#address_kana ⇒ Object
The Kana variation of the individual’s primary address (Japan only).
-
#address_kanji ⇒ Object
The Kanji variation of the individual’s primary address (Japan only).
-
#dob ⇒ Object
The individual’s date of birth.
-
#email ⇒ Object
The individual’s email address.
-
#first_name ⇒ Object
The individual’s first name.
-
#first_name_kana ⇒ Object
The Kana variation of the individual’s first name (Japan only).
-
#first_name_kanji ⇒ Object
The Kanji variation of the individual’s first name (Japan only).
-
#full_name_aliases ⇒ Object
A list of alternate names or aliases that the individual is known by.
-
#gender ⇒ Object
The individual’s gender.
-
#id_number ⇒ Object
The government-issued ID number of the individual, as appropriate for the representative’s country.
-
#id_number_secondary ⇒ Object
The government-issued secondary ID number of the individual, as appropriate for the representative’s country, will be used for enhanced verification checks.
-
#last_name ⇒ Object
The individual’s last name.
-
#last_name_kana ⇒ Object
The Kana variation of the individual’s last name (Japan only).
-
#last_name_kanji ⇒ Object
The Kanji variation of the individual’s last name (Japan only).
-
#maiden_name ⇒ Object
The individual’s maiden name.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#phone ⇒ Object
The individual’s phone number.
-
#political_exposure ⇒ Object
Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
-
#registered_address ⇒ Object
The individual’s registered address.
-
#relationship ⇒ Object
Describes the person’s relationship to the account.
-
#ssn_last_4 ⇒ Object
The last four digits of the individual’s Social Security Number (U.S. only).
-
#verification ⇒ Object
The individual’s verification document information.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, address_kana: nil, address_kanji: nil, dob: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil) ⇒ Individual
Returns a new instance of Individual.
2449 2450 2451 2452 2453 2454 2455 2456 2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 2468 2469 2470 2471 2472 2473 2474 2475 2476 2477 2478 2479 2480 2481 2482 2483 2484 2485 2486 2487 2488 2489 2490 2491 2492 2493 2494 2495 2496 2497 |
# File 'lib/stripe/resources/account.rb', line 2449 def initialize( address: nil, address_kana: nil, address_kanji: nil, dob: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil ) @address = address @address_kana = address_kana @address_kanji = address_kanji @dob = dob @email = email @first_name = first_name @first_name_kana = first_name_kana @first_name_kanji = first_name_kanji @full_name_aliases = full_name_aliases @gender = gender @id_number = id_number @id_number_secondary = id_number_secondary @last_name = last_name @last_name_kana = last_name_kana @last_name_kanji = last_name_kanji @maiden_name = maiden_name @metadata = @phone = phone @political_exposure = political_exposure @registered_address = registered_address @relationship = relationship @ssn_last_4 = ssn_last_4 @verification = verification end |
Instance Attribute Details
#address ⇒ Object
The individual’s primary address.
2403 2404 2405 |
# File 'lib/stripe/resources/account.rb', line 2403 def address @address end |
#address_kana ⇒ Object
The Kana variation of the individual’s primary address (Japan only).
2405 2406 2407 |
# File 'lib/stripe/resources/account.rb', line 2405 def address_kana @address_kana end |
#address_kanji ⇒ Object
The Kanji variation of the individual’s primary address (Japan only).
2407 2408 2409 |
# File 'lib/stripe/resources/account.rb', line 2407 def address_kanji @address_kanji end |
#dob ⇒ Object
The individual’s date of birth.
2409 2410 2411 |
# File 'lib/stripe/resources/account.rb', line 2409 def dob @dob end |
#email ⇒ Object
The individual’s email address.
2411 2412 2413 |
# File 'lib/stripe/resources/account.rb', line 2411 def email @email end |
#first_name ⇒ Object
The individual’s first name.
2413 2414 2415 |
# File 'lib/stripe/resources/account.rb', line 2413 def first_name @first_name end |
#first_name_kana ⇒ Object
The Kana variation of the individual’s first name (Japan only).
2415 2416 2417 |
# File 'lib/stripe/resources/account.rb', line 2415 def first_name_kana @first_name_kana end |
#first_name_kanji ⇒ Object
The Kanji variation of the individual’s first name (Japan only).
2417 2418 2419 |
# File 'lib/stripe/resources/account.rb', line 2417 def first_name_kanji @first_name_kanji end |
#full_name_aliases ⇒ Object
A list of alternate names or aliases that the individual is known by.
2419 2420 2421 |
# File 'lib/stripe/resources/account.rb', line 2419 def full_name_aliases @full_name_aliases end |
#gender ⇒ Object
The individual’s gender
2421 2422 2423 |
# File 'lib/stripe/resources/account.rb', line 2421 def gender @gender end |
#id_number ⇒ Object
The government-issued ID number of the individual, as appropriate for the representative’s country. (Examples are a Social Security Number in the U.S., or a Social Insurance Number in Canada). Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).
2423 2424 2425 |
# File 'lib/stripe/resources/account.rb', line 2423 def id_number @id_number end |
#id_number_secondary ⇒ Object
The government-issued secondary ID number of the individual, as appropriate for the representative’s country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).
2425 2426 2427 |
# File 'lib/stripe/resources/account.rb', line 2425 def id_number_secondary @id_number_secondary end |
#last_name ⇒ Object
The individual’s last name.
2427 2428 2429 |
# File 'lib/stripe/resources/account.rb', line 2427 def last_name @last_name end |
#last_name_kana ⇒ Object
The Kana variation of the individual’s last name (Japan only).
2429 2430 2431 |
# File 'lib/stripe/resources/account.rb', line 2429 def last_name_kana @last_name_kana end |
#last_name_kanji ⇒ Object
The Kanji variation of the individual’s last name (Japan only).
2431 2432 2433 |
# File 'lib/stripe/resources/account.rb', line 2431 def last_name_kanji @last_name_kanji end |
#maiden_name ⇒ Object
The individual’s maiden name.
2433 2434 2435 |
# File 'lib/stripe/resources/account.rb', line 2433 def maiden_name @maiden_name end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
2435 2436 2437 |
# File 'lib/stripe/resources/account.rb', line 2435 def @metadata end |
#phone ⇒ Object
The individual’s phone number.
2437 2438 2439 |
# File 'lib/stripe/resources/account.rb', line 2437 def phone @phone end |
#political_exposure ⇒ Object
Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
2439 2440 2441 |
# File 'lib/stripe/resources/account.rb', line 2439 def political_exposure @political_exposure end |
#registered_address ⇒ Object
The individual’s registered address.
2441 2442 2443 |
# File 'lib/stripe/resources/account.rb', line 2441 def registered_address @registered_address end |
#relationship ⇒ Object
Describes the person’s relationship to the account.
2443 2444 2445 |
# File 'lib/stripe/resources/account.rb', line 2443 def relationship @relationship end |
#ssn_last_4 ⇒ Object
The last four digits of the individual’s Social Security Number (U.S. only).
2445 2446 2447 |
# File 'lib/stripe/resources/account.rb', line 2445 def ssn_last_4 @ssn_last_4 end |
#verification ⇒ Object
The individual’s verification document information.
2447 2448 2449 |
# File 'lib/stripe/resources/account.rb', line 2447 def verification @verification end |