Class: Stripe::Account::UpdateParams::Individual

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: Address, AddressKana, AddressKanji, Dob, RegisteredAddress, Relationship, Verification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, address_kana: nil, address_kanji: nil, dob: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil) ⇒ Individual

Returns a new instance of Individual.



2390
2391
2392
2393
2394
2395
2396
2397
2398
2399
2400
2401
2402
2403
2404
2405
2406
2407
2408
2409
2410
2411
2412
2413
2414
2415
2416
2417
2418
2419
2420
2421
2422
2423
2424
2425
2426
2427
2428
2429
2430
2431
2432
2433
2434
2435
2436
2437
2438
# File 'lib/stripe/resources/account.rb', line 2390

def initialize(
  address: nil,
  address_kana: nil,
  address_kanji: nil,
  dob: nil,
  email: nil,
  first_name: nil,
  first_name_kana: nil,
  first_name_kanji: nil,
  full_name_aliases: nil,
  gender: nil,
  id_number: nil,
  id_number_secondary: nil,
  last_name: nil,
  last_name_kana: nil,
  last_name_kanji: nil,
  maiden_name: nil,
  metadata: nil,
  phone: nil,
  political_exposure: nil,
  registered_address: nil,
  relationship: nil,
  ssn_last_4: nil,
  verification: nil
)
  @address = address
  @address_kana = address_kana
  @address_kanji = address_kanji
  @dob = dob
  @email = email
  @first_name = first_name
  @first_name_kana = first_name_kana
  @first_name_kanji = first_name_kanji
  @full_name_aliases = full_name_aliases
  @gender = gender
  @id_number = id_number
  @id_number_secondary = id_number_secondary
  @last_name = last_name
  @last_name_kana = last_name_kana
  @last_name_kanji = last_name_kanji
  @maiden_name = maiden_name
  @metadata = 
  @phone = phone
  @political_exposure = political_exposure
  @registered_address = registered_address
  @relationship = relationship
  @ssn_last_4 = ssn_last_4
  @verification = verification
end

Instance Attribute Details

#addressObject

The individual’s primary address.



2344
2345
2346
# File 'lib/stripe/resources/account.rb', line 2344

def address
  @address
end

#address_kanaObject

The Kana variation of the individual’s primary address (Japan only).



2346
2347
2348
# File 'lib/stripe/resources/account.rb', line 2346

def address_kana
  @address_kana
end

#address_kanjiObject

The Kanji variation of the individual’s primary address (Japan only).



2348
2349
2350
# File 'lib/stripe/resources/account.rb', line 2348

def address_kanji
  @address_kanji
end

#dobObject

The individual’s date of birth.



2350
2351
2352
# File 'lib/stripe/resources/account.rb', line 2350

def dob
  @dob
end

#emailObject

The individual’s email address.



2352
2353
2354
# File 'lib/stripe/resources/account.rb', line 2352

def email
  @email
end

#first_nameObject

The individual’s first name.



2354
2355
2356
# File 'lib/stripe/resources/account.rb', line 2354

def first_name
  @first_name
end

#first_name_kanaObject

The Kana variation of the individual’s first name (Japan only).



2356
2357
2358
# File 'lib/stripe/resources/account.rb', line 2356

def first_name_kana
  @first_name_kana
end

#first_name_kanjiObject

The Kanji variation of the individual’s first name (Japan only).



2358
2359
2360
# File 'lib/stripe/resources/account.rb', line 2358

def first_name_kanji
  @first_name_kanji
end

#full_name_aliasesObject

A list of alternate names or aliases that the individual is known by.



2360
2361
2362
# File 'lib/stripe/resources/account.rb', line 2360

def full_name_aliases
  @full_name_aliases
end

#genderObject

The individual’s gender



2362
2363
2364
# File 'lib/stripe/resources/account.rb', line 2362

def gender
  @gender
end

#id_numberObject

The government-issued ID number of the individual, as appropriate for the representative’s country. (Examples are a Social Security Number in the U.S., or a Social Insurance Number in Canada). Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).



2364
2365
2366
# File 'lib/stripe/resources/account.rb', line 2364

def id_number
  @id_number
end

#id_number_secondaryObject

The government-issued secondary ID number of the individual, as appropriate for the representative’s country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).



2366
2367
2368
# File 'lib/stripe/resources/account.rb', line 2366

def id_number_secondary
  @id_number_secondary
end

#last_nameObject

The individual’s last name.



2368
2369
2370
# File 'lib/stripe/resources/account.rb', line 2368

def last_name
  @last_name
end

#last_name_kanaObject

The Kana variation of the individual’s last name (Japan only).



2370
2371
2372
# File 'lib/stripe/resources/account.rb', line 2370

def last_name_kana
  @last_name_kana
end

#last_name_kanjiObject

The Kanji variation of the individual’s last name (Japan only).



2372
2373
2374
# File 'lib/stripe/resources/account.rb', line 2372

def last_name_kanji
  @last_name_kanji
end

#maiden_nameObject

The individual’s maiden name.



2374
2375
2376
# File 'lib/stripe/resources/account.rb', line 2374

def maiden_name
  @maiden_name
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2376
2377
2378
# File 'lib/stripe/resources/account.rb', line 2376

def 
  @metadata
end

#phoneObject

The individual’s phone number.



2378
2379
2380
# File 'lib/stripe/resources/account.rb', line 2378

def phone
  @phone
end

#political_exposureObject

Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.



2380
2381
2382
# File 'lib/stripe/resources/account.rb', line 2380

def political_exposure
  @political_exposure
end

#registered_addressObject

The individual’s registered address.



2382
2383
2384
# File 'lib/stripe/resources/account.rb', line 2382

def registered_address
  @registered_address
end

#relationshipObject

Describes the person’s relationship to the account.



2384
2385
2386
# File 'lib/stripe/resources/account.rb', line 2384

def relationship
  @relationship
end

#ssn_last_4Object

The last four digits of the individual’s Social Security Number (U.S. only).



2386
2387
2388
# File 'lib/stripe/resources/account.rb', line 2386

def ssn_last_4
  @ssn_last_4
end

#verificationObject

The individual’s verification document information.



2388
2389
2390
# File 'lib/stripe/resources/account.rb', line 2388

def verification
  @verification
end