Class: Stripe::Account::UpdateParams::Individual

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: Address, AddressKana, AddressKanji, Dob, RegisteredAddress, Relationship, Verification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, address_kana: nil, address_kanji: nil, dob: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil) ⇒ Individual

Returns a new instance of Individual.



2341
2342
2343
2344
2345
2346
2347
2348
2349
2350
2351
2352
2353
2354
2355
2356
2357
2358
2359
2360
2361
2362
2363
2364
2365
2366
2367
2368
2369
2370
2371
2372
2373
2374
2375
2376
2377
2378
2379
2380
2381
2382
2383
2384
2385
2386
2387
2388
2389
# File 'lib/stripe/resources/account.rb', line 2341

def initialize(
  address: nil,
  address_kana: nil,
  address_kanji: nil,
  dob: nil,
  email: nil,
  first_name: nil,
  first_name_kana: nil,
  first_name_kanji: nil,
  full_name_aliases: nil,
  gender: nil,
  id_number: nil,
  id_number_secondary: nil,
  last_name: nil,
  last_name_kana: nil,
  last_name_kanji: nil,
  maiden_name: nil,
  metadata: nil,
  phone: nil,
  political_exposure: nil,
  registered_address: nil,
  relationship: nil,
  ssn_last_4: nil,
  verification: nil
)
  @address = address
  @address_kana = address_kana
  @address_kanji = address_kanji
  @dob = dob
  @email = email
  @first_name = first_name
  @first_name_kana = first_name_kana
  @first_name_kanji = first_name_kanji
  @full_name_aliases = full_name_aliases
  @gender = gender
  @id_number = id_number
  @id_number_secondary = id_number_secondary
  @last_name = last_name
  @last_name_kana = last_name_kana
  @last_name_kanji = last_name_kanji
  @maiden_name = maiden_name
  @metadata = 
  @phone = phone
  @political_exposure = political_exposure
  @registered_address = registered_address
  @relationship = relationship
  @ssn_last_4 = ssn_last_4
  @verification = verification
end

Instance Attribute Details

#addressObject

The individual’s primary address.



2295
2296
2297
# File 'lib/stripe/resources/account.rb', line 2295

def address
  @address
end

#address_kanaObject

The Kana variation of the individual’s primary address (Japan only).



2297
2298
2299
# File 'lib/stripe/resources/account.rb', line 2297

def address_kana
  @address_kana
end

#address_kanjiObject

The Kanji variation of the individual’s primary address (Japan only).



2299
2300
2301
# File 'lib/stripe/resources/account.rb', line 2299

def address_kanji
  @address_kanji
end

#dobObject

The individual’s date of birth.



2301
2302
2303
# File 'lib/stripe/resources/account.rb', line 2301

def dob
  @dob
end

#emailObject

The individual’s email address.



2303
2304
2305
# File 'lib/stripe/resources/account.rb', line 2303

def email
  @email
end

#first_nameObject

The individual’s first name.



2305
2306
2307
# File 'lib/stripe/resources/account.rb', line 2305

def first_name
  @first_name
end

#first_name_kanaObject

The Kana variation of the individual’s first name (Japan only).



2307
2308
2309
# File 'lib/stripe/resources/account.rb', line 2307

def first_name_kana
  @first_name_kana
end

#first_name_kanjiObject

The Kanji variation of the individual’s first name (Japan only).



2309
2310
2311
# File 'lib/stripe/resources/account.rb', line 2309

def first_name_kanji
  @first_name_kanji
end

#full_name_aliasesObject

A list of alternate names or aliases that the individual is known by.



2311
2312
2313
# File 'lib/stripe/resources/account.rb', line 2311

def full_name_aliases
  @full_name_aliases
end

#genderObject

The individual’s gender



2313
2314
2315
# File 'lib/stripe/resources/account.rb', line 2313

def gender
  @gender
end

#id_numberObject

The government-issued ID number of the individual, as appropriate for the representative’s country. (Examples are a Social Security Number in the U.S., or a Social Insurance Number in Canada). Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).



2315
2316
2317
# File 'lib/stripe/resources/account.rb', line 2315

def id_number
  @id_number
end

#id_number_secondaryObject

The government-issued secondary ID number of the individual, as appropriate for the representative’s country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).



2317
2318
2319
# File 'lib/stripe/resources/account.rb', line 2317

def id_number_secondary
  @id_number_secondary
end

#last_nameObject

The individual’s last name.



2319
2320
2321
# File 'lib/stripe/resources/account.rb', line 2319

def last_name
  @last_name
end

#last_name_kanaObject

The Kana variation of the individual’s last name (Japan only).



2321
2322
2323
# File 'lib/stripe/resources/account.rb', line 2321

def last_name_kana
  @last_name_kana
end

#last_name_kanjiObject

The Kanji variation of the individual’s last name (Japan only).



2323
2324
2325
# File 'lib/stripe/resources/account.rb', line 2323

def last_name_kanji
  @last_name_kanji
end

#maiden_nameObject

The individual’s maiden name.



2325
2326
2327
# File 'lib/stripe/resources/account.rb', line 2325

def maiden_name
  @maiden_name
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2327
2328
2329
# File 'lib/stripe/resources/account.rb', line 2327

def 
  @metadata
end

#phoneObject

The individual’s phone number.



2329
2330
2331
# File 'lib/stripe/resources/account.rb', line 2329

def phone
  @phone
end

#political_exposureObject

Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.



2331
2332
2333
# File 'lib/stripe/resources/account.rb', line 2331

def political_exposure
  @political_exposure
end

#registered_addressObject

The individual’s registered address.



2333
2334
2335
# File 'lib/stripe/resources/account.rb', line 2333

def registered_address
  @registered_address
end

#relationshipObject

Describes the person’s relationship to the account.



2335
2336
2337
# File 'lib/stripe/resources/account.rb', line 2335

def relationship
  @relationship
end

#ssn_last_4Object

The last four digits of the individual’s Social Security Number (U.S. only).



2337
2338
2339
# File 'lib/stripe/resources/account.rb', line 2337

def ssn_last_4
  @ssn_last_4
end

#verificationObject

The individual’s verification document information.



2339
2340
2341
# File 'lib/stripe/resources/account.rb', line 2339

def verification
  @verification
end