Class: Stripe::Account::UpdateParams::Individual

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: Address, AddressKana, AddressKanji, Dob, RegisteredAddress, Relationship, Verification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, address_kana: nil, address_kanji: nil, dob: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil) ⇒ Individual

Returns a new instance of Individual.



2717
2718
2719
2720
2721
2722
2723
2724
2725
2726
2727
2728
2729
2730
2731
2732
2733
2734
2735
2736
2737
2738
2739
2740
2741
2742
2743
2744
2745
2746
2747
2748
2749
2750
2751
2752
2753
2754
2755
2756
2757
2758
2759
2760
2761
2762
2763
2764
2765
# File 'lib/stripe/resources/account.rb', line 2717

def initialize(
  address: nil,
  address_kana: nil,
  address_kanji: nil,
  dob: nil,
  email: nil,
  first_name: nil,
  first_name_kana: nil,
  first_name_kanji: nil,
  full_name_aliases: nil,
  gender: nil,
  id_number: nil,
  id_number_secondary: nil,
  last_name: nil,
  last_name_kana: nil,
  last_name_kanji: nil,
  maiden_name: nil,
  metadata: nil,
  phone: nil,
  political_exposure: nil,
  registered_address: nil,
  relationship: nil,
  ssn_last_4: nil,
  verification: nil
)
  @address = address
  @address_kana = address_kana
  @address_kanji = address_kanji
  @dob = dob
  @email = email
  @first_name = first_name
  @first_name_kana = first_name_kana
  @first_name_kanji = first_name_kanji
  @full_name_aliases = full_name_aliases
  @gender = gender
  @id_number = id_number
  @id_number_secondary = id_number_secondary
  @last_name = last_name
  @last_name_kana = last_name_kana
  @last_name_kanji = last_name_kanji
  @maiden_name = maiden_name
  @metadata = 
  @phone = phone
  @political_exposure = political_exposure
  @registered_address = registered_address
  @relationship = relationship
  @ssn_last_4 = ssn_last_4
  @verification = verification
end

Instance Attribute Details

#addressObject

The individual’s primary address.



2649
2650
2651
# File 'lib/stripe/resources/account.rb', line 2649

def address
  @address
end

#address_kanaObject

The Kana variation of the individual’s primary address (Japan only).



2652
2653
2654
# File 'lib/stripe/resources/account.rb', line 2652

def address_kana
  @address_kana
end

#address_kanjiObject

The Kanji variation of the individual’s primary address (Japan only).



2655
2656
2657
# File 'lib/stripe/resources/account.rb', line 2655

def address_kanji
  @address_kanji
end

#dobObject

The individual’s date of birth.



2658
2659
2660
# File 'lib/stripe/resources/account.rb', line 2658

def dob
  @dob
end

#emailObject

The individual’s email address.



2661
2662
2663
# File 'lib/stripe/resources/account.rb', line 2661

def email
  @email
end

#first_nameObject

The individual’s first name.



2664
2665
2666
# File 'lib/stripe/resources/account.rb', line 2664

def first_name
  @first_name
end

#first_name_kanaObject

The Kana variation of the individual’s first name (Japan only).



2667
2668
2669
# File 'lib/stripe/resources/account.rb', line 2667

def first_name_kana
  @first_name_kana
end

#first_name_kanjiObject

The Kanji variation of the individual’s first name (Japan only).



2670
2671
2672
# File 'lib/stripe/resources/account.rb', line 2670

def first_name_kanji
  @first_name_kanji
end

#full_name_aliasesObject

A list of alternate names or aliases that the individual is known by.



2673
2674
2675
# File 'lib/stripe/resources/account.rb', line 2673

def full_name_aliases
  @full_name_aliases
end

#genderObject

The individual’s gender



2676
2677
2678
# File 'lib/stripe/resources/account.rb', line 2676

def gender
  @gender
end

#id_numberObject

The government-issued ID number of the individual, as appropriate for the representative’s country. (Examples are a Social Security Number in the U.S., or a Social Insurance Number in Canada). Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).



2679
2680
2681
# File 'lib/stripe/resources/account.rb', line 2679

def id_number
  @id_number
end

#id_number_secondaryObject

The government-issued secondary ID number of the individual, as appropriate for the representative’s country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).



2682
2683
2684
# File 'lib/stripe/resources/account.rb', line 2682

def id_number_secondary
  @id_number_secondary
end

#last_nameObject

The individual’s last name.



2685
2686
2687
# File 'lib/stripe/resources/account.rb', line 2685

def last_name
  @last_name
end

#last_name_kanaObject

The Kana variation of the individual’s last name (Japan only).



2688
2689
2690
# File 'lib/stripe/resources/account.rb', line 2688

def last_name_kana
  @last_name_kana
end

#last_name_kanjiObject

The Kanji variation of the individual’s last name (Japan only).



2691
2692
2693
# File 'lib/stripe/resources/account.rb', line 2691

def last_name_kanji
  @last_name_kanji
end

#maiden_nameObject

The individual’s maiden name.



2694
2695
2696
# File 'lib/stripe/resources/account.rb', line 2694

def maiden_name
  @maiden_name
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2697
2698
2699
# File 'lib/stripe/resources/account.rb', line 2697

def 
  @metadata
end

#phoneObject

The individual’s phone number.



2700
2701
2702
# File 'lib/stripe/resources/account.rb', line 2700

def phone
  @phone
end

#political_exposureObject

Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.



2703
2704
2705
# File 'lib/stripe/resources/account.rb', line 2703

def political_exposure
  @political_exposure
end

#registered_addressObject

The individual’s registered address.



2706
2707
2708
# File 'lib/stripe/resources/account.rb', line 2706

def registered_address
  @registered_address
end

#relationshipObject

Describes the person’s relationship to the account.



2709
2710
2711
# File 'lib/stripe/resources/account.rb', line 2709

def relationship
  @relationship
end

#ssn_last_4Object

The last four digits of the individual’s Social Security Number (U.S. only).



2712
2713
2714
# File 'lib/stripe/resources/account.rb', line 2712

def ssn_last_4
  @ssn_last_4
end

#verificationObject

The individual’s verification document information.



2715
2716
2717
# File 'lib/stripe/resources/account.rb', line 2715

def verification
  @verification
end