Class: Stripe::Account::UpdateParams::Individual::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship

Returns a new instance of Relationship.



2126
2127
2128
2129
2130
2131
2132
2133
2134
2135
2136
2137
2138
# File 'lib/stripe/resources/account.rb', line 2126

def initialize(
  director: nil,
  executive: nil,
  owner: nil,
  percent_ownership: nil,
  title: nil
)
  @director = director
  @executive = executive
  @owner = owner
  @percent_ownership = percent_ownership
  @title = title
end

Instance Attribute Details

#directorObject

Whether the person is a director of the account’s legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



2116
2117
2118
# File 'lib/stripe/resources/account.rb', line 2116

def director
  @director
end

#executiveObject

Whether the person has significant responsibility to control, manage, or direct the organization.



2118
2119
2120
# File 'lib/stripe/resources/account.rb', line 2118

def executive
  @executive
end

#ownerObject

Whether the person is an owner of the account’s legal entity.



2120
2121
2122
# File 'lib/stripe/resources/account.rb', line 2120

def owner
  @owner
end

#percent_ownershipObject

The percent owned by the person of the account’s legal entity.



2122
2123
2124
# File 'lib/stripe/resources/account.rb', line 2122

def percent_ownership
  @percent_ownership
end

#titleObject

The person’s title (e.g., CEO, Support Engineer).



2124
2125
2126
# File 'lib/stripe/resources/account.rb', line 2124

def title
  @title
end