Class: Stripe::Account::UpdateParams::Individual::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship

Returns a new instance of Relationship.



2347
2348
2349
2350
2351
2352
2353
2354
2355
2356
2357
2358
2359
# File 'lib/stripe/resources/account.rb', line 2347

def initialize(
  director: nil,
  executive: nil,
  owner: nil,
  percent_ownership: nil,
  title: nil
)
  @director = director
  @executive = executive
  @owner = owner
  @percent_ownership = percent_ownership
  @title = title
end

Instance Attribute Details

#directorObject

Whether the person is a director of the account’s legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



2337
2338
2339
# File 'lib/stripe/resources/account.rb', line 2337

def director
  @director
end

#executiveObject

Whether the person has significant responsibility to control, manage, or direct the organization.



2339
2340
2341
# File 'lib/stripe/resources/account.rb', line 2339

def executive
  @executive
end

#ownerObject

Whether the person is an owner of the account’s legal entity.



2341
2342
2343
# File 'lib/stripe/resources/account.rb', line 2341

def owner
  @owner
end

#percent_ownershipObject

The percent owned by the person of the account’s legal entity.



2343
2344
2345
# File 'lib/stripe/resources/account.rb', line 2343

def percent_ownership
  @percent_ownership
end

#titleObject

The person’s title (e.g., CEO, Support Engineer).



2345
2346
2347
# File 'lib/stripe/resources/account.rb', line 2345

def title
  @title
end