Class: Stripe::Account::UpdateParams::Individual::Relationship
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::UpdateParams::Individual::Relationship
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#director ⇒ Object
Whether the person is a director of the account’s legal entity.
-
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
-
#owner ⇒ Object
Whether the person is an owner of the account’s legal entity.
-
#percent_ownership ⇒ Object
The percent owned by the person of the account’s legal entity.
-
#title ⇒ Object
The person’s title (e.g., CEO, Support Engineer).
Instance Method Summary collapse
-
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
constructor
A new instance of Relationship.
Methods inherited from RequestParams
Constructor Details
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
Returns a new instance of Relationship.
2294 2295 2296 2297 2298 2299 2300 2301 2302 2303 2304 2305 2306 |
# File 'lib/stripe/resources/account.rb', line 2294 def initialize( director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil ) @director = director @executive = executive @owner = owner @percent_ownership = percent_ownership @title = title end |
Instance Attribute Details
#director ⇒ Object
Whether the person is a director of the account’s legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.
2284 2285 2286 |
# File 'lib/stripe/resources/account.rb', line 2284 def director @director end |
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
2286 2287 2288 |
# File 'lib/stripe/resources/account.rb', line 2286 def executive @executive end |
#owner ⇒ Object
Whether the person is an owner of the account’s legal entity.
2288 2289 2290 |
# File 'lib/stripe/resources/account.rb', line 2288 def owner @owner end |
#percent_ownership ⇒ Object
The percent owned by the person of the account’s legal entity.
2290 2291 2292 |
# File 'lib/stripe/resources/account.rb', line 2290 def percent_ownership @percent_ownership end |
#title ⇒ Object
The person’s title (e.g., CEO, Support Engineer).
2292 2293 2294 |
# File 'lib/stripe/resources/account.rb', line 2292 def title @title end |