Class: Stripe::Account::UpdateParams::Individual::Relationship
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::UpdateParams::Individual::Relationship
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#director ⇒ Object
Whether the person is a director of the account’s legal entity.
-
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
-
#owner ⇒ Object
Whether the person is an owner of the account’s legal entity.
-
#percent_ownership ⇒ Object
The percent owned by the person of the account’s legal entity.
-
#title ⇒ Object
The person’s title (e.g., CEO, Support Engineer).
Instance Method Summary collapse
-
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
constructor
A new instance of Relationship.
Methods inherited from RequestParams
Constructor Details
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
Returns a new instance of Relationship.
2596 2597 2598 2599 2600 2601 2602 2603 2604 2605 2606 2607 2608 |
# File 'lib/stripe/resources/account.rb', line 2596 def initialize( director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil ) @director = director @executive = executive @owner = owner @percent_ownership = percent_ownership @title = title end |
Instance Attribute Details
#director ⇒ Object
Whether the person is a director of the account’s legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.
2582 2583 2584 |
# File 'lib/stripe/resources/account.rb', line 2582 def director @director end |
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
2585 2586 2587 |
# File 'lib/stripe/resources/account.rb', line 2585 def executive @executive end |
#owner ⇒ Object
Whether the person is an owner of the account’s legal entity.
2588 2589 2590 |
# File 'lib/stripe/resources/account.rb', line 2588 def owner @owner end |
#percent_ownership ⇒ Object
The percent owned by the person of the account’s legal entity.
2591 2592 2593 |
# File 'lib/stripe/resources/account.rb', line 2591 def percent_ownership @percent_ownership end |
#title ⇒ Object
The person’s title (e.g., CEO, Support Engineer).
2594 2595 2596 |
# File 'lib/stripe/resources/account.rb', line 2594 def title @title end |