Class: Stripe::Account::UpdateParams::Individual::Verification::AdditionalDocument
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::UpdateParams::Individual::Verification::AdditionalDocument
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#back ⇒ Object
The back of an ID returned by a [file upload](stripe.com/docs/api#create_file) with a ‘purpose` value of `identity_document`.
-
#front ⇒ Object
The front of an ID returned by a [file upload](stripe.com/docs/api#create_file) with a ‘purpose` value of `identity_document`.
Instance Method Summary collapse
-
#initialize(back: nil, front: nil) ⇒ AdditionalDocument
constructor
A new instance of AdditionalDocument.
Methods inherited from RequestParams
Constructor Details
#initialize(back: nil, front: nil) ⇒ AdditionalDocument
Returns a new instance of AdditionalDocument.
2314 2315 2316 2317 |
# File 'lib/stripe/resources/account.rb', line 2314 def initialize(back: nil, front: nil) @back = back @front = front end |
Instance Attribute Details
#back ⇒ Object
The back of an ID returned by a [file upload](stripe.com/docs/api#create_file) with a ‘purpose` value of `identity_document`. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.
2310 2311 2312 |
# File 'lib/stripe/resources/account.rb', line 2310 def back @back end |
#front ⇒ Object
The front of an ID returned by a [file upload](stripe.com/docs/api#create_file) with a ‘purpose` value of `identity_document`. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.
2312 2313 2314 |
# File 'lib/stripe/resources/account.rb', line 2312 def front @front end |