Class: Stripe::Account::UpdateParams::Settings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::UpdateParams::Settings
- Defined in:
- lib/stripe/resources/account.rb
Defined Under Namespace
Classes: BacsDebitPayments, BankBcaOnboarding, Branding, Capital, CardIssuing, CardPayments, Invoices, Payments, Payouts, TaxForms, Treasury
Instance Attribute Summary collapse
-
#bacs_debit_payments ⇒ Object
Settings specific to Bacs Direct Debit payments.
-
#bank_bca_onboarding ⇒ Object
Settings specific to bank BCA onboarding for Indonesia bank transfers payments method.
-
#branding ⇒ Object
Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.
-
#capital ⇒ Object
Settings specific to the account’s use of the Capital product.
-
#card_issuing ⇒ Object
Settings specific to the account’s use of the Card Issuing product.
-
#card_payments ⇒ Object
Settings specific to card charging on the account.
-
#invoices ⇒ Object
Settings specific to the account’s use of Invoices.
-
#payments ⇒ Object
Settings that apply across payment methods for charging on the account.
-
#payouts ⇒ Object
Settings specific to the account’s payouts.
-
#tax_forms ⇒ Object
Settings specific to the account’s tax forms.
-
#treasury ⇒ Object
Settings specific to the account’s Treasury FinancialAccounts.
Instance Method Summary collapse
-
#initialize(bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, tax_forms: nil, treasury: nil) ⇒ Settings
constructor
A new instance of Settings.
Methods inherited from RequestParams
Constructor Details
#initialize(bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, tax_forms: nil, treasury: nil) ⇒ Settings
Returns a new instance of Settings.
3270 3271 3272 3273 3274 3275 3276 3277 3278 3279 3280 3281 3282 3283 3284 3285 3286 3287 3288 3289 3290 3291 3292 3293 3294 |
# File 'lib/stripe/resources/account.rb', line 3270 def initialize( bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, tax_forms: nil, treasury: nil ) @bacs_debit_payments = bacs_debit_payments @bank_bca_onboarding = bank_bca_onboarding @branding = branding @capital = capital @card_issuing = card_issuing @card_payments = card_payments @invoices = invoices @payments = payments @payouts = payouts @tax_forms = tax_forms @treasury = treasury end |
Instance Attribute Details
#bacs_debit_payments ⇒ Object
Settings specific to Bacs Direct Debit payments.
3248 3249 3250 |
# File 'lib/stripe/resources/account.rb', line 3248 def bacs_debit_payments @bacs_debit_payments end |
#bank_bca_onboarding ⇒ Object
Settings specific to bank BCA onboarding for Indonesia bank transfers payments method.
3250 3251 3252 |
# File 'lib/stripe/resources/account.rb', line 3250 def bank_bca_onboarding @bank_bca_onboarding end |
#branding ⇒ Object
Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.
3252 3253 3254 |
# File 'lib/stripe/resources/account.rb', line 3252 def branding @branding end |
#capital ⇒ Object
Settings specific to the account’s use of the Capital product.
3254 3255 3256 |
# File 'lib/stripe/resources/account.rb', line 3254 def capital @capital end |
#card_issuing ⇒ Object
Settings specific to the account’s use of the Card Issuing product.
3256 3257 3258 |
# File 'lib/stripe/resources/account.rb', line 3256 def card_issuing @card_issuing end |
#card_payments ⇒ Object
Settings specific to card charging on the account.
3258 3259 3260 |
# File 'lib/stripe/resources/account.rb', line 3258 def card_payments @card_payments end |
#invoices ⇒ Object
Settings specific to the account’s use of Invoices.
3260 3261 3262 |
# File 'lib/stripe/resources/account.rb', line 3260 def invoices @invoices end |
#payments ⇒ Object
Settings that apply across payment methods for charging on the account.
3262 3263 3264 |
# File 'lib/stripe/resources/account.rb', line 3262 def payments @payments end |
#payouts ⇒ Object
Settings specific to the account’s payouts.
3264 3265 3266 |
# File 'lib/stripe/resources/account.rb', line 3264 def payouts @payouts end |
#tax_forms ⇒ Object
Settings specific to the account’s tax forms.
3266 3267 3268 |
# File 'lib/stripe/resources/account.rb', line 3266 def tax_forms @tax_forms end |
#treasury ⇒ Object
Settings specific to the account’s Treasury FinancialAccounts.
3268 3269 3270 |
# File 'lib/stripe/resources/account.rb', line 3268 def treasury @treasury end |