Class: Stripe::Account::UpdateParams::Settings

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: BacsDebitPayments, BankBcaOnboarding, Branding, Capital, CardIssuing, CardPayments, Invoices, Payments, Payouts, TaxForms, Treasury

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, tax_forms: nil, treasury: nil) ⇒ Settings

Returns a new instance of Settings.



2846
2847
2848
2849
2850
2851
2852
2853
2854
2855
2856
2857
2858
2859
2860
2861
2862
2863
2864
2865
2866
2867
2868
2869
2870
# File 'lib/stripe/resources/account.rb', line 2846

def initialize(
  bacs_debit_payments: nil,
  bank_bca_onboarding: nil,
  branding: nil,
  capital: nil,
  card_issuing: nil,
  card_payments: nil,
  invoices: nil,
  payments: nil,
  payouts: nil,
  tax_forms: nil,
  treasury: nil
)
  @bacs_debit_payments = bacs_debit_payments
  @bank_bca_onboarding = bank_bca_onboarding
  @branding = branding
  @capital = capital
  @card_issuing = card_issuing
  @card_payments = card_payments
  @invoices = invoices
  @payments = payments
  @payouts = payouts
  @tax_forms = tax_forms
  @treasury = treasury
end

Instance Attribute Details

#bacs_debit_paymentsObject

Settings specific to Bacs Direct Debit payments.



2824
2825
2826
# File 'lib/stripe/resources/account.rb', line 2824

def bacs_debit_payments
  @bacs_debit_payments
end

#bank_bca_onboardingObject

Settings specific to bank BCA onboarding for Indonesia bank transfers payments method.



2826
2827
2828
# File 'lib/stripe/resources/account.rb', line 2826

def bank_bca_onboarding
  @bank_bca_onboarding
end

#brandingObject

Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.



2828
2829
2830
# File 'lib/stripe/resources/account.rb', line 2828

def branding
  @branding
end

#capitalObject

Settings specific to the account’s use of the Capital product.



2830
2831
2832
# File 'lib/stripe/resources/account.rb', line 2830

def capital
  @capital
end

#card_issuingObject

Settings specific to the account’s use of the Card Issuing product.



2832
2833
2834
# File 'lib/stripe/resources/account.rb', line 2832

def card_issuing
  @card_issuing
end

#card_paymentsObject

Settings specific to card charging on the account.



2834
2835
2836
# File 'lib/stripe/resources/account.rb', line 2834

def card_payments
  @card_payments
end

#invoicesObject

Settings specific to the account’s use of Invoices.



2836
2837
2838
# File 'lib/stripe/resources/account.rb', line 2836

def invoices
  @invoices
end

#paymentsObject

Settings that apply across payment methods for charging on the account.



2838
2839
2840
# File 'lib/stripe/resources/account.rb', line 2838

def payments
  @payments
end

#payoutsObject

Settings specific to the account’s payouts.



2840
2841
2842
# File 'lib/stripe/resources/account.rb', line 2840

def payouts
  @payouts
end

#tax_formsObject

Settings specific to the account’s tax forms.



2842
2843
2844
# File 'lib/stripe/resources/account.rb', line 2842

def tax_forms
  @tax_forms
end

#treasuryObject

Settings specific to the account’s Treasury FinancialAccounts.



2844
2845
2846
# File 'lib/stripe/resources/account.rb', line 2844

def treasury
  @treasury
end