Class: Stripe::Account::UpdateParams::Settings

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: BacsDebitPayments, BankBcaOnboarding, Branding, Capital, CardIssuing, CardPayments, Invoices, Payments, Payouts, TaxForms, Treasury

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, tax_forms: nil, treasury: nil) ⇒ Settings

Returns a new instance of Settings.



2787
2788
2789
2790
2791
2792
2793
2794
2795
2796
2797
2798
2799
2800
2801
2802
2803
2804
2805
2806
2807
2808
2809
2810
2811
# File 'lib/stripe/resources/account.rb', line 2787

def initialize(
  bacs_debit_payments: nil,
  bank_bca_onboarding: nil,
  branding: nil,
  capital: nil,
  card_issuing: nil,
  card_payments: nil,
  invoices: nil,
  payments: nil,
  payouts: nil,
  tax_forms: nil,
  treasury: nil
)
  @bacs_debit_payments = bacs_debit_payments
  @bank_bca_onboarding = bank_bca_onboarding
  @branding = branding
  @capital = capital
  @card_issuing = card_issuing
  @card_payments = card_payments
  @invoices = invoices
  @payments = payments
  @payouts = payouts
  @tax_forms = tax_forms
  @treasury = treasury
end

Instance Attribute Details

#bacs_debit_paymentsObject

Settings specific to Bacs Direct Debit payments.



2765
2766
2767
# File 'lib/stripe/resources/account.rb', line 2765

def bacs_debit_payments
  @bacs_debit_payments
end

#bank_bca_onboardingObject

Settings specific to bank BCA onboarding for Indonesia bank transfers payments method.



2767
2768
2769
# File 'lib/stripe/resources/account.rb', line 2767

def bank_bca_onboarding
  @bank_bca_onboarding
end

#brandingObject

Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.



2769
2770
2771
# File 'lib/stripe/resources/account.rb', line 2769

def branding
  @branding
end

#capitalObject

Settings specific to the account’s use of the Capital product.



2771
2772
2773
# File 'lib/stripe/resources/account.rb', line 2771

def capital
  @capital
end

#card_issuingObject

Settings specific to the account’s use of the Card Issuing product.



2773
2774
2775
# File 'lib/stripe/resources/account.rb', line 2773

def card_issuing
  @card_issuing
end

#card_paymentsObject

Settings specific to card charging on the account.



2775
2776
2777
# File 'lib/stripe/resources/account.rb', line 2775

def card_payments
  @card_payments
end

#invoicesObject

Settings specific to the account’s use of Invoices.



2777
2778
2779
# File 'lib/stripe/resources/account.rb', line 2777

def invoices
  @invoices
end

#paymentsObject

Settings that apply across payment methods for charging on the account.



2779
2780
2781
# File 'lib/stripe/resources/account.rb', line 2779

def payments
  @payments
end

#payoutsObject

Settings specific to the account’s payouts.



2781
2782
2783
# File 'lib/stripe/resources/account.rb', line 2781

def payouts
  @payouts
end

#tax_formsObject

Settings specific to the account’s tax forms.



2783
2784
2785
# File 'lib/stripe/resources/account.rb', line 2783

def tax_forms
  @tax_forms
end

#treasuryObject

Settings specific to the account’s Treasury FinancialAccounts.



2785
2786
2787
# File 'lib/stripe/resources/account.rb', line 2785

def treasury
  @treasury
end