Class: Stripe::Account::UpdateParams::Settings

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: BacsDebitPayments, BankBcaOnboarding, Branding, Capital, CardIssuing, CardPayments, Invoices, Payments, Payouts, TaxForms, Treasury

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, tax_forms: nil, treasury: nil) ⇒ Settings

Returns a new instance of Settings.



2757
2758
2759
2760
2761
2762
2763
2764
2765
2766
2767
2768
2769
2770
2771
2772
2773
2774
2775
2776
2777
2778
2779
2780
2781
# File 'lib/stripe/resources/account.rb', line 2757

def initialize(
  bacs_debit_payments: nil,
  bank_bca_onboarding: nil,
  branding: nil,
  capital: nil,
  card_issuing: nil,
  card_payments: nil,
  invoices: nil,
  payments: nil,
  payouts: nil,
  tax_forms: nil,
  treasury: nil
)
  @bacs_debit_payments = bacs_debit_payments
  @bank_bca_onboarding = bank_bca_onboarding
  @branding = branding
  @capital = capital
  @card_issuing = card_issuing
  @card_payments = card_payments
  @invoices = invoices
  @payments = payments
  @payouts = payouts
  @tax_forms = tax_forms
  @treasury = treasury
end

Instance Attribute Details

#bacs_debit_paymentsObject

Settings specific to Bacs Direct Debit payments.



2735
2736
2737
# File 'lib/stripe/resources/account.rb', line 2735

def bacs_debit_payments
  @bacs_debit_payments
end

#bank_bca_onboardingObject

Settings specific to bank BCA onboarding for Indonesia bank transfers payments method.



2737
2738
2739
# File 'lib/stripe/resources/account.rb', line 2737

def bank_bca_onboarding
  @bank_bca_onboarding
end

#brandingObject

Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.



2739
2740
2741
# File 'lib/stripe/resources/account.rb', line 2739

def branding
  @branding
end

#capitalObject

Settings specific to the account’s use of the Capital product.



2741
2742
2743
# File 'lib/stripe/resources/account.rb', line 2741

def capital
  @capital
end

#card_issuingObject

Settings specific to the account’s use of the Card Issuing product.



2743
2744
2745
# File 'lib/stripe/resources/account.rb', line 2743

def card_issuing
  @card_issuing
end

#card_paymentsObject

Settings specific to card charging on the account.



2745
2746
2747
# File 'lib/stripe/resources/account.rb', line 2745

def card_payments
  @card_payments
end

#invoicesObject

Settings specific to the account’s use of Invoices.



2747
2748
2749
# File 'lib/stripe/resources/account.rb', line 2747

def invoices
  @invoices
end

#paymentsObject

Settings that apply across payment methods for charging on the account.



2749
2750
2751
# File 'lib/stripe/resources/account.rb', line 2749

def payments
  @payments
end

#payoutsObject

Settings specific to the account’s payouts.



2751
2752
2753
# File 'lib/stripe/resources/account.rb', line 2751

def payouts
  @payouts
end

#tax_formsObject

Settings specific to the account’s tax forms.



2753
2754
2755
# File 'lib/stripe/resources/account.rb', line 2753

def tax_forms
  @tax_forms
end

#treasuryObject

Settings specific to the account’s Treasury FinancialAccounts.



2755
2756
2757
# File 'lib/stripe/resources/account.rb', line 2755

def treasury
  @treasury
end