Class: Stripe::Account::UpdateParams::Settings

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: BacsDebitPayments, BankBcaOnboarding, Branding, Capital, CardIssuing, CardPayments, Invoices, Payments, Payouts, TaxForms, Treasury

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, tax_forms: nil, treasury: nil) ⇒ Settings

Returns a new instance of Settings.



3053
3054
3055
3056
3057
3058
3059
3060
3061
3062
3063
3064
3065
3066
3067
3068
3069
3070
3071
3072
3073
3074
3075
3076
3077
# File 'lib/stripe/resources/account.rb', line 3053

def initialize(
  bacs_debit_payments: nil,
  bank_bca_onboarding: nil,
  branding: nil,
  capital: nil,
  card_issuing: nil,
  card_payments: nil,
  invoices: nil,
  payments: nil,
  payouts: nil,
  tax_forms: nil,
  treasury: nil
)
  @bacs_debit_payments = bacs_debit_payments
  @bank_bca_onboarding = bank_bca_onboarding
  @branding = branding
  @capital = capital
  @card_issuing = card_issuing
  @card_payments = card_payments
  @invoices = invoices
  @payments = payments
  @payouts = payouts
  @tax_forms = tax_forms
  @treasury = treasury
end

Instance Attribute Details

#bacs_debit_paymentsObject

Settings specific to Bacs Direct Debit payments.



3021
3022
3023
# File 'lib/stripe/resources/account.rb', line 3021

def bacs_debit_payments
  @bacs_debit_payments
end

#bank_bca_onboardingObject

Settings specific to bank BCA onboarding for Indonesia bank transfers payments method.



3024
3025
3026
# File 'lib/stripe/resources/account.rb', line 3024

def bank_bca_onboarding
  @bank_bca_onboarding
end

#brandingObject

Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.



3027
3028
3029
# File 'lib/stripe/resources/account.rb', line 3027

def branding
  @branding
end

#capitalObject

Settings specific to the account’s use of the Capital product.



3030
3031
3032
# File 'lib/stripe/resources/account.rb', line 3030

def capital
  @capital
end

#card_issuingObject

Settings specific to the account’s use of the Card Issuing product.



3033
3034
3035
# File 'lib/stripe/resources/account.rb', line 3033

def card_issuing
  @card_issuing
end

#card_paymentsObject

Settings specific to card charging on the account.



3036
3037
3038
# File 'lib/stripe/resources/account.rb', line 3036

def card_payments
  @card_payments
end

#invoicesObject

Settings specific to the account’s use of Invoices.



3039
3040
3041
# File 'lib/stripe/resources/account.rb', line 3039

def invoices
  @invoices
end

#paymentsObject

Settings that apply across payment methods for charging on the account.



3042
3043
3044
# File 'lib/stripe/resources/account.rb', line 3042

def payments
  @payments
end

#payoutsObject

Settings specific to the account’s payouts.



3045
3046
3047
# File 'lib/stripe/resources/account.rb', line 3045

def payouts
  @payouts
end

#tax_formsObject

Settings specific to the account’s tax forms.



3048
3049
3050
# File 'lib/stripe/resources/account.rb', line 3048

def tax_forms
  @tax_forms
end

#treasuryObject

Settings specific to the account’s Treasury FinancialAccounts.



3051
3052
3053
# File 'lib/stripe/resources/account.rb', line 3051

def treasury
  @treasury
end