Class: Stripe::Account::UpdateParams::Settings

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: BacsDebitPayments, BankBcaOnboarding, Branding, Capital, CardIssuing, CardPayments, Invoices, Payments, Payouts, TaxForms, Treasury

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, tax_forms: nil, treasury: nil) ⇒ Settings

Returns a new instance of Settings.



2646
2647
2648
2649
2650
2651
2652
2653
2654
2655
2656
2657
2658
2659
2660
2661
2662
2663
2664
2665
2666
2667
2668
2669
2670
# File 'lib/stripe/resources/account.rb', line 2646

def initialize(
  bacs_debit_payments: nil,
  bank_bca_onboarding: nil,
  branding: nil,
  capital: nil,
  card_issuing: nil,
  card_payments: nil,
  invoices: nil,
  payments: nil,
  payouts: nil,
  tax_forms: nil,
  treasury: nil
)
  @bacs_debit_payments = bacs_debit_payments
  @bank_bca_onboarding = bank_bca_onboarding
  @branding = branding
  @capital = capital
  @card_issuing = card_issuing
  @card_payments = card_payments
  @invoices = invoices
  @payments = payments
  @payouts = payouts
  @tax_forms = tax_forms
  @treasury = treasury
end

Instance Attribute Details

#bacs_debit_paymentsObject

Settings specific to Bacs Direct Debit payments.



2624
2625
2626
# File 'lib/stripe/resources/account.rb', line 2624

def bacs_debit_payments
  @bacs_debit_payments
end

#bank_bca_onboardingObject

Settings specific to bank BCA onboarding for Indonesia bank transfers payments method.



2626
2627
2628
# File 'lib/stripe/resources/account.rb', line 2626

def bank_bca_onboarding
  @bank_bca_onboarding
end

#brandingObject

Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.



2628
2629
2630
# File 'lib/stripe/resources/account.rb', line 2628

def branding
  @branding
end

#capitalObject

Settings specific to the account’s use of the Capital product.



2630
2631
2632
# File 'lib/stripe/resources/account.rb', line 2630

def capital
  @capital
end

#card_issuingObject

Settings specific to the account’s use of the Card Issuing product.



2632
2633
2634
# File 'lib/stripe/resources/account.rb', line 2632

def card_issuing
  @card_issuing
end

#card_paymentsObject

Settings specific to card charging on the account.



2634
2635
2636
# File 'lib/stripe/resources/account.rb', line 2634

def card_payments
  @card_payments
end

#invoicesObject

Settings specific to the account’s use of Invoices.



2636
2637
2638
# File 'lib/stripe/resources/account.rb', line 2636

def invoices
  @invoices
end

#paymentsObject

Settings that apply across payment methods for charging on the account.



2638
2639
2640
# File 'lib/stripe/resources/account.rb', line 2638

def payments
  @payments
end

#payoutsObject

Settings specific to the account’s payouts.



2640
2641
2642
# File 'lib/stripe/resources/account.rb', line 2640

def payouts
  @payouts
end

#tax_formsObject

Settings specific to the account’s tax forms.



2642
2643
2644
# File 'lib/stripe/resources/account.rb', line 2642

def tax_forms
  @tax_forms
end

#treasuryObject

Settings specific to the account’s Treasury FinancialAccounts.



2644
2645
2646
# File 'lib/stripe/resources/account.rb', line 2644

def treasury
  @treasury
end