Class: Stripe::Account::UpdateParams::Settings

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: BacsDebitPayments, BankBcaOnboarding, Branding, Capital, CardIssuing, CardPayments, Invoices, Payments, Payouts, TaxForms, Treasury

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, tax_forms: nil, treasury: nil) ⇒ Settings

Returns a new instance of Settings.



2693
2694
2695
2696
2697
2698
2699
2700
2701
2702
2703
2704
2705
2706
2707
2708
2709
2710
2711
2712
2713
2714
2715
2716
2717
# File 'lib/stripe/resources/account.rb', line 2693

def initialize(
  bacs_debit_payments: nil,
  bank_bca_onboarding: nil,
  branding: nil,
  capital: nil,
  card_issuing: nil,
  card_payments: nil,
  invoices: nil,
  payments: nil,
  payouts: nil,
  tax_forms: nil,
  treasury: nil
)
  @bacs_debit_payments = bacs_debit_payments
  @bank_bca_onboarding = bank_bca_onboarding
  @branding = branding
  @capital = capital
  @card_issuing = card_issuing
  @card_payments = card_payments
  @invoices = invoices
  @payments = payments
  @payouts = payouts
  @tax_forms = tax_forms
  @treasury = treasury
end

Instance Attribute Details

#bacs_debit_paymentsObject

Settings specific to Bacs Direct Debit payments.



2671
2672
2673
# File 'lib/stripe/resources/account.rb', line 2671

def bacs_debit_payments
  @bacs_debit_payments
end

#bank_bca_onboardingObject

Settings specific to bank BCA onboarding for Indonesia bank transfers payments method.



2673
2674
2675
# File 'lib/stripe/resources/account.rb', line 2673

def bank_bca_onboarding
  @bank_bca_onboarding
end

#brandingObject

Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.



2675
2676
2677
# File 'lib/stripe/resources/account.rb', line 2675

def branding
  @branding
end

#capitalObject

Settings specific to the account’s use of the Capital product.



2677
2678
2679
# File 'lib/stripe/resources/account.rb', line 2677

def capital
  @capital
end

#card_issuingObject

Settings specific to the account’s use of the Card Issuing product.



2679
2680
2681
# File 'lib/stripe/resources/account.rb', line 2679

def card_issuing
  @card_issuing
end

#card_paymentsObject

Settings specific to card charging on the account.



2681
2682
2683
# File 'lib/stripe/resources/account.rb', line 2681

def card_payments
  @card_payments
end

#invoicesObject

Settings specific to the account’s use of Invoices.



2683
2684
2685
# File 'lib/stripe/resources/account.rb', line 2683

def invoices
  @invoices
end

#paymentsObject

Settings that apply across payment methods for charging on the account.



2685
2686
2687
# File 'lib/stripe/resources/account.rb', line 2685

def payments
  @payments
end

#payoutsObject

Settings specific to the account’s payouts.



2687
2688
2689
# File 'lib/stripe/resources/account.rb', line 2687

def payouts
  @payouts
end

#tax_formsObject

Settings specific to the account’s tax forms.



2689
2690
2691
# File 'lib/stripe/resources/account.rb', line 2689

def tax_forms
  @tax_forms
end

#treasuryObject

Settings specific to the account’s Treasury FinancialAccounts.



2691
2692
2693
# File 'lib/stripe/resources/account.rb', line 2691

def treasury
  @treasury
end