Class: Stripe::Account::UpdateParams::Settings::Branding
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::UpdateParams::Settings::Branding
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#icon ⇒ Object
(ID of a [file upload](stripe.com/docs/guides/file-upload)) An icon for the account.
-
#logo ⇒ Object
(ID of a [file upload](stripe.com/docs/guides/file-upload)) A logo for the account that will be used in Checkout instead of the icon and without the account’s name next to it if provided.
-
#primary_color ⇒ Object
A CSS hex color value representing the primary branding color for this account.
-
#secondary_color ⇒ Object
A CSS hex color value representing the secondary branding color for this account.
Instance Method Summary collapse
-
#initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil) ⇒ Branding
constructor
A new instance of Branding.
Methods inherited from RequestParams
Constructor Details
#initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil) ⇒ Branding
Returns a new instance of Branding.
2293 2294 2295 2296 2297 2298 |
# File 'lib/stripe/resources/account.rb', line 2293 def initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil) @icon = icon @logo = logo @primary_color = primary_color @secondary_color = secondary_color end |
Instance Attribute Details
#icon ⇒ Object
(ID of a [file upload](stripe.com/docs/guides/file-upload)) An icon for the account. Must be square and at least 128px x 128px.
2285 2286 2287 |
# File 'lib/stripe/resources/account.rb', line 2285 def icon @icon end |
#logo ⇒ Object
(ID of a [file upload](stripe.com/docs/guides/file-upload)) A logo for the account that will be used in Checkout instead of the icon and without the account’s name next to it if provided. Must be at least 128px x 128px.
2287 2288 2289 |
# File 'lib/stripe/resources/account.rb', line 2287 def logo @logo end |
#primary_color ⇒ Object
A CSS hex color value representing the primary branding color for this account.
2289 2290 2291 |
# File 'lib/stripe/resources/account.rb', line 2289 def primary_color @primary_color end |
#secondary_color ⇒ Object
A CSS hex color value representing the secondary branding color for this account.
2291 2292 2293 |
# File 'lib/stripe/resources/account.rb', line 2291 def secondary_color @secondary_color end |