Class: Stripe::Account::UpdateParams::Settings::Branding

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil) ⇒ Branding

Returns a new instance of Branding.



2243
2244
2245
2246
2247
2248
# File 'lib/stripe/resources/account.rb', line 2243

def initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil)
  @icon = icon
  @logo = 
  @primary_color = primary_color
  @secondary_color = secondary_color
end

Instance Attribute Details

#iconObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) An icon for the account. Must be square and at least 128px x 128px.



2235
2236
2237
# File 'lib/stripe/resources/account.rb', line 2235

def icon
  @icon
end

#logoObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) A logo for the account that will be used in Checkout instead of the icon and without the account’s name next to it if provided. Must be at least 128px x 128px.



2237
2238
2239
# File 'lib/stripe/resources/account.rb', line 2237

def 
  @logo
end

#primary_colorObject

A CSS hex color value representing the primary branding color for this account.



2239
2240
2241
# File 'lib/stripe/resources/account.rb', line 2239

def primary_color
  @primary_color
end

#secondary_colorObject

A CSS hex color value representing the secondary branding color for this account.



2241
2242
2243
# File 'lib/stripe/resources/account.rb', line 2241

def secondary_color
  @secondary_color
end