Class: Stripe::Account::UpdateParams::Settings::Branding

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil) ⇒ Branding

Returns a new instance of Branding.



2455
2456
2457
2458
2459
2460
# File 'lib/stripe/resources/account.rb', line 2455

def initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil)
  @icon = icon
  @logo = 
  @primary_color = primary_color
  @secondary_color = secondary_color
end

Instance Attribute Details

#iconObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) An icon for the account. Must be square and at least 128px x 128px.



2447
2448
2449
# File 'lib/stripe/resources/account.rb', line 2447

def icon
  @icon
end

#logoObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) A logo for the account that will be used in Checkout instead of the icon and without the account’s name next to it if provided. Must be at least 128px x 128px.



2449
2450
2451
# File 'lib/stripe/resources/account.rb', line 2449

def 
  @logo
end

#primary_colorObject

A CSS hex color value representing the primary branding color for this account.



2451
2452
2453
# File 'lib/stripe/resources/account.rb', line 2451

def primary_color
  @primary_color
end

#secondary_colorObject

A CSS hex color value representing the secondary branding color for this account.



2453
2454
2455
# File 'lib/stripe/resources/account.rb', line 2453

def secondary_color
  @secondary_color
end