Class: Stripe::Account::UpdateParams::Settings::CardIssuing::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



2636
2637
2638
2639
2640
# File 'lib/stripe/resources/account.rb', line 2636

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



2630
2631
2632
# File 'lib/stripe/resources/account.rb', line 2630

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



2632
2633
2634
# File 'lib/stripe/resources/account.rb', line 2632

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



2634
2635
2636
# File 'lib/stripe/resources/account.rb', line 2634

def user_agent
  @user_agent
end