Class: Stripe::Account::UpdateParams::Settings::CardIssuing::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



2622
2623
2624
2625
2626
# File 'lib/stripe/resources/account.rb', line 2622

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



2616
2617
2618
# File 'lib/stripe/resources/account.rb', line 2616

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



2618
2619
2620
# File 'lib/stripe/resources/account.rb', line 2618

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



2620
2621
2622
# File 'lib/stripe/resources/account.rb', line 2620

def user_agent
  @user_agent
end