Class: Stripe::Account::UpdateParams::Settings::CardIssuing::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



2586
2587
2588
2589
2590
# File 'lib/stripe/resources/account.rb', line 2586

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



2580
2581
2582
# File 'lib/stripe/resources/account.rb', line 2580

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



2582
2583
2584
# File 'lib/stripe/resources/account.rb', line 2582

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



2584
2585
2586
# File 'lib/stripe/resources/account.rb', line 2584

def user_agent
  @user_agent
end