Class: Stripe::Account::UpdateParams::Settings::CardIssuing::TosAcceptance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::UpdateParams::Settings::CardIssuing::TosAcceptance
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the account representative accepted the service agreement.
-
#ip ⇒ Object
The IP address from which the account representative accepted the service agreement.
-
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted the service agreement.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance
constructor
A new instance of TosAcceptance.
Methods inherited from RequestParams
Constructor Details
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance
Returns a new instance of TosAcceptance.
2484 2485 2486 2487 2488 |
# File 'lib/stripe/resources/account.rb', line 2484 def initialize(date: nil, ip: nil, user_agent: nil) @date = date @ip = ip @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the account representative accepted the service agreement.
2478 2479 2480 |
# File 'lib/stripe/resources/account.rb', line 2478 def date @date end |
#ip ⇒ Object
The IP address from which the account representative accepted the service agreement.
2480 2481 2482 |
# File 'lib/stripe/resources/account.rb', line 2480 def ip @ip end |
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted the service agreement.
2482 2483 2484 |
# File 'lib/stripe/resources/account.rb', line 2482 def user_agent @user_agent end |