Class: Stripe::Account::UpdateParams::Settings::CardIssuing::TosAcceptance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::UpdateParams::Settings::CardIssuing::TosAcceptance
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the account representative accepted the service agreement.
-
#ip ⇒ Object
The IP address from which the account representative accepted the service agreement.
-
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted the service agreement.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance
constructor
A new instance of TosAcceptance.
Methods inherited from RequestParams
Constructor Details
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance
Returns a new instance of TosAcceptance.
2868 2869 2870 2871 2872 |
# File 'lib/stripe/resources/account.rb', line 2868 def initialize(date: nil, ip: nil, user_agent: nil) @date = date @ip = ip @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the account representative accepted the service agreement.
2860 2861 2862 |
# File 'lib/stripe/resources/account.rb', line 2860 def date @date end |
#ip ⇒ Object
The IP address from which the account representative accepted the service agreement.
2863 2864 2865 |
# File 'lib/stripe/resources/account.rb', line 2863 def ip @ip end |
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted the service agreement.
2866 2867 2868 |
# File 'lib/stripe/resources/account.rb', line 2866 def user_agent @user_agent end |