Class: Stripe::Account::UpdateParams::Settings::CardPayments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: DeclineOn

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(decline_on: nil, statement_descriptor_prefix: nil, statement_descriptor_prefix_kana: nil, statement_descriptor_prefix_kanji: nil) ⇒ CardPayments

Returns a new instance of CardPayments.



2621
2622
2623
2624
2625
2626
2627
2628
2629
2630
2631
# File 'lib/stripe/resources/account.rb', line 2621

def initialize(
  decline_on: nil,
  statement_descriptor_prefix: nil,
  statement_descriptor_prefix_kana: nil,
  statement_descriptor_prefix_kanji: nil
)
  @decline_on = decline_on
  @statement_descriptor_prefix = statement_descriptor_prefix
  @statement_descriptor_prefix_kana = statement_descriptor_prefix_kana
  @statement_descriptor_prefix_kanji = statement_descriptor_prefix_kanji
end

Instance Attribute Details

#decline_onObject

Automatically declines certain charge types regardless of whether the card issuer accepted or declined the charge.



2613
2614
2615
# File 'lib/stripe/resources/account.rb', line 2613

def decline_on
  @decline_on
end

#statement_descriptor_prefixObject

The default text that appears on credit card statements when a charge is made. This field prefixes any dynamic ‘statement_descriptor` specified on the charge. `statement_descriptor_prefix` is useful for maximizing descriptor space for the dynamic portion.



2615
2616
2617
# File 'lib/stripe/resources/account.rb', line 2615

def statement_descriptor_prefix
  @statement_descriptor_prefix
end

#statement_descriptor_prefix_kanaObject

The Kana variation of the default text that appears on credit card statements when a charge is made (Japan only). This field prefixes any dynamic ‘statement_descriptor_suffix_kana` specified on the charge. `statement_descriptor_prefix_kana` is useful for maximizing descriptor space for the dynamic portion.



2617
2618
2619
# File 'lib/stripe/resources/account.rb', line 2617

def statement_descriptor_prefix_kana
  @statement_descriptor_prefix_kana
end

#statement_descriptor_prefix_kanjiObject

The Kanji variation of the default text that appears on credit card statements when a charge is made (Japan only). This field prefixes any dynamic ‘statement_descriptor_suffix_kanji` specified on the charge. `statement_descriptor_prefix_kanji` is useful for maximizing descriptor space for the dynamic portion.



2619
2620
2621
# File 'lib/stripe/resources/account.rb', line 2619

def statement_descriptor_prefix_kanji
  @statement_descriptor_prefix_kanji
end