Class: Stripe::Account::UpdateParams::Settings::Payouts

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Defined Under Namespace

Classes: Schedule

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(debit_negative_balances: nil, schedule: nil, statement_descriptor: nil) ⇒ Payouts

Returns a new instance of Payouts.



2726
2727
2728
2729
2730
# File 'lib/stripe/resources/account.rb', line 2726

def initialize(debit_negative_balances: nil, schedule: nil, statement_descriptor: nil)
  @debit_negative_balances = debit_negative_balances
  @schedule = schedule
  @statement_descriptor = statement_descriptor
end

Instance Attribute Details

#debit_negative_balancesObject

A Boolean indicating whether Stripe should try to reclaim negative balances from an attached bank account. For details, see [Understanding Connect Account Balances](/connect/account-balances).



2720
2721
2722
# File 'lib/stripe/resources/account.rb', line 2720

def debit_negative_balances
  @debit_negative_balances
end

#scheduleObject

Details on when funds from charges are available, and when they are paid out to an external account. For details, see our [Setting Bank and Debit Card Payouts](/connect/bank-transfers#payout-information) documentation.



2722
2723
2724
# File 'lib/stripe/resources/account.rb', line 2722

def schedule
  @schedule
end

#statement_descriptorObject

The text that appears on the bank account statement for payouts. If not set, this defaults to the platform’s bank descriptor as set in the Dashboard.



2724
2725
2726
# File 'lib/stripe/resources/account.rb', line 2724

def statement_descriptor
  @statement_descriptor
end