Class: Stripe::Account::UpdateParams::Settings::Payouts::Schedule
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::UpdateParams::Settings::Payouts::Schedule
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#delay_days ⇒ Object
The number of days charge funds are held before being paid out.
-
#interval ⇒ Object
How frequently available funds are paid out.
-
#monthly_anchor ⇒ Object
The day of the month when available funds are paid out, specified as a number between 1–31.
-
#monthly_payout_days ⇒ Object
The days of the month when available funds are paid out, specified as an array of numbers between 1–31.
-
#weekly_anchor ⇒ Object
The day of the week when available funds are paid out, specified as ‘monday`, `tuesday`, etc.
-
#weekly_payout_days ⇒ Object
The days of the week when available funds are paid out, specified as an array, e.g., [‘monday`, `tuesday`].
Instance Method Summary collapse
-
#initialize(delay_days: nil, interval: nil, monthly_anchor: nil, monthly_payout_days: nil, weekly_anchor: nil, weekly_payout_days: nil) ⇒ Schedule
constructor
A new instance of Schedule.
Methods inherited from RequestParams
Constructor Details
#initialize(delay_days: nil, interval: nil, monthly_anchor: nil, monthly_payout_days: nil, weekly_anchor: nil, weekly_payout_days: nil) ⇒ Schedule
Returns a new instance of Schedule.
2762 2763 2764 2765 2766 2767 2768 2769 2770 2771 2772 2773 2774 2775 2776 |
# File 'lib/stripe/resources/account.rb', line 2762 def initialize( delay_days: nil, interval: nil, monthly_anchor: nil, monthly_payout_days: nil, weekly_anchor: nil, weekly_payout_days: nil ) @delay_days = delay_days @interval = interval @monthly_anchor = monthly_anchor @monthly_payout_days = monthly_payout_days @weekly_anchor = weekly_anchor @weekly_payout_days = weekly_payout_days end |
Instance Attribute Details
#delay_days ⇒ Object
The number of days charge funds are held before being paid out. May also be set to ‘minimum`, representing the lowest available value for the account country. Default is `minimum`. The `delay_days` parameter remains at the last configured value if `interval` is `manual`. [Learn more about controlling payout delay days](/connect/manage-payout-schedule).
2750 2751 2752 |
# File 'lib/stripe/resources/account.rb', line 2750 def delay_days @delay_days end |
#interval ⇒ Object
How frequently available funds are paid out. One of: ‘daily`, `manual`, `weekly`, or `monthly`. Default is `daily`.
2752 2753 2754 |
# File 'lib/stripe/resources/account.rb', line 2752 def interval @interval end |
#monthly_anchor ⇒ Object
The day of the month when available funds are paid out, specified as a number between 1–31. Payouts nominally scheduled between the 29th and 31st of the month are instead sent on the last day of a shorter month. Required and applicable only if ‘interval` is `monthly`.
2754 2755 2756 |
# File 'lib/stripe/resources/account.rb', line 2754 def monthly_anchor @monthly_anchor end |
#monthly_payout_days ⇒ Object
The days of the month when available funds are paid out, specified as an array of numbers between 1–31. Payouts nominally scheduled between the 29th and 31st of the month are instead sent on the last day of a shorter month. Required and applicable only if ‘interval` is `monthly` and `monthly_anchor` is not set.
2756 2757 2758 |
# File 'lib/stripe/resources/account.rb', line 2756 def monthly_payout_days @monthly_payout_days end |
#weekly_anchor ⇒ Object
The day of the week when available funds are paid out, specified as ‘monday`, `tuesday`, etc. (required and applicable only if `interval` is `weekly`.)
2758 2759 2760 |
# File 'lib/stripe/resources/account.rb', line 2758 def weekly_anchor @weekly_anchor end |
#weekly_payout_days ⇒ Object
The days of the week when available funds are paid out, specified as an array, e.g., [‘monday`, `tuesday`]. (required and applicable only if `interval` is `weekly` and `weekly_anchor` is not set.)
2760 2761 2762 |
# File 'lib/stripe/resources/account.rb', line 2760 def weekly_payout_days @weekly_payout_days end |