Class: Stripe::Account::UpdateParams::Settings::Treasury::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



2765
2766
2767
2768
2769
# File 'lib/stripe/resources/account.rb', line 2765

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



2759
2760
2761
# File 'lib/stripe/resources/account.rb', line 2759

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



2761
2762
2763
# File 'lib/stripe/resources/account.rb', line 2761

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



2763
2764
2765
# File 'lib/stripe/resources/account.rb', line 2763

def user_agent
  @user_agent
end