Class: Stripe::Account::UpdateParams::Settings::Treasury::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



2416
2417
2418
2419
2420
# File 'lib/stripe/resources/account.rb', line 2416

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



2410
2411
2412
# File 'lib/stripe/resources/account.rb', line 2410

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



2412
2413
2414
# File 'lib/stripe/resources/account.rb', line 2412

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



2414
2415
2416
# File 'lib/stripe/resources/account.rb', line 2414

def user_agent
  @user_agent
end