Class: Stripe::Account::UpdateParams::Settings::Treasury::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



2751
2752
2753
2754
2755
# File 'lib/stripe/resources/account.rb', line 2751

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



2745
2746
2747
# File 'lib/stripe/resources/account.rb', line 2745

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



2747
2748
2749
# File 'lib/stripe/resources/account.rb', line 2747

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



2749
2750
2751
# File 'lib/stripe/resources/account.rb', line 2749

def user_agent
  @user_agent
end