Class: Stripe::Account::UpdateParams::Settings::Treasury::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



2715
2716
2717
2718
2719
# File 'lib/stripe/resources/account.rb', line 2715

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



2709
2710
2711
# File 'lib/stripe/resources/account.rb', line 2709

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



2711
2712
2713
# File 'lib/stripe/resources/account.rb', line 2711

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



2713
2714
2715
# File 'lib/stripe/resources/account.rb', line 2713

def user_agent
  @user_agent
end