Class: Stripe::Account::UpdateParams::TosAcceptance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::UpdateParams::TosAcceptance
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the account representative accepted their service agreement.
-
#ip ⇒ Object
The IP address from which the account representative accepted their service agreement.
-
#service_agreement ⇒ Object
The user’s service agreement type.
-
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted their service agreement.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance
constructor
A new instance of TosAcceptance.
Methods inherited from RequestParams
Constructor Details
#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance
Returns a new instance of TosAcceptance.
2883 2884 2885 2886 2887 2888 |
# File 'lib/stripe/resources/account.rb', line 2883 def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) @date = date @ip = ip @service_agreement = service_agreement @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the account representative accepted their service agreement.
2875 2876 2877 |
# File 'lib/stripe/resources/account.rb', line 2875 def date @date end |
#ip ⇒ Object
The IP address from which the account representative accepted their service agreement.
2877 2878 2879 |
# File 'lib/stripe/resources/account.rb', line 2877 def ip @ip end |
#service_agreement ⇒ Object
The user’s service agreement type.
2879 2880 2881 |
# File 'lib/stripe/resources/account.rb', line 2879 def service_agreement @service_agreement end |
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted their service agreement.
2881 2882 2883 |
# File 'lib/stripe/resources/account.rb', line 2881 def user_agent @user_agent end |