Class: Stripe::Account::UpdateParams::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



2838
2839
2840
2841
2842
2843
# File 'lib/stripe/resources/account.rb', line 2838

def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil)
  @date = date
  @ip = ip
  @service_agreement = service_agreement
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted their service agreement.



2830
2831
2832
# File 'lib/stripe/resources/account.rb', line 2830

def date
  @date
end

#ipObject

The IP address from which the account representative accepted their service agreement.



2832
2833
2834
# File 'lib/stripe/resources/account.rb', line 2832

def ip
  @ip
end

#service_agreementObject

The user’s service agreement type.



2834
2835
2836
# File 'lib/stripe/resources/account.rb', line 2834

def service_agreement
  @service_agreement
end

#user_agentObject

The user agent of the browser from which the account representative accepted their service agreement.



2836
2837
2838
# File 'lib/stripe/resources/account.rb', line 2836

def user_agent
  @user_agent
end