Class: Stripe::Account::UpdateParams::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



2824
2825
2826
2827
2828
2829
# File 'lib/stripe/resources/account.rb', line 2824

def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil)
  @date = date
  @ip = ip
  @service_agreement = service_agreement
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted their service agreement.



2816
2817
2818
# File 'lib/stripe/resources/account.rb', line 2816

def date
  @date
end

#ipObject

The IP address from which the account representative accepted their service agreement.



2818
2819
2820
# File 'lib/stripe/resources/account.rb', line 2818

def ip
  @ip
end

#service_agreementObject

The user’s service agreement type.



2820
2821
2822
# File 'lib/stripe/resources/account.rb', line 2820

def service_agreement
  @service_agreement
end

#user_agentObject

The user agent of the browser from which the account representative accepted their service agreement.



2822
2823
2824
# File 'lib/stripe/resources/account.rb', line 2822

def user_agent
  @user_agent
end