Class: Stripe::Account::UpdateParams::TosAcceptance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Account::UpdateParams::TosAcceptance
- Defined in:
- lib/stripe/resources/account.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the account representative accepted their service agreement.
-
#ip ⇒ Object
The IP address from which the account representative accepted their service agreement.
-
#service_agreement ⇒ Object
The user’s service agreement type.
-
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted their service agreement.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance
constructor
A new instance of TosAcceptance.
Methods inherited from RequestParams
Constructor Details
#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance
Returns a new instance of TosAcceptance.
2794 2795 2796 2797 2798 2799 |
# File 'lib/stripe/resources/account.rb', line 2794 def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) @date = date @ip = ip @service_agreement = service_agreement @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the account representative accepted their service agreement.
2786 2787 2788 |
# File 'lib/stripe/resources/account.rb', line 2786 def date @date end |
#ip ⇒ Object
The IP address from which the account representative accepted their service agreement.
2788 2789 2790 |
# File 'lib/stripe/resources/account.rb', line 2788 def ip @ip end |
#service_agreement ⇒ Object
The user’s service agreement type.
2790 2791 2792 |
# File 'lib/stripe/resources/account.rb', line 2790 def service_agreement @service_agreement end |
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted their service agreement.
2792 2793 2794 |
# File 'lib/stripe/resources/account.rb', line 2792 def user_agent @user_agent end |