Class: Stripe::Account::UpdateParams::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



2441
2442
2443
2444
2445
2446
# File 'lib/stripe/resources/account.rb', line 2441

def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil)
  @date = date
  @ip = ip
  @service_agreement = service_agreement
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted their service agreement.



2433
2434
2435
# File 'lib/stripe/resources/account.rb', line 2433

def date
  @date
end

#ipObject

The IP address from which the account representative accepted their service agreement.



2435
2436
2437
# File 'lib/stripe/resources/account.rb', line 2435

def ip
  @ip
end

#service_agreementObject

The user’s service agreement type.



2437
2438
2439
# File 'lib/stripe/resources/account.rb', line 2437

def service_agreement
  @service_agreement
end

#user_agentObject

The user agent of the browser from which the account representative accepted their service agreement.



2439
2440
2441
# File 'lib/stripe/resources/account.rb', line 2439

def user_agent
  @user_agent
end