Class: Stripe::AccountCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountCreateParams
- Defined in:
- lib/stripe/params/account_create_params.rb
Defined Under Namespace
Classes: BankAccount, BusinessProfile, Capabilities, Card, CardToken, Company, Controller, Documents, Groups, Individual, RiskControls, Settings, TosAcceptance
Instance Attribute Summary collapse
-
#account_token ⇒ Object
An account token, used to securely provide details to the account.
-
#business_profile ⇒ Object
Business information about the account.
-
#business_type ⇒ Object
The business type.
-
#capabilities ⇒ Object
Each key of the dictionary represents a capability, and each capability maps to its settings (for example, whether it has been requested or not).
-
#company ⇒ Object
Information about the company or business.
-
#controller ⇒ Object
A hash of configuration describing the account controller's attributes.
-
#country ⇒ Object
The country in which the account holder resides, or in which the business is legally established.
-
#default_currency ⇒ Object
Three-letter ISO currency code representing the default currency for the account.
-
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
-
#email ⇒ Object
The email address of the account holder.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#external_account ⇒ Object
A card or bank account to attach to the account for receiving payouts (you won’t be able to use it for top-ups).
-
#groups ⇒ Object
A hash of account group type to tokens.
-
#individual ⇒ Object
Information about the person represented by the account.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#risk_controls ⇒ Object
A hash to configure risk controls on the account.
-
#settings ⇒ Object
Options for customizing how the account functions within Stripe.
-
#tos_acceptance ⇒ Object
Details on the account's acceptance of the Stripe Services Agreement.
-
#type ⇒ Object
The
typeparameter is deprecated.
Instance Method Summary collapse
-
#initialize(account_token: nil, business_profile: nil, business_type: nil, capabilities: nil, company: nil, controller: nil, country: nil, default_currency: nil, documents: nil, email: nil, expand: nil, external_account: nil, groups: nil, individual: nil, metadata: nil, risk_controls: nil, settings: nil, tos_acceptance: nil, type: nil) ⇒ AccountCreateParams
constructor
A new instance of AccountCreateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(account_token: nil, business_profile: nil, business_type: nil, capabilities: nil, company: nil, controller: nil, country: nil, default_currency: nil, documents: nil, email: nil, expand: nil, external_account: nil, groups: nil, individual: nil, metadata: nil, risk_controls: nil, settings: nil, tos_acceptance: nil, type: nil) ⇒ AccountCreateParams
Returns a new instance of AccountCreateParams.
2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 2680 2681 2682 2683 2684 2685 2686 2687 2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 |
# File 'lib/stripe/params/account_create_params.rb', line 2667 def initialize( account_token: nil, business_profile: nil, business_type: nil, capabilities: nil, company: nil, controller: nil, country: nil, default_currency: nil, documents: nil, email: nil, expand: nil, external_account: nil, groups: nil, individual: nil, metadata: nil, risk_controls: nil, settings: nil, tos_acceptance: nil, type: nil ) @account_token = account_token @business_profile = business_profile @business_type = business_type @capabilities = capabilities @company = company @controller = controller @country = country @default_currency = default_currency @documents = documents @email = email @expand = @external_account = external_account @groups = groups @individual = individual @metadata = @risk_controls = risk_controls @settings = settings @tos_acceptance = tos_acceptance @type = type end |
Instance Attribute Details
#account_token ⇒ Object
An account token, used to securely provide details to the account.
2622 2623 2624 |
# File 'lib/stripe/params/account_create_params.rb', line 2622 def account_token @account_token end |
#business_profile ⇒ Object
Business information about the account.
2624 2625 2626 |
# File 'lib/stripe/params/account_create_params.rb', line 2624 def business_profile @business_profile end |
#business_type ⇒ Object
The business type. Once you create an Account Link or Account Session, this property can only be updated for accounts where controller.requirement_collection is application, which includes Custom accounts.
2626 2627 2628 |
# File 'lib/stripe/params/account_create_params.rb', line 2626 def business_type @business_type end |
#capabilities ⇒ Object
Each key of the dictionary represents a capability, and each capability maps to its settings (for example, whether it has been requested or not). Each capability is inactive until you have provided its specific requirements and Stripe has verified them. An account might have some of its requested capabilities be active and some be inactive.
Required when account.controller.stripe_dashboard.type
is none, which includes Custom accounts.
2635 2636 2637 |
# File 'lib/stripe/params/account_create_params.rb', line 2635 def capabilities @capabilities end |
#company ⇒ Object
Information about the company or business. This field is available for any business_type. Once you create an Account Link or Account Session, this property can only be updated for accounts where controller.requirement_collection is application, which includes Custom accounts.
2637 2638 2639 |
# File 'lib/stripe/params/account_create_params.rb', line 2637 def company @company end |
#controller ⇒ Object
A hash of configuration describing the account controller's attributes.
2639 2640 2641 |
# File 'lib/stripe/params/account_create_params.rb', line 2639 def controller @controller end |
#country ⇒ Object
The country in which the account holder resides, or in which the business is legally established. This should be an ISO 3166-1 alpha-2 country code. For example, if you are in the United States and the business for which you're creating an account is legally represented in Canada, you would use CA as the country for the account being created. Available countries include Stripe's global markets as well as countries where cross-border payouts are supported.
2641 2642 2643 |
# File 'lib/stripe/params/account_create_params.rb', line 2641 def country @country end |
#default_currency ⇒ Object
Three-letter ISO currency code representing the default currency for the account. This must be a currency that Stripe supports in the account's country.
2643 2644 2645 |
# File 'lib/stripe/params/account_create_params.rb', line 2643 def default_currency @default_currency end |
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
2645 2646 2647 |
# File 'lib/stripe/params/account_create_params.rb', line 2645 def documents @documents end |
#email ⇒ Object
The email address of the account holder. This is only to make the account easier to identify to you. If controller.requirement_collection is application, which includes Custom accounts, Stripe doesn't email the account without your consent.
2647 2648 2649 |
# File 'lib/stripe/params/account_create_params.rb', line 2647 def email @email end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2649 2650 2651 |
# File 'lib/stripe/params/account_create_params.rb', line 2649 def @expand end |
#external_account ⇒ Object
A card or bank account to attach to the account for receiving payouts (you won’t be able to use it for top-ups). You can provide either a token, like the ones returned by Stripe.js, or a dictionary, as documented in the external_account parameter for bank account creation.
By default, providing an external account sets it as the new default external account for its currency, and deletes the old default if one exists. To add additional external accounts without replacing the existing default for the currency, use the bank account or card creation APIs. After you create an Account Link or Account Session, this property can only be updated for accounts where controller.requirement_collection is application, which includes Custom accounts.
2651 2652 2653 |
# File 'lib/stripe/params/account_create_params.rb', line 2651 def external_account @external_account end |
#groups ⇒ Object
A hash of account group type to tokens. These are account groups this account should be added to.
2653 2654 2655 |
# File 'lib/stripe/params/account_create_params.rb', line 2653 def groups @groups end |
#individual ⇒ Object
Information about the person represented by the account. This field is null unless business_type is set to individual. Once you create an Account Link or Account Session, this property can only be updated for accounts where controller.requirement_collection is application, which includes Custom accounts.
2655 2656 2657 |
# File 'lib/stripe/params/account_create_params.rb', line 2655 def individual @individual end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
2657 2658 2659 |
# File 'lib/stripe/params/account_create_params.rb', line 2657 def @metadata end |
#risk_controls ⇒ Object
A hash to configure risk controls on the account. Please see this page for more details.
2659 2660 2661 |
# File 'lib/stripe/params/account_create_params.rb', line 2659 def risk_controls @risk_controls end |
#settings ⇒ Object
Options for customizing how the account functions within Stripe.
2661 2662 2663 |
# File 'lib/stripe/params/account_create_params.rb', line 2661 def settings @settings end |
#tos_acceptance ⇒ Object
Details on the account's acceptance of the Stripe Services Agreement. This property can only be updated for accounts where controller.requirement_collection is application, which includes Custom accounts. This property defaults to a full service agreement when empty.
2663 2664 2665 |
# File 'lib/stripe/params/account_create_params.rb', line 2663 def tos_acceptance @tos_acceptance end |
#type ⇒ Object
The type parameter is deprecated. Use controller instead to configure dashboard access, fee payer, loss liability, and requirement collection.
2665 2666 2667 |
# File 'lib/stripe/params/account_create_params.rb', line 2665 def type @type end |