Class: Stripe::AccountCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountCreateParams
- Defined in:
- lib/stripe/params/account_create_params.rb
Defined Under Namespace
Classes: BankAccount, BusinessProfile, Capabilities, Card, CardToken, Company, Controller, Documents, Groups, Individual, Settings, TosAcceptance
Instance Attribute Summary collapse
-
#account_token ⇒ Object
An account token, used to securely provide details to the account.
-
#business_profile ⇒ Object
Business information about the account.
-
#business_type ⇒ Object
The business type.
-
#capabilities ⇒ Object
Each key of the dictionary represents a capability, and each capability maps to its settings (for example, whether it has been requested or not).
-
#company ⇒ Object
Information about the company or business.
-
#controller ⇒ Object
A hash of configuration describing the account controller's attributes.
-
#country ⇒ Object
The country in which the account holder resides, or in which the business is legally established.
-
#default_currency ⇒ Object
Three-letter ISO currency code representing the default currency for the account.
-
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
-
#email ⇒ Object
The email address of the account holder.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#external_account ⇒ Object
A card or bank account to attach to the account for receiving payouts (you won’t be able to use it for top-ups).
-
#groups ⇒ Object
A hash of account group type to tokens.
-
#individual ⇒ Object
Information about the person represented by the account.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#settings ⇒ Object
Options for customizing how the account functions within Stripe.
-
#tos_acceptance ⇒ Object
Details on the account's acceptance of the Stripe Services Agreement.
-
#type ⇒ Object
The
typeparameter is deprecated.
Instance Method Summary collapse
-
#initialize(account_token: nil, business_profile: nil, business_type: nil, capabilities: nil, company: nil, controller: nil, country: nil, default_currency: nil, documents: nil, email: nil, expand: nil, external_account: nil, groups: nil, individual: nil, metadata: nil, settings: nil, tos_acceptance: nil, type: nil) ⇒ AccountCreateParams
constructor
A new instance of AccountCreateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(account_token: nil, business_profile: nil, business_type: nil, capabilities: nil, company: nil, controller: nil, country: nil, default_currency: nil, documents: nil, email: nil, expand: nil, external_account: nil, groups: nil, individual: nil, metadata: nil, settings: nil, tos_acceptance: nil, type: nil) ⇒ AccountCreateParams
Returns a new instance of AccountCreateParams.
2210 2211 2212 2213 2214 2215 2216 2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 2246 2247 2248 |
# File 'lib/stripe/params/account_create_params.rb', line 2210 def initialize( account_token: nil, business_profile: nil, business_type: nil, capabilities: nil, company: nil, controller: nil, country: nil, default_currency: nil, documents: nil, email: nil, expand: nil, external_account: nil, groups: nil, individual: nil, metadata: nil, settings: nil, tos_acceptance: nil, type: nil ) @account_token = account_token @business_profile = business_profile @business_type = business_type @capabilities = capabilities @company = company @controller = controller @country = country @default_currency = default_currency @documents = documents @email = email @expand = @external_account = external_account @groups = groups @individual = individual @metadata = @settings = settings @tos_acceptance = tos_acceptance @type = type end |
Instance Attribute Details
#account_token ⇒ Object
An account token, used to securely provide details to the account.
2167 2168 2169 |
# File 'lib/stripe/params/account_create_params.rb', line 2167 def account_token @account_token end |
#business_profile ⇒ Object
Business information about the account.
2169 2170 2171 |
# File 'lib/stripe/params/account_create_params.rb', line 2169 def business_profile @business_profile end |
#business_type ⇒ Object
The business type. Once you create an Account Link or Account Session, this property can only be updated for accounts where controller.requirement_collection is application, which includes Custom accounts.
2171 2172 2173 |
# File 'lib/stripe/params/account_create_params.rb', line 2171 def business_type @business_type end |
#capabilities ⇒ Object
Each key of the dictionary represents a capability, and each capability maps to its settings (for example, whether it has been requested or not). Each capability is inactive until you have provided its specific requirements and Stripe has verified them. An account might have some of its requested capabilities be active and some be inactive.
Required when account.controller.stripe_dashboard.type
is none, which includes Custom accounts.
2180 2181 2182 |
# File 'lib/stripe/params/account_create_params.rb', line 2180 def capabilities @capabilities end |
#company ⇒ Object
Information about the company or business. This field is available for any business_type. Once you create an Account Link or Account Session, this property can only be updated for accounts where controller.requirement_collection is application, which includes Custom accounts.
2182 2183 2184 |
# File 'lib/stripe/params/account_create_params.rb', line 2182 def company @company end |
#controller ⇒ Object
A hash of configuration describing the account controller's attributes.
2184 2185 2186 |
# File 'lib/stripe/params/account_create_params.rb', line 2184 def controller @controller end |
#country ⇒ Object
The country in which the account holder resides, or in which the business is legally established. This should be an ISO 3166-1 alpha-2 country code. For example, if you are in the United States and the business for which you're creating an account is legally represented in Canada, you would use CA as the country for the account being created. Available countries include Stripe's global markets as well as countries where cross-border payouts are supported.
2186 2187 2188 |
# File 'lib/stripe/params/account_create_params.rb', line 2186 def country @country end |
#default_currency ⇒ Object
Three-letter ISO currency code representing the default currency for the account. This must be a currency that Stripe supports in the account's country.
2188 2189 2190 |
# File 'lib/stripe/params/account_create_params.rb', line 2188 def default_currency @default_currency end |
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
2190 2191 2192 |
# File 'lib/stripe/params/account_create_params.rb', line 2190 def documents @documents end |
#email ⇒ Object
The email address of the account holder. This is only to make the account easier to identify to you. If controller.requirement_collection is application, which includes Custom accounts, Stripe doesn't email the account without your consent.
2192 2193 2194 |
# File 'lib/stripe/params/account_create_params.rb', line 2192 def email @email end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2194 2195 2196 |
# File 'lib/stripe/params/account_create_params.rb', line 2194 def @expand end |
#external_account ⇒ Object
A card or bank account to attach to the account for receiving payouts (you won’t be able to use it for top-ups). You can provide either a token, like the ones returned by Stripe.js, or a dictionary, as documented in the external_account parameter for bank account creation.
By default, providing an external account sets it as the new default external account for its currency, and deletes the old default if one exists. To add additional external accounts without replacing the existing default for the currency, use the bank account or card creation APIs. After you create an Account Link or Account Session, this property can only be updated for accounts where controller.requirement_collection is application, which includes Custom accounts.
2196 2197 2198 |
# File 'lib/stripe/params/account_create_params.rb', line 2196 def external_account @external_account end |
#groups ⇒ Object
A hash of account group type to tokens. These are account groups this account should be added to.
2198 2199 2200 |
# File 'lib/stripe/params/account_create_params.rb', line 2198 def groups @groups end |
#individual ⇒ Object
Information about the person represented by the account. This field is null unless business_type is set to individual. Once you create an Account Link or Account Session, this property can only be updated for accounts where controller.requirement_collection is application, which includes Custom accounts.
2200 2201 2202 |
# File 'lib/stripe/params/account_create_params.rb', line 2200 def individual @individual end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
2202 2203 2204 |
# File 'lib/stripe/params/account_create_params.rb', line 2202 def @metadata end |
#settings ⇒ Object
Options for customizing how the account functions within Stripe.
2204 2205 2206 |
# File 'lib/stripe/params/account_create_params.rb', line 2204 def settings @settings end |
#tos_acceptance ⇒ Object
Details on the account's acceptance of the Stripe Services Agreement. This property can only be updated for accounts where controller.requirement_collection is application, which includes Custom accounts. This property defaults to a full service agreement when empty.
2206 2207 2208 |
# File 'lib/stripe/params/account_create_params.rb', line 2206 def tos_acceptance @tos_acceptance end |
#type ⇒ Object
The type parameter is deprecated. Use controller instead to configure dashboard access, fee payer, loss liability, and requirement collection.
2208 2209 2210 |
# File 'lib/stripe/params/account_create_params.rb', line 2208 def type @type end |