Class: Stripe::AccountCreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/account_create_params.rb

Defined Under Namespace

Classes: BankAccount, BusinessProfile, Capabilities, Card, CardToken, Company, Controller, Documents, Groups, Individual, RiskControls, Settings, TosAcceptance

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(account_token: nil, business_profile: nil, business_type: nil, capabilities: nil, company: nil, controller: nil, country: nil, default_currency: nil, documents: nil, email: nil, expand: nil, external_account: nil, groups: nil, individual: nil, metadata: nil, risk_controls: nil, settings: nil, tos_acceptance: nil, type: nil) ⇒ AccountCreateParams

Returns a new instance of AccountCreateParams.



2581
2582
2583
2584
2585
2586
2587
2588
2589
2590
2591
2592
2593
2594
2595
2596
2597
2598
2599
2600
2601
2602
2603
2604
2605
2606
2607
2608
2609
2610
2611
2612
2613
2614
2615
2616
2617
2618
2619
2620
2621
# File 'lib/stripe/params/account_create_params.rb', line 2581

def initialize(
  account_token: nil,
  business_profile: nil,
  business_type: nil,
  capabilities: nil,
  company: nil,
  controller: nil,
  country: nil,
  default_currency: nil,
  documents: nil,
  email: nil,
  expand: nil,
  external_account: nil,
  groups: nil,
  individual: nil,
  metadata: nil,
  risk_controls: nil,
  settings: nil,
  tos_acceptance: nil,
  type: nil
)
  @account_token = 
  @business_profile = business_profile
  @business_type = business_type
  @capabilities = capabilities
  @company = company
  @controller = controller
  @country = country
  @default_currency = default_currency
  @documents = documents
  @email = email
  @expand = expand
  @external_account = 
  @groups = groups
  @individual = individual
  @metadata = 
  @risk_controls = risk_controls
  @settings = settings
  @tos_acceptance = tos_acceptance
  @type = type
end

Instance Attribute Details

#account_tokenObject

An account token, used to securely provide details to the account.



2536
2537
2538
# File 'lib/stripe/params/account_create_params.rb', line 2536

def 
  @account_token
end

#business_profileObject

Business information about the account.



2538
2539
2540
# File 'lib/stripe/params/account_create_params.rb', line 2538

def business_profile
  @business_profile
end

#business_typeObject

The business type. Once you create an Account Link or Account Session, this property can only be updated for accounts where controller.requirement_collection is application, which includes Custom accounts.



2540
2541
2542
# File 'lib/stripe/params/account_create_params.rb', line 2540

def business_type
  @business_type
end

#capabilitiesObject

Each key of the dictionary represents a capability, and each capability maps to its settings (for example, whether it has been requested or not). Each capability is inactive until you have provided its specific requirements and Stripe has verified them. An account might have some of its requested capabilities be active and some be inactive.

Required when account.controller.stripe_dashboard.type is none, which includes Custom accounts.



2549
2550
2551
# File 'lib/stripe/params/account_create_params.rb', line 2549

def capabilities
  @capabilities
end

#companyObject

Information about the company or business. This field is available for any business_type. Once you create an Account Link or Account Session, this property can only be updated for accounts where controller.requirement_collection is application, which includes Custom accounts.



2551
2552
2553
# File 'lib/stripe/params/account_create_params.rb', line 2551

def company
  @company
end

#controllerObject

A hash of configuration describing the account controller's attributes.



2553
2554
2555
# File 'lib/stripe/params/account_create_params.rb', line 2553

def controller
  @controller
end

#countryObject

The country in which the account holder resides, or in which the business is legally established. This should be an ISO 3166-1 alpha-2 country code. For example, if you are in the United States and the business for which you're creating an account is legally represented in Canada, you would use CA as the country for the account being created. Available countries include Stripe's global markets as well as countries where cross-border payouts are supported.



2555
2556
2557
# File 'lib/stripe/params/account_create_params.rb', line 2555

def country
  @country
end

#default_currencyObject

Three-letter ISO currency code representing the default currency for the account. This must be a currency that Stripe supports in the account's country.



2557
2558
2559
# File 'lib/stripe/params/account_create_params.rb', line 2557

def default_currency
  @default_currency
end

#documentsObject

Documents that may be submitted to satisfy various informational requests.



2559
2560
2561
# File 'lib/stripe/params/account_create_params.rb', line 2559

def documents
  @documents
end

#emailObject

The email address of the account holder. This is only to make the account easier to identify to you. If controller.requirement_collection is application, which includes Custom accounts, Stripe doesn't email the account without your consent.



2561
2562
2563
# File 'lib/stripe/params/account_create_params.rb', line 2561

def email
  @email
end

#expandObject

Specifies which fields in the response should be expanded.



2563
2564
2565
# File 'lib/stripe/params/account_create_params.rb', line 2563

def expand
  @expand
end

#external_accountObject

A card or bank account to attach to the account for receiving payouts (you won’t be able to use it for top-ups). You can provide either a token, like the ones returned by Stripe.js, or a dictionary, as documented in the external_account parameter for bank account creation.

By default, providing an external account sets it as the new default external account for its currency, and deletes the old default if one exists. To add additional external accounts without replacing the existing default for the currency, use the bank account or card creation APIs. After you create an Account Link or Account Session, this property can only be updated for accounts where controller.requirement_collection is application, which includes Custom accounts.



2565
2566
2567
# File 'lib/stripe/params/account_create_params.rb', line 2565

def 
  @external_account
end

#groupsObject

A hash of account group type to tokens. These are account groups this account should be added to.



2567
2568
2569
# File 'lib/stripe/params/account_create_params.rb', line 2567

def groups
  @groups
end

#individualObject

Information about the person represented by the account. This field is null unless business_type is set to individual. Once you create an Account Link or Account Session, this property can only be updated for accounts where controller.requirement_collection is application, which includes Custom accounts.



2569
2570
2571
# File 'lib/stripe/params/account_create_params.rb', line 2569

def individual
  @individual
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.



2571
2572
2573
# File 'lib/stripe/params/account_create_params.rb', line 2571

def 
  @metadata
end

#risk_controlsObject

A hash to configure risk controls on the account. Please see this page for more details.



2573
2574
2575
# File 'lib/stripe/params/account_create_params.rb', line 2573

def risk_controls
  @risk_controls
end

#settingsObject

Options for customizing how the account functions within Stripe.



2575
2576
2577
# File 'lib/stripe/params/account_create_params.rb', line 2575

def settings
  @settings
end

#tos_acceptanceObject

Details on the account's acceptance of the Stripe Services Agreement. This property can only be updated for accounts where controller.requirement_collection is application, which includes Custom accounts. This property defaults to a full service agreement when empty.



2577
2578
2579
# File 'lib/stripe/params/account_create_params.rb', line 2577

def tos_acceptance
  @tos_acceptance
end

#typeObject

The type parameter is deprecated. Use controller instead to configure dashboard access, fee payer, loss liability, and requirement collection.



2579
2580
2581
# File 'lib/stripe/params/account_create_params.rb', line 2579

def type
  @type
end