Class: Stripe::AccountCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountCreateParams
- Defined in:
- lib/stripe/params/account_create_params.rb
Defined Under Namespace
Classes: BankAccount, BusinessProfile, Capabilities, Card, CardToken, Company, Controller, Documents, Groups, Individual, RiskControls, Settings, TosAcceptance
Instance Attribute Summary collapse
-
#account_token ⇒ Object
An [account token](api.stripe.com#create_account_token), used to securely provide details to the account.
-
#business_profile ⇒ Object
Business information about the account.
-
#business_type ⇒ Object
The business type.
-
#capabilities ⇒ Object
Each key of the dictionary represents a capability, and each capability maps to its settings (for example, whether it has been requested or not).
-
#company ⇒ Object
Information about the company or business.
-
#controller ⇒ Object
A hash of configuration describing the account controller’s attributes.
-
#country ⇒ Object
The country in which the account holder resides, or in which the business is legally established.
-
#default_currency ⇒ Object
Three-letter ISO currency code representing the default currency for the account.
-
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
-
#email ⇒ Object
The email address of the account holder.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#external_account ⇒ Object
A card or bank account to attach to the account for receiving [payouts](/connect/bank-debit-card-payouts) (you won’t be able to use it for top-ups).
-
#groups ⇒ Object
A hash of account group type to tokens.
-
#individual ⇒ Object
Information about the person represented by the account.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#risk_controls ⇒ Object
A hash to configure risk controls on the account.
-
#settings ⇒ Object
Options for customizing how the account functions within Stripe.
-
#tos_acceptance ⇒ Object
Details on the account’s acceptance of the [Stripe Services Agreement](/connect/updating-accounts#tos-acceptance).
-
#type ⇒ Object
The ‘type` parameter is deprecated.
Instance Method Summary collapse
-
#initialize(account_token: nil, business_profile: nil, business_type: nil, capabilities: nil, company: nil, controller: nil, country: nil, default_currency: nil, documents: nil, email: nil, expand: nil, external_account: nil, groups: nil, individual: nil, metadata: nil, risk_controls: nil, settings: nil, tos_acceptance: nil, type: nil) ⇒ AccountCreateParams
constructor
A new instance of AccountCreateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(account_token: nil, business_profile: nil, business_type: nil, capabilities: nil, company: nil, controller: nil, country: nil, default_currency: nil, documents: nil, email: nil, expand: nil, external_account: nil, groups: nil, individual: nil, metadata: nil, risk_controls: nil, settings: nil, tos_acceptance: nil, type: nil) ⇒ AccountCreateParams
Returns a new instance of AccountCreateParams.
2558 2559 2560 2561 2562 2563 2564 2565 2566 2567 2568 2569 2570 2571 2572 2573 2574 2575 2576 2577 2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 2594 2595 2596 2597 2598 |
# File 'lib/stripe/params/account_create_params.rb', line 2558 def initialize( account_token: nil, business_profile: nil, business_type: nil, capabilities: nil, company: nil, controller: nil, country: nil, default_currency: nil, documents: nil, email: nil, expand: nil, external_account: nil, groups: nil, individual: nil, metadata: nil, risk_controls: nil, settings: nil, tos_acceptance: nil, type: nil ) @account_token = account_token @business_profile = business_profile @business_type = business_type @capabilities = capabilities @company = company @controller = controller @country = country @default_currency = default_currency @documents = documents @email = email @expand = @external_account = external_account @groups = groups @individual = individual @metadata = @risk_controls = risk_controls @settings = settings @tos_acceptance = tos_acceptance @type = type end |
Instance Attribute Details
#account_token ⇒ Object
An [account token](api.stripe.com#create_account_token), used to securely provide details to the account.
2513 2514 2515 |
# File 'lib/stripe/params/account_create_params.rb', line 2513 def account_token @account_token end |
#business_profile ⇒ Object
Business information about the account.
2515 2516 2517 |
# File 'lib/stripe/params/account_create_params.rb', line 2515 def business_profile @business_profile end |
#business_type ⇒ Object
The business type. Once you create an [Account Link](/api/account_links) or [Account Session](/api/account_sessions), this property can only be updated for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is ‘application`, which includes Custom accounts.
2517 2518 2519 |
# File 'lib/stripe/params/account_create_params.rb', line 2517 def business_type @business_type end |
#capabilities ⇒ Object
Each key of the dictionary represents a capability, and each capability maps to its settings (for example, whether it has been requested or not). Each capability is inactive until you have provided its specific requirements and Stripe has verified them. An account might have some of its requested capabilities be active and some be inactive.
Required when [account.controller.stripe_dashboard.type](/api/accounts/create#create_account-controller-dashboard-type) is ‘none`, which includes Custom accounts.
2526 2527 2528 |
# File 'lib/stripe/params/account_create_params.rb', line 2526 def capabilities @capabilities end |
#company ⇒ Object
Information about the company or business. This field is available for any ‘business_type`. Once you create an [Account Link](/api/account_links) or [Account Session](/api/account_sessions), this property can only be updated for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is `application`, which includes Custom accounts.
2528 2529 2530 |
# File 'lib/stripe/params/account_create_params.rb', line 2528 def company @company end |
#controller ⇒ Object
A hash of configuration describing the account controller’s attributes.
2530 2531 2532 |
# File 'lib/stripe/params/account_create_params.rb', line 2530 def controller @controller end |
#country ⇒ Object
The country in which the account holder resides, or in which the business is legally established. This should be an ISO 3166-1 alpha-2 country code. For example, if you are in the United States and the business for which you’re creating an account is legally represented in Canada, you would use ‘CA` as the country for the account being created. Available countries include [Stripe’s global markets](stripe.com/global) as well as countries where [cross-border payouts](stripe.com/docs/connect/cross-border-payouts) are supported.
2532 2533 2534 |
# File 'lib/stripe/params/account_create_params.rb', line 2532 def country @country end |
#default_currency ⇒ Object
Three-letter ISO currency code representing the default currency for the account. This must be a currency that [Stripe supports in the account’s country](docs.stripe.com/payouts).
2534 2535 2536 |
# File 'lib/stripe/params/account_create_params.rb', line 2534 def default_currency @default_currency end |
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
2536 2537 2538 |
# File 'lib/stripe/params/account_create_params.rb', line 2536 def documents @documents end |
#email ⇒ Object
The email address of the account holder. This is only to make the account easier to identify to you. If [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is ‘application`, which includes Custom accounts, Stripe doesn’t email the account without your consent.
2538 2539 2540 |
# File 'lib/stripe/params/account_create_params.rb', line 2538 def email @email end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2540 2541 2542 |
# File 'lib/stripe/params/account_create_params.rb', line 2540 def @expand end |
#external_account ⇒ Object
A card or bank account to attach to the account for receiving [payouts](/connect/bank-debit-card-payouts) (you won’t be able to use it for top-ups). You can provide either a token, like the ones returned by [Stripe.js](/js), or a dictionary, as documented in the ‘external_account` parameter for [bank account](/api#account_create_bank_account) creation.
By default, providing an external account sets it as the new default external account for its currency, and deletes the old default if one exists. To add additional external accounts without replacing the existing default for the currency, use the [bank account](/api#account_create_bank_account) or [card creation](/api#account_create_card) APIs. After you create an [Account Link](/api/account_links) or [Account Session](/api/account_sessions), this property can only be updated for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is `application`, which includes Custom accounts.
2542 2543 2544 |
# File 'lib/stripe/params/account_create_params.rb', line 2542 def external_account @external_account end |
#groups ⇒ Object
A hash of account group type to tokens. These are account groups this account should be added to.
2544 2545 2546 |
# File 'lib/stripe/params/account_create_params.rb', line 2544 def groups @groups end |
#individual ⇒ Object
Information about the person represented by the account. This field is null unless ‘business_type` is set to `individual`. Once you create an [Account Link](/api/account_links) or [Account Session](/api/account_sessions), this property can only be updated for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is `application`, which includes Custom accounts.
2546 2547 2548 |
# File 'lib/stripe/params/account_create_params.rb', line 2546 def individual @individual end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
2548 2549 2550 |
# File 'lib/stripe/params/account_create_params.rb', line 2548 def @metadata end |
#risk_controls ⇒ Object
A hash to configure risk controls on the account. Please see [this page for more details](/connect/pausing-payments-or-payouts-on-connected-accounts).
2550 2551 2552 |
# File 'lib/stripe/params/account_create_params.rb', line 2550 def risk_controls @risk_controls end |
#settings ⇒ Object
Options for customizing how the account functions within Stripe.
2552 2553 2554 |
# File 'lib/stripe/params/account_create_params.rb', line 2552 def settings @settings end |
#tos_acceptance ⇒ Object
Details on the account’s acceptance of the [Stripe Services Agreement](/connect/updating-accounts#tos-acceptance). This property can only be updated for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is ‘application`, which includes Custom accounts. This property defaults to a `full` service agreement when empty.
2554 2555 2556 |
# File 'lib/stripe/params/account_create_params.rb', line 2554 def tos_acceptance @tos_acceptance end |
#type ⇒ Object
The ‘type` parameter is deprecated. Use [`controller`](/api/accounts/create#create_account-controller) instead to configure dashboard access, fee payer, loss liability, and requirement collection.
2556 2557 2558 |
# File 'lib/stripe/params/account_create_params.rb', line 2556 def type @type end |