Class: Stripe::AccountCreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/account_create_params.rb

Defined Under Namespace

Classes: BankAccount, BusinessProfile, Capabilities, Card, CardToken, Company, Controller, Documents, Groups, Individual, RiskControls, Settings, TosAcceptance

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_token: nil, business_profile: nil, business_type: nil, capabilities: nil, company: nil, controller: nil, country: nil, default_currency: nil, documents: nil, email: nil, expand: nil, external_account: nil, groups: nil, individual: nil, metadata: nil, risk_controls: nil, settings: nil, tos_acceptance: nil, type: nil) ⇒ AccountCreateParams

Returns a new instance of AccountCreateParams.



2408
2409
2410
2411
2412
2413
2414
2415
2416
2417
2418
2419
2420
2421
2422
2423
2424
2425
2426
2427
2428
2429
2430
2431
2432
2433
2434
2435
2436
2437
2438
2439
2440
2441
2442
2443
2444
2445
2446
2447
2448
# File 'lib/stripe/params/account_create_params.rb', line 2408

def initialize(
  account_token: nil,
  business_profile: nil,
  business_type: nil,
  capabilities: nil,
  company: nil,
  controller: nil,
  country: nil,
  default_currency: nil,
  documents: nil,
  email: nil,
  expand: nil,
  external_account: nil,
  groups: nil,
  individual: nil,
  metadata: nil,
  risk_controls: nil,
  settings: nil,
  tos_acceptance: nil,
  type: nil
)
  @account_token = 
  @business_profile = business_profile
  @business_type = business_type
  @capabilities = capabilities
  @company = company
  @controller = controller
  @country = country
  @default_currency = default_currency
  @documents = documents
  @email = email
  @expand = expand
  @external_account = 
  @groups = groups
  @individual = individual
  @metadata = 
  @risk_controls = risk_controls
  @settings = settings
  @tos_acceptance = tos_acceptance
  @type = type
end

Instance Attribute Details

#account_tokenObject

An [account token](stripe.com/docs/api#create_account_token), used to securely provide details to the account.



2363
2364
2365
# File 'lib/stripe/params/account_create_params.rb', line 2363

def 
  @account_token
end

#business_profileObject

Business information about the account.



2365
2366
2367
# File 'lib/stripe/params/account_create_params.rb', line 2365

def business_profile
  @business_profile
end

#business_typeObject

The business type. Once you create an [Account Link](/api/account_links) or [Account Session](/api/account_sessions), this property can only be updated for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is ‘application`, which includes Custom accounts.



2367
2368
2369
# File 'lib/stripe/params/account_create_params.rb', line 2367

def business_type
  @business_type
end

#capabilitiesObject

Each key of the dictionary represents a capability, and each capability maps to its settings (for example, whether it has been requested or not). Each capability is inactive until you have provided its specific requirements and Stripe has verified them. An account might have some of its requested capabilities be active and some be inactive.

Required when [account.controller.stripe_dashboard.type](/api/accounts/create#create_account-controller-dashboard-type) is ‘none`, which includes Custom accounts.



2376
2377
2378
# File 'lib/stripe/params/account_create_params.rb', line 2376

def capabilities
  @capabilities
end

#companyObject

Information about the company or business. This field is available for any ‘business_type`. Once you create an [Account Link](/api/account_links) or [Account Session](/api/account_sessions), this property can only be updated for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is `application`, which includes Custom accounts.



2378
2379
2380
# File 'lib/stripe/params/account_create_params.rb', line 2378

def company
  @company
end

#controllerObject

A hash of configuration describing the account controller’s attributes.



2380
2381
2382
# File 'lib/stripe/params/account_create_params.rb', line 2380

def controller
  @controller
end

#countryObject

The country in which the account holder resides, or in which the business is legally established. This should be an ISO 3166-1 alpha-2 country code. For example, if you are in the United States and the business for which you’re creating an account is legally represented in Canada, you would use ‘CA` as the country for the account being created. Available countries include [Stripe’s global markets](stripe.com/global) as well as countries where [cross-border payouts](stripe.com/docs/connect/cross-border-payouts) are supported.



2382
2383
2384
# File 'lib/stripe/params/account_create_params.rb', line 2382

def country
  @country
end

#default_currencyObject

Three-letter ISO currency code representing the default currency for the account. This must be a currency that [Stripe supports in the account’s country](docs.stripe.com/payouts).



2384
2385
2386
# File 'lib/stripe/params/account_create_params.rb', line 2384

def default_currency
  @default_currency
end

#documentsObject

Documents that may be submitted to satisfy various informational requests.



2386
2387
2388
# File 'lib/stripe/params/account_create_params.rb', line 2386

def documents
  @documents
end

#emailObject

The email address of the account holder. This is only to make the account easier to identify to you. If [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is ‘application`, which includes Custom accounts, Stripe doesn’t email the account without your consent.



2388
2389
2390
# File 'lib/stripe/params/account_create_params.rb', line 2388

def email
  @email
end

#expandObject

Specifies which fields in the response should be expanded.



2390
2391
2392
# File 'lib/stripe/params/account_create_params.rb', line 2390

def expand
  @expand
end

#external_accountObject

A card or bank account to attach to the account for receiving [payouts](/connect/bank-debit-card-payouts) (you won’t be able to use it for top-ups). You can provide either a token, like the ones returned by [Stripe.js](/js), or a dictionary, as documented in the ‘external_account` parameter for [bank account](/api#account_create_bank_account) creation.
By default, providing an external account sets it as the new default external account for its currency, and deletes the old default if one exists. To add additional external accounts without replacing the existing default for the currency, use the [bank account](/api#account_create_bank_account) or [card creation](/api#account_create_card) APIs. After you create an [Account Link](/api/account_links) or [Account Session](/api/account_sessions), this property can only be updated for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is `application`, which includes Custom accounts.



2392
2393
2394
# File 'lib/stripe/params/account_create_params.rb', line 2392

def 
  @external_account
end

#groupsObject

A hash of account group type to tokens. These are account groups this account should be added to.



2394
2395
2396
# File 'lib/stripe/params/account_create_params.rb', line 2394

def groups
  @groups
end

#individualObject

Information about the person represented by the account. This field is null unless ‘business_type` is set to `individual`. Once you create an [Account Link](/api/account_links) or [Account Session](/api/account_sessions), this property can only be updated for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is `application`, which includes Custom accounts.



2396
2397
2398
# File 'lib/stripe/params/account_create_params.rb', line 2396

def individual
  @individual
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2398
2399
2400
# File 'lib/stripe/params/account_create_params.rb', line 2398

def 
  @metadata
end

#risk_controlsObject

A hash to configure risk controls on the account. Please see [this page for more details](/connect/pausing-payments-or-payouts-on-connected-accounts).



2400
2401
2402
# File 'lib/stripe/params/account_create_params.rb', line 2400

def risk_controls
  @risk_controls
end

#settingsObject

Options for customizing how the account functions within Stripe.



2402
2403
2404
# File 'lib/stripe/params/account_create_params.rb', line 2402

def settings
  @settings
end

#tos_acceptanceObject

Details on the account’s acceptance of the [Stripe Services Agreement](/connect/updating-accounts#tos-acceptance). This property can only be updated for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is ‘application`, which includes Custom accounts. This property defaults to a `full` service agreement when empty.



2404
2405
2406
# File 'lib/stripe/params/account_create_params.rb', line 2404

def tos_acceptance
  @tos_acceptance
end

#typeObject

The type of Stripe account to create. May be one of ‘custom`, `express` or `standard`.



2406
2407
2408
# File 'lib/stripe/params/account_create_params.rb', line 2406

def type
  @type
end