Class: Stripe::AccountCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountCreateParams
- Defined in:
- lib/stripe/params/account_create_params.rb
Defined Under Namespace
Classes: BankAccount, BusinessProfile, Capabilities, Card, CardToken, Company, Controller, Documents, Groups, Individual, RiskControls, Settings, TosAcceptance
Instance Attribute Summary collapse
-
#account_token ⇒ Object
An [account token](stripe.com/docs/api#create_account_token), used to securely provide details to the account.
-
#business_profile ⇒ Object
Business information about the account.
-
#business_type ⇒ Object
The business type.
-
#capabilities ⇒ Object
Each key of the dictionary represents a capability, and each capability maps to its settings (for example, whether it has been requested or not).
-
#company ⇒ Object
Information about the company or business.
-
#controller ⇒ Object
A hash of configuration describing the account controller’s attributes.
-
#country ⇒ Object
The country in which the account holder resides, or in which the business is legally established.
-
#default_currency ⇒ Object
Three-letter ISO currency code representing the default currency for the account.
-
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
-
#email ⇒ Object
The email address of the account holder.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#external_account ⇒ Object
A card or bank account to attach to the account for receiving [payouts](/connect/bank-debit-card-payouts) (you won’t be able to use it for top-ups).
-
#groups ⇒ Object
A hash of account group type to tokens.
-
#individual ⇒ Object
Information about the person represented by the account.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#risk_controls ⇒ Object
A hash to configure risk controls on the account.
-
#settings ⇒ Object
Options for customizing how the account functions within Stripe.
-
#tos_acceptance ⇒ Object
Details on the account’s acceptance of the [Stripe Services Agreement](/connect/updating-accounts#tos-acceptance).
-
#type ⇒ Object
The type of Stripe account to create.
Instance Method Summary collapse
-
#initialize(account_token: nil, business_profile: nil, business_type: nil, capabilities: nil, company: nil, controller: nil, country: nil, default_currency: nil, documents: nil, email: nil, expand: nil, external_account: nil, groups: nil, individual: nil, metadata: nil, risk_controls: nil, settings: nil, tos_acceptance: nil, type: nil) ⇒ AccountCreateParams
constructor
A new instance of AccountCreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(account_token: nil, business_profile: nil, business_type: nil, capabilities: nil, company: nil, controller: nil, country: nil, default_currency: nil, documents: nil, email: nil, expand: nil, external_account: nil, groups: nil, individual: nil, metadata: nil, risk_controls: nil, settings: nil, tos_acceptance: nil, type: nil) ⇒ AccountCreateParams
Returns a new instance of AccountCreateParams.
2359 2360 2361 2362 2363 2364 2365 2366 2367 2368 2369 2370 2371 2372 2373 2374 2375 2376 2377 2378 2379 2380 2381 2382 2383 2384 2385 2386 2387 2388 2389 2390 2391 2392 2393 2394 2395 2396 2397 2398 2399 |
# File 'lib/stripe/params/account_create_params.rb', line 2359 def initialize( account_token: nil, business_profile: nil, business_type: nil, capabilities: nil, company: nil, controller: nil, country: nil, default_currency: nil, documents: nil, email: nil, expand: nil, external_account: nil, groups: nil, individual: nil, metadata: nil, risk_controls: nil, settings: nil, tos_acceptance: nil, type: nil ) @account_token = account_token @business_profile = business_profile @business_type = business_type @capabilities = capabilities @company = company @controller = controller @country = country @default_currency = default_currency @documents = documents @email = email @expand = @external_account = external_account @groups = groups @individual = individual @metadata = @risk_controls = risk_controls @settings = settings @tos_acceptance = tos_acceptance @type = type end |
Instance Attribute Details
#account_token ⇒ Object
An [account token](stripe.com/docs/api#create_account_token), used to securely provide details to the account.
2314 2315 2316 |
# File 'lib/stripe/params/account_create_params.rb', line 2314 def account_token @account_token end |
#business_profile ⇒ Object
Business information about the account.
2316 2317 2318 |
# File 'lib/stripe/params/account_create_params.rb', line 2316 def business_profile @business_profile end |
#business_type ⇒ Object
The business type. Once you create an [Account Link](/api/account_links) or [Account Session](/api/account_sessions), this property can only be updated for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is ‘application`, which includes Custom accounts.
2318 2319 2320 |
# File 'lib/stripe/params/account_create_params.rb', line 2318 def business_type @business_type end |
#capabilities ⇒ Object
Each key of the dictionary represents a capability, and each capability maps to its settings (for example, whether it has been requested or not). Each capability is inactive until you have provided its specific requirements and Stripe has verified them. An account might have some of its requested capabilities be active and some be inactive.
Required when [account.controller.stripe_dashboard.type](/api/accounts/create#create_account-controller-dashboard-type) is ‘none`, which includes Custom accounts.
2327 2328 2329 |
# File 'lib/stripe/params/account_create_params.rb', line 2327 def capabilities @capabilities end |
#company ⇒ Object
Information about the company or business. This field is available for any ‘business_type`. Once you create an [Account Link](/api/account_links) or [Account Session](/api/account_sessions), this property can only be updated for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is `application`, which includes Custom accounts.
2329 2330 2331 |
# File 'lib/stripe/params/account_create_params.rb', line 2329 def company @company end |
#controller ⇒ Object
A hash of configuration describing the account controller’s attributes.
2331 2332 2333 |
# File 'lib/stripe/params/account_create_params.rb', line 2331 def controller @controller end |
#country ⇒ Object
The country in which the account holder resides, or in which the business is legally established. This should be an ISO 3166-1 alpha-2 country code. For example, if you are in the United States and the business for which you’re creating an account is legally represented in Canada, you would use ‘CA` as the country for the account being created. Available countries include [Stripe’s global markets](stripe.com/global) as well as countries where [cross-border payouts](stripe.com/docs/connect/cross-border-payouts) are supported.
2333 2334 2335 |
# File 'lib/stripe/params/account_create_params.rb', line 2333 def country @country end |
#default_currency ⇒ Object
Three-letter ISO currency code representing the default currency for the account. This must be a currency that [Stripe supports in the account’s country](docs.stripe.com/payouts).
2335 2336 2337 |
# File 'lib/stripe/params/account_create_params.rb', line 2335 def default_currency @default_currency end |
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
2337 2338 2339 |
# File 'lib/stripe/params/account_create_params.rb', line 2337 def documents @documents end |
#email ⇒ Object
The email address of the account holder. This is only to make the account easier to identify to you. If [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is ‘application`, which includes Custom accounts, Stripe doesn’t email the account without your consent.
2339 2340 2341 |
# File 'lib/stripe/params/account_create_params.rb', line 2339 def email @email end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2341 2342 2343 |
# File 'lib/stripe/params/account_create_params.rb', line 2341 def @expand end |
#external_account ⇒ Object
A card or bank account to attach to the account for receiving [payouts](/connect/bank-debit-card-payouts) (you won’t be able to use it for top-ups). You can provide either a token, like the ones returned by [Stripe.js](/js), or a dictionary, as documented in the ‘external_account` parameter for [bank account](/api#account_create_bank_account) creation.
By default, providing an external account sets it as the new default external account for its currency, and deletes the old default if one exists. To add additional external accounts without replacing the existing default for the currency, use the [bank account](/api#account_create_bank_account) or [card creation](/api#account_create_card) APIs. After you create an [Account Link](/api/account_links) or [Account Session](/api/account_sessions), this property can only be updated for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is `application`, which includes Custom accounts.
2343 2344 2345 |
# File 'lib/stripe/params/account_create_params.rb', line 2343 def external_account @external_account end |
#groups ⇒ Object
A hash of account group type to tokens. These are account groups this account should be added to.
2345 2346 2347 |
# File 'lib/stripe/params/account_create_params.rb', line 2345 def groups @groups end |
#individual ⇒ Object
Information about the person represented by the account. This field is null unless ‘business_type` is set to `individual`. Once you create an [Account Link](/api/account_links) or [Account Session](/api/account_sessions), this property can only be updated for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is `application`, which includes Custom accounts.
2347 2348 2349 |
# File 'lib/stripe/params/account_create_params.rb', line 2347 def individual @individual end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
2349 2350 2351 |
# File 'lib/stripe/params/account_create_params.rb', line 2349 def @metadata end |
#risk_controls ⇒ Object
A hash to configure risk controls on the account. Please see [this page for more details](/connect/pausing-payments-or-payouts-on-connected-accounts).
2351 2352 2353 |
# File 'lib/stripe/params/account_create_params.rb', line 2351 def risk_controls @risk_controls end |
#settings ⇒ Object
Options for customizing how the account functions within Stripe.
2353 2354 2355 |
# File 'lib/stripe/params/account_create_params.rb', line 2353 def settings @settings end |
#tos_acceptance ⇒ Object
Details on the account’s acceptance of the [Stripe Services Agreement](/connect/updating-accounts#tos-acceptance). This property can only be updated for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is ‘application`, which includes Custom accounts. This property defaults to a `full` service agreement when empty.
2355 2356 2357 |
# File 'lib/stripe/params/account_create_params.rb', line 2355 def tos_acceptance @tos_acceptance end |
#type ⇒ Object
The type of Stripe account to create. May be one of ‘custom`, `express` or `standard`.
2357 2358 2359 |
# File 'lib/stripe/params/account_create_params.rb', line 2357 def type @type end |