Class: Stripe::AccountCreateParams::Capabilities::CardPayments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(requested: nil) ⇒ CardPayments

Returns a new instance of CardPayments.



297
298
299
# File 'lib/stripe/params/account_create_params.rb', line 297

def initialize(requested: nil)
  @requested = requested
end

Instance Attribute Details

#requestedObject

Passing true requests the capability for the account, if it is not already requested. A requested capability may not immediately become active. Any requirements to activate the capability are returned in the ‘requirements` arrays.



295
296
297
# File 'lib/stripe/params/account_create_params.rb', line 295

def requested
  @requested
end