Class: Stripe::AccountCreateParams::Company

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/account_create_params.rb

Defined Under Namespace

Classes: Address, AddressKana, AddressKanji, AdministrativeAddress, DirectorshipDeclaration, OwnershipDeclaration, PrincipalPlaceOfBusiness, RegistrationDate, RepresentativeDeclaration, Verification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(address: nil, address_kana: nil, address_kanji: nil, administrative_address: nil, directors_provided: nil, directorship_declaration: nil, executives_provided: nil, export_license_id: nil, export_purpose_code: nil, name: nil, name_kana: nil, name_kanji: nil, owners_provided: nil, ownership_declaration: nil, ownership_exemption_reason: nil, phone: nil, principal_place_of_business: nil, registration_date: nil, registration_number: nil, representative_declaration: nil, structure: nil, tax_id: nil, tax_id_registrar: nil, vat_id: nil, verification: nil) ⇒ Company

Returns a new instance of Company.



1587
1588
1589
1590
1591
1592
1593
1594
1595
1596
1597
1598
1599
1600
1601
1602
1603
1604
1605
1606
1607
1608
1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
1626
1627
1628
1629
1630
1631
1632
1633
1634
1635
1636
1637
1638
1639
# File 'lib/stripe/params/account_create_params.rb', line 1587

def initialize(
  address: nil,
  address_kana: nil,
  address_kanji: nil,
  administrative_address: nil,
  directors_provided: nil,
  directorship_declaration: nil,
  executives_provided: nil,
  export_license_id: nil,
  export_purpose_code: nil,
  name: nil,
  name_kana: nil,
  name_kanji: nil,
  owners_provided: nil,
  ownership_declaration: nil,
  ownership_exemption_reason: nil,
  phone: nil,
  principal_place_of_business: nil,
  registration_date: nil,
  registration_number: nil,
  representative_declaration: nil,
  structure: nil,
  tax_id: nil,
  tax_id_registrar: nil,
  vat_id: nil,
  verification: nil
)
  @address = address
  @address_kana = address_kana
  @address_kanji = address_kanji
  @administrative_address = administrative_address
  @directors_provided = directors_provided
  @directorship_declaration = directorship_declaration
  @executives_provided = executives_provided
  @export_license_id = export_license_id
  @export_purpose_code = export_purpose_code
  @name = name
  @name_kana = name_kana
  @name_kanji = name_kanji
  @owners_provided = owners_provided
  @ownership_declaration = ownership_declaration
  @ownership_exemption_reason = ownership_exemption_reason
  @phone = phone
  @principal_place_of_business = principal_place_of_business
  @registration_date = registration_date
  @registration_number = registration_number
  @representative_declaration = representative_declaration
  @structure = structure
  @tax_id = tax_id
  @tax_id_registrar = tax_id_registrar
  @vat_id = vat_id
  @verification = verification
end

Instance Attribute Details

#addressObject

The company's primary address.



1535
1536
1537
# File 'lib/stripe/params/account_create_params.rb', line 1535

def address
  @address
end

#address_kanaObject

The Kana variation of the company's primary address (Japan only).



1537
1538
1539
# File 'lib/stripe/params/account_create_params.rb', line 1537

def address_kana
  @address_kana
end

#address_kanjiObject

The Kanji variation of the company's primary address (Japan only).



1539
1540
1541
# File 'lib/stripe/params/account_create_params.rb', line 1539

def address_kanji
  @address_kanji
end

#administrative_addressObject

The location where the business is administered.



1541
1542
1543
# File 'lib/stripe/params/account_create_params.rb', line 1541

def administrative_address
  @administrative_address
end

#directors_providedObject

Whether the company's directors have been provided. Set this Boolean to true after creating all the company's directors with the Persons API for accounts with a relationship.director requirement. This value is not automatically set to true after creating directors, so it needs to be updated to indicate all directors have been provided.



1543
1544
1545
# File 'lib/stripe/params/account_create_params.rb', line 1543

def directors_provided
  @directors_provided
end

#directorship_declarationObject

This hash is used to attest that the directors information provided to Stripe is both current and correct.



1545
1546
1547
# File 'lib/stripe/params/account_create_params.rb', line 1545

def directorship_declaration
  @directorship_declaration
end

#executives_providedObject

Whether the company's executives have been provided. Set this Boolean to true after creating all the company's executives with the Persons API for accounts with a relationship.executive requirement.



1547
1548
1549
# File 'lib/stripe/params/account_create_params.rb', line 1547

def executives_provided
  @executives_provided
end

#export_license_idObject

The export license ID number of the company, also referred as Import Export Code (India only).



1549
1550
1551
# File 'lib/stripe/params/account_create_params.rb', line 1549

def export_license_id
  @export_license_id
end

#export_purpose_codeObject

The purpose code to use for export transactions (India only).



1551
1552
1553
# File 'lib/stripe/params/account_create_params.rb', line 1551

def export_purpose_code
  @export_purpose_code
end

#nameObject

The company's legal name.



1553
1554
1555
# File 'lib/stripe/params/account_create_params.rb', line 1553

def name
  @name
end

#name_kanaObject

The Kana variation of the company's legal name (Japan only).



1555
1556
1557
# File 'lib/stripe/params/account_create_params.rb', line 1555

def name_kana
  @name_kana
end

#name_kanjiObject

The Kanji variation of the company's legal name (Japan only).



1557
1558
1559
# File 'lib/stripe/params/account_create_params.rb', line 1557

def name_kanji
  @name_kanji
end

#owners_providedObject

Whether the company's owners have been provided. Set this Boolean to true after creating all the company's owners with the Persons API for accounts with a relationship.owner requirement.



1559
1560
1561
# File 'lib/stripe/params/account_create_params.rb', line 1559

def owners_provided
  @owners_provided
end

#ownership_declarationObject

This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.



1561
1562
1563
# File 'lib/stripe/params/account_create_params.rb', line 1561

def ownership_declaration
  @ownership_declaration
end

#ownership_exemption_reasonObject

This value is used to determine if a business is exempt from providing ultimate beneficial owners. See this support article and changelog for more details.



1563
1564
1565
# File 'lib/stripe/params/account_create_params.rb', line 1563

def ownership_exemption_reason
  @ownership_exemption_reason
end

#phoneObject

The company's phone number (used for verification).



1565
1566
1567
# File 'lib/stripe/params/account_create_params.rb', line 1565

def phone
  @phone
end

#principal_place_of_businessObject

The primary location where the business conducts operations.



1567
1568
1569
# File 'lib/stripe/params/account_create_params.rb', line 1567

def principal_place_of_business
  @principal_place_of_business
end

#registration_dateObject

When the business was incorporated or registered.



1569
1570
1571
# File 'lib/stripe/params/account_create_params.rb', line 1569

def registration_date
  @registration_date
end

#registration_numberObject

The identification number given to a company when it is registered or incorporated, if distinct from the identification number used for filing taxes. (Examples are the CIN for companies and LLP IN for partnerships in India, and the Company Registration Number in Hong Kong).



1571
1572
1573
# File 'lib/stripe/params/account_create_params.rb', line 1571

def registration_number
  @registration_number
end

#representative_declarationObject

This hash is used to attest that the representative is authorized to act as the representative of their legal entity.



1573
1574
1575
# File 'lib/stripe/params/account_create_params.rb', line 1573

def representative_declaration
  @representative_declaration
end

#structureObject

The category identifying the legal structure of the company or legal entity. See Business structure for more details. Pass an empty string to unset this value.



1575
1576
1577
# File 'lib/stripe/params/account_create_params.rb', line 1575

def structure
  @structure
end

#tax_idObject

The business ID number of the company, as appropriate for the company’s country. (Examples are an Employer ID Number in the U.S., a Business Number in Canada, or a Company Number in the UK.)

Changing this value requires that the account re-accept the terms of service.



1579
1580
1581
# File 'lib/stripe/params/account_create_params.rb', line 1579

def tax_id
  @tax_id
end

#tax_id_registrarObject

The jurisdiction in which the tax_id is registered (Germany-based companies only).



1581
1582
1583
# File 'lib/stripe/params/account_create_params.rb', line 1581

def tax_id_registrar
  @tax_id_registrar
end

#vat_idObject

The VAT number of the company.



1583
1584
1585
# File 'lib/stripe/params/account_create_params.rb', line 1583

def vat_id
  @vat_id
end

#verificationObject

Information on the verification state of the company.



1585
1586
1587
# File 'lib/stripe/params/account_create_params.rb', line 1585

def verification
  @verification
end