Class: Stripe::AccountCreateParams::Company
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountCreateParams::Company
- Defined in:
- lib/stripe/params/account_create_params.rb
Defined Under Namespace
Classes: Address, AddressKana, AddressKanji, AdministrativeAddress, DirectorshipDeclaration, OwnershipDeclaration, PrincipalPlaceOfBusiness, RegistrationDate, RepresentativeDeclaration, Verification
Instance Attribute Summary collapse
-
#address ⇒ Object
The company's primary address.
-
#address_kana ⇒ Object
The Kana variation of the company's primary address (Japan only).
-
#address_kanji ⇒ Object
The Kanji variation of the company's primary address (Japan only).
-
#administrative_address ⇒ Object
Attribute for param field administrative_address.
-
#directors_provided ⇒ Object
Whether the company's directors have been provided.
-
#directorship_declaration ⇒ Object
This hash is used to attest that the directors information provided to Stripe is both current and correct.
-
#executives_provided ⇒ Object
Whether the company's executives have been provided.
-
#export_license_id ⇒ Object
The export license ID number of the company, also referred as Import Export Code (India only).
-
#export_purpose_code ⇒ Object
The purpose code to use for export transactions (India only).
-
#name ⇒ Object
The company's legal name.
-
#name_kana ⇒ Object
The Kana variation of the company's legal name (Japan only).
-
#name_kanji ⇒ Object
The Kanji variation of the company's legal name (Japan only).
-
#owners_provided ⇒ Object
Whether the company's owners have been provided.
-
#ownership_declaration ⇒ Object
This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.
-
#ownership_exemption_reason ⇒ Object
This value is used to determine if a business is exempt from providing ultimate beneficial owners.
-
#phone ⇒ Object
The company's phone number (used for verification).
-
#principal_place_of_business ⇒ Object
Attribute for param field principal_place_of_business.
-
#registration_date ⇒ Object
When the business was incorporated or registered.
-
#registration_number ⇒ Object
The identification number given to a company when it is registered or incorporated, if distinct from the identification number used for filing taxes.
-
#representative_declaration ⇒ Object
This hash is used to attest that the representative is authorized to act as the representative of their legal entity.
-
#structure ⇒ Object
The category identifying the legal structure of the company or legal entity.
-
#tax_id ⇒ Object
The business ID number of the company, as appropriate for the company’s country.
-
#tax_id_registrar ⇒ Object
The jurisdiction in which the
tax_idis registered (Germany-based companies only). -
#vat_id ⇒ Object
The VAT number of the company.
-
#verification ⇒ Object
Information on the verification state of the company.
Instance Method Summary collapse
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(address: nil, address_kana: nil, address_kanji: nil, administrative_address: nil, directors_provided: nil, directorship_declaration: nil, executives_provided: nil, export_license_id: nil, export_purpose_code: nil, name: nil, name_kana: nil, name_kanji: nil, owners_provided: nil, ownership_declaration: nil, ownership_exemption_reason: nil, phone: nil, principal_place_of_business: nil, registration_date: nil, registration_number: nil, representative_declaration: nil, structure: nil, tax_id: nil, tax_id_registrar: nil, vat_id: nil, verification: nil) ⇒ Company
Returns a new instance of Company.
1568 1569 1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 1584 1585 1586 1587 1588 1589 1590 1591 1592 1593 1594 1595 1596 1597 1598 1599 1600 1601 1602 1603 1604 1605 1606 1607 1608 1609 1610 1611 1612 1613 1614 1615 1616 1617 1618 1619 1620 |
# File 'lib/stripe/params/account_create_params.rb', line 1568 def initialize( address: nil, address_kana: nil, address_kanji: nil, administrative_address: nil, directors_provided: nil, directorship_declaration: nil, executives_provided: nil, export_license_id: nil, export_purpose_code: nil, name: nil, name_kana: nil, name_kanji: nil, owners_provided: nil, ownership_declaration: nil, ownership_exemption_reason: nil, phone: nil, principal_place_of_business: nil, registration_date: nil, registration_number: nil, representative_declaration: nil, structure: nil, tax_id: nil, tax_id_registrar: nil, vat_id: nil, verification: nil ) @address = address @address_kana = address_kana @address_kanji = address_kanji @administrative_address = administrative_address @directors_provided = directors_provided @directorship_declaration = directorship_declaration @executives_provided = executives_provided @export_license_id = export_license_id @export_purpose_code = export_purpose_code @name = name @name_kana = name_kana @name_kanji = name_kanji @owners_provided = owners_provided @ownership_declaration = ownership_declaration @ownership_exemption_reason = ownership_exemption_reason @phone = phone @principal_place_of_business = principal_place_of_business @registration_date = registration_date @registration_number = registration_number @representative_declaration = representative_declaration @structure = structure @tax_id = tax_id @tax_id_registrar = tax_id_registrar @vat_id = vat_id @verification = verification end |
Instance Attribute Details
#address ⇒ Object
The company's primary address.
1516 1517 1518 |
# File 'lib/stripe/params/account_create_params.rb', line 1516 def address @address end |
#address_kana ⇒ Object
The Kana variation of the company's primary address (Japan only).
1518 1519 1520 |
# File 'lib/stripe/params/account_create_params.rb', line 1518 def address_kana @address_kana end |
#address_kanji ⇒ Object
The Kanji variation of the company's primary address (Japan only).
1520 1521 1522 |
# File 'lib/stripe/params/account_create_params.rb', line 1520 def address_kanji @address_kanji end |
#administrative_address ⇒ Object
Attribute for param field administrative_address
1522 1523 1524 |
# File 'lib/stripe/params/account_create_params.rb', line 1522 def administrative_address @administrative_address end |
#directors_provided ⇒ Object
Whether the company's directors have been provided. Set this Boolean to true after creating all the company's directors with the Persons API for accounts with a relationship.director requirement. This value is not automatically set to true after creating directors, so it needs to be updated to indicate all directors have been provided.
1524 1525 1526 |
# File 'lib/stripe/params/account_create_params.rb', line 1524 def directors_provided @directors_provided end |
#directorship_declaration ⇒ Object
This hash is used to attest that the directors information provided to Stripe is both current and correct.
1526 1527 1528 |
# File 'lib/stripe/params/account_create_params.rb', line 1526 def directorship_declaration @directorship_declaration end |
#executives_provided ⇒ Object
Whether the company's executives have been provided. Set this Boolean to true after creating all the company's executives with the Persons API for accounts with a relationship.executive requirement.
1528 1529 1530 |
# File 'lib/stripe/params/account_create_params.rb', line 1528 def executives_provided @executives_provided end |
#export_license_id ⇒ Object
The export license ID number of the company, also referred as Import Export Code (India only).
1530 1531 1532 |
# File 'lib/stripe/params/account_create_params.rb', line 1530 def export_license_id @export_license_id end |
#export_purpose_code ⇒ Object
The purpose code to use for export transactions (India only).
1532 1533 1534 |
# File 'lib/stripe/params/account_create_params.rb', line 1532 def export_purpose_code @export_purpose_code end |
#name ⇒ Object
The company's legal name.
1534 1535 1536 |
# File 'lib/stripe/params/account_create_params.rb', line 1534 def name @name end |
#name_kana ⇒ Object
The Kana variation of the company's legal name (Japan only).
1536 1537 1538 |
# File 'lib/stripe/params/account_create_params.rb', line 1536 def name_kana @name_kana end |
#name_kanji ⇒ Object
The Kanji variation of the company's legal name (Japan only).
1538 1539 1540 |
# File 'lib/stripe/params/account_create_params.rb', line 1538 def name_kanji @name_kanji end |
#owners_provided ⇒ Object
Whether the company's owners have been provided. Set this Boolean to true after creating all the company's owners with the Persons API for accounts with a relationship.owner requirement.
1540 1541 1542 |
# File 'lib/stripe/params/account_create_params.rb', line 1540 def owners_provided @owners_provided end |
#ownership_declaration ⇒ Object
This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.
1542 1543 1544 |
# File 'lib/stripe/params/account_create_params.rb', line 1542 def ownership_declaration @ownership_declaration end |
#ownership_exemption_reason ⇒ Object
This value is used to determine if a business is exempt from providing ultimate beneficial owners. See this support article and changelog for more details.
1544 1545 1546 |
# File 'lib/stripe/params/account_create_params.rb', line 1544 def ownership_exemption_reason @ownership_exemption_reason end |
#phone ⇒ Object
The company's phone number (used for verification).
1546 1547 1548 |
# File 'lib/stripe/params/account_create_params.rb', line 1546 def phone @phone end |
#principal_place_of_business ⇒ Object
Attribute for param field principal_place_of_business
1548 1549 1550 |
# File 'lib/stripe/params/account_create_params.rb', line 1548 def principal_place_of_business @principal_place_of_business end |
#registration_date ⇒ Object
When the business was incorporated or registered.
1550 1551 1552 |
# File 'lib/stripe/params/account_create_params.rb', line 1550 def registration_date @registration_date end |
#registration_number ⇒ Object
The identification number given to a company when it is registered or incorporated, if distinct from the identification number used for filing taxes. (Examples are the CIN for companies and LLP IN for partnerships in India, and the Company Registration Number in Hong Kong).
1552 1553 1554 |
# File 'lib/stripe/params/account_create_params.rb', line 1552 def registration_number @registration_number end |
#representative_declaration ⇒ Object
This hash is used to attest that the representative is authorized to act as the representative of their legal entity.
1554 1555 1556 |
# File 'lib/stripe/params/account_create_params.rb', line 1554 def representative_declaration @representative_declaration end |
#structure ⇒ Object
The category identifying the legal structure of the company or legal entity. See Business structure for more details. Pass an empty string to unset this value.
1556 1557 1558 |
# File 'lib/stripe/params/account_create_params.rb', line 1556 def structure @structure end |
#tax_id ⇒ Object
The business ID number of the company, as appropriate for the company’s country. (Examples are an Employer ID Number in the U.S., a Business Number in Canada, or a Company Number in the UK.)
Changing this value requires that the account re-accept the terms of service.
1560 1561 1562 |
# File 'lib/stripe/params/account_create_params.rb', line 1560 def tax_id @tax_id end |
#tax_id_registrar ⇒ Object
The jurisdiction in which the tax_id is registered (Germany-based companies only).
1562 1563 1564 |
# File 'lib/stripe/params/account_create_params.rb', line 1562 def tax_id_registrar @tax_id_registrar end |
#vat_id ⇒ Object
The VAT number of the company.
1564 1565 1566 |
# File 'lib/stripe/params/account_create_params.rb', line 1564 def vat_id @vat_id end |
#verification ⇒ Object
Information on the verification state of the company.
1566 1567 1568 |
# File 'lib/stripe/params/account_create_params.rb', line 1566 def verification @verification end |