Class: Stripe::AccountCreateParams::Company::DirectorshipDeclaration
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountCreateParams::Company::DirectorshipDeclaration
- Defined in:
- lib/stripe/params/account_create_params.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the directorship declaration attestation was made.
-
#ip ⇒ Object
The IP address from which the directorship declaration attestation was made.
-
#user_agent ⇒ Object
The user agent of the browser from which the directorship declaration attestation was made.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ DirectorshipDeclaration
constructor
A new instance of DirectorshipDeclaration.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ DirectorshipDeclaration
Returns a new instance of DirectorshipDeclaration.
1382 1383 1384 1385 1386 |
# File 'lib/stripe/params/account_create_params.rb', line 1382 def initialize(date: nil, ip: nil, user_agent: nil) @date = date @ip = ip @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the directorship declaration attestation was made.
1376 1377 1378 |
# File 'lib/stripe/params/account_create_params.rb', line 1376 def date @date end |
#ip ⇒ Object
The IP address from which the directorship declaration attestation was made.
1378 1379 1380 |
# File 'lib/stripe/params/account_create_params.rb', line 1378 def ip @ip end |
#user_agent ⇒ Object
The user agent of the browser from which the directorship declaration attestation was made.
1380 1381 1382 |
# File 'lib/stripe/params/account_create_params.rb', line 1380 def user_agent @user_agent end |