Class: Stripe::AccountCreateParams::Company::DirectorshipDeclaration
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountCreateParams::Company::DirectorshipDeclaration
- Defined in:
- lib/stripe/params/account_create_params.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the directorship declaration attestation was made.
-
#ip ⇒ Object
The IP address from which the directorship declaration attestation was made.
-
#user_agent ⇒ Object
The user agent of the browser from which the directorship declaration attestation was made.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ DirectorshipDeclaration
constructor
A new instance of DirectorshipDeclaration.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ DirectorshipDeclaration
Returns a new instance of DirectorshipDeclaration.
1330 1331 1332 1333 1334 |
# File 'lib/stripe/params/account_create_params.rb', line 1330 def initialize(date: nil, ip: nil, user_agent: nil) @date = date @ip = ip @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the directorship declaration attestation was made.
1324 1325 1326 |
# File 'lib/stripe/params/account_create_params.rb', line 1324 def date @date end |
#ip ⇒ Object
The IP address from which the directorship declaration attestation was made.
1326 1327 1328 |
# File 'lib/stripe/params/account_create_params.rb', line 1326 def ip @ip end |
#user_agent ⇒ Object
The user agent of the browser from which the directorship declaration attestation was made.
1328 1329 1330 |
# File 'lib/stripe/params/account_create_params.rb', line 1328 def user_agent @user_agent end |