Class: Stripe::AccountCreateParams::Company::DirectorshipDeclaration
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountCreateParams::Company::DirectorshipDeclaration
- Defined in:
- lib/stripe/params/account_create_params.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the directorship declaration attestation was made.
-
#ip ⇒ Object
The IP address from which the directorship declaration attestation was made.
-
#user_agent ⇒ Object
The user agent of the browser from which the directorship declaration attestation was made.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ DirectorshipDeclaration
constructor
A new instance of DirectorshipDeclaration.
Methods inherited from RequestParams
Constructor Details
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ DirectorshipDeclaration
Returns a new instance of DirectorshipDeclaration.
1313 1314 1315 1316 1317 |
# File 'lib/stripe/params/account_create_params.rb', line 1313 def initialize(date: nil, ip: nil, user_agent: nil) @date = date @ip = ip @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the directorship declaration attestation was made.
1307 1308 1309 |
# File 'lib/stripe/params/account_create_params.rb', line 1307 def date @date end |
#ip ⇒ Object
The IP address from which the directorship declaration attestation was made.
1309 1310 1311 |
# File 'lib/stripe/params/account_create_params.rb', line 1309 def ip @ip end |
#user_agent ⇒ Object
The user agent of the browser from which the directorship declaration attestation was made.
1311 1312 1313 |
# File 'lib/stripe/params/account_create_params.rb', line 1311 def user_agent @user_agent end |