Class: Stripe::AccountCreateParams::Company::OwnershipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ OwnershipDeclaration

Returns a new instance of OwnershipDeclaration.



1416
1417
1418
1419
1420
# File 'lib/stripe/params/account_create_params.rb', line 1416

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the beneficial owner attestation was made.



1410
1411
1412
# File 'lib/stripe/params/account_create_params.rb', line 1410

def date
  @date
end

#ipObject

The IP address from which the beneficial owner attestation was made.



1412
1413
1414
# File 'lib/stripe/params/account_create_params.rb', line 1412

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the beneficial owner attestation was made.



1414
1415
1416
# File 'lib/stripe/params/account_create_params.rb', line 1414

def user_agent
  @user_agent
end