Class: Stripe::AccountCreateParams::Company::RepresentativeDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ RepresentativeDeclaration

Returns a new instance of RepresentativeDeclaration.



1401
1402
1403
1404
1405
# File 'lib/stripe/params/account_create_params.rb', line 1401

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the representative declaration attestation was made.



1395
1396
1397
# File 'lib/stripe/params/account_create_params.rb', line 1395

def date
  @date
end

#ipObject

The IP address from which the representative declaration attestation was made.



1397
1398
1399
# File 'lib/stripe/params/account_create_params.rb', line 1397

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the representative declaration attestation was made.



1399
1400
1401
# File 'lib/stripe/params/account_create_params.rb', line 1399

def user_agent
  @user_agent
end