Class: Stripe::AccountCreateParams::Company::RepresentativeDeclaration
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountCreateParams::Company::RepresentativeDeclaration
- Defined in:
- lib/stripe/params/account_create_params.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the representative declaration attestation was made.
-
#ip ⇒ Object
The IP address from which the representative declaration attestation was made.
-
#user_agent ⇒ Object
The user agent of the browser from which the representative declaration attestation was made.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ RepresentativeDeclaration
constructor
A new instance of RepresentativeDeclaration.
Methods inherited from RequestParams
Constructor Details
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ RepresentativeDeclaration
Returns a new instance of RepresentativeDeclaration.
1358 1359 1360 1361 1362 |
# File 'lib/stripe/params/account_create_params.rb', line 1358 def initialize(date: nil, ip: nil, user_agent: nil) @date = date @ip = ip @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the representative declaration attestation was made.
1352 1353 1354 |
# File 'lib/stripe/params/account_create_params.rb', line 1352 def date @date end |
#ip ⇒ Object
The IP address from which the representative declaration attestation was made.
1354 1355 1356 |
# File 'lib/stripe/params/account_create_params.rb', line 1354 def ip @ip end |
#user_agent ⇒ Object
The user agent of the browser from which the representative declaration attestation was made.
1356 1357 1358 |
# File 'lib/stripe/params/account_create_params.rb', line 1356 def user_agent @user_agent end |