Class: Stripe::AccountCreateParams::Controller

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/account_create_params.rb

Defined Under Namespace

Classes: Application, Dashboard, Fees, Losses, StripeDashboard

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(application: nil, dashboard: nil, fees: nil, losses: nil, requirement_collection: nil, stripe_dashboard: nil) ⇒ Controller

Returns a new instance of Controller.



1687
1688
1689
1690
1691
1692
1693
1694
1695
1696
1697
1698
1699
1700
1701
# File 'lib/stripe/params/account_create_params.rb', line 1687

def initialize(
  application: nil,
  dashboard: nil,
  fees: nil,
  losses: nil,
  requirement_collection: nil,
  stripe_dashboard: nil
)
  @application = application
  @dashboard = dashboard
  @fees = fees
  @losses = losses
  @requirement_collection = requirement_collection
  @stripe_dashboard = stripe_dashboard
end

Instance Attribute Details

#applicationObject

A hash of configuration describing the Connect application that controls the account.



1675
1676
1677
# File 'lib/stripe/params/account_create_params.rb', line 1675

def application
  @application
end

#dashboardObject

Properties of the account's dashboard.



1677
1678
1679
# File 'lib/stripe/params/account_create_params.rb', line 1677

def dashboard
  @dashboard
end

#feesObject

A hash of configuration for who pays Stripe fees for product usage on this account.



1679
1680
1681
# File 'lib/stripe/params/account_create_params.rb', line 1679

def fees
  @fees
end

#lossesObject

A hash of configuration for products that have negative balance liability, and whether Stripe or a Connect application is responsible for them.



1681
1682
1683
# File 'lib/stripe/params/account_create_params.rb', line 1681

def losses
  @losses
end

#requirement_collectionObject

A value indicating responsibility for collecting updated information when requirements on the account are due or change. Defaults to stripe.



1683
1684
1685
# File 'lib/stripe/params/account_create_params.rb', line 1683

def requirement_collection
  @requirement_collection
end

#stripe_dashboardObject

A hash of configuration for Stripe-hosted dashboards.



1685
1686
1687
# File 'lib/stripe/params/account_create_params.rb', line 1685

def stripe_dashboard
  @stripe_dashboard
end