Class: Stripe::AccountCreateParams::Controller
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountCreateParams::Controller
- Defined in:
- lib/stripe/params/account_create_params.rb
Defined Under Namespace
Classes: Application, Dashboard, Fees, Losses, StripeDashboard
Instance Attribute Summary collapse
-
#application ⇒ Object
A hash of configuration describing the Connect application that controls the account.
-
#dashboard ⇒ Object
Properties of the account’s dashboard.
-
#fees ⇒ Object
A hash of configuration for who pays Stripe fees for product usage on this account.
-
#losses ⇒ Object
A hash of configuration for products that have negative balance liability, and whether Stripe or a Connect application is responsible for them.
-
#requirement_collection ⇒ Object
A value indicating responsibility for collecting updated information when requirements on the account are due or change.
-
#stripe_dashboard ⇒ Object
A hash of configuration for Stripe-hosted dashboards.
Instance Method Summary collapse
-
#initialize(application: nil, dashboard: nil, fees: nil, losses: nil, requirement_collection: nil, stripe_dashboard: nil) ⇒ Controller
constructor
A new instance of Controller.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(application: nil, dashboard: nil, fees: nil, losses: nil, requirement_collection: nil, stripe_dashboard: nil) ⇒ Controller
Returns a new instance of Controller.
1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 1647 1648 |
# File 'lib/stripe/params/account_create_params.rb', line 1634 def initialize( application: nil, dashboard: nil, fees: nil, losses: nil, requirement_collection: nil, stripe_dashboard: nil ) @application = application @dashboard = dashboard @fees = fees @losses = losses @requirement_collection = requirement_collection @stripe_dashboard = stripe_dashboard end |
Instance Attribute Details
#application ⇒ Object
A hash of configuration describing the Connect application that controls the account.
1622 1623 1624 |
# File 'lib/stripe/params/account_create_params.rb', line 1622 def application @application end |
#dashboard ⇒ Object
Properties of the account’s dashboard.
1624 1625 1626 |
# File 'lib/stripe/params/account_create_params.rb', line 1624 def dashboard @dashboard end |
#fees ⇒ Object
A hash of configuration for who pays Stripe fees for product usage on this account.
1626 1627 1628 |
# File 'lib/stripe/params/account_create_params.rb', line 1626 def fees @fees end |
#losses ⇒ Object
A hash of configuration for products that have negative balance liability, and whether Stripe or a Connect application is responsible for them.
1628 1629 1630 |
# File 'lib/stripe/params/account_create_params.rb', line 1628 def losses @losses end |
#requirement_collection ⇒ Object
A value indicating responsibility for collecting updated information when requirements on the account are due or change. Defaults to ‘stripe`.
1630 1631 1632 |
# File 'lib/stripe/params/account_create_params.rb', line 1630 def requirement_collection @requirement_collection end |
#stripe_dashboard ⇒ Object
A hash of configuration for Stripe-hosted dashboards.
1632 1633 1634 |
# File 'lib/stripe/params/account_create_params.rb', line 1632 def stripe_dashboard @stripe_dashboard end |