Class: Stripe::AccountCreateParams::Controller

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/account_create_params.rb

Defined Under Namespace

Classes: Application, Dashboard, Fees, Losses, StripeDashboard

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(application: nil, dashboard: nil, fees: nil, losses: nil, requirement_collection: nil, stripe_dashboard: nil) ⇒ Controller

Returns a new instance of Controller.



1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
1626
1627
1628
1629
# File 'lib/stripe/params/account_create_params.rb', line 1615

def initialize(
  application: nil,
  dashboard: nil,
  fees: nil,
  losses: nil,
  requirement_collection: nil,
  stripe_dashboard: nil
)
  @application = application
  @dashboard = dashboard
  @fees = fees
  @losses = losses
  @requirement_collection = requirement_collection
  @stripe_dashboard = stripe_dashboard
end

Instance Attribute Details

#applicationObject

A hash of configuration describing the Connect application that controls the account.



1603
1604
1605
# File 'lib/stripe/params/account_create_params.rb', line 1603

def application
  @application
end

#dashboardObject

Properties of the account’s dashboard.



1605
1606
1607
# File 'lib/stripe/params/account_create_params.rb', line 1605

def dashboard
  @dashboard
end

#feesObject

A hash of configuration for who pays Stripe fees for product usage on this account.



1607
1608
1609
# File 'lib/stripe/params/account_create_params.rb', line 1607

def fees
  @fees
end

#lossesObject

A hash of configuration for products that have negative balance liability, and whether Stripe or a Connect application is responsible for them.



1609
1610
1611
# File 'lib/stripe/params/account_create_params.rb', line 1609

def losses
  @losses
end

#requirement_collectionObject

A value indicating responsibility for collecting updated information when requirements on the account are due or change. Defaults to ‘stripe`.



1611
1612
1613
# File 'lib/stripe/params/account_create_params.rb', line 1611

def requirement_collection
  @requirement_collection
end

#stripe_dashboardObject

A hash of configuration for Stripe-hosted dashboards.



1613
1614
1615
# File 'lib/stripe/params/account_create_params.rb', line 1613

def stripe_dashboard
  @stripe_dashboard
end