Class: Stripe::AccountCreateParams::Controller
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountCreateParams::Controller
- Defined in:
- lib/stripe/params/account_create_params.rb
Defined Under Namespace
Classes: Fees, Losses, StripeDashboard
Instance Attribute Summary collapse
-
#fees ⇒ Object
A hash of configuration for who pays Stripe fees for product usage on this account.
-
#losses ⇒ Object
A hash of configuration for products that have negative balance liability, and whether Stripe or a Connect application is responsible for them.
-
#requirement_collection ⇒ Object
A value indicating responsibility for collecting updated information when requirements on the account are due or change.
-
#stripe_dashboard ⇒ Object
A hash of configuration for Stripe-hosted dashboards.
Instance Method Summary collapse
-
#initialize(fees: nil, losses: nil, requirement_collection: nil, stripe_dashboard: nil) ⇒ Controller
constructor
A new instance of Controller.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(fees: nil, losses: nil, requirement_collection: nil, stripe_dashboard: nil) ⇒ Controller
Returns a new instance of Controller.
1414 1415 1416 1417 1418 1419 |
# File 'lib/stripe/params/account_create_params.rb', line 1414 def initialize(fees: nil, losses: nil, requirement_collection: nil, stripe_dashboard: nil) @fees = fees @losses = losses @requirement_collection = requirement_collection @stripe_dashboard = stripe_dashboard end |
Instance Attribute Details
#fees ⇒ Object
A hash of configuration for who pays Stripe fees for product usage on this account.
1406 1407 1408 |
# File 'lib/stripe/params/account_create_params.rb', line 1406 def fees @fees end |
#losses ⇒ Object
A hash of configuration for products that have negative balance liability, and whether Stripe or a Connect application is responsible for them.
1408 1409 1410 |
# File 'lib/stripe/params/account_create_params.rb', line 1408 def losses @losses end |
#requirement_collection ⇒ Object
A value indicating responsibility for collecting updated information when requirements on the account are due or change. Defaults to ‘stripe`.
1410 1411 1412 |
# File 'lib/stripe/params/account_create_params.rb', line 1410 def requirement_collection @requirement_collection end |
#stripe_dashboard ⇒ Object
A hash of configuration for Stripe-hosted dashboards.
1412 1413 1414 |
# File 'lib/stripe/params/account_create_params.rb', line 1412 def stripe_dashboard @stripe_dashboard end |