Class: Stripe::AccountCreateParams::Controller
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountCreateParams::Controller
- Defined in:
- lib/stripe/params/account_create_params.rb
Defined Under Namespace
Classes: Application, Dashboard, Fees, Losses, StripeDashboard
Instance Attribute Summary collapse
-
#application ⇒ Object
A hash of configuration describing the Connect application that controls the account.
-
#dashboard ⇒ Object
Properties of the account’s dashboard.
-
#fees ⇒ Object
A hash of configuration for who pays Stripe fees for product usage on this account.
-
#losses ⇒ Object
A hash of configuration for products that have negative balance liability, and whether Stripe or a Connect application is responsible for them.
-
#requirement_collection ⇒ Object
A value indicating responsibility for collecting updated information when requirements on the account are due or change.
-
#stripe_dashboard ⇒ Object
A hash of configuration for Stripe-hosted dashboards.
Instance Method Summary collapse
-
#initialize(application: nil, dashboard: nil, fees: nil, losses: nil, requirement_collection: nil, stripe_dashboard: nil) ⇒ Controller
constructor
A new instance of Controller.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(application: nil, dashboard: nil, fees: nil, losses: nil, requirement_collection: nil, stripe_dashboard: nil) ⇒ Controller
Returns a new instance of Controller.
1589 1590 1591 1592 1593 1594 1595 1596 1597 1598 1599 1600 1601 1602 1603 |
# File 'lib/stripe/params/account_create_params.rb', line 1589 def initialize( application: nil, dashboard: nil, fees: nil, losses: nil, requirement_collection: nil, stripe_dashboard: nil ) @application = application @dashboard = dashboard @fees = fees @losses = losses @requirement_collection = requirement_collection @stripe_dashboard = stripe_dashboard end |
Instance Attribute Details
#application ⇒ Object
A hash of configuration describing the Connect application that controls the account.
1577 1578 1579 |
# File 'lib/stripe/params/account_create_params.rb', line 1577 def application @application end |
#dashboard ⇒ Object
Properties of the account’s dashboard.
1579 1580 1581 |
# File 'lib/stripe/params/account_create_params.rb', line 1579 def dashboard @dashboard end |
#fees ⇒ Object
A hash of configuration for who pays Stripe fees for product usage on this account.
1581 1582 1583 |
# File 'lib/stripe/params/account_create_params.rb', line 1581 def fees @fees end |
#losses ⇒ Object
A hash of configuration for products that have negative balance liability, and whether Stripe or a Connect application is responsible for them.
1583 1584 1585 |
# File 'lib/stripe/params/account_create_params.rb', line 1583 def losses @losses end |
#requirement_collection ⇒ Object
A value indicating responsibility for collecting updated information when requirements on the account are due or change. Defaults to ‘stripe`.
1585 1586 1587 |
# File 'lib/stripe/params/account_create_params.rb', line 1585 def requirement_collection @requirement_collection end |
#stripe_dashboard ⇒ Object
A hash of configuration for Stripe-hosted dashboards.
1587 1588 1589 |
# File 'lib/stripe/params/account_create_params.rb', line 1587 def stripe_dashboard @stripe_dashboard end |