Class: Stripe::AccountCreateParams::Controller

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/account_create_params.rb

Defined Under Namespace

Classes: Application, Dashboard, Fees, Losses, StripeDashboard

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(application: nil, dashboard: nil, fees: nil, losses: nil, requirement_collection: nil, stripe_dashboard: nil) ⇒ Controller

Returns a new instance of Controller.



1563
1564
1565
1566
1567
1568
1569
1570
1571
1572
1573
1574
1575
1576
1577
# File 'lib/stripe/params/account_create_params.rb', line 1563

def initialize(
  application: nil,
  dashboard: nil,
  fees: nil,
  losses: nil,
  requirement_collection: nil,
  stripe_dashboard: nil
)
  @application = application
  @dashboard = dashboard
  @fees = fees
  @losses = losses
  @requirement_collection = requirement_collection
  @stripe_dashboard = stripe_dashboard
end

Instance Attribute Details

#applicationObject

A hash of configuration describing the Connect application that controls the account.



1551
1552
1553
# File 'lib/stripe/params/account_create_params.rb', line 1551

def application
  @application
end

#dashboardObject

Properties of the account’s dashboard.



1553
1554
1555
# File 'lib/stripe/params/account_create_params.rb', line 1553

def dashboard
  @dashboard
end

#feesObject

A hash of configuration for who pays Stripe fees for product usage on this account.



1555
1556
1557
# File 'lib/stripe/params/account_create_params.rb', line 1555

def fees
  @fees
end

#lossesObject

A hash of configuration for products that have negative balance liability, and whether Stripe or a Connect application is responsible for them.



1557
1558
1559
# File 'lib/stripe/params/account_create_params.rb', line 1557

def losses
  @losses
end

#requirement_collectionObject

A value indicating responsibility for collecting updated information when requirements on the account are due or change. Defaults to ‘stripe`.



1559
1560
1561
# File 'lib/stripe/params/account_create_params.rb', line 1559

def requirement_collection
  @requirement_collection
end

#stripe_dashboardObject

A hash of configuration for Stripe-hosted dashboards.



1561
1562
1563
# File 'lib/stripe/params/account_create_params.rb', line 1561

def stripe_dashboard
  @stripe_dashboard
end