Class: Stripe::AccountCreateParams::Documents::ProofOfUltimateBeneficialOwnership

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Defined Under Namespace

Classes: Signer

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(files: nil, signer: nil) ⇒ ProofOfUltimateBeneficialOwnership

Returns a new instance of ProofOfUltimateBeneficialOwnership.



1572
1573
1574
1575
# File 'lib/stripe/params/account_create_params.rb', line 1572

def initialize(files: nil, signer: nil)
  @files = files
  @signer = signer
end

Instance Attribute Details

#filesObject

One or more document ids returned by a file upload with a purpose value of account_requirement.



1568
1569
1570
# File 'lib/stripe/params/account_create_params.rb', line 1568

def files
  @files
end

#signerObject

Information regarding the person signing the document if applicable.



1570
1571
1572
# File 'lib/stripe/params/account_create_params.rb', line 1570

def signer
  @signer
end