Class: Stripe::AccountCreateParams::Documents::ProofOfUltimateBeneficialOwnership
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountCreateParams::Documents::ProofOfUltimateBeneficialOwnership
- Defined in:
- lib/stripe/params/account_create_params.rb
Defined Under Namespace
Classes: Signer
Instance Attribute Summary collapse
-
#files ⇒ Object
One or more document ids returned by a file upload with a
purposevalue ofaccount_requirement. -
#signer ⇒ Object
Information regarding the person signing the document if applicable.
Instance Method Summary collapse
-
#initialize(files: nil, signer: nil) ⇒ ProofOfUltimateBeneficialOwnership
constructor
A new instance of ProofOfUltimateBeneficialOwnership.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(files: nil, signer: nil) ⇒ ProofOfUltimateBeneficialOwnership
Returns a new instance of ProofOfUltimateBeneficialOwnership.
1782 1783 1784 1785 |
# File 'lib/stripe/params/account_create_params.rb', line 1782 def initialize(files: nil, signer: nil) @files = files @signer = signer end |
Instance Attribute Details
#files ⇒ Object
One or more document ids returned by a file upload with a purpose value of account_requirement.
1778 1779 1780 |
# File 'lib/stripe/params/account_create_params.rb', line 1778 def files @files end |
#signer ⇒ Object
Information regarding the person signing the document if applicable.
1780 1781 1782 |
# File 'lib/stripe/params/account_create_params.rb', line 1780 def signer @signer end |