Class: Stripe::AccountCreateParams::Documents::ProofOfUltimateBeneficialOwnership

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Defined Under Namespace

Classes: Signer

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(files: nil, signer: nil) ⇒ ProofOfUltimateBeneficialOwnership

Returns a new instance of ProofOfUltimateBeneficialOwnership.



1730
1731
1732
1733
# File 'lib/stripe/params/account_create_params.rb', line 1730

def initialize(files: nil, signer: nil)
  @files = files
  @signer = signer
end

Instance Attribute Details

#filesObject

One or more document ids returned by a [file upload](api.stripe.com#create_file) with a ‘purpose` value of `account_requirement`.



1726
1727
1728
# File 'lib/stripe/params/account_create_params.rb', line 1726

def files
  @files
end

#signerObject

Information regarding the person signing the document if applicable.



1728
1729
1730
# File 'lib/stripe/params/account_create_params.rb', line 1728

def signer
  @signer
end