Class: Stripe::AccountCreateParams::Documents::ProofOfUltimateBeneficialOwnership

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Defined Under Namespace

Classes: Signer

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(files: nil, signer: nil) ⇒ ProofOfUltimateBeneficialOwnership

Returns a new instance of ProofOfUltimateBeneficialOwnership.



1704
1705
1706
1707
# File 'lib/stripe/params/account_create_params.rb', line 1704

def initialize(files: nil, signer: nil)
  @files = files
  @signer = signer
end

Instance Attribute Details

#filesObject

One or more document ids returned by a [file upload](api.stripe.com#create_file) with a ‘purpose` value of `account_requirement`.



1700
1701
1702
# File 'lib/stripe/params/account_create_params.rb', line 1700

def files
  @files
end

#signerObject

Information regarding the person signing the document if applicable.



1702
1703
1704
# File 'lib/stripe/params/account_create_params.rb', line 1702

def signer
  @signer
end