Class: Stripe::AccountCreateParams::Documents::ProofOfUltimateBeneficialOwnership
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountCreateParams::Documents::ProofOfUltimateBeneficialOwnership
- Defined in:
- lib/stripe/params/account_create_params.rb
Defined Under Namespace
Classes: Signer
Instance Attribute Summary collapse
-
#files ⇒ Object
One or more document ids returned by a [file upload](api.stripe.com#create_file) with a ‘purpose` value of `account_requirement`.
-
#signer ⇒ Object
Information regarding the person signing the document if applicable.
Instance Method Summary collapse
-
#initialize(files: nil, signer: nil) ⇒ ProofOfUltimateBeneficialOwnership
constructor
A new instance of ProofOfUltimateBeneficialOwnership.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(files: nil, signer: nil) ⇒ ProofOfUltimateBeneficialOwnership
Returns a new instance of ProofOfUltimateBeneficialOwnership.
1704 1705 1706 1707 |
# File 'lib/stripe/params/account_create_params.rb', line 1704 def initialize(files: nil, signer: nil) @files = files @signer = signer end |
Instance Attribute Details
#files ⇒ Object
One or more document ids returned by a [file upload](api.stripe.com#create_file) with a ‘purpose` value of `account_requirement`.
1700 1701 1702 |
# File 'lib/stripe/params/account_create_params.rb', line 1700 def files @files end |
#signer ⇒ Object
Information regarding the person signing the document if applicable.
1702 1703 1704 |
# File 'lib/stripe/params/account_create_params.rb', line 1702 def signer @signer end |