Class: Stripe::AccountCreateParams::Groups
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountCreateParams::Groups
- Defined in:
- lib/stripe/params/account_create_params.rb
Instance Attribute Summary collapse
-
#payments_pricing ⇒ Object
The group the account is in to determine their payments pricing, and null if the account is on customized pricing.
Instance Method Summary collapse
-
#initialize(payments_pricing: nil) ⇒ Groups
constructor
A new instance of Groups.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(payments_pricing: nil) ⇒ Groups
Returns a new instance of Groups.
1848 1849 1850 |
# File 'lib/stripe/params/account_create_params.rb', line 1848 def initialize(payments_pricing: nil) @payments_pricing = payments_pricing end |
Instance Attribute Details
#payments_pricing ⇒ Object
The group the account is in to determine their payments pricing, and null if the account is on customized pricing. See the Platform pricing tool documentation for details.
1846 1847 1848 |
# File 'lib/stripe/params/account_create_params.rb', line 1846 def payments_pricing @payments_pricing end |