Class: Stripe::AccountCreateParams::Groups

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(payments_pricing: nil) ⇒ Groups

Returns a new instance of Groups.



1671
1672
1673
# File 'lib/stripe/params/account_create_params.rb', line 1671

def initialize(payments_pricing: nil)
  @payments_pricing = payments_pricing
end

Instance Attribute Details

#payments_pricingObject

The group the account is in to determine their payments pricing, and null if the account is on customized pricing. [See the Platform pricing tool documentation](stripe.com/docs/connect/platform-pricing-tools) for details.



1669
1670
1671
# File 'lib/stripe/params/account_create_params.rb', line 1669

def payments_pricing
  @payments_pricing
end