Class: Stripe::AccountCreateParams::Individual

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/account_create_params.rb

Defined Under Namespace

Classes: Address, AddressKana, AddressKanji, BirthAddress, Dob, RegisteredAddress, Relationship, SelfReportedIncome, SelfReportedMonthlyHousingPayment, Verification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(address: nil, address_kana: nil, address_kanji: nil, birth_address: nil, dob: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, self_reported_income: nil, self_reported_monthly_housing_payment: nil, ssn_last_4: nil, verification: nil) ⇒ Individual

Returns a new instance of Individual.



2170
2171
2172
2173
2174
2175
2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
2188
2189
2190
2191
2192
2193
2194
2195
2196
2197
2198
2199
2200
2201
2202
2203
2204
2205
2206
2207
2208
2209
2210
2211
2212
2213
2214
2215
2216
2217
2218
2219
2220
2221
2222
2223
2224
# File 'lib/stripe/params/account_create_params.rb', line 2170

def initialize(
  address: nil,
  address_kana: nil,
  address_kanji: nil,
  birth_address: nil,
  dob: nil,
  email: nil,
  first_name: nil,
  first_name_kana: nil,
  first_name_kanji: nil,
  full_name_aliases: nil,
  gender: nil,
  id_number: nil,
  id_number_secondary: nil,
  last_name: nil,
  last_name_kana: nil,
  last_name_kanji: nil,
  maiden_name: nil,
  metadata: nil,
  phone: nil,
  political_exposure: nil,
  registered_address: nil,
  relationship: nil,
  self_reported_income: nil,
  self_reported_monthly_housing_payment: nil,
  ssn_last_4: nil,
  verification: nil
)
  @address = address
  @address_kana = address_kana
  @address_kanji = address_kanji
  @birth_address = birth_address
  @dob = dob
  @email = email
  @first_name = first_name
  @first_name_kana = first_name_kana
  @first_name_kanji = first_name_kanji
  @full_name_aliases = full_name_aliases
  @gender = gender
  @id_number = id_number
  @id_number_secondary = id_number_secondary
  @last_name = last_name
  @last_name_kana = last_name_kana
  @last_name_kanji = last_name_kanji
  @maiden_name = maiden_name
  @metadata = 
  @phone = phone
  @political_exposure = political_exposure
  @registered_address = registered_address
  @relationship = relationship
  @self_reported_income = self_reported_income
  @self_reported_monthly_housing_payment = self_reported_monthly_housing_payment
  @ssn_last_4 = ssn_last_4
  @verification = verification
end

Instance Attribute Details

#addressObject

The individual's primary address.



2118
2119
2120
# File 'lib/stripe/params/account_create_params.rb', line 2118

def address
  @address
end

#address_kanaObject

The Kana variation of the individual's primary address (Japan only).



2120
2121
2122
# File 'lib/stripe/params/account_create_params.rb', line 2120

def address_kana
  @address_kana
end

#address_kanjiObject

The Kanji variation of the individual's primary address (Japan only).



2122
2123
2124
# File 'lib/stripe/params/account_create_params.rb', line 2122

def address_kanji
  @address_kanji
end

#birth_addressObject

Attribute for param field birth_address



2124
2125
2126
# File 'lib/stripe/params/account_create_params.rb', line 2124

def birth_address
  @birth_address
end

#dobObject

The individual's date of birth.



2126
2127
2128
# File 'lib/stripe/params/account_create_params.rb', line 2126

def dob
  @dob
end

#emailObject

The individual's email address.



2128
2129
2130
# File 'lib/stripe/params/account_create_params.rb', line 2128

def email
  @email
end

#first_nameObject

The individual's first name.



2130
2131
2132
# File 'lib/stripe/params/account_create_params.rb', line 2130

def first_name
  @first_name
end

#first_name_kanaObject

The Kana variation of the individual's first name (Japan only).



2132
2133
2134
# File 'lib/stripe/params/account_create_params.rb', line 2132

def first_name_kana
  @first_name_kana
end

#first_name_kanjiObject

The Kanji variation of the individual's first name (Japan only).



2134
2135
2136
# File 'lib/stripe/params/account_create_params.rb', line 2134

def first_name_kanji
  @first_name_kanji
end

#full_name_aliasesObject

A list of alternate names or aliases that the individual is known by.



2136
2137
2138
# File 'lib/stripe/params/account_create_params.rb', line 2136

def full_name_aliases
  @full_name_aliases
end

#genderObject

The individual's gender



2138
2139
2140
# File 'lib/stripe/params/account_create_params.rb', line 2138

def gender
  @gender
end

#id_numberObject

The government-issued ID number of the individual, as appropriate for the representative's country. (Examples are a Social Security Number in the U.S., or a Social Insurance Number in Canada). Instead of the number itself, you can also provide a PII token created with Stripe.js.



2140
2141
2142
# File 'lib/stripe/params/account_create_params.rb', line 2140

def id_number
  @id_number
end

#id_number_secondaryObject

The government-issued secondary ID number of the individual, as appropriate for the representative's country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a PII token created with Stripe.js.



2142
2143
2144
# File 'lib/stripe/params/account_create_params.rb', line 2142

def id_number_secondary
  @id_number_secondary
end

#last_nameObject

The individual's last name.



2144
2145
2146
# File 'lib/stripe/params/account_create_params.rb', line 2144

def last_name
  @last_name
end

#last_name_kanaObject

The Kana variation of the individual's last name (Japan only).



2146
2147
2148
# File 'lib/stripe/params/account_create_params.rb', line 2146

def last_name_kana
  @last_name_kana
end

#last_name_kanjiObject

The Kanji variation of the individual's last name (Japan only).



2148
2149
2150
# File 'lib/stripe/params/account_create_params.rb', line 2148

def last_name_kanji
  @last_name_kanji
end

#maiden_nameObject

The individual's maiden name.



2150
2151
2152
# File 'lib/stripe/params/account_create_params.rb', line 2150

def maiden_name
  @maiden_name
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.



2152
2153
2154
# File 'lib/stripe/params/account_create_params.rb', line 2152

def 
  @metadata
end

#phoneObject

The individual's phone number.



2154
2155
2156
# File 'lib/stripe/params/account_create_params.rb', line 2154

def phone
  @phone
end

#political_exposureObject

Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.



2156
2157
2158
# File 'lib/stripe/params/account_create_params.rb', line 2156

def political_exposure
  @political_exposure
end

#registered_addressObject

The individual's registered address.



2158
2159
2160
# File 'lib/stripe/params/account_create_params.rb', line 2158

def registered_address
  @registered_address
end

#relationshipObject

Describes the person’s relationship to the account.



2160
2161
2162
# File 'lib/stripe/params/account_create_params.rb', line 2160

def relationship
  @relationship
end

#self_reported_incomeObject

The credit applicant's self-reported yearly income in minor units.



2162
2163
2164
# File 'lib/stripe/params/account_create_params.rb', line 2162

def self_reported_income
  @self_reported_income
end

#self_reported_monthly_housing_paymentObject

The credit applicant's self-reported monthly housing payment in minor units.



2164
2165
2166
# File 'lib/stripe/params/account_create_params.rb', line 2164

def self_reported_monthly_housing_payment
  @self_reported_monthly_housing_payment
end

#ssn_last_4Object

The last four digits of the individual's Social Security Number (U.S. only).



2166
2167
2168
# File 'lib/stripe/params/account_create_params.rb', line 2166

def ssn_last_4
  @ssn_last_4
end

#verificationObject

The individual's verification document information.



2168
2169
2170
# File 'lib/stripe/params/account_create_params.rb', line 2168

def verification
  @verification
end