Class: Stripe::AccountCreateParams::Individual

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/account_create_params.rb

Defined Under Namespace

Classes: Address, AddressKana, AddressKanji, BirthAddress, Dob, RegisteredAddress, Relationship, SelfReportedIncome, SelfReportedMonthlyHousingPayment, Verification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(address: nil, address_kana: nil, address_kanji: nil, birth_address: nil, dob: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, self_reported_income: nil, self_reported_monthly_housing_payment: nil, ssn_last_4: nil, verification: nil) ⇒ Individual

Returns a new instance of Individual.



2122
2123
2124
2125
2126
2127
2128
2129
2130
2131
2132
2133
2134
2135
2136
2137
2138
2139
2140
2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
2154
2155
2156
2157
2158
2159
2160
2161
2162
2163
2164
2165
2166
2167
2168
2169
2170
2171
2172
2173
2174
2175
2176
# File 'lib/stripe/params/account_create_params.rb', line 2122

def initialize(
  address: nil,
  address_kana: nil,
  address_kanji: nil,
  birth_address: nil,
  dob: nil,
  email: nil,
  first_name: nil,
  first_name_kana: nil,
  first_name_kanji: nil,
  full_name_aliases: nil,
  gender: nil,
  id_number: nil,
  id_number_secondary: nil,
  last_name: nil,
  last_name_kana: nil,
  last_name_kanji: nil,
  maiden_name: nil,
  metadata: nil,
  phone: nil,
  political_exposure: nil,
  registered_address: nil,
  relationship: nil,
  self_reported_income: nil,
  self_reported_monthly_housing_payment: nil,
  ssn_last_4: nil,
  verification: nil
)
  @address = address
  @address_kana = address_kana
  @address_kanji = address_kanji
  @birth_address = birth_address
  @dob = dob
  @email = email
  @first_name = first_name
  @first_name_kana = first_name_kana
  @first_name_kanji = first_name_kanji
  @full_name_aliases = full_name_aliases
  @gender = gender
  @id_number = id_number
  @id_number_secondary = id_number_secondary
  @last_name = last_name
  @last_name_kana = last_name_kana
  @last_name_kanji = last_name_kanji
  @maiden_name = maiden_name
  @metadata = 
  @phone = phone
  @political_exposure = political_exposure
  @registered_address = registered_address
  @relationship = relationship
  @self_reported_income = self_reported_income
  @self_reported_monthly_housing_payment = self_reported_monthly_housing_payment
  @ssn_last_4 = ssn_last_4
  @verification = verification
end

Instance Attribute Details

#addressObject

The individual’s primary address.



2070
2071
2072
# File 'lib/stripe/params/account_create_params.rb', line 2070

def address
  @address
end

#address_kanaObject

The Kana variation of the individual’s primary address (Japan only).



2072
2073
2074
# File 'lib/stripe/params/account_create_params.rb', line 2072

def address_kana
  @address_kana
end

#address_kanjiObject

The Kanji variation of the individual’s primary address (Japan only).



2074
2075
2076
# File 'lib/stripe/params/account_create_params.rb', line 2074

def address_kanji
  @address_kanji
end

#birth_addressObject

Attribute for param field birth_address



2076
2077
2078
# File 'lib/stripe/params/account_create_params.rb', line 2076

def birth_address
  @birth_address
end

#dobObject

The individual’s date of birth.



2078
2079
2080
# File 'lib/stripe/params/account_create_params.rb', line 2078

def dob
  @dob
end

#emailObject

The individual’s email address.



2080
2081
2082
# File 'lib/stripe/params/account_create_params.rb', line 2080

def email
  @email
end

#first_nameObject

The individual’s first name.



2082
2083
2084
# File 'lib/stripe/params/account_create_params.rb', line 2082

def first_name
  @first_name
end

#first_name_kanaObject

The Kana variation of the individual’s first name (Japan only).



2084
2085
2086
# File 'lib/stripe/params/account_create_params.rb', line 2084

def first_name_kana
  @first_name_kana
end

#first_name_kanjiObject

The Kanji variation of the individual’s first name (Japan only).



2086
2087
2088
# File 'lib/stripe/params/account_create_params.rb', line 2086

def first_name_kanji
  @first_name_kanji
end

#full_name_aliasesObject

A list of alternate names or aliases that the individual is known by.



2088
2089
2090
# File 'lib/stripe/params/account_create_params.rb', line 2088

def full_name_aliases
  @full_name_aliases
end

#genderObject

The individual’s gender



2090
2091
2092
# File 'lib/stripe/params/account_create_params.rb', line 2090

def gender
  @gender
end

#id_numberObject

The government-issued ID number of the individual, as appropriate for the representative’s country. (Examples are a Social Security Number in the U.S., or a Social Insurance Number in Canada). Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).



2092
2093
2094
# File 'lib/stripe/params/account_create_params.rb', line 2092

def id_number
  @id_number
end

#id_number_secondaryObject

The government-issued secondary ID number of the individual, as appropriate for the representative’s country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).



2094
2095
2096
# File 'lib/stripe/params/account_create_params.rb', line 2094

def id_number_secondary
  @id_number_secondary
end

#last_nameObject

The individual’s last name.



2096
2097
2098
# File 'lib/stripe/params/account_create_params.rb', line 2096

def last_name
  @last_name
end

#last_name_kanaObject

The Kana variation of the individual’s last name (Japan only).



2098
2099
2100
# File 'lib/stripe/params/account_create_params.rb', line 2098

def last_name_kana
  @last_name_kana
end

#last_name_kanjiObject

The Kanji variation of the individual’s last name (Japan only).



2100
2101
2102
# File 'lib/stripe/params/account_create_params.rb', line 2100

def last_name_kanji
  @last_name_kanji
end

#maiden_nameObject

The individual’s maiden name.



2102
2103
2104
# File 'lib/stripe/params/account_create_params.rb', line 2102

def maiden_name
  @maiden_name
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2104
2105
2106
# File 'lib/stripe/params/account_create_params.rb', line 2104

def 
  @metadata
end

#phoneObject

The individual’s phone number.



2106
2107
2108
# File 'lib/stripe/params/account_create_params.rb', line 2106

def phone
  @phone
end

#political_exposureObject

Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.



2108
2109
2110
# File 'lib/stripe/params/account_create_params.rb', line 2108

def political_exposure
  @political_exposure
end

#registered_addressObject

The individual’s registered address.



2110
2111
2112
# File 'lib/stripe/params/account_create_params.rb', line 2110

def registered_address
  @registered_address
end

#relationshipObject

Describes the person’s relationship to the account.



2112
2113
2114
# File 'lib/stripe/params/account_create_params.rb', line 2112

def relationship
  @relationship
end

#self_reported_incomeObject

The credit applicant’s self-reported yearly income in minor units.



2114
2115
2116
# File 'lib/stripe/params/account_create_params.rb', line 2114

def self_reported_income
  @self_reported_income
end

#self_reported_monthly_housing_paymentObject

The credit applicant’s self-reported monthly housing payment in minor units.



2116
2117
2118
# File 'lib/stripe/params/account_create_params.rb', line 2116

def self_reported_monthly_housing_payment
  @self_reported_monthly_housing_payment
end

#ssn_last_4Object

The last four digits of the individual’s Social Security Number (U.S. only).



2118
2119
2120
# File 'lib/stripe/params/account_create_params.rb', line 2118

def ssn_last_4
  @ssn_last_4
end

#verificationObject

The individual’s verification document information.



2120
2121
2122
# File 'lib/stripe/params/account_create_params.rb', line 2120

def verification
  @verification
end