Class: Stripe::AccountCreateParams::Individual

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/account_create_params.rb

Defined Under Namespace

Classes: Address, AddressKana, AddressKanji, Dob, RegisteredAddress, Relationship, Verification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(address: nil, address_kana: nil, address_kanji: nil, dob: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil) ⇒ Individual

Returns a new instance of Individual.



2042
2043
2044
2045
2046
2047
2048
2049
2050
2051
2052
2053
2054
2055
2056
2057
2058
2059
2060
2061
2062
2063
2064
2065
2066
2067
2068
2069
2070
2071
2072
2073
2074
2075
2076
2077
2078
2079
2080
2081
2082
2083
2084
2085
2086
2087
2088
2089
2090
# File 'lib/stripe/params/account_create_params.rb', line 2042

def initialize(
  address: nil,
  address_kana: nil,
  address_kanji: nil,
  dob: nil,
  email: nil,
  first_name: nil,
  first_name_kana: nil,
  first_name_kanji: nil,
  full_name_aliases: nil,
  gender: nil,
  id_number: nil,
  id_number_secondary: nil,
  last_name: nil,
  last_name_kana: nil,
  last_name_kanji: nil,
  maiden_name: nil,
  metadata: nil,
  phone: nil,
  political_exposure: nil,
  registered_address: nil,
  relationship: nil,
  ssn_last_4: nil,
  verification: nil
)
  @address = address
  @address_kana = address_kana
  @address_kanji = address_kanji
  @dob = dob
  @email = email
  @first_name = first_name
  @first_name_kana = first_name_kana
  @first_name_kanji = first_name_kanji
  @full_name_aliases = full_name_aliases
  @gender = gender
  @id_number = id_number
  @id_number_secondary = id_number_secondary
  @last_name = last_name
  @last_name_kana = last_name_kana
  @last_name_kanji = last_name_kanji
  @maiden_name = maiden_name
  @metadata = 
  @phone = phone
  @political_exposure = political_exposure
  @registered_address = registered_address
  @relationship = relationship
  @ssn_last_4 = ssn_last_4
  @verification = verification
end

Instance Attribute Details

#addressObject

The individual’s primary address.



1996
1997
1998
# File 'lib/stripe/params/account_create_params.rb', line 1996

def address
  @address
end

#address_kanaObject

The Kana variation of the individual’s primary address (Japan only).



1998
1999
2000
# File 'lib/stripe/params/account_create_params.rb', line 1998

def address_kana
  @address_kana
end

#address_kanjiObject

The Kanji variation of the individual’s primary address (Japan only).



2000
2001
2002
# File 'lib/stripe/params/account_create_params.rb', line 2000

def address_kanji
  @address_kanji
end

#dobObject

The individual’s date of birth.



2002
2003
2004
# File 'lib/stripe/params/account_create_params.rb', line 2002

def dob
  @dob
end

#emailObject

The individual’s email address.



2004
2005
2006
# File 'lib/stripe/params/account_create_params.rb', line 2004

def email
  @email
end

#first_nameObject

The individual’s first name.



2006
2007
2008
# File 'lib/stripe/params/account_create_params.rb', line 2006

def first_name
  @first_name
end

#first_name_kanaObject

The Kana variation of the individual’s first name (Japan only).



2008
2009
2010
# File 'lib/stripe/params/account_create_params.rb', line 2008

def first_name_kana
  @first_name_kana
end

#first_name_kanjiObject

The Kanji variation of the individual’s first name (Japan only).



2010
2011
2012
# File 'lib/stripe/params/account_create_params.rb', line 2010

def first_name_kanji
  @first_name_kanji
end

#full_name_aliasesObject

A list of alternate names or aliases that the individual is known by.



2012
2013
2014
# File 'lib/stripe/params/account_create_params.rb', line 2012

def full_name_aliases
  @full_name_aliases
end

#genderObject

The individual’s gender



2014
2015
2016
# File 'lib/stripe/params/account_create_params.rb', line 2014

def gender
  @gender
end

#id_numberObject

The government-issued ID number of the individual, as appropriate for the representative’s country. (Examples are a Social Security Number in the U.S., or a Social Insurance Number in Canada). Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).



2016
2017
2018
# File 'lib/stripe/params/account_create_params.rb', line 2016

def id_number
  @id_number
end

#id_number_secondaryObject

The government-issued secondary ID number of the individual, as appropriate for the representative’s country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).



2018
2019
2020
# File 'lib/stripe/params/account_create_params.rb', line 2018

def id_number_secondary
  @id_number_secondary
end

#last_nameObject

The individual’s last name.



2020
2021
2022
# File 'lib/stripe/params/account_create_params.rb', line 2020

def last_name
  @last_name
end

#last_name_kanaObject

The Kana variation of the individual’s last name (Japan only).



2022
2023
2024
# File 'lib/stripe/params/account_create_params.rb', line 2022

def last_name_kana
  @last_name_kana
end

#last_name_kanjiObject

The Kanji variation of the individual’s last name (Japan only).



2024
2025
2026
# File 'lib/stripe/params/account_create_params.rb', line 2024

def last_name_kanji
  @last_name_kanji
end

#maiden_nameObject

The individual’s maiden name.



2026
2027
2028
# File 'lib/stripe/params/account_create_params.rb', line 2026

def maiden_name
  @maiden_name
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2028
2029
2030
# File 'lib/stripe/params/account_create_params.rb', line 2028

def 
  @metadata
end

#phoneObject

The individual’s phone number.



2030
2031
2032
# File 'lib/stripe/params/account_create_params.rb', line 2030

def phone
  @phone
end

#political_exposureObject

Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.



2032
2033
2034
# File 'lib/stripe/params/account_create_params.rb', line 2032

def political_exposure
  @political_exposure
end

#registered_addressObject

The individual’s registered address.



2034
2035
2036
# File 'lib/stripe/params/account_create_params.rb', line 2034

def registered_address
  @registered_address
end

#relationshipObject

Describes the person’s relationship to the account.



2036
2037
2038
# File 'lib/stripe/params/account_create_params.rb', line 2036

def relationship
  @relationship
end

#ssn_last_4Object

The last four digits of the individual’s Social Security Number (U.S. only).



2038
2039
2040
# File 'lib/stripe/params/account_create_params.rb', line 2038

def ssn_last_4
  @ssn_last_4
end

#verificationObject

The individual’s verification document information.



2040
2041
2042
# File 'lib/stripe/params/account_create_params.rb', line 2040

def verification
  @verification
end