Class: Stripe::AccountCreateParams::Individual

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/account_create_params.rb

Defined Under Namespace

Classes: Address, AddressKana, AddressKanji, Dob, RegisteredAddress, Relationship, SelfReportedIncome, SelfReportedMonthlyHousingPayment, Verification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(address: nil, address_kana: nil, address_kanji: nil, dob: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, self_reported_income: nil, self_reported_monthly_housing_payment: nil, ssn_last_4: nil, verification: nil) ⇒ Individual

Returns a new instance of Individual.



2063
2064
2065
2066
2067
2068
2069
2070
2071
2072
2073
2074
2075
2076
2077
2078
2079
2080
2081
2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
2101
2102
2103
2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
2114
2115
# File 'lib/stripe/params/account_create_params.rb', line 2063

def initialize(
  address: nil,
  address_kana: nil,
  address_kanji: nil,
  dob: nil,
  email: nil,
  first_name: nil,
  first_name_kana: nil,
  first_name_kanji: nil,
  full_name_aliases: nil,
  gender: nil,
  id_number: nil,
  id_number_secondary: nil,
  last_name: nil,
  last_name_kana: nil,
  last_name_kanji: nil,
  maiden_name: nil,
  metadata: nil,
  phone: nil,
  political_exposure: nil,
  registered_address: nil,
  relationship: nil,
  self_reported_income: nil,
  self_reported_monthly_housing_payment: nil,
  ssn_last_4: nil,
  verification: nil
)
  @address = address
  @address_kana = address_kana
  @address_kanji = address_kanji
  @dob = dob
  @email = email
  @first_name = first_name
  @first_name_kana = first_name_kana
  @first_name_kanji = first_name_kanji
  @full_name_aliases = full_name_aliases
  @gender = gender
  @id_number = id_number
  @id_number_secondary = id_number_secondary
  @last_name = last_name
  @last_name_kana = last_name_kana
  @last_name_kanji = last_name_kanji
  @maiden_name = maiden_name
  @metadata = 
  @phone = phone
  @political_exposure = political_exposure
  @registered_address = registered_address
  @relationship = relationship
  @self_reported_income = self_reported_income
  @self_reported_monthly_housing_payment = self_reported_monthly_housing_payment
  @ssn_last_4 = ssn_last_4
  @verification = verification
end

Instance Attribute Details

#addressObject

The individual’s primary address.



2013
2014
2015
# File 'lib/stripe/params/account_create_params.rb', line 2013

def address
  @address
end

#address_kanaObject

The Kana variation of the individual’s primary address (Japan only).



2015
2016
2017
# File 'lib/stripe/params/account_create_params.rb', line 2015

def address_kana
  @address_kana
end

#address_kanjiObject

The Kanji variation of the individual’s primary address (Japan only).



2017
2018
2019
# File 'lib/stripe/params/account_create_params.rb', line 2017

def address_kanji
  @address_kanji
end

#dobObject

The individual’s date of birth.



2019
2020
2021
# File 'lib/stripe/params/account_create_params.rb', line 2019

def dob
  @dob
end

#emailObject

The individual’s email address.



2021
2022
2023
# File 'lib/stripe/params/account_create_params.rb', line 2021

def email
  @email
end

#first_nameObject

The individual’s first name.



2023
2024
2025
# File 'lib/stripe/params/account_create_params.rb', line 2023

def first_name
  @first_name
end

#first_name_kanaObject

The Kana variation of the individual’s first name (Japan only).



2025
2026
2027
# File 'lib/stripe/params/account_create_params.rb', line 2025

def first_name_kana
  @first_name_kana
end

#first_name_kanjiObject

The Kanji variation of the individual’s first name (Japan only).



2027
2028
2029
# File 'lib/stripe/params/account_create_params.rb', line 2027

def first_name_kanji
  @first_name_kanji
end

#full_name_aliasesObject

A list of alternate names or aliases that the individual is known by.



2029
2030
2031
# File 'lib/stripe/params/account_create_params.rb', line 2029

def full_name_aliases
  @full_name_aliases
end

#genderObject

The individual’s gender



2031
2032
2033
# File 'lib/stripe/params/account_create_params.rb', line 2031

def gender
  @gender
end

#id_numberObject

The government-issued ID number of the individual, as appropriate for the representative’s country. (Examples are a Social Security Number in the U.S., or a Social Insurance Number in Canada). Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).



2033
2034
2035
# File 'lib/stripe/params/account_create_params.rb', line 2033

def id_number
  @id_number
end

#id_number_secondaryObject

The government-issued secondary ID number of the individual, as appropriate for the representative’s country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).



2035
2036
2037
# File 'lib/stripe/params/account_create_params.rb', line 2035

def id_number_secondary
  @id_number_secondary
end

#last_nameObject

The individual’s last name.



2037
2038
2039
# File 'lib/stripe/params/account_create_params.rb', line 2037

def last_name
  @last_name
end

#last_name_kanaObject

The Kana variation of the individual’s last name (Japan only).



2039
2040
2041
# File 'lib/stripe/params/account_create_params.rb', line 2039

def last_name_kana
  @last_name_kana
end

#last_name_kanjiObject

The Kanji variation of the individual’s last name (Japan only).



2041
2042
2043
# File 'lib/stripe/params/account_create_params.rb', line 2041

def last_name_kanji
  @last_name_kanji
end

#maiden_nameObject

The individual’s maiden name.



2043
2044
2045
# File 'lib/stripe/params/account_create_params.rb', line 2043

def maiden_name
  @maiden_name
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2045
2046
2047
# File 'lib/stripe/params/account_create_params.rb', line 2045

def 
  @metadata
end

#phoneObject

The individual’s phone number.



2047
2048
2049
# File 'lib/stripe/params/account_create_params.rb', line 2047

def phone
  @phone
end

#political_exposureObject

Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.



2049
2050
2051
# File 'lib/stripe/params/account_create_params.rb', line 2049

def political_exposure
  @political_exposure
end

#registered_addressObject

The individual’s registered address.



2051
2052
2053
# File 'lib/stripe/params/account_create_params.rb', line 2051

def registered_address
  @registered_address
end

#relationshipObject

Describes the person’s relationship to the account.



2053
2054
2055
# File 'lib/stripe/params/account_create_params.rb', line 2053

def relationship
  @relationship
end

#self_reported_incomeObject

The credit applicant’s self-reported yearly income in minor units.



2055
2056
2057
# File 'lib/stripe/params/account_create_params.rb', line 2055

def self_reported_income
  @self_reported_income
end

#self_reported_monthly_housing_paymentObject

The credit applicant’s self-reported monthly housing payment in minor units.



2057
2058
2059
# File 'lib/stripe/params/account_create_params.rb', line 2057

def self_reported_monthly_housing_payment
  @self_reported_monthly_housing_payment
end

#ssn_last_4Object

The last four digits of the individual’s Social Security Number (U.S. only).



2059
2060
2061
# File 'lib/stripe/params/account_create_params.rb', line 2059

def ssn_last_4
  @ssn_last_4
end

#verificationObject

The individual’s verification document information.



2061
2062
2063
# File 'lib/stripe/params/account_create_params.rb', line 2061

def verification
  @verification
end