Class: Stripe::AccountCreateParams::Individual
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountCreateParams::Individual
- Defined in:
- lib/stripe/params/account_create_params.rb
Defined Under Namespace
Classes: Address, AddressKana, AddressKanji, Dob, RegisteredAddress, Relationship, Verification
Instance Attribute Summary collapse
-
#address ⇒ Object
The individual’s primary address.
-
#address_kana ⇒ Object
The Kana variation of the individual’s primary address (Japan only).
-
#address_kanji ⇒ Object
The Kanji variation of the individual’s primary address (Japan only).
-
#dob ⇒ Object
The individual’s date of birth.
-
#email ⇒ Object
The individual’s email address.
-
#first_name ⇒ Object
The individual’s first name.
-
#first_name_kana ⇒ Object
The Kana variation of the individual’s first name (Japan only).
-
#first_name_kanji ⇒ Object
The Kanji variation of the individual’s first name (Japan only).
-
#full_name_aliases ⇒ Object
A list of alternate names or aliases that the individual is known by.
-
#gender ⇒ Object
The individual’s gender.
-
#id_number ⇒ Object
The government-issued ID number of the individual, as appropriate for the representative’s country.
-
#id_number_secondary ⇒ Object
The government-issued secondary ID number of the individual, as appropriate for the representative’s country, will be used for enhanced verification checks.
-
#last_name ⇒ Object
The individual’s last name.
-
#last_name_kana ⇒ Object
The Kana variation of the individual’s last name (Japan only).
-
#last_name_kanji ⇒ Object
The Kanji variation of the individual’s last name (Japan only).
-
#maiden_name ⇒ Object
The individual’s maiden name.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#phone ⇒ Object
The individual’s phone number.
-
#political_exposure ⇒ Object
Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
-
#registered_address ⇒ Object
The individual’s registered address.
-
#relationship ⇒ Object
Describes the person’s relationship to the account.
-
#ssn_last_4 ⇒ Object
The last four digits of the individual’s Social Security Number (U.S. only).
-
#verification ⇒ Object
The individual’s verification document information.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, address_kana: nil, address_kanji: nil, dob: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil) ⇒ Individual
Returns a new instance of Individual.
1932 1933 1934 1935 1936 1937 1938 1939 1940 1941 1942 1943 1944 1945 1946 1947 1948 1949 1950 1951 1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 |
# File 'lib/stripe/params/account_create_params.rb', line 1932 def initialize( address: nil, address_kana: nil, address_kanji: nil, dob: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil ) @address = address @address_kana = address_kana @address_kanji = address_kanji @dob = dob @email = email @first_name = first_name @first_name_kana = first_name_kana @first_name_kanji = first_name_kanji @full_name_aliases = full_name_aliases @gender = gender @id_number = id_number @id_number_secondary = id_number_secondary @last_name = last_name @last_name_kana = last_name_kana @last_name_kanji = last_name_kanji @maiden_name = maiden_name @metadata = @phone = phone @political_exposure = political_exposure @registered_address = registered_address @relationship = relationship @ssn_last_4 = ssn_last_4 @verification = verification end |
Instance Attribute Details
#address ⇒ Object
The individual’s primary address.
1886 1887 1888 |
# File 'lib/stripe/params/account_create_params.rb', line 1886 def address @address end |
#address_kana ⇒ Object
The Kana variation of the individual’s primary address (Japan only).
1888 1889 1890 |
# File 'lib/stripe/params/account_create_params.rb', line 1888 def address_kana @address_kana end |
#address_kanji ⇒ Object
The Kanji variation of the individual’s primary address (Japan only).
1890 1891 1892 |
# File 'lib/stripe/params/account_create_params.rb', line 1890 def address_kanji @address_kanji end |
#dob ⇒ Object
The individual’s date of birth.
1892 1893 1894 |
# File 'lib/stripe/params/account_create_params.rb', line 1892 def dob @dob end |
#email ⇒ Object
The individual’s email address.
1894 1895 1896 |
# File 'lib/stripe/params/account_create_params.rb', line 1894 def email @email end |
#first_name ⇒ Object
The individual’s first name.
1896 1897 1898 |
# File 'lib/stripe/params/account_create_params.rb', line 1896 def first_name @first_name end |
#first_name_kana ⇒ Object
The Kana variation of the individual’s first name (Japan only).
1898 1899 1900 |
# File 'lib/stripe/params/account_create_params.rb', line 1898 def first_name_kana @first_name_kana end |
#first_name_kanji ⇒ Object
The Kanji variation of the individual’s first name (Japan only).
1900 1901 1902 |
# File 'lib/stripe/params/account_create_params.rb', line 1900 def first_name_kanji @first_name_kanji end |
#full_name_aliases ⇒ Object
A list of alternate names or aliases that the individual is known by.
1902 1903 1904 |
# File 'lib/stripe/params/account_create_params.rb', line 1902 def full_name_aliases @full_name_aliases end |
#gender ⇒ Object
The individual’s gender
1904 1905 1906 |
# File 'lib/stripe/params/account_create_params.rb', line 1904 def gender @gender end |
#id_number ⇒ Object
The government-issued ID number of the individual, as appropriate for the representative’s country. (Examples are a Social Security Number in the U.S., or a Social Insurance Number in Canada). Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).
1906 1907 1908 |
# File 'lib/stripe/params/account_create_params.rb', line 1906 def id_number @id_number end |
#id_number_secondary ⇒ Object
The government-issued secondary ID number of the individual, as appropriate for the representative’s country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).
1908 1909 1910 |
# File 'lib/stripe/params/account_create_params.rb', line 1908 def id_number_secondary @id_number_secondary end |
#last_name ⇒ Object
The individual’s last name.
1910 1911 1912 |
# File 'lib/stripe/params/account_create_params.rb', line 1910 def last_name @last_name end |
#last_name_kana ⇒ Object
The Kana variation of the individual’s last name (Japan only).
1912 1913 1914 |
# File 'lib/stripe/params/account_create_params.rb', line 1912 def last_name_kana @last_name_kana end |
#last_name_kanji ⇒ Object
The Kanji variation of the individual’s last name (Japan only).
1914 1915 1916 |
# File 'lib/stripe/params/account_create_params.rb', line 1914 def last_name_kanji @last_name_kanji end |
#maiden_name ⇒ Object
The individual’s maiden name.
1916 1917 1918 |
# File 'lib/stripe/params/account_create_params.rb', line 1916 def maiden_name @maiden_name end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
1918 1919 1920 |
# File 'lib/stripe/params/account_create_params.rb', line 1918 def @metadata end |
#phone ⇒ Object
The individual’s phone number.
1920 1921 1922 |
# File 'lib/stripe/params/account_create_params.rb', line 1920 def phone @phone end |
#political_exposure ⇒ Object
Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
1922 1923 1924 |
# File 'lib/stripe/params/account_create_params.rb', line 1922 def political_exposure @political_exposure end |
#registered_address ⇒ Object
The individual’s registered address.
1924 1925 1926 |
# File 'lib/stripe/params/account_create_params.rb', line 1924 def registered_address @registered_address end |
#relationship ⇒ Object
Describes the person’s relationship to the account.
1926 1927 1928 |
# File 'lib/stripe/params/account_create_params.rb', line 1926 def relationship @relationship end |
#ssn_last_4 ⇒ Object
The last four digits of the individual’s Social Security Number (U.S. only).
1928 1929 1930 |
# File 'lib/stripe/params/account_create_params.rb', line 1928 def ssn_last_4 @ssn_last_4 end |
#verification ⇒ Object
The individual’s verification document information.
1930 1931 1932 |
# File 'lib/stripe/params/account_create_params.rb', line 1930 def verification @verification end |