Class: Stripe::AccountCreateParams::Individual::Relationship
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountCreateParams::Individual::Relationship
- Defined in:
- lib/stripe/params/account_create_params.rb
Instance Attribute Summary collapse
-
#director ⇒ Object
Whether the person is a director of the account's legal entity.
-
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
-
#owner ⇒ Object
Whether the person is an owner of the account’s legal entity.
-
#percent_ownership ⇒ Object
The percent owned by the person of the account's legal entity.
-
#title ⇒ Object
The person's title (e.g., CEO, Support Engineer).
Instance Method Summary collapse
-
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
constructor
A new instance of Relationship.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
Returns a new instance of Relationship.
1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 1795 1796 |
# File 'lib/stripe/params/account_create_params.rb', line 1784 def initialize( director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil ) @director = director @executive = executive @owner = owner @percent_ownership = percent_ownership @title = title end |
Instance Attribute Details
#director ⇒ Object
Whether the person is a director of the account's legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.
1774 1775 1776 |
# File 'lib/stripe/params/account_create_params.rb', line 1774 def director @director end |
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
1776 1777 1778 |
# File 'lib/stripe/params/account_create_params.rb', line 1776 def executive @executive end |
#owner ⇒ Object
Whether the person is an owner of the account’s legal entity.
1778 1779 1780 |
# File 'lib/stripe/params/account_create_params.rb', line 1778 def owner @owner end |
#percent_ownership ⇒ Object
The percent owned by the person of the account's legal entity.
1780 1781 1782 |
# File 'lib/stripe/params/account_create_params.rb', line 1780 def percent_ownership @percent_ownership end |
#title ⇒ Object
The person's title (e.g., CEO, Support Engineer).
1782 1783 1784 |
# File 'lib/stripe/params/account_create_params.rb', line 1782 def title @title end |