Class: Stripe::AccountCreateParams::Individual::Relationship
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountCreateParams::Individual::Relationship
- Defined in:
- lib/stripe/params/account_create_params.rb
Instance Attribute Summary collapse
-
#director ⇒ Object
Whether the person is a director of the account’s legal entity.
-
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
-
#owner ⇒ Object
Whether the person is an owner of the account’s legal entity.
-
#percent_ownership ⇒ Object
The percent owned by the person of the account’s legal entity.
-
#title ⇒ Object
The person’s title (e.g., CEO, Support Engineer).
Instance Method Summary collapse
-
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
constructor
A new instance of Relationship.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
Returns a new instance of Relationship.
1965 1966 1967 1968 1969 1970 1971 1972 1973 1974 1975 1976 1977 |
# File 'lib/stripe/params/account_create_params.rb', line 1965 def initialize( director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil ) @director = director @executive = executive @owner = owner @percent_ownership = percent_ownership @title = title end |
Instance Attribute Details
#director ⇒ Object
Whether the person is a director of the account’s legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.
1955 1956 1957 |
# File 'lib/stripe/params/account_create_params.rb', line 1955 def director @director end |
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
1957 1958 1959 |
# File 'lib/stripe/params/account_create_params.rb', line 1957 def executive @executive end |
#owner ⇒ Object
Whether the person is an owner of the account’s legal entity.
1959 1960 1961 |
# File 'lib/stripe/params/account_create_params.rb', line 1959 def owner @owner end |
#percent_ownership ⇒ Object
The percent owned by the person of the account’s legal entity.
1961 1962 1963 |
# File 'lib/stripe/params/account_create_params.rb', line 1961 def percent_ownership @percent_ownership end |
#title ⇒ Object
The person’s title (e.g., CEO, Support Engineer).
1963 1964 1965 |
# File 'lib/stripe/params/account_create_params.rb', line 1963 def title @title end |