Class: Stripe::AccountCreateParams::Individual::Relationship
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountCreateParams::Individual::Relationship
- Defined in:
- lib/stripe/params/account_create_params.rb
Instance Attribute Summary collapse
-
#director ⇒ Object
Whether the person is a director of the account’s legal entity.
-
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
-
#owner ⇒ Object
Whether the person is an owner of the account’s legal entity.
-
#percent_ownership ⇒ Object
The percent owned by the person of the account’s legal entity.
-
#title ⇒ Object
The person’s title (e.g., CEO, Support Engineer).
Instance Method Summary collapse
-
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
constructor
A new instance of Relationship.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
Returns a new instance of Relationship.
1920 1921 1922 1923 1924 1925 1926 1927 1928 1929 1930 1931 1932 |
# File 'lib/stripe/params/account_create_params.rb', line 1920 def initialize( director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil ) @director = director @executive = executive @owner = owner @percent_ownership = percent_ownership @title = title end |
Instance Attribute Details
#director ⇒ Object
Whether the person is a director of the account’s legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.
1910 1911 1912 |
# File 'lib/stripe/params/account_create_params.rb', line 1910 def director @director end |
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
1912 1913 1914 |
# File 'lib/stripe/params/account_create_params.rb', line 1912 def executive @executive end |
#owner ⇒ Object
Whether the person is an owner of the account’s legal entity.
1914 1915 1916 |
# File 'lib/stripe/params/account_create_params.rb', line 1914 def owner @owner end |
#percent_ownership ⇒ Object
The percent owned by the person of the account’s legal entity.
1916 1917 1918 |
# File 'lib/stripe/params/account_create_params.rb', line 1916 def percent_ownership @percent_ownership end |
#title ⇒ Object
The person’s title (e.g., CEO, Support Engineer).
1918 1919 1920 |
# File 'lib/stripe/params/account_create_params.rb', line 1918 def title @title end |