Class: Stripe::AccountCreateParams::Individual::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship

Returns a new instance of Relationship.



1684
1685
1686
1687
1688
1689
1690
1691
1692
1693
1694
1695
1696
# File 'lib/stripe/params/account_create_params.rb', line 1684

def initialize(
  director: nil,
  executive: nil,
  owner: nil,
  percent_ownership: nil,
  title: nil
)
  @director = director
  @executive = executive
  @owner = owner
  @percent_ownership = percent_ownership
  @title = title
end

Instance Attribute Details

#directorObject

Whether the person is a director of the account’s legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



1674
1675
1676
# File 'lib/stripe/params/account_create_params.rb', line 1674

def director
  @director
end

#executiveObject

Whether the person has significant responsibility to control, manage, or direct the organization.



1676
1677
1678
# File 'lib/stripe/params/account_create_params.rb', line 1676

def executive
  @executive
end

#ownerObject

Whether the person is an owner of the account’s legal entity.



1678
1679
1680
# File 'lib/stripe/params/account_create_params.rb', line 1678

def owner
  @owner
end

#percent_ownershipObject

The percent owned by the person of the account’s legal entity.



1680
1681
1682
# File 'lib/stripe/params/account_create_params.rb', line 1680

def percent_ownership
  @percent_ownership
end

#titleObject

The person’s title (e.g., CEO, Support Engineer).



1682
1683
1684
# File 'lib/stripe/params/account_create_params.rb', line 1682

def title
  @title
end