Class: Stripe::AccountCreateParams::Individual::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship

Returns a new instance of Relationship.



1617
1618
1619
1620
1621
1622
1623
1624
1625
1626
1627
1628
1629
# File 'lib/stripe/params/account_create_params.rb', line 1617

def initialize(
  director: nil,
  executive: nil,
  owner: nil,
  percent_ownership: nil,
  title: nil
)
  @director = director
  @executive = executive
  @owner = owner
  @percent_ownership = percent_ownership
  @title = title
end

Instance Attribute Details

#directorObject

Whether the person is a director of the account’s legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



1607
1608
1609
# File 'lib/stripe/params/account_create_params.rb', line 1607

def director
  @director
end

#executiveObject

Whether the person has significant responsibility to control, manage, or direct the organization.



1609
1610
1611
# File 'lib/stripe/params/account_create_params.rb', line 1609

def executive
  @executive
end

#ownerObject

Whether the person is an owner of the account’s legal entity.



1611
1612
1613
# File 'lib/stripe/params/account_create_params.rb', line 1611

def owner
  @owner
end

#percent_ownershipObject

The percent owned by the person of the account’s legal entity.



1613
1614
1615
# File 'lib/stripe/params/account_create_params.rb', line 1613

def percent_ownership
  @percent_ownership
end

#titleObject

The person’s title (e.g., CEO, Support Engineer).



1615
1616
1617
# File 'lib/stripe/params/account_create_params.rb', line 1615

def title
  @title
end