Class: Stripe::AccountCreateParams::Individual::Verification::Document

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(back: nil, front: nil) ⇒ Document

Returns a new instance of Document.



1997
1998
1999
2000
# File 'lib/stripe/params/account_create_params.rb', line 1997

def initialize(back: nil, front: nil)
  @back = back
  @front = front
end

Instance Attribute Details

#backObject

The back of an ID returned by a [file upload](api.stripe.com#create_file) with a ‘purpose` value of `identity_document`. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.



1993
1994
1995
# File 'lib/stripe/params/account_create_params.rb', line 1993

def back
  @back
end

#frontObject

The front of an ID returned by a [file upload](api.stripe.com#create_file) with a ‘purpose` value of `identity_document`. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.



1995
1996
1997
# File 'lib/stripe/params/account_create_params.rb', line 1995

def front
  @front
end