Class: Stripe::AccountCreateParams::Settings

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/account_create_params.rb

Defined Under Namespace

Classes: BacsDebitPayments, BankBcaOnboarding, Branding, Capital, CardIssuing, CardPayments, Invoices, Payments, Payouts, PaypayPayments, SmartDisputes, TaxForms, Treasury

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, paypay_payments: nil, smart_disputes: nil, tax_forms: nil, treasury: nil) ⇒ Settings

Returns a new instance of Settings.



2573
2574
2575
2576
2577
2578
2579
2580
2581
2582
2583
2584
2585
2586
2587
2588
2589
2590
2591
2592
2593
2594
2595
2596
2597
2598
2599
2600
2601
# File 'lib/stripe/params/account_create_params.rb', line 2573

def initialize(
  bacs_debit_payments: nil,
  bank_bca_onboarding: nil,
  branding: nil,
  capital: nil,
  card_issuing: nil,
  card_payments: nil,
  invoices: nil,
  payments: nil,
  payouts: nil,
  paypay_payments: nil,
  smart_disputes: nil,
  tax_forms: nil,
  treasury: nil
)
  @bacs_debit_payments = bacs_debit_payments
  @bank_bca_onboarding = bank_bca_onboarding
  @branding = branding
  @capital = capital
  @card_issuing = card_issuing
  @card_payments = card_payments
  @invoices = invoices
  @payments = payments
  @payouts = payouts
  @paypay_payments = paypay_payments
  @smart_disputes = smart_disputes
  @tax_forms = tax_forms
  @treasury = treasury
end

Instance Attribute Details

#bacs_debit_paymentsObject

Settings specific to Bacs Direct Debit.



2547
2548
2549
# File 'lib/stripe/params/account_create_params.rb', line 2547

def bacs_debit_payments
  @bacs_debit_payments
end

#bank_bca_onboardingObject

Settings specific to bank BCA onboarding for Indonesia bank transfers payments method.



2549
2550
2551
# File 'lib/stripe/params/account_create_params.rb', line 2549

def bank_bca_onboarding
  @bank_bca_onboarding
end

#brandingObject

Settings used to apply the account's branding to email receipts, invoices, Checkout, and other products.



2551
2552
2553
# File 'lib/stripe/params/account_create_params.rb', line 2551

def branding
  @branding
end

#capitalObject

Settings specific to the account's use of the Capital product.



2553
2554
2555
# File 'lib/stripe/params/account_create_params.rb', line 2553

def capital
  @capital
end

#card_issuingObject

Settings specific to the account's use of the Card Issuing product.



2555
2556
2557
# File 'lib/stripe/params/account_create_params.rb', line 2555

def card_issuing
  @card_issuing
end

#card_paymentsObject

Settings specific to card charging on the account.



2557
2558
2559
# File 'lib/stripe/params/account_create_params.rb', line 2557

def card_payments
  @card_payments
end

#invoicesObject

Settings specific to the account’s use of Invoices.



2559
2560
2561
# File 'lib/stripe/params/account_create_params.rb', line 2559

def invoices
  @invoices
end

#paymentsObject

Settings that apply across payment methods for charging on the account.



2561
2562
2563
# File 'lib/stripe/params/account_create_params.rb', line 2561

def payments
  @payments
end

#payoutsObject

Settings specific to the account's payouts.



2563
2564
2565
# File 'lib/stripe/params/account_create_params.rb', line 2563

def payouts
  @payouts
end

#paypay_paymentsObject

Settings specific to the PayPay payments method.



2565
2566
2567
# File 'lib/stripe/params/account_create_params.rb', line 2565

def paypay_payments
  @paypay_payments
end

#smart_disputesObject

Settings specific to the account's use of Smart Disputes.



2567
2568
2569
# File 'lib/stripe/params/account_create_params.rb', line 2567

def smart_disputes
  @smart_disputes
end

#tax_formsObject

Settings specific to the account's tax forms.



2569
2570
2571
# File 'lib/stripe/params/account_create_params.rb', line 2569

def tax_forms
  @tax_forms
end

#treasuryObject

Settings specific to the account's Treasury FinancialAccounts.



2571
2572
2573
# File 'lib/stripe/params/account_create_params.rb', line 2571

def treasury
  @treasury
end