Class: Stripe::AccountCreateParams::Settings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountCreateParams::Settings
- Defined in:
- lib/stripe/params/account_create_params.rb
Defined Under Namespace
Classes: BacsDebitPayments, Branding, CardIssuing, CardPayments, Invoices, Payments, Payouts, Treasury
Instance Attribute Summary collapse
-
#bacs_debit_payments ⇒ Object
Settings specific to Bacs Direct Debit.
-
#branding ⇒ Object
Settings used to apply the account's branding to email receipts, invoices, Checkout, and other products.
-
#card_issuing ⇒ Object
Settings specific to the account's use of the Card Issuing product.
-
#card_payments ⇒ Object
Settings specific to card charging on the account.
-
#invoices ⇒ Object
Settings specific to the account’s use of Invoices.
-
#payments ⇒ Object
Settings that apply across payment methods for charging on the account.
-
#payouts ⇒ Object
Settings specific to the account's payouts.
-
#treasury ⇒ Object
Settings specific to the account's Treasury FinancialAccounts.
Instance Method Summary collapse
-
#initialize(bacs_debit_payments: nil, branding: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, treasury: nil) ⇒ Settings
constructor
A new instance of Settings.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(bacs_debit_payments: nil, branding: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, treasury: nil) ⇒ Settings
Returns a new instance of Settings.
2128 2129 2130 2131 2132 2133 2134 2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 |
# File 'lib/stripe/params/account_create_params.rb', line 2128 def initialize( bacs_debit_payments: nil, branding: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, treasury: nil ) @bacs_debit_payments = bacs_debit_payments @branding = branding @card_issuing = card_issuing @card_payments = card_payments @invoices = invoices @payments = payments @payouts = payouts @treasury = treasury end |
Instance Attribute Details
#bacs_debit_payments ⇒ Object
Settings specific to Bacs Direct Debit.
2112 2113 2114 |
# File 'lib/stripe/params/account_create_params.rb', line 2112 def bacs_debit_payments @bacs_debit_payments end |
#branding ⇒ Object
Settings used to apply the account's branding to email receipts, invoices, Checkout, and other products.
2114 2115 2116 |
# File 'lib/stripe/params/account_create_params.rb', line 2114 def branding @branding end |
#card_issuing ⇒ Object
Settings specific to the account's use of the Card Issuing product.
2116 2117 2118 |
# File 'lib/stripe/params/account_create_params.rb', line 2116 def card_issuing @card_issuing end |
#card_payments ⇒ Object
Settings specific to card charging on the account.
2118 2119 2120 |
# File 'lib/stripe/params/account_create_params.rb', line 2118 def card_payments @card_payments end |
#invoices ⇒ Object
Settings specific to the account’s use of Invoices.
2120 2121 2122 |
# File 'lib/stripe/params/account_create_params.rb', line 2120 def invoices @invoices end |
#payments ⇒ Object
Settings that apply across payment methods for charging on the account.
2122 2123 2124 |
# File 'lib/stripe/params/account_create_params.rb', line 2122 def payments @payments end |
#payouts ⇒ Object
Settings specific to the account's payouts.
2124 2125 2126 |
# File 'lib/stripe/params/account_create_params.rb', line 2124 def payouts @payouts end |
#treasury ⇒ Object
Settings specific to the account's Treasury FinancialAccounts.
2126 2127 2128 |
# File 'lib/stripe/params/account_create_params.rb', line 2126 def treasury @treasury end |