Class: Stripe::AccountCreateParams::Settings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountCreateParams::Settings
- Defined in:
- lib/stripe/params/account_create_params.rb
Defined Under Namespace
Classes: BacsDebitPayments, BankBcaOnboarding, Branding, Capital, CardIssuing, CardPayments, Invoices, Payments, Payouts, PaypayPayments, SmartDisputes, TaxForms, Treasury
Instance Attribute Summary collapse
-
#bacs_debit_payments ⇒ Object
Settings specific to Bacs Direct Debit.
-
#bank_bca_onboarding ⇒ Object
Settings specific to bank BCA onboarding for Indonesia bank transfers payments method.
-
#branding ⇒ Object
Settings used to apply the account's branding to email receipts, invoices, Checkout, and other products.
-
#capital ⇒ Object
Settings specific to the account's use of the Capital product.
-
#card_issuing ⇒ Object
Settings specific to the account's use of the Card Issuing product.
-
#card_payments ⇒ Object
Settings specific to card charging on the account.
-
#invoices ⇒ Object
Settings specific to the account’s use of Invoices.
-
#payments ⇒ Object
Settings that apply across payment methods for charging on the account.
-
#payouts ⇒ Object
Settings specific to the account's payouts.
-
#paypay_payments ⇒ Object
Settings specific to the PayPay payments method.
-
#smart_disputes ⇒ Object
Settings specific to the account's use of Smart Disputes.
-
#tax_forms ⇒ Object
Settings specific to the account's tax forms.
-
#treasury ⇒ Object
Settings specific to the account's Treasury FinancialAccounts.
Instance Method Summary collapse
-
#initialize(bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, paypay_payments: nil, smart_disputes: nil, tax_forms: nil, treasury: nil) ⇒ Settings
constructor
A new instance of Settings.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, paypay_payments: nil, smart_disputes: nil, tax_forms: nil, treasury: nil) ⇒ Settings
Returns a new instance of Settings.
2487 2488 2489 2490 2491 2492 2493 2494 2495 2496 2497 2498 2499 2500 2501 2502 2503 2504 2505 2506 2507 2508 2509 2510 2511 2512 2513 2514 2515 |
# File 'lib/stripe/params/account_create_params.rb', line 2487 def initialize( bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, paypay_payments: nil, smart_disputes: nil, tax_forms: nil, treasury: nil ) @bacs_debit_payments = bacs_debit_payments @bank_bca_onboarding = bank_bca_onboarding @branding = branding @capital = capital @card_issuing = card_issuing @card_payments = card_payments @invoices = invoices @payments = payments @payouts = payouts @paypay_payments = paypay_payments @smart_disputes = smart_disputes @tax_forms = tax_forms @treasury = treasury end |
Instance Attribute Details
#bacs_debit_payments ⇒ Object
Settings specific to Bacs Direct Debit.
2461 2462 2463 |
# File 'lib/stripe/params/account_create_params.rb', line 2461 def bacs_debit_payments @bacs_debit_payments end |
#bank_bca_onboarding ⇒ Object
Settings specific to bank BCA onboarding for Indonesia bank transfers payments method.
2463 2464 2465 |
# File 'lib/stripe/params/account_create_params.rb', line 2463 def bank_bca_onboarding @bank_bca_onboarding end |
#branding ⇒ Object
Settings used to apply the account's branding to email receipts, invoices, Checkout, and other products.
2465 2466 2467 |
# File 'lib/stripe/params/account_create_params.rb', line 2465 def branding @branding end |
#capital ⇒ Object
Settings specific to the account's use of the Capital product.
2467 2468 2469 |
# File 'lib/stripe/params/account_create_params.rb', line 2467 def capital @capital end |
#card_issuing ⇒ Object
Settings specific to the account's use of the Card Issuing product.
2469 2470 2471 |
# File 'lib/stripe/params/account_create_params.rb', line 2469 def card_issuing @card_issuing end |
#card_payments ⇒ Object
Settings specific to card charging on the account.
2471 2472 2473 |
# File 'lib/stripe/params/account_create_params.rb', line 2471 def card_payments @card_payments end |
#invoices ⇒ Object
Settings specific to the account’s use of Invoices.
2473 2474 2475 |
# File 'lib/stripe/params/account_create_params.rb', line 2473 def invoices @invoices end |
#payments ⇒ Object
Settings that apply across payment methods for charging on the account.
2475 2476 2477 |
# File 'lib/stripe/params/account_create_params.rb', line 2475 def payments @payments end |
#payouts ⇒ Object
Settings specific to the account's payouts.
2477 2478 2479 |
# File 'lib/stripe/params/account_create_params.rb', line 2477 def payouts @payouts end |
#paypay_payments ⇒ Object
Settings specific to the PayPay payments method.
2479 2480 2481 |
# File 'lib/stripe/params/account_create_params.rb', line 2479 def paypay_payments @paypay_payments end |
#smart_disputes ⇒ Object
Settings specific to the account's use of Smart Disputes.
2481 2482 2483 |
# File 'lib/stripe/params/account_create_params.rb', line 2481 def smart_disputes @smart_disputes end |
#tax_forms ⇒ Object
Settings specific to the account's tax forms.
2483 2484 2485 |
# File 'lib/stripe/params/account_create_params.rb', line 2483 def tax_forms @tax_forms end |
#treasury ⇒ Object
Settings specific to the account's Treasury FinancialAccounts.
2485 2486 2487 |
# File 'lib/stripe/params/account_create_params.rb', line 2485 def treasury @treasury end |