Class: Stripe::AccountCreateParams::Settings

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/account_create_params.rb

Defined Under Namespace

Classes: BacsDebitPayments, BankBcaOnboarding, Branding, Capital, CardIssuing, CardPayments, Invoices, Payments, Payouts, PaypayPayments, SmartDisputes, TaxForms, Treasury

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, paypay_payments: nil, smart_disputes: nil, tax_forms: nil, treasury: nil) ⇒ Settings

Returns a new instance of Settings.



2525
2526
2527
2528
2529
2530
2531
2532
2533
2534
2535
2536
2537
2538
2539
2540
2541
2542
2543
2544
2545
2546
2547
2548
2549
2550
2551
2552
2553
# File 'lib/stripe/params/account_create_params.rb', line 2525

def initialize(
  bacs_debit_payments: nil,
  bank_bca_onboarding: nil,
  branding: nil,
  capital: nil,
  card_issuing: nil,
  card_payments: nil,
  invoices: nil,
  payments: nil,
  payouts: nil,
  paypay_payments: nil,
  smart_disputes: nil,
  tax_forms: nil,
  treasury: nil
)
  @bacs_debit_payments = bacs_debit_payments
  @bank_bca_onboarding = bank_bca_onboarding
  @branding = branding
  @capital = capital
  @card_issuing = card_issuing
  @card_payments = card_payments
  @invoices = invoices
  @payments = payments
  @payouts = payouts
  @paypay_payments = paypay_payments
  @smart_disputes = smart_disputes
  @tax_forms = tax_forms
  @treasury = treasury
end

Instance Attribute Details

#bacs_debit_paymentsObject

Settings specific to Bacs Direct Debit.



2499
2500
2501
# File 'lib/stripe/params/account_create_params.rb', line 2499

def bacs_debit_payments
  @bacs_debit_payments
end

#bank_bca_onboardingObject

Settings specific to bank BCA onboarding for Indonesia bank transfers payments method.



2501
2502
2503
# File 'lib/stripe/params/account_create_params.rb', line 2501

def bank_bca_onboarding
  @bank_bca_onboarding
end

#brandingObject

Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.



2503
2504
2505
# File 'lib/stripe/params/account_create_params.rb', line 2503

def branding
  @branding
end

#capitalObject

Settings specific to the account’s use of the Capital product.



2505
2506
2507
# File 'lib/stripe/params/account_create_params.rb', line 2505

def capital
  @capital
end

#card_issuingObject

Settings specific to the account’s use of the Card Issuing product.



2507
2508
2509
# File 'lib/stripe/params/account_create_params.rb', line 2507

def card_issuing
  @card_issuing
end

#card_paymentsObject

Settings specific to card charging on the account.



2509
2510
2511
# File 'lib/stripe/params/account_create_params.rb', line 2509

def card_payments
  @card_payments
end

#invoicesObject

Settings specific to the account’s use of Invoices.



2511
2512
2513
# File 'lib/stripe/params/account_create_params.rb', line 2511

def invoices
  @invoices
end

#paymentsObject

Settings that apply across payment methods for charging on the account.



2513
2514
2515
# File 'lib/stripe/params/account_create_params.rb', line 2513

def payments
  @payments
end

#payoutsObject

Settings specific to the account’s payouts.



2515
2516
2517
# File 'lib/stripe/params/account_create_params.rb', line 2515

def payouts
  @payouts
end

#paypay_paymentsObject

Settings specific to the PayPay payments method.



2517
2518
2519
# File 'lib/stripe/params/account_create_params.rb', line 2517

def paypay_payments
  @paypay_payments
end

#smart_disputesObject

Settings specific to the account’s use of Smart Disputes.



2519
2520
2521
# File 'lib/stripe/params/account_create_params.rb', line 2519

def smart_disputes
  @smart_disputes
end

#tax_formsObject

Settings specific to the account’s tax forms.



2521
2522
2523
# File 'lib/stripe/params/account_create_params.rb', line 2521

def tax_forms
  @tax_forms
end

#treasuryObject

Settings specific to the account’s Treasury FinancialAccounts.



2523
2524
2525
# File 'lib/stripe/params/account_create_params.rb', line 2523

def treasury
  @treasury
end