Class: Stripe::AccountCreateParams::Settings

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/account_create_params.rb

Defined Under Namespace

Classes: BacsDebitPayments, Branding, CardIssuing, CardPayments, Invoices, Payments, Payouts, Treasury

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(bacs_debit_payments: nil, branding: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, treasury: nil) ⇒ Settings

Returns a new instance of Settings.



2080
2081
2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
2092
2093
2094
2095
2096
2097
2098
# File 'lib/stripe/params/account_create_params.rb', line 2080

def initialize(
  bacs_debit_payments: nil,
  branding: nil,
  card_issuing: nil,
  card_payments: nil,
  invoices: nil,
  payments: nil,
  payouts: nil,
  treasury: nil
)
  @bacs_debit_payments = bacs_debit_payments
  @branding = branding
  @card_issuing = card_issuing
  @card_payments = card_payments
  @invoices = invoices
  @payments = payments
  @payouts = payouts
  @treasury = treasury
end

Instance Attribute Details

#bacs_debit_paymentsObject

Settings specific to Bacs Direct Debit.



2064
2065
2066
# File 'lib/stripe/params/account_create_params.rb', line 2064

def bacs_debit_payments
  @bacs_debit_payments
end

#brandingObject

Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.



2066
2067
2068
# File 'lib/stripe/params/account_create_params.rb', line 2066

def branding
  @branding
end

#card_issuingObject

Settings specific to the account’s use of the Card Issuing product.



2068
2069
2070
# File 'lib/stripe/params/account_create_params.rb', line 2068

def card_issuing
  @card_issuing
end

#card_paymentsObject

Settings specific to card charging on the account.



2070
2071
2072
# File 'lib/stripe/params/account_create_params.rb', line 2070

def card_payments
  @card_payments
end

#invoicesObject

Settings specific to the account’s use of Invoices.



2072
2073
2074
# File 'lib/stripe/params/account_create_params.rb', line 2072

def invoices
  @invoices
end

#paymentsObject

Settings that apply across payment methods for charging on the account.



2074
2075
2076
# File 'lib/stripe/params/account_create_params.rb', line 2074

def payments
  @payments
end

#payoutsObject

Settings specific to the account’s payouts.



2076
2077
2078
# File 'lib/stripe/params/account_create_params.rb', line 2076

def payouts
  @payouts
end

#treasuryObject

Settings specific to the account’s Treasury FinancialAccounts.



2078
2079
2080
# File 'lib/stripe/params/account_create_params.rb', line 2078

def treasury
  @treasury
end