Class: Stripe::AccountCreateParams::Settings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountCreateParams::Settings
- Defined in:
- lib/stripe/params/account_create_params.rb
Defined Under Namespace
Classes: BacsDebitPayments, BankBcaOnboarding, Branding, Capital, CardIssuing, CardPayments, Invoices, Payments, Payouts, PaypayPayments, SmartDisputes, TaxForms, Treasury
Instance Attribute Summary collapse
-
#bacs_debit_payments ⇒ Object
Settings specific to Bacs Direct Debit.
-
#bank_bca_onboarding ⇒ Object
Settings specific to bank BCA onboarding for Indonesia bank transfers payments method.
-
#branding ⇒ Object
Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.
-
#capital ⇒ Object
Settings specific to the account’s use of the Capital product.
-
#card_issuing ⇒ Object
Settings specific to the account’s use of the Card Issuing product.
-
#card_payments ⇒ Object
Settings specific to card charging on the account.
-
#invoices ⇒ Object
Settings specific to the account’s use of Invoices.
-
#payments ⇒ Object
Settings that apply across payment methods for charging on the account.
-
#payouts ⇒ Object
Settings specific to the account’s payouts.
-
#paypay_payments ⇒ Object
Settings specific to the PayPay payments method.
-
#smart_disputes ⇒ Object
Settings specific to the account’s use of Smart Disputes.
-
#tax_forms ⇒ Object
Settings specific to the account’s tax forms.
-
#treasury ⇒ Object
Settings specific to the account’s Treasury FinancialAccounts.
Instance Method Summary collapse
-
#initialize(bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, paypay_payments: nil, smart_disputes: nil, tax_forms: nil, treasury: nil) ⇒ Settings
constructor
A new instance of Settings.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, paypay_payments: nil, smart_disputes: nil, tax_forms: nil, treasury: nil) ⇒ Settings
Returns a new instance of Settings.
2419 2420 2421 2422 2423 2424 2425 2426 2427 2428 2429 2430 2431 2432 2433 2434 2435 2436 2437 2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 |
# File 'lib/stripe/params/account_create_params.rb', line 2419 def initialize( bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, paypay_payments: nil, smart_disputes: nil, tax_forms: nil, treasury: nil ) @bacs_debit_payments = bacs_debit_payments @bank_bca_onboarding = bank_bca_onboarding @branding = branding @capital = capital @card_issuing = card_issuing @card_payments = card_payments @invoices = invoices @payments = payments @payouts = payouts @paypay_payments = paypay_payments @smart_disputes = smart_disputes @tax_forms = tax_forms @treasury = treasury end |
Instance Attribute Details
#bacs_debit_payments ⇒ Object
Settings specific to Bacs Direct Debit.
2393 2394 2395 |
# File 'lib/stripe/params/account_create_params.rb', line 2393 def bacs_debit_payments @bacs_debit_payments end |
#bank_bca_onboarding ⇒ Object
Settings specific to bank BCA onboarding for Indonesia bank transfers payments method.
2395 2396 2397 |
# File 'lib/stripe/params/account_create_params.rb', line 2395 def bank_bca_onboarding @bank_bca_onboarding end |
#branding ⇒ Object
Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.
2397 2398 2399 |
# File 'lib/stripe/params/account_create_params.rb', line 2397 def branding @branding end |
#capital ⇒ Object
Settings specific to the account’s use of the Capital product.
2399 2400 2401 |
# File 'lib/stripe/params/account_create_params.rb', line 2399 def capital @capital end |
#card_issuing ⇒ Object
Settings specific to the account’s use of the Card Issuing product.
2401 2402 2403 |
# File 'lib/stripe/params/account_create_params.rb', line 2401 def card_issuing @card_issuing end |
#card_payments ⇒ Object
Settings specific to card charging on the account.
2403 2404 2405 |
# File 'lib/stripe/params/account_create_params.rb', line 2403 def card_payments @card_payments end |
#invoices ⇒ Object
Settings specific to the account’s use of Invoices.
2405 2406 2407 |
# File 'lib/stripe/params/account_create_params.rb', line 2405 def invoices @invoices end |
#payments ⇒ Object
Settings that apply across payment methods for charging on the account.
2407 2408 2409 |
# File 'lib/stripe/params/account_create_params.rb', line 2407 def payments @payments end |
#payouts ⇒ Object
Settings specific to the account’s payouts.
2409 2410 2411 |
# File 'lib/stripe/params/account_create_params.rb', line 2409 def payouts @payouts end |
#paypay_payments ⇒ Object
Settings specific to the PayPay payments method.
2411 2412 2413 |
# File 'lib/stripe/params/account_create_params.rb', line 2411 def paypay_payments @paypay_payments end |
#smart_disputes ⇒ Object
Settings specific to the account’s use of Smart Disputes.
2413 2414 2415 |
# File 'lib/stripe/params/account_create_params.rb', line 2413 def smart_disputes @smart_disputes end |
#tax_forms ⇒ Object
Settings specific to the account’s tax forms.
2415 2416 2417 |
# File 'lib/stripe/params/account_create_params.rb', line 2415 def tax_forms @tax_forms end |
#treasury ⇒ Object
Settings specific to the account’s Treasury FinancialAccounts.
2417 2418 2419 |
# File 'lib/stripe/params/account_create_params.rb', line 2417 def treasury @treasury end |