Class: Stripe::AccountCreateParams::Settings

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/account_create_params.rb

Defined Under Namespace

Classes: BacsDebitPayments, BankBcaOnboarding, Branding, Capital, CardIssuing, CardPayments, Invoices, Payments, Payouts, PaypayPayments, SmartDisputes, TaxForms, Treasury

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, paypay_payments: nil, smart_disputes: nil, tax_forms: nil, treasury: nil) ⇒ Settings

Returns a new instance of Settings.



2406
2407
2408
2409
2410
2411
2412
2413
2414
2415
2416
2417
2418
2419
2420
2421
2422
2423
2424
2425
2426
2427
2428
2429
2430
2431
2432
2433
2434
# File 'lib/stripe/params/account_create_params.rb', line 2406

def initialize(
  bacs_debit_payments: nil,
  bank_bca_onboarding: nil,
  branding: nil,
  capital: nil,
  card_issuing: nil,
  card_payments: nil,
  invoices: nil,
  payments: nil,
  payouts: nil,
  paypay_payments: nil,
  smart_disputes: nil,
  tax_forms: nil,
  treasury: nil
)
  @bacs_debit_payments = bacs_debit_payments
  @bank_bca_onboarding = bank_bca_onboarding
  @branding = branding
  @capital = capital
  @card_issuing = card_issuing
  @card_payments = card_payments
  @invoices = invoices
  @payments = payments
  @payouts = payouts
  @paypay_payments = paypay_payments
  @smart_disputes = smart_disputes
  @tax_forms = tax_forms
  @treasury = treasury
end

Instance Attribute Details

#bacs_debit_paymentsObject

Settings specific to Bacs Direct Debit.



2380
2381
2382
# File 'lib/stripe/params/account_create_params.rb', line 2380

def bacs_debit_payments
  @bacs_debit_payments
end

#bank_bca_onboardingObject

Settings specific to bank BCA onboarding for Indonesia bank transfers payments method.



2382
2383
2384
# File 'lib/stripe/params/account_create_params.rb', line 2382

def bank_bca_onboarding
  @bank_bca_onboarding
end

#brandingObject

Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.



2384
2385
2386
# File 'lib/stripe/params/account_create_params.rb', line 2384

def branding
  @branding
end

#capitalObject

Settings specific to the account’s use of the Capital product.



2386
2387
2388
# File 'lib/stripe/params/account_create_params.rb', line 2386

def capital
  @capital
end

#card_issuingObject

Settings specific to the account’s use of the Card Issuing product.



2388
2389
2390
# File 'lib/stripe/params/account_create_params.rb', line 2388

def card_issuing
  @card_issuing
end

#card_paymentsObject

Settings specific to card charging on the account.



2390
2391
2392
# File 'lib/stripe/params/account_create_params.rb', line 2390

def card_payments
  @card_payments
end

#invoicesObject

Settings specific to the account’s use of Invoices.



2392
2393
2394
# File 'lib/stripe/params/account_create_params.rb', line 2392

def invoices
  @invoices
end

#paymentsObject

Settings that apply across payment methods for charging on the account.



2394
2395
2396
# File 'lib/stripe/params/account_create_params.rb', line 2394

def payments
  @payments
end

#payoutsObject

Settings specific to the account’s payouts.



2396
2397
2398
# File 'lib/stripe/params/account_create_params.rb', line 2396

def payouts
  @payouts
end

#paypay_paymentsObject

Settings specific to the PayPay payments method.



2398
2399
2400
# File 'lib/stripe/params/account_create_params.rb', line 2398

def paypay_payments
  @paypay_payments
end

#smart_disputesObject

Settings specific to the account’s use of Smart Disputes.



2400
2401
2402
# File 'lib/stripe/params/account_create_params.rb', line 2400

def smart_disputes
  @smart_disputes
end

#tax_formsObject

Settings specific to the account’s tax forms.



2402
2403
2404
# File 'lib/stripe/params/account_create_params.rb', line 2402

def tax_forms
  @tax_forms
end

#treasuryObject

Settings specific to the account’s Treasury FinancialAccounts.



2404
2405
2406
# File 'lib/stripe/params/account_create_params.rb', line 2404

def treasury
  @treasury
end