Class: Stripe::AccountCreateParams::Settings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountCreateParams::Settings
- Defined in:
- lib/stripe/params/account_create_params.rb
Defined Under Namespace
Classes: BacsDebitPayments, BankBcaOnboarding, Branding, Capital, CardIssuing, CardPayments, Invoices, Payments, Payouts, PaypayPayments, TaxForms, Treasury
Instance Attribute Summary collapse
-
#bacs_debit_payments ⇒ Object
Settings specific to Bacs Direct Debit.
-
#bank_bca_onboarding ⇒ Object
Settings specific to bank BCA onboarding for Indonesia bank transfers payments method.
-
#branding ⇒ Object
Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.
-
#capital ⇒ Object
Settings specific to the account’s use of the Capital product.
-
#card_issuing ⇒ Object
Settings specific to the account’s use of the Card Issuing product.
-
#card_payments ⇒ Object
Settings specific to card charging on the account.
-
#invoices ⇒ Object
Settings specific to the account’s use of Invoices.
-
#payments ⇒ Object
Settings that apply across payment methods for charging on the account.
-
#payouts ⇒ Object
Settings specific to the account’s payouts.
-
#paypay_payments ⇒ Object
Settings specific to the PayPay payments method.
-
#tax_forms ⇒ Object
Settings specific to the account’s tax forms.
-
#treasury ⇒ Object
Settings specific to the account’s Treasury FinancialAccounts.
Instance Method Summary collapse
-
#initialize(bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, paypay_payments: nil, tax_forms: nil, treasury: nil) ⇒ Settings
constructor
A new instance of Settings.
Methods inherited from RequestParams
Constructor Details
#initialize(bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, paypay_payments: nil, tax_forms: nil, treasury: nil) ⇒ Settings
Returns a new instance of Settings.
2383 2384 2385 2386 2387 2388 2389 2390 2391 2392 2393 2394 2395 2396 2397 2398 2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 |
# File 'lib/stripe/params/account_create_params.rb', line 2383 def initialize( bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, paypay_payments: nil, tax_forms: nil, treasury: nil ) @bacs_debit_payments = bacs_debit_payments @bank_bca_onboarding = bank_bca_onboarding @branding = branding @capital = capital @card_issuing = card_issuing @card_payments = card_payments @invoices = invoices @payments = payments @payouts = payouts @paypay_payments = paypay_payments @tax_forms = tax_forms @treasury = treasury end |
Instance Attribute Details
#bacs_debit_payments ⇒ Object
Settings specific to Bacs Direct Debit.
2359 2360 2361 |
# File 'lib/stripe/params/account_create_params.rb', line 2359 def bacs_debit_payments @bacs_debit_payments end |
#bank_bca_onboarding ⇒ Object
Settings specific to bank BCA onboarding for Indonesia bank transfers payments method.
2361 2362 2363 |
# File 'lib/stripe/params/account_create_params.rb', line 2361 def bank_bca_onboarding @bank_bca_onboarding end |
#branding ⇒ Object
Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.
2363 2364 2365 |
# File 'lib/stripe/params/account_create_params.rb', line 2363 def branding @branding end |
#capital ⇒ Object
Settings specific to the account’s use of the Capital product.
2365 2366 2367 |
# File 'lib/stripe/params/account_create_params.rb', line 2365 def capital @capital end |
#card_issuing ⇒ Object
Settings specific to the account’s use of the Card Issuing product.
2367 2368 2369 |
# File 'lib/stripe/params/account_create_params.rb', line 2367 def card_issuing @card_issuing end |
#card_payments ⇒ Object
Settings specific to card charging on the account.
2369 2370 2371 |
# File 'lib/stripe/params/account_create_params.rb', line 2369 def card_payments @card_payments end |
#invoices ⇒ Object
Settings specific to the account’s use of Invoices.
2371 2372 2373 |
# File 'lib/stripe/params/account_create_params.rb', line 2371 def invoices @invoices end |
#payments ⇒ Object
Settings that apply across payment methods for charging on the account.
2373 2374 2375 |
# File 'lib/stripe/params/account_create_params.rb', line 2373 def payments @payments end |
#payouts ⇒ Object
Settings specific to the account’s payouts.
2375 2376 2377 |
# File 'lib/stripe/params/account_create_params.rb', line 2375 def payouts @payouts end |
#paypay_payments ⇒ Object
Settings specific to the PayPay payments method.
2377 2378 2379 |
# File 'lib/stripe/params/account_create_params.rb', line 2377 def paypay_payments @paypay_payments end |
#tax_forms ⇒ Object
Settings specific to the account’s tax forms.
2379 2380 2381 |
# File 'lib/stripe/params/account_create_params.rb', line 2379 def tax_forms @tax_forms end |
#treasury ⇒ Object
Settings specific to the account’s Treasury FinancialAccounts.
2381 2382 2383 |
# File 'lib/stripe/params/account_create_params.rb', line 2381 def treasury @treasury end |