Class: Stripe::AccountCreateParams::Settings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountCreateParams::Settings
- Defined in:
- lib/stripe/params/account_create_params.rb
Defined Under Namespace
Classes: BacsDebitPayments, BankBcaOnboarding, Branding, Capital, CardIssuing, CardPayments, Invoices, Payments, Payouts, PaypayPayments, TaxForms, Treasury
Instance Attribute Summary collapse
-
#bacs_debit_payments ⇒ Object
Settings specific to Bacs Direct Debit.
-
#bank_bca_onboarding ⇒ Object
Settings specific to bank BCA onboarding for Indonesia bank transfers payments method.
-
#branding ⇒ Object
Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.
-
#capital ⇒ Object
Settings specific to the account’s use of the Capital product.
-
#card_issuing ⇒ Object
Settings specific to the account’s use of the Card Issuing product.
-
#card_payments ⇒ Object
Settings specific to card charging on the account.
-
#invoices ⇒ Object
Settings specific to the account’s use of Invoices.
-
#payments ⇒ Object
Settings that apply across payment methods for charging on the account.
-
#payouts ⇒ Object
Settings specific to the account’s payouts.
-
#paypay_payments ⇒ Object
Settings specific to the PayPay payments method.
-
#tax_forms ⇒ Object
Settings specific to the account’s tax forms.
-
#treasury ⇒ Object
Settings specific to the account’s Treasury FinancialAccounts.
Instance Method Summary collapse
-
#initialize(bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, paypay_payments: nil, tax_forms: nil, treasury: nil) ⇒ Settings
constructor
A new instance of Settings.
Methods inherited from RequestParams
Constructor Details
#initialize(bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, paypay_payments: nil, tax_forms: nil, treasury: nil) ⇒ Settings
Returns a new instance of Settings.
2316 2317 2318 2319 2320 2321 2322 2323 2324 2325 2326 2327 2328 2329 2330 2331 2332 2333 2334 2335 2336 2337 2338 2339 2340 2341 2342 |
# File 'lib/stripe/params/account_create_params.rb', line 2316 def initialize( bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, paypay_payments: nil, tax_forms: nil, treasury: nil ) @bacs_debit_payments = bacs_debit_payments @bank_bca_onboarding = bank_bca_onboarding @branding = branding @capital = capital @card_issuing = card_issuing @card_payments = card_payments @invoices = invoices @payments = payments @payouts = payouts @paypay_payments = paypay_payments @tax_forms = tax_forms @treasury = treasury end |
Instance Attribute Details
#bacs_debit_payments ⇒ Object
Settings specific to Bacs Direct Debit.
2292 2293 2294 |
# File 'lib/stripe/params/account_create_params.rb', line 2292 def bacs_debit_payments @bacs_debit_payments end |
#bank_bca_onboarding ⇒ Object
Settings specific to bank BCA onboarding for Indonesia bank transfers payments method.
2294 2295 2296 |
# File 'lib/stripe/params/account_create_params.rb', line 2294 def bank_bca_onboarding @bank_bca_onboarding end |
#branding ⇒ Object
Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.
2296 2297 2298 |
# File 'lib/stripe/params/account_create_params.rb', line 2296 def branding @branding end |
#capital ⇒ Object
Settings specific to the account’s use of the Capital product.
2298 2299 2300 |
# File 'lib/stripe/params/account_create_params.rb', line 2298 def capital @capital end |
#card_issuing ⇒ Object
Settings specific to the account’s use of the Card Issuing product.
2300 2301 2302 |
# File 'lib/stripe/params/account_create_params.rb', line 2300 def card_issuing @card_issuing end |
#card_payments ⇒ Object
Settings specific to card charging on the account.
2302 2303 2304 |
# File 'lib/stripe/params/account_create_params.rb', line 2302 def card_payments @card_payments end |
#invoices ⇒ Object
Settings specific to the account’s use of Invoices.
2304 2305 2306 |
# File 'lib/stripe/params/account_create_params.rb', line 2304 def invoices @invoices end |
#payments ⇒ Object
Settings that apply across payment methods for charging on the account.
2306 2307 2308 |
# File 'lib/stripe/params/account_create_params.rb', line 2306 def payments @payments end |
#payouts ⇒ Object
Settings specific to the account’s payouts.
2308 2309 2310 |
# File 'lib/stripe/params/account_create_params.rb', line 2308 def payouts @payouts end |
#paypay_payments ⇒ Object
Settings specific to the PayPay payments method.
2310 2311 2312 |
# File 'lib/stripe/params/account_create_params.rb', line 2310 def paypay_payments @paypay_payments end |
#tax_forms ⇒ Object
Settings specific to the account’s tax forms.
2312 2313 2314 |
# File 'lib/stripe/params/account_create_params.rb', line 2312 def tax_forms @tax_forms end |
#treasury ⇒ Object
Settings specific to the account’s Treasury FinancialAccounts.
2314 2315 2316 |
# File 'lib/stripe/params/account_create_params.rb', line 2314 def treasury @treasury end |